%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%CASE6515RTE
%   AC Power flow data for French system.
%   Please see CASEFORMAT for details on the case file format.
%
%   This case accurately represents the size and complexity of French
%   very high voltage and high voltage transmission network.
%   These data are snapshots of French VHV+HV grid in 2013.
%   These data can be used to validate mathematical methods and tools.
%   These data should NOT be used for operation
%   nor planning of the French or European grids.
%
%   When publishing results using this data, please cite:
%     C. Josz, S. Fliscounakis, J. Maeght, and P. Panciatici,
%     "AC Power Flow Data in MATPOWER and QCQP Format: iTesla, RTE Snapshots, and PEGASE"
%     http://arxiv.org/abs/1603.01533
%
%   Contacts (primary contact for this file : Jean Maeght):
%   Cédric Josz, Stéphane Fliscounakis, Jean Maeght, Patrick Panciatici
%   firstname.lastname@rte-france.com
%   Réseau de Transport d'Electricité (French Transmission System Operator)
%   Département Expertise Système, Immeuble "Le Colbert"
%   9 rue de la Porte de Buc, 78000 Versailles Cedex, France
%   March 4th, 2016
%
%   Copyright (c) 2016 by Cédric Josz, Stéphane Fliscounakis, Jean Maeght,
%   and Patrick Panciatici
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case6515_rte
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3	 1	 14.8	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4	 1	 49.6	 2.8	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	5	 1	 12.9	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	6	 1	 13.0	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	7	 1	 2.3	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	8	 1	 15.8	 -0.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	9	 1	 14.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	10	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	11	 1	 33.2	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	12	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	13	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07767	    0.00000	 380.0	 1	    1.10263	    1.05271;
	14	 1	 63.2	 13.3	 0.0	 30.4	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	15	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	16	 1	 13.9	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	17	 1	 10.9	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	18	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	19	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	20	 1	 5.6	 -18.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	21	 1	 7.6	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	22	 1	 18.5	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	23	 1	 22.4	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	24	 1	 17.0	 -1.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	25	 1	 54.7	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	26	 1	 15.1	 10.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	27	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	28	 1	 0.9	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	29	 1	 76.5	 9.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	30	 1	 39.9	 3.5	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	31	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	32	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	33	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	34	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	35	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	36	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	37	 1	 -2.7	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	38	 1	 5.0	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	39	 1	 43.6	 -2.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	40	 1	 38.1	 4.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	41	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	42	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04169	    0.00000	 63.0	 1	    1.13099	    0.95238;
	43	 1	 3.2	 2.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	44	 1	 13.3	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	45	 1	 3.8	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	46	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	47	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	48	 1	 40.4	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	49	 1	 9.8	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	50	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00289	    0.00000	 63.0	 1	    1.06927	    0.93651;
	51	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	52	 1	 6.5	 2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	53	 1	 0.0	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	54	 1	 0.3	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	55	 1	 50.9	 12.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	56	 1	 75.5	 20.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	57	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	58	 1	 154.0	 36.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	59	 1	 5.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	60	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	61	 1	 46.3	 11.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	62	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	63	 1	 16.8	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	64	 1	 67.3	 7.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	65	 1	 12.0	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	66	 1	 13.0	 -6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	67	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	68	 1	 53.1	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	69	 1	 20.8	 1.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	70	 1	 10.6	 4.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	71	 1	 69.4	 17.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	72	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	73	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	74	 1	 58.8	 -5.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	75	 1	 25.2	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	76	 1	 5.9	 -2.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	77	 1	 43.7	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	78	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	79	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	80	 1	 32.4	 10.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	81	 1	 32.4	 9.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	82	 1	 11.3	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	83	 1	 79.0	 24.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	84	 1	 -0.1	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	85	 1	 0.7	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	86	 1	 48.8	 5.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	87	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	88	 1	 14.8	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	89	 1	 26.2	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	90	 1	 0.2	 -2.3	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	91	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	92	 1	 31.8	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	93	 1	 2.0	 -2.8	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	94	 1	 18.2	 -4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	95	 1	 57.2	 9.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	96	 1	 0.9	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	97	 1	 57.7	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	98	 1	 9.5	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	99	 1	 35.8	 5.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	100	 1	 63.0	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	101	 1	 17.3	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	102	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	103	 1	 12.6	 -1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	105	 1	 36.9	 2.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	106	 1	 58.2	 10.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	107	 1	 107.0	 14.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	108	 1	 12.2	 -2.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	109	 1	 67.8	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	111	 1	 38.7	 -7.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	114	 1	 13.4	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	117	 1	 14.9	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	118	 1	 2.0	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	119	 1	 40.6	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	120	 1	 22.0	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	121	 1	 20.8	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	122	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	123	 1	 12.0	 4.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	124	 1	 8.0	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	125	 1	 11.1	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	126	 1	 0.2	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	127	 1	 14.7	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	128	 1	 13.8	 7.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	129	 1	 19.1	 10.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	131	 1	 119.3	 12.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	132	 2	 9.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	133	 1	 2.7	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	134	 1	 101.1	 27.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	136	 1	 23.9	 1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	137	 2	 8.7	 -3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	139	 1	 8.0	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	140	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	142	 1	 22.4	 7.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	144	 1	 16.0	 5.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	145	 1	 23.4	 9.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	147	 1	 30.0	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	148	 1	 6.6	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	149	 1	 16.9	 4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	150	 1	 48.5	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	151	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	152	 1	 45.3	 12.0	 0.0	 7.7	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	153	 1	 27.3	 -5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	155	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	157	 1	 0.0	 -2.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	158	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	160	 1	 41.7	 5.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	161	 1	 43.7	 10.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	162	 1	 -0.3	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	165	 1	 16.5	 14.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	166	 1	 13.3	 3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	167	 1	 17.8	 -0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	168	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	169	 1	 9.9	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	170	 1	 79.8	 13.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	171	 1	 28.0	 0.8	 0.0	 30.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	173	 1	 28.5	 8.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	174	 1	 59.7	 11.6	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	176	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	181	 1	 12.7	 -5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	182	 1	 16.0	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	183	 1	 5.5	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	184	 1	 5.0	 1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	185	 1	 30.6	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	186	 1	 1.2	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	187	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00969	    0.00000	 63.0	 1	    1.09875	    0.92063;
	189	 1	 16.8	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	190	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	191	 1	 15.4	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	192	 1	 9.9	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	193	 1	 0.1	 0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	194	 2	 0.7	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00800	    0.00000	 63.0	 1	    1.06362	    0.95238;
	196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00800	    0.00000	 63.0	 1	    1.06362	    0.95238;
	197	 1	 27.5	 -0.6	 0.0	 15.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	198	 1	 11.1	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	199	 1	 12.6	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	201	 1	 81.0	 25.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	202	 1	 49.8	 2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	203	 1	 28.6	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	206	 1	 54.4	 9.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	207	 1	 33.9	 4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	208	 1	 16.6	 -0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	209	 1	 2.2	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	210	 1	 41.5	 6.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	211	 1	 32.5	 14.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	214	 1	 43.1	 4.5	 0.0	 30.4	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	216	 1	 21.1	 -3.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	217	 1	 31.1	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	218	 1	 3.3	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	219	 1	 11.1	 -4.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	220	 1	 14.8	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	221	 1	 13.0	 -6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01154	    0.00000	 225.0	 1	    1.08975	    0.93333;
	223	 1	 42.4	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	224	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	225	 1	 76.8	 16.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	226	 1	 77.8	 71.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	227	 1	 5.0	 -1.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	228	 1	 10.9	 -2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	229	 1	 12.0	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	231	 1	 7.0	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	232	 1	 7.2	 0.1	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	233	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	234	 1	 24.7	 8.1	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	235	 1	 17.7	 3.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	236	 1	 28.6	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	237	 1	 43.7	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	238	 1	 25.2	 -1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	239	 1	 53.9	 4.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	240	 1	 51.1	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	241	 1	 56.7	 9.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	242	 1	 56.2	 8.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	243	 1	 26.7	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	244	 1	 58.0	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	245	 1	 13.7	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	246	 2	 13.7	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	248	 1	 33.4	 13.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	249	 1	 26.1	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	250	 1	 27.4	 -9.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	251	 1	 10.6	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	252	 1	 9.6	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	253	 1	 54.1	 5.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	254	 1	 20.0	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	255	 1	 9.5	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	256	 2	 1.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	258	 2	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	259	 1	 33.0	 -2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	261	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	262	 1	 0.0	 0.0	 0.0	 80.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	263	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05921	    0.00000	 380.0	 1	    1.10526	    1.01316;
	265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	266	 1	 32.5	 7.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	267	 1	 66.3	 12.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	268	 1	 12.2	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	269	 1	 23.2	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	272	 1	 45.8	 4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	273	 1	 28.5	 3.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	274	 1	 54.5	 9.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	277	 1	 3.7	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	278	 1	 1.5	 4.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	279	 1	 11.0	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	280	 1	 44.0	 14.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	281	 1	 12.8	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	282	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	283	 1	 12.1	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	284	 1	 16.8	 4.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	285	 1	 -1.7	 4.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	286	 1	 32.2	 20.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	287	 1	 35.7	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	288	 1	 36.8	 -2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	289	 1	 43.6	 9.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	290	 1	 7.3	 3.7	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	291	 1	 15.8	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	292	 1	 1.0	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	293	 1	 45.4	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	294	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	295	 1	 23.4	 4.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	296	 1	 6.9	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	297	 1	 2.0	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	298	 1	 13.9	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	299	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	300	 1	 53.5	 16.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	301	 1	 3.0	 0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	302	 1	 16.3	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	303	 1	 42.3	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	304	 1	 36.7	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	305	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	306	 1	 14.5	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	307	 1	 21.4	 -2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	308	 1	 0.6	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	309	 1	 7.0	 2.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	310	 1	 13.0	 4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	311	 1	 1.3	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	312	 1	 2.0	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	313	 1	 32.0	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	315	 1	 21.5	 -0.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	316	 1	 35.3	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	317	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	318	 1	 13.7	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	319	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	320	 1	 36.6	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	322	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07879	    0.00000	 380.0	 1	    1.10526	    1.05232;
	324	 1	 28.5	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	325	 2	 18.0	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	326	 1	 11.7	 19.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	328	 1	 39.4	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	329	 1	 74.3	 5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	330	 1	 84.5	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	332	 2	 9.2	 -0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	333	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	334	 1	 7.4	 -2.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	335	 1	 3.0	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	336	 2	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	337	 1	 13.6	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	338	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	339	 1	 17.8	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	340	 1	 25.2	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	341	 1	 7.7	 -10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	342	 1	 13.8	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	344	 1	 11.5	 -3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	345	 1	 23.4	 -5.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	346	 1	 13.1	 -0.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	347	 1	 -0.7	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	348	 1	 53.9	 6.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	351	 1	 36.0	 2.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	352	 1	 5.8	 2.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	353	 1	 34.0	 -10.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	354	 1	 2.5	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	355	 1	 3.0	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	356	 1	 6.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	357	 1	 14.7	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	358	 1	 23.9	 10.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	359	 1	 35.3	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	360	 1	 54.9	 5.6	 0.0	 19.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	363	 1	 10.0	 4.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	364	 2	 -3.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	365	 1	 -0.1	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	370	 1	 60.0	 14.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	371	 1	 12.0	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	373	 1	 24.9	 7.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	374	 1	 25.7	 3.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	375	 1	 17.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	376	 1	 54.3	 -0.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	377	 1	 6.0	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	378	 1	 27.5	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	381	 1	 52.7	 7.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	382	 1	 17.3	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	383	 1	 43.9	 15.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	384	 1	 20.1	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	385	 1	 18.9	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	386	 1	 45.9	 9.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	387	 1	 5.4	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	388	 1	 44.8	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	389	 1	 29.0	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	390	 1	 0.8	 0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	391	 1	 24.5	 -4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	392	 1	 29.6	 1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	393	 1	 6.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	394	 1	 6.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	395	 1	 44.1	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	396	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	397	 1	 13.0	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	398	 1	 6.7	 2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	399	 1	 0.8	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	400	 1	 20.2	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	401	 1	 5.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	402	 1	 22.4	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	403	 1	 24.2	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	404	 1	 32.0	 10.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	405	 1	 6.0	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	406	 1	 60.7	 3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	407	 1	 1.5	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	408	 1	 13.8	 -4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	409	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	410	 1	 21.0	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	411	 1	 17.8	 -3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	412	 1	 24.7	 -11.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	413	 1	 29.0	 -1.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	414	 1	 -0.4	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	415	 1	 10.5	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	416	 1	 67.6	 14.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	417	 1	 18.2	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	418	 1	 10.0	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	419	 1	 29.8	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	420	 1	 -4.2	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	427	 1	 0.3	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	428	 1	 4.0	 -1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	429	 1	 58.6	 6.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	430	 1	 117.3	 33.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	431	 1	 13.0	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	432	 1	 26.0	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	433	 1	 3.5	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	434	 1	 14.0	 -4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	435	 1	 37.4	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	436	 1	 26.9	 -2.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	437	 1	 1.0	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	438	 1	 12.9	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	439	 1	 13.5	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	440	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	441	 1	 2.4	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	442	 1	 27.5	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	443	 1	 12.6	 3.1	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	445	 1	 25.8	 7.1	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	447	 2	 1.0	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04102	    0.00000	 225.0	 1	    1.09538	    0.98667;
	450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	451	 1	 1.0	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	452	 1	 0.0	 0.0	 0.0	 50.0	 1	    1.00909	    0.00000	 63.0	 1	    1.06580	    0.95238;
	453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	454	 1	 26.5	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	455	 1	 10.6	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	456	 1	 29.6	 5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	460	 1	 22.0	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	461	 1	 13.9	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	462	 1	 34.7	 -4.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	463	 1	 -0.8	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	464	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.98822	    0.00000	 20.0	 1	    1.17644	    0.80000;
	465	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	466	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	467	 1	 79.7	 11.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	468	 1	 32.9	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	469	 1	 -0.6	 -1.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	470	 2	 1.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	471	 1	 -0.3	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	472	 1	 496.9	 284.7	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.15789	    0.94737;
	473	 1	 507.9	 312.7	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.15789	    0.94737;
	474	 1	 62.1	 6.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	478	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.95059	    0.00000	 45.0	 1	    1.01230	    0.88889;
	479	 2	 10.9	 -4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	482	 1	 15.9	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	483	 1	 61.3	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	484	 1	 52.2	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	485	 1	 35.9	 3.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	486	 1	 9.0	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	487	 1	 48.6	 12.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	488	 1	 0.8	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	489	 1	 30.6	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	490	 1	 -26.9	 9.1	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	491	 2	 0.2	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	492	 1	 24.0	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	493	 1	 -0.1	 -0.1	 0.0	 0.0	 1	    1.04848	    0.00000	 225.0	 1	    1.09697	    1.00000;
	494	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	495	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	497	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	498	 1	 4.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04136	    0.00000	 225.0	 1	    1.09606	    0.98667;
	500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04144	    0.00000	 225.0	 1	    1.09622	    0.98667;
	501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	502	 1	 23.4	 -3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	503	 1	 39.2	 -3.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	506	 1	 5.9	 2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	507	 1	 54.4	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	508	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	509	 1	 35.4	 3.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	510	 1	 44.5	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	511	 1	 47.2	 11.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	512	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	513	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	514	 1	 2.7	 1.6	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	515	 1	 2.0	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	516	 1	 27.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	517	 1	 38.4	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	518	 1	 14.4	 6.1	 0.0	 0.0	 1	    0.96890	    0.00000	 63.0	 1	    1.04891	    0.88889;
	519	 1	 31.3	 -1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	520	 1	 29.5	 -4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	525	 1	 11.0	 5.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	526	 1	 6.0	 20.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	529	 1	 2.6	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	530	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	532	 1	 31.6	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	533	 1	 24.5	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	534	 1	 25.2	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	537	 1	 18.5	 -2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	538	 1	 31.3	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	539	 1	 18.1	 4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	540	 1	 10.0	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	542	 1	 54.7	 7.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	543	 1	 55.7	 10.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	546	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	549	 1	 34.4	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	550	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	551	 1	 53.1	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	552	 1	 31.5	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	553	 1	 1.7	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	554	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04533	    0.00000	 225.0	 1	    1.09066	    1.00000;
	556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04533	    0.00000	 225.0	 1	    1.09066	    1.00000;
	557	 1	 65.4	 1.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	558	 1	 35.0	 -2.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	559	 1	 15.2	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	560	 1	 12.9	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	561	 1	 29.6	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	562	 1	 17.8	 -0.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	565	 1	 16.5	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	566	 1	 36.2	 7.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	567	 1	 1.9	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	568	 1	 11.9	 4.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	570	 1	 22.2	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	571	 1	 16.6	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	572	 1	 43.1	 -6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	574	 1	 7.6	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	575	 1	 3.2	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	576	 1	 8.0	 -0.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	577	 1	 38.0	 6.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	578	 1	 8.3	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	583	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	584	 1	 4.0	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	585	 1	 21.3	 3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	586	 2	 35.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	587	 1	 30.7	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	588	 1	 12.2	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	589	 2	 14.0	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	590	 1	 154.3	 40.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	591	 1	 22.4	 -5.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	592	 1	 15.2	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	593	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04848	    0.00000	 225.0	 1	    1.09697	    1.00000;
	595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	596	 1	 7.3	 -1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	597	 1	 9.7	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	598	 1	 34.8	 0.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	599	 1	 8.9	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	600	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	601	 1	 -0.8	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	609	 1	 2.7	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	610	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	612	 1	 38.0	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	613	 1	 18.7	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	614	 1	 10.9	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	615	 1	 38.4	 11.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	616	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	618	 1	 16.4	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	619	 1	 19.3	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	620	 1	 3.2	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	621	 1	 3.2	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	622	 1	 3.3	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	623	 1	 14.8	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	624	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	625	 1	 52.5	 -1.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	626	 1	 10.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	627	 1	 11.5	 -0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	629	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	630	 1	 34.8	 11.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	631	 1	 68.7	 4.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	632	 1	 -0.7	 0.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	633	 2	 12.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	634	 1	 9.1	 -0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	635	 1	 24.7	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	636	 2	 31.5	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	637	 1	 21.3	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	638	 1	 6.9	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	639	 1	 4.0	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	640	 1	 34.7	 4.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04531	    0.00000	 225.0	 1	    1.09063	    1.00000;
	642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04531	    0.00000	 225.0	 1	    1.09062	    1.00000;
	643	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04535	    0.00000	 225.0	 1	    1.09070	    1.00000;
	644	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04532	    0.00000	 225.0	 1	    1.09064	    1.00000;
	645	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04534	    0.00000	 225.0	 1	    1.09069	    1.00000;
	646	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	647	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	648	 1	 13.9	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	649	 1	 16.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	650	 1	 25.9	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	651	 1	 31.3	 -2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	652	 1	 31.8	 4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	653	 1	 44.4	 8.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	654	 1	 51.3	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	655	 1	 11.8	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	657	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	658	 1	 37.8	 6.6	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	659	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	661	 1	 7.4	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	662	 1	 48.9	 9.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	663	 1	 32.1	 12.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	664	 1	 12.0	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	665	 1	 1.6	 -2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	666	 1	 44.9	 5.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	667	 1	 -0.0	 -14.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	668	 1	 33.5	 -2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	669	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	673	 1	 0.0	 0.0	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	675	 1	 13.7	 -8.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	676	 1	 34.9	 4.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	677	 1	 26.2	 -6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	678	 1	 2.3	 11.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	679	 1	 6.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	680	 1	 14.8	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	681	 1	 -1.3	 2.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02475	    0.00000	 90.0	 1	    1.07173	    0.97778;
	683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	684	 1	 14.0	 0.2	 0.0	 0.0	 1	    1.02186	    0.00000	 90.0	 1	    1.06667	    0.97706;
	685	 1	 15.3	 -2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	686	 1	 95.2	 18.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	688	 1	 34.8	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	689	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	690	 1	 -3.3	 0.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	691	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	692	 1	 -3.3	 0.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	693	 1	 4.8	 2.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	694	 1	 4.0	 2.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	695	 1	 11.7	 -4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	697	 1	 45.5	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	700	 1	 26.5	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	701	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	702	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	703	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	704	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	707	 1	 42.5	 12.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	710	 2	 9.6	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	711	 1	 24.0	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	712	 1	 20.2	 0.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	713	 1	 25.2	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	714	 1	 29.2	 0.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	715	 1	 0.0	 0.0	 0.0	 29.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	716	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	718	 1	 0.0	 -5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	719	 1	 17.3	 -3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	720	 1	 -0.2	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	721	 1	 1.5	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	722	 1	 29.3	 -2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	723	 1	 26.9	 -7.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	724	 1	 9.8	 -3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	725	 1	 39.5	 4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	727	 1	 50.9	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	728	 1	 29.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	729	 1	 37.4	 6.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	730	 1	 10.4	 12.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	731	 1	 10.5	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	732	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02000	    0.00000	 225.0	 1	    1.08889	    0.95111;
	733	 1	 30.9	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	734	 1	 20.0	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	735	 1	 22.9	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	736	 1	 52.4	 12.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	737	 1	 14.9	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	738	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	739	 1	 -2.8	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	740	 1	 9.0	 1.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	741	 1	 30.8	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	742	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	743	 1	 46.3	 -1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	744	 1	 81.4	 11.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	745	 1	 12.0	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	746	 1	 12.0	 -3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	749	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	750	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	751	 2	 11.5	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	752	 1	 12.9	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	753	 1	 4.0	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	754	 1	 13.0	 -4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	755	 1	 12.8	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	756	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	757	 1	 10.4	 4.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	758	 1	 24.2	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	759	 1	 19.0	 0.6	 0.0	 78.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	760	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	761	 1	 49.1	 2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	762	 1	 114.2	 34.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	763	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	764	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	765	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	766	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	767	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	769	 1	 17.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	770	 1	 21.8	 1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	771	 1	 9.4	 -2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	772	 1	 18.0	 5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	775	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	776	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	777	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	778	 1	 71.7	 18.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	779	 1	 10.9	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	780	 1	 44.3	 7.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	781	 1	 27.9	 -2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	783	 1	 10.0	 4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	784	 1	 11.0	 5.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	785	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	786	 1	 6.3	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	787	 1	 19.4	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	788	 1	 28.7	 -2.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	789	 1	 106.7	 8.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	790	 1	 2.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	791	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	792	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	793	 1	 -9.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	794	 1	 -22.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	797	 1	 10.0	 5.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	799	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	800	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	801	 1	 64.8	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	803	 1	 13.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	806	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	807	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	808	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	810	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	811	 1	 11.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	812	 1	 13.4	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	813	 1	 62.4	 22.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	814	 1	 -0.6	 0.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	815	 1	 -2.1	 -3.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	816	 1	 69.6	 22.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	817	 1	 2.9	 -2.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	818	 1	 5.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	819	 1	 15.1	 -0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	820	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	821	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	822	 1	 83.3	 17.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	825	 1	 24.5	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	826	 1	 41.1	 1.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	827	 1	 30.8	 -4.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	828	 1	 6.7	 0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	829	 1	 1.2	 0.5	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	831	 2	 0.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	832	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	834	 1	 53.9	 6.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	835	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	836	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	837	 1	 0.1	 -1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	838	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	839	 1	 41.2	 -4.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	840	 1	 48.2	 -3.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	841	 2	 -1.7	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	843	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	844	 1	 9.6	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	845	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	846	 1	 45.1	 -2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	847	 1	 2.3	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	848	 1	 27.2	 12.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	849	 1	 10.8	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	850	 1	 30.5	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	851	 1	 18.0	 3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	852	 1	 28.9	 0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	853	 1	 16.0	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	855	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	857	 1	 2.9	 -1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	858	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	859	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	860	 1	 7.0	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	861	 1	 10.2	 3.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	862	 2	 17.0	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	864	 1	 38.8	 12.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	865	 1	 26.0	 5.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	866	 1	 22.2	 -4.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	867	 1	 0.2	 -1.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	868	 1	 0.2	 -1.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	869	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	870	 2	 6.2	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	871	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	872	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	873	 1	 0.3	 -4.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	874	 1	 45.4	 5.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	875	 1	 16.0	 9.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	876	 1	 22.9	 9.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	877	 1	 -2.7	 -3.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	878	 1	 52.0	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	879	 1	 49.2	 3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	880	 1	 24.0	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	881	 1	 26.0	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	882	 1	 1.1	 -0.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	883	 1	 14.1	 9.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	884	 1	 19.0	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	885	 1	 30.1	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	886	 1	 55.5	 1.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	887	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	888	 1	 48.0	 11.1	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	889	 1	 3.9	 0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	890	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	891	 1	 59.9	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	892	 1	 65.9	 16.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	893	 1	 54.3	 14.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	894	 2	 -40.9	 1.4	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	895	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	896	 1	 41.7	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	897	 1	 6.0	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	898	 1	 30.5	 2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	899	 1	 15.9	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	900	 1	 3.1	 -3.8	 0.0	 0.0	 1	    1.07445	    0.00000	 380.0	 1	    1.10943	    1.03947;
	901	 1	 54.1	 18.3	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	902	 1	 -2.6	 0.0	 0.0	 0.0	 1	    1.07695	    0.00000	 380.0	 1	    1.11444	    1.03947;
	903	 1	 -41.6	 -9.7	 0.0	 0.0	 1	    1.07699	    0.00000	 380.0	 1	    1.11451	    1.03947;
	904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	905	 1	 5.0	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	906	 1	 11.1	 -0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	907	 1	 25.7	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	908	 1	 28.8	 2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	909	 1	 42.0	 4.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	910	 1	 101.2	 26.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	911	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	912	 1	 14.0	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	913	 1	 34.3	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	914	 1	 17.9	 -3.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	915	 1	 6.4	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	916	 1	 0.7	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	917	 1	 7.7	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	918	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	919	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	920	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	921	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	922	 1	 9.2	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	923	 1	 35.3	 6.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	924	 1	 23.8	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	925	 1	 1.6	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	926	 1	 13.7	 -5.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	927	 1	 -4.0	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	930	 1	 23.9	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	931	 1	 12.8	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	933	 1	 55.8	 10.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	934	 1	 2.2	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	935	 1	 33.4	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	936	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	937	 1	 5.5	 0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	938	 1	 5.0	 9.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	940	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	941	 1	 12.9	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	942	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00889	    0.00000	 225.0	 1	    1.08889	    0.92889;
	944	 1	 104.1	 -13.7	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	945	 1	 8.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	946	 1	 59.1	 11.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	947	 1	 0.0	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	948	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	949	 2	 2.7	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	950	 1	 34.9	 4.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	951	 1	 16.3	 -1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	952	 1	 10.0	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	953	 1	 35.4	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	954	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	955	 1	 17.3	 2.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	956	 1	 -0.0	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	957	 1	 14.0	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	960	 1	 5.0	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	961	 1	 2.3	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	962	 1	 -0.3	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	963	 1	 9.5	 -4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	964	 1	 37.1	 -0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	965	 1	 49.3	 12.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	967	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	968	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	969	 1	 0.6	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	970	 2	 48.8	 29.8	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	972	 1	 38.2	 -4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	973	 1	 66.9	 22.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	974	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	975	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	976	 1	 1.6	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	977	 1	 37.4	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	978	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	981	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	982	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	983	 1	 12.6	 3.4	 0.0	 0.0	 1	    1.00406	    0.00000	 63.0	 1	    1.07161	    0.93651;
	984	 1	 57.7	 7.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	985	 1	 5.5	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	986	 1	 33.4	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	987	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	988	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	989	 1	 17.4	 -0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	990	 1	 13.0	 1.3	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	991	 1	 9.0	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	992	 2	 -1.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	993	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	994	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	995	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	996	 1	 20.9	 -2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	997	 1	 17.5	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	998	 1	 13.5	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	999	 1	 8.3	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1000	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1004	 1	 55.5	 11.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1005	 1	 2.0	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1006	 1	 0.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1007	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04577	    0.00000	 225.0	 1	    1.09155	    1.00000;
	1008	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1009	 1	 17.7	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1010	 1	 9.9	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1012	 1	 45.0	 1.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1013	 1	 111.4	 14.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1014	 2	 -2.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1015	 1	 29.9	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1016	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00084	    0.00000	 63.0	 1	    1.06518	    0.93651;
	1017	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1018	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00165	    0.00000	 63.0	 1	    1.06679	    0.93651;
	1019	 1	 11.9	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1020	 1	 46.1	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1021	 1	 12.4	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1022	 1	 68.1	 15.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1023	 1	 32.1	 4.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1024	 1	 20.1	 5.1	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1025	 1	 38.7	 -3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1026	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1027	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1028	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1029	 1	 1.0	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1030	 1	 29.4	 5.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1031	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01852	    0.00000	 63.0	 1	    1.08466	    0.95238;
	1032	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01855	    0.00000	 63.0	 1	    1.08471	    0.95238;
	1033	 1	 80.2	 12.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1034	 1	 2.0	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1035	 1	 37.9	 9.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1036	 1	 20.5	 5.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1037	 1	 0.0	 -7.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1038	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1042	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1043	 1	 18.9	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1045	 1	 41.9	 2.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1047	 1	 -1.6	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1048	 1	 31.4	 3.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1052	 1	 60.1	 13.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1053	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1054	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1055	 1	 15.5	 -4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1056	 1	 0.0	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1058	 1	 25.9	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1059	 1	 16.0	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1060	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1061	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1062	 2	 11.2	 3.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1063	 1	 52.9	 19.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1065	 1	 28.1	 9.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1066	 1	 20.0	 -5.3	 0.0	 0.0	 1	    1.05768	    0.00000	 380.0	 1	    1.11537	    1.00000;
	1067	 1	 -21.2	 8.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1068	 1	 4.6	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1069	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1070	 1	 15.2	 -1.3	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	1071	 2	 4.2	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1072	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1073	 1	 0.6	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1075	 1	 9.1	 -3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1078	 1	 0.0	 0.0	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1080	 1	 -16.5	 -1.5	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1081	 1	 -16.4	 -1.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1082	 1	 22.9	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1083	 1	 43.4	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1085	 1	 -2.1	 -12.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1086	 1	 0.1	 -6.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1087	 1	 2.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1088	 1	 22.0	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1089	 1	 -3.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1090	 1	 12.9	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1091	 1	 9.8	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1092	 1	 4.6	 -2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1093	 1	 91.8	 12.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1094	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1095	 1	 6.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1096	 1	 42.3	 4.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1097	 1	 57.3	 15.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1099	 1	 29.3	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1100	 1	 39.4	 2.0	 0.0	 0.0	 1	    1.00386	    0.00000	 63.0	 1	    1.07121	    0.93651;
	1101	 1	 54.2	 14.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1102	 1	 18.2	 0.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1104	 1	 23.0	 4.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1105	 1	 18.2	 1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1106	 1	 19.7	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1107	 1	 34.2	 -4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1108	 1	 25.1	 -2.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1110	 1	 3.0	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1111	 1	 30.8	 -2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00327	    0.00000	 63.0	 1	    1.05416	    0.95238;
	1113	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1114	 1	 10.8	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1115	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00175	    0.00000	 63.0	 1	    1.06700	    0.93651;
	1116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1118	 1	 2.5	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1119	 1	 1.0	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1120	 1	 61.8	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1121	 1	 23.9	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1123	 1	 23.0	 -2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1124	 1	 78.5	 14.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1125	 1	 21.5	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1126	 1	 21.9	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1127	 1	 29.0	 -3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1128	 1	 9.9	 -11.7	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	1129	 1	 -0.3	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1130	 2	 1.0	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1132	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1133	 1	 25.4	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1134	 1	 2.1	 -2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1135	 1	 0.0	 0.0	 0.0	 29.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1137	 1	 48.0	 5.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1138	 1	 17.6	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1139	 1	 16.8	 -7.9	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1140	 1	 44.9	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1141	 1	 2.6	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1142	 1	 0.5	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1143	 1	 66.4	 14.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1144	 1	 20.9	 8.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1145	 1	 15.0	 5.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1146	 1	 26.5	 0.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1148	 1	 54.2	 -0.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1149	 1	 11.0	 -3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1150	 1	 33.3	 -1.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1151	 1	 38.1	 5.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1152	 1	 9.1	 -2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1153	 1	 12.9	 -2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1154	 1	 40.1	 -1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1155	 1	 11.0	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1159	 1	 31.5	 5.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1160	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1161	 1	 86.8	 25.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1162	 1	 31.5	 19.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1163	 1	 34.6	 12.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1168	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1169	 1	 3.1	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1170	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1171	 1	 6.0	 -9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1172	 1	 22.5	 -3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1173	 1	 9.3	 12.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1174	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1175	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1176	 1	 -0.3	 1.5	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1179	 1	 -1.0	 4.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1180	 1	 6.9	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1181	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1182	 1	 13.5	 10.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1183	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1185	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1186	 1	 0.3	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1187	 1	 66.3	 19.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1188	 1	 54.5	 11.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1189	 1	 -1.1	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1190	 1	 174.6	 29.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1191	 1	 24.1	 4.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1192	 1	 14.8	 -1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1193	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1194	 1	 20.6	 -8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1195	 1	 36.6	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1199	 1	 -0.7	 2.7	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1201	 1	 33.1	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1202	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1203	 1	 36.2	 6.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1206	 1	 54.2	 3.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1207	 1	 10.1	 4.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1208	 1	 17.4	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1211	 1	 0.0	 0.0	 0.0	 40.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1213	 1	 6.9	 3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1214	 1	 17.0	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1215	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04542	    0.00000	 225.0	 1	    1.09084	    1.00000;
	1216	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1217	 1	 18.2	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1218	 1	 0.2	 0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1219	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07973	    0.00000	 380.0	 1	    1.10420	    1.05526;
	1220	 1	 8.0	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1221	 1	 8.0	 -2.6	 0.0	 0.0	 1	    1.02358	    0.00000	 90.0	 1	    1.06939	    0.97778;
	1222	 1	 47.9	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1223	 1	 13.1	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1224	 1	 2.8	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1225	 1	 27.6	 3.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1226	 1	 34.6	 -4.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1227	 1	 22.6	 15.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1228	 1	 16.9	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1229	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1231	 1	 0.0	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1232	 1	 2.0	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1234	 1	 46.8	 15.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1235	 1	 16.2	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1236	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1237	 1	 46.6	 9.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1238	 1	 29.5	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1241	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1243	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1244	 1	 25.9	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1246	 1	 7.1	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1247	 1	 43.2	 6.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1249	 1	 28.9	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1251	 1	 0.0	 0.0	 0.0	 9.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	1252	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1253	 1	 62.7	 3.5	 0.0	 0.0	 1	    1.00016	    0.00000	 63.0	 1	    1.06381	    0.93651;
	1254	 1	 31.9	 4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1255	 1	 24.3	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1256	 1	 62.2	 11.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1257	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1259	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1260	 1	 2.1	 -1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1261	 1	 11.9	 -0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1262	 1	 -0.1	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1263	 1	 18.5	 -9.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1264	 1	 15.6	 -6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1267	 1	 8.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1268	 1	 36.1	 -1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1269	 1	 92.7	 17.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1270	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1271	 1	 11.0	 3.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1272	 1	 33.2	 6.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1273	 1	 10.8	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1274	 1	 11.3	 -7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1278	 1	 49.0	 7.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1279	 1	 46.0	 13.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1280	 1	 1.1	 -0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1281	 1	 40.1	 -2.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1282	 1	 13.1	 1.2	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1283	 1	 9.4	 -8.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1284	 1	 0.2	 -1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1285	 1	 30.2	 3.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1286	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1287	 1	 50.4	 20.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1289	 1	 11.9	 13.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1291	 2	 -1.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1294	 1	 14.6	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1295	 1	 21.0	 -3.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1296	 1	 0.2	 -0.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1298	 1	 -29.6	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1300	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1301	 1	 47.2	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1302	 1	 37.7	 3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1303	 1	 28.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1304	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1305	 1	 10.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1306	 1	 17.1	 -0.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1307	 1	 36.3	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1308	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1309	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1310	 1	 -3.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1311	 1	 19.0	 -4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1312	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1314	 1	 -0.1	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1315	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1316	 1	 -0.3	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1317	 1	 35.5	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1318	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1320	 1	 43.1	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1321	 1	 40.5	 -2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1322	 1	 2.0	 2.3	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1323	 1	 0.0	 0.3	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1324	 1	 4.3	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1325	 1	 20.4	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1326	 1	 26.4	 -1.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1327	 1	 43.7	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1328	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1329	 1	 22.8	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1330	 2	 0.3	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1332	 1	 44.0	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1334	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1335	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1337	 1	 16.4	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1338	 1	 -0.1	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1339	 1	 0.4	 -0.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1340	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1341	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1342	 1	 14.6	 1.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1344	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03908	    0.00000	 225.0	 1	    1.09149	    0.98667;
	1345	 2	 -17.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1346	 1	 27.7	 9.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1347	 1	 1.2	 -4.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1348	 1	 50.6	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1349	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1351	 1	 14.9	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1352	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1353	 1	 7.0	 2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1354	 1	 27.3	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1355	 1	 26.5	 7.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1356	 1	 25.9	 -3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1358	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1359	 1	 17.1	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1360	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99778	    0.00000	 225.0	 1	    1.08889	    0.90667;
	1361	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1362	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1363	 1	 1.0	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1364	 1	 20.5	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1367	 1	 2.6	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1368	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1369	 1	 20.7	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1370	 1	 9.4	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1371	 1	 27.7	 -3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1372	 1	 61.0	 14.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1373	 1	 50.1	 14.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1374	 1	 -0.0	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1376	 1	 6.9	 1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1377	 1	 139.5	 30.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1378	 1	 15.1	 6.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1379	 1	 13.1	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00445	    0.00000	 225.0	 1	    1.08889	    0.92000;
	1382	 1	 15.6	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1383	 1	 0.0	 -0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1384	 1	 25.7	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1385	 1	 34.1	 5.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1386	 1	 18.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1388	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1389	 1	 1.3	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1391	 1	 4.2	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1392	 1	 33.9	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1393	 1	 -0.8	 -0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1394	 1	 16.4	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1395	 1	 10.6	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1396	 1	 6.0	 2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1397	 1	 16.4	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1398	 1	 59.9	 9.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1399	 1	 0.4	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1400	 1	 30.9	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1401	 1	 -1.1	 -0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1402	 1	 24.7	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1403	 1	 7.1	 -3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1404	 1	 0.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1405	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1406	 1	 5.4	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1407	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1409	 1	 44.8	 1.9	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1410	 1	 14.9	 7.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1411	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1412	 1	 20.2	 -2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1413	 1	 14.0	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1415	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1416	 1	 39.2	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1417	 1	 18.8	 5.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1418	 1	 39.2	 6.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1419	 1	 34.6	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1420	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1421	 1	 2.6	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1422	 1	 75.6	 14.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1423	 1	 24.2	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1424	 1	 7.4	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1425	 2	 34.0	 18.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1426	 1	 41.6	 10.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1427	 1	 32.9	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1428	 1	 -0.1	 1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1429	 1	 20.4	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1430	 1	 -0.2	 -2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1431	 1	 41.6	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1433	 1	 85.2	 13.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1434	 1	 21.5	 -0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1436	 1	 40.0	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1437	 1	 38.3	 1.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1438	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1439	 1	 4.9	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1440	 1	 21.5	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1441	 1	 27.0	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1442	 1	 36.9	 -4.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1443	 1	 18.3	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1444	 1	 12.1	 3.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1445	 1	 21.6	 3.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1447	 1	 3.9	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1448	 1	 0.0	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1449	 1	 60.7	 17.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1450	 1	 -0.4	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1451	 1	 79.0	 24.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1452	 1	 20.0	 -2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1453	 1	 1.0	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1454	 1	 1.0	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1455	 1	 32.2	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1456	 1	 21.8	 -10.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1458	 1	 11.0	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1459	 1	 0.0	 0.0	 0.0	 6.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	1460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1461	 1	 18.0	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1465	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1466	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1467	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99778	    0.00000	 225.0	 1	    1.08889	    0.90667;
	1468	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1469	 1	 17.6	 0.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1470	 1	 12.0	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1471	 1	 71.0	 17.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1472	 1	 60.9	 13.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1475	 1	 29.4	 6.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1476	 1	 50.1	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1477	 1	 11.4	 -1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1478	 1	 4.8	 1.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1479	 1	 -0.6	 7.9	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1481	 1	 31.0	 -2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01854	    0.00000	 63.0	 1	    1.08470	    0.95238;
	1483	 1	 64.0	 22.0	 0.0	 20.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04161	    0.00000	 63.0	 1	    1.13084	    0.95238;
	1485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	1486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	1487	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1488	 1	 43.7	 5.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1489	 1	 5.7	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1490	 1	 12.0	 2.2	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1491	 1	 28.0	 5.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1492	 1	 31.6	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1493	 1	 27.6	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1494	 1	 17.1	 4.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1495	 1	 29.3	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1496	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1497	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1499	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	1500	 1	 15.1	 3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1501	 1	 10.0	 4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1502	 1	 34.0	 3.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1504	 1	 16.6	 -74.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1505	 1	 148.5	 28.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	1506	 1	 14.6	 -0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1507	 1	 18.7	 4.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1508	 1	 77.5	 4.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1509	 1	 18.4	 -5.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1511	 1	 12.8	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1512	 1	 12.8	 0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1513	 1	 28.6	 2.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1514	 1	 15.5	 -3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1515	 1	 38.2	 2.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1516	 1	 38.4	 10.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1521	 1	 38.1	 4.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1522	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	1523	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	1524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.15556	    0.88889;
	1525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.15556	    0.88889;
	1526	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1528	 1	 50.6	 3.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1529	 1	 26.6	 3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1530	 1	 2.0	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1531	 1	 36.1	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1532	 1	 20.0	 5.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1535	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1537	 1	 18.1	 -3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1539	 1	 44.5	 13.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1540	 1	 6.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1545	 1	 3.0	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1546	 1	 11.8	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1547	 1	 10.9	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1548	 1	 22.0	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1549	 1	 26.0	 5.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1550	 1	 28.9	 3.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1551	 1	 24.6	 -6.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1552	 1	 8.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1553	 1	 34.7	 -6.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1554	 1	 38.5	 4.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1555	 1	 26.3	 3.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1556	 1	 40.7	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1557	 1	 0.9	 -0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1558	 1	 30.7	 5.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1559	 1	 25.1	 7.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1560	 2	 29.3	 8.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1561	 1	 37.9	 2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1562	 1	 7.8	 11.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1563	 1	 60.1	 5.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1564	 1	 40.5	 6.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1565	 1	 44.4	 10.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1566	 1	 16.0	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1567	 1	 14.2	 4.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1568	 1	 27.5	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1570	 1	 26.5	 7.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1571	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	1572	 1	 80.4	 19.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1573	 1	 21.0	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1574	 1	 7.4	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1575	 1	 45.0	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1576	 1	 37.9	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1577	 1	 26.0	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1582	 1	 21.3	 3.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1583	 1	 82.3	 9.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1584	 2	 39.0	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1587	 1	 27.7	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	1590	 1	 27.0	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1591	 1	 11.9	 7.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1592	 1	 25.9	 0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1593	 1	 14.4	 11.3	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	1594	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1595	 1	 25.9	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1596	 1	 15.7	 -2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1597	 1	 41.6	 3.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1599	 2	 -5.0	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04498	    0.00000	 225.0	 1	    1.08552	    1.00444;
	1601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1602	 1	 25.8	 10.5	 0.0	 30.0	 1	    1.00440	    0.00000	 63.0	 1	    1.05641	    0.95238;
	1603	 1	 133.4	 23.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1605	 2	 -1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1606	 1	 -9.0	 0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1607	 1	 20.6	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1608	 1	 5.3	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1610	 1	 39.8	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1611	 1	 24.7	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1612	 1	 55.2	 5.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1613	 1	 52.2	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1614	 1	 8.9	 -4.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1616	 1	 12.0	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1617	 1	 4.3	 -3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1619	 1	 26.8	 4.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1621	 1	 40.8	 -2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1622	 1	 59.6	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1623	 1	 -1.7	 -1.6	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1624	 1	 56.9	 12.6	 0.0	 0.0	 1	    0.99754	    0.00000	 63.0	 1	    1.04762	    0.94747;
	1625	 1	 47.5	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1627	 1	 12.3	 -2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1628	 1	 33.2	 7.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1629	 1	 51.2	 12.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1630	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1631	 1	 9.8	 3.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1632	 1	 60.3	 13.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1633	 1	 23.6	 5.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1634	 1	 20.6	 -2.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1635	 1	 21.9	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1636	 1	 10.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1637	 1	 22.6	 5.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1638	 1	 38.7	 2.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1639	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1640	 1	 22.3	 -0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1641	 1	 -2.9	 -4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1642	 1	 33.0	 3.1	 0.0	 0.0	 1	    1.00020	    0.00000	 63.0	 1	    1.06390	    0.93651;
	1643	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1644	 1	 16.9	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1645	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1646	 1	 24.4	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1647	 1	 16.5	 6.7	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1648	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1649	 1	 13.8	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1650	 1	 10.3	 -2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1651	 1	 43.5	 7.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1652	 1	 29.9	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1653	 1	 40.3	 6.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1654	 1	 21.1	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1655	 1	 19.1	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1656	 1	 24.1	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1657	 1	 48.6	 7.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1658	 1	 0.6	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1659	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1660	 1	 12.6	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1661	 1	 16.3	 13.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1662	 1	 34.7	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1663	 1	 46.9	 13.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1664	 1	 8.4	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1665	 1	 18.5	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1666	 1	 -1.5	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1667	 1	 21.6	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1668	 1	 31.7	 22.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1669	 1	 21.6	 3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1671	 1	 24.0	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1672	 1	 1.4	 0.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1673	 1	 61.4	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1675	 1	 10.4	 -6.6	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1676	 1	 20.8	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1677	 1	 12.5	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1678	 1	 58.5	 -7.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1679	 1	 4.3	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1680	 1	 37.6	 -5.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1681	 1	 18.2	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1682	 1	 59.6	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1684	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1685	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1687	 1	 8.0	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1688	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1689	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1690	 1	 90.3	 -0.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1691	 1	 0.7	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1692	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1693	 2	 -0.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1694	 1	 34.1	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07631	    0.00000	 380.0	 1	    1.11315	    1.03947;
	1696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07631	    0.00000	 380.0	 1	    1.11315	    1.03947;
	1697	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04009	    0.00000	 225.0	 1	    1.09351	    0.98667;
	1699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04001	    0.00000	 225.0	 1	    1.09336	    0.98667;
	1700	 2	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1701	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1702	 1	 8.3	 35.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1703	 2	 0.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1704	 2	 7.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1705	 1	 45.1	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1706	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1707	 1	 73.7	 25.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1717	 1	 66.9	 10.8	 0.0	 10.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	1718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01556	    0.00000	 225.0	 1	    1.08889	    0.94222;
	1719	 1	 66.4	 12.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1720	 1	 72.3	 17.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1721	 1	 1.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1723	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1724	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1726	 1	 23.6	 3.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1727	 1	 25.7	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1728	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1729	 1	 -3.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1730	 1	 14.8	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1731	 1	 52.5	 3.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1732	 1	 17.0	 4.3	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1733	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1734	 1	 14.1	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1735	 1	 26.5	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1738	 1	 15.0	 -1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1739	 1	 21.0	 2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1740	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1741	 1	 12.2	 -2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1742	 1	 -0.7	 3.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1743	 1	 -0.7	 3.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1745	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1747	 2	 -6.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1748	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1749	 2	 -4.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1752	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1753	 1	 21.0	 -4.3	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1756	 1	 23.8	 8.5	 0.0	 15.4	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1757	 1	 2.0	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1758	 1	 11.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1759	 1	 1.4	 0.9	 0.0	 0.0	 1	    1.00077	    0.00000	 63.0	 1	    1.06504	    0.93651;
	1760	 1	 25.8	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1761	 1	 19.6	 12.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1762	 1	 34.7	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1763	 1	 3.5	 2.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1764	 1	 6.6	 -0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1765	 1	 28.0	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1767	 1	 54.1	 8.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1768	 1	 0.4	 -4.4	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1769	 1	 21.4	 8.8	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1770	 1	 20.8	 -5.2	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1771	 1	 0.4	 -2.4	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1773	 1	 32.7	 18.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1774	 1	 -1.5	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1777	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1778	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1779	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1780	 1	 33.9	 4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1781	 1	 79.8	 5.4	 0.0	 30.4	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1782	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1783	 1	 15.9	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1784	 1	 1.5	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1785	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98531	    0.00000	 63.0	 1	    1.06585	    0.90476;
	1786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1788	 1	 11.2	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1789	 1	 0.7	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1791	 1	 29.4	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1792	 1	 18.1	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1795	 1	 13.0	 6.8	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1798	 1	 43.5	 8.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1799	 1	 35.0	 5.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1800	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1801	 1	 19.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1802	 1	 52.6	 15.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1803	 1	 2.2	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1806	 1	 6.7	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1807	 1	 18.7	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1808	 1	 5.9	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1809	 1	 5.0	 4.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1810	 1	 4.0	 3.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1811	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1813	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1814	 1	 33.0	 6.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1815	 1	 24.6	 6.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1816	 1	 49.8	 -1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1817	 1	 6.8	 1.6	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	1818	 1	 30.4	 -4.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1819	 1	 3.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1820	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1821	 1	 11.5	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1822	 1	 50.3	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1825	 1	 42.1	 6.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1826	 1	 44.8	 1.4	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1830	 1	 13.9	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1831	 1	 52.7	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1832	 1	 85.1	 -0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1834	 1	 -1.4	 -0.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1835	 1	 4.8	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1836	 1	 15.9	 2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1837	 1	 16.3	 -2.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1838	 1	 47.7	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1840	 1	 36.0	 18.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1841	 1	 -1.2	 -2.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1842	 1	 -0.2	 -0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1843	 1	 8.4	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1845	 1	 -2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1846	 1	 7.4	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1847	 1	 11.4	 10.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1848	 1	 -0.2	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1850	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1851	 1	 17.9	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1852	 1	 0.3	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1853	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1854	 1	 35.1	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1855	 1	 22.0	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1856	 1	 28.0	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1857	 1	 21.1	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1858	 1	 29.2	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1859	 1	 40.7	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1860	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1861	 2	 0.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1862	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1864	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1865	 1	 9.0	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1866	 1	 15.0	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1867	 1	 28.4	 7.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1868	 1	 35.8	 1.4	 0.0	 0.0	 1	    1.01921	    0.00000	 90.0	 1	    1.06667	    0.97176;
	1869	 1	 3.1	 -3.7	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1870	 1	 36.5	 -5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1871	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1872	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1873	 1	 49.8	 8.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1874	 1	 39.2	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1875	 1	 18.9	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1876	 1	 0.8	 1.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1877	 1	 3.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1878	 1	 51.9	 19.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1879	 1	 6.0	 -2.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1880	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1881	 1	 -3.4	 2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1882	 1	 21.9	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1883	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1884	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1885	 1	 14.4	 -2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1886	 1	 10.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1887	 1	 10.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1888	 1	 32.4	 1.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1889	 1	 37.8	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1890	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1891	 1	 34.8	 15.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1892	 1	 29.4	 9.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1893	 1	 110.8	 28.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1894	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1895	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1896	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1897	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1900	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1902	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1905	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1906	 1	 15.0	 -5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1907	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1908	 1	 1.2	 -2.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1909	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1910	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1911	 1	 30.1	 -0.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1912	 1	 31.6	 6.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1913	 1	 47.0	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1914	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1917	 1	 -1.7	 15.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1918	 1	 77.2	 6.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1919	 1	 16.2	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1920	 1	 67.2	 10.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1921	 1	 40.3	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1922	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1923	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1924	 1	 3.7	 -5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1925	 1	 32.0	 5.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1926	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1927	 1	 52.5	 14.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1928	 2	 16.2	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1930	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1931	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1932	 1	 58.1	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1933	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1934	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1935	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1936	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1938	 1	 -9.7	 -15.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1940	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1941	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1942	 1	 25.0	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1945	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01556	    0.00000	 225.0	 1	    1.08889	    0.94222;
	1946	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1947	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00014	    0.00000	 63.0	 1	    1.04790	    0.95238;
	1948	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1949	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1950	 1	 13.4	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1951	 1	 25.3	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1952	 1	 37.2	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1953	 1	 38.0	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1954	 1	 15.6	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1955	 1	 27.7	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1956	 1	 0.9	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1957	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1958	 1	 16.3	 -5.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1959	 1	 1.2	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1960	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1961	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1963	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1964	 1	 21.7	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1966	 1	 13.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1967	 1	 30.9	 -2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1968	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1969	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1970	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1971	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1972	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1974	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1977	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1978	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1979	 1	 9.6	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1981	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1982	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1983	 2	 -1.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1984	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1985	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1986	 1	 32.3	 0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1987	 2	 -1.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1988	 1	 1.5	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1989	 1	 55.9	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1990	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1991	 1	 43.8	 4.0	 0.0	 0.0	 1	    1.02363	    0.00000	 90.0	 1	    1.06949	    0.97778;
	1992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1993	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1994	 1	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1995	 1	 0.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1996	 1	 15.1	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1998	 1	 13.5	 2.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1999	 1	 14.2	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2000	 1	 8.9	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2001	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2002	 1	 0.4	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2004	 1	 21.9	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2006	 1	 56.5	 13.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2007	 1	 14.0	 3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2008	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2009	 1	 49.6	 9.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2010	 1	 22.3	 6.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2011	 1	 1.7	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2012	 1	 21.9	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2013	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2014	 1	 13.3	 -2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2015	 1	 2.0	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2016	 1	 61.6	 21.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2017	 1	 -14.2	 -22.1	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2018	 1	 -2.1	 16.2	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2019	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2020	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2021	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04527	    0.00000	 225.0	 1	    1.09055	    1.00000;
	2022	 1	 7.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2023	 1	 0.6	 -2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2024	 1	 27.8	 18.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2025	 1	 27.9	 -0.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2026	 1	 35.3	 4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2027	 1	 46.7	 1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2028	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2029	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2030	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2031	 1	 10.1	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2032	 1	 61.6	 11.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2033	 1	 31.6	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2034	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2035	 1	 32.5	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2036	 1	 9.9	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2037	 1	 15.9	 -2.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2038	 1	 17.8	 -4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2039	 1	 8.0	 -5.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2040	 1	 32.5	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2042	 1	 48.6	 2.6	 0.0	 15.4	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2043	 1	 10.5	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2044	 1	 38.7	 3.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2045	 1	 8.0	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2048	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2050	 1	 30.7	 0.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2051	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2052	 1	 24.8	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2053	 1	 16.4	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2054	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2055	 1	 -0.7	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2058	 1	 19.4	 3.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2059	 1	 16.4	 2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2060	 1	 17.4	 1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2061	 1	 17.0	 -4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2062	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2064	 1	 -7.8	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2065	 1	 -6.4	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2066	 1	 -15.8	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2068	 1	 14.3	 3.2	 0.0	 0.0	 1	    1.00051	    0.00000	 63.0	 1	    1.06451	    0.93651;
	2069	 1	 49.2	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2070	 1	 31.1	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2071	 1	 0.1	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2072	 1	 37.1	 3.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00108	    0.00000	 63.0	 1	    1.06566	    0.93651;
	2074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2076	 1	 15.0	 5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2077	 1	 22.9	 -6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2079	 1	 34.3	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2080	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2081	 1	 71.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2082	 1	 97.0	 -5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2084	 1	 0.5	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2085	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2086	 1	 18.7	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2089	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2090	 1	 51.6	 9.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2091	 1	 27.0	 4.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2092	 1	 13.9	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2093	 1	 21.3	 3.8	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	2095	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	2096	 1	 53.9	 19.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2098	 1	 13.7	 3.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2099	 2	 10.0	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2100	 1	 23.7	 -0.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2101	 1	 18.0	 -6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2102	 1	 14.0	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2103	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04461	    0.00000	 225.0	 1	    1.08478	    1.00444;
	2106	 1	 30.6	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2107	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2108	 1	 16.6	 4.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2109	 1	 1.7	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2110	 1	 8.7	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2111	 1	 7.7	 -2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2114	 1	 5.7	 -3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2115	 1	 15.6	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2116	 1	 25.9	 3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2117	 1	 14.9	 9.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2118	 1	 26.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2119	 1	 -0.3	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2120	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2121	 1	 3.0	 -0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2122	 1	 49.1	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2123	 1	 28.9	 -8.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2127	 1	 14.0	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2128	 1	 15.1	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2129	 1	 36.4	 -4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	2135	 1	 38.6	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.08889	    0.95556;
	2136	 1	 17.3	 4.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2137	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2138	 1	 13.0	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2140	 1	 404.1	 116.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2141	 1	 20.1	 9.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2142	 1	 3.0	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2143	 1	 16.1	 -1.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2144	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2145	 1	 -1.8	 2.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2146	 1	 31.2	 13.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2147	 1	 57.5	 11.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2151	 1	 20.2	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2152	 1	 12.0	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2153	 1	 25.5	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2154	 1	 25.3	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2155	 1	 12.7	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2158	 1	 40.8	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2159	 1	 14.0	 4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2160	 1	 57.3	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2161	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2162	 1	 54.8	 5.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04522	    0.00000	 225.0	 1	    1.08599	    1.00444;
	2165	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2166	 1	 36.6	 -1.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2168	 1	 5.6	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2169	 1	 8.6	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2170	 1	 14.6	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2171	 1	 -0.7	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2172	 1	 20.0	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2174	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2175	 1	 32.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2176	 1	 32.3	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2177	 1	 65.8	 20.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2180	 1	 58.0	 15.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2181	 1	 19.2	 6.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2182	 1	 19.6	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2183	 1	 60.2	 12.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2184	 1	 35.2	 6.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2186	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2187	 1	 26.1	 1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2189	 1	 2.0	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2190	 1	 35.2	 1.8	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	2191	 1	 42.8	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2192	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2193	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2194	 1	 18.1	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2195	 2	 0.7	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2196	 1	 6.2	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	2197	 1	 6.2	 0.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2199	 1	 11.2	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2200	 1	 -5.8	 8.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2201	 1	 -8.2	 2.3	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2202	 1	 10.2	 -0.9	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	2203	 1	 61.3	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2204	 1	 51.3	 2.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2205	 1	 2.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2206	 1	 115.5	 6.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2207	 1	 14.9	 5.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2208	 1	 27.2	 6.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2209	 1	 1.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2210	 1	 94.8	 9.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2211	 1	 8.9	 -1.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2212	 1	 15.9	 3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2213	 1	 7.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2214	 1	 42.7	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2215	 1	 26.6	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2216	 1	 78.2	 8.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2217	 1	 123.2	 36.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2218	 1	 2.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2219	 1	 15.4	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2220	 1	 40.4	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2221	 1	 28.3	 4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2223	 1	 79.9	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2225	 1	 6.9	 1.2	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2226	 1	 40.0	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2227	 1	 31.0	 10.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2230	 1	 21.6	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2231	 1	 6.2	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2233	 1	 36.0	 7.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2234	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2235	 1	 17.4	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2236	 1	 -11.9	 -0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	2237	 1	 51.7	 7.7	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2238	 1	 11.3	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2239	 1	 -0.6	 4.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2240	 1	 0.3	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2241	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.83000	    0.00000	 150.0	 1	    1.00000	    0.66000;
	2242	 1	 48.1	 -14.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2243	 1	 14.3	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2244	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2245	 1	 3.3	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2247	 2	 0.5	 -0.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2248	 1	 4.0	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2250	 1	 9.9	 -9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2251	 1	 31.1	 0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2252	 1	 10.2	 5.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2253	 1	 21.0	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	2254	 1	 49.3	 30.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2256	 1	 94.6	 6.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2257	 1	 45.7	 12.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2258	 1	 65.3	 10.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2259	 1	 55.1	 8.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2260	 1	 1.9	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2261	 1	 6.0	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2262	 1	 15.4	 2.8	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2263	 1	 33.3	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2266	 1	 29.5	 -1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2267	 1	 4.6	 -0.5	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	2268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03873	    0.00000	 63.0	 1	    1.12508	    0.95238;
	2269	 1	 1.9	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2270	 1	 -2.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2271	 1	 56.4	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	2274	 1	 29.7	 4.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2276	 1	 2.0	 -4.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2278	 1	 1.2	 -0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2279	 1	 3.6	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2281	 1	 8.9	 -8.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2282	 1	 -144.4	 -14.3	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	2283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	2284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2285	 1	 60.5	 24.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2286	 1	 18.1	 1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2287	 1	 6.2	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2291	 1	 15.3	 3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2292	 1	 49.4	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2295	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2296	 1	 50.6	 15.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2297	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00463	    0.00000	 63.0	 1	    1.07275	    0.93651;
	2299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2300	 1	 39.3	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2301	 1	 18.1	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2302	 1	 7.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2303	 1	 11.1	 -3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2304	 1	 -0.6	 -1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2305	 1	 15.7	 0.3	 0.0	 15.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2306	 1	 9.0	 -0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2307	 1	 5.0	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2308	 1	 54.5	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2309	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2310	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2311	 1	 29.2	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2312	 1	 20.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2313	 1	 60.4	 0.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2315	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2316	 1	 62.0	 10.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2317	 1	 15.9	 4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2318	 1	 35.0	 3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2319	 1	 10.0	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2320	 1	 14.9	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2321	 1	 52.3	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2322	 1	 18.5	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2323	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2324	 1	 20.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2325	 1	 50.3	 13.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2326	 1	 38.5	 11.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2327	 1	 32.3	 4.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2328	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2329	 1	 14.1	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2331	 1	 41.5	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2332	 1	 9.4	 -3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2333	 1	 5.0	 5.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2334	 1	 16.8	 3.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2335	 1	 19.2	 9.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2336	 1	 0.3	 4.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2337	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07688	    0.00000	 380.0	 1	    1.10263	    1.05114;
	2338	 1	 26.3	 -4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2339	 1	 13.6	 8.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2340	 1	 1.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2341	 2	 5.0	 2.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2342	 2	 1.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2343	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2344	 1	 16.7	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2345	 1	 12.1	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2347	 1	 16.8	 -1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2348	 1	 38.6	 -0.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2351	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2353	 1	 10.0	 4.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2354	 1	 21.0	 -7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2355	 1	 8.4	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2356	 1	 10.9	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2357	 1	 8.8	 -3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2358	 1	 42.9	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2359	 1	 18.6	 7.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2360	 1	 31.4	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2361	 1	 63.1	 5.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2362	 1	 45.7	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2364	 2	 -3.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2365	 2	 -2.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2366	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2367	 2	 -0.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2368	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2374	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2377	 1	 1.4	 -0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2378	 1	 22.9	 6.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2379	 1	 12.2	 -4.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2380	 1	 7.2	 5.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2381	 1	 26.3	 -4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2382	 1	 2.4	 1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2383	 1	 8.0	 -2.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2384	 1	 27.0	 1.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2385	 1	 7.0	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2386	 1	 43.8	 4.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2387	 1	 18.6	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2388	 1	 1.9	 1.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2389	 1	 10.0	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2390	 1	 0.6	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2391	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2392	 1	 14.3	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2393	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2394	 1	 7.6	 -3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2395	 1	 19.4	 -5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2396	 1	 11.0	 -3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2397	 1	 35.9	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2398	 1	 7.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2399	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2401	 1	 49.7	 17.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2402	 1	 12.3	 5.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2403	 1	 8.3	 5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2404	 1	 11.8	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2405	 1	 23.9	 -0.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2406	 1	 9.7	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2407	 1	 10.0	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2409	 1	 15.4	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2410	 1	 17.7	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2411	 1	 18.8	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2412	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2413	 1	 34.6	 5.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2414	 1	 50.9	 4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2415	 1	 4.9	 1.3	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2416	 1	 16.5	 12.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2417	 1	 16.5	 16.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2418	 1	 0.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2419	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2420	 1	 -13.0	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2421	 1	 21.0	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2422	 1	 0.8	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2423	 1	 48.5	 5.5	 0.0	 29.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2426	 1	 30.4	 -1.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2427	 1	 10.8	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2428	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2429	 1	 13.9	 -4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2430	 1	 17.5	 4.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2431	 1	 18.9	 4.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2433	 1	 18.0	 6.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2434	 1	 11.8	 -6.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2435	 1	 50.1	 11.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2436	 1	 105.8	 25.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2437	 1	 9.4	 -3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2439	 1	 2.0	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2440	 1	 11.1	 -5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2441	 1	 38.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2442	 1	 5.3	 -0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2443	 1	 14.6	 0.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2444	 1	 16.8	 2.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2445	 1	 17.8	 -0.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2446	 1	 9.0	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2449	 1	 35.9	 -2.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2450	 1	 2.7	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2451	 1	 10.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2452	 1	 17.4	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2453	 1	 29.9	 -10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2454	 1	 60.4	 12.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2456	 1	 12.6	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2460	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04536	    0.00000	 225.0	 1	    1.09073	    1.00000;
	2461	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2462	 1	 0.7	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2463	 1	 4.4	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2464	 1	 8.8	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2465	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2466	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2468	 1	 0.0	 0.0	 0.0	 30.4	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2471	 1	 26.1	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2472	 1	 49.4	 1.6	 0.0	 0.0	 1	    1.01475	    0.00000	 63.0	 1	    1.06349	    0.96601;
	2473	 1	 10.0	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2474	 1	 12.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2475	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2478	 1	 10.5	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2481	 1	 21.1	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2482	 1	 65.4	 17.0	 0.0	 92.0	 1	    1.02259	    0.00000	 90.0	 1	    1.06741	    0.97778;
	2483	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2485	 1	 34.4	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2486	 1	 14.4	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2487	 1	 22.7	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2488	 1	 23.8	 -8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2489	 1	 16.7	 1.6	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2491	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2492	 1	 30.1	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2493	 1	 47.2	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2494	 1	 23.9	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2495	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2496	 1	 26.2	 -2.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2497	 1	 0.0	 0.4	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2498	 1	 9.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2499	 1	 17.8	 -6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2500	 1	 0.0	 -0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2501	 1	 17.2	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2502	 1	 42.1	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2504	 1	 38.8	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2505	 1	 4.0	 -4.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2506	 1	 13.6	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2507	 1	 33.6	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2508	 1	 5.0	 -3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2509	 1	 31.7	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2511	 1	 26.6	 1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2512	 1	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2513	 1	 51.6	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2514	 1	 48.6	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2519	 1	 17.1	 9.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2520	 1	 19.1	 6.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2522	 1	 -0.7	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2523	 2	 87.0	 9.0	 0.0	 0.0	 1	    1.04906	    0.00000	 90.0	 1	    1.14256	    0.95556;
	2524	 1	 19.8	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2525	 1	 51.4	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2526	 1	 53.8	 3.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2527	 1	 8.7	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2529	 1	 54.3	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2530	 1	 19.5	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2531	 1	 45.4	 5.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2532	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2534	 1	 81.2	 12.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2535	 1	 16.2	 10.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2537	 1	 11.8	 -4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2538	 1	 37.0	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2540	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2541	 1	 14.0	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2542	 1	 33.4	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2544	 1	 25.8	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2545	 1	 31.0	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2546	 1	 0.9	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2547	 1	 2.0	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2548	 1	 11.8	 -0.3	 0.0	 60.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2549	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	2550	 1	 32.8	 3.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2551	 1	 60.5	 14.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2552	 1	 27.0	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2553	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.00228	    0.00000	 63.0	 1	    1.06806	    0.93651;
	2554	 1	 46.9	 1.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2555	 1	 4.9	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2556	 1	 22.9	 -0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2557	 1	 14.3	 -0.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2558	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2559	 1	 20.7	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2560	 1	 33.9	 0.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2561	 1	 19.3	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2562	 1	 34.7	 -6.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2563	 1	 10.7	 -1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2564	 1	 15.4	 -0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2565	 1	 16.9	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2566	 1	 40.6	 13.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2569	 1	 40.4	 4.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2570	 1	 7.4	 1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2571	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2572	 1	 35.4	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2573	 1	 30.2	 4.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2574	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2575	 1	 63.8	 16.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2576	 1	 12.3	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2577	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2578	 1	 18.5	 14.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	2580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2581	 1	 29.8	 -5.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2582	 1	 26.2	 5.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2586	 1	 19.7	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2587	 1	 0.1	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2588	 1	 -0.5	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2589	 1	 6.0	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2591	 1	 48.6	 21.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2592	 1	 37.5	 1.0	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	2593	 1	 13.0	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2594	 1	 49.8	 9.8	 0.0	 30.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2596	 1	 1.5	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2597	 1	 21.2	 3.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2599	 1	 10.3	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2600	 1	 -2.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2601	 1	 35.6	 -7.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2602	 1	 25.9	 -2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2603	 1	 16.5	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2604	 1	 28.4	 -6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2608	 1	 18.7	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2610	 1	 23.6	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2611	 2	 23.2	 0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2612	 1	 5.2	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2613	 1	 30.2	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2614	 1	 49.9	 12.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2615	 1	 12.6	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2616	 1	 48.0	 5.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2618	 1	 28.2	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2619	 1	 17.0	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2620	 1	 12.5	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2621	 1	 30.0	 6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2622	 1	 7.4	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2623	 1	 13.7	 -2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2624	 1	 32.9	 4.1	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	2625	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	2626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2627	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2628	 1	 62.5	 14.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2629	 1	 22.7	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2630	 1	 6.9	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2631	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2632	 1	 8.4	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2633	 1	 13.3	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2634	 1	 16.2	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2635	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2636	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2637	 1	 19.2	 -2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2639	 1	 0.5	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2640	 2	 -2.9	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2641	 1	 3.0	 -1.9	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2642	 1	 49.9	 12.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2643	 1	 -12.6	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2644	 2	 0.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2645	 2	 7.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2646	 2	 -14.4	 -6.3	 0.0	 0.0	 1	    1.00421	    0.00000	 63.0	 1	    1.08779	    0.92063;
	2647	 1	 -1.2	 -0.4	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2648	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2649	 1	 15.8	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2650	 1	 17.8	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2651	 1	 8.5	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2652	 2	 3.5	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	2655	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2656	 1	 4.4	 -2.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2657	 1	 0.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2658	 1	 23.7	 4.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2659	 2	 -7.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2660	 2	 0.6	 7.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2661	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2662	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2663	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2664	 2	 -0.4	 2.3	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2665	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2667	 1	 73.6	 9.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2669	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	2670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2673	 1	 54.8	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2674	 1	 7.0	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2675	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2676	 1	 10.0	 -3.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2677	 1	 49.4	 8.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2678	 1	 4.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2679	 1	 7.8	 8.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2680	 1	 -0.7	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2681	 1	 46.2	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2682	 1	 95.1	 22.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2683	 1	 43.5	 3.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2684	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2685	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2686	 1	 38.6	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2687	 1	 24.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2688	 1	 20.0	 3.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2689	 1	 10.8	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2690	 1	 8.6	 -0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2691	 1	 24.3	 -1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2692	 1	 25.7	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2693	 1	 118.4	 29.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2694	 1	 16.0	 7.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2695	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2696	 1	 19.2	 -3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2697	 1	 24.4	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2698	 1	 16.4	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2699	 1	 15.3	 4.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2700	 1	 0.2	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2701	 1	 43.4	 0.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2702	 1	 19.2	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2703	 1	 13.5	 9.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00156	    0.00000	 63.0	 1	    1.06662	    0.93651;
	2706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2708	 1	 6.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2709	 1	 28.7	 0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2711	 1	 30.9	 -1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2712	 1	 34.6	 4.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	2713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2715	 1	 33.0	 6.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2718	 1	 5.5	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2719	 1	 -1.3	 4.6	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2720	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2721	 1	 0.0	 0.0	 0.0	 640.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2722	 1	 69.5	 18.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2723	 1	 30.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2724	 1	 2.5	 -0.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2725	 1	 24.6	 -1.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2726	 1	 32.2	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2727	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2728	 1	 8.1	 -5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2729	 1	 11.3	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2730	 1	 0.0	 -2.0	 0.0	 0.0	 1	    1.00330	    0.00000	 63.0	 1	    1.07009	    0.93651;
	2731	 1	 35.7	 3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2732	 1	 8.8	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2733	 1	 25.9	 -7.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2734	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2735	 1	 21.5	 -1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2736	 1	 5.0	 1.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2737	 1	 5.8	 13.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2738	 1	 1.3	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2739	 1	 1.0	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2740	 1	 14.0	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2741	 1	 20.0	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2742	 1	 11.8	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2743	 1	 18.6	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2745	 1	 1.4	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2746	 1	 16.7	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2747	 1	 4.3	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	2748	 1	 -0.1	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04532	    0.00000	 225.0	 1	    1.09064	    1.00000;
	2750	 1	 26.8	 -3.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2751	 1	 -0.6	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2752	 1	 29.5	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2753	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00409	    0.00000	 63.0	 1	    1.05579	    0.95238;
	2756	 1	 45.9	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2757	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2758	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2759	 1	 2.0	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2760	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2761	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04167	    0.00000	 63.0	 1	    1.13096	    0.95238;
	2766	 1	 24.6	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2767	 1	 36.0	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2768	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2772	 1	 21.5	 -1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2773	 1	 12.8	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2776	 1	 42.5	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2778	 1	 31.7	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2779	 1	 60.5	 11.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2783	 1	 12.1	 14.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2785	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07213	    0.00000	 380.0	 1	    1.10263	    1.04163;
	2786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07151	    0.00000	 380.0	 1	    1.10263	    1.04038;
	2787	 1	 24.6	 3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2788	 1	 17.7	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2789	 1	 14.9	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2792	 1	 5.3	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2793	 1	 -0.0	 -0.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2794	 1	 95.9	 7.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2795	 1	 131.1	 20.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2797	 1	 -0.4	 4.0	 0.0	 80.0	 1	    1.02222	    0.00000	 225.0	 1	    1.08889	    0.95556;
	2798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2799	 1	 15.0	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2800	 1	 16.9	 -2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2801	 1	 49.7	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	2804	 1	 2.5	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	2805	 1	 17.8	 13.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2806	 1	 31.9	 -8.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2807	 1	 15.6	 -7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2808	 1	 9.0	 2.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2809	 1	 0.0	 0.0	 0.0	 89.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2810	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2811	 1	 28.2	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2812	 1	 24.6	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2813	 1	 5.3	 0.7	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	2814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2815	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2816	 1	 17.0	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2817	 1	 8.9	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2818	 2	 2.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2819	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03896	    0.00000	 225.0	 1	    1.09125	    0.98667;
	2821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03891	    0.00000	 225.0	 1	    1.09116	    0.98667;
	2822	 1	 53.5	 8.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2823	 1	 9.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2824	 1	 30.5	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2825	 1	 102.4	 19.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2826	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2827	 1	 22.6	 2.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2828	 1	 26.5	 5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2829	 1	 60.0	 9.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2830	 1	 7.7	 -2.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2831	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98947	    0.00000	 225.0	 1	    1.09005	    0.88889;
	2832	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2833	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2834	 1	 26.8	 2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2835	 1	 43.7	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2836	 1	 11.6	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2837	 1	 3.5	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2838	 2	 0.6	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2839	 1	 44.1	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2840	 1	 15.2	 -4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2841	 1	 41.6	 -28.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2842	 1	 17.8	 -6.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2843	 1	 62.7	 2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2844	 1	 -0.1	 -20.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2845	 1	 24.9	 -6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2846	 1	 19.9	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2847	 1	 49.3	 6.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2850	 1	 19.3	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2851	 1	 42.5	 7.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2852	 1	 41.5	 15.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2853	 1	 22.8	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2854	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2855	 1	 -13.1	 -12.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2856	 1	 1.7	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2857	 1	 10.9	 -2.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2858	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2859	 1	 0.5	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2860	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2861	 1	 63.3	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2862	 1	 1.4	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2864	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2865	 1	 20.0	 1.4	 0.0	 0.0	 1	    1.00107	    0.00000	 63.0	 1	    1.06563	    0.93651;
	2866	 1	 29.0	 6.9	 0.0	 0.0	 1	    1.00038	    0.00000	 63.0	 1	    1.06425	    0.93651;
	2867	 1	 20.4	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2868	 1	 7.8	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2869	 1	 15.0	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2870	 1	 -0.3	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2871	 1	 -5.0	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2872	 1	 20.9	 4.0	 0.0	 0.0	 1	    1.02112	    0.00000	 90.0	 1	    1.06667	    0.97557;
	2873	 1	 0.6	 -6.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2874	 1	 36.4	 6.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2876	 1	 36.0	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2877	 1	 3.0	 2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2878	 1	 16.9	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2879	 1	 9.3	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2880	 1	 0.6	 4.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2881	 1	 1.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2882	 1	 0.5	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2883	 1	 29.6	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2884	 1	 25.1	 4.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2885	 1	 37.5	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2886	 1	 5.8	 -7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2887	 1	 32.7	 12.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2888	 1	 -0.1	 -0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2889	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00014	    0.00000	 63.0	 1	    1.06378	    0.93651;
	2890	 1	 19.6	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2891	 1	 68.0	 7.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2892	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2894	 1	 0.7	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2895	 1	 47.9	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2896	 1	 5.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2897	 1	 14.6	 4.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2898	 1	 8.8	 -8.1	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2899	 2	 0.0	 1.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2900	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00968	    0.00000	 63.0	 1	    1.09872	    0.92063;
	2901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2902	 1	 30.9	 -1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2904	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2905	 1	 52.8	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2906	 1	 37.8	 -5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2907	 1	 21.7	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2908	 2	 20.0	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2909	 1	 14.9	 -6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2910	 1	 23.4	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2911	 1	 20.2	 -4.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2912	 1	 31.5	 7.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2913	 1	 63.4	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2914	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2918	 1	 7.0	 2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2919	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2920	 1	 47.0	 2.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2921	 1	 15.3	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2922	 1	 20.0	 3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2923	 1	 22.7	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2924	 1	 11.9	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2925	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2926	 1	 36.7	 -6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2927	 1	 14.9	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2928	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2929	 1	 57.9	 12.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2930	 1	 35.4	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2931	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2932	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2933	 1	 65.0	 15.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2934	 1	 44.9	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2935	 1	 10.8	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2936	 1	 21.3	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2938	 1	 12.0	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2939	 1	 8.0	 1.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2940	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2941	 1	 14.6	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2942	 1	 13.0	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2943	 1	 13.0	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2945	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04529	    0.00000	 225.0	 1	    1.09058	    1.00000;
	2946	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2947	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2948	 1	 9.9	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2949	 1	 28.8	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2950	 1	 157.7	 47.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2951	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2952	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2953	 1	 16.7	 -4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2954	 1	 18.1	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2955	 1	 46.6	 11.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2956	 1	 14.9	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2957	 1	 -0.2	 -0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2958	 1	 12.4	 -4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2960	 1	 17.3	 -6.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2961	 1	 12.9	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2962	 1	 0.0	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2963	 1	 12.7	 -1.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2964	 1	 29.2	 7.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2967	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2968	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2970	 1	 -1.0	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2971	 1	 50.4	 23.9	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2973	 1	 30.1	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2974	 1	 23.7	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2975	 2	 0.1	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2976	 1	 45.3	 5.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2977	 1	 22.3	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2978	 1	 25.9	 -4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2979	 1	 34.7	 -1.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2980	 1	 1.8	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2981	 1	 3.0	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2982	 1	 28.5	 4.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2983	 1	 18.9	 9.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2984	 1	 16.2	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2985	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2986	 1	 36.8	 3.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2987	 1	 31.9	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2988	 1	 -5.7	 5.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2989	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2990	 1	 14.0	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2991	 1	 18.5	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2992	 1	 22.1	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2993	 2	 12.0	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2994	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2995	 1	 6.7	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2998	 1	 57.5	 15.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2999	 1	 56.1	 27.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3000	 1	 46.2	 -9.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3001	 1	 42.8	 13.1	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3003	 1	 28.6	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3004	 1	 50.2	 2.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3006	 1	 137.7	 15.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3007	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3008	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3009	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3011	 1	 24.1	 4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3012	 1	 56.0	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3013	 1	 60.7	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3014	 1	 2.3	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3015	 1	 49.5	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3016	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3017	 1	 22.5	 2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3018	 1	 0.8	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3020	 2	 1.8	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3021	 2	 13.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3022	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00129	    0.00000	 63.0	 1	    1.06608	    0.93651;
	3023	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3024	 1	 11.0	 -1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3025	 1	 1.0	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3026	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3027	 1	 37.6	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3028	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3029	 1	 48.8	 5.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3030	 1	 3.6	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3031	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3032	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3033	 1	 24.7	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3034	 1	 42.1	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3035	 1	 24.3	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3036	 1	 28.9	 -4.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3037	 1	 31.1	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3038	 1	 -35.5	 9.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3039	 1	 1.3	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3040	 1	 21.8	 -9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3041	 1	 0.9	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3042	 1	 56.8	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3043	 1	 20.5	 -1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3044	 1	 22.0	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3045	 1	 11.9	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3046	 1	 40.6	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3047	 1	 41.3	 4.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3048	 1	 10.4	 2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3049	 1	 60.0	 12.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3050	 1	 9.0	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3052	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3053	 1	 1.2	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3054	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07928	    0.00000	 380.0	 1	    1.10593	    1.05263;
	3057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07932	    0.00000	 380.0	 1	    1.10601	    1.05263;
	3058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07932	    0.00000	 380.0	 1	    1.10601	    1.05263;
	3059	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3060	 1	 39.8	 4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3061	 1	 15.9	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3062	 1	 30.5	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3063	 1	 21.3	 5.3	 0.0	 29.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3065	 1	 15.8	 -2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3066	 1	 31.7	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3067	 1	 29.3	 6.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3068	 1	 49.9	 2.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3069	 1	 33.4	 -2.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3070	 1	 6.4	 -0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3071	 1	 4.7	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3072	 1	 25.9	 -4.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3073	 1	 34.2	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3075	 1	 0.0	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3077	 1	 1.9	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3078	 1	 20.3	 0.6	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3079	 1	 3.9	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3080	 1	 12.5	 3.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3081	 1	 23.6	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3085	 1	 93.0	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3087	 1	 3.1	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3089	 1	 5.9	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3090	 1	 30.8	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3091	 1	 29.8	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3092	 1	 19.5	 2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3093	 1	 0.0	 -0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3094	 1	 1.0	 -2.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3095	 1	 14.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3096	 1	 17.8	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3097	 1	 13.6	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3098	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3099	 1	 26.2	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3101	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3102	 1	 75.2	 21.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3104	 1	 32.1	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3105	 1	 15.8	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3106	 1	 9.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3107	 2	 7.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3108	 1	 34.0	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3109	 1	 70.3	 4.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3110	 1	 -1.2	 -2.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3111	 1	 53.4	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3112	 1	 46.4	 19.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3113	 1	 11.6	 -0.2	 0.0	 16.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3114	 1	 -0.2	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3116	 2	 -0.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3117	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3118	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3122	 1	 22.6	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3123	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3124	 1	 7.3	 0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3125	 1	 12.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3126	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3127	 1	 91.7	 19.9	 0.0	 19.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3129	 1	 36.1	 2.4	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3130	 1	 2.0	 2.0	 0.0	 0.0	 1	    1.00480	    0.00000	 63.0	 1	    1.08896	    0.92063;
	3131	 1	 26.5	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3132	 1	 13.7	 -5.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3133	 1	 38.6	 4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3134	 1	 31.2	 4.2	 0.0	 0.0	 1	    1.00135	    0.00000	 63.0	 1	    1.06620	    0.93651;
	3135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3136	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3137	 1	 60.1	 11.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3138	 1	 42.2	 -4.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3139	 1	 12.6	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3140	 1	 33.0	 7.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3141	 1	 47.1	 -7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3142	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3144	 1	 6.5	 1.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3145	 1	 17.7	 12.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3146	 1	 54.5	 5.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3147	 1	 25.8	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3148	 1	 1.0	 0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05375	    0.00000	 380.0	 1	    1.10263	    1.00487;
	3151	 1	 16.8	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3152	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	3153	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3155	 1	 4.9	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3156	 1	 32.5	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3157	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3158	 1	 32.0	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3159	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3160	 1	 20.1	 4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3161	 1	 23.6	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3162	 1	 0.3	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3163	 1	 117.4	 24.9	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3164	 1	 9.4	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04474	    0.00000	 225.0	 1	    1.08948	    1.00000;
	3166	 1	 1.8	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3167	 1	 57.4	 14.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3168	 1	 44.1	 6.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3170	 1	 0.7	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3172	 1	 15.3	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3173	 1	 0.7	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3174	 1	 48.5	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3175	 1	 38.9	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3177	 1	 8.4	 -3.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3178	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3179	 1	 0.0	 0.0	 0.0	 78.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06504	    0.00000	 380.0	 1	    1.10263	    1.02745;
	3181	 1	 18.8	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3182	 1	 25.3	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3183	 1	 10.5	 1.8	 0.0	 0.0	 1	    0.98794	    0.00000	 63.0	 1	    1.07112	    0.90476;
	3184	 1	 27.7	 -1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3185	 1	 48.5	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3186	 1	 22.9	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3187	 1	 11.3	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3188	 1	 13.3	 -0.6	 0.0	 0.0	 1	    1.00356	    0.00000	 63.0	 1	    1.07062	    0.93651;
	3189	 1	 3.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3190	 1	 45.8	 9.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3191	 1	 15.0	 5.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3192	 1	 25.0	 6.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3193	 1	 31.2	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3194	 1	 37.0	 33.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3195	 1	 35.2	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3196	 1	 8.7	 4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3197	 1	 40.0	 12.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3199	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3201	 1	 56.3	 13.0	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3202	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99556	    0.00000	 225.0	 1	    1.08889	    0.90222;
	3203	 1	 12.9	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3204	 1	 30.3	 20.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3205	 1	 0.3	 6.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3206	 1	 20.1	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3207	 1	 14.7	 0.6	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3208	 1	 22.1	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3209	 1	 18.7	 -4.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3210	 2	 11.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3211	 1	 48.2	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3212	 1	 127.0	 32.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3213	 1	 7.5	 -0.2	 0.0	 0.0	 1	    0.97073	    0.00000	 63.0	 1	    1.05257	    0.88889;
	3214	 1	 0.8	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00799	    0.00000	 63.0	 1	    1.06360	    0.95238;
	3216	 1	 2.9	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3217	 1	 163.3	 70.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3218	 1	 46.9	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3219	 1	 16.6	 -5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3220	 1	 59.5	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3221	 1	 5.0	 -2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3223	 1	 0.6	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3224	 1	 18.2	 3.2	 0.0	 0.0	 1	    1.01287	    0.00000	 63.0	 1	    1.06349	    0.96226;
	3225	 1	 3.0	 -0.3	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3226	 1	 28.0	 -7.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3227	 1	 25.7	 -1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3228	 1	 4.8	 5.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3229	 1	 0.0	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3230	 1	 19.2	 -37.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3231	 1	 50.2	 8.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3232	 1	 50.2	 9.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3233	 1	 44.7	 10.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3234	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3235	 1	 35.0	 1.4	 0.0	 0.0	 1	    1.01825	    0.00000	 90.0	 1	    1.06667	    0.96984;
	3236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3237	 1	 1.3	 1.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3238	 1	 24.0	 2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3239	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3241	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3242	 1	 7.4	 2.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3243	 1	 24.1	 69.1	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	3244	 1	 19.5	 2.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3245	 1	 30.7	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3246	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3247	 1	 35.6	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3248	 1	 3.0	 1.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3249	 1	 8.2	 -3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3250	 1	 47.7	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3251	 1	 44.1	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3252	 1	 10.0	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3258	 1	 46.9	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3259	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3260	 1	 17.3	 2.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3261	 1	 21.2	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3262	 1	 66.6	 9.6	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3264	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3265	 1	 4.3	 -11.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3266	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3267	 1	 15.4	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3268	 1	 33.1	 4.9	 0.0	 0.0	 1	    0.99020	    0.00000	 63.0	 1	    1.04762	    0.93277;
	3269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3270	 1	 35.8	 8.2	 0.0	 0.0	 1	    1.00222	    0.00000	 225.0	 1	    1.08889	    0.91556;
	3271	 1	 97.3	 18.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3272	 1	 19.8	 -3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3273	 1	 143.2	 16.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3274	 1	 32.8	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3276	 1	 18.4	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3277	 1	 64.9	 5.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3278	 1	 5.4	 19.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3280	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3281	 2	 -1.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3282	 2	 -1.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3287	 1	 2.4	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3288	 1	 63.6	 9.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3289	 1	 2.0	 -1.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02281	    0.00000	 63.0	 1	    1.09324	    0.95238;
	3291	 1	 49.1	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3292	 1	 28.1	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3293	 1	 11.3	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3294	 1	 -0.1	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3295	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3296	 1	 5.6	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3297	 1	 22.1	 10.4	 0.0	 15.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3300	 1	 1.2	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3301	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01984	    0.00000	 63.0	 1	    1.07143	    0.96825;
	3302	 1	 54.5	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3304	 1	 23.1	 -0.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3305	 1	 -0.2	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3306	 1	 2.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3308	 2	 0.7	 10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3309	 1	 2.5	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3310	 1	 12.9	 1.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3311	 1	 47.8	 17.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3312	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3313	 1	 2.8	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3314	 1	 29.7	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3315	 1	 27.2	 -4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3316	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3317	 1	 -1.0	 101.6	 0.0	 0.0	 1	    1.08041	    0.00000	 380.0	 1	    1.11870	    1.04211;
	3318	 1	 0.0	 5.3	 0.0	 0.0	 1	    1.07925	    0.00000	 380.0	 1	    1.11639	    1.04211;
	3319	 1	 34.1	 4.9	 0.0	 0.0	 1	    1.08215	    0.00000	 380.0	 1	    1.12219	    1.04211;
	3320	 1	 19.0	 23.5	 0.0	 0.0	 1	    1.08041	    0.00000	 380.0	 1	    1.11871	    1.04211;
	3321	 1	 0.2	 0.5	 0.0	 60.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3322	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3324	 1	 -1.9	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3325	 1	 6.0	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3326	 1	 4.5	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3327	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3328	 1	 0.3	 0.5	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3329	 1	 4.3	 1.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3330	 1	 18.0	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3331	 1	 22.9	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3332	 1	 13.0	 4.6	 0.0	 0.0	 1	    1.00126	    0.00000	 63.0	 1	    1.06602	    0.93651;
	3333	 1	 0.0	 0.5	 0.0	 0.0	 1	    1.00142	    0.00000	 63.0	 1	    1.06633	    0.93651;
	3334	 1	 56.5	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3335	 1	 24.0	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3337	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3338	 1	 28.4	 -2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3339	 1	 54.8	 10.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3340	 1	 15.2	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3341	 1	 0.2	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3342	 1	 73.5	 21.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3343	 1	 3.0	 2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3344	 1	 2.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3345	 2	 28.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3347	 1	 9.5	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3348	 1	 37.6	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3349	 1	 0.1	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3351	 1	 82.7	 36.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3352	 1	 3.6	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3353	 1	 35.8	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3354	 1	 24.7	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3355	 1	 32.9	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3356	 1	 59.0	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3357	 1	 2.2	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3358	 1	 20.5	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3359	 1	 50.0	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3360	 1	 32.0	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3361	 1	 27.8	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3362	 1	 6.0	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3363	 1	 45.9	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3365	 1	 72.2	 -5.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04157	    0.00000	 63.0	 1	    1.13076	    0.95238;
	3367	 1	 146.7	 0.0	 0.0	 0.0	 1	    1.03827	    0.00000	 225.0	 1	    1.08988	    0.98667;
	3368	 1	 5.6	 -1.1	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3369	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3370	 1	 34.6	 5.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07669	    0.00000	 380.0	 1	    1.11127	    1.04211;
	3373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07714	    0.00000	 380.0	 1	    1.11217	    1.04211;
	3374	 1	 -8.7	 -1.1	 0.0	 0.0	 1	    1.07716	    0.00000	 380.0	 1	    1.11220	    1.04211;
	3375	 1	 -1.1	 2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3376	 1	 22.3	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3377	 1	 32.8	 2.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3378	 1	 11.5	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3379	 1	 28.1	 6.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	3381	 1	 0.0	 0.0	 0.0	 80.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3382	 1	 37.1	 1.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3383	 1	 8.5	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3384	 1	 13.4	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3385	 1	 4.4	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3386	 1	 0.0	 -0.9	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3387	 1	 38.1	 0.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3388	 1	 8.6	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3389	 1	 46.0	 0.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3391	 1	 0.9	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3393	 1	 45.6	 6.2	 0.0	 0.0	 1	    0.99244	    0.00000	 63.0	 1	    1.04762	    0.93727;
	3394	 1	 20.6	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3395	 1	 39.4	 6.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3396	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	3397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02445	    0.00000	 225.0	 1	    1.08889	    0.96000;
	3398	 1	 39.3	 3.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3399	 1	 13.9	 14.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3400	 1	 19.4	 0.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3401	 1	 35.9	 14.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3402	 1	 10.5	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3403	 1	 33.7	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3404	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3405	 2	 32.0	 11.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3406	 1	 30.3	 6.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3407	 1	 100.7	 5.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3408	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00021	    0.00000	 63.0	 1	    1.06392	    0.93651;
	3409	 1	 33.6	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3410	 1	 173.7	 77.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3411	 1	 15.5	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3412	 1	 15.2	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3413	 1	 6.2	 1.5	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3414	 1	 5.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3415	 1	 23.7	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3416	 1	 -4.8	 0.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3417	 1	 5.2	 -3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3418	 2	 -4.6	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3419	 1	 27.7	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3420	 1	 14.8	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3422	 1	 29.8	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3423	 1	 49.5	 -9.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3424	 2	 43.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3425	 1	 10.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00265	    0.00000	 63.0	 1	    1.05291	    0.95238;
	3427	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3428	 1	 0.8	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3429	 1	 26.0	 -7.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3430	 1	 -2.0	 -12.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3431	 1	 56.3	 4.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3433	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3434	 1	 11.9	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3435	 1	 16.2	 0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3436	 1	 25.9	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3437	 1	 -4.6	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3438	 1	 64.6	 3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3439	 1	 35.2	 0.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3440	 1	 34.4	 -3.8	 0.0	 0.0	 1	    1.00809	    0.00000	 63.0	 1	    1.06379	    0.95238;
	3441	 1	 5.5	 -32.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3442	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.95000	    0.00000	 150.0	 1	    1.10000	    0.80000;
	3443	 1	 9.2	 1.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3445	 1	 15.9	 -3.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3446	 1	 0.6	 0.9	 0.0	 0.0	 1	    0.99209	    0.00000	 63.0	 1	    1.07942	    0.90476;
	3447	 1	 36.3	 0.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3448	 1	 12.1	 -2.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3449	 1	 23.9	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3450	 1	 9.0	 -3.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3451	 1	 8.1	 1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3453	 1	 29.6	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3454	 1	 17.8	 -1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3455	 1	 28.4	 -2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3456	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3457	 1	 78.4	 17.8	 0.0	 30.7	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3458	 1	 31.8	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3459	 1	 32.4	 -5.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3460	 1	 21.6	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3461	 1	 26.1	 3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3462	 1	 -0.1	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3463	 1	 56.2	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3464	 1	 18.8	 12.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3465	 1	 31.5	 12.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3466	 1	 50.4	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3467	 1	 7.7	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3468	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3469	 1	 25.4	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05375	    0.00000	 380.0	 1	    1.10263	    1.00487;
	3472	 1	 0.5	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3473	 1	 1.5	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3474	 1	 0.5	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3475	 1	 6.5	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3484	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3486	 1	 33.9	 3.5	 0.0	 0.0	 1	    1.00358	    0.00000	 63.0	 1	    1.06349	    0.94367;
	3487	 1	 60.9	 6.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3488	 1	 49.6	 2.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3490	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3491	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3492	 1	 11.9	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3494	 1	 11.5	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3495	 1	 12.5	 -2.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3496	 1	 23.0	 -2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3497	 1	 24.3	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3498	 1	 31.4	 5.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3499	 1	 -0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3500	 1	 17.6	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3501	 1	 10.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3502	 1	 -4.0	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3504	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3505	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3506	 1	 -6.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3507	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3508	 1	 8.2	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3510	 1	 10.0	 4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3511	 1	 29.1	 5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3512	 1	 48.1	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3513	 1	 11.9	 -2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3519	 1	 9.2	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3520	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3521	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3524	 1	 12.9	 -3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3526	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3527	 1	 16.5	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3528	 1	 88.4	 16.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3529	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	3530	 1	 40.1	 6.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3532	 1	 13.9	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3535	 1	 -1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3537	 1	 3.9	 1.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3539	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.00889	    0.00000	 225.0	 1	    1.08889	    0.92889;
	3540	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3541	 1	 24.3	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3542	 1	 42.7	 13.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3544	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3545	 1	 54.2	 5.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3546	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3547	 1	 1.8	 1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3548	 1	 7.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3549	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04148	    0.00000	 63.0	 1	    1.13058	    0.95238;
	3550	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3551	 1	 39.6	 1.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3552	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3553	 1	 22.5	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3554	 1	 32.7	 6.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3555	 1	 -1.1	 19.5	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3556	 1	 71.8	 3.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3557	 1	 43.1	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3558	 1	 -7.0	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3559	 1	 17.8	 7.1	 0.0	 15.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3561	 1	 26.8	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3562	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3565	 1	 92.0	 61.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3566	 1	 21.8	 10.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3567	 1	 36.6	 6.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3569	 1	 9.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3570	 1	 0.1	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3571	 1	 31.0	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3572	 1	 53.4	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3573	 1	 -1.8	 0.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3574	 1	 68.6	 25.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3575	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3576	 1	 43.3	 -0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3577	 1	 58.0	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3582	 1	 53.9	 13.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3583	 1	 4.2	 3.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3584	 1	 36.1	 -4.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3586	 2	 -1.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3587	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3590	 1	 21.0	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3591	 1	 23.0	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3592	 1	 7.6	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3593	 1	 0.5	 2.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3594	 1	 -1.7	 17.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3596	 1	 29.7	 -8.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3598	 1	 7.0	 1.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	3599	 1	 27.4	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3600	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3604	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3605	 1	 -22.9	 -2.9	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3606	 1	 20.4	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3608	 1	 34.6	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3610	 1	 26.5	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3611	 1	 16.5	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3613	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3616	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3617	 1	 1.5	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3619	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3621	 1	 28.1	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3622	 1	 7.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3623	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3624	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07033	    0.00000	 380.0	 1	    1.10263	    1.03803;
	3625	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3626	 1	 3.8	 -0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3627	 1	 1.8	 -0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3628	 1	 15.9	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3629	 1	 16.9	 3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3630	 1	 65.5	 28.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3631	 1	 30.0	 5.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3632	 1	 24.6	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3633	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3634	 1	 68.1	 3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3635	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3636	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00157	    0.00000	 63.0	 1	    1.06663	    0.93651;
	3637	 1	 25.1	 3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3638	 1	 60.0	 1.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3639	 1	 18.5	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3640	 1	 12.0	 22.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3641	 1	 29.2	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3642	 1	 6.2	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3643	 1	 17.6	 -1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3644	 1	 17.9	 5.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3645	 1	 27.5	 12.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3646	 1	 31.5	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3647	 1	 43.4	 11.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3648	 1	 -0.4	 -15.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3649	 1	 10.0	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3650	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3651	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3652	 2	 18.2	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3653	 1	 86.9	 47.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3655	 1	 24.6	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3656	 1	 12.0	 -0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3657	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3658	 1	 8.7	 -9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3659	 1	 15.3	 20.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3660	 1	 17.9	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3661	 2	 6.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3662	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3664	 1	 0.0	 0.0	 0.0	 31.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3665	 1	 0.0	 0.0	 0.0	 40.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3667	 2	 1.1	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3668	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3669	 1	 15.8	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	3671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	3672	 1	 16.9	 -3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3673	 1	 28.6	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3674	 1	 60.4	 -2.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3675	 1	 10.3	 7.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3676	 1	 16.5	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3677	 1	 2.5	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3678	 1	 50.1	 -4.3	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3679	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3680	 1	 21.9	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3681	 1	 13.0	 -3.0	 0.0	 0.0	 1	    1.00098	    0.00000	 63.0	 1	    1.06545	    0.93651;
	3682	 1	 11.9	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3683	 1	 33.3	 -4.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3684	 2	 24.0	 2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3685	 1	 41.8	 6.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3686	 2	 -0.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3687	 1	 10.6	 -0.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3688	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3689	 1	 27.5	 -11.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3690	 1	 27.7	 3.2	 0.0	 0.0	 1	    1.00108	    0.00000	 63.0	 1	    1.08152	    0.92063;
	3691	 1	 3.7	 3.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3692	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3693	 1	 57.8	 9.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3694	 1	 29.6	 5.2	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3695	 1	 16.9	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3696	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3697	 1	 16.1	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3698	 1	 17.8	 -0.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3699	 1	 14.3	 -9.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3700	 1	 58.6	 1.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3701	 1	 0.1	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3702	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3703	 1	 -0.7	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3706	 1	 6.0	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3707	 1	 96.0	 13.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3708	 1	 4.6	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3709	 1	 38.1	 8.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3710	 1	 85.9	 1.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3712	 1	 122.5	 2.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3713	 1	 6.0	 -0.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3714	 1	 51.7	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3715	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3716	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3717	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3718	 1	 19.9	 1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3719	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00414	    0.00000	 63.0	 1	    1.05589	    0.95238;
	3720	 1	 50.6	 4.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3722	 1	 1.8	 1.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3723	 1	 1.0	 -0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3727	 1	 -1.0	 -1.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3728	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	3730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3731	 1	 14.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3732	 1	 34.7	 10.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3733	 1	 18.3	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3734	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3735	 1	 87.5	 10.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3736	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3738	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3739	 1	 6.0	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3740	 1	 9.0	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3742	 1	 51.3	 23.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3744	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3745	 1	 77.9	 19.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3747	 1	 0.6	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3748	 2	 6.2	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3749	 1	 12.6	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3750	 1	 0.5	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3752	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	3753	 1	 11.5	 -7.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3756	 1	 34.0	 0.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3757	 1	 28.6	 -3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3758	 1	 41.5	 2.0	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3759	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3760	 1	 7.0	 -0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3761	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3762	 1	 8.7	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3763	 1	 345.7	 128.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3765	 1	 15.4	 4.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3766	 1	 33.8	 4.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3767	 1	 15.4	 -14.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3769	 1	 0.8	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3770	 1	 0.4	 1.8	 0.0	 0.0	 1	    1.03961	    0.00000	 225.0	 1	    1.09256	    0.98667;
	3771	 1	 6.8	 2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3772	 1	 26.9	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3776	 1	 12.1	 2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3777	 1	 62.0	 33.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3778	 1	 35.1	 -9.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3779	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3782	 1	 7.9	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3783	 1	 -2.1	 0.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3784	 1	 0.2	 -3.2	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3785	 1	 30.9	 8.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3788	 1	 23.1	 4.3	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3789	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3790	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3792	 1	 66.2	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3793	 1	 24.4	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3795	 1	 27.5	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3796	 1	 13.6	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3797	 1	 5.8	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3798	 1	 17.7	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3799	 1	 33.6	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3800	 1	 -2.2	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3801	 1	 33.8	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3802	 1	 27.0	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3803	 1	 -0.6	 4.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3804	 1	 47.4	 21.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3806	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3807	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3809	 1	 11.1	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3810	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3812	 1	 14.3	 1.0	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3813	 1	 24.7	 -7.9	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3814	 1	 17.6	 6.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3815	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3816	 2	 -4.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3817	 2	 -0.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3818	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3819	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3822	 1	 21.9	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3823	 1	 1.1	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3824	 1	 19.2	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3825	 1	 2.1	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3826	 1	 16.5	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3827	 1	 42.3	 4.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3828	 1	 30.3	 5.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3829	 1	 49.7	 13.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3832	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3834	 1	 12.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3835	 1	 19.3	 -2.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3836	 1	 44.2	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3837	 1	 11.4	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3838	 1	 35.7	 -8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3839	 1	 46.4	 12.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3840	 1	 50.0	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3842	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3843	 1	 10.9	 -4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3844	 1	 10.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3845	 1	 3.0	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3846	 1	 112.4	 14.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3847	 1	 1.7	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3849	 1	 20.0	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3850	 1	 39.2	 12.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3851	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3852	 1	 1.6	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3853	 2	 0.7	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3854	 1	 2.2	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3855	 1	 11.9	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3856	 1	 52.0	 5.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3857	 1	 4.0	 -4.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3858	 1	 42.2	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3859	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3860	 1	 49.0	 4.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3861	 1	 44.2	 5.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3862	 1	 32.9	 11.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3864	 1	 40.4	 -6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3865	 1	 8.0	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3866	 1	 17.7	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3867	 1	 25.2	 2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3868	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3869	 1	 46.8	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3870	 1	 31.4	 0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3871	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3872	 1	 2.6	 5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3873	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3874	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3876	 1	 26.9	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3877	 1	 15.5	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3878	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3879	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3880	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3881	 1	 91.5	 8.4	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3882	 1	 44.3	 8.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3883	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3884	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3885	 1	 0.1	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3886	 1	 41.1	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3887	 1	 21.7	 3.7	 0.0	 0.0	 1	    1.01274	    0.00000	 63.0	 1	    1.07937	    0.94610;
	3888	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3889	 1	 19.2	 -1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	3890	 1	 32.1	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3891	 1	 13.6	 -5.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3892	 1	 0.6	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3893	 2	 23.3	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3894	 1	 0.2	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3895	 1	 36.0	 8.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3896	 1	 42.4	 4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3899	 1	 1.0	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3900	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3902	 1	 34.0	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3903	 1	 2.2	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3904	 1	 11.3	 -1.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3905	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3907	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3908	 1	 19.9	 19.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3909	 1	 7.6	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3910	 1	 2.7	 16.7	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	3911	 1	 12.1	 -0.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3912	 1	 6.0	 -1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3913	 1	 52.4	 4.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3914	 1	 7.8	 -6.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3915	 1	 13.6	 2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3916	 1	 29.5	 4.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3918	 1	 9.4	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3919	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3920	 1	 45.0	 6.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3921	 1	 37.0	 8.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3922	 1	 43.1	 5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3923	 1	 11.2	 1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	3924	 1	 6.9	 -1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	3925	 1	 7.2	 -1.1	 0.0	 0.0	 1	    1.02667	    0.00000	 225.0	 1	    1.08889	    0.96444;
	3926	 1	 25.5	 12.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3927	 2	 -0.6	 -3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	3929	 1	 11.2	 -9.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3930	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3931	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3932	 1	 11.4	 -4.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3933	 1	 3.1	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3934	 1	 66.5	 0.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3935	 1	 68.5	 12.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3936	 1	 13.9	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04534	    0.00000	 225.0	 1	    1.09067	    1.00000;
	3938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3939	 1	 25.0	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3940	 1	 -7.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3941	 1	 0.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3942	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3944	 1	 25.2	 2.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3945	 1	 1.1	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3946	 1	 12.3	 2.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3947	 1	 99.6	 36.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3948	 1	 35.4	 8.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3949	 1	 27.1	 6.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3950	 1	 10.6	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3951	 1	 4.9	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3952	 1	 30.5	 12.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3953	 1	 16.2	 3.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3954	 1	 12.6	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3955	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3956	 1	 16.8	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3957	 1	 17.7	 1.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3958	 1	 44.4	 9.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3960	 1	 -0.1	 -0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3961	 1	 0.3	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3963	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3964	 1	 46.8	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3966	 1	 96.3	 30.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3967	 1	 29.1	 4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3968	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3969	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3972	 1	 19.4	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3973	 1	 24.4	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3974	 1	 14.2	 7.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3975	 1	 9.1	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3976	 1	 71.1	 41.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3977	 2	 15.2	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3978	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3981	 1	 31.6	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3982	 1	 17.2	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3983	 1	 4.4	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3984	 1	 58.6	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3985	 1	 27.9	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3986	 1	 0.7	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3987	 2	 12.3	 -1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3988	 1	 26.8	 1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3989	 1	 7.9	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3990	 1	 13.1	 -1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3991	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3992	 1	 1.7	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3993	 1	 -1.2	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3994	 1	 25.9	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3995	 1	 4.0	 -2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3997	 1	 -1.8	 -4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3998	 1	 8.0	 -4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3999	 1	 5.0	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4000	 1	 34.7	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4001	 1	 55.6	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4002	 1	 1.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4003	 1	 24.6	 -1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4004	 1	 34.7	 -5.7	 0.0	 34.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4006	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4007	 1	 18.2	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4008	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4009	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4012	 1	 15.8	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4013	 1	 0.6	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4014	 1	 33.5	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4015	 1	 32.0	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4016	 1	 57.9	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4017	 1	 30.4	 10.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4018	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4019	 1	 15.5	 6.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4020	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04520	    0.00000	 225.0	 1	    1.09040	    1.00000;
	4021	 1	 36.4	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4022	 1	 43.7	 1.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4023	 1	 34.8	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4024	 1	 23.0	 3.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4025	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4026	 1	 51.5	 -13.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4027	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4028	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	4029	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4030	 1	 84.7	 19.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4031	 1	 28.7	 2.4	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4032	 1	 7.1	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4033	 1	 23.2	 6.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4034	 1	 20.3	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4035	 1	 24.3	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4036	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4037	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4038	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4039	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4040	 1	 136.0	 41.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4041	 1	 16.6	 -3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4042	 1	 50.0	 7.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4043	 1	 101.2	 22.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4044	 1	 55.5	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4045	 1	 10.5	 -2.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4047	 1	 46.5	 12.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4048	 1	 19.3	 5.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4050	 1	 8.5	 5.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4051	 1	 9.9	 -0.9	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	4052	 1	 0.9	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4053	 1	 23.9	 2.3	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	4054	 1	 7.0	 -2.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4055	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4056	 1	 11.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4059	 1	 25.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4060	 1	 20.7	 0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4061	 1	 57.1	 49.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4062	 1	 7.3	 0.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00560	    0.00000	 63.0	 1	    1.07469	    0.93651;
	4064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4065	 1	 14.8	 3.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	4067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4070	 1	 34.7	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4071	 1	 15.4	 -1.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4072	 1	 33.5	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4073	 1	 12.8	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4074	 1	 0.1	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4075	 1	 18.8	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4080	 1	 66.7	 11.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4081	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4087	 1	 18.8	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4089	 1	 70.1	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4090	 1	 12.6	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4091	 1	 5.3	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4092	 1	 30.5	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4095	 1	 36.2	 2.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4096	 1	 37.0	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4097	 1	 0.1	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4098	 1	 11.0	 -2.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4099	 1	 1.5	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4100	 1	 43.0	 -2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4101	 1	 22.3	 9.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4103	 1	 92.4	 24.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4104	 1	 30.4	 0.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4107	 1	 0.4	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4108	 1	 11.3	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4109	 1	 28.8	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4112	 1	 0.6	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4113	 1	 39.6	 8.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4114	 1	 14.5	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4115	 1	 8.3	 2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4116	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4117	 1	 44.9	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4118	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	4122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	4123	 1	 13.7	 3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4124	 1	 11.4	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4125	 1	 14.7	 -3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4126	 1	 109.8	 32.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4127	 1	 41.5	 8.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4128	 1	 29.6	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4129	 2	 16.0	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4130	 1	 25.4	 -0.6	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4131	 2	 27.3	 -6.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4132	 1	 -0.2	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4136	 1	 15.6	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4137	 1	 10.8	 22.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4138	 1	 40.6	 8.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	4139	 1	 14.4	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4141	 1	 43.1	 10.7	 0.0	 48.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4142	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4143	 1	 16.7	 12.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4144	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4145	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4146	 1	 49.3	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4147	 1	 14.9	 0.0	 0.0	 0.0	 1	    1.00320	    0.00000	 63.0	 1	    1.06989	    0.93651;
	4148	 1	 13.7	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4149	 1	 36.5	 1.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4150	 1	 3.3	 -2.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4151	 1	 0.3	 -3.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4152	 1	 19.2	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	4153	 1	 35.0	 -13.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4155	 1	 12.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4156	 1	 29.8	 5.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4157	 1	 103.0	 12.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4158	 1	 0.0	 -0.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4159	 1	 7.1	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4160	 1	 52.2	 5.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4161	 1	 36.4	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4162	 1	 30.7	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4163	 1	 12.9	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4164	 1	 28.8	 -5.1	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	4166	 1	 8.1	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4168	 1	 6.3	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4169	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4172	 1	 -23.1	 11.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4174	 1	 52.6	 5.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4175	 1	 17.6	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4176	 1	 25.7	 -7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4177	 1	 27.6	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4178	 1	 36.7	 6.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4179	 1	 10.0	 4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4180	 1	 3.6	 1.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4181	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4182	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4183	 1	 23.5	 3.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4184	 1	 24.7	 -60.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.04762	    0.98413;
	4185	 1	 19.9	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4186	 1	 0.0	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4187	 1	 -7.7	 -2.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4188	 1	 -7.7	 -2.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4189	 1	 6.1	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4190	 1	 73.1	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4191	 1	 49.7	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4192	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4193	 1	 0.0	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4194	 1	 37.5	 -4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4195	 1	 101.4	 21.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4196	 1	 65.7	 -2.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4197	 1	 11.9	 -6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4198	 1	 24.2	 -3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4199	 1	 27.9	 2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4201	 1	 5.0	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4202	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4203	 1	 17.1	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4204	 1	 6.1	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4205	 1	 43.9	 4.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4206	 1	 61.3	 11.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4207	 1	 8.1	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4208	 1	 14.0	 3.3	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4209	 1	 111.6	 2.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4210	 1	 32.2	 -6.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4211	 1	 12.9	 2.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4212	 1	 6.8	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4213	 1	 35.6	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4214	 1	 16.6	 4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4215	 1	 0.1	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4216	 1	 37.1	 20.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4217	 1	 42.8	 16.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03995	    0.00000	 225.0	 1	    1.09323	    0.98667;
	4219	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07619	    0.00000	 380.0	 1	    1.11291	    1.03947;
	4220	 1	 16.0	 4.8	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4221	 1	 32.8	 6.1	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4222	 1	 9.1	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4223	 1	 0.1	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4225	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4229	 1	 0.9	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4230	 1	 19.1	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4231	 2	 -8.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4232	 1	 11.8	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4233	 1	 19.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4234	 1	 12.8	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4235	 1	 26.2	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4236	 1	 36.6	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4237	 1	 28.0	 5.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4238	 1	 44.0	 4.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4239	 1	 7.2	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4240	 1	 14.7	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4241	 1	 42.4	 6.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4242	 1	 17.7	 8.6	 0.0	 34.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4243	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4244	 2	 -29.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4245	 2	 18.4	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4246	 1	 1.9	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4248	 1	 23.4	 -2.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4249	 1	 14.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4250	 1	 36.2	 -3.6	 0.0	 20.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4251	 1	 45.3	 17.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4252	 1	 57.6	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4255	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4257	 1	 27.7	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4258	 1	 39.4	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4259	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4260	 1	 22.2	 -3.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4261	 1	 0.2	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4265	 1	 62.6	 4.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4266	 1	 20.0	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4267	 1	 4.5	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4268	 1	 1.2	 -1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4271	 1	 29.6	 8.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4272	 1	 34.9	 3.7	 0.0	 0.0	 1	    0.99687	    0.00000	 63.0	 1	    1.07937	    0.91438;
	4273	 1	 21.2	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4274	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4275	 2	 6.2	 -3.6	 0.0	 0.0	 1	    1.01911	    0.00000	 63.0	 1	    1.06996	    0.96825;
	4276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4277	 1	 0.5	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4279	 1	 41.0	 3.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4280	 1	 13.8	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4281	 1	 33.6	 4.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4282	 1	 45.5	 10.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4283	 1	 42.6	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4284	 1	 1.0	 -3.5	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4287	 1	 45.3	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4288	 1	 9.0	 8.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03574	    0.00000	 63.0	 1	    1.11910	    0.95238;
	4291	 1	 5.4	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4293	 2	 1.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4295	 1	 32.1	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4296	 1	 19.4	 -0.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4298	 1	 1.9	 2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4299	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4300	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4301	 1	 4.8	 -4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4302	 1	 62.0	 13.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4304	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4305	 1	 17.5	 -1.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4306	 1	 -0.4	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4308	 1	 -0.0	 0.5	 0.0	 0.0	 1	    1.00109	    0.00000	 63.0	 1	    1.06568	    0.93651;
	4309	 1	 19.0	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4310	 1	 38.2	 7.7	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4311	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4312	 1	 20.8	 4.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4314	 1	 30.0	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4315	 2	 -3.0	 0.0	 0.0	 0.0	 1	    1.00012	    0.00000	 63.0	 1	    1.06373	    0.93651;
	4316	 1	 -0.6	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4317	 1	 46.0	 6.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4318	 1	 41.9	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4319	 2	 -11.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4320	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4321	 1	 55.5	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4322	 1	 19.4	 -5.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4323	 1	 23.6	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4324	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4325	 1	 17.3	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4326	 2	 3.3	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4327	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4328	 1	 10.1	 -1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4329	 1	 36.3	 16.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4332	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4333	 1	 20.7	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4334	 1	 16.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4335	 1	 18.8	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4336	 1	 25.7	 4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4337	 1	 31.1	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4338	 1	 0.7	 -0.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4339	 1	 25.4	 3.1	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4340	 1	 24.4	 3.1	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4341	 1	 31.4	 0.1	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4344	 1	 13.0	 -2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4345	 2	 0.7	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4346	 1	 169.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03878	    0.00000	 225.0	 1	    1.09090	    0.98667;
	4348	 1	 33.4	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4349	 1	 46.1	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4350	 1	 20.9	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4351	 1	 19.9	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4352	 2	 1.7	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4353	 1	 62.9	 9.1	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4354	 1	 9.3	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4355	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4356	 1	 26.8	 -1.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4357	 1	 22.2	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4358	 1	 16.0	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4359	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4360	 1	 34.7	 -2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4361	 1	 53.9	 9.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4362	 1	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4363	 1	 27.5	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4364	 1	 62.4	 -2.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4365	 1	 -11.2	 -6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4367	 1	 11.5	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4368	 1	 4.3	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4369	 1	 33.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4370	 1	 25.4	 -3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4371	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4372	 1	 3.0	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4373	 1	 19.6	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4374	 1	 13.0	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4375	 1	 13.0	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4376	 1	 17.7	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4377	 1	 13.1	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4378	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4379	 1	 34.4	 5.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4381	 1	 29.3	 -5.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4382	 1	 18.0	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4383	 1	 4.2	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4384	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4385	 1	 44.2	 5.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4386	 1	 114.7	 17.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4388	 1	 11.3	 3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4389	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4390	 1	 61.8	 6.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4391	 1	 6.5	 1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4393	 1	 10.0	 -5.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4394	 1	 11.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4395	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4396	 1	 55.2	 17.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4397	 1	 37.9	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4398	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4399	 1	 107.9	 24.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4400	 1	 3.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4401	 1	 30.5	 4.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4402	 1	 35.4	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4403	 1	 42.7	 -1.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4404	 1	 2.7	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4405	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04529	    0.00000	 225.0	 1	    1.09058	    1.00000;
	4406	 1	 22.6	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4407	 1	 49.0	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4408	 1	 14.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4409	 1	 23.9	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4410	 1	 27.0	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4411	 1	 42.1	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4412	 1	 55.1	 13.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4413	 1	 22.2	 -5.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4414	 1	 48.2	 6.0	 0.0	 0.0	 1	    1.00608	    0.00000	 63.0	 1	    1.06349	    0.94867;
	4415	 2	 -1.5	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4416	 1	 0.0	 0.0	 0.0	 -15.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4417	 1	 7.1	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4418	 1	 34.0	 9.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4419	 1	 29.0	 0.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4420	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4423	 1	 11.0	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4424	 1	 13.1	 7.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4425	 1	 -0.2	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4426	 1	 15.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4427	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4428	 1	 31.3	 1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4429	 1	 17.5	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4430	 1	 14.3	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4431	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4433	 1	 7.5	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4434	 1	 42.1	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4435	 1	 23.7	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4436	 1	 7.4	 -0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4437	 1	 22.7	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4438	 1	 0.9	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4441	 1	 74.3	 11.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4442	 1	 27.2	 7.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4443	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02790	    0.00000	 150.0	 1	    1.08913	    0.96667;
	4444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4446	 1	 2.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4447	 1	 24.9	 9.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4448	 1	 1.3	 9.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4449	 1	 40.7	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4450	 1	 41.7	 8.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4451	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4453	 1	 14.8	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4454	 1	 0.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4455	 1	 3.4	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4456	 1	 7.7	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4458	 1	 39.8	 4.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4459	 1	 8.7	 0.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4460	 1	 47.7	 12.9	 0.0	 20.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4462	 1	 39.2	 8.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4463	 1	 15.4	 -3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4464	 1	 5.3	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4465	 1	 0.3	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4466	 1	 0.9	 0.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4469	 1	 17.9	 12.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4470	 1	 30.1	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4472	 1	 13.8	 2.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4474	 1	 9.0	 -4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4475	 1	 13.8	 2.9	 0.0	 15.4	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	4477	 2	 -3.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4478	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4479	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4480	 2	 -0.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4481	 2	 -1.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4482	 2	 -0.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4487	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4488	 1	 -1.9	 3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4491	 1	 15.0	 -1.5	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	4492	 1	 3.8	 0.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4493	 1	 12.0	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4494	 1	 2.0	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4495	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4496	 1	 25.1	 2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4497	 1	 37.7	 4.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4498	 1	 46.7	 -0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4499	 1	 6.0	 3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4500	 1	 5.3	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 63.0	 1	    1.10730	    0.96825;
	4502	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 63.0	 1	    1.10730	    0.96825;
	4503	 1	 16.2	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4504	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4506	 1	 0.0	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4507	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4508	 2	 66.6	 10.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4510	 1	 1.0	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4511	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4513	 1	 25.1	 -3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4514	 1	 14.5	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4515	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4516	 1	 21.9	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.08889	    0.93778;
	4518	 1	 78.5	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4519	 1	 55.0	 11.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4520	 1	 5.4	 -11.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4521	 1	 19.1	 -3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4522	 1	 32.5	 -5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4523	 1	 13.2	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4524	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00627	    0.00000	 63.0	 1	    1.07604	    0.93651;
	4525	 1	 2.1	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4526	 1	 14.6	 13.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02368	    0.00000	 150.0	 1	    1.08069	    0.96667;
	4528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4529	 1	 12.9	 0.9	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	4530	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4531	 1	 19.8	 -4.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4533	 1	 12.3	 4.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4534	 1	 1.0	 -3.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4537	 1	 29.1	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4538	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	4539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4540	 1	 13.4	 -4.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4541	 1	 30.2	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4542	 1	 45.8	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4546	 1	 45.5	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4547	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.00558	    0.00000	 63.0	 1	    1.07466	    0.93651;
	4548	 1	 28.3	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4549	 1	 -0.5	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4550	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4551	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07634	    0.00000	 380.0	 1	    1.10526	    1.04743;
	4552	 1	 26.8	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4553	 1	 23.6	 8.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4554	 1	 33.3	 0.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4555	 1	 9.8	 -5.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4557	 1	 32.6	 -5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4558	 1	 6.6	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4559	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4561	 1	 -0.1	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4562	 1	 1.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4563	 1	 106.8	 19.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4565	 1	 3.0	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4566	 1	 0.7	 -37.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4567	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4568	 1	 2.0	 0.2	 0.0	 0.0	 1	    1.00014	    0.00000	 63.0	 1	    1.06378	    0.93651;
	4569	 1	 23.8	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4570	 1	 21.2	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4571	 1	 11.4	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4574	 2	 128.0	 67.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07854	    0.00000	 380.0	 1	    1.10263	    1.05445;
	4578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04164	    0.00000	 63.0	 1	    1.13089	    0.95238;
	4582	 2	 3.8	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4583	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4585	 1	 47.5	 9.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4586	 1	 184.5	 64.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4587	 1	 3.0	 1.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4588	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4589	 1	 10.0	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4590	 1	 18.3	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4591	 1	 3.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4592	 1	 103.5	 28.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4593	 1	 6.0	 2.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4594	 1	 8.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4598	 1	 45.6	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4600	 1	 1.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4604	 1	 11.3	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4605	 1	 0.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4606	 1	 6.3	 -2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4607	 1	 33.6	 2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4608	 1	 15.8	 1.5	 0.0	 0.0	 1	    1.01565	    0.00000	 90.0	 1	    1.06667	    0.96464;
	4609	 1	 1.7	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4610	 1	 60.8	 -12.3	 0.0	 90.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4612	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4613	 1	 54.5	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4614	 1	 0.0	 1.4	 0.0	 0.0	 1	    1.02267	    0.00000	 90.0	 1	    1.06757	    0.97778;
	4615	 1	 29.5	 5.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4616	 1	 2.0	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4617	 1	 36.9	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4619	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4620	 1	 24.7	 8.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4621	 1	 15.7	 -0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4622	 1	 0.9	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4623	 1	 21.5	 2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4624	 1	 21.9	 9.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4625	 1	 19.0	 -0.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4626	 1	 4.0	 2.2	 0.0	 0.0	 1	    1.00010	    0.00000	 63.0	 1	    1.06370	    0.93651;
	4627	 1	 17.6	 -7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4628	 1	 17.2	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4629	 1	 52.6	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4630	 1	 24.3	 3.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4631	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4632	 1	 41.3	 6.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4633	 1	 9.2	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4634	 1	 16.7	 -4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4635	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4636	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4637	 1	 26.2	 7.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4638	 1	 56.4	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4639	 1	 20.5	 2.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4640	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4643	 1	 89.7	 25.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4644	 1	 22.0	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4645	 1	 4.6	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4646	 1	 8.4	 -3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4647	 1	 1.0	 -1.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4648	 1	 99.3	 24.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4649	 1	 0.0	 0.0	 0.0	 60.8	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4650	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4651	 1	 56.1	 8.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4652	 1	 22.5	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4656	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4657	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4658	 1	 48.0	 5.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4659	 1	 46.6	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4661	 1	 8.9	 3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4662	 1	 -2.5	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4665	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4666	 1	 25.0	 6.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4667	 1	 -0.6	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4668	 1	 58.4	 -4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4669	 1	 14.8	 -2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4670	 1	 28.0	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4671	 1	 18.1	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4672	 1	 84.8	 -6.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4673	 1	 38.9	 9.4	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4674	 2	 -3.3	 1.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4675	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4676	 1	 72.0	 24.3	 0.0	 61.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06479	    0.00000	 380.0	 1	    1.10263	    1.02694;
	4679	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4680	 1	 28.6	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4681	 1	 18.5	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4682	 1	 40.0	 -1.2	 0.0	 61.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4684	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4685	 1	 22.6	 3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4686	 1	 33.8	 -5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4687	 1	 15.9	 0.3	 0.0	 0.0	 1	    1.01981	    0.00000	 90.0	 1	    1.06667	    0.97296;
	4688	 1	 11.7	 -1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00162	    0.00000	 63.0	 1	    1.06674	    0.93651;
	4690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4691	 1	 33.0	 5.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4694	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4698	 1	 13.1	 -2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4699	 1	 1.8	 1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4700	 1	 35.8	 6.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4701	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4702	 1	 16.1	 -0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4703	 1	 28.0	 9.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4704	 1	 0.8	 3.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4714	 3	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10263	    1.05526;
	4715	 1	 31.0	 -10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4716	 1	 46.5	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4718	 2	 -6.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4719	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4720	 1	 15.3	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4721	 2	 13.7	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4723	 1	 19.9	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4724	 1	 10.3	 -1.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4725	 1	 2.3	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4726	 1	 48.3	 12.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4727	 1	 11.9	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4728	 1	 68.6	 16.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4729	 1	 4.1	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4730	 1	 50.3	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4731	 1	 44.3	 -6.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4732	 1	 21.2	 -3.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4733	 1	 0.1	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4734	 1	 0.0	 -9.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4735	 1	 28.5	 10.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4736	 1	 55.5	 5.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4737	 1	 56.7	 20.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4738	 1	 2.0	 0.3	 0.0	 0.0	 1	    1.04470	    0.00000	 225.0	 1	    1.08497	    1.00444;
	4739	 1	 5.6	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	4740	 1	 45.0	 12.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4742	 1	 58.9	 10.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4743	 1	 9.6	 -4.3	 0.0	 50.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4745	 1	 45.6	 15.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4747	 1	 21.4	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4749	 1	 66.4	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4751	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4752	 1	 2.0	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4753	 1	 25.4	 21.4	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	4754	 1	 13.0	 -1.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4755	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4756	 1	 32.0	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4757	 2	 -1.9	 -4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4758	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4759	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4760	 1	 7.0	 -0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4761	 1	 43.5	 9.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4762	 1	 15.5	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4765	 1	 131.1	 25.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4766	 1	 30.3	 -1.5	 0.0	 0.0	 1	    1.01246	    0.00000	 63.0	 1	    1.06349	    0.96142;
	4767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4768	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4770	 1	 44.5	 3.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4771	 1	 13.5	 2.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4772	 1	 17.2	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4775	 1	 -15.6	 -0.6	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4777	 1	 23.0	 6.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4778	 2	 29.2	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4779	 1	 47.0	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4781	 1	 15.9	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4782	 1	 71.8	 7.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4783	 1	 22.8	 -3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4785	 1	 32.2	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4786	 1	 3.4	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4787	 1	 29.7	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4788	 1	 -0.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4789	 1	 21.9	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4793	 1	 21.8	 1.1	 0.0	 27.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4794	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4795	 1	 -14.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4797	 1	 9.0	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4798	 1	 17.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4799	 1	 11.7	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4800	 1	 25.9	 4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4801	 1	 14.9	 4.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4802	 1	 47.4	 -1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4803	 1	 27.5	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03963	    0.00000	 225.0	 1	    1.09259	    0.98667;
	4805	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4806	 1	 59.9	 1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4807	 1	 41.7	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4808	 1	 17.7	 7.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4810	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4812	 1	 3.5	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4813	 1	 26.9	 0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4814	 1	 7.8	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4815	 1	 22.1	 3.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4816	 1	 50.1	 23.8	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4817	 1	 69.4	 14.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4818	 2	 -2.2	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4819	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4820	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4823	 1	 -3.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4824	 1	 0.8	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4825	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4826	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4827	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4828	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4829	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4830	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4832	 1	 0.0	 0.0	 0.0	 29.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4834	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4836	 1	 33.1	 2.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4837	 1	 32.7	 -1.3	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	4838	 1	 21.0	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4840	 1	 63.5	 15.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4841	 1	 14.9	 4.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4842	 1	 27.9	 3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4843	 1	 0.8	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4844	 1	 19.3	 -2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4845	 1	 30.8	 4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4846	 1	 24.5	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4847	 1	 30.2	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4848	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00157	    0.00000	 63.0	 1	    1.06664	    0.93651;
	4849	 1	 67.0	 6.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4850	 1	 48.3	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4851	 1	 18.1	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4852	 1	 3.3	 6.1	 0.0	 0.0	 1	    1.00142	    0.00000	 63.0	 1	    1.06634	    0.93651;
	4853	 1	 85.9	 8.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4854	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4855	 1	 5.9	 -4.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4856	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4857	 1	 0.3	 1.7	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4858	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4859	 1	 3.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4860	 1	 7.1	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4861	 1	 26.1	 7.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4862	 1	 19.2	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4864	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	4865	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4866	 1	 55.8	 4.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4867	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4868	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4869	 2	 6.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4870	 1	 23.4	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4871	 1	 24.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4872	 1	 2.3	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4873	 1	 29.6	 3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4874	 1	 47.7	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4875	 1	 8.0	 2.1	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	4876	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4877	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4878	 1	 2.9	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4879	 1	 28.9	 9.7	 0.0	 0.0	 1	    1.00299	    0.00000	 63.0	 1	    1.05360	    0.95238;
	4880	 1	 9.0	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4881	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4882	 1	 136.3	 33.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4883	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4884	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4885	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4886	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4887	 1	 18.1	 -0.4	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4888	 1	 10.8	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4889	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4890	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03947	    0.00000	 380.0	 1	    1.10526	    0.97368;
	4891	 1	 30.9	 1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4892	 1	 52.6	 7.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4893	 1	 31.6	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4894	 1	 9.9	 -2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4895	 1	 10.3	 13.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4896	 1	 11.1	 -0.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4897	 1	 -13.3	 1.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4898	 1	 32.9	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4899	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4900	 1	 13.6	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4901	 1	 63.9	 10.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4902	 1	 13.0	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4903	 2	 0.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4904	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4905	 1	 4.7	 -2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4907	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4908	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4909	 1	 30.9	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4910	 1	 10.8	 0.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4911	 1	 37.5	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4912	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03883	    0.00000	 225.0	 1	    1.09100	    0.98667;
	4913	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4914	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07287	    0.00000	 380.0	 1	    1.10627	    1.03947;
	4915	 1	 6.2	 -0.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4916	 1	 13.5	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4917	 1	 39.6	 4.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4918	 1	 76.5	 21.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4919	 1	 8.7	 6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4920	 1	 4.9	 6.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4921	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4922	 1	 -21.3	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4923	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4924	 1	 32.0	 5.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4925	 2	 26.0	 6.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4926	 1	 0.0	 0.0	 0.0	 50.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4927	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4928	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4930	 1	 40.7	 8.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4931	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4933	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4934	 1	 4.9	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4935	 1	 52.2	 6.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4936	 1	 43.0	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4937	 1	 0.7	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4938	 1	 57.9	 10.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4939	 1	 39.0	 0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4940	 1	 0.7	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4941	 1	 0.7	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4942	 1	 1.7	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4945	 1	 48.3	 7.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4946	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4947	 1	 150.4	 45.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4948	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4949	 1	 35.9	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4950	 1	 7.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4951	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4952	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4953	 1	 1.3	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4954	 1	 32.7	 -2.3	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4955	 1	 38.7	 9.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4956	 1	 12.8	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4957	 1	 0.9	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4958	 1	 6.8	 -2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4961	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4963	 1	 30.5	 5.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4964	 1	 23.7	 4.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4966	 1	 21.3	 -13.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4967	 1	 33.3	 -8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4968	 1	 4.7	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4969	 1	 1.9	 -6.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4973	 2	 -0.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4974	 1	 0.1	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4976	 1	 13.1	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4977	 1	 20.7	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4978	 1	 34.8	 5.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4981	 1	 56.3	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4982	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4984	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4985	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4986	 2	 16.5	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4987	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4988	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4989	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4990	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4991	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4993	 1	 14.7	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4994	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4995	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4996	 1	 9.0	 -2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4997	 1	 15.9	 4.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4999	 1	 5.0	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5000	 1	 33.9	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5001	 1	 30.3	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5004	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5005	 1	 0.3	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5006	 1	 37.0	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5007	 1	 0.1	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5008	 1	 -11.3	 -1.8	 0.0	 0.0	 1	    1.00461	    0.00000	 63.0	 1	    1.07271	    0.93651;
	5009	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5010	 1	 39.4	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5011	 1	 20.0	 3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5012	 1	 14.3	 -1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5013	 1	 45.8	 22.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5014	 1	 -2.1	 3.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5015	 1	 18.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5016	 1	 0.5	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5017	 1	 11.2	 -3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5018	 1	 10.0	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5019	 1	 26.7	 -6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5020	 1	 8.8	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5021	 1	 -20.9	 -4.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	5022	 1	 34.6	 -3.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5023	 1	 9.2	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5024	 1	 4.1	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5025	 1	 90.7	 17.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5026	 1	 65.0	 10.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5027	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5028	 1	 26.9	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5029	 1	 4.8	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5030	 1	 -0.2	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5031	 1	 19.1	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5032	 1	 26.9	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5033	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5034	 1	 16.7	 -3.6	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	5035	 1	 16.0	 7.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5036	 1	 16.7	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5037	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5038	 1	 159.5	 34.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5040	 1	 12.7	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5041	 2	 22.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5042	 1	 16.8	 3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5043	 1	 21.2	 -6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5044	 2	 30.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5045	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5046	 1	 24.9	 5.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	5047	 1	 4.2	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5048	 1	 2.0	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5049	 1	 171.6	 61.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5050	 1	 -15.0	 -2.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	5051	 1	 4.5	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5052	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5053	 1	 14.7	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5054	 1	 29.3	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5055	 1	 0.0	 0.0	 0.0	 34.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5057	 1	 11.9	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5058	 1	 42.2	 15.2	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	5059	 1	 2.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5060	 1	 6.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5061	 1	 7.3	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5062	 1	 29.0	 6.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5064	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5065	 1	 -1.3	 -9.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5068	 1	 47.6	 5.4	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	5069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5070	 1	 44.6	 9.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	5071	 1	 23.2	 4.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5072	 1	 31.2	 7.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5073	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5075	 1	 13.5	 8.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5076	 1	 23.5	 8.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5077	 1	 3.4	 1.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5079	 1	 10.8	 5.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5080	 1	 4.1	 1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5081	 1	 12.3	 1.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5083	 1	 4.9	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5084	 1	 12.2	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5085	 1	 59.0	 4.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5086	 1	 23.2	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5087	 1	 38.8	 4.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5089	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	5090	 1	 33.8	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5091	 1	 0.5	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5092	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5093	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5094	 1	 29.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5095	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5096	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5099	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5101	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5104	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5105	 1	 2.7	 2.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5107	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5108	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5117	 1	 7.7	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5118	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 150.0	 1	    1.10000	    0.96667;
	5123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5128	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5129	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00074	    0.00000	 63.0	 1	    1.06497	    0.93651;
	5131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5134	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5144	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5145	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5146	 1	 12.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5151	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5152	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5153	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5155	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5160	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5161	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5168	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5174	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5181	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5182	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	5186	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5187	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5189	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5190	 1	 33.6	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5191	 1	 14.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5192	 1	 43.7	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5193	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5194	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5199	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5201	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5202	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5203	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5204	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5207	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5208	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5215	 1	 -13.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5216	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5219	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5223	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5225	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5226	 1	 -20.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5231	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5233	 1	 6.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5234	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5235	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5238	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00085	    0.00000	 63.0	 1	    1.06519	    0.93651;
	5240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5241	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5243	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5244	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	5246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5251	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5252	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00327	    0.00000	 63.0	 1	    1.05416	    0.95238;
	5255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	5258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5259	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5261	 1	 24.8	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5274	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5292	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5293	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5300	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5301	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5302	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5304	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5309	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5310	 1	 18.1	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5311	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5312	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5315	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5317	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5318	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5320	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5322	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5324	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5325	 1	 11.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5326	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5328	 1	 5.8	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5332	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5334	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5335	 1	 -8.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5337	 1	 -19.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5340	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5341	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5344	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5348	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5351	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5355	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5358	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00080	    0.00000	 63.0	 1	    1.06510	    0.93651;
	5359	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5360	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5370	 1	 3.3	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5374	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5375	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5377	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5384	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5388	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5389	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5391	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5393	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5394	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5395	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5396	 1	 22.2	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5398	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5399	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00062	    0.00000	 63.0	 1	    1.06474	    0.93651;
	5401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5402	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5403	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5404	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5405	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5406	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5407	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5409	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5410	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5411	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5412	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5413	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5415	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5416	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5417	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5418	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5419	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5420	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5427	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5428	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5429	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5430	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5432	 1	 -32.8	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5433	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5434	 1	 8.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5442	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5443	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5456	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5465	 1	 -5.2	 1.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5466	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5467	 1	 -53.4	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5487	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5488	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5491	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5492	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5494	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5495	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5496	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5497	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5502	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5506	 1	 57.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5507	 1	 35.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00407	    0.00000	 63.0	 1	    1.05575	    0.95238;
	5511	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5512	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5513	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5526	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5529	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5530	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5540	 1	 -1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5546	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 150.0	 1	    1.10000	    0.96667;
	5547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5549	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5550	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5551	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5552	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00129	    0.00000	 63.0	 1	    1.06608	    0.93651;
	5554	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5557	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5558	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5559	 1	 -17.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5562	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5565	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5566	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5568	 1	 10.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5570	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5571	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5574	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5576	 1	 18.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5584	 1	 -60.3	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 150.0	 1	    1.10000	    0.96667;
	5585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5592	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5596	 1	 19.3	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5605	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99080	    0.00000	 225.0	 1	    1.09271	    0.88889;
	5606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5610	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5613	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5616	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00022	    0.00000	 63.0	 1	    1.06394	    0.93651;
	5618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5619	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5622	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5624	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5625	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5627	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5628	 1	 -2.1	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5629	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5630	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5631	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5632	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5633	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5634	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5635	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5636	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5637	 1	 -15.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5639	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5640	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5643	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5644	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5645	 1	 10.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5646	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	5647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5648	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02000	    0.00000	 150.0	 1	    1.05333	    0.98667;
	5649	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5650	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5651	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5652	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5655	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5657	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5658	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5659	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5660	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5661	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5662	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5664	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5667	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5669	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00414	    0.00000	 63.0	 1	    1.05589	    0.95238;
	5670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5673	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5675	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5679	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5683	 1	 49.2	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5684	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5685	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5688	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5689	 1	 1.9	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5691	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5694	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	5696	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5697	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5701	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5702	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5708	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04538	    0.00000	 225.0	 1	    1.09076	    1.00000;
	5710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5712	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5719	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5723	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5727	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5728	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5731	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5732	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5733	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5734	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5735	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5738	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5744	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5745	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5752	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5753	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5754	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5757	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5758	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5759	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5760	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5761	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5765	 1	 36.1	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5766	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5775	 1	 46.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5778	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5779	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00428	    0.00000	 63.0	 1	    1.07205	    0.93651;
	5784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5785	 1	 3.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5788	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00519	    0.00000	 63.0	 1	    1.07388	    0.93651;
	5789	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5794	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5795	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5800	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5801	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5805	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5806	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5807	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5810	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5811	 1	 -9.7	 0.0	 0.0	 0.0	 1	    1.00163	    0.00000	 63.0	 1	    1.06676	    0.93651;
	5812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5815	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5816	 1	 3.7	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5817	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5818	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5819	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07228	    0.00000	 380.0	 1	    1.10263	    1.04194;
	5823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5826	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5832	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5834	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5836	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5838	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5839	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5840	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5843	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5845	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5846	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5847	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5850	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5851	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5852	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5855	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5856	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5857	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5858	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5859	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5860	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5861	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5862	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5863	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5864	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5865	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5866	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5867	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5868	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5869	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5870	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5871	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5872	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5873	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5874	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5875	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5876	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5877	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5878	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5879	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5880	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5881	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5882	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5883	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5884	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5885	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5886	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5887	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5888	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5889	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5890	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5891	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5892	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5893	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5894	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5895	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	5896	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5897	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5898	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5899	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5900	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5901	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5902	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5903	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5904	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5905	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5906	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5907	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5908	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5909	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5910	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5911	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5912	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5913	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5914	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5915	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5916	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5917	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5918	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5919	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5920	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5921	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5922	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5923	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5924	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5925	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5926	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5927	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5928	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5929	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5930	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5931	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5932	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	5933	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5934	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5935	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5936	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5937	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5938	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5939	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5940	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5941	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5942	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5943	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5944	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5945	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5946	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5947	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5948	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5949	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5950	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5951	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5952	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5953	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5954	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5955	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5956	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5957	 1	 122.0	 7.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5958	 2	 1.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5959	 2	 -847.2	 -89.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5960	 1	 89.5	 -8.6	 0.0	 0.0	 1	    0.97500	    0.00000	 90.0	 1	    1.15000	    0.80000;
	5961	 1	 105.6	 12.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5962	 2	 -4.2	 207.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5963	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5964	 2	 167.8	 80.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5965	 2	 -20.0	 -26.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5966	 1	 -48.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5967	 2	 612.9	 169.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5968	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5969	 1	 111.9	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5970	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5971	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5972	 2	 -271.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5973	 1	 302.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5974	 1	 -96.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5975	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5976	 1	 116.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5977	 1	 630.3	 26.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5978	 1	 217.0	 19.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5979	 1	 -1.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	5980	 1	 2.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5981	 1	 159.5	 -1.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5982	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5983	 2	 331.6	 64.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5984	 1	 480.0	 143.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5985	 1	 -372.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5986	 1	 14.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5987	 1	 -0.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5988	 2	 -224.0	 -45.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5989	 1	 72.2	 5.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5990	 1	 2777.7	 -495.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5991	 1	 72.1	 0.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5992	 1	 537.6	 120.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5993	 1	 446.0	 128.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5994	 1	 150.0	 -8.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5995	 1	 147.4	 57.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5996	 1	 379.9	 -18.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5997	 2	 -285.4	 351.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5998	 1	 57.3	 -55.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5999	 1	 103.9	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6000	 1	 86.8	 26.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6001	 1	 291.7	 38.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6002	 2	 -92.0	 219.9	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6003	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6004	 1	 23.0	 14.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6005	 1	 -1.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6006	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6007	 1	 -139.4	 149.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6008	 1	 12.7	 12.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6009	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6010	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6011	 1	 149.0	 33.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6012	 1	 184.4	 23.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6013	 1	 90.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6014	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6015	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	6016	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6017	 1	 7.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6018	 1	 198.1	 52.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6019	 1	 88.1	 -0.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6020	 1	 81.0	 -4.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6021	 2	 87.0	 -12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6022	 1	 122.4	 80.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6023	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6024	 1	 -99.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6025	 1	 201.1	 64.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6026	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6027	 2	 495.3	 3.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6028	 1	 802.7	 58.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6029	 2	 -29.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6030	 1	 545.3	 59.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6031	 1	 212.5	 75.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6032	 1	 52.5	 -79.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6033	 1	 86.6	 -23.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6034	 1	 148.6	 9.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6035	 1	 127.2	 -32.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6036	 1	 859.1	 214.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6037	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6038	 1	 319.4	 80.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6039	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6040	 2	 29.2	 4.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6041	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6042	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6043	 1	 341.3	 -55.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6044	 1	 32.2	 -4.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6045	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6046	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6047	 1	 -90.9	 178.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6048	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6049	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6050	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6051	 1	 187.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6052	 1	 109.5	 6.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6053	 1	 172.7	 3.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6054	 1	 198.2	 21.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6055	 2	 300.9	 264.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6056	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6057	 1	 677.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6058	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6059	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6060	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6061	 1	 494.1	 11.9	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6062	 1	 250.6	 -92.1	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6063	 1	 -4.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6064	 1	 -1.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6065	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6066	 2	 628.8	 188.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6067	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6068	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6069	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6070	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6071	 1	 -1308.6	 -133.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6072	 1	 25.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6073	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6074	 1	 260.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6075	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6076	 1	 151.5	 48.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6077	 1	 31.7	 56.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6078	 1	 76.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6079	 1	 419.2	 43.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6080	 1	 -287.4	 59.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6081	 1	 38.7	 111.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6082	 1	 234.4	 -112.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6083	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6084	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6085	 1	 115.3	 284.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6086	 1	 176.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6087	 1	 271.4	 46.1	 0.0	 100.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6088	 2	 -1.7	 15.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6089	 2	 0.0	 0.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6090	 2	 220.0	 67.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6091	 1	 -315.7	 24.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6092	 2	 -31.6	 -48.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6093	 2	 87.8	 8.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6094	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6095	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6096	 1	 90.3	 10.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6097	 1	 2.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6098	 1	 445.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6099	 1	 -10.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6100	 1	 -370.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6101	 1	 19.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6102	 1	 -316.0	 0.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6103	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6104	 2	 363.0	 46.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6105	 1	 1.7	 -14.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6106	 2	 -242.0	 187.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6107	 1	 48.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6108	 1	 211.0	 -14.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6109	 1	 239.4	 -13.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6110	 1	 379.6	 104.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6111	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6112	 2	 92.0	 121.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6113	 2	 54.9	 64.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6114	 1	 -592.2	 89.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6115	 2	 242.5	 69.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6116	 1	 -176.9	 12.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6117	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6118	 1	 224.3	 6.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6119	 1	 -439.5	 180.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6120	 1	 393.9	 70.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6121	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6122	 1	 -120.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6123	 1	 314.8	 38.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6124	 1	 432.7	 122.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6125	 1	 198.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6126	 2	 124.4	 25.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6127	 1	 -81.0	 42.5	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6128	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6129	 1	 141.0	 -34.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6130	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6131	 1	 75.5	 14.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6132	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6133	 2	 464.8	 -8.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6134	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6135	 1	 -5.2	 -18.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6136	 1	 6.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6137	 1	 567.9	 126.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6138	 1	 312.5	 -273.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6139	 2	 239.0	 23.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6140	 1	 189.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6141	 1	 -94.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6142	 1	 -148.1	 184.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6143	 1	 172.6	 11.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6144	 1	 124.5	 0.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6145	 1	 267.9	 370.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6146	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6147	 1	 50.0	 -6.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6148	 1	 40.7	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6149	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6150	 1	 -29.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6151	 1	 9.4	 45.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6152	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6153	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6154	 1	 347.1	 37.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6155	 1	 83.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6156	 1	 -80.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6157	 2	 118.0	 -38.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6158	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6159	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6160	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6161	 1	 -1441.2	 294.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6162	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6163	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6164	 1	 -2.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6165	 2	 44.0	 -4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6166	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6167	 1	 113.0	 10.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6168	 1	 62.1	 19.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6169	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6170	 1	 114.0	 -36.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6171	 1	 213.5	 32.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6172	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6173	 2	 307.0	 53.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6174	 2	 253.0	 41.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6175	 1	 849.2	 -0.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6176	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6177	 1	 -36.1	 33.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6178	 1	 -78.9	 31.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6179	 2	 226.0	 39.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6180	 1	 -706.0	 -56.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6181	 1	 192.5	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6182	 1	 935.6	 302.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6183	 1	 363.0	 80.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6184	 2	 329.1	 -21.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6185	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6186	 1	 -32.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6187	 1	 124.8	 13.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6188	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6189	 2	 4.0	 106.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6190	 1	 10.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6191	 1	 276.6	 43.9	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6192	 1	 212.8	 22.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6193	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6194	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6195	 2	 50.8	 -12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6196	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6197	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6198	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6199	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6200	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6201	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6202	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6203	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6204	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99647	    0.00000	 380.0	 1	    1.19295	    0.80000;
	6205	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6206	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6207	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6208	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6209	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6210	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6211	 1	 48.4	 189.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6212	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6213	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6214	 1	 -78.5	 190.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6215	 1	 352.9	 -159.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6216	 2	 16.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6217	 1	 241.6	 57.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6218	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6219	 2	 448.0	 11.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6220	 1	 104.3	 25.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6221	 2	 2.0	 4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6222	 2	 12.7	 27.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6223	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6224	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6225	 1	 104.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6226	 2	 17.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6227	 1	 170.4	 88.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6228	 1	 211.4	 87.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6229	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6230	 1	 0.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6231	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6232	 1	 122.0	 33.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6233	 1	 61.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6234	 1	 -82.0	 7.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6235	 1	 670.5	 0.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6236	 1	 -733.6	 142.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6237	 1	 141.6	 21.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6238	 1	 27.5	 12.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6239	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6240	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6241	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6242	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6243	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6244	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6245	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6246	 1	 -20.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6247	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6248	 1	 232.5	 66.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6249	 1	 260.6	 41.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6250	 1	 227.8	 118.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6251	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6252	 1	 247.0	 33.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6253	 1	 319.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6254	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6255	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6256	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6257	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6258	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6259	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6260	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6261	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6262	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6263	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6264	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6265	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6266	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6267	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6268	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6269	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6270	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6271	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6272	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6273	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6274	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6275	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6276	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6278	 2	 16.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6279	 2	 14.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6280	 2	 14.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6281	 2	 10.0	 7.5	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	6282	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6283	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6284	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6285	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6286	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6287	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6288	 2	 13.0	 7.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6289	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6290	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6291	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6292	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6293	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6294	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6295	 2	 31.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6296	 2	 31.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6297	 2	 38.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6298	 2	 38.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6299	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6300	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6301	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6302	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6303	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6304	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6305	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6306	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6307	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6308	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6309	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6310	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6311	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6312	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6313	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6314	 2	 1.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6315	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6316	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6317	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6319	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6320	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6321	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6322	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6323	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6324	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6325	 2	 3.5	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6326	 2	 3.5	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6327	 2	 4.2	 2.3	 0.0	 0.0	 1	    0.97500	    0.00000	 14.0	 1	    1.15000	    0.80000;
	6328	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6329	 2	 30.0	 14.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6330	 2	 30.0	 14.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6332	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6333	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6334	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6335	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6336	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6337	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6338	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6339	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6340	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6341	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6342	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6343	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6344	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6345	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 21.0	 1	    1.15000	    0.80000;
	6346	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6347	 2	 8.8	 6.6	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	6348	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6349	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6350	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6351	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6352	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6353	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6354	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6355	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6356	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6357	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6358	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6359	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6360	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6361	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6362	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6363	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6364	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6365	 2	 7.3	 5.5	 0.0	 0.0	 1	    0.97500	    0.00000	 21.0	 1	    1.15000	    0.80000;
	6366	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6367	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6368	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6369	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6370	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6371	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6372	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6373	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6374	 2	 10.8	 8.6	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6375	 2	 10.0	 6.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6376	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6377	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6379	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6380	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6381	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6382	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6383	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6384	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6385	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6386	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6387	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6388	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6389	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6390	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6391	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6392	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6393	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6394	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6395	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6396	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6397	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6398	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6399	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6400	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6401	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6402	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6403	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6404	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6405	 2	 14.0	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6406	 2	 14.0	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6407	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6408	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6409	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6410	 2	 5.9	 3.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6411	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6412	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6413	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6414	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6415	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6416	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6417	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6418	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6419	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6420	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6421	 2	 30.0	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6422	 2	 30.0	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6423	 2	 12.0	 3.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	6424	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6425	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	6426	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6427	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6428	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6429	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6430	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6431	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6432	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6433	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6434	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6435	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6436	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6437	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6438	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6439	 2	 13.0	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6440	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6441	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6442	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6443	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6444	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6445	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6446	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6447	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6448	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6449	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6450	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6451	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6452	 2	 10.8	 8.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6453	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6454	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	6455	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	6456	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	6457	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6458	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6459	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6460	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6461	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 13.0	 1	    1.15000	    0.80000;
	6462	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 13.0	 1	    1.15000	    0.80000;
	6463	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 13.0	 1	    1.15000	    0.80000;
	6464	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 13.0	 1	    1.15000	    0.80000;
	6465	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6466	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6467	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6468	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6469	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6470	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6471	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6472	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6473	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6474	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6475	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6476	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6477	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6478	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6479	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6480	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6481	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6482	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6483	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6484	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6485	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6486	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6487	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6488	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6489	 2	 7.0	 4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	6490	 2	 7.0	 4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	6491	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6492	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6493	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6494	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6495	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6496	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6497	 2	 41.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6498	 2	 41.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6499	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6500	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6501	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6502	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6503	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6504	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6505	 2	 35.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6506	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6507	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6508	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6509	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6510	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6511	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6512	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6513	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6514	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6515	 2	 18.0	 10.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6516	 2	 18.0	 10.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6517	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6518	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6519	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	4	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 12.0	 0.0; % COW
	4	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 10.0	 0.0; % NG
	5	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 9.1	 0.0; % NG
	11	 14.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 28.0	 0.0; % NG
	11	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 18.0	 0.0; % PEL
	17	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.2	 0.0; % NG
	19	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 1.2	 0.0; % PEL
	22	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	24	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 16.1	 0.0; % NG
	24	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 35.5	 0.0; % NG
	25	 18.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 1	 36.0	 0.0; % PEL
	25	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 27.2	 0.0; % NG
	40	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 8.0	 0.0; % NG
	47	 8.0	 -0.25	 9.5	 -10.0	 0.999999	 100.0	 1	 16.0	 0.0; % COW
	47	 8.0	 -0.25	 9.5	 -10.0	 0.999999	 100.0	 1	 16.0	 0.0; % PEL
	48	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 23.0	 0.0; % PEL
	48	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 24.0	 0.0; % COW
	57	 6.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 13.0	 0.0; % COW
	64	 0.0	 0.0	 0.0	 0.0	 0.9888895	 100.0	 0	 24.0	 0.0; % NG
	64	 0.0	 0.0	 0.0	 0.0	 0.9888895	 100.0	 0	 27.6	 0.0; % NG
	69	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 30.04	 0.0; % NG
	70	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 23.0	 0.0; % COW
	85	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 6.68	 0.0; % NG
	86	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 9.2	 0.0; % NG
	102	 23.0	 6.0	 21.0	 -9.0	 1.0158755	 100.0	 1	 46.0	 0.0; % NG
	122	 6.0	 1.5	 5.0	 -2.0	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	124	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 9.0	 0.0; % NG
	125	 13.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 26.0	 0.0; % NG
	125	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	132	 8.5	 0.0	 3.0	 -3.0	 1.000001	 100.0	 1	 17.0	 0.0; % PEL
	132	 0.0	 0.8	 1.0	 -1.0	 1.000001	 100.0	 0	 4.0	 0.0; % NG
	132	 0.0	 0.8	 3.0	 -3.0	 1.000001	 100.0	 0	 14.0	 0.0; % NG
	132	 0.0	 0.8	 3.0	 -3.0	 1.000001	 100.0	 0	 14.0	 0.0; % COW
	137	 0.0	 -0.2	 0.8	 -0.8	 1.015872	 100.0	 0	 18.0	 0.0; % PEL
	137	 9.0	 0.0	 0.8	 -0.8	 1.015872	 100.0	 1	 18.0	 0.0; % NG
	155	 0.0	 0.47	 1.76	 -1.76	 1.0000025	 100.0	 0	 5.3	 0.0; % NG
	158	 8.95	 -1.5	 10.0	 -13.0	 0.9444445	 100.0	 1	 17.9	 0.0; % NG
	158	 8.95	 -1.5	 10.0	 -13.0	 0.9444445	 100.0	 1	 17.9	 0.0; % PEL
	176	 0.0	 0.78	 10.0	 -4.0	 1.0	 100.0	 0	 30.0	 0.0; % PEL
	187	 0.0	 1.92	 8.0	 -8.0	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	187	 0.0	 1.91	 2.0	 -2.0	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	190	 0.0	 -0.37	 14.0	 -14.0	 0.9444445	 100.0	 0	 30.0	 0.0; % NG
	192	 11.75	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 23.5	 0.0; % PEL
	194	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % NG
	194	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % NG
	217	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.94	 0.0; % NG
	224	 0.0	 0.79	 2.0	 0.0	 1.0	 100.0	 0	 6.0	 0.0; % NG
	227	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 7.5	 0.0; % COW
	236	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 33.5	 0.0; % NG
	236	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 24.3	 0.0; % NG
	238	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % PEL
	238	 18.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 36.0	 0.0; % COW
	246	 0.0	 0.0	 2.0	 0.0	 0.999999	 100.0	 0	 1.0	 0.0; % PEL
	246	 0.0	 -0.31	 10.0	 -10.0	 0.999999	 100.0	 0	 31.0	 0.0; % PEL
	246	 0.0	 -0.31	 10.0	 -10.0	 0.999999	 100.0	 0	 31.0	 0.0; % NG
	246	 0.0	 -0.31	 10.0	 -10.0	 0.999999	 100.0	 0	 31.0	 0.0; % COW
	256	 13.0	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 26.0	 0.0; % NG
	256	 13.0	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 26.0	 0.0; % PEL
	258	 15.0	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 30.0	 0.0; % NG
	261	 0.0	 1.78	 4.0	 -4.0	 1.0000025	 100.0	 0	 8.0	 0.0; % COW
	269	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.6	 0.0; % NG
	282	 0.0	 -0.32	 6.1	 -6.2	 0.999999	 100.0	 0	 11.6	 0.0; % NG
	295	 0.0	 0.0	 0.0	 0.0	 0.9888895	 100.0	 0	 25.3	 0.0; % NG
	296	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	305	 0.0	 -6.56	 9.0	 -9.0	 0.999999	 100.0	 0	 15.0	 0.0; % NG
	312	 12.9	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 25.8	 0.0; % PEL
	312	 24.8	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 49.6	 0.0; % NG
	317	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.0	 -7.0; % SYNC
	317	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.0	 -7.0; % SYNC
	319	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 10.8	 0.0; % PEL
	325	 0.0	 -0.29	 4.0	 -4.0	 0.999999	 100.0	 0	 11.0	 0.0; % NG
	332	 0.0	 1.22	 13.0	 -9.0	 1.015872	 100.0	 0	 25.0	 0.0; % PEL
	333	 0.0	 4.72	 13.0	 -9.0	 1.0233335	 100.0	 0	 25.0	 0.0; % NG
	336	 6.5	 -0.5	 5.0	 -6.0	 1.0000025	 100.0	 1	 13.0	 0.0; % NG
	338	 0.0	 1.74	 10.0	 -10.0	 1.0000025	 100.0	 0	 21.0	 0.0; % PEL
	338	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 2.0	 0.0; % PEL
	345	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 2.3	 0.0; % PEL
	345	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 19.5	 0.0; % PEL
	348	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 22.0	 0.0; % PEL
	357	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % COW
	357	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	364	 65.0	 16.5	 59.0	 -26.0	 1.046665	 100.0	 1	 130.0	 0.0; % NG
	391	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 2.7	 0.0; % PEL
	409	 0.0	 1.09	 5.0	 -5.0	 1.015872	 100.0	 0	 18.0	 0.0; % NG
	411	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	411	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % NG
	431	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	440	 0.0	 1.25	 10.96	 -11.99	 1.0000025	 100.0	 0	 34.25	 0.0; % NG
	447	 12.5	 -0.5	 8.0	 -9.0	 1.015872	 100.0	 1	 25.0	 0.0; % NG
	462	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 2.4	 0.0; % PEL
	462	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 16.0	 0.0; % NG
	464	 14.0	 1.5	 6.0	 -3.0	 0.98822	 100.0	 1	 27.0	 1.0; % NG
	464	 14.0	 1.5	 6.0	 -3.0	 0.98822	 100.0	 1	 27.0	 1.0; % NG
	466	 0.0	 0.0	 19.0	 -10.0	 1.0079355	 100.0	 0	 48.0	 1.0; % NG
	470	 0.0	 -0.68	 6.0	 -6.0	 0.999999	 100.0	 0	 10.0	 0.0; % NG
	470	 0.0	 -2.11	 5.4	 -5.4	 0.999999	 100.0	 0	 9.0	 0.0; % NG
	479	 0.0	 -0.24	 17.0	 -16.0	 0.999999	 100.0	 0	 27.0	 0.0; % NG
	479	 0.0	 -0.24	 17.0	 -16.0	 0.999999	 100.0	 0	 27.0	 0.0; % NG
	479	 0.0	 -0.24	 17.0	 -16.0	 0.999999	 100.0	 0	 27.0	 0.0; % PEL
	491	 0.0	 -2.0	 8.0	 -17.0	 1.033334	 100.0	 0	 23.4	 0.0; % PEL
	508	 0.0	 1.77	 2.0	 -2.0	 0.999999	 100.0	 0	 4.0	 0.0; % NG
	519	 0.0	 0.0	 0.0	 0.0	 1.015874	 100.0	 0	 10.0	 0.0; % PEL
	520	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	530	 4.0	 0.0	 4.8	 -4.8	 0.999999	 100.0	 1	 8.0	 0.0; % COW
	530	 4.0	 0.0	 4.8	 -4.8	 0.999999	 100.0	 1	 8.0	 0.0; % COW
	530	 4.0	 0.0	 4.8	 -4.8	 0.999999	 100.0	 1	 8.0	 0.0; % COW
	537	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	537	 12.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 24.0	 0.0; % PEL
	546	 4.5	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 9.0	 0.0; % NG
	548	 0.0	 1.04	 2.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	570	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % COW
	570	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 30.0	 0.0; % PEL
	570	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 11.5	 0.0; % NG
	583	 8.0	 1.5	 7.0	 -4.0	 1.0000005	 100.0	 1	 16.0	 0.0; % PEL
	585	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 9.0	 0.0; % NG
	586	 0.0	 4.82	 5.7	 -5.7	 0.999999	 100.0	 0	 9.5	 0.0; % NG
	589	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 1.0	 0.0; % PEL
	593	 0.0	 1.09	 10.0	 -10.0	 1.0000025	 100.0	 0	 21.0	 0.0; % PEL
	600	 0.0	 0.79	 1.0	 -1.0	 1.015872	 100.0	 0	 6.1	 0.0; % PEL
	610	 22.5	 0.0	 45.0	 -45.0	 0.975	 100.0	 1	 45.0	 0.0; % NG
	610	 0.0	 -0.45	 45.0	 -45.0	 0.975	 100.0	 0	 45.0	 0.0; % NG
	612	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	612	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	612	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	613	 0.0	 0.0	 0.0	 0.0	 1.0000005	 100.0	 0	 35.0	 0.0; % NG
	613	 0.0	 0.0	 0.0	 0.0	 1.0000005	 100.0	 0	 11.5	 0.0; % PEL
	624	 0.0	 0.0	 8.3	 -8.3	 1.0111115	 100.0	 1	 8.3	 -8.3; % PEL
	633	 0.0	 -2.55	 4.0	 -4.0	 0.999999	 100.0	 0	 7.3	 0.0; % COW
	636	 0.0	 0.25	 7.0	 0.0	 1.015872	 100.0	 0	 15.0	 0.0; % NG
	636	 7.5	 3.5	 7.0	 0.0	 1.015872	 100.0	 1	 15.0	 0.0; % NG
	646	 119.5	 2.5	 80.0	 -75.0	 1.078945	 100.0	 1	 239.0	 0.0; % NG
	657	 0.0	 0.51	 7.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % NG
	675	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	675	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % PEL
	676	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 7.5	 0.0; % NG
	676	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 24.0	 0.0; % PEL
	684	 0.0	 0.0	 0.0	 0.0	 1.0218635	 100.0	 0	 6.6	 0.0; % NG
	685	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	689	 4.5	 0.5	 6.0	 -5.0	 0.9444445	 100.0	 1	 9.0	 0.0; % COW
	689	 4.5	 0.5	 6.0	 -5.0	 0.9444445	 100.0	 1	 9.0	 0.0; % PEL
	689	 0.0	 1.22	 8.0	 -5.0	 0.9444445	 100.0	 0	 11.0	 0.0; % NG
	689	 5.5	 1.5	 8.0	 -5.0	 0.9444445	 100.0	 1	 11.0	 0.0; % PEL
	700	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 32.35	 0.0; % NG
	700	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 12.0	 0.0; % NG
	700	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 21.0	 0.0; % NG
	704	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	704	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	703	 18.5	 0.0	 15.0	 -15.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	703	 18.5	 0.0	 15.0	 -15.0	 0.975	 100.0	 1	 37.0	 0.0; % COW
	702	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	702	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	710	 0.0	 2.0	 2.0	 -2.0	 0.9444445	 100.0	 0	 4.0	 0.0; % PEL
	710	 0.0	 2.16	 2.5	 -2.5	 0.9444445	 100.0	 0	 4.0	 0.0; % NG
	710	 2.85	 0.0	 3.0	 -3.0	 0.9444445	 100.0	 1	 5.7	 0.0; % NG
	710	 0.0	 0.5	 6.0	 -5.0	 0.9444445	 100.0	 0	 8.5	 0.0; % NG
	737	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 19.5	 0.0; % PEL
	738	 19.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 39.0	 0.0; % PEL
	739	 5.75	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 11.5	 0.0; % PEL
	739	 16.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 32.0	 0.0; % NG
	741	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 12.0	 0.0; % NG
	741	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 32.0	 0.0; % NG
	742	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 5.0	 0.0; % NG
	749	 0.0	 3.42	 3.97	 -3.7	 0.999999	 100.0	 0	 6.7	 0.0; % PEL
	749	 0.0	 2.98	 3.54	 -3.0	 0.999999	 100.0	 0	 5.6	 0.0; % NG
	750	 13.3	 0.0	 15.0	 -15.0	 0.999999	 100.0	 1	 26.6	 0.0; % NG
	751	 4.0	 0.0	 2.0	 -2.0	 1.022224	 100.0	 1	 7.0	 1.0; % NG
	756	 0.0	 -0.31	 3.0	 -3.0	 0.999999	 100.0	 0	 5.0	 -5.0; % NG
	763	 0.0	 0.84	 8.0	 -8.0	 0.9888895	 100.0	 0	 23.5	 0.0; % PEL
	765	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 6.0	 0.0; % PEL
	766	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 6.0	 0.0; % NG
	765	 18.75	 1.79	 10.0	 -6.42	 0.999999	 100.0	 1	 37.5	 0.0; % PEL
	766	 18.75	 2.0	 10.0	 -6.0	 0.999999	 100.0	 1	 37.5	 0.0; % COW
	767	 0.0	 0.06	 0.06	 -0.06	 0.825	 100.0	 0	 0.6	 0.0; % PEL
	767	 0.0	 1.89	 2.61	 -2.61	 0.825	 100.0	 0	 26.1	 0.0; % NG
	767	 0.0	 0.16	 0.16	 -0.16	 0.825	 100.0	 0	 1.6	 0.0; % PEL
	767	 0.0	 0.11	 0.11	 -0.11	 0.825	 100.0	 0	 1.1	 0.0; % PEL
	771	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 37.5	 0.0; % COW
	771	 17.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 34.0	 0.0; % NG
	791	 0.0	 -0.47	 26.0	 -26.0	 0.975	 100.0	 0	 8.0	 0.0; % PEL
	791	 0.0	 -0.47	 26.0	 -26.0	 0.975	 100.0	 0	 15.0	 0.0; % COW
	792	 0.0	 -0.47	 26.0	 -26.0	 0.975	 100.0	 0	 19.0	 0.0; % NG
	806	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	806	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % NG
	807	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % NG
	807	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % NG
	808	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % NG
	808	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	812	 20.4	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 40.8	 0.0; % COW
	820	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % NG
	820	 0.0	 0.0	 6.0	 -9.0	 1.015872	 100.0	 0	 32.0	 1.0; % PEL
	821	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % NG
	821	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % PEL
	821	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % NG
	821	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % NG
	831	 0.0	 1.01	 3.0	 -3.0	 1.0000025	 100.0	 0	 13.0	 0.0; % NG
	831	 0.0	 3.0	 3.0	 -3.0	 1.0000025	 100.0	 0	 7.0	 0.0; % NG
	834	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 2.4	 0.0; % PEL
	835	 13.5	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 27.0	 0.0; % COW
	836	 0.0	 -0.46	 10.0	 -10.0	 0.9444445	 100.0	 0	 20.0	 0.0; % PEL
	838	 0.0	 1.03	 3.14	 -3.43	 1.0000025	 100.0	 0	 9.8	 0.0; % PEL
	838	 0.0	 0.99	 1.0	 0.0	 1.0000025	 100.0	 0	 5.0	 0.0; % PEL
	841	 7.5	 2.95	 3.0	 2.9	 1.0000025	 100.0	 1	 15.0	 0.0; % NG
	843	 0.0	 1.6	 7.5	 -7.5	 1.0000025	 100.0	 0	 19.0	 0.0; % PEL
	843	 0.0	 1.6	 7.5	 -7.5	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	862	 0.0	 0.0	 1.0	 0.9	 1.0000025	 100.0	 0	 12.0	 0.0; % COW
	862	 0.0	 0.89	 1.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % COW
	869	 7.0	 0.0	 7.0	 -7.0	 1.0000025	 100.0	 1	 14.0	 0.0; % NG
	870	 7.0	 0.0	 7.0	 -7.0	 1.0000025	 100.0	 1	 14.0	 0.0; % NG
	890	 0.0	 1.68	 6.0	 -6.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	890	 0.0	 1.68	 3.0	 -3.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	894	 0.0	 0.47	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % PEL
	894	 0.0	 0.47	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % COW
	894	 0.0	 0.47	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % NG
	894	 0.0	 0.47	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % PEL
	912	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 14.0	 0.0; % NG
	945	 4.05	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 8.1	 0.0; % PEL
	949	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 2.0	 0.0; % PEL
	970	 25.0	 9.0	 27.0	 -9.0	 0.975	 100.0	 1	 50.0	 0.0; % NG
	972	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 18.0	 0.0; % NG
	978	 4.0	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 8.0	 0.0; % COW
	978	 4.0	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 8.0	 0.0; % PEL
	988	 0.0	 3.09	 22.0	 -10.0	 1.027779	 100.0	 0	 49.0	 0.0; % PEL
	988	 0.0	 3.09	 7.0	 -3.0	 1.027779	 100.0	 0	 15.0	 0.0; % NG
	988	 0.0	 3.09	 22.0	 -10.0	 1.027779	 100.0	 0	 49.0	 0.0; % NG
	990	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 22.0	 0.0; % PEL
	992	 0.0	 1.0	 1.0	 -1.0	 1.022224	 100.0	 0	 4.0	 0.0; % PEL
	1014	 1.5	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 3.0	 0.0; % PEL
	1014	 0.0	 1.0	 1.0	 0.0	 1.000001	 100.0	 0	 3.0	 0.0; % PEL
	1018	 3.6	 0.0	 4.0	 -4.0	 1.001649	 100.0	 1	 7.2	 0.0; % NG
	1030	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.0	 0.0; % PEL
	1053	 0.0	 -0.27	 12.0	 -10.0	 0.999999	 100.0	 0	 20.0	 0.0; % COW
	1055	 6.9	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 13.8	 0.0; % NG
	1055	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 1.2	 0.0; % PEL
	1062	 9.4	 1.5	 6.0	 -3.0	 1.022222	 100.0	 1	 11.8	 7.0; % NG
	1063	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % NG
	1070	 0.0	 0.0	 0.0	 0.0	 0.9682545	 100.0	 0	 12.0	 0.0; % NG
	1071	 6.0	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 12.0	 0.0; % NG
	1075	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.0	 0.0; % NG
	1113	 16.0	 0.0	 6.0	 -6.0	 0.975	 100.0	 1	 18.0	 14.0; % PEL
	1113	 6.5	 0.0	 3.0	 -3.0	 0.975	 100.0	 1	 8.0	 5.0; % COW
	1113	 6.5	 0.0	 3.0	 -3.0	 0.975	 100.0	 1	 8.0	 5.0; % PEL
	1113	 6.5	 0.0	 3.0	 -3.0	 0.975	 100.0	 1	 8.0	 5.0; % NG
	1115	 9.0	 0.0	 10.0	 -10.0	 1.001754	 100.0	 1	 18.0	 0.0; % PEL
	1115	 9.0	 0.0	 10.0	 -10.0	 1.001754	 100.0	 1	 18.0	 0.0; % NG
	1130	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 7.0	 0.0; % PEL
	1133	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	1140	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	1152	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.0	 0.0; % NG
	1152	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % COW
	1215	 31.0	 0.0	 40.0	 -40.0	 1.04542	 100.0	 1	 62.0	 0.0; % NG
	1216	 20.7	 0.415	 12.42	 -11.59	 1.044445	 100.0	 1	 41.4	 0.0; % NG
	1226	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 11.2	 0.0; % NG
	1251	 0.0	 -0.35	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1251	 0.0	 -0.35	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1261	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 30.0	 0.0; % NG
	1263	 12.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 24.0	 0.0; % PEL
	1264	 12.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 24.0	 0.0; % NG
	1268	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 4.6	 0.0; % PEL
	1282	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 29.0	 0.0; % PEL
	1282	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 14.3	 0.0; % NG
	1291	 0.0	 0.35	 0.35	 -0.35	 1.0000025	 100.0	 0	 1.06	 0.0; % PEL
	1291	 0.0	 1.64	 2.6	 -2.8	 1.0000025	 100.0	 0	 8.0	 0.0; % PEL
	1291	 4.0	 -0.1	 2.6	 -2.8	 1.0000025	 100.0	 1	 8.0	 0.0; % COW
	1308	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 4.0	 0.0; % PEL
	1315	 8.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 17.0	 0.0; % NG
	1315	 8.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 17.0	 0.0; % PEL
	1315	 0.0	 0.92	 1.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % NG
	1318	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.8	 0.6; % NG
	1318	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.8	 0.6; % PEL
	1320	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % NG
	1320	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.9	 0.0; % NG
	1328	 0.0	 0.51	 6.5	 -6.5	 0.9444445	 100.0	 0	 12.4	 0.0; % NG
	1330	 0.0	 0.0	 1.0	 0.9	 1.000001	 100.0	 0	 5.0	 0.0; % NG
	1330	 2.5	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 5.0	 0.0; % COW
	1345	 0.0	 -11.45	 40.0	 -40.0	 0.999999	 100.0	 0	 72.5	 0.0; % NG
	1349	 5.5	 3.0	 5.0	 1.0	 0.975	 100.0	 1	 11.0	 0.0; % NG
	1349	 5.5	 3.0	 5.0	 1.0	 0.975	 100.0	 1	 11.0	 0.0; % NG
	1359	 9.075	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 18.15	 0.0; % NG
	1359	 17.85	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 35.7	 0.0; % COW
	1359	 14.2	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 28.4	 0.0; % NG
	1362	 22.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 45.0	 0.0; % NG
	1361	 22.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 45.0	 0.0; % NG
	1368	 0.0	 1.29	 7.0	 -5.0	 1.015872	 100.0	 0	 13.0	 0.0; % COW
	1368	 6.5	 1.28	 7.56	 -5.0	 1.015872	 100.0	 1	 13.0	 0.0; % COW
	1415	 0.0	 0.0	 22.0	 -10.0	 1.015872	 100.0	 0	 50.0	 5.0; % NG
	1425	 25.0	 0.0	 50.0	 -50.0	 1.000001	 100.0	 1	 50.0	 0.0; % PEL
	1425	 25.0	 0.0	 50.0	 -50.0	 1.000001	 100.0	 1	 50.0	 0.0; % NG
	1438	 0.0	 0.0	 22.0	 -10.0	 1.015872	 100.0	 0	 50.0	 5.0; % PEL
	1445	 10.5	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 21.0	 0.0; % NG
	1459	 0.0	 1.07	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1459	 0.0	 1.07	 2.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1459	 0.0	 1.07	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % PEL
	1468	 0.0	 -0.35	 0.3	 -0.35	 1.0158755	 100.0	 0	 3.0	 0.0; % NG
	1469	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 10.0	 0.0; % NG
	1479	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 10.0	 0.0; % NG
	1500	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 26.0	 0.0; % PEL
	1502	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 10.0	 0.0; % COW
	1502	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 20.0	 0.0; % PEL
	1522	 141.5	 20.0	 100.0	 -60.0	 0.975	 100.0	 1	 239.0	 44.0; % NG
	1523	 125.5	 12.5	 70.0	 -45.0	 0.975	 100.0	 1	 169.0	 82.0; % COW
	1553	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 20.0	 0.0; % NG
	1553	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 15.85	 0.0; % NG
	1560	 25.0	 6.5	 22.0	 -9.0	 1.033333	 100.0	 1	 49.0	 1.0; % NG
	1564	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 12.0	 0.0; % NG
	1564	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 24.0	 0.0; % PEL
	1565	 0.0	 0.0	 0.0	 0.0	 1.046665	 100.0	 0	 4.0	 0.0; % NG
	1566	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % COW
	1570	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 24.0	 0.0; % PEL
	1570	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 14.0	 0.0; % NG
	1584	 0.0	 -8.4	 6.0	 -8.4	 0.999999	 100.0	 0	 10.2	 0.0; % NG
	1594	 16.5	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 33.0	 0.0; % NG
	1594	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	1599	 18.0	 -0.5	 11.0	 -12.0	 1.022224	 100.0	 1	 36.0	 0.0; % NG
	1599	 18.0	 -0.5	 11.0	 -12.0	 1.022224	 100.0	 1	 36.0	 0.0; % PEL
	1605	 21.0	 5.0	 20.0	 -10.0	 1.0000005	 100.0	 1	 42.0	 0.0; % NG
	1619	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 22.0	 0.0; % NG
	1619	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 10.0	 0.0; % NG
	1630	 0.0	 0.91	 1.0	 0.0	 1.0377785	 100.0	 0	 78.0	 0.0; % NG
	1643	 0.0	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 3.7	 0.7; % NG
	1644	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 5.1	 0.0; % PEL
	1644	 5.95	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 11.9	 0.0; % PEL
	1645	 26.0	 -1.5	 10.0	 -13.0	 1.04444	 100.0	 1	 52.0	 0.0; % NG
	1648	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 4.0	 0.0; % NG
	1659	 0.0	 0.87	 6.0	 -6.0	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	1675	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 10.0	 0.0; % NG
	1675	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 17.5	 0.0; % PEL
	1684	 5.5	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 11.0	 0.0; % PEL
	1684	 5.5	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 11.0	 0.0; % PEL
	1685	 0.0	 1.62	 3.0	 0.0	 1.0000025	 100.0	 0	 27.0	 0.0; % NG
	1686	 0.0	 1.16	 3.0	 -3.0	 1.015872	 100.0	 0	 10.33	 0.0; % NG
	1686	 0.0	 2.72	 3.0	 -3.0	 1.015872	 100.0	 0	 10.33	 0.0; % NG
	1687	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 12.0	 0.0; % COW
	1688	 0.0	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 3.2	 0.6; % NG
	1693	 3.55	 0.07	 2.13	 -1.99	 1.0000025	 100.0	 1	 7.1	 0.0; % COW
	1697	 0.0	 -0.0	 0.0	 -0.0	 1.0158755	 100.0	 0	 15.0	 0.0; % PEL
	1697	 0.0	 -0.0	 0.0	 -0.0	 1.0158755	 100.0	 0	 15.0	 0.0; % COW
	1697	 0.0	 -0.0	 0.0	 -0.0	 1.0158755	 100.0	 0	 15.0	 0.0; % NG
	1700	 0.0	 1.65	 3.0	 0.0	 1.0000025	 100.0	 0	 31.0	 0.0; % PEL
	1703	 0.0	 0.0	 2.0	 1.9	 1.0000025	 100.0	 0	 18.0	 0.0; % PEL
	1704	 0.0	 2.93	 25.0	 -25.0	 1.0000025	 100.0	 0	 40.0	 0.0; % NG
	1706	 14.45	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 28.9	 0.0; % NG
	1717	 0.0	 0.0	 0.0	 0.0	 1.015874	 100.0	 0	 2.0	 0.0; % PEL
	1728	 0.0	 -0.35	 2.7	 -2.0	 0.975	 100.0	 0	 4.5	 0.0; % PEL
	1728	 0.0	 -0.35	 8.0	 -8.0	 0.975	 100.0	 0	 14.5	 0.0; % COW
	1731	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 4.5	 0.0; % PEL
	1733	 0.0	 -0.22	 7.5	 -7.5	 0.999999	 100.0	 0	 12.0	 0.0; % COW
	1740	 13.5	 0.0	 14.0	 -14.0	 1.0000025	 100.0	 1	 27.0	 0.0; % NG
	1740	 0.0	 1.26	 6.0	 -6.0	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	1747	 20.0	 1.0	 20.0	 -18.0	 0.975	 100.0	 1	 40.0	 0.0; % NG
	1748	 20.0	 1.0	 20.0	 -18.0	 0.975	 100.0	 1	 40.0	 0.0; % NG
	1749	 20.0	 1.0	 20.0	 -18.0	 0.975	 100.0	 1	 40.0	 0.0; % NG
	1803	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 3.6	 0.0; % NG
	1813	 0.0	 0.46	 2.0	 0.0	 1.0000025	 100.0	 0	 10.6	 0.0; % NG
	1830	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 9.2	 0.0; % NG
	1837	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 32.7	 0.0; % PEL
	1843	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 16.0	 0.0; % NG
	1843	 16.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 32.0	 0.0; % NG
	1853	 0.0	 0.89	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	1853	 0.0	 0.89	 1.0	 -1.0	 1.015872	 100.0	 0	 4.0	 0.0; % PEL
	1861	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % PEL
	1864	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 6.0	 0.0; % COW
	1864	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 2.0	 0.0; % NG
	1869	 12.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 24.0	 0.0; % COW
	1869	 18.25	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 36.5	 0.0; % NG
	1869	 21.75	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 43.5	 0.0; % NG
	1870	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	1871	 22.0	 5.5	 20.0	 -9.0	 1.0000005	 100.0	 1	 44.0	 0.0; % NG
	1872	 0.0	 -0.86	 3.5	 -3.5	 0.999999	 100.0	 0	 5.9	 0.0; % NG
	1877	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 9.0	 0.0; % NG
	1886	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	1894	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % COW
	1895	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1896	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1897	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1909	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 1.2	 0.0; % PEL
	1928	 0.0	 0.72	 1.0	 -1.0	 1.000001	 100.0	 0	 3.0	 0.0; % COW
	1941	 0.0	 -0.45	 26.0	 -26.0	 0.999999	 100.0	 0	 43.0	 0.0; % PEL
	1940	 0.0	 -0.55	 20.0	 -20.0	 0.999999	 100.0	 0	 38.0	 0.0; % COW
	1949	 0.0	 0.0	 2.0	 1.9	 1.0000025	 100.0	 0	 30.0	 0.0; % PEL
	1960	 0.0	 0.89	 2.0	 0.0	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	1968	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1969	 12.0	 0.705	 1.42	 -0.01	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1970	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1971	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1972	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1981	 14.5	 0.0	 10.0	 -10.0	 0.975	 100.0	 1	 29.0	 0.0; % PEL
	1981	 14.5	 0.0	 10.0	 -10.0	 0.975	 100.0	 1	 29.0	 0.0; % PEL
	1982	 14.5	 -6.5	 5.0	 -18.0	 0.999999	 100.0	 1	 29.0	 0.0; % PEL
	1983	 14.5	 -5.0	 8.0	 -18.0	 0.999999	 100.0	 1	 29.0	 0.0; % COW
	1985	 0.0	 0.59	 6.0	 -6.0	 1.0000025	 100.0	 0	 8.0	 0.0; % PEL
	1987	 2.55	 0.0	 2.0	 -2.0	 1.0000025	 100.0	 1	 4.6	 0.5; % PEL
	1987	 0.0	 0.0	 2.0	 -2.0	 1.0000025	 100.0	 0	 4.6	 0.5; % NG
	1993	 0.0	 -2.96	 2.0	 -2.96	 0.999999	 100.0	 0	 3.6	 0.0; % NG
	2001	 0.0	 0.58	 5.0	 -5.0	 0.9444445	 100.0	 0	 8.5	 0.0; % NG
	2008	 23.0	 6.0	 21.0	 -9.0	 1.0158755	 100.0	 1	 46.0	 0.0; % NG
	2019	 12.0	 0.0	 9.0	 -9.0	 1.0000025	 100.0	 1	 24.0	 0.0; % PEL
	2020	 12.0	 0.0	 9.0	 -9.0	 1.0000025	 100.0	 1	 24.0	 0.0; % COW
	2020	 12.0	 0.0	 9.0	 -9.0	 1.0000025	 100.0	 1	 24.0	 0.0; % PEL
	2025	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 12.0	 0.0; % COW
	2029	 0.0	 0.0	 7.0	 -7.0	 1.000001	 100.0	 1	 30.0	 -30.0; % PEL
	2037	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 9.0	 0.0; % NG
	2051	 17.0	 1.5	 19.0	 -16.0	 0.999999	 100.0	 1	 34.0	 0.0; % NG
	2061	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	2085	 0.0	 1.89	 2.0	 0.0	 1.0000025	 100.0	 0	 5.0	 0.0; % NG
	2098	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 16.0	 0.0; % NG
	2099	 27.5	 6.0	 22.0	 -10.0	 1.022222	 100.0	 1	 54.0	 1.0; % PEL
	2103	 8.0	 0.0	 5.0	 -5.0	 1.0079355	 100.0	 1	 16.0	 0.0; % NG
	2123	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 19.9	 0.0; % NG
	2123	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 32.4	 0.0; % NG
	2151	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.25	 0.0; % NG
	2151	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.0	 0.0; % NG
	2161	 14.5	 3.5	 13.0	 -6.0	 1.027779	 100.0	 1	 29.0	 0.0; % NG
	2165	 22.5	 6.0	 22.0	 -10.0	 1.0000005	 100.0	 1	 45.0	 0.0; % NG
	2166	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 12.0	 0.0; % NG
	2182	 12.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 24.0	 0.0; % NG
	2182	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 29.92	 0.0; % PEL
	2187	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 9.2	 0.0; % NG
	2190	 0.0	 0.0	 0.0	 0.0	 0.9682545	 100.0	 0	 12.0	 0.0; % COW
	2190	 0.0	 0.0	 0.0	 0.0	 0.9682545	 100.0	 0	 12.0	 0.0; % PEL
	2192	 0.0	 0.0	 22.0	 -10.0	 1.022222	 100.0	 0	 47.0	 37.0; % NG
	2193	 7.5	 0.0	 9.0	 -9.0	 0.9444445	 100.0	 1	 15.0	 0.0; % NG
	2195	 10.0	 1.95	 2.0	 1.9	 1.000001	 100.0	 1	 20.0	 0.0; % NG
	2226	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 28.0	 0.0; % NG
	2226	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 26.0	 0.0; % NG
	2245	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	2245	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 36.0	 0.0; % COW
	2247	 0.0	 0.0	 8.0	 -8.0	 0.975	 100.0	 0	 24.0	 2.5; % PEL
	2247	 13.25	 0.0	 8.0	 -8.0	 0.975	 100.0	 1	 24.0	 2.5; % PEL
	2281	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 13.8	 0.0; % NG
	2291	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	2295	 0.0	 2.36	 17.0	 -20.0	 1.0000005	 100.0	 0	 56.0	 0.0; % PEL
	2297	 0.0	 4.15	 20.0	 -20.0	 1.0000005	 100.0	 0	 64.0	 -64.0; % NG
	2303	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % COW
	2303	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	2329	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	2335	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 11.5	 0.0; % NG
	2339	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 3.6	 0.0; % NG
	2341	 14.0	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 0.0; % NG
	2341	 14.0	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 0.0; % NG
	2341	 14.0	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 0.0; % COW
	2342	 0.0	 0.9	 1.0	 -1.0	 1.0000025	 100.0	 0	 10.0	 0.0; % PEL
	2342	 0.0	 0.87	 3.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % COW
	2343	 0.0	 1.92	 2.0	 -2.0	 1.022224	 100.0	 0	 7.0	 0.0; % NG
	2364	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	2365	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	2366	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	2367	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	2368	 10.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 20.0	 0.0; % NG
	2378	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.0	 0.0; % PEL
	2394	 6.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 12.0	 0.0; % NG
	2396	 17.45	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 34.9	 0.0; % NG
	2396	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 19.3	 0.0; % NG
	2412	 18.0	 0.0	 14.0	 -14.0	 1.000001	 100.0	 1	 36.0	 0.0; % NG
	2414	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.9	 0.0; % PEL
	2414	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 19.2	 0.0; % PEL
	2421	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.0	 0.0; % NG
	2421	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 16.0	 0.0; % COW
	2421	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	2433	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 19.7	 0.0; % PEL
	2437	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 22.6	 0.0; % PEL
	2437	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 1.7	 0.0; % PEL
	2440	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 18.0	 0.0; % NG
	2440	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 21.0	 0.0; % NG
	2445	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 10.4	 0.0; % NG
	2444	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 22.0	 0.0; % PEL
	2460	 0.0	 0.4	 8.0	 -8.0	 1.045365	 100.0	 0	 21.0	 0.0; % NG
	2461	 0.0	 0.27	 3.0	 -3.0	 1.015872	 100.0	 0	 4.5	 0.0; % NG
	2461	 0.0	 1.25	 3.0	 -3.0	 1.015872	 100.0	 0	 4.5	 0.0; % NG
	2464	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.7	 0.0; % PEL
	2475	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 12.0	 0.0; % NG
	2481	 13.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 26.0	 0.0; % PEL
	2495	 0.0	 0.01	 5.0	 -5.0	 1.015872	 100.0	 0	 12.0	 0.0; % COW
	2523	 44.0	 5.5	 19.0	 -8.0	 1.049058	 100.0	 1	 50.0	 38.0; % NG
	2523	 44.0	 5.5	 19.0	 -8.0	 1.049058	 100.0	 1	 50.0	 38.0; % NG
	2529	 10.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.0	 0.0; % PEL
	2529	 18.425	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 36.85	 0.0; % COW
	2530	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.5	 0.0; % NG
	2530	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 15.0	 0.0; % COW
	2532	 4.8	 0.0	 0.96	 -0.96	 1.0158755	 100.0	 1	 9.6	 0.0; % NG
	2545	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 5.66	 0.0; % PEL
	2547	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 16.0	 0.0; % NG
	2555	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 18.85	 0.0; % NG
	2555	 17.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 34.0	 0.0; % NG
	2558	 8.0	 1.5	 12.0	 -9.0	 0.999999	 100.0	 1	 16.0	 0.0; % NG
	2563	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 16.8	 0.0; % NG
	2576	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 16.8	 0.0; % PEL
	2576	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 13.5	 0.0; % COW
	2581	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % NG
	2586	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % PEL
	2586	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.7	 0.0; % PEL
	2592	 0.0	 0.0	 0.0	 0.0	 0.975	 100.0	 0	 4.6	 0.0; % NG
	2601	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 12.0	 0.0; % PEL
	2601	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 9.0	 0.0; % NG
	2610	 11.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 22.0	 0.0; % PEL
	2611	 0.0	 -1.2	 1.0	 -2.0	 1.015872	 100.0	 0	 8.9	 0.0; % NG
	2616	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.05	 0.0; % NG
	2624	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 37.5	 0.0; % PEL
	2624	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 12.0	 0.0; % NG
	2627	 14.0	 4.5	 16.0	 -7.0	 1.0158755	 100.0	 1	 28.0	 0.0; % NG
	2640	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 5.0	 0.0; % NG
	2640	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	2640	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 5.0	 0.0; % NG
	2643	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 2.3	 0.0; % PEL
	2644	 9.0	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 18.0	 0.0; % NG
	2645	 11.0	 0.0	 14.0	 -14.0	 1.0000025	 100.0	 1	 22.0	 0.0; % PEL
	2645	 11.0	 0.0	 14.0	 -14.0	 1.0000025	 100.0	 1	 22.0	 0.0; % PEL
	2645	 14.5	 -4.0	 8.0	 -16.0	 1.0000025	 100.0	 1	 29.0	 0.0; % NG
	2646	 0.0	 -0.08	 0.1	 -0.1	 1.0042125	 100.0	 0	 1.0	 0.0; % PEL
	2646	 0.0	 -0.19	 6.0	 -6.0	 1.0042125	 100.0	 0	 10.0	 0.0; % NG
	2646	 0.0	 -0.19	 5.0	 -5.0	 1.0042125	 100.0	 0	 9.0	 0.0; % NG
	2649	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 35.0	 0.0; % COW
	2649	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 24.0	 0.0; % PEL
	2652	 14.0	 3.95	 4.0	 3.9	 1.0000025	 100.0	 1	 28.0	 0.0; % NG
	2659	 0.0	 -0.66	 1.7	 -1.7	 0.999999	 100.0	 0	 2.6	 0.0; % PEL
	2659	 4.9	 0.0	 6.0	 -6.0	 0.999999	 100.0	 1	 9.8	 0.0; % NG
	2660	 17.5	 -1.5	 12.0	 -15.0	 1.015872	 100.0	 1	 35.0	 0.0; % PEL
	2660	 17.5	 -1.5	 12.0	 -15.0	 1.015872	 100.0	 1	 35.0	 0.0; % PEL
	2663	 0.0	 0.31	 1.0	 0.0	 0.975	 100.0	 0	 11.0	 0.0; % NG
	2664	 3.5	 0.95	 1.0	 0.9	 0.975	 100.0	 1	 7.0	 0.0; % NG
	2663	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 3.0	 0.0; % NG
	2662	 0.0	 -1.54	 4.0	 -7.0	 0.975	 100.0	 0	 12.0	 0.0; % COW
	2664	 0.0	 -0.1	 0.1	 -0.1	 0.975	 100.0	 0	 4.0	 0.0; % NG
	2665	 6.0	 -1.285	 4.43	 -7.0	 1.0000025	 100.0	 1	 12.0	 0.0; % PEL
	2669	 0.0	 2.57	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2669	 0.0	 2.57	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2669	 0.0	 2.57	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2669	 0.0	 2.0	 2.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2669	 0.0	 2.57	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2674	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.15	 0.0; % NG
	2688	 18.2	 0.0	 0.0	 0.0	 1.033333	 100.0	 1	 36.4	 0.0; % NG
	2695	 7.5	 -0.5	 6.0	 -7.0	 1.0000005	 100.0	 1	 15.0	 0.0; % PEL
	2729	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 21.8	 0.0; % PEL
	2734	 8.5	 0.0	 10.0	 -10.0	 1.000001	 100.0	 1	 17.0	 0.0; % PEL
	2734	 8.5	 0.0	 10.0	 -10.0	 1.000001	 100.0	 1	 17.0	 0.0; % NG
	2766	 13.25	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 26.5	 0.0; % NG
	2776	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 14.0	 0.0; % NG
	2812	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % COW
	2813	 8.075	 0.0	 0.0	 0.0	 0.984126	 100.0	 1	 16.15	 0.0; % NG
	2818	 0.0	 -0.28	 8.0	 -8.0	 1.0000025	 100.0	 0	 20.0	 0.0; % NG
	2822	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % PEL
	2833	 6.0	 1.5	 5.0	 -2.0	 1.0000005	 100.0	 1	 12.0	 0.0; % NG
	2838	 0.0	 -0.57	 4.63	 -5.56	 1.033334	 100.0	 0	 13.8	 0.0; % COW
	2840	 10.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 20.0	 0.0; % PEL
	2840	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	2843	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	2843	 16.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 32.0	 0.0; % PEL
	2845	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 2.0	 0.0; % PEL
	2845	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 12.0	 0.0; % NG
	2857	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 17.6	 0.0; % NG
	2868	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % NG
	2874	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 13.8	 0.0; % NG
	2876	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 14.8	 0.0; % NG
	2876	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 2.4	 0.0; % PEL
	2884	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.2	 0.0; % NG
	2899	 0.0	 0.0	 9.0	 -9.0	 0.975	 100.0	 0	 26.5	 6.0; % PEL
	2899	 16.25	 0.0	 9.0	 -9.0	 0.975	 100.0	 1	 26.5	 6.0; % NG
	2899	 0.0	 0.0	 8.0	 -8.0	 0.975	 100.0	 0	 22.9	 6.0; % NG
	2904	 0.0	 0.73	 1.0	 0.0	 1.0	 100.0	 0	 14.0	 0.0; % NG
	2904	 0.0	 0.73	 1.0	 0.0	 1.0	 100.0	 0	 12.0	 -10.0; % COW
	2904	 0.0	 0.73	 1.0	 0.0	 1.0	 100.0	 0	 12.0	 -10.0; % COW
	2908	 0.0	 -3.54	 5.43	 -5.43	 1.0000025	 100.0	 0	 16.3	 0.0; % NG
	2928	 0.0	 -0.8	 3.0	 -3.0	 0.999999	 100.0	 0	 6.0	 0.0; % NG
	2929	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 8.0	 0.0; % COW
	2941	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 34.5	 0.0; % NG
	2948	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.0	 0.0; % NG
	2954	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 18.0	 0.0; % PEL
	2954	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % PEL
	2975	 0.0	 -0.43	 0.47	 -1.3	 1.0158755	 100.0	 0	 4.7	 0.0; % NG
	2982	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 8.2	 0.0; % NG
	2993	 17.0	 0.0	 17.0	 -17.0	 0.999999	 100.0	 1	 34.0	 0.0; % NG
	3020	 0.0	 -1.3	 1.7	 -1.7	 1.0158755	 100.0	 0	 17.0	 0.0; % PEL
	3020	 0.0	 -1.3	 1.7	 -1.7	 1.0158755	 100.0	 0	 17.0	 0.0; % PEL
	3021	 0.0	 3.18	 3.59	 -3.0	 0.999999	 100.0	 0	 5.0	 0.0; % NG
	3022	 6.5	 0.0	 8.0	 -8.0	 1.001294	 100.0	 1	 13.0	 0.0; % PEL
	3022	 6.5	 0.0	 8.0	 -8.0	 1.001294	 100.0	 1	 13.0	 0.0; % NG
	3024	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 18.4	 0.0; % NG
	3027	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 2.4	 0.0; % PEL
	3027	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	3029	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 11.5	 0.0; % NG
	3036	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 6.9	 0.0; % PEL
	3038	 0.0	 0.0	 0.0	 0.0	 1.044445	 100.0	 0	 55.4	 0.0; % NG
	3049	 8.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 16.0	 0.0; % COW
	3059	 0.0	 0.77	 9.0	 -9.0	 0.999999	 100.0	 0	 15.8	 0.0; % COW
	3060	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 2.0	 0.0; % PEL
	3070	 8.625	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 17.25	 0.0; % PEL
	3098	 0.0	 -0.44	 5.0	 -10.0	 0.9444445	 100.0	 0	 19.5	 0.0; % NG
	3107	 0.0	 3.6	 12.0	 0.0	 0.999999	 100.0	 0	 9.0	 0.0; % NG
	3110	 0.0	 0.0	 0.0	 0.0	 1.0377785	 100.0	 0	 54.0	 0.0; % NG
	3113	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 11.1	 0.0; % NG
	3116	 19.0	 0.5	 20.0	 -19.0	 0.975	 100.0	 1	 38.0	 0.0; % PEL
	3117	 19.0	 0.5	 20.0	 -19.0	 0.975	 100.0	 1	 38.0	 0.0; % COW
	3118	 19.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 38.0	 0.0; % NG
	3122	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 4.25	 0.0; % NG
	3123	 0.0	 1.19	 10.0	 -10.0	 0.999999	 100.0	 0	 16.8	 0.0; % NG
	3123	 0.0	 1.19	 17.3	 -17.3	 0.999999	 100.0	 0	 16.0	 0.0; % NG
	3125	 10.4	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 20.8	 0.0; % NG
	3126	 0.0	 1.21	 6.0	 -6.0	 1.0000025	 100.0	 0	 8.0	 0.0; % PEL
	3131	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 7.2	 0.0; % NG
	3132	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	3132	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 18.0	 0.0; % PEL
	3136	 5.5	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 11.0	 0.0; % NG
	3136	 7.0	 0.0	 0.1	 -0.1	 1.000001	 100.0	 1	 14.0	 0.0; % NG
	3140	 0.0	 0.0	 0.0	 0.0	 1.0377785	 100.0	 0	 8.0	 0.0; % NG
	3140	 0.0	 0.0	 0.0	 0.0	 1.0377785	 100.0	 0	 8.0	 0.0; % PEL
	3142	 0.0	 0.45	 0.5	 -0.5	 1.0000025	 100.0	 0	 1.5	 0.0; % PEL
	3147	 5.25	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 10.5	 0.0; % COW
	3147	 4.3	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 8.6	 0.0; % NG
	3151	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % PEL
	3157	 26.5	 6.0	 22.0	 -10.0	 1.0111115	 100.0	 1	 48.0	 5.0; % NG
	3159	 8.0	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 16.0	 0.0; % NG
	3159	 8.0	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 16.0	 0.0; % PEL
	3159	 9.0	 0.0	 12.0	 -12.0	 1.000001	 100.0	 1	 18.0	 0.0; % PEL
	3178	 0.0	 0.94	 10.0	 -3.0	 1.0	 100.0	 0	 27.0	 0.0; % NG
	3178	 0.0	 0.94	 10.0	 -3.0	 1.0	 100.0	 0	 27.0	 0.0; % NG
	3185	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 10.0	 0.0; % NG
	3185	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 12.0	 0.0; % NG
	3188	 9.0	 0.0	 0.0	 0.0	 1.003564	 100.0	 1	 18.0	 0.0; % PEL
	3188	 0.0	 0.0	 0.0	 0.0	 1.003564	 100.0	 0	 10.0	 0.0; % NG
	3210	 10.0	 1.0	 2.0	 0.0	 1.0	 100.0	 1	 20.0	 0.0; % COW
	3219	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 22.6	 0.0; % PEL
	3219	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	3238	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 22.3	 0.0; % PEL
	3239	 11.0	 1.95	 2.0	 1.9	 1.000001	 100.0	 1	 22.0	 0.0; % NG
	3241	 0.0	 -0.83	 3.0	 -3.0	 0.999999	 100.0	 0	 5.2	 0.0; % NG
	3244	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 9.2	 0.0; % NG
	3246	 5.0	 0.0	 4.0	 -4.0	 1.0000025	 100.0	 1	 10.0	 0.0; % PEL
	3250	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.8	 0.0; % NG
	3260	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 7.5	 0.0; % PEL
	3264	 3.0	 0.0	 0.1	 -0.1	 1.0000025	 100.0	 1	 6.0	 0.0; % COW
	3265	 18.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 36.0	 0.0; % PEL
	3265	 16.35	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 32.7	 0.0; % NG
	3265	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % COW
	3266	 21.0	 2.5	 25.0	 -20.0	 1.0	 100.0	 1	 42.0	 0.0; % NG
	3266	 21.0	 2.5	 25.0	 -20.0	 1.0	 100.0	 1	 42.0	 0.0; % NG
	3276	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % PEL
	3276	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % COW
	3280	 18.05	 2.5	 20.0	 -15.0	 0.975	 100.0	 1	 36.1	 0.0; % PEL
	3281	 18.05	 2.5	 20.0	 -15.0	 0.975	 100.0	 1	 36.1	 0.0; % NG
	3282	 18.05	 2.5	 20.0	 -15.0	 0.975	 100.0	 1	 36.1	 0.0; % NG
	3295	 0.0	 0.79	 8.5	 -8.5	 0.999999	 100.0	 0	 11.4	 0.0; % PEL
	3301	 6.5	 0.0	 5.0	 -5.0	 1.019842	 100.0	 1	 13.0	 0.0; % NG
	3308	 8.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 17.0	 0.0; % NG
	3308	 8.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 17.0	 0.0; % NG
	3313	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 18.0	 0.0; % NG
	3313	 5.1	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 10.2	 0.0; % NG
	3315	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	3315	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 19.4	 0.0; % COW
	3339	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	3345	 0.0	 0.0	 24.0	 -24.0	 0.999999	 100.0	 0	 51.0	 0.8; % COW
	3377	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 8.0	 0.0; % PEL
	3377	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 20.0	 0.0; % NG
	3382	 19.9	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 39.8	 0.0; % NG
	3383	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 15.0	 0.0; % COW
	3405	 21.5	 6.0	 22.0	 -10.0	 1.0158755	 100.0	 1	 43.0	 0.0; % NG
	3408	 12.0	 -0.255	 7.0	 -7.51	 1.000214	 100.0	 1	 24.0	 0.0; % NG
	3418	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 7.5	 0.0; % PEL
	3418	 3.75	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 1	 7.5	 0.0; % COW
	3418	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 7.5	 0.0; % COW
	3418	 3.75	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 1	 7.5	 0.0; % PEL
	3418	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 7.5	 0.0; % NG
	3423	 17.5	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 35.0	 0.0; % PEL
	3423	 18.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 36.0	 0.0; % NG
	3424	 11.55	 0.0	 14.0	 -14.0	 0.999999	 100.0	 1	 23.1	 0.0; % NG
	3424	 11.55	 0.0	 14.0	 -14.0	 0.999999	 100.0	 1	 23.1	 0.0; % NG
	3431	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 3.0	 0.0; % NG
	3434	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.0	 0.0; % PEL
	3437	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 24.0	 0.0; % COW
	3440	 0.0	 0.0	 0.0	 0.0	 1.0080855	 100.0	 0	 12.0	 0.0; % COW
	3440	 0.0	 0.0	 0.0	 0.0	 1.0080855	 100.0	 0	 10.5	 0.0; % COW
	3445	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 1.7	 0.0; % PEL
	3450	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 20.55	 0.0; % NG
	3451	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.0	 0.0; % PEL
	3454	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 12.0	 0.0; % NG
	3461	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % COW
	3468	 6.6	 0.0	 8.0	 -8.0	 0.999999	 100.0	 1	 13.2	 0.0; % NG
	3488	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 1.25	 0.0; % PEL
	3491	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 0.0	 -8.0; % SYNC
	3491	 26.5	 3.5	 17.0	 -10.0	 1.0	 100.0	 1	 53.0	 0.0; % NG
	3495	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 21.2	 0.0; % PEL
	3504	 17.5	 0.0	 15.0	 -15.0	 1.044445	 100.0	 1	 35.0	 0.0; % COW
	3505	 0.0	 -0.43	 15.0	 -10.0	 0.975	 100.0	 0	 50.0	 0.0; % NG
	3507	 0.0	 1.15	 2.8	 -2.8	 0.999999	 100.0	 0	 4.8	 0.0; % PEL
	3508	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 18.0	 0.0; % NG
	3513	 24.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 48.0	 0.0; % NG
	3513	 8.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 16.0	 0.0; % PEL
	3521	 0.0	 -12.99	 16.0	 -16.0	 0.999999	 100.0	 0	 26.2	 0.0; % NG
	3530	 5.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 10.0	 0.0; % PEL
	3544	 6.4	 0.0	 7.6	 -7.6	 0.999999	 100.0	 1	 12.8	 0.0; % COW
	3545	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 12.0	 0.0; % PEL
	3550	 0.0	 0.58	 5.0	 -2.0	 1.0158755	 100.0	 0	 12.0	 0.0; % COW
	3550	 0.0	 0.58	 5.0	 -2.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	3550	 0.0	 0.58	 5.0	 -2.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	3549	 0.0	 0.67	 22.0	 -10.0	 1.0414805	 100.0	 0	 43.0	 0.0; % PEL
	3584	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 10.0	 0.0; % NG
	3587	 10.4	 -2.0	 6.0	 -10.0	 0.975	 100.0	 1	 20.0	 0.8; % NG
	3587	 10.4	 0.0	 4.2	 -4.2	 0.975	 100.0	 1	 20.0	 0.8; % NG
	3586	 0.0	 0.0	 4.2	 -4.2	 0.975	 100.0	 0	 20.0	 0.8; % PEL
	3586	 10.4	 0.0	 4.2	 -4.2	 0.975	 100.0	 1	 20.0	 0.8; % PEL
	3600	 11.5	 0.5	 10.0	 -9.0	 1.000001	 100.0	 1	 23.0	 0.0; % PEL
	3600	 11.5	 0.5	 10.0	 -9.0	 1.000001	 100.0	 1	 23.0	 0.0; % PEL
	3600	 11.5	 0.5	 10.0	 -9.0	 1.000001	 100.0	 1	 23.0	 0.0; % NG
	3604	 0.0	 10.0	 30.0	 -10.0	 0.999999	 100.0	 1	 40.0	 -40.0; % NG
	3604	 0.0	 0.0	 28.0	 -28.0	 0.999999	 100.0	 1	 50.0	 -50.0; % NG
	3636	 0.0	 -0.14	 3.0	 -1.0	 1.001569	 100.0	 0	 2.0	 0.0; % PEL
	3646	 7.445	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 14.89	 0.0; % COW
	3646	 17.385	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 34.77	 0.0; % NG
	3649	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	3651	 3.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 7.0	 0.0; % COW
	3651	 3.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 7.0	 0.0; % COW
	3652	 0.0	 -4.56	 12.0	 -12.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	3657	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	3660	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % PEL
	3661	 0.0	 1.0	 1.0	 -1.0	 1.0079355	 100.0	 0	 3.0	 0.0; % NG
	3667	 0.0	 -0.86	 7.0	 -7.0	 0.999999	 100.0	 0	 12.0	 0.0; % COW
	3667	 0.0	 -0.86	 7.0	 -7.0	 0.999999	 100.0	 0	 12.0	 0.0; % NG
	3668	 0.0	 -0.98	 3.0	 -3.0	 0.999999	 100.0	 0	 4.5	 0.0; % PEL
	3684	 0.0	 0.93	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	3686	 0.0	 0.79	 1.8	 -1.8	 0.999999	 100.0	 0	 3.0	 0.0; % NG
	3692	 4.75	 0.0	 6.0	 -6.0	 0.999999	 100.0	 1	 9.5	 0.0; % NG
	3694	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 8.0	 0.0; % COW
	3696	 0.0	 0.79	 5.6	 -5.6	 0.999999	 100.0	 0	 8.8	 0.0; % NG
	3713	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 24.0	 0.0; % PEL
	3715	 9.0	 0.0	 8.0	 -8.0	 1.027779	 100.0	 1	 18.0	 0.0; % PEL
	3716	 0.0	 -0.57	 17.0	 -11.0	 0.999999	 100.0	 0	 19.0	 0.0; % PEL
	3717	 22.0	 0.0	 17.0	 -17.0	 0.999999	 100.0	 1	 44.0	 0.0; % NG
	3744	 0.0	 -0.32	 6.0	 -7.0	 0.999999	 100.0	 0	 9.0	 0.0; % NG
	3748	 8.4	 0.25	 4.6	 -4.1	 0.999999	 100.0	 1	 11.2	 5.6; % NG
	3753	 21.5	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 43.0	 0.0; % NG
	3758	 5.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 1	 10.0	 0.0; % NG
	3758	 10.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 1	 20.0	 0.0; % COW
	3760	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 22.05	 0.0; % PEL
	3761	 6.0	 0.0	 1.2	 -1.2	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	3796	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	3796	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % COW
	3799	 13.125	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 26.25	 0.0; % NG
	3799	 10.125	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.25	 0.0; % NG
	3799	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	3801	 10.01	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.02	 0.0; % PEL
	3801	 10.175	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.35	 0.0; % PEL
	3816	 18.9	 2.0	 12.0	 -8.0	 0.975	 100.0	 1	 37.8	 0.0; % PEL
	3817	 18.9	 2.0	 12.0	 -8.0	 0.975	 100.0	 1	 37.8	 0.0; % NG
	3818	 18.9	 2.0	 12.0	 -8.0	 0.975	 100.0	 1	 37.8	 0.0; % COW
	3822	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 27.2	 0.0; % NG
	3826	 15.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 30.0	 0.0; % PEL
	3836	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 9.1	 0.0; % NG
	3842	 6.0	 0.0	 7.2	 -7.2	 0.999999	 100.0	 1	 12.0	 0.0; % NG
	3842	 6.5	 0.0	 7.8	 -7.8	 0.999999	 100.0	 1	 13.0	 0.0; % NG
	3853	 11.0	 1.0	 6.0	 -4.0	 1.0000025	 100.0	 1	 22.0	 0.0; % NG
	3863	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.68	 0.0; % NG
	3868	 4.5	 0.0	 3.0	 -3.0	 1.022224	 100.0	 1	 9.0	 0.0; % NG
	3869	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % PEL
	3876	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 8.0	 0.0; % COW
	3889	 0.0	 0.0	 0.0	 0.0	 1.0277795	 100.0	 0	 12.0	 0.0; % NG
	3893	 0.0	 1.0	 1.0	 -1.0	 1.0079355	 100.0	 0	 2.0	 0.0; % PEL
	3893	 0.0	 1.0	 1.0	 -1.0	 1.0079355	 100.0	 0	 2.0	 0.0; % PEL
	3904	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 13.2	 0.0; % COW
	3904	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 18.0	 0.0; % NG
	3919	 0.0	 1.85	 5.0	 -4.5	 1.0000025	 100.0	 0	 7.0	 0.0; % NG
	3924	 16.0	 0.0	 0.0	 0.0	 1.015874	 100.0	 1	 32.0	 0.0; % PEL
	3925	 27.5	 0.0	 0.0	 0.0	 1.026667	 100.0	 1	 55.0	 0.0; % NG
	3927	 0.0	 1.15	 2.0	 -3.0	 1.015872	 100.0	 0	 7.0	 0.0; % NG
	3939	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 17.2	 0.0; % NG
	3940	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 11.69	 0.0; % NG
	3951	 18.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 36.0	 0.0; % PEL
	3969	 20.5	 0.0	 6.0	 -6.0	 0.975	 100.0	 1	 40.0	 1.0; % NG
	3969	 20.5	 0.0	 6.0	 -6.0	 0.975	 100.0	 1	 40.0	 1.0; % NG
	3968	 20.5	 -5.0	 5.0	 -15.0	 0.975	 100.0	 1	 40.0	 1.0; % COW
	3968	 20.5	 -5.0	 5.0	 -15.0	 0.975	 100.0	 1	 40.0	 1.0; % NG
	3977	 0.0	 0.09	 0.1	 -0.1	 1.000001	 100.0	 0	 2.2	 0.0; % PEL
	3977	 0.0	 0.0	 4.0	 3.9	 1.000001	 100.0	 0	 12.0	 0.0; % NG
	3987	 0.0	 -0.13	 1.0	 -1.0	 1.015872	 100.0	 0	 2.0	 0.0; % PEL
	3987	 0.0	 2.37	 3.0	 -3.0	 1.015872	 100.0	 0	 8.0	 0.0; % NG
	3987	 4.0	 0.0	 3.0	 -3.0	 1.015872	 100.0	 1	 8.0	 0.0; % PEL
	3998	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	3998	 12.4	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 24.8	 0.0; % COW
	4000	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 13.8	 0.0; % COW
	4000	 11.35	 0.0	 0.0	 0.0	 1.022222	 100.0	 1	 22.7	 0.0; % PEL
	4025	 0.0	 0.52	 6.5	 -6.5	 0.999999	 100.0	 0	 10.6	 0.0; % PEL
	4029	 0.0	 0.54	 11.0	 -11.0	 0.9444445	 100.0	 0	 18.0	 0.0; % PEL
	4031	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 30.4	 0.0; % PEL
	4031	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 16.0	 0.0; % NG
	4054	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 26.0	 0.0; % COW
	4055	 13.5	 -2.5	 6.0	 -11.0	 1.015872	 100.0	 1	 27.0	 0.0; % NG
	4055	 13.5	 -2.5	 6.0	 -11.0	 1.015872	 100.0	 1	 27.0	 0.0; % PEL
	4065	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 17.1	 0.0; % NG
	4071	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 2.4	 0.0; % PEL
	4108	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	4125	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.9	 0.0; % NG
	4129	 6.15	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 12.3	 0.0; % NG
	4129	 0.0	 -0.22	 5.0	 -5.0	 0.999999	 100.0	 0	 12.3	 0.0; % NG
	4129	 6.15	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 12.3	 0.0; % NG
	4131	 0.0	 0.72	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	4131	 0.0	 2.0	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	4169	 12.0	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 24.0	 0.0; % PEL
	4198	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % COW
	4198	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	4217	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	4216	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	4231	 6.5	 6.5	 13.0	 0.0	 0.999999	 100.0	 1	 13.0	 0.0; % PEL
	4235	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 16.4	 0.0; % NG
	4244	 21.0	 0.0	 42.0	 -42.0	 1.000001	 100.0	 1	 42.0	 0.0; % PEL
	4245	 9.5	 0.105	 5.21	 -5.0	 1.015872	 100.0	 1	 19.0	 0.0; % NG
	4260	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 15.5	 0.0; % NG
	4260	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 25.7	 0.0; % NG
	4274	 6.0	 0.0	 5.0	 -5.0	 0.975	 100.0	 1	 12.0	 0.0; % NG
	4274	 6.0	 0.0	 5.0	 -5.0	 0.975	 100.0	 1	 12.0	 0.0; % NG
	4275	 0.0	 1.32	 5.0	 -5.0	 1.019107	 100.0	 0	 12.0	 0.0; % COW
	4275	 6.0	 0.0	 5.0	 -5.0	 1.019107	 100.0	 1	 12.0	 0.0; % COW
	4293	 0.0	 -0.5	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	4299	 23.0	 -7.0	 20.0	 -34.0	 0.999999	 100.0	 1	 46.0	 0.0; % NG
	4300	 0.0	 1.83	 3.6	 -3.6	 0.999999	 100.0	 0	 6.0	 0.0; % PEL
	4301	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 1.74	 0.0; % PEL
	4305	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 8.1	 0.0; % PEL
	4309	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 13.8	 0.0; % NG
	4309	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 15.0	 0.0; % NG
	4315	 22.0	 0.0	 25.0	 -25.0	 1.000119	 100.0	 1	 44.0	 0.0; % NG
	4319	 9.0	 0.0	 14.0	 -14.0	 1.000001	 100.0	 1	 18.0	 0.0; % PEL
	4320	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 4.0	 0.0; % NG
	4324	 0.0	 -0.4	 35.0	 -35.0	 1.0111115	 100.0	 0	 58.0	 0.0; % NG
	4326	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 11.0	 0.0; % NG
	4326	 0.0	 2.0	 2.0	 -2.0	 1.0079355	 100.0	 0	 6.0	 0.0; % PEL
	4327	 19.5	 0.0	 24.0	 -24.0	 0.999999	 100.0	 1	 39.0	 0.0; % NG
	4337	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % COW
	4337	 16.5	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 33.0	 0.0; % PEL
	4345	 13.0	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 26.0	 0.0; % NG
	4352	 0.0	 0.0	 1.0	 0.9	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	4371	 7.5	 2.95	 3.0	 2.9	 1.000001	 100.0	 1	 15.0	 0.0; % NG
	4371	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 2.0	 0.0; % PEL
	4376	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 4.0	 0.0; % PEL
	4379	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 16.0	 0.0; % COW
	4384	 0.0	 -0.46	 1.0	 -1.0	 1.015872	 100.0	 0	 2.0	 0.0; % COW
	4384	 0.0	 -0.46	 1.0	 -1.0	 1.015872	 100.0	 0	 2.0	 0.0; % PEL
	4384	 0.0	 -0.46	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	4393	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 13.6	 0.0; % NG
	4413	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 2.6	 0.0; % PEL
	4413	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 17.9	 0.0; % PEL
	4414	 0.0	 0.0	 0.0	 0.0	 1.006081	 100.0	 0	 6.0	 0.0; % NG
	4414	 0.0	 0.0	 0.0	 0.0	 1.006081	 100.0	 0	 10.25	 0.0; % NG
	4415	 0.0	 0.63	 1.0	 -1.0	 1.015872	 100.0	 0	 3.0	 0.0; % PEL
	4431	 0.0	 -0.53	 2.0	 -2.0	 1.0000025	 100.0	 0	 6.0	 0.0; % COW
	4449	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 12.0	 0.0; % NG
	4449	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 4.0	 0.0; % NG
	4451	 13.0	 -0.465	 16.07	 -17.0	 1.0233335	 100.0	 1	 26.0	 0.0; % NG
	4451	 13.0	 -0.465	 16.07	 -17.0	 1.0233335	 100.0	 1	 26.0	 0.0; % NG
	4455	 14.95	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 29.9	 0.0; % NG
	4456	 6.85	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 13.7	 0.0; % COW
	4475	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	4477	 0.0	 0.82	 1.0	 -1.0	 1.0000025	 100.0	 0	 50.0	 0.0; % NG
	4478	 11.85	 0.01	 2.02	 -2.0	 0.975	 100.0	 1	 23.7	 0.0; % COW
	4479	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % NG
	4480	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % PEL
	4481	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % NG
	4482	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % PEL
	4495	 0.0	 1.74	 15.0	 -15.0	 1.0158755	 100.0	 0	 21.4	 0.0; % PEL
	4508	 0.0	 0.2	 16.0	 -14.0	 1.015872	 100.0	 0	 31.0	 0.0; % PEL
	4511	 10.5	 1.1	 6.7	 -4.5	 0.975	 100.0	 1	 21.0	 0.0; % PEL
	4511	 10.5	 1.0	 6.0	 -4.0	 0.975	 100.0	 1	 21.0	 0.0; % NG
	4515	 43.5	 0.43	 26.1	 -25.24	 1.044445	 100.0	 1	 87.0	 0.0; % COW
	4524	 11.0	 0.0	 10.0	 -10.0	 1.006274	 100.0	 1	 22.0	 0.0; % NG
	4524	 11.0	 1.0	 12.0	 -10.0	 1.006274	 100.0	 1	 22.0	 0.0; % PEL
	4538	 0.0	 2.09	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4538	 0.0	 2.09	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4538	 0.0	 2.09	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4538	 0.0	 2.09	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4538	 0.0	 2.09	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4567	 11.0	 0.0	 7.1	 -7.1	 1.0000025	 100.0	 1	 22.0	 0.0; % NG
	4571	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 11.7	 0.0; % NG
	4574	 44.5	 9.0	 27.0	 -9.0	 1.0377785	 100.0	 1	 45.0	 44.0; % NG
	4574	 44.5	 9.0	 27.0	 -9.0	 1.0377785	 100.0	 1	 45.0	 44.0; % PEL
	4582	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	4583	 0.0	 1.16	 10.0	 -10.0	 0.999999	 100.0	 0	 16.8	 0.0; % NG
	4585	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 6.0	 0.0; % NG
	4588	 6.35	 0.0	 5.0	 -5.0	 1.0000025	 100.0	 1	 12.7	 0.0; % NG
	4588	 6.35	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 12.7	 0.0; % PEL
	4623	 18.4	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 36.8	 0.0; % NG
	4634	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % NG
	4635	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % PEL
	4636	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 4.0	 0.0; % NG
	4645	 15.75	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 31.5	 0.0; % PEL
	4646	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 33.0	 0.0; % NG
	4651	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 17.5	 0.0; % PEL
	4657	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 9.0	 0.0; % NG
	4661	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % NG
	4662	 17.5	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 35.0	 0.0; % COW
	4669	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	4669	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 22.0	 0.0; % PEL
	4674	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 3.0	 0.0; % PEL
	4674	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 1.0	 0.0; % NG
	4674	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 5.0	 0.0; % NG
	4674	 3.5	 0.0	 0.1	 -0.1	 0.975	 100.0	 1	 7.0	 0.0; % COW
	4674	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 3.0	 0.0; % PEL
	4686	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 14.0	 0.0; % PEL
	4701	 0.0	 -0.43	 1.0	 -1.0	 1.015872	 100.0	 0	 1.0	 0.0; % PEL
	4701	 0.0	 -0.43	 1.0	 -1.0	 1.015872	 100.0	 0	 1.0	 0.0; % PEL
	4701	 0.0	 -0.43	 1.0	 -1.0	 1.015872	 100.0	 0	 1.0	 0.0; % PEL
	4718	 5.75	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 1	 11.5	 0.0; % NG
	4718	 0.0	 0.8	 1.0	 -1.0	 1.0000025	 100.0	 0	 11.5	 0.0; % PEL
	4719	 0.0	 0.75	 1.0	 0.0	 1.0	 100.0	 0	 11.0	 0.0; % NG
	4719	 0.0	 0.1	 0.1	 -0.1	 1.0	 100.0	 0	 2.5	 0.0; % NG
	4720	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	4721	 5.0	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 10.0	 0.0; % NG
	4721	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % NG
	4721	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % PEL
	4757	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 9.0	 0.0; % NG
	4758	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	4758	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	4759	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	4759	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	4768	 15.0	 0.0	 10.0	 -10.0	 1.0233335	 100.0	 1	 30.0	 0.0; % PEL
	4771	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 3.3	 0.0; % NG
	4778	 0.0	 0.81	 1.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % COW
	4783	 14.0	 0.0	 0.0	 0.0	 1.0000005	 100.0	 1	 28.0	 0.0; % NG
	4789	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 9.2	 0.0; % NG
	4794	 0.0	 -3.06	 8.5	 -8.5	 0.999999	 100.0	 0	 14.0	 0.0; % NG
	4805	 13.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 27.0	 0.0; % NG
	4815	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 20.0	 0.0; % NG
	4818	 3.2	 0.0	 0.64	 -0.64	 1.0158755	 100.0	 1	 6.4	 0.0; % COW
	4819	 8.0	 -0.45	 3.6	 -4.5	 0.975	 100.0	 1	 15.0	 1.0; % NG
	4819	 7.5	 -0.5	 3.0	 -4.0	 0.975	 100.0	 1	 15.0	 0.0; % COW
	4820	 7.5	 -0.5	 3.0	 -4.0	 0.975	 100.0	 1	 15.0	 0.0; % COW
	4820	 8.0	 -0.45	 3.6	 -4.5	 0.975	 100.0	 1	 15.0	 1.0; % NG
	4827	 0.0	 -0.35	 70.0	 -70.0	 0.975	 100.0	 0	 150.0	 0.0; % NG
	4830	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % COW
	4830	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % NG
	4829	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % NG
	4829	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % NG
	4826	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % NG
	4826	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % NG
	4825	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % NG
	4825	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % NG
	4828	 75.0	 0.0	 70.0	 -70.0	 0.975	 100.0	 1	 150.0	 0.0; % NG
	4828	 75.0	 0.0	 70.0	 -70.0	 0.975	 100.0	 1	 150.0	 0.0; % NG
	4827	 75.0	 0.0	 70.0	 -70.0	 0.975	 100.0	 1	 150.0	 0.0; % COW
	4837	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 34.0	 0.0; % COW
	4837	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 24.0	 0.0; % PEL
	4848	 0.0	 -0.14	 5.5	 -5.5	 1.001574	 100.0	 0	 9.0	 0.0; % NG
	4856	 0.0	 1.75	 4.0	 -4.0	 0.9444445	 100.0	 0	 6.4	 0.0; % NG
	4856	 0.0	 1.75	 6.4	 -6.4	 0.9444445	 100.0	 0	 10.8	 0.0; % NG
	4869	 0.0	 -0.38	 6.8	 -6.8	 0.999999	 100.0	 0	 11.2	 0.0; % NG
	4869	 0.0	 4.98	 6.8	 -6.8	 0.999999	 100.0	 0	 11.2	 0.0; % NG
	4876	 0.0	 -0.89	 7.0	 -12.0	 1.033334	 100.0	 0	 22.0	 0.0; % PEL
	4883	 6.4	 0.0	 7.7	 -7.7	 0.999999	 100.0	 1	 12.8	 0.0; % NG
	4887	 17.51	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 35.02	 0.0; % NG
	4887	 10.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 20.0	 0.0; % NG
	4899	 0.0	 -0.0	 0.0	 -1.0	 1.0158755	 100.0	 0	 5.0	 0.0; % NG
	4903	 0.0	 0.0	 9.8	 -9.8	 0.999999	 100.0	 0	 15.9	 0.2; % NG
	4905	 10.8	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 21.6	 0.0; % NG
	4905	 10.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 20.0	 0.0; % COW
	4905	 15.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 30.0	 0.0; % PEL
	4925	 16.0	 2.0	 12.0	 -8.0	 1.015872	 100.0	 1	 32.0	 0.0; % PEL
	4928	 16.5	 0.0	 12.0	 -12.0	 1.0000025	 100.0	 1	 33.0	 0.0; % NG
	4935	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 20.0	 0.0; % NG
	4951	 4.8	 0.0	 6.0	 -6.0	 0.9444445	 100.0	 1	 9.6	 0.0; % NG
	4955	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 4.0	 0.0; % NG
	4966	 11.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 22.0	 0.0; % PEL
	4966	 12.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 24.0	 0.0; % PEL
	4973	 0.0	 0.19	 18.0	 -18.0	 0.999999	 100.0	 0	 30.0	 0.0; % COW
	4973	 15.0	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 30.0	 0.0; % NG
	4986	 16.0	 -1.0	 16.0	 -18.0	 0.999999	 100.0	 1	 32.0	 0.0; % PEL
	4987	 17.55	 -4.5	 12.0	 -21.0	 0.975	 100.0	 1	 35.1	 0.0; % NG
	4988	 17.55	 -4.5	 12.0	 -21.0	 0.975	 100.0	 1	 35.1	 0.0; % PEL
	4989	 17.55	 -4.5	 12.0	 -21.0	 0.975	 100.0	 1	 35.1	 0.0; % NG
	4996	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	4997	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 30.5	 0.0; % NG
	5015	 6.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 12.0	 0.0; % COW
	5015	 10.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.0	 0.0; % NG
	5017	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.7	 0.0; % PEL
	5023	 9.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 18.0	 0.0; % NG
	5027	 18.0	 3.95	 4.0	 3.9	 1.000001	 100.0	 1	 36.0	 0.0; % NG
	5033	 25.3	 0.505	 15.18	 -14.17	 1.0000025	 100.0	 1	 50.6	 0.0; % NG
	5041	 0.0	 -4.79	 11.0	 -11.0	 0.999999	 100.0	 0	 18.0	 0.0; % NG
	5042	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	5044	 0.0	 0.98	 5.0	 -5.0	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	5044	 0.0	 -1.72	 5.0	 -5.0	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	5046	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 24.0	 0.0; % PEL
	5046	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 16.0	 0.0; % PEL
	5050	 0.0	 0.0	 0.0	 0.0	 1.0277795	 100.0	 0	 36.0	 0.0; % PEL
	5052	 0.0	 -0.0	 0.0	 -0.01	 1.0158755	 100.0	 0	 5.6	 0.0; % COW
	5052	 0.0	 -0.0	 0.0	 -0.01	 1.0158755	 100.0	 0	 5.6	 0.0; % PEL
	5058	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 3.0	 0.0; % PEL
	5958	 0.0	 4.64	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	5958	 0.0	 4.64	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	5958	 0.0	 4.64	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	5959	 0.0	 12.49	 125.0	 -125.0	 0.975	 100.0	 0	 670.0	 0.0; % COW
	5959	 0.0	 12.49	 125.0	 -125.0	 0.975	 100.0	 0	 670.0	 0.0; % COW
	5961	 0.0	 0.0	 100.0	 -100.0	 0.975	 100.0	 0	 250.0	 50.0; % NG
	5962	 700.0	 70.0	 470.0	 -330.0	 0.975	 100.0	 1	 1100.0	 300.0; % NUC
	5962	 700.0	 70.0	 470.0	 -330.0	 0.975	 100.0	 1	 1100.0	 300.0; % COW
	5964	 0.0	 -31.4	 60.0	 -60.0	 0.975	 100.0	 0	 200.0	 -20.0; % COW
	5965	 0.0	 -24.96	 60.0	 -60.0	 0.975	 100.0	 0	 200.0	 -20.0; % NG
	5967	 0.0	 0.0	 0.0	 0.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	5967	 0.0	 0.0	 0.0	 0.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	5968	 0.0	 0.69	 0.89	 0.0	 0.975	 100.0	 0	 0.0	 -1.38; % SYNC
	5968	 0.0	 0.69	 0.89	 0.0	 0.975	 100.0	 0	 0.0	 -1.38; % SYNC
	5972	 275.0	 -40.0	 300.0	 -380.0	 0.975	 100.0	 1	 500.0	 50.0; % NG
	5975	 42.62	 -3.655	 25.57	 -32.88	 0.975	 100.0	 1	 85.24	 0.0; % NG
	5975	 42.62	 -3.655	 25.57	 -32.88	 0.975	 100.0	 1	 85.24	 0.0; % NG
	5983	 0.0	 -3.03	 100.0	 -100.0	 0.975	 100.0	 0	 250.0	 -250.0; % COW
	5983	 0.0	 -3.03	 100.0	 -100.0	 0.975	 100.0	 0	 250.0	 -250.0; % NG
	5986	 0.0	 2.57	 40.0	 -40.0	 0.975	 100.0	 0	 30.0	 0.0; % PEL
	5986	 0.0	 2.57	 40.0	 -40.0	 0.975	 100.0	 0	 60.0	 0.0; % NG
	5988	 225.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 450.0	 0.0; % COW
	5988	 225.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 450.0	 0.0; % COW
	5997	 0.0	 95.5	 95.5	 0.0	 0.975	 100.0	 0	 0.0	 -54.0; % SYNC
	5997	 0.0	 95.5	 95.5	 0.0	 0.975	 100.0	 0	 0.0	 -15.0; % SYNC
	6002	 0.0	 -0.04	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6002	 0.0	 -0.04	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6002	 28.5	 0.0	 17.1	 -17.1	 0.975	 100.0	 1	 57.0	 0.0; % NG
	6002	 28.5	 0.0	 17.1	 -17.1	 0.975	 100.0	 1	 57.0	 0.0; % PEL
	6002	 0.0	 -0.04	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6002	 0.0	 -0.04	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6003	 124.61	 0.0	 74.77	 -74.77	 0.975	 100.0	 1	 249.22	 0.0; % NG
	6003	 125.6	 0.0	 75.36	 -75.36	 0.975	 100.0	 1	 251.2	 0.0; % NG
	6003	 198.785	 0.0	 119.27	 -119.27	 0.975	 100.0	 1	 397.57	 0.0; % NG
	6006	 265.45	 0.0	 159.27	 -159.27	 0.975	 100.0	 1	 530.9	 0.0; % NG
	6009	 450.0	 0.0	 280.0	 -280.0	 0.975	 100.0	 1	 600.0	 300.0; % COW
	6010	 250.0	 0.0	 280.0	 -280.0	 0.975	 100.0	 1	 500.0	 0.0; % NG
	6014	 301.5	 66.5	 304.0	 -171.0	 0.975	 100.0	 1	 418.0	 185.0; % COW
	6014	 0.0	 0.0	 304.0	 -171.0	 0.975	 100.0	 0	 418.0	 185.0; % NG
	6014	 0.0	 0.0	 304.0	 -171.0	 0.975	 100.0	 0	 379.0	 230.0; % NG
	6014	 279.0	 98.0	 367.0	 -171.0	 0.975	 100.0	 1	 393.0	 165.0; % COW
	6022	 0.0	 0.11	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6021	 24.95	 -33.13	 14.97	 -81.23	 0.975	 100.0	 1	 49.9	 0.0; % NG
	6023	 127.93	 0.0	 76.76	 -76.76	 0.975	 100.0	 1	 255.86	 0.0; % NG
	6026	 244.255	 0.0	 146.55	 -146.55	 0.975	 100.0	 1	 488.51	 0.0; % NG
	6027	 0.0	 7.0	 7.0	 0.0	 0.975	 100.0	 0	 0.0	 -1.0; % SYNC
	6029	 653.0	 235.0	 570.0	 -100.0	 0.975	 100.0	 1	 1056.0	 250.0; % COW
	6029	 0.0	 0.0	 523.0	 -125.0	 0.975	 100.0	 0	 1056.0	 200.0; % COW
	6029	 304.0	 84.0	 263.0	 -95.0	 0.975	 100.0	 1	 412.0	 196.0; % NG
	6029	 304.0	 72.5	 240.0	 -95.0	 0.975	 100.0	 1	 412.0	 196.0; % NG
	6040	 350.0	 142.5	 400.0	 -115.0	 0.975	 100.0	 1	 600.0	 100.0; % COW
	6045	 0.0	 3.49	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6049	 0.0	 -5.23	 0.38	 -5.35	 0.975	 100.0	 0	 1.26	 0.0; % PEL
	6055	 254.0	 0.0	 152.4	 -152.4	 0.975	 100.0	 1	 508.0	 0.0; % COW
	6058	 543.72	 0.0	 326.23	 -326.23	 0.975	 100.0	 1	 1087.44	 0.0; % COW
	6066	 675.0	 70.0	 355.0	 -215.0	 0.975	 100.0	 1	 1050.0	 300.0; % NUC
	6066	 605.0	 70.0	 355.0	 -215.0	 0.975	 100.0	 1	 910.0	 300.0; % NUC
	6066	 605.0	 70.0	 355.0	 -215.0	 0.975	 100.0	 1	 910.0	 300.0; % COW
	6069	 0.0	 3.49	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6070	 0.0	 0.34	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6083	 0.0	 3.5	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6084	 0.0	 0.21	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6088	 692.5	 0.0	 415.5	 -415.5	 0.975	 100.0	 1	 1385.0	 0.0; % COW
	6089	 0.0	 -2.84	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6090	 110.0	 0.5	 67.0	 -66.0	 0.975	 100.0	 1	 220.0	 0.0; % NG
	6092	 0.0	 0.12	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % NG
	6093	 21.5	 17.55	 48.0	 -12.9	 0.975	 100.0	 1	 43.0	 0.0; % PEL
	6092	 21.5	 -5.55	 12.9	 -24.0	 0.975	 100.0	 1	 43.0	 0.0; % NG
	6092	 11.0	 -8.7	 6.6	 -24.0	 0.975	 100.0	 1	 22.0	 0.0; % COW
	6095	 63.215	 18.535	 75.0	 -37.93	 0.975	 100.0	 1	 126.43	 0.0; % NG
	6094	 11.28	 5.225	 17.22	 -6.77	 0.975	 100.0	 1	 22.56	 0.0; % NG
	6103	 610.835	 0.0	 366.5	 -366.5	 0.975	 100.0	 1	 1221.67	 0.0; % COW
	6104	 225.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 450.0	 0.0; % COW
	6106	 0.0	 -59.9	 0.0	 -59.9	 0.975	 100.0	 0	 0.0	 -103.72; % SYNC
	6113	 131.0	 0.0	 78.6	 -78.6	 0.975	 100.0	 1	 262.0	 0.0; % NG
	6112	 129.0	 0.0	 77.4	 -77.4	 0.975	 100.0	 1	 258.0	 0.0; % NG
	6113	 129.0	 0.0	 77.4	 -77.4	 0.975	 100.0	 1	 258.0	 0.0; % COW
	6112	 0.0	 1.06	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6115	 0.0	 -0.23	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6115	 0.0	 62.77	 63.0	 -0.3	 0.975	 100.0	 0	 1.0	 0.0; % PEL
	6117	 113.33	 27.72	 123.44	 -68.0	 0.975	 100.0	 1	 226.66	 0.0; % NG
	6126	 369.5	 0.0	 221.7	 -221.7	 0.975	 100.0	 1	 739.0	 0.0; % COW
	6130	 0.0	 -296.49	 300.0	 -300.0	 0.975	 100.0	 0	 0.0	 -1656.97; % SYNC
	6132	 3.545	 -1.73	 2.13	 -5.59	 0.975	 100.0	 1	 7.09	 0.0; % NG
	6133	 92.5	 0.0	 55.5	 -55.5	 0.975	 100.0	 1	 185.0	 0.0; % NG
	6133	 94.5	 0.0	 56.7	 -56.7	 0.975	 100.0	 1	 189.0	 0.0; % NG
	6134	 0.0	 3.28	 182.0	 -252.0	 0.975	 100.0	 0	 280.0	 -280.0; % NG
	6134	 0.0	 3.28	 182.0	 -252.0	 0.975	 100.0	 0	 280.0	 -280.0; % NG
	6134	 0.0	 3.28	 182.0	 -252.0	 0.975	 100.0	 0	 280.0	 -280.0; % COW
	6134	 0.0	 3.28	 182.0	 -252.0	 0.975	 100.0	 0	 280.0	 -280.0; % NG
	6139	 228.0	 0.0	 136.8	 -136.8	 0.975	 100.0	 1	 456.0	 0.0; % COW
	6139	 77.0	 2.4	 51.0	 -46.2	 0.975	 100.0	 1	 154.0	 0.0; % NG
	6139	 25.0	 18.0	 51.0	 -15.0	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6139	 46.5	 11.55	 51.0	 -27.9	 0.975	 100.0	 1	 93.0	 0.0; % NG
	6139	 36.5	 14.55	 51.0	 -21.9	 0.975	 100.0	 1	 73.0	 0.0; % PEL
	6146	 0.0	 0.09	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6157	 0.0	 -14.07	 0.0	 -14.07	 0.975	 100.0	 0	 0.0	 -71.42; % SYNC
	6157	 0.0	 -14.07	 0.0	 -14.07	 0.975	 100.0	 0	 0.0	 -71.42; % SYNC
	6158	 0.0	 3.52	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6160	 0.0	 0.09	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6162	 182.035	 0.0	 109.22	 -109.22	 0.975	 100.0	 1	 364.07	 0.0; % NG
	6162	 99.33	 0.0	 59.6	 -59.6	 0.975	 100.0	 1	 198.66	 0.0; % COW
	6165	 93.59	 0.0	 56.15	 -56.15	 0.975	 100.0	 1	 187.18	 0.0; % NG
	6165	 93.59	 0.0	 56.15	 -56.15	 0.975	 100.0	 1	 187.18	 0.0; % NG
	6172	 1427.63	 0.0	 856.58	 -856.58	 0.975	 100.0	 1	 2855.26	 0.0; % NUC
	6173	 0.0	 -2.67	 0.0	 -2.68	 0.975	 100.0	 0	 0.0	 -14.16; % SYNC
	6174	 10.405	 2.585	 11.41	 -6.24	 0.975	 100.0	 1	 20.81	 0.0; % COW
	6174	 10.405	 2.585	 11.41	 -6.24	 0.975	 100.0	 1	 20.81	 0.0; % COW
	6176	 0.0	 3.51	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6179	 0.0	 0.0	 343.0	 -169.0	 0.975	 100.0	 0	 396.0	 223.0; % NG
	6184	 135.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 300.0	 -30.0; % COW
	6188	 147.56	 0.0	 88.54	 -88.54	 0.975	 100.0	 1	 295.12	 0.0; % NG
	6188	 147.56	 0.0	 88.54	 -88.54	 0.975	 100.0	 1	 295.12	 0.0; % COW
	6189	 0.0	 10.23	 10.28	 0.0	 0.975	 100.0	 0	 0.0	 -3.67; % SYNC
	6193	 385.0	 0.0	 300.0	 -300.0	 0.975	 100.0	 1	 770.0	 0.0; % COW
	6193	 385.0	 0.0	 300.0	 -300.0	 0.975	 100.0	 1	 770.0	 0.0; % COW
	6194	 0.0	 62.51	 62.51	 0.0	 0.975	 100.0	 0	 0.0	 -423.35; % SYNC
	6194	 0.0	 62.51	 62.51	 0.0	 0.975	 100.0	 0	 0.0	 -423.35; % SYNC
	6194	 0.0	 62.51	 62.51	 0.0	 0.975	 100.0	 0	 0.0	 -423.35; % SYNC
	6195	 0.0	 3.79	 100.0	 -100.0	 0.975	 100.0	 0	 200.0	 0.0; % NG
	6196	 0.0	 0.09	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6196	 11.64	 -51.01	 6.98	 -109.0	 0.975	 100.0	 1	 23.28	 0.0; % NG
	6212	 0.0	 3.52	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6215	 0.0	 0.0	 355.0	 -215.0	 0.975	 100.0	 0	 910.0	 300.0; % COW
	6216	 0.0	 1.45	 99.0	 -99.0	 0.975	 100.0	 0	 330.0	 0.0; % NG
	6216	 0.0	 1.45	 99.0	 -99.0	 0.975	 100.0	 0	 330.0	 0.0; % NG
	6216	 0.0	 -0.2	 216.0	 -216.0	 0.975	 100.0	 0	 720.0	 0.0; % NG
	6218	 0.0	 -0.08	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % COW
	6218	 0.0	 33.14	 33.23	 0.0	 0.975	 100.0	 0	 0.0	 -343.28; % SYNC
	6218	 125.0	 0.0	 120.0	 -120.0	 0.975	 100.0	 1	 250.0	 0.0; % NG
	6218	 125.0	 0.0	 120.0	 -120.0	 0.975	 100.0	 1	 250.0	 0.0; % NG
	6218	 125.0	 0.0	 120.0	 -120.0	 0.975	 100.0	 1	 250.0	 0.0; % NG
	6218	 0.0	 -0.08	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	6218	 0.0	 -0.08	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	6219	 332.5	 142.5	 400.0	 -115.0	 0.975	 100.0	 1	 665.0	 0.0; % COW
	6221	 45.12	 0.0	 27.07	 -27.07	 0.975	 100.0	 1	 90.24	 0.0; % COW
	6222	 700.0	 70.0	 470.0	 -330.0	 0.975	 100.0	 1	 1100.0	 300.0; % COW
	6226	 47.625	 0.0	 28.58	 -28.58	 0.975	 100.0	 1	 95.25	 0.0; % NG
	6229	 0.0	 -5.95	 0.0	 -6.0	 0.975	 100.0	 0	 0.0	 -87.1; % SYNC
	6229	 0.0	 -5.95	 0.0	 -6.0	 0.975	 100.0	 0	 0.0	 -87.1; % SYNC
	6231	 59.06	 10.09	 55.62	 -35.44	 0.975	 100.0	 1	 118.12	 0.0; % NG
	6231	 59.06	 10.09	 55.62	 -35.44	 0.975	 100.0	 1	 118.12	 0.0; % NG
	6239	 176.54	 0.0	 105.92	 -105.92	 0.975	 100.0	 1	 353.08	 0.0; % NG
	6245	 0.0	 3.41	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6247	 625.0	 -14.0	 515.0	 -543.0	 0.975	 100.0	 1	 970.0	 280.0; % COW
	6247	 285.0	 -44.0	 206.0	 -294.0	 0.975	 100.0	 1	 370.0	 200.0; % NG
	6247	 285.0	 -44.0	 206.0	 -294.0	 0.975	 100.0	 1	 370.0	 200.0; % NG
	6255	 0.0	 0.0	 260.97	 -173.14	 0.975	 100.0	 0	 670.0	 200.0; % COW
	6256	 0.0	 0.0	 269.33	 -111.09	 0.975	 100.0	 0	 700.0	 140.0; % COW
	6257	 11.5	 2.565	 14.0	 -8.87	 0.975	 100.0	 1	 23.0	 0.0; % PEL
	6258	 11.5	 2.565	 14.0	 -8.87	 0.975	 100.0	 1	 23.0	 0.0; % PEL
	6259	 13.5	 4.515	 22.36	 -13.33	 0.975	 100.0	 1	 27.0	 0.0; % PEL
	6260	 43.0	 16.295	 36.04	 -3.45	 0.975	 100.0	 1	 86.0	 0.0; % COW
	6261	 0.0	 1.21	 22.19	 -3.23	 0.975	 100.0	 0	 49.0	 0.0; % PEL
	6262	 62.0	 28.595	 79.63	 -22.44	 0.975	 100.0	 1	 124.0	 0.0; % NG
	6263	 16.0	 1.73	 10.26	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6264	 16.0	 1.73	 10.26	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6265	 16.0	 1.545	 9.89	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6266	 16.0	 1.545	 9.89	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % PEL
	6267	 46.0	 14.82	 59.82	 -30.18	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6268	 46.0	 14.82	 59.82	 -30.18	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6269	 46.0	 17.7	 62.7	 -27.3	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6270	 46.0	 17.7	 62.7	 -27.3	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6271	 46.0	 11.985	 62.7	 -38.73	 0.975	 100.0	 1	 92.0	 0.0; % PEL
	6272	 46.0	 13.135	 62.7	 -36.43	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6273	 593.11	 -42.045	 337.46	 -421.55	 0.975	 100.0	 1	 938.11	 248.11; % COW
	6274	 630.08	 -32.72	 346.45	 -411.89	 0.975	 100.0	 1	 975.08	 285.08; % NUC
	6275	 609.11	 -38.01	 337.68	 -413.7	 0.975	 100.0	 1	 969.11	 249.11; % COW
	6276	 594.11	 -41.905	 337.57	 -421.38	 0.975	 100.0	 1	 939.11	 249.11; % COW
	6278	 204.0	 31.78	 164.82	 -101.26	 0.975	 100.0	 1	 252.0	 156.0; % NG
	6279	 202.0	 31.955	 164.82	 -100.91	 0.975	 100.0	 1	 250.0	 154.0; % NG
	6280	 202.0	 22.52	 101.23	 -56.19	 0.975	 100.0	 1	 250.0	 154.0; % COW
	6281	 213.5	 42.55	 245.17	 -160.07	 0.975	 100.0	 1	 305.0	 122.0; % NG
	6282	 122.0	 17.885	 102.26	 -66.49	 0.975	 100.0	 1	 155.0	 89.0; % NG
	6283	 29.0	 0.375	 21.3	 -20.55	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6284	 29.0	 1.79	 16.07	 -12.49	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6285	 29.0	 0.375	 21.3	 -20.55	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6286	 29.0	 1.79	 16.07	 -12.49	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6287	 29.0	 1.74	 15.97	 -12.49	 0.975	 100.0	 1	 58.0	 0.0; % PEL
	6288	 198.0	 45.885	 173.05	 -81.28	 0.975	 100.0	 1	 263.0	 133.0; % NG
	6289	 69.5	 21.71	 99.9	 -56.48	 0.975	 100.0	 1	 139.0	 0.0; % NG
	6290	 24.5	 4.605	 31.97	 -22.76	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6291	 24.5	 4.57	 31.96	 -22.82	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6292	 16.0	 4.37	 22.37	 -13.63	 0.975	 100.0	 1	 32.0	 0.0; % PEL
	6293	 16.0	 2.37	 20.37	 -15.63	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6294	 16.0	 4.21	 22.21	 -13.79	 0.975	 100.0	 1	 32.0	 0.0; % COW
	6295	 602.1	 161.365	 550.49	 -227.76	 0.975	 100.0	 1	 937.1	 267.1; % NUC
	6296	 601.21	 162.89	 552.32	 -226.54	 0.975	 100.0	 1	 936.21	 266.21; % NUC
	6297	 592.09	 146.155	 517.9	 -225.59	 0.975	 100.0	 1	 917.09	 267.09; % COW
	6298	 591.19	 146.165	 517.99	 -225.66	 0.975	 100.0	 1	 916.19	 266.19; % COW
	6299	 813.0	 218.085	 673.87	 -237.7	 0.975	 100.0	 1	 1308.0	 318.0; % COW
	6300	 813.0	 218.085	 673.87	 -237.7	 0.975	 100.0	 1	 1308.0	 318.0; % COW
	6301	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6302	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6303	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6304	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6305	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6306	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6307	 10.0	 1.615	 10.54	 -7.31	 0.975	 100.0	 1	 20.0	 0.0; % NG
	6308	 833.5	 226.955	 703.47	 -249.56	 0.975	 100.0	 1	 1330.0	 337.0; % COW
	6309	 863.5	 235.535	 712.05	 -240.98	 0.975	 100.0	 1	 1360.0	 367.0; % COW
	6310	 863.5	 235.535	 712.05	 -240.98	 0.975	 100.0	 1	 1360.0	 367.0; % COW
	6311	 45.0	 10.005	 53.82	 -33.81	 0.975	 100.0	 1	 90.0	 0.0; % NG
	6312	 47.5	 10.18	 53.63	 -33.27	 0.975	 100.0	 1	 95.0	 0.0; % NG
	6313	 51.0	 12.17	 53.95	 -29.61	 0.975	 100.0	 1	 102.0	 0.0; % NG
	6314	 1.45	 91.015	 285.21	 -103.18	 0.975	 100.0	 1	 1.5	 1.4; % PEL
	6315	 0.0	 32.44	 109.25	 -44.37	 0.975	 100.0	 1	 240.0	 -240.0; % COW
	6316	 0.0	 33.005	 109.25	 -43.24	 0.975	 100.0	 1	 240.0	 -240.0; % NG
	6317	 584.03	 170.355	 500.95	 -160.24	 0.975	 100.0	 1	 939.03	 229.03; % COW
	6319	 595.06	 190.47	 533.66	 -152.72	 0.975	 100.0	 1	 950.06	 240.06; % COW
	6320	 593.06	 199.795	 552.85	 -153.26	 0.975	 100.0	 1	 948.06	 238.06; % COW
	6321	 953.0	 217.35	 657.68	 -222.98	 0.975	 100.0	 1	 1503.0	 403.0; % COW
	6322	 953.0	 217.35	 657.68	 -222.98	 0.975	 100.0	 1	 1503.0	 403.0; % COW
	6323	 948.0	 -28.08	 390.29	 -446.45	 0.975	 100.0	 1	 1498.0	 398.0; % COW
	6324	 948.0	 -38.82	 368.81	 -446.45	 0.975	 100.0	 1	 1498.0	 398.0; % NUC
	6325	 66.75	 21.35	 93.6	 -50.9	 0.975	 100.0	 1	 125.0	 8.5; % NG
	6326	 66.75	 21.35	 93.6	 -50.9	 0.975	 100.0	 1	 125.0	 8.5; % COW
	6327	 76.2	 35.07	 72.7	 -2.56	 0.975	 100.0	 1	 148.2	 4.2; % COW
	6328	 0.0	 0.0	 328.92	 -51.66	 0.975	 100.0	 0	 685.0	 180.0; % COW
	6329	 460.0	 94.405	 359.66	 -170.85	 0.975	 100.0	 1	 610.0	 310.0; % COW
	6330	 460.0	 55.15	 323.14	 -212.84	 0.975	 100.0	 1	 610.0	 310.0; % PEL
	6332	 0.0	 0.0	 380.92	 -216.75	 0.975	 100.0	 0	 700.0	 205.0; % NG
	6333	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6334	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % PEL
	6335	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6336	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6337	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6338	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6339	 640.0	 196.325	 521.6	 -128.95	 0.975	 100.0	 1	 1000.0	 280.0; % COW
	6340	 640.0	 196.325	 521.6	 -128.95	 0.975	 100.0	 1	 1000.0	 280.0; % COW
	6341	 640.0	 218.295	 566.43	 -129.84	 0.975	 100.0	 1	 1000.0	 280.0; % NUC
	6342	 605.0	 208.07	 565.46	 -149.32	 0.975	 100.0	 1	 930.0	 280.0; % COW
	6343	 28.5	 4.565	 21.89	 -12.76	 0.975	 100.0	 1	 57.0	 0.0; % PEL
	6344	 28.5	 4.565	 21.89	 -12.76	 0.975	 100.0	 1	 57.0	 0.0; % NG
	6345	 0.0	 0.0	 320.29	 -95.56	 0.975	 100.0	 0	 451.0	 239.0; % NG
	6346	 0.0	 0.0	 63.51	 -8.25	 0.975	 100.0	 0	 63.0	 21.0; % NG
	6347	 341.3	 54.86	 274.22	 -164.5	 0.975	 100.0	 1	 433.8	 248.8; % NG
	6348	 577.95	 187.455	 526.72	 -151.81	 0.975	 100.0	 1	 922.95	 232.95; % NUC
	6349	 577.95	 187.455	 526.72	 -151.81	 0.975	 100.0	 1	 922.95	 232.95; % COW
	6350	 584.95	 188.785	 527.48	 -149.91	 0.975	 100.0	 1	 929.95	 239.95; % COW
	6351	 599.96	 191.73	 529.25	 -145.79	 0.975	 100.0	 1	 944.96	 254.96; % COW
	6352	 0.0	 -4.51	 10.38	 -5.76	 0.975	 100.0	 0	 32.0	 0.0; % PEL
	6353	 860.0	 -28.245	 407.48	 -463.97	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	6354	 860.0	 -28.245	 407.48	 -463.97	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	6355	 15.75	 4.47	 22.47	 -13.53	 0.975	 100.0	 1	 31.5	 0.0; % NG
	6356	 32.5	 7.34	 37.34	 -22.66	 0.975	 100.0	 1	 65.0	 0.0; % COW
	6357	 35.0	 0.32	 22.34	 -21.7	 0.975	 100.0	 1	 70.0	 0.0; % NG
	6358	 32.5	 8.95	 53.95	 -36.05	 0.975	 100.0	 1	 65.0	 0.0; % NG
	6359	 32.5	 10.38	 55.38	 -34.62	 0.975	 100.0	 1	 65.0	 0.0; % NG
	6360	 35.0	 9.63	 39.63	 -20.37	 0.975	 100.0	 1	 70.0	 0.0; % NG
	6361	 798.0	 36.21	 566.82	 -494.4	 0.975	 100.0	 1	 1308.0	 288.0; % COW
	6362	 798.0	 36.21	 566.82	 -494.4	 0.975	 100.0	 1	 1308.0	 288.0; % COW
	6363	 0.0	 -1.89	 10.52	 -6.96	 0.975	 100.0	 0	 22.0	 0.0; % NG
	6364	 0.0	 -1.89	 10.52	 -6.96	 0.975	 100.0	 0	 22.0	 0.0; % PEL
	6365	 273.76	 84.835	 286.78	 -117.11	 0.975	 100.0	 1	 458.26	 89.26; % COW
	6366	 18.0	 -1.11	 10.34	 -12.56	 0.975	 100.0	 1	 36.0	 0.0; % NG
	6367	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6368	 607.0	 190.895	 527.89	 -146.1	 0.975	 100.0	 1	 947.0	 267.0; % NG
	6369	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % NG
	6370	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6371	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6372	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6373	 0.0	 0.0	 132.48	 -11.56	 0.975	 100.0	 0	 240.0	 125.0; % NG
	6374	 336.8	 72.235	 271.84	 -127.37	 0.975	 100.0	 1	 456.8	 216.8; % COW
	6375	 195.0	 33.755	 166.41	 -98.9	 0.975	 100.0	 1	 260.0	 130.0; % NG
	6376	 0.0	 0.0	 280.73	 -126.32	 0.975	 100.0	 0	 585.0	 250.0; % NG
	6377	 0.0	 0.0	 287.58	 -119.25	 0.975	 100.0	 0	 585.0	 250.0; % COW
	6379	 28.5	 10.395	 32.55	 -11.76	 0.975	 100.0	 1	 57.0	 0.0; % NG
	6380	 28.5	 10.315	 32.55	 -11.92	 0.975	 100.0	 1	 57.0	 0.0; % PEL
	6381	 8.0	 6.455	 20.13	 -7.22	 0.975	 100.0	 1	 31.0	 -15.0; % NG
	6382	 15.5	 5.97	 33.89	 -21.95	 0.975	 100.0	 1	 31.0	 0.0; % NG
	6383	 9.75	 1.46	 7.83	 -4.91	 0.975	 100.0	 1	 19.5	 0.0; % NG
	6384	 9.75	 1.46	 7.83	 -4.91	 0.975	 100.0	 1	 19.5	 0.0; % COW
	6385	 0.0	 -7.3	 8.32	 -7.73	 0.975	 100.0	 0	 21.0	 0.0; % PEL
	6386	 17.5	 0.905	 9.05	 -7.24	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6387	 17.5	 0.905	 9.05	 -7.24	 0.975	 100.0	 1	 35.0	 0.0; % COW
	6388	 17.5	 -0.15	 11.43	 -11.73	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6389	 17.5	 1.005	 9.25	 -7.24	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6390	 0.0	 0.0	 112.63	 -113.65	 0.975	 100.0	 0	 235.0	 120.0; % NG
	6391	 23.5	 2.41	 10.25	 -5.43	 0.975	 100.0	 1	 47.0	 0.0; % NG
	6392	 23.5	 2.41	 10.25	 -5.43	 0.975	 100.0	 1	 47.0	 0.0; % NG
	6393	 36.5	 10.17	 51.92	 -31.58	 0.975	 100.0	 1	 73.0	 0.0; % PEL
	6394	 34.5	 13.355	 55.2	 -28.49	 0.975	 100.0	 1	 69.0	 0.0; % NG
	6395	 38.0	 11.28	 51.28	 -28.72	 0.975	 100.0	 1	 76.0	 0.0; % COW
	6396	 38.75	 10.505	 51.13	 -30.12	 0.975	 100.0	 1	 77.5	 0.0; % NG
	6397	 15.5	 2.14	 14.95	 -10.67	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	6398	 15.5	 2.14	 14.95	 -10.67	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	6399	 15.5	 2.14	 14.95	 -10.67	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	6400	 25.0	 8.08	 31.73	 -15.57	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6401	 18.5	 3.79	 15.94	 -8.36	 0.975	 100.0	 1	 37.0	 0.0; % PEL
	6402	 18.5	 3.79	 15.94	 -8.36	 0.975	 100.0	 1	 37.0	 0.0; % NG
	6403	 18.5	 3.79	 15.94	 -8.36	 0.975	 100.0	 1	 37.0	 0.0; % NG
	6404	 18.5	 3.79	 15.94	 -8.36	 0.975	 100.0	 1	 37.0	 0.0; % COW
	6405	 193.5	 68.455	 170.47	 -33.56	 0.975	 100.0	 1	 250.0	 137.0; % NG
	6406	 193.5	 68.455	 170.47	 -33.56	 0.975	 100.0	 1	 250.0	 137.0; % NG
	6407	 9.5	 1.75	 10.62	 -7.12	 0.975	 100.0	 1	 19.0	 0.0; % PEL
	6408	 9.5	 1.75	 10.62	 -7.12	 0.975	 100.0	 1	 19.0	 0.0; % NG
	6409	 61.0	 7.46	 25.64	 -10.72	 0.975	 100.0	 1	 122.0	 0.0; % NG
	6410	 310.9	 26.99	 215.24	 -161.26	 0.975	 100.0	 1	 419.9	 201.9; % NG
	6411	 26.0	 10.215	 39.82	 -19.39	 0.975	 100.0	 1	 52.0	 0.0; % PEL
	6412	 26.0	 10.215	 39.82	 -19.39	 0.975	 100.0	 1	 52.0	 0.0; % PEL
	6413	 0.0	 0.0	 104.23	 -23.38	 0.975	 100.0	 0	 185.0	 5.0; % NG
	6414	 0.0	 0.0	 104.23	 -23.38	 0.975	 100.0	 0	 185.0	 5.0; % NG
	6415	 4.5	 69.52	 195.6	 -56.56	 0.975	 100.0	 1	 227.0	 -218.0; % NG
	6416	 4.5	 69.84	 195.94	 -56.26	 0.975	 100.0	 1	 227.0	 -218.0; % NG
	6417	 4.5	 69.84	 195.94	 -56.26	 0.975	 100.0	 1	 227.0	 -218.0; % COW
	6418	 4.5	 69.935	 196.04	 -56.17	 0.975	 100.0	 1	 227.0	 -218.0; % NG
	6419	 32.5	 12.59	 79.87	 -54.69	 0.975	 100.0	 1	 65.0	 0.0; % NG
	6420	 32.5	 12.59	 79.87	 -54.69	 0.975	 100.0	 1	 65.0	 0.0; % PEL
	6421	 593.5	 182.745	 511.82	 -146.33	 0.975	 100.0	 1	 950.0	 237.0; % COW
	6422	 593.5	 193.685	 533.7	 -146.33	 0.975	 100.0	 1	 950.0	 237.0; % COW
	6423	 242.0	 22.125	 194.0	 -149.75	 0.975	 100.0	 1	 316.0	 168.0; % NG
	6424	 149.0	 42.4	 179.42	 -94.62	 0.975	 100.0	 1	 191.0	 107.0; % COW
	6425	 0.0	 0.0	 194.29	 -148.96	 0.975	 100.0	 0	 304.0	 156.0; % NG
	6426	 824.5	 229.315	 671.92	 -213.29	 0.975	 100.0	 1	 1360.0	 289.0; % COW
	6427	 30.5	 2.34	 28.9	 -24.22	 0.975	 100.0	 1	 61.0	 0.0; % NG
	6428	 30.5	 2.34	 28.9	 -24.22	 0.975	 100.0	 1	 61.0	 0.0; % NG
	6429	 17.5	 6.57	 23.24	 -10.1	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6430	 865.0	 235.84	 706.84	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % NUC
	6431	 865.0	 235.84	 706.84	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % COW
	6432	 865.0	 230.335	 695.83	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % COW
	6433	 820.0	 210.31	 681.31	 -260.69	 0.975	 100.0	 1	 1290.0	 350.0; % COW
	6434	 25.9	 13.51	 37.51	 -10.49	 0.975	 100.0	 1	 51.0	 0.8; % NG
	6435	 860.0	 234.135	 675.48	 -207.21	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	6436	 860.0	 234.135	 675.48	 -207.21	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	6437	 0.0	 0.0	 322.12	 -100.08	 0.975	 100.0	 0	 585.0	 175.0; % PEL
	6438	 0.0	 0.0	 322.12	 -100.08	 0.975	 100.0	 0	 585.0	 175.0; % COW
	6439	 393.0	 119.02	 330.12	 -92.08	 0.975	 100.0	 1	 598.0	 188.0; % COW
	6440	 0.0	 0.0	 311.95	 -109.4	 0.975	 100.0	 0	 585.0	 175.0; % COW
	6441	 21.5	 6.31	 33.11	 -20.49	 0.975	 100.0	 1	 43.0	 0.0; % NG
	6442	 21.5	 6.31	 33.11	 -20.49	 0.975	 100.0	 1	 43.0	 0.0; % NG
	6443	 21.5	 6.31	 33.11	 -20.49	 0.975	 100.0	 1	 43.0	 0.0; % PEL
	6444	 40.0	 10.44	 42.66	 -21.78	 0.975	 100.0	 1	 80.0	 0.0; % COW
	6445	 165.0	 16.655	 109.16	 -75.85	 0.975	 100.0	 1	 245.0	 85.0; % NG
	6446	 450.0	 57.26	 230.47	 -115.95	 0.975	 100.0	 1	 605.0	 295.0; % COW
	6447	 28.0	 4.12	 24.74	 -16.5	 0.975	 100.0	 1	 56.0	 0.0; % NG
	6448	 28.0	 4.12	 24.74	 -16.5	 0.975	 100.0	 1	 56.0	 0.0; % NG
	6449	 29.0	 29.66	 61.2	 -1.88	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6450	 11.55	 3.15	 17.15	 -10.85	 0.975	 100.0	 1	 23.1	 0.0; % NG
	6451	 11.55	 3.14	 17.14	 -10.86	 0.975	 100.0	 1	 23.1	 0.0; % PEL
	6452	 335.3	 88.785	 184.29	 -6.72	 0.975	 100.0	 1	 439.8	 230.8; % NG
	6453	 20.5	 2.215	 21.74	 -17.31	 0.975	 100.0	 1	 41.0	 0.0; % NG
	6454	 0.0	 5.19	 18.02	 -6.63	 0.975	 100.0	 0	 80.0	 -80.0; % NG
	6455	 0.0	 9.63	 18.02	 -6.63	 0.975	 100.0	 0	 80.0	 -80.0; % NG
	6456	 0.0	 11.08	 18.02	 -6.63	 0.975	 100.0	 0	 80.0	 -80.0; % NG
	6457	 16.0	 4.57	 19.57	 -10.43	 0.975	 100.0	 1	 32.0	 0.0; % PEL
	6458	 0.0	 -4.17	 19.57	 -10.43	 0.975	 100.0	 0	 32.0	 0.0; % NG
	6459	 16.0	 4.57	 19.57	 -10.43	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6460	 0.0	 -4.17	 19.57	 -10.43	 0.975	 100.0	 0	 32.0	 0.0; % NG
	6461	 0.0	 22.435	 124.73	 -79.86	 0.975	 100.0	 1	 180.0	 -180.0; % NG
	6462	 0.0	 13.035	 116.01	 -89.94	 0.975	 100.0	 1	 180.0	 -180.0; % NG
	6463	 0.0	 22.435	 124.73	 -79.86	 0.975	 100.0	 1	 180.0	 -180.0; % NG
	6464	 0.0	 22.435	 124.73	 -79.86	 0.975	 100.0	 1	 180.0	 -180.0; % COW
	6465	 16.0	 4.095	 27.25	 -19.06	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6466	 0.0	 -3.67	 27.25	 -19.06	 0.975	 100.0	 0	 32.0	 0.0; % PEL
	6467	 14.5	 3.765	 27.25	 -19.72	 0.975	 100.0	 1	 29.0	 0.0; % PEL
	6468	 0.0	 -4.21	 27.25	 -19.06	 0.975	 100.0	 0	 32.0	 0.0; % NG
	6469	 0.0	 -4.0	 27.25	 -19.06	 0.975	 100.0	 0	 32.0	 0.0; % PEL
	6470	 22.0	 4.315	 14.64	 -6.01	 0.975	 100.0	 1	 44.0	 0.0; % NG
	6471	 15.5	 2.94	 19.26	 -13.38	 0.975	 100.0	 1	 31.0	 0.0; % NG
	6472	 15.5	 2.94	 19.26	 -13.38	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	6473	 19.0	 4.36	 27.02	 -18.3	 0.975	 100.0	 1	 38.0	 0.0; % NG
	6474	 19.0	 4.225	 26.96	 -18.51	 0.975	 100.0	 1	 38.0	 0.0; % PEL
	6475	 19.0	 4.225	 26.96	 -18.51	 0.975	 100.0	 1	 38.0	 0.0; % NG
	6476	 33.0	 7.725	 41.08	 -25.63	 0.975	 100.0	 1	 66.0	 0.0; % NG
	6477	 42.0	 15.305	 54.62	 -24.01	 0.975	 100.0	 1	 84.0	 0.0; % NG
	6478	 42.0	 15.305	 54.62	 -24.01	 0.975	 100.0	 1	 84.0	 0.0; % NG
	6479	 0.0	 -2.17	 26.24	 -3.76	 0.975	 100.0	 0	 33.0	 0.0; % PEL
	6480	 40.5	 11.12	 51.12	 -28.88	 0.975	 100.0	 1	 81.0	 0.0; % PEL
	6481	 40.5	 11.12	 51.12	 -28.88	 0.975	 100.0	 1	 81.0	 0.0; % COW
	6482	 40.5	 11.12	 51.12	 -28.88	 0.975	 100.0	 1	 81.0	 0.0; % COW
	6483	 40.5	 11.12	 51.12	 -28.88	 0.975	 100.0	 1	 81.0	 0.0; % NG
	6484	 65.0	 6.33	 30.84	 -18.18	 0.975	 100.0	 1	 130.0	 0.0; % COW
	6485	 807.0	 215.91	 671.48	 -239.66	 0.975	 100.0	 1	 1332.0	 282.0; % COW
	6486	 807.0	 215.91	 671.48	 -239.66	 0.975	 100.0	 1	 1332.0	 282.0; % NUC
	6487	 217.5	 91.59	 168.9	 14.28	 0.975	 100.0	 1	 285.0	 150.0; % NG
	6488	 410.0	 53.715	 204.97	 -97.54	 0.975	 100.0	 1	 595.0	 225.0; % COW
	6489	 285.0	 60.695	 140.69	 -19.3	 0.975	 100.0	 1	 443.0	 127.0; % NG
	6490	 285.0	 62.485	 144.35	 -19.38	 0.975	 100.0	 1	 443.0	 127.0; % COW
	6491	 25.0	 1.74	 27.73	 -24.25	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6492	 25.0	 1.74	 27.73	 -24.25	 0.975	 100.0	 1	 50.0	 0.0; % COW
	6493	 15.0	 4.19	 21.62	 -13.24	 0.975	 100.0	 1	 30.0	 0.0; % NG
	6494	 15.0	 4.19	 21.62	 -13.24	 0.975	 100.0	 1	 30.0	 0.0; % NG
	6495	 42.5	 19.785	 57.42	 -17.85	 0.975	 100.0	 1	 85.0	 0.0; % NG
	6496	 0.0	 0.0	 50.12	 -14.95	 0.975	 100.0	 0	 58.0	 55.0; % NG
	6497	 589.89	 197.89	 545.1	 -149.32	 0.975	 100.0	 1	 949.89	 229.89; % COW
	6498	 592.89	 198.435	 545.34	 -148.47	 0.975	 100.0	 1	 952.89	 232.89; % COW
	6499	 24.5	 0.785	 21.77	 -20.2	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6500	 24.5	 0.785	 21.77	 -20.2	 0.975	 100.0	 1	 49.0	 0.0; % PEL
	6501	 24.5	 0.785	 21.77	 -20.2	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6502	 78.0	 32.39	 112.39	 -47.61	 0.975	 100.0	 1	 156.0	 0.0; % NG
	6503	 49.5	 -5.525	 22.91	 -33.96	 0.975	 100.0	 1	 99.0	 0.0; % NG
	6504	 49.5	 -5.525	 22.91	 -33.96	 0.975	 100.0	 1	 99.0	 0.0; % NG
	6505	 630.0	 121.775	 405.58	 -162.03	 0.975	 100.0	 1	 985.0	 275.0; % NG
	6506	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	6507	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	6508	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	6509	 0.0	 0.0	 102.61	 -26.72	 0.975	 100.0	 0	 185.0	 72.0; % NG
	6510	 0.0	 0.0	 102.61	 -24.82	 0.975	 100.0	 0	 185.0	 72.0; % NG
	6511	 0.0	 0.0	 102.61	 -24.82	 0.975	 100.0	 0	 185.0	 72.0; % NG
	6512	 0.0	 19.4	 89.4	 -50.6	 0.975	 100.0	 1	 64.0	 -64.0; % PEL
	6513	 0.0	 19.4	 89.4	 -50.6	 0.975	 100.0	 1	 64.0	 -64.0; % NG
	6514	 0.0	 19.4	 89.4	 -50.6	 0.975	 100.0	 1	 64.0	 -64.0; % NG
	6515	 203.0	 30.365	 148.09	 -87.36	 0.975	 100.0	 1	 268.0	 138.0; % NG
	6516	 203.0	 30.365	 148.09	 -87.36	 0.975	 100.0	 1	 268.0	 138.0; % NG
	6517	 90.0	 27.8	 97.8	 -42.2	 0.975	 100.0	 1	 180.0	 0.0; % NG
	6518	 68.0	 43.88	 133.88	 -46.12	 0.975	 100.0	 1	 136.0	 0.0; % NG
	6519	 64.0	 38.95	 123.95	 -46.05	 0.975	 100.0	 1	 128.0	 0.0; % NG
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	  13.409395	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.107344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.925525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.484465	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.925421	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.288203	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.056805	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.340978	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.662206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.703933	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.557087	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.026509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.735298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.571794	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  95.370382	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.662993	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.880796	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.733966	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.732519	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.970101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.646350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.566193	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.544217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.679418	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.393878	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.830882	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.424725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.272820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.460903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.749890	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.262547	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.213206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.985309	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 129.405681	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.334698	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.436639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.318814	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.856054	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.508935	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.816967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.577782	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.074195	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.067002	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.040562	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.319622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.375829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.804258	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.429469	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.720694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  62.366023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.750649	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.509795	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.781153	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.846763	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.198164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.720127	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.320585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.326679	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.168862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.147421	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.203379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.475949	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.895622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.682197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.201272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.185353	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.709576	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	 107.154842	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.126708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.200206	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.028681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.214731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.226922	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.113676	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.856160	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.708099	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.648630	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.902368	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.157163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.281249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.373446	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.380567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.429155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.641328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.065015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.884585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.611076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.038261	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.423740	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.214475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.270388	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.720652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.404552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.607197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.430596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.733430	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.624427	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.340402	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.111380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.429814	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.846056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.485381	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.025122	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.402417	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.537009	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.144639	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.740858	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.382454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.286070	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.753632	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.144417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.051989	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.320952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.421884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.588389	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.298354	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.050420	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.665482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.428964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.844648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.664680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.314561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.424900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.476686	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.031232	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.394024	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.417268	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.530774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.789937	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.642733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.248529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.815061	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.672977	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.982832	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.150494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.341177	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.658011	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.745883	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.889667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.415985	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.729573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.351772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.527648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.460931	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.399727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.369194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.996049	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.670952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.871201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.579564	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.576855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.550069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.795537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.559824	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.215905	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.716487	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.225307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.888565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.351447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.291115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.264681	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.478238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.955760	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.397864	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.479741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.477258	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.034318	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.116001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.700924	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.090042	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.103190	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.049675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  91.065151	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.340308	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.447435	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.460049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.209898	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.100324	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.687083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.028476	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.973804	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.873140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.666793	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.564503	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.867748	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.015386	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.300428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.832710	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.391841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.701407	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.477873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.478832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.474634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.431478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.338369	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.619040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.186506	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.393834	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.711325	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.629677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.508800	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.191720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.203298	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.901410	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.094642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.334139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.775339	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.203011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.167839	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.591146	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.582435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.254207	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.292378	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.306703	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.957279	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.235539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.657372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.563691	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.080953	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.530629	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.899592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.810959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.738827	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.495725	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.576543	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.884377	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  60.482135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.379420	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.228426	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.173689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.230452	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.885340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.997249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.342953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.656893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.582971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.957755	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.436618	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.715020	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.090078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.100909	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.204683	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.693791	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.911136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.506774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.327036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.507609	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.561117	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.818261	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.548349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.890898	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.127483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.950753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.520038	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.745572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.604960	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.410679	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.370264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.335249	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.098831	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.497461	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.030861	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.443734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.360172	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.000447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.007224	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.425230	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.877074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.194253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.064731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.951829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.914779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.516261	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.929788	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.252891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.764651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.943136	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.210595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.373231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.654882	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.143823	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.803197	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.328351	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.888357	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.023300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.570682	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.450002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.677847	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.947272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.855856	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.633248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.768418	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.594573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.161428	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.682171	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.075103	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.932577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.022043	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.788517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.801366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.766909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.887321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.530475	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.591726	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.489844	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.394166	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.050036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.453018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.314189	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.140979	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.233340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.212122	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.980492	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.198384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.694313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.969701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.809887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.259587	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.145117	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.579227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.246384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.668743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.546928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.573984	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.559870	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.003408	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.555591	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.493929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.546466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.699467	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.930220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.214161	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.793600	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.677016	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.279721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.203803	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.277096	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.988508	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.046501	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  87.867183	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.915957	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.954676	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.332116	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.129835	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.482488	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.165023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.618840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.252574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.242819	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.016307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.057857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.634891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.330194	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.608156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.836012	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.222938	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.298519	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.305333	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.968027	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.553672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.254570	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.512162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.981176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.778365	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.635649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.244657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.649829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.608964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.522766	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.737107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.002204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.228574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  87.946720	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.374699	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.077660	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.828307	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.415877	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.985842	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.680257	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 132.992010	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.284656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.117022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.731237	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.027326	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.498381	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.206225	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.791574	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.458259	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.453446	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.231003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.726605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.054287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.096422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 142.396153	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.258257	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 132.812963	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.195322	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.085268	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.738844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.083589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.987370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.423215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.173746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.973984	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.133092	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.156126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.457558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.909986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.030400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.477682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.752850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.257780	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.664342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.016299	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.591765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.834003	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.779683	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.992769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.001940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.163640	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.636853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.056349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.314298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.220210	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.118768	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.966395	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.643072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.230409	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  79.873659	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.970870	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.951735	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.716204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.562370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.262889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.075473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.873959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.977629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.934364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.534616	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.087676	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.063487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.036805	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.501244	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.615083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.096763	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.075229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.585088	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.442102	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.336006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.611434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.541182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.994339	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.369056	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.140511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.039636	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.283436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.812945	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.381001	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.999555	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.793589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.034659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.958201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.757569	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.573418	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.856919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.863442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.778285	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.371334	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 132.304749	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.238784	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.712329	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.411533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.235834	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.678159	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.986275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.101191	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.940327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.936138	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.870301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.055725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.094880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.088855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.844626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  91.651474	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.910346	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.137484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.662349	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.442180	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.067685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.403664	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.252690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.176013	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.684856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.704915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.833542	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.011733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.578515	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.936541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.119867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.082401	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.875805	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.514136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.054942	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.356323	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.125745	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.763824	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.598361	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.103836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.758633	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.634329	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  60.156886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.519102	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.626391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.604014	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.782723	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.842731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.488424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.982146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.721414	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.388357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.330401	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.293347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.344515	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.118607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.591469	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.173667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.848404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.050154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.303826	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.134569	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 131.047825	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.810944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.516402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.492493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.565469	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.740371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.828599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.112175	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.000553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.224770	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 131.143234	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.832805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.781425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.462695	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.996771	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.412682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.984530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.937526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.409948	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   2.773901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.888444	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.070890	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.684172	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.184906	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.117078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.892831	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.621534	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.022309	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.578875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.187552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.984763	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.408667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.796642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.842329	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.121934	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.557126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.873917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  63.838770	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.729738	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.248189	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.428198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.951411	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.078330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.041985	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.776510	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.036011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.434125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.973732	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.236889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.697549	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.036768	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.580108	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.201187	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.845111	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.684726	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.390284	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.242948	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.234341	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.030544	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.343663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.151967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.903992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.434673	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.997241	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.971616	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.729029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.472129	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  91.830686	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.019230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.437747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.515295	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.371401	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.950602	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.667904	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.653127	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.979663	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.884418	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.014577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.886769	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.229170	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.235350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.832643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.360405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.584264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.643940	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.036634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.744405	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.927603	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.515969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.291911	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.450004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.519967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.280505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.981680	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.758281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.628250	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.073518	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 127.297401	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.196456	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.109404	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.900478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.463058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.977790	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   5.603681	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.874643	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.509363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.946454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 132.093485	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.995656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.229621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.000222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.126599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.964981	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.929260	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.182546	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.780403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.452193	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.823285	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.755694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.096642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.002534	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.343147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.338693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.862117	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.672519	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.566337	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.991897	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.114526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.799273	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.597611	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.733306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.124107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.266436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.532070	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.511177	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.918494	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.384081	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.012240	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.789504	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.122247	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.058303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.020239	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.284906	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.465970	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  23.560598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.224425	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.217556	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.346851	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.128600	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.542914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.277542	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  91.151849	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.483356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.006589	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.771989	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.521626	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.189114	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.605150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.458808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.548011	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.031999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.696658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.525638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.126097	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.677476	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.175963	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.056306	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.239527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.849513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.164934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.914629	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.409430	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.149599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.448171	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.774984	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.492725	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.110998	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.993674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.941763	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.264305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.776570	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.176165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.038434	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.581688	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.484247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.930310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.860449	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.125178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.893913	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.404940	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.594800	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.639275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.214935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.560314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.518702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.344217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.729776	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  96.613906	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.762502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.212808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.441990	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.758440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.606762	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.202609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.301659	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 128.097226	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.895615	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.878541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.766744	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.998603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.050809	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.266400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.534363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.182099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.407438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.581042	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.453936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.894102	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.449056	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.467046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.179315	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.707343	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.028400	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.454632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.087422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.784269	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.168092	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.128895	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.836218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.357581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.604055	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.356194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.974452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.060551	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.928791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.987214	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.799969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.691382	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.647624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.165037	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.794903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.399642	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.730830	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.457660	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 130.162855	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.011328	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.326491	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.843786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.029653	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  59.098897	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.681216	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.757255	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.736391	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  60.842390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.946265	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.183981	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.182153	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.067412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.129050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.727139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.709462	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.102670	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.215268	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.172080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.784888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.423083	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.951199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.713653	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.172953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.462826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.138878	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.626231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.188707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.867097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.714467	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.941605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.708773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.891348	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.410407	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.295450	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.557950	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.292692	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.344679	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.074041	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.763911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.297262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.230256	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.487832	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.236866	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.240428	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.195300	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.432100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.110017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.141931	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.348422	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.336293	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.820388	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.063570	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.481790	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.658776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.904719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.434151	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.611827	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.387026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.498497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.725262	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.422684	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.938652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.016399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.601049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.669483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.979243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.399376	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.432021	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.223839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.807603	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.599499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.541847	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.584722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 134.093034	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.452783	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.895698	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.473724	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.663303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.180523	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.317053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  87.311751	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.424943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.315193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.327332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.946526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.170061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.939708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.403741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.496049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.821032	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.078930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.588747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.518375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.145729	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.198156	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.885104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.972941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.321572	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.824481	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.470211	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.683656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.089034	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.192064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.307481	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.502348	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.661833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.769854	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.092646	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.053502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.230912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.297054	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 121.944271	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.005987	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.674022	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  90.606511	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.114673	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.412387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.481403	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.217215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.995089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.276141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.239354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.905108	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.271630	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.236265	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.524927	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.370355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.508118	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.507727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.126471	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.815779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.842764	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.922411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.629514	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.759047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.805174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.797119	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.076438	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.998199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.280951	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.317201	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.028014	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.961231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.232676	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.576203	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.034205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.368197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.115238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.834282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.461969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.494226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.644484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.040247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.675980	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.777680	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.827025	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.975877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.436034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.197805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.327023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.487947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.183247	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.584862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.627357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.810273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.591838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.547239	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.148038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.261002	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.637688	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.550322	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.474205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.728126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.178231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.206766	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.590229	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.738870	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.038409	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.119694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.954983	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.185798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.003316	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.427875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.818344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.626478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.470062	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.900642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.901649	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.081828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.499706	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.509292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.204544	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.337405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.233394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.328747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.908254	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  91.859019	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.068550	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.276446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.155005	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.937581	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.983848	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.359390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.294916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.661291	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.155565	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.261964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.360736	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  15.456209	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.822587	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.955951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.457274	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.976983	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  46.524421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.426367	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.935722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.854269	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.272046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.288111	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.416492	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.352823	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.279173	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  11.546813	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.412931	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.044742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.062908	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.645723	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.916325	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.291975	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.557200	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.348995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.076469	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.310369	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.799936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.104540	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   3.710323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.488089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.482566	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.325950	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.703622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.924096	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.483339	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  28.249777	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.566458	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.879577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.407560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.679877	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.905055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.368899	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.388362	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.587718	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.533809	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   8.179185	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  17.293161	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.067466	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.217931	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.055755	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.280011	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.329686	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.322942	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.242550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.487800	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.008161	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.461560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.537918	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.048027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.493327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.741400	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.909545	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  34.944511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.190534	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.357769	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.158758	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.715634	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.108124	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.737197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.383542	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  45.527668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.869486	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.338326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.228686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.736391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.294214	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.471560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.900160	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.355315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.573015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.803966	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.576680	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.224931	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  33.845675	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.298045	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.005671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.626186	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.377865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.220795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.185466	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  32.791371	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.484005	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.962264	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.651446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.615635	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.392413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.408417	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  30.296273	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.671055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  27.808800	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.072308	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.558300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.045676	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.350118	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.435259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.744821	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.826439	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.941021	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  37.392385	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.452618	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.318543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.637298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.213303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.887254	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.371294	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.533452	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.292861	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  44.939248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.733569	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.665120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.574762	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.158624	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.782653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.972006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.718091	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.319259	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  98.086271	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.944503	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.785290	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.590448	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 124.514858	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.680873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.459182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.357163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.985230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.091361	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.545577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.045286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.826650	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.805715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.766079	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.064217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.899228	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.562757	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.806872	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.620487	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.324249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.807982	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.885046	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.600078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.444267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.343668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.380677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.979182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.896747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.721467	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.029918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.640809	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.591128	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.166570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.033995	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.373785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.652827	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.171723	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   6.339420	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  30.388643	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.473227	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.721413	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.806967	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.075307	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.389712	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.121470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.624913	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.026216	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.290205	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.220209	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.836569	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.294370	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.800176	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  58.589032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.021794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.775292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.864325	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.182948	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.080035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.679994	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.265817	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.481165	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.714461	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.876874	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.315143	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.667799	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  36.626034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.411423	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.758901	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.762641	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.518810	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.203368	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.203226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.314280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.285942	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.622530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.167096	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.956757	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.626631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.826078	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.234610	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.257433	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  31.414659	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 121.489119	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.677505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.997120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.983049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.890435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.187889	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  15.636326	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.705972	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.011599	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.291800	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.952295	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.962309	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.074235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.403250	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.642843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.459517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.897639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.521812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.282820	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.991229	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.414717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.731178	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.064594	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.278627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.426860	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.305975	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.219516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.867981	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.890417	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.615060	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.600144	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.502302	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.826732	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.944022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.384199	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.521047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.416944	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.850076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.196640	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.485248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.463813	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  88.091019	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.153126	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.201752	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.103436	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.735019	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.147275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.618614	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.850451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.856146	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.917709	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.573574	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.963013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.918869	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.554256	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.955866	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.183827	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.275183	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.202023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.722036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.695132	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.306487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.890262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.739291	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.877167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.596138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.167443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.640630	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.060257	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.842797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.605474	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.022370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.549218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.149017	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.930655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.932632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.075538	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.387692	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.655756	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.973294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.907234	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.424809	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.340641	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.588453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.358937	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.478742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.194995	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  29.487763	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.207639	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.587337	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.264224	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.163592	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.175895	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.867276	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.192361	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.474540	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.897254	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.661495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.512811	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 133.903546	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.765386	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.984138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.120074	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.893610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.513960	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.342276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.152144	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 131.617141	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.896535	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.545141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.509007	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.084950	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.046148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.059552	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.049705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.377012	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.632164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.793140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.119119	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.992475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.616559	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.240601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.479076	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.824742	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.886631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.686027	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.281529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.576722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.054800	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.733114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.278278	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.211190	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.436217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.141053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.337430	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.234871	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.615460	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.116878	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.665077	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.941239	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.701508	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.831188	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.375811	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  48.637386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.133331	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.594177	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.265628	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.661982	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.620577	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.958304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.858462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.899184	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.894826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.358258	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.242383	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.782455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.799606	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.514222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.341166	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.150142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.271373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.355596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.907765	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.807453	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.045544	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.694302	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.192539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.266287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.964271	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.224896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.145450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.275681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.032415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.410582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.094582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.749510	   0.000000; % NG
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	4647	 1	 0.005726	 0.010482	 0.0	 2186	 2186	 2186	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 1	 0.01284	 0.025679	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 2	 0.005799	 0.010615	 0.0075	 2441	 2441	 2441	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 3	 0.134039	 0.309398	 0.0035	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	2303	 3	 0.049131	 0.133283	 0.0015	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	700	 4	 0.025926	 0.109136	 0.0002	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 4	 0.05	 0.126914	 0.0006	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5046	 4	 0.02321	 0.097407	 0.0016	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 5	 0.040564	 0.113631	 0.0013	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 6	 0.006047	 0.020912	 0.0222	 1398	 1398	 1398	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 7	 0.012472	 0.032099	 0.0061	 884	 884	 884	 0.0	 0.0	 1	 -30.0	 30.0;
	2466	 8	 0.002607	 0.017462	 0.0324	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 9	 0.053893	 0.14258	 0.0017	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 10	 0.000247	 0.001235	 0.0005	 24078	 24078	 24078	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 10	 0.000247	 0.001235	 0.0002	 24078	 24078	 24078	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 11	 0.039753	 0.100988	 0.0047	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 11	 0.037654	 0.096173	 0.001	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	2181	 12	 0.014613	 0.060721	 0.0008	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 12	 0.034064	 0.121139	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 12	 0.000242	 0.000442	 0.0004	 60355	 60355	 60355	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 13	 2.1e-05	 0.000125	 0.1386	 737.0	 737.0	 737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 13	 0.000145	 0.001877	 0.0635	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 13	 0.000319	 0.003234	 0.0838	 1841.0	 1841.0	 1841.0	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 13	 2.1e-05	 0.000125	 0.1386	 737.0	 737.0	 737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 14	 0.04	 0.134198	 0.0274	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	2874	 14	 0.012222	 0.052346	 0.0026	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 14	 0.007284	 0.045432	 0.0024	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	4955	 14	 0.059963	 0.154222	 0.0236	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 14	 0.018025	 0.110988	 0.0073	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	2874	 14	 0.012222	 0.052593	 0.0032	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 14	 0.007284	 0.044938	 0.0024	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 15	 0.037541	 0.100529	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 15	 0.090199	 0.211388	 0.0023	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	4455	 15	 0.09801	 0.267574	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 16	 0.071806	 0.191484	 0.0019	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	337	 16	 0.119174	 0.284958	 0.0044	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 17	 0.022346	 0.061111	 0.0029	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	3727	 18	 0.009383	 0.019753	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 19	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3727	 20	 0.001975	 0.004444	 0.0	 5369	 5369	 5369	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 21	 0.036296	 0.099012	 0.0045	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	1598	 21	 0.032716	 0.089136	 0.0057	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	1843	 22	 0.138574	 0.351474	 0.0058	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5023	 22	 0.094407	 0.210456	 0.0044	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	1157	 23	 0.047115	 0.117158	 0.001	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	2703	 23	 0.039557	 0.120937	 0.0132	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	3425	 23	 0.022676	 0.062484	 0.0007	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 24	 0.064568	 0.16716	 0.0113	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 24	 0.048605	 0.128481	 0.0062	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 25	 0.004815	 0.02963	 0.0016	 1048	 1048	 1048	 0.0	 0.0	 1	 -30.0	 30.0;
	2093	 25	 0.007309	 0.04463	 0.0073	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	612	 26	 0.034321	 0.145802	 0.0073	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1866	 26	 0.004815	 0.009753	 0.0005	 2731	 2731	 2731	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 26	 0.049012	 0.133704	 0.0063	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 26	 0.04642	 0.126543	 0.0058	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	3339	 26	 0.046296	 0.125926	 0.006	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4632	 26	 0.053704	 0.136753	 0.0065	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 26	 0.03358	 0.120988	 0.0062	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 27	 0.006163	 0.041067	 0.0759	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2350	 27	 0.000652	 0.004369	 0.0081	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 28	 0.050945	 0.131922	 0.0015	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 28	 0.058781	 0.149005	 0.0017	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	2887	 29	 0.067019	 0.137566	 0.0037	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 29	 0.032754	 0.088939	 0.0039	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 29	 0.030184	 0.080096	 0.0053	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 30	 0.066049	 0.187778	 0.0099	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	1553	 30	 0.065062	 0.133704	 0.0062	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4841	 30	 0.041728	 0.106049	 0.005	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 31	 0.009574	 0.03875	 0.0114	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	3162	 31	 0.000171	 0.000313	 0.0002	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3692	 31	 0.034266	 0.09423	 0.001	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 31	 0.006803	 0.028219	 0.0	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 31	 0.008566	 0.037541	 0.0121	 767	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	3729	 32	 0.009733	 0.034089	 0.0185	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 34	 0.000277	 0.002015	 0.003	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1017	 33	 0.00881	 0.033995	 0.0607	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1158	 33	 0.004642	 0.019832	 0.0354	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2580	 34	 0.008861	 0.03506	 0.0623	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 34	 0.006993	 0.032869	 0.0557	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4746	 33	 0.002173	 0.008731	 0.0152	 3441	 3441	 3441	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 34	 0.00077	 0.003121	 0.0051	 9629	 9629	 9629	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 33	 0.004109	 0.016138	 0.0284	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	368	 35	 8.3e-05	 0.000907	 0.0202	 1034.0	 1034.0	 1034.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 35	 0.000552	 0.006726	 0.0939	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 35	 0.000512	 0.008012	 0.2455	 2462.0	 2462.0	 2462.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3135	 35	 0.001107	 0.00918	 0.1906	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 36	 6.2e-05	 0.000741	 0.0173	 1095.0	 1095.0	 1095.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 35	 0.000512	 0.008019	 0.2455	 2462.0	 2462.0	 2462.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 36	 0.001153	 0.013123	 0.1841	 1433.0	 1433.0	 1433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 37	 0.055933	 0.120685	 0.0013	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 37	 0.039053	 0.084404	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 38	 0.00252	 0.006551	 0.0001	 4462	 4462	 4462	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 39	 0.009877	 0.042222	 0.0021	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 39	 0.024815	 0.063086	 0.0029	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 39	 0.009877	 0.042222	 0.0021	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	2251	 40	 0.056173	 0.142593	 0.0066	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 40	 0.034444	 0.109012	 0.0076	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	430	 41	 0.000158	 0.000672	 0.0719	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 41	 4.5e-05	 8.9e-05	 0.002	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1484	 42	 0.01096	 0.020063	 0.009	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 42	 0.002268	 0.008818	 0.0099	 3668	 3668	 3668	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 43	 0.001481	 0.006296	 0.0039	 4689	 4689	 4689	 0.0	 0.0	 1	 -30.0	 30.0;
	3488	 44	 0.050617	 0.137012	 0.009	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 44	 0.074326	 0.194507	 0.0021	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 45	 0.000247	 0.000741	 0.0	 38027	 38027	 38027	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 46	 0.049131	 0.134039	 0.001	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 46	 0.033258	 0.090955	 0.001	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 46	 0.067437	 0.123442	 0.001	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 47	 0.037289	 0.118166	 0.001	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 48	 0.021358	 0.057037	 0.0005	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 49	 0.071303	 0.180902	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	2345	 49	 0.071554	 0.18191	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 50	 0.028193	 0.104535	 0.0013	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 50	 0.055404	 0.171429	 0.01	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3553	 50	 0.010834	 0.071554	 0.001	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	4629	 50	 0.013857	 0.030234	 0.0003	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	3553	 50	 0.011414	 0.070648	 0.0009	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	4629	 50	 0.013757	 0.030108	 0.0003	 900	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	1196	 51	 0.00478	 0.028622	 0.0547	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1197	 51	 0.00478	 0.028583	 0.0547	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 52	 0.01284	 0.032716	 0.0015	 846	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	5489	 52	 0.014198	 0.036049	 0.0016	 767	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 53	 0.005291	 0.021668	 0.0003	 1285	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	2769	 54	 0.01358	 0.047654	 0.0023	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	373	 55	 0.000257	 0.000514	 0.0294	 53862	 53862	 53862	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 56	 0.000257	 0.002153	 0.2147	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 56	 0.000277	 0.000869	 0.0931	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 57	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 58	 0.000237	 0.00083	 0.1863	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 58	 0.000178	 0.000612	 0.1377	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 59	 0.030486	 0.076342	 0.002	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 59	 0.011086	 0.024691	 0.0015	 1124	 1124	 1124	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 60	 0.044344	 0.170572	 0.0021	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	3525	 60	 0.036709	 0.151776	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 61	 0.017788	 0.048551	 0.0006	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 61	 0.057521	 0.145251	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 62	 0.014109	 0.057949	 0.0029	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	2950	 62	 0.007055	 0.02973	 0.0014	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	371	 63	 0.024263	 0.065911	 0.0007	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 63	 0.020912	 0.059209	 0.0016	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 64	 0.002568	 0.011753	 0.0203	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 64	 0.002568	 0.011615	 0.0228	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 65	 0.006299	 0.033585	 0.0599	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 65	 0.006299	 0.033661	 0.06	 889	 889	 889	 0.0	 0.0	 1	 -30.0	 30.0;
	1546	 66	 0.102293	 0.226757	 0.0025	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 66	 0.177551	 0.405291	 0.0046	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	3249	 66	 0.088264	 0.161566	 0.0017	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 67	 0.007307	 0.014613	 0.0002	 1862	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 68	 0.067775	 0.139834	 0.001	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 68	 0.047367	 0.16125	 0.0021	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5151	 68	 0.004031	 0.016629	 0.001	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 69	 0.073066	 0.205089	 0.0022	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 70	 4.8e-05	 8.8e-05	 0.0001	 303410	 303410	 303410	 0.0	 0.0	 1	 -30.0	 30.0;
	2165	 71	 0.000252	 0.00252	 0.0008	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 71	 0.030738	 0.088687	 0.0169	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 71	 0.006551	 0.016377	 0.0171	 1625	 1625	 1625	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 71	 0.025195	 0.07483	 0.0204	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	3746	 72	 9.9e-05	 0.00077	 0.078	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3746	 73	 9.9e-05	 0.00077	 0.077	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 74	 0.000514	 0.003437	 0.0061	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 74	 0.005476	 0.036879	 0.1255	 522.0	 522.0	 522.0	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 74	 0.000514	 0.003457	 0.0061	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 75	 0.017531	 0.046914	 0.0023	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	2084	 75	 0.005309	 0.014321	 0.0006	 1945	 1945	 1945	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 76	 0.003477	 0.01118	 0.0187	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3832	 76	 0.000612	 0.003121	 0.0152	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2344	 77	 0.013857	 0.035525	 0.0004	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	240	 78	 0.002771	 0.008314	 0.0083	 3471	 3471	 3471	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 78	 0.000151	 0.000302	 0.0	 90076	 90076	 90076	 0.0	 0.0	 1	 -30.0	 30.0;
	630	 79	 0.010758	 0.02187	 0.0071	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 79	 0.003779	 0.014613	 0.0198	 1899	 1899	 1899	 0.0	 0.0	 1	 -30.0	 30.0;
	2410	 79	 0.008314	 0.017057	 0.024	 1510	 1510	 1510	 0.0	 0.0	 1	 -30.0	 30.0;
	4077	 79	 0.000252	 0.001764	 0.0043	 16079	 16079	 16079	 0.0	 0.0	 1	 -30.0	 30.0;
	630	 79	 0.010758	 0.02187	 0.0071	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	4076	 79	 0.000302	 0.001562	 0.0037	 18009	 18009	 18009	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 81	 2.4e-05	 0.000144	 0.0213	 701.0	 701.0	 701.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 80	 7.1e-05	 0.000162	 0.0162	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 82	 0.068027	 0.173091	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 82	 0.027211	 0.068783	 0.001	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 82	 0.03099	 0.202822	 0.002	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 83	 0.000257	 0.001165	 0.002	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 84	 0.045603	 0.11741	 0.001	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	3802	 84	 0.008566	 0.024691	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 85	 0.047317	 0.131595	 0.0015	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	2809	 86	 0.040494	 0.128889	 0.0064	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 86	 0.037778	 0.097037	 0.0045	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	3771	 87	 0.032071	 0.058705	 0.0006	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 87	 0.062887	 0.204157	 0.002	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	3771	 87	 0.032026	 0.058624	 0.0006	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	1617	 88	 0.075838	 0.224742	 0.0027	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1706	 88	 0.028471	 0.089695	 0.001	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	3642	 88	 0.080373	 0.255732	 0.003	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 88	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	2496	 89	 0.033531	 0.087235	 0.0166	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	4226	 89	 0.03037	 0.08321	 0.0039	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 90	 0.000444	 0.001136	 0.0	 21404	 21404	 21404	 0.0	 0.0	 1	 -30.0	 30.0;
	3727	 91	 0.057284	 0.130864	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	653	 92	 0.054749	 0.157445	 0.0027	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4056	 92	 0.038549	 0.103049	 0.0012	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 92	 0.012598	 0.052406	 0.0006	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 93	 0.006914	 0.020741	 0.0	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 94	 0.007901	 0.020741	 0.001	 1339	 1339	 1339	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 94	 0.02	 0.054691	 0.0026	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 95	 0.012099	 0.030864	 0.0047	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	1174	 95	 0.013704	 0.034444	 0.003	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 95	 0.005679	 0.014198	 0.0023	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 96	 0.009549	 0.040766	 0.0005	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 97	 0.026505	 0.119426	 0.1007	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	4176	 97	 0.087641	 0.160426	 0.0015	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4445	 97	 0.021542	 0.05868	 0.003	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 97	 0.026505	 0.119426	 0.1007	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 98	 0.000176	 0.000479	 0.0006	 59599	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 98	 0.141119	 0.363442	 0.0042	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 98	 0.074477	 0.177601	 0.0021	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2633	 99	 0.025195	 0.067523	 0.0064	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 99	 0.025069	 0.067599	 0.0064	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 100	 0.024792	 0.057949	 0.003	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	1194	 100	 0.028723	 0.11683	 0.0015	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 100	 0.027589	 0.112547	 0.0048	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 101	 0.032124	 0.082892	 0.003	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 101	 0.025573	 0.09869	 0.0012	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 102	 0.001512	 0.005291	 0.0064	 5495	 5495	 5495	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 103	 0.03351	 0.120433	 0.0058	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2487	 103	 0.062988	 0.159486	 0.0017	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 103	 0.024943	 0.104283	 0.0031	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 103	 0.033762	 0.120433	 0.0057	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 104	 0.005709	 0.037926	 0.0688	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 104	 0.001758	 0.011654	 0.0208	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 105	 0.001383	 0.009462	 0.0172	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1559	 105	 0.00156	 0.006933	 0.0121	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 105	 0.006376	 0.028733	 0.0506	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 105	 0.00158	 0.010627	 0.0192	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2208	 106	 0.005556	 0.025185	 0.0008	 1225	 1225	 1225	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 106	 0.007531	 0.046914	 0.0036	 676	 676	 676	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 106	 0.033457	 0.09642	 0.0047	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 106	 0.006914	 0.042469	 0.0005	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 107	 0.001086	 0.003536	 0.3766	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 107	 0.001086	 0.003536	 0.3766	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 108	 0.026543	 0.074691	 0.0034	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 108	 0.026914	 0.075802	 0.0034	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	633	 109	 0.04059	 0.110708	 0.0013	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 109	 0.073646	 0.225598	 0.0087	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	765	 109	 0.02066	 0.088687	 0.0021	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5203	 109	 0.019904	 0.08516	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	5207	 109	 0.014361	 0.068027	 0.0035	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	4740	 109	 0.059209	 0.150164	 0.0021	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	481	 110	 0.004741	 0.020385	 0.0334	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 110	 0.009027	 0.048869	 0.084	 351.0	 351.0	 351.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 110	 0.003516	 0.016257	 0.0273	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	719	 111	 0.059461	 0.163265	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 111	 0.146384	 0.373394	 0.0051	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 112	 0.006299	 0.027715	 0.0003	 1009	 1009	 1009	 0.0	 0.0	 1	 -30.0	 30.0;
	1656	 112	 0.008818	 0.028471	 0.0003	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	2296	 112	 0.043588	 0.145629	 0.008	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 112	 0.015117	 0.051902	 0.0006	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 112	 0.006551	 0.025951	 0.0003	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	1655	 112	 0.008314	 0.027211	 0.0003	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	2296	 112	 0.043689	 0.145528	 0.0081	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 112	 0.008566	 0.027967	 0.0003	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 113	 0.000514	 0.003417	 0.0278	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 113	 0.001084	 0.007198	 0.0132	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 113	 0.000523	 0.002436	 0.0167	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 113	 0.000514	 0.003457	 0.0203	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 113	 0.001086	 0.007249	 0.0132	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5263	 113	 0.000553	 0.002469	 0.0157	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 113	 0.001086	 0.007269	 0.0132	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3521	 114	 0.038725	 0.112799	 0.0116	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	3994	 114	 0.023935	 0.079617	 0.0021	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	1244	 117	 0.135693	 0.248384	 0.0025	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 117	 0.192681	 0.352701	 0.0037	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 117	 0.057193	 0.145377	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 117	 0.021736	 0.039788	 0.0004	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 118	 0.002469	 0.006938	 0.0248	 4034	 4034	 4034	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 119	 0.016125	 0.068279	 0.0081	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 119	 0.059209	 0.150416	 0.0021	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 119	 0.016125	 0.068279	 0.0081	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	2703	 120	 0.013605	 0.039305	 0.0061	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 121	 0.031015	 0.078685	 0.0032	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 121	 0.080927	 0.181204	 0.0038	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	5106	 122	 0.007811	 0.016377	 0.0024	 1677	 1677	 1677	 0.0	 0.0	 1	 -30.0	 30.0;
	5106	 123	 0.007811	 0.016377	 0.0024	 1677	 1677	 1677	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 124	 0.010124	 0.028518	 0.0013	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 125	 0.084656	 0.231041	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 125	 0.061225	 0.275888	 0.003	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4309	 126	 0.102293	 0.245906	 0.0027	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5738	 126	 0.036533	 0.088435	 0.001	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 127	 0.001039	 0.001902	 0.0015	 13220	 13220	 13220	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 129	 0.019148	 0.081381	 0.0012	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	4259	 129	 0.02318	 0.04258	 0.0006	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 129	 0.002268	 0.022424	 0.0002	 1311	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	5742	 128	 0.012094	 0.030486	 0.0004	 901	 901	 901	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 128	 0.03351	 0.088435	 0.001	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	5295	 128	 0.00252	 0.02066	 0.0002	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 130	 0.001837	 0.011694	 0.0759	 467.0	 467.0	 467.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3413	 130	 0.001067	 0.007131	 0.0132	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4575	 130	 0.001284	 0.008593	 0.0152	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4576	 130	 0.001284	 0.008593	 0.0162	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4576	 130	 0.001284	 0.008533	 0.0162	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	788	 131	 0.000494	 0.000928	 0.0699	 29203	 29203	 29203	 0.0	 0.0	 1	 -30.0	 30.0;
	1148	 131	 0.000184	 0.00159	 0.1661	 464.0	 464.0	 464.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4042	 131	 0.000198	 0.001711	 0.1711	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 131	 0.000751	 0.003358	 0.1534	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2195	 132	 0.007037	 0.022716	 0.0011	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 132	 0.028025	 0.071111	 0.0034	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 133	 0.005192	 0.009503	 0.009	 2646	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 135	 0.000178	 0.001047	 0.1499	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 134	 0.000119	 0.000474	 0.0688	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 135	 0.000316	 0.002232	 0.2774	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 136	 0.060864	 0.152469	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 136	 0.058222	 0.146864	 0.007	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	626	 137	 0.047115	 0.108088	 0.0031	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 137	 0.036281	 0.154195	 0.0037	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 138	 0.037227	 0.106836	 0.0328	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 138	 0.006089	 0.020756	 0.0067	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 139	 0.086848	 0.206626	 0.0036	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4751	 139	 0.032754	 0.0839	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 140	 0.000729	 0.005118	 0.0933	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 140	 0.000755	 0.005235	 0.0909	 419.0	 419.0	 419.0	 0.0	 0.0	 1	 -30.0	 30.0;
	856	 141	 0.001787	 0.01946	 0.4214	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	185	 142	 0.01615	 0.036583	 0.027	 761	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 142	 0.018645	 0.048123	 0.0006	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	2218	 142	 0.03351	 0.061476	 0.0006	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	2219	 142	 0.024943	 0.066264	 0.0007	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	3891	 142	 0.079617	 0.198035	 0.0025	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 142	 0.0194	 0.05291	 0.0006	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	3891	 142	 0.068279	 0.185689	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 143	 0.001719	 0.00877	 0.0157	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4133	 143	 0.009165	 0.04318	 0.077	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1553	 144	 0.070988	 0.185185	 0.0089	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 144	 0.000617	 0.001852	 0.0011	 16510	 16510	 16510	 0.0	 0.0	 1	 -30.0	 30.0;
	3693	 144	 0.010988	 0.068148	 0.0006	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5046	 144	 0.005309	 0.034691	 0.0382	 915	 915	 915	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 144	 0.00963	 0.059753	 0.0032	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 144	 0.002346	 0.006173	 0.0002	 4881	 4881	 4881	 0.0	 0.0	 1	 -30.0	 30.0;
	505	 145	 0.004879	 0.032454	 0.0602	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	701	 145	 0.006341	 0.042746	 0.0785	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 145	 0.006914	 0.031249	 0.0547	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 146	 0.000582	 0.007652	 0.2643	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 146	 0.001648	 0.021634	 0.748	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 146	 0.000838	 0.014301	 0.5198	 2245	 2245	 2245	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 146	 0.001163	 0.015312	 0.5285	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 146	 0.000575	 0.007576	 0.2614	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 146	 0.001646	 0.021633	 0.7479	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 146	 0.000838	 0.014287	 0.5198	 2247	 2247	 2247	 0.0	 0.0	 1	 -30.0	 30.0;
	4603	 146	 0.00117	 0.015339	 0.5285	 2074	 2074	 2074	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 146	 0.001821	 0.017874	 0.4318	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 147	 0.004485	 0.01683	 0.0154	 1696	 1696	 1696	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 148	 0.003023	 0.01159	 0.0002	 2466	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	4242	 149	 0.022222	 0.060124	 0.0029	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1995	 150	 0.007307	 0.030486	 0.0071	 942	 942	 942	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 152	 0.070043	 0.190728	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 151	 0.110103	 0.294533	 0.004	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 152	 0.034014	 0.145629	 0.0018	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 151	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3575	 153	 0.042328	 0.115898	 0.001	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 153	 0.021416	 0.061476	 0.001	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 153	 0.0194	 0.053414	 0.001	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 153	 0.021416	 0.061728	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 154	 0.000672	 0.003477	 0.0365	 254.0	 254.0	 254.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 155	 0.000831	 0.001688	 0.0	 16165	 16165	 16165	 0.0	 0.0	 1	 -30.0	 30.0;
	689	 157	 0.138123	 0.332	 0.001	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	4745	 158	 0.000988	 0.003457	 0.0	 7261	 7261	 7261	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 157	 0.008395	 0.02321	 0.0	 1058	 1058	 1058	 0.0	 0.0	 1	 -30.0	 30.0;
	1727	 159	 0.047518	 0.118922	 0.0013	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 159	 0.022928	 0.053414	 0.0006	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	2839	 159	 0.080373	 0.201562	 0.004	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3692	 159	 0.019652	 0.05291	 0.001	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 161	 0.000632	 0.004188	 0.0081	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 160	 0.000612	 0.004148	 0.0071	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 162	 0.024321	 0.06679	 0.0031	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	4669	 162	 0.015062	 0.041605	 0.0019	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 164	 0.001587	 0.003527	 0.0013	 7864	 7864	 7864	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 163	 0.001587	 0.003527	 0.0013	 7864	 7864	 7864	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 167	 0.03642	 0.095185	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	1590	 167	 0.014938	 0.061852	 0.0046	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3618	 167	 0.043951	 0.11642	 0.007	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 166	 0.014815	 0.033457	 0.0015	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 166	 0.004198	 0.010741	 0.0013	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	4496	 166	 0.02	 0.049136	 0.0629	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 167	 0.014444	 0.036173	 0.0018	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 167	 0.015679	 0.042593	 0.0019	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 166	 0.041975	 0.106173	 0.0125	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	3449	 166	 0.022753	 0.056914	 0.0028	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 166	 0.031235	 0.082839	 0.0042	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 168	 0.000672	 0.004405	 0.0081	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 168	 0.000968	 0.004602	 0.0081	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 168	 0.000632	 0.004444	 0.0081	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 169	 0.016173	 0.044198	 0.0021	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	2570	 170	 0.001481	 0.005679	 0.0267	 5167	 5167	 5167	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 170	 0.008642	 0.018272	 0.0045	 1501	 1501	 1501	 0.0	 0.0	 1	 -30.0	 30.0;
	1563	 171	 0.006173	 0.026296	 0.0015	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 171	 0.039753	 0.105062	 0.0073	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 171	 0.010617	 0.027407	 0.0034	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	1563	 171	 0.006173	 0.026173	 0.0013	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 172	 0.001975	 0.013215	 0.0243	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 172	 0.001956	 0.013037	 0.0243	 2348	 2348	 2348	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 173	 0.000988	 0.004074	 0.0002	 8279	 8279	 8279	 0.0	 0.0	 1	 -30.0	 30.0;
	445	 174	 0.030494	 0.121605	 0.0071	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 174	 0.009877	 0.025062	 0.0011	 1284	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 174	 0.020741	 0.052469	 0.0003	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 175	 0.018896	 0.056185	 0.0006	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 175	 0.002771	 0.008314	 0.0001	 3471	 3471	 3471	 0.0	 0.0	 1	 -30.0	 30.0;
	4719	 176	 0.002933	 0.010267	 0.0032	 2959	 2959	 2959	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 176	 0.0028	 0.007511	 0.0022	 3941	 3941	 3941	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 177	 2e-05	 0.000198	 0.0121	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 178	 2e-05	 0.000198	 0.0142	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	916	 179	 0.001008	 0.002268	 0.0034	 11544	 11544	 11544	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 179	 0.002771	 0.007055	 0.0075	 3780	 3780	 3780	 0.0	 0.0	 1	 -30.0	 30.0;
	1493	 179	 0.008411	 0.015397	 0.0491	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	3467	 179	 0.008566	 0.016377	 0.0064	 1551	 1551	 1551	 0.0	 0.0	 1	 -30.0	 30.0;
	4937	 179	 0.006299	 0.01159	 0.0008	 2172	 2172	 2172	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 179	 0.002478	 0.004537	 0.0024	 5543	 5543	 5543	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 179	 0.006488	 0.011876	 0.015	 2118	 2118	 2118	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 179	 0.001008	 0.002771	 0.0037	 9717	 9717	 9717	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 179	 0.003191	 0.005842	 0.0075	 4305	 4305	 4305	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 179	 0.002771	 0.007307	 0.0079	 3667	 3667	 3667	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 179	 0.000756	 0.002268	 0.003	 11985	 11985	 11985	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 179	 0.000974	 0.001783	 0.0033	 14102	 14102	 14102	 0.0	 0.0	 1	 -30.0	 30.0;
	994	 180	 0.000277	 0.000928	 0.2066	 31961	 31961	 31961	 0.0	 0.0	 1	 -30.0	 30.0;
	1051	 180	 0.002037	 0.010904	 0.0187	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 180	 0.000415	 0.002015	 0.1266	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1269	 180	 0.000395	 0.00156	 0.1893	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 180	 4e-05	 0.000178	 0.0152	 169660	 169660	 169660	 0.0	 0.0	 1	 -30.0	 30.0;
	2966	 180	 0.001323	 0.012444	 0.0678	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4386	 180	 0.000454	 0.002133	 0.2511	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4947	 180	 0.000119	 0.000691	 0.1002	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5038	 180	 0.00083	 0.005175	 0.0203	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	994	 180	 0.000277	 0.000928	 0.2086	 31961	 31961	 31961	 0.0	 0.0	 1	 -30.0	 30.0;
	2966	 180	 0.001314	 0.012115	 0.0673	 943.0	 943.0	 943.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4944	 180	 5.9e-05	 0.000217	 0.0496	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4943	 180	 5.9e-05	 0.000217	 0.0466	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 181	 0.023583	 0.064324	 0.0007	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	4411	 182	 0.000854	 0.001563	 0.0007	 16578	 16578	 16578	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 183	 0.015369	 0.060469	 0.0013	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	1036	 184	 0.004314	 0.007897	 0.0123	 3370	 3370	 3370	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 185	 0.009625	 0.024339	 0.0003	 1163	 1163	 1163	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 186	 0.002593	 0.00716	 0.0003	 3901	 3901	 3901	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 187	 0.008566	 0.018896	 0.0002	 1466	 1466	 1466	 0.0	 0.0	 1	 -30.0	 30.0;
	2900	 188	 0.020912	 0.071303	 0.0008	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 189	 0.041068	 0.139078	 0.0016	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 189	 0.070547	 0.233132	 0.0127	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 190	 0.000494	 0.000988	 0.0	 23633	 23633	 23633	 0.0	 0.0	 1	 -30.0	 30.0;
	2750	 191	 0.018025	 0.049136	 0.0023	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 191	 0.024198	 0.061728	 0.0029	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	317	 192	 0.062232	 0.138574	 0.0015	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 192	 0.035525	 0.084782	 0.0009	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	4095	 193	 0.000158	 0.000948	 0.002	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 194	 0.043588	 0.119174	 0.0013	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 194	 0.095062	 0.299849	 0.0069	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 194	 0.048375	 0.166037	 0.002	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3215	 195	 0.004193	 0.007675	 0.0057	 3377	 3377	 3377	 0.0	 0.0	 1	 -30.0	 30.0;
	3215	 196	 0.004377	 0.008012	 0.0058	 3235	 3235	 3235	 0.0	 0.0	 1	 -30.0	 30.0;
	321	 197	 0.035273	 0.218443	 0.0029	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 197	 0.000252	 0.000504	 0.0	 53974	 53974	 53974	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 197	 0.034442	 0.11809	 0.0091	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	321	 197	 0.034266	 0.221466	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	831	 198	 0.0839	 0.229025	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 198	 0.048627	 0.123205	 0.0014	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 199	 0.008025	 0.021852	 0.001	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	2455	 200	 0.001521	 0.007076	 0.0118	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4560	 200	 0.002469	 0.011457	 0.0203	 315.0	 315.0	 315.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1381	 201	 0.001442	 0.009699	 0.0172	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 201	 0.001422	 0.009541	 0.0172	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	392	 202	 0.024691	 0.056941	 0.001	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	1074	 202	 0.0194	 0.038549	 0.0033	 685	 685	 685	 0.0	 0.0	 1	 -30.0	 30.0;
	834	 203	 0.006914	 0.029259	 0.0015	 1051	 1051	 1051	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 203	 0.007037	 0.029877	 0.0015	 1030	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 203	 0.02037	 0.08642	 0.0044	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 203	 0.007531	 0.047037	 0.0047	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 203	 0.019136	 0.051481	 0.0024	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	834	 203	 0.007531	 0.031605	 0.0016	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 203	 0.00716	 0.031852	 0.0021	 968	 968	 968	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 204	 0.004681	 0.028227	 0.0516	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2720	 204	 0.001185	 0.008	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 204	 0.005333	 0.02722	 0.0491	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 205	 0.000145	 0.001911	 0.0661	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 205	 0.000253	 0.003323	 0.1148	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	392	 206	 0.018645	 0.041068	 0.0005	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 206	 0.049131	 0.124465	 0.0014	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 206	 0.02192	 0.091207	 0.0011	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	563	 207	 0.015117	 0.039808	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	563	 207	 0.015117	 0.039808	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 208	 0.012296	 0.031173	 0.0015	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 208	 0.020988	 0.06716	 0.0032	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 209	 0.004787	 0.018141	 0.0002	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	1797	 211	 0.003779	 0.020912	 0.0028	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 210	 0.007055	 0.020408	 0.0002	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	1797	 211	 0.003779	 0.020912	 0.0028	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 212	 0.000494	 0.002252	 0.004	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 213	 0.000494	 0.002252	 0.004	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	525	 214	 0.000741	 0.001358	 0.0036	 19602	 19602	 19602	 0.0	 0.0	 1	 -30.0	 30.0;
	1182	 214	 0.044444	 0.111728	 0.0053	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 214	 0.093457	 0.227654	 0.0115	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	1738	 214	 0.024938	 0.06642	 0.0032	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 214	 0.045309	 0.116049	 0.0055	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 214	 0.06758	 0.184444	 0.0162	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 214	 0.065062	 0.177531	 0.0083	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	352	 215	 0.004563	 0.030696	 0.0557	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1136	 215	 0.009857	 0.04478	 0.077	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2892	 215	 0.017106	 0.078321	 0.1387	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 215	 0.010272	 0.048691	 0.0866	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 216	 0.11867	 0.311413	 0.0041	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 216	 0.087931	 0.176115	 0.0018	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 217	 0.057654	 0.152716	 0.0076	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	1582	 217	 0.037654	 0.101605	 0.0047	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	2769	 218	 0.00037	 0.001235	 0.0015	 23039	 23039	 23039	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 219	 0.013827	 0.037778	 0.0018	 739	 739	 739	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 220	 0.015631	 0.028612	 0.0002	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	255	 221	 0.093978	 0.258755	 0.004	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 221	 0.160699	 0.294157	 0.003	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 221	 0.059209	 0.163265	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 222	 0.012978	 0.059338	 0.1002	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 222	 0.01197	 0.056632	 0.0942	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 223	 0.014613	 0.039808	 0.0005	 718	 718	 718	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 223	 0.114412	 0.301335	 0.0036	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 223	 0.026002	 0.055883	 0.0011	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 224	 0.000578	 0.001156	 0.0004	 24440	 24440	 24440	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 226	 0.000316	 0.001679	 0.0192	 17970	 17970	 17970	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 225	 0.000316	 0.001679	 0.0192	 17970	 17970	 17970	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 228	 0.06576	 0.166541	 0.0019	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 227	 0.063946	 0.174402	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 229	 0.015369	 0.064399	 0.0106	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3141	 229	 0.163093	 0.298541	 0.0034	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 229	 0.017407	 0.031864	 0.0009	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 229	 0.015344	 0.064248	 0.0103	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	2490	 230	 0.000277	 0.000573	 0.0334	 48541	 48541	 48541	 0.0	 0.0	 1	 -30.0	 30.0;
	520	 231	 0.049383	 0.134444	 0.0063	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	1869	 232	 0.009383	 0.039012	 0.0019	 772	 772	 772	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 232	 0.015803	 0.066543	 0.0034	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 234	 0.009012	 0.029012	 0.0003	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 235	 0.001055	 0.004836	 0.0081	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 236	 0.003951	 0.010247	 0.0005	 2910	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 237	 0.042303	 0.10708	 0.0017	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 237	 0.006047	 0.015117	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	2697	 238	 0.035185	 0.095802	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	5017	 238	 0.039691	 0.108716	 0.0052	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 239	 0.081633	 0.151675	 0.0016	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 239	 0.057949	 0.240111	 0.003	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 239	 0.006299	 0.017133	 0.0038	 1618	 1618	 1618	 0.0	 0.0	 1	 -30.0	 30.0;
	5739	 239	 0.047871	 0.197783	 0.0025	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	360	 240	 0.044092	 0.11164	 0.0017	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4561	 240	 0.003704	 0.023029	 0.0026	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	697	 241	 0.009111	 0.029012	 0.0043	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	4453	 241	 0.020926	 0.060074	 0.0028	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 241	 0.014222	 0.048111	 0.0024	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 242	 0.056437	 0.160242	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 242	 0.050894	 0.146384	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 243	 0.058957	 0.160494	 0.0018	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 243	 0.067019	 0.17032	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 244	 0.038148	 0.094691	 0.018	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 244	 0.034259	 0.085321	 0.0145	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 245	 0.058705	 0.164777	 0.0018	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	282	 246	 0.004031	 0.009826	 0.0001	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 246	 0.024943	 0.112371	 0.003	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	756	 246	 0.006097	 0.011161	 0.0002	 2322	 2322	 2322	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 246	 0.106843	 0.195575	 0.0051	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	4733	 246	 0.010582	 0.039557	 0.001	 722	 722	 722	 0.0	 0.0	 1	 -30.0	 30.0;
	3579	 247	 0.002114	 0.008553	 0.0152	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 248	 0.000198	 0.000731	 0.0942	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2115	 249	 0.058705	 0.235072	 0.0025	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 249	 0.042378	 0.116024	 0.0134	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	1272	 250	 0.087176	 0.228773	 0.0059	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1627	 250	 0.092727	 0.169735	 0.005	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2263	 250	 0.113127	 0.312169	 0.006	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 251	 0.005424	 0.009929	 0.0373	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 252	 0.026667	 0.07037	 0.0032	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 252	 0.00963	 0.026049	 0.0011	 1070	 1070	 1070	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 253	 0.004812	 0.019703	 0.0002	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 253	 0.005039	 0.022424	 0.0002	 1324	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	1118	 254	 0.067599	 0.171378	 0.0019	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3823	 254	 0.043336	 0.111363	 0.0013	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 254	 0.004787	 0.013102	 0.0002	 2181	 2181	 2181	 0.0	 0.0	 1	 -30.0	 30.0;
	559	 255	 0.166768	 0.305266	 0.003	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	1687	 255	 0.06198	 0.171076	 0.0042	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 256	 0.037365	 0.080247	 0.0009	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 256	 0.06198	 0.162409	 0.0017	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	4560	 257	 0.00324	 0.012616	 0.0225	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 258	 0.005679	 0.015185	 0.0006	 1871	 1871	 1871	 0.0	 0.0	 1	 -30.0	 30.0;
	768	 259	 0.086288	 0.157948	 0.0015	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 259	 0.000882	 0.002494	 0.0021	 11497	 11497	 11497	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 260	 0.007522	 0.029736	 0.0496	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 260	 0.006809	 0.03043	 0.0521	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 261	 0.038297	 0.078861	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	1381	 263	 0.002153	 0.014736	 0.0273	 565.0	 565.0	 565.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1629	 262	 0.000581	 0.003838	 0.0071	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 262	 0.001857	 0.020306	 0.0557	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 263	 0.002331	 0.015526	 0.0278	 549.0	 549.0	 549.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5417	 262	 0.001345	 0.008968	 0.0162	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1628	 262	 0.000573	 0.003911	 0.0071	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2206	 262	 0.001896	 0.012701	 0.0233	 501.0	 501.0	 501.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 264	 0.000602	 0.006717	 0.1357	 1725.0	 1725.0	 1725.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 264	 0.00063	 0.007098	 0.1588	 1916.0	 1916.0	 1916.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 264	 0.000367	 0.004631	 0.1126	 2275.0	 2275.0	 2275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 264	 0.000472	 0.006201	 0.2137	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 264	 0.001504	 0.019298	 0.4577	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	733	 265	 0.001844	 0.003375	 0.0026	 7450	 7450	 7450	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 266	 0.000158	 0.001106	 0.1357	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1278	 267	 0.000219	 0.00193	 0.1954	 407.0	 407.0	 407.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 267	 0.000158	 0.000909	 0.1316	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3528	 267	 0.000411	 0.00356	 0.3564	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 266	 0.000158	 0.001264	 0.1286	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1906	 268	 0.045855	 0.121189	 0.0013	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 268	 0.064248	 0.156211	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 269	 0.100277	 0.244898	 0.0026	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 269	 0.072411	 0.175888	 0.0019	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 271	 0.000198	 0.001383	 0.003	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 270	 0.000217	 0.001402	 0.003	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 272	 0.036029	 0.091711	 0.001	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	1701	 272	 0.018896	 0.047367	 0.0008	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 272	 0.003427	 0.009272	 0.0121	 2987	 2987	 2987	 0.0	 0.0	 1	 -30.0	 30.0;
	4842	 272	 0.006299	 0.018392	 0.0164	 1519	 1519	 1519	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 272	 0.017637	 0.044092	 0.0008	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 272	 0.046273	 0.084703	 0.0015	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 272	 0.00383	 0.008869	 0.0143	 3057	 3057	 3057	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 273	 0.001304	 0.008691	 0.0152	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 273	 0.000691	 0.004662	 0.0091	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 274	 0.009506	 0.058889	 0.0039	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 274	 0.009383	 0.058765	 0.0031	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	278	 275	 9.9e-05	 0.000415	 0.0456	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1057	 276	 1e-06	 0.000104	 0.078	 1086.0	 1086.0	 1086.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 276	 0.000353	 0.004584	 0.1184	 2357.0	 2357.0	 2357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 276	 0.000699	 0.009179	 0.3177	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 276	 0.000353	 0.004584	 0.1184	 2357.0	 2357.0	 2357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 276	 0.000734	 0.009245	 0.3148	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 276	 7e-06	 0.000104	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 276	 7e-06	 0.000104	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	745	 277	 0.01	 0.026667	 0.0046	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	986	 277	 0.049259	 0.114321	 0.0079	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 277	 0.019383	 0.049383	 0.0256	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	746	 277	 0.009877	 0.026667	 0.0046	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 277	 0.02037	 0.052469	 0.0097	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 278	 0.002556	 0.017333	 0.0805	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 278	 0.008849	 0.062617	 0.1144	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 279	 0.024943	 0.069287	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 280	 0.032259	 0.085247	 0.0109	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	4955	 280	 0.051284	 0.130198	 0.0139	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 280	 0.049012	 0.133827	 0.0063	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 280	 0.006543	 0.026148	 0.1306	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 281	 0.136634	 0.39607	 0.0046	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 283	 0.000617	 0.001728	 0.0	 16188	 16188	 16188	 0.0	 0.0	 1	 -30.0	 30.0;
	448	 284	 0.010582	 0.03351	 0.0004	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	2670	 284	 0.000227	 0.000907	 0.0013	 32529	 32529	 32529	 0.0	 0.0	 1	 -30.0	 30.0;
	3645	 284	 0.00907	 0.026707	 0.0103	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	5127	 285	 2.2e-05	 9.9e-05	 0.001	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 286	 2e-05	 9.9e-05	 0.0	 306461	 306461	 306461	 0.0	 0.0	 1	 -30.0	 30.0;
	965	 287	 0.025062	 0.064074	 0.0135	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	2323	 288	 1.2e-05	 0.000123	 0.0002	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	2912	 288	 0.00679	 0.013704	 0.0523	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 288	 0.022346	 0.075432	 0.0037	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	5436	 288	 1.2e-05	 0.000123	 0.0002	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 289	 0.000573	 0.002588	 0.0051	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2796	 290	 0.002407	 0.006741	 0.0242	 4503	 4503	 4503	 0.0	 0.0	 1	 -30.0	 30.0;
	2172	 291	 0.102041	 0.259007	 0.0029	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 291	 0.060555	 0.110845	 0.0026	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 291	 0.053918	 0.146888	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 291	 0.047367	 0.19098	 0.0021	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 293	 0.00385	 0.007048	 0.0043	 3677	 3677	 3677	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 293	 0.039808	 0.117914	 0.0111	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	1569	 293	 0.019854	 0.04772	 0.0085	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	1244	 294	 0.011208	 0.020515	 0.0007	 1302	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 295	 2e-05	 0.000198	 0.001	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 296	 0.085412	 0.216931	 0.0024	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	1756	 297	 0.003275	 0.008062	 0.0001	 3394	 3394	 3394	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 298	 0.027715	 0.069791	 0.001	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 299	 0.000988	 0.003827	 0.001	 8155	 8155	 8155	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 300	 0.000138	 0.00077	 0.001	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 301	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 302	 0.006551	 0.028219	 0.042	 1020	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 302	 0.005291	 0.024036	 0.0256	 1200	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	197	 303	 0.036533	 0.120433	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 303	 0.071303	 0.195263	 0.0022	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 303	 0.046259	 0.156664	 0.0024	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	197	 303	 0.036533	 0.120433	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 303	 0.071378	 0.195288	 0.0022	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	4836	 304	 0.039305	 0.163517	 0.0072	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5411	 304	 0.04006	 0.090703	 0.0039	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	695	 305	 0.091993	 0.168392	 0.001	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 305	 0.059713	 0.134543	 0.001	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 306	 0.090023	 0.243966	 0.0043	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	2483	 307	 0.055309	 0.140247	 0.0065	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4938	 307	 0.027531	 0.070124	 0.0032	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	1310	 308	 0.023003	 0.052003	 0.0006	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 308	 0.01358	 0.034114	 0.0004	 829	 829	 829	 0.0	 0.0	 1	 -30.0	 30.0;
	1638	 310	 0.001512	 0.010078	 0.014	 2898	 2898	 2898	 0.0	 0.0	 1	 -30.0	 30.0;
	1638	 309	 0.006551	 0.012094	 0.0046	 2147	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 311	 0.003951	 0.007901	 0.0003	 3363	 3363	 3363	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 312	 0.000123	 0.001235	 0.0006	 24326	 24326	 24326	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 313	 0.003049	 0.011111	 0.0172	 2640	 2640	 2640	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 313	 0.024188	 0.061476	 0.0007	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 313	 0.008818	 0.053918	 0.0007	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 314	 0.001171	 0.007842	 0.0166	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 314	 0.002212	 0.014979	 0.0388	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1036	 315	 0.025309	 0.057778	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 315	 0.000741	 0.001852	 0.0002	 15203	 15203	 15203	 0.0	 0.0	 1	 -30.0	 30.0;
	2289	 316	 0.021416	 0.086672	 0.0011	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 316	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 316	 0.00252	 0.006551	 0.0001	 4334	 4334	 4334	 0.0	 0.0	 1	 -30.0	 30.0;
	2289	 316	 0.021164	 0.08642	 0.0011	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	3297	 317	 0.083799	 0.195137	 0.0022	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 318	 0.002585	 0.004732	 0.0029	 5314	 5314	 5314	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 319	 0.000479	 0.001285	 0.0	 22178	 22178	 22178	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 320	 0.019259	 0.061728	 0.0021	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 320	 0.020123	 0.051111	 0.0021	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	835	 321	 0.008679	 0.015886	 0.0142	 1681	 1681	 1681	 0.0	 0.0	 1	 -30.0	 30.0;
	2311	 321	 0.035878	 0.14646	 0.0	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 321	 0.009675	 0.060166	 0.0022	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 321	 0.039053	 0.145377	 0.0054	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 321	 0.040312	 0.118166	 0.0049	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2311	 321	 0.036054	 0.147241	 0.0074	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 321	 0.0097	 0.060393	 0.0027	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 321	 0.020408	 0.13026	 0.0016	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 321	 0.020106	 0.076216	 0.0011	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	4150	 322	 0.000691	 0.002588	 0.1691	 11556	 11556	 11556	 0.0	 0.0	 1	 -30.0	 30.0;
	4151	 322	 0.000691	 0.002588	 0.1509	 11556	 11556	 11556	 0.0	 0.0	 1	 -30.0	 30.0;
	1936	 323	 0.001627	 0.014855	 0.3899	 1717.0	 1717.0	 1717.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1936	 323	 0.001676	 0.013899	 0.4216	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2312	 324	 0.002771	 0.009574	 0.0091	 2963	 2963	 2963	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 324	 0.002771	 0.010834	 0.016	 2641	 2641	 2641	 0.0	 0.0	 1	 -30.0	 30.0;
	522	 325	 0.027186	 0.073369	 0.0039	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	521	 325	 0.027085	 0.073243	 0.0034	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	1845	 326	 0.023285	 0.042623	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	2610	 326	 0.04258	 0.112371	 0.0012	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 326	 0.062988	 0.133535	 0.0017	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 326	 0.006677	 0.035122	 0.0059	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 326	 0.039053	 0.099017	 0.0011	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 326	 0.006551	 0.035021	 0.0059	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 327	 0.003081	 0.020286	 0.0365	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3086	 327	 0.00241	 0.01603	 0.0294	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 328	 0.034014	 0.100025	 0.0012	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 328	 0.048526	 0.153691	 0.0023	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 329	 0.001605	 0.009877	 0.0342	 3207	 3207	 3207	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 329	 0.00284	 0.006049	 0.0031	 4803	 4803	 4803	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 330	 0.0194	 0.049635	 0.0022	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 330	 0.000252	 0.00126	 0.0	 23670	 23670	 23670	 0.0	 0.0	 1	 -30.0	 30.0;
	4749	 330	 0.028975	 0.075082	 0.0009	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 331	 0.000176	 0.001385	 0.1521	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 331	 0.001817	 0.012642	 0.0233	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 331	 0.001865	 0.012502	 0.0229	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 332	 0.039053	 0.099269	 0.0011	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	3684	 332	 0.074578	 0.195767	 0.0022	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 333	 0.007422	 0.024489	 0.0081	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 333	 0.028356	 0.083956	 0.0274	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	2549	 333	 0.016844	 0.058489	 0.0198	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	4768	 333	 0.009067	 0.028133	 0.0095	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 334	 0.051146	 0.143613	 0.0016	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 335	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 336	 0.028723	 0.075082	 0.0009	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	4928	 336	 0.01285	 0.032502	 0.0004	 871	 871	 871	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 337	 0.098514	 0.257748	 0.0029	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	2646	 337	 0.179853	 0.329219	 0.0038	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	1700	 338	 0.039557	 0.089695	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	1864	 338	 0.053726	 0.098344	 0.0014	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3297	 339	 0.111615	 0.283699	 0.0033	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	3501	 339	 0.037213	 0.126279	 0.0015	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 339	 0.090199	 0.228773	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 340	 0.054938	 0.149753	 0.007	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3385	 341	 0.067574	 0.180927	 0.0108	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3238	 342	 0.041824	 0.115394	 0.0013	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	3888	 342	 0.041975	 0.173293	 0.0021	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5408	 342	 0.015117	 0.080625	 0.0006	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 343	 0.000593	 0.00401	 0.0071	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1865	 344	 0.055959	 0.123205	 0.0037	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4526	 344	 0.130763	 0.331822	 0.0039	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	5300	 344	 0.116906	 0.21416	 0.0029	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	676	 345	 0.048272	 0.114444	 0.0049	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 345	 0.065679	 0.150988	 0.0068	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 346	 0.010351	 0.032395	 0.0562	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 346	 0.009146	 0.025778	 0.041	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 347	 0.060217	 0.164273	 0.0018	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 348	 0.022839	 0.046914	 0.0021	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	3382	 348	 0.035062	 0.071852	 0.0074	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	3318	 349	 0.000395	 0.006648	 0.2426	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 349	 0.000492	 0.008345	 0.3032	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 350	 0.001198	 0.015699	 0.5401	 2026	 2026	 2026	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 350	 0.000734	 0.010623	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 349	 0.001479	 0.019446	 0.6729	 1636	 1636	 1636	 0.0	 0.0	 1	 -30.0	 30.0;
	4835	 350	 0.000305	 0.003975	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 349	 0.000395	 0.006641	 0.2426	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 350	 0.000492	 0.008338	 0.3032	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 349	 0.001184	 0.015568	 0.5372	 2043	 2043	 2043	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 349	 0.000734	 0.010623	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4603	 350	 0.001482	 0.019467	 0.6729	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	4835	 349	 0.000305	 0.003982	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 350	 0.000388	 0.0066	 0.2397	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3317	 350	 0.000388	 0.006593	 0.2397	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 351	 0.001817	 0.012049	 0.0233	 439.0	 439.0	 439.0	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 352	 0.003496	 0.023269	 0.0425	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 353	 0.03225	 0.10456	 0.0013	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2695	 353	 0.004558	 0.008344	 0.0062	 3014	 3014	 3014	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 353	 0.018645	 0.063996	 0.0007	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 354	 0.001008	 0.00252	 0.0	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	1359	 355	 0.050139	 0.112371	 0.0012	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	358	 356	 0.004031	 0.010078	 0.0001	 2802	 2802	 2802	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 357	 0.114764	 0.210075	 0.006	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	3151	 357	 0.065294	 0.11952	 0.0013	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 357	 0.037818	 0.16125	 0.0025	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 358	 0.07231	 0.176619	 0.002	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 358	 0.053414	 0.133787	 0.001	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 358	 0.002268	 0.005014	 0.0001	 5527	 5527	 5527	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 358	 0.006551	 0.016881	 0.0002	 1680	 1680	 1680	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 359	 0.028723	 0.06324	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 360	 0.028849	 0.113731	 0.042	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4561	 360	 0.004031	 0.024691	 0.0003	 1216	 1216	 1216	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 360	 0.016881	 0.042832	 0.0005	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 360	 0.008239	 0.053641	 0.0017	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	2447	 361	 0.019498	 0.06712	 0.0206	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 362	 0.006262	 0.040849	 0.0749	 398.0	 398.0	 398.0	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 363	 0.008272	 0.035062	 0.0171	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 363	 0.002346	 0.009877	 0.0002	 3419	 3419	 3419	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 363	 0.002346	 0.009753	 0.0002	 3460	 3460	 3460	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 364	 2e-05	 0.000198	 0.003	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 365	 0.001114	 0.002039	 0.0009	 12708	 12708	 12708	 0.0	 0.0	 1	 -30.0	 30.0;
	2139	 366	 0.001936	 0.0128	 0.0182	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	864	 369	 2e-05	 0.000198	 0.0081	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 369	 0.000296	 0.000988	 0.2207	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	865	 370	 8.5e-05	 0.000198	 0.0192	 386.0	 386.0	 386.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3011	 371	 0.025145	 0.068808	 0.0008	 416	 416	 416	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 371	 0.011892	 0.061199	 0.0007	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 372	 0.002487	 0.016492	 0.0304	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 372	 0.000873	 0.003563	 0.004	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 372	 0.003563	 0.023682	 0.044	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 372	 0.002724	 0.018108	 0.0334	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2175	 372	 0.000873	 0.003563	 0.004	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 373	 0.000257	 0.000928	 0.1134	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3551	 374	 0.0839	 0.212648	 0.0024	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 374	 0.083396	 0.21164	 0.0024	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	1174	 375	 0.055309	 0.150988	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 375	 0.039753	 0.108519	 0.005	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	2582	 375	 0.034691	 0.094568	 0.0044	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	2100	 376	 0.049383	 0.137062	 0.0016	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 376	 0.029479	 0.186445	 0.0024	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 376	 0.02973	 0.188461	 0.0024	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	652	 377	 0.047292	 0.098262	 0.0011	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	2329	 377	 0.066012	 0.13681	 0.0015	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	2773	 377	 0.046107	 0.127236	 0.0014	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	401	 378	 0.069035	 0.187957	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	1257	 378	 0.057924	 0.106028	 0.0026	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	1537	 378	 0.174099	 0.45553	 0.0051	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	1909	 378	 0.083396	 0.211892	 0.0051	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 378	 0.127992	 0.330814	 0.004	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	4901	 378	 0.081381	 0.206097	 0.0036	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	5020	 378	 0.03351	 0.09675	 0.003	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	4901	 378	 0.062988	 0.200302	 0.004	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5020	 378	 0.03351	 0.09675	 0.003	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	469	 379	 0.002291	 0.009936	 0.0304	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3101	 379	 0.004168	 0.028918	 0.0597	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 379	 0.002054	 0.024691	 0.1276	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4093	 379	 0.004879	 0.032533	 0.0607	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 379	 0.005294	 0.036998	 0.0668	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 379	 0.001422	 0.009896	 0.0172	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 380	 0.002168	 0.029238	 0.9906	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 380	 0.001468	 0.01491	 0.3841	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 380	 0.002479	 0.028151	 0.6296	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 380	 0.00072	 0.00946	 0.3263	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 380	 0.00142	 0.01617	 0.3636	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 380	 0.002486	 0.028165	 0.6296	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	4292	 380	 0.001184	 0.016073	 0.4869	 1979	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 381	 0.033333	 0.08321	 0.0039	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 381	 0.016543	 0.041975	 0.0019	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 382	 0.102797	 0.262031	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 382	 0.078534	 0.19229	 0.0021	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 382	 0.014361	 0.036785	 0.0012	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 383	 0.037289	 0.152381	 0.002	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 383	 0.082263	 0.222676	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 383	 0.037264	 0.15223	 0.0023	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 383	 0.082263	 0.222676	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 384	 0.080877	 0.164021	 0.0016	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 384	 0.052406	 0.143361	 0.0017	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5761	 384	 0.096643	 0.176905	 0.0017	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 385	 0.088687	 0.230033	 0.0002	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 385	 0.033258	 0.089947	 0.001	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 386	 0.000521	 0.002315	 0.019	 13045	 13045	 13045	 0.0	 0.0	 1	 -30.0	 30.0;
	1596	 387	 0.018272	 0.07679	 0.0039	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 387	 0.013765	 0.057852	 0.007	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 388	 0.006667	 0.043457	 0.0003	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 388	 0.024691	 0.103704	 0.0016	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	1405	 389	 0.002016	 0.004283	 0.0021	 6238	 6238	 6238	 0.0	 0.0	 1	 -30.0	 30.0;
	1882	 389	 0.008793	 0.026405	 0.0003	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	3854	 389	 0.013958	 0.087679	 0.0011	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 389	 0.075913	 0.210683	 0.0023	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	1404	 389	 0.002135	 0.003909	 0.0034	 6629	 6629	 6629	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 390	 0.053918	 0.138574	 0.0016	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 390	 0.014865	 0.038045	 0.0004	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 391	 0.031746	 0.072058	 0.0008	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	1823	 391	 0.090703	 0.247669	 0.0028	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	2330	 391	 0.061225	 0.148652	 0.0016	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 391	 0.16513	 0.330511	 0.0096	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 391	 0.031998	 0.08642	 0.001	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 392	 0.018645	 0.077097	 0.001	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 393	 0.057308	 0.104902	 0.001	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 394	 0.001008	 0.002268	 0.0	 12255	 12255	 12255	 0.0	 0.0	 1	 -30.0	 30.0;
	1792	 395	 0.00252	 0.015369	 0.0002	 1953	 1953	 1953	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 395	 0.004001	 0.007323	 0.0	 3645	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	1792	 395	 0.002268	 0.015369	 0.0002	 1958	 1958	 1958	 0.0	 0.0	 1	 -30.0	 30.0;
	3871	 396	 0.015621	 0.081355	 0.001	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 396	 0.016175	 0.085462	 0.0014	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	2399	 397	 0.053918	 0.184933	 0.0	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 397	 0.066264	 0.227261	 0.0	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 398	 0.005432	 0.013827	 0.0066	 2000	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 399	 0.000504	 0.00252	 0.0006	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	2243	 400	 0.056286	 0.153515	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 400	 0.07231	 0.184429	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2306	 402	 0.073593	 0.163333	 0.007	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 402	 0.084197	 0.191605	 0.0089	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 403	 0.019652	 0.055682	 0.0061	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 403	 0.069035	 0.142353	 0.001	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 404	 0.023683	 0.067775	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 404	 0.004031	 0.015369	 0.0185	 1859	 1859	 1859	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 405	 0.020242	 0.037052	 0.0011	 700	 700	 700	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 406	 0.016049	 0.045679	 0.0076	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	1867	 406	 0.00584	 0.019309	 0.001	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 406	 0.010864	 0.035803	 0.0018	 794	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	2362	 407	 0.008605	 0.022012	 0.001	 1257	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 407	 0.013173	 0.041235	 0.002	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	2818	 408	 0.085664	 0.233711	 0.0028	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	3927	 409	 0.054926	 0.100781	 0.0011	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 410	 0.012963	 0.035062	 0.0028	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 410	 0.004691	 0.012963	 0.0018	 2155	 2155	 2155	 0.0	 0.0	 1	 -30.0	 30.0;
	1870	 411	 0.023457	 0.098765	 0.005	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3197	 411	 0.02021	 0.085111	 0.0044	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 412	 0.016881	 0.069035	 0.0017	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 412	 0.076342	 0.184933	 0.0024	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 412	 0.027261	 0.115294	 0.0019	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 412	 0.057848	 0.157823	 0.0046	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 413	 0.065004	 0.18065	 0.0019	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 413	 0.062232	 0.178634	 0.0019	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 414	 0.059209	 0.150416	 0.0021	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 414	 0.000176	 0.000454	 0.0	 60637	 60637	 60637	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 415	 0.070295	 0.181658	 0.0021	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 415	 0.067271	 0.173091	 0.002	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4446	 415	 0.001008	 0.003275	 0.0004	 8876	 8876	 8876	 0.0	 0.0	 1	 -30.0	 30.0;
	545	 416	 0.000178	 0.000909	 0.002	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	862	 417	 0.067019	 0.2129	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 417	 0.07735	 0.263542	 0.0029	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 417	 0.087377	 0.23996	 0.0028	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	3741	 418	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 419	 0.082389	 0.209121	 0.0024	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 419	 0.013354	 0.03477	 0.0004	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 419	 0.003779	 0.023432	 0.0003	 1282	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 420	 0.004031	 0.010834	 0.0002	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 421	 0.001512	 0.003023	 0.0013	 8736	 8736	 8736	 0.0	 0.0	 1	 -30.0	 30.0;
	1483	 422	 0.039305	 0.173217	 0.0571	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	1483	 422	 0.039305	 0.173293	 0.0571	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	855	 423	 0.00241	 0.015694	 0.0294	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 423	 0.006874	 0.044761	 0.0835	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 424	 0.051146	 0.139078	 0.0019	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	3411	 424	 0.05165	 0.140842	 0.0016	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 424	 0.018645	 0.050643	 0.002	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	4533	 424	 0.074074	 0.188713	 0.0036	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 424	 0.051398	 0.14059	 0.0016	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 424	 0.017637	 0.048375	 0.002	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 424	 0.017637	 0.048375	 0.002	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 425	 0.001521	 0.021728	 0.0871	 831.0	 831.0	 831.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 425	 0.001304	 0.017205	 0.0729	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 426	 0.001678	 0.003072	 0.0	 8185	 8185	 8185	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 427	 0.008314	 0.018645	 0.0002	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 428	 0.008314	 0.022928	 0.0002	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	3873	 429	 0.006047	 0.015873	 0.0002	 1739	 1739	 1739	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 429	 0.00252	 0.006299	 0.0004	 4352	 4352	 4352	 0.0	 0.0	 1	 -30.0	 30.0;
	3873	 429	 0.005795	 0.016125	 0.0002	 1724	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	1666	 429	 0.021083	 0.038593	 0.0004	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 430	 0.000336	 0.001363	 0.1499	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1270	 430	 0.000178	 0.001422	 0.1448	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3297	 431	 0.052482	 0.176846	 0.0022	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	3207	 432	 0.147392	 0.387503	 0.0044	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 432	 0.124465	 0.321492	 0.0	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 433	 0.001764	 0.004535	 0.0001	 5888	 5888	 5888	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 434	 0.03351	 0.108214	 0.0013	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 434	 0.018392	 0.060217	 0.0008	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	987	 435	 0.027531	 0.072222	 0.0034	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	2846	 435	 0.031235	 0.087901	 0.0045	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 435	 0.036173	 0.098518	 0.0047	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 435	 0.016049	 0.042716	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 435	 0.034815	 0.095062	 0.0044	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	3987	 436	 0.080121	 0.168304	 0.0018	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5704	 436	 0.046863	 0.196019	 0.0024	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	2551	 437	 0.009322	 0.021668	 0.0004	 1320	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 438	 0.052397	 0.095912	 0.001	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 439	 0.023885	 0.059587	 0.0012	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	2219	 439	 0.032903	 0.060228	 0.0006	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 439	 0.031721	 0.081885	 0.0013	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 440	 0.000403	 0.001109	 0.0	 25776	 25776	 25776	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 441	 0.006047	 0.025951	 0.0	 1109	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 442	 0.025447	 0.067775	 0.0008	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 442	 0.024188	 0.064752	 0.012	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	1558	 443	 0.014074	 0.059136	 0.0038	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 445	 0.002469	 0.015679	 0.0008	 2031	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	2032	 443	 0.008272	 0.035062	 0.0028	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	4875	 445	 0.005062	 0.01037	 0.0005	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 443	 0.007531	 0.019259	 0.0019	 1672	 1672	 1672	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 445	 0.002469	 0.015679	 0.0008	 2031	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	2032	 444	 0.008272	 0.034815	 0.0046	 897	 897	 897	 0.0	 0.0	 1	 -30.0	 30.0;
	4875	 445	 0.005062	 0.010494	 0.0005	 2767	 2767	 2767	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 446	 0.002252	 0.011951	 0.0218	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 446	 0.00079	 0.005333	 0.0101	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 447	 0.008062	 0.020408	 0.0002	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	1234	 448	 0.027211	 0.172336	 0.0117	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 448	 0.015117	 0.065004	 0.0008	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	3983	 448	 0.02372	 0.043419	 0.0005	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 448	 0.014109	 0.038549	 0.0015	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 449	 0.001501	 0.010015	 0.0182	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1435	 449	 0.003103	 0.021146	 0.04	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 449	 0.00162	 0.010765	 0.0203	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 449	 0.001807	 0.017201	 0.0618	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 449	 0.000217	 0.001442	 0.003	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 449	 0.00162	 0.010726	 0.0203	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	499	 449	 0.000119	 0.001086	 0.004	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2246	 450	 0.00072	 0.009453	 0.3263	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2763	 450	 0.003206	 0.03536	 0.9025	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 450	 0.000616	 0.008054	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2246	 450	 0.000713	 0.009384	 0.3235	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 450	 0.000616	 0.008061	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	501	 450	 3.5e-05	 0.000374	 0.0087	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 451	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 452	 0.106324	 0.289746	 0.0033	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2339	 452	 0.060217	 0.168808	 0.0018	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 452	 0.048879	 0.124717	 0.0013	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 452	 0.058705	 0.152935	 0.0017	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	2339	 452	 0.060972	 0.169312	 0.0018	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	3440	 452	 0.008818	 0.025195	 0.0002	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 453	 0.013393	 0.069551	 0.1261	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 453	 0.013491	 0.070361	 0.1271	 412.0	 412.0	 412.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 454	 0.006299	 0.017385	 0.0002	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 456	 0.002346	 0.006296	 0.0002	 4777	 4777	 4777	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 455	 0.002346	 0.00642	 0.0003	 4695	 4695	 4695	 0.0	 0.0	 1	 -30.0	 30.0;
	4245	 457	 0.001764	 0.004535	 0.0048	 6068	 6068	 6068	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 458	 0.001956	 0.010469	 0.3286	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3620	 458	 0.001402	 0.010173	 0.2673	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 459	 0.000648	 0.00657	 0.1704	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 459	 0.000651	 0.006572	 0.1704	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 460	 0.004485	 0.020282	 0.0241	 1465	 1465	 1465	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 461	 0.05029	 0.138246	 0.0033	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 462	 0.05165	 0.140842	 0.0016	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 463	 0.002963	 0.008025	 0.0003	 3473	 3473	 3473	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 465	 0.003311	 0.006061	 0.0112	 4634	 4634	 4634	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 466	 2.5e-05	 0.00252	 0.0001	 11716	 11716	 11716	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 467	 0.002016	 0.005039	 0.0093	 5279	 5279	 5279	 0.0	 0.0	 1	 -30.0	 30.0;
	3481	 467	 0.022681	 0.041517	 0.0216	 606	 606	 606	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 468	 0.011086	 0.028219	 0.0301	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 467	 0.001512	 0.005291	 0.0095	 5207	 5207	 5207	 0.0	 0.0	 1	 -30.0	 30.0;
	3480	 467	 0.022761	 0.041664	 0.0218	 604	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 468	 0.011086	 0.028219	 0.0302	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 467	 0.002016	 0.005039	 0.0091	 5279	 5279	 5279	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 470	 0.078181	 0.17866	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	977	 471	 0.062358	 0.148047	 0.0068	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	3345	 471	 0.018392	 0.05291	 0.001	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	3744	 471	 0.011208	 0.020515	 0.0002	 1264	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 473	 1e-05	 0.0001	 0.0029	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 472	 1e-05	 0.0001	 0.0029	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4297	 474	 0.012568	 0.033383	 0.0066	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	4298	 474	 0.012568	 0.033383	 0.0066	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 475	 0.035777	 0.088435	 0.001	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 475	 0.027211	 0.072058	 0.0009	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 476	 0.027715	 0.070547	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 477	 0.008062	 0.03351	 0.0004	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 477	 0.008062	 0.03351	 0.0004	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 478	 0.059259	 0.163457	 0.0	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	647	 479	 0.008062	 0.027463	 0.0021	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	1835	 479	 0.01033	 0.036029	 0.003	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	3578	 479	 0.000252	 0.00126	 0.0021	 22978	 22978	 22978	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 480	 0.000436	 0.000797	 0.0006	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 480	 0.012002	 0.02197	 0.0233	 1180	 1180	 1180	 0.0	 0.0	 1	 -30.0	 30.0;
	2148	 480	 0.074578	 0.197279	 0.003	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	2168	 480	 0.005039	 0.01285	 0.0002	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 480	 0.003527	 0.01285	 0.0015	 2216	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	1569	 480	 0.015042	 0.040539	 0.0164	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	2169	 480	 0.005039	 0.01285	 0.0002	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	2170	 480	 0.003023	 0.013102	 0.0002	 2196	 2196	 2196	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 481	 0.00332	 0.015328	 0.0267	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 482	 0.047972	 0.124465	 0.0037	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	2509	 483	 0.007307	 0.029226	 0.0316	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 483	 0.006551	 0.01285	 0.0128	 2109	 2109	 2109	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 483	 0.001512	 0.004283	 0.0001	 6697	 6697	 6697	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 483	 0.001008	 0.003779	 0.0001	 7777	 7777	 7777	 0.0	 0.0	 1	 -30.0	 30.0;
	965	 484	 0.010864	 0.045062	 0.0305	 641	 641	 641	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 484	 0.010494	 0.04321	 0.0245	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	3545	 485	 0.108088	 0.349458	 0.0048	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 486	 0.010078	 0.025447	 0.0003	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 487	 0.04642	 0.125432	 0.0058	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 487	 0.022963	 0.062346	 0.0058	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 488	 0.011338	 0.027715	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	3639	 488	 0.018896	 0.053666	 0.0	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	2263	 489	 0.035525	 0.097758	 0.0011	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	2618	 489	 0.049131	 0.135047	 0.0013	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 490	 0.010864	 0.070494	 0.0006	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 491	 2.4e-05	 9.7e-05	 0.001	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3571	 492	 0.028496	 0.059461	 0.0006	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 492	 0.074074	 0.152683	 0.002	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	594	 493	 9.9e-05	 0.000198	 0.0223	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 494	 1.4e-05	 0.000145	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 495	 7e-06	 0.000159	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 496	 1.4e-05	 0.000166	 0.0058	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 497	 1.4e-05	 0.00018	 0.0058	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2158	 498	 0.001008	 0.00252	 0.0019	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 502	 0.018148	 0.085185	 0.004	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	2562	 502	 0.035679	 0.097901	 0.0047	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 502	 0.056173	 0.23963	 0.0121	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 503	 0.017654	 0.074815	 0.0076	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 503	 0.017778	 0.074074	 0.0081	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	741	 504	 0.044815	 0.11642	 0.0008	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 504	 0.040494	 0.104198	 0.0049	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	1817	 504	 0.009753	 0.026049	 0.0013	 1243	 1243	 1243	 0.0	 0.0	 1	 -30.0	 30.0;
	5123	 504	 0.000123	 0.001235	 0.0002	 27851	 27851	 27851	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 504	 0.009753	 0.026049	 0.0002	 1243	 1243	 1243	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 506	 0.020408	 0.066264	 0.0013	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 506	 0.009322	 0.02973	 0.0019	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 507	 0.010124	 0.025679	 0.0011	 1077	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 507	 0.010247	 0.025926	 0.0013	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 508	 0.047329	 0.086634	 0.0007	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	1564	 509	 0.021111	 0.121111	 0.006	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 509	 0.016173	 0.091235	 0.005	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 510	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5621	 510	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 511	 0.000251	 0.002177	 0.2187	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3093	 512	 9.9e-05	 0.000741	 0.0	 34920	 34920	 34920	 0.0	 0.0	 1	 -30.0	 30.0;
	2578	 513	 0.013933	 0.049685	 0.0097	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 514	 0.001084	 0.014247	 0.491	 2232	 2232	 2232	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 514	 0.000492	 0.006489	 0.2224	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3236	 514	 7e-06	 0.000152	 0.0058	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2969	 514	 0.001112	 0.01462	 0.5054	 2175	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	3154	 514	 0.000492	 0.006489	 0.2238	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3237	 514	 7e-06	 0.000104	 0.0029	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 515	 0.023086	 0.061111	 0.0029	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	2587	 515	 0.024938	 0.065802	 0.0031	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 516	 0.099585	 0.18229	 0.0019	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5456	 517	 0.011842	 0.032502	 0.0004	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	2267	 518	 0.031746	 0.072058	 0.001	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	3213	 518	 0.028219	 0.069539	 0.0015	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 519	 0.088183	 0.199295	 0.0021	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	4198	 520	 0.044568	 0.11321	 0.0053	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	4310	 520	 0.054691	 0.140864	 0.0066	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1407	 521	 0.016377	 0.102041	 0.0017	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2890	 521	 0.018392	 0.084908	 0.0021	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	2926	 522	 0.011766	 0.048702	 0.0026	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 521	 0.005719	 0.022726	 0.0023	 1260	 1260	 1260	 0.0	 0.0	 1	 -30.0	 30.0;
	3838	 522	 0.040816	 0.117914	 0.0061	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	4266	 521	 0.044596	 0.113631	 0.0037	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 522	 0.004661	 0.018392	 0.0022	 1557	 1557	 1557	 0.0	 0.0	 1	 -30.0	 30.0;
	2926	 521	 0.013883	 0.056009	 0.0025	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	1346	 523	 0.001264	 0.00964	 0.0375	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1408	 523	 0.001264	 0.008415	 0.0152	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 523	 0.002627	 0.012188	 0.0218	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 523	 0.001063	 0.007064	 0.0132	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 523	 0.002489	 0.016711	 0.0304	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 523	 0.0016	 0.014933	 0.0537	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1346	 523	 0.001264	 0.009659	 0.0405	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	959	 524	 0.000501	 0.005472	 0.1155	 1429.0	 1429.0	 1429.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2917	 524	 0.000429	 0.004737	 0.1011	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1132	 526	 0.040564	 0.086924	 0.001	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	1922	 526	 0.04006	 0.107836	 0.0012	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 526	 0.035651	 0.095087	 0.0011	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 526	 0.011842	 0.031746	 0.0003	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	3316	 526	 0.015117	 0.032502	 0.0004	 824	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	4248	 526	 0.07357	 0.192744	 0.0021	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	4693	 526	 0.013303	 0.035072	 0.0004	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	4769	 526	 0.058201	 0.147644	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 526	 0.012572	 0.033207	 0.0003	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	5700	 526	 0.065508	 0.233812	 0.0033	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	4692	 526	 0.010834	 0.035777	 0.0004	 790	 790	 790	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 527	 0.000553	 0.003714	 0.0116	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1446	 527	 0.003951	 0.020148	 0.0511	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 527	 0.007447	 0.034884	 0.0628	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 527	 0.000632	 0.004286	 0.0081	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 527	 0.000553	 0.003714	 0.0121	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 527	 0.001106	 0.005353	 0.0091	 5617	 5617	 5617	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 527	 0.000672	 0.004543	 0.0081	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	529	 528	 0.003149	 0.007962	 0.0001	 3553	 3553	 3553	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 528	 0.018166	 0.094533	 0.0071	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1843	 528	 0.019425	 0.101209	 0.0084	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 530	 0.003527	 0.008818	 0.0003	 3109	 3109	 3109	 0.0	 0.0	 1	 -30.0	 30.0;
	532	 531	 2.5e-05	 0.000252	 0.0003	 113138	 113138	 113138	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 531	 0.013754	 0.025176	 0.0118	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 531	 0.011276	 0.02064	 0.0109	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 534	 0.008314	 0.01683	 0.0143	 1527	 1527	 1527	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 533	 0.008314	 0.016528	 0.014	 1549	 1549	 1549	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 535	 0.008852	 0.029938	 0.0015	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	1356	 535	 0.009049	 0.023296	 0.0011	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 535	 0.000123	 0.000741	 0.0	 39543	 39543	 39543	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 535	 0.017531	 0.047778	 0.0023	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 535	 0.010988	 0.02963	 0.0015	 940	 940	 940	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 535	 0.004444	 0.008889	 0.0003	 2989	 2989	 2989	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 535	 0.009259	 0.029333	 0.0015	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 535	 0.009753	 0.040617	 0.0021	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 535	 0.006049	 0.025062	 0.0013	 1153	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 536	 0.004188	 0.027872	 0.0516	 485.0	 485.0	 485.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 536	 0.00322	 0.022183	 0.0395	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 536	 0.00322	 0.022183	 0.0395	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 537	 0.035049	 0.095617	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	1321	 537	 0.032099	 0.081728	 0.0039	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 537	 0.049876	 0.121235	 0.0058	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	1194	 538	 0.034517	 0.092719	 0.003	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 538	 0.06198	 0.16125	 0.0021	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 539	 0.053086	 0.144321	 0.0068	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 540	 0.029012	 0.081605	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 541	 0.008115	 0.014854	 0.0098	 1745	 1745	 1745	 0.0	 0.0	 1	 -30.0	 30.0;
	1346	 542	 0.000217	 0.00081	 0.1013	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1346	 543	 0.000257	 0.000988	 0.1215	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2091	 544	 0.02037	 0.05358	 0.0045	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	2683	 544	 0.017901	 0.057778	 0.0028	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 544	 0.000988	 0.004074	 0.0005	 7234	 7234	 7234	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 544	 0.005185	 0.016049	 0.0008	 1798	 1798	 1798	 0.0	 0.0	 1	 -30.0	 30.0;
	2892	 545	 0.003358	 0.02242	 0.0415	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 545	 0.003437	 0.022933	 0.0425	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1685	 546	 0.05417	 0.111111	 0.0012	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 546	 0.06387	 0.131318	 0.0014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 547	 0.02973	 0.081129	 0.0009	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 547	 0.031746	 0.086924	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 548	 0.061225	 0.153691	 0.0015	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 548	 0.099043	 0.241547	 0.0023	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	3071	 549	 0.001764	 0.005039	 0.0001	 5697	 5697	 5697	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 550	 0.052154	 0.112623	 0.0013	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1543	 551	 0.012346	 0.032716	 0.0016	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 551	 0.075309	 0.190988	 0.0091	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3569	 551	 0.015926	 0.041605	 0.0019	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 551	 0.020123	 0.051111	 0.0024	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	1543	 551	 0.015679	 0.040494	 0.0019	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 552	 0.045352	 0.114386	 0.0013	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	1556	 552	 0.060721	 0.154699	 0.0021	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	3394	 553	 0.03351	 0.069539	 0.0067	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	5707	 553	 0.031368	 0.064752	 0.001	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 554	 0.017133	 0.054422	 0.0006	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	4899	 554	 0.144873	 0.279919	 0.003	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 554	 0.017133	 0.054422	 0.0006	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 556	 0.002145	 0.009679	 0.017	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 555	 0.002125	 0.009576	 0.0168	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 557	 0.000691	 0.001383	 0.2045	 20021	 20021	 20021	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 558	 0.001699	 0.011299	 0.0213	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 559	 0.054674	 0.175359	 0.002	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 559	 0.099017	 0.282187	 0.003	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	3642	 559	 0.029226	 0.09297	 0.001	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	4375	 559	 0.003023	 0.010078	 0.0099	 2807	 2807	 2807	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 560	 0.003527	 0.00907	 0.0001	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 561	 0.045603	 0.11615	 0.0013	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	1133	 562	 0.050864	 0.130617	 0.006	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 562	 0.040741	 0.103704	 0.0049	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	2658	 563	 0.04006	 0.109599	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4800	 563	 0.035777	 0.09549	 0.0011	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	1446	 564	 0.0048	 0.022637	 0.0405	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3088	 564	 0.003319	 0.015664	 0.0263	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 565	 0.031267	 0.19413	 0.0025	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	2981	 565	 0.003779	 0.010078	 0.0005	 2826	 2826	 2826	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 565	 0.031267	 0.194104	 0.0025	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 566	 0.024938	 0.068148	 0.0032	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	4235	 566	 0.024198	 0.065802	 0.0031	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2446	 567	 0.029151	 0.079289	 0.0009	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5806	 567	 0.030562	 0.083371	 0.0009	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	4536	 568	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	2311	 569	 0.016881	 0.055682	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	5031	 569	 0.065256	 0.219451	 0.0025	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	585	 570	 0.048803	 0.131973	 0.0015	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 570	 0.0839	 0.233308	 0.003	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 571	 0.015369	 0.037541	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	3324	 571	 0.094986	 0.236332	 0.0025	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 572	 0.063668	 0.160393	 0.0018	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 572	 0.020408	 0.052658	 0.001	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 574	 0.053704	 0.141111	 0.0066	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 574	 0.046543	 0.118025	 0.0055	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 574	 0.02	 0.054691	 0.0026	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 574	 0.022593	 0.071852	 0.0036	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	3114	 574	 0.042716	 0.116667	 0.0055	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5703	 574	 0.021728	 0.059506	 0.0028	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	1576	 575	 0.175697	 0.321613	 0.003	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 575	 0.123346	 0.225783	 0.002	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	1826	 576	 0.001696	 0.003104	 0.0005	 8751	 8751	 8751	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 577	 0.000514	 0.001541	 0.1144	 19054	 19054	 19054	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 578	 0.00252	 0.006878	 0.0001	 4152	 4152	 4152	 0.0	 0.0	 1	 -30.0	 30.0;
	1212	 580	 0.00324	 0.034272	 0.1336	 892	 892	 892	 0.0	 0.0	 1	 -30.0	 30.0;
	1726	 581	 0.005077	 0.023783	 0.0425	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3253	 581	 0.002368	 0.018825	 0.0511	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3648	 581	 0.003279	 0.043101	 0.1822	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 581	 0.0014	 0.011018	 0.0192	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 579	 4.8e-05	 8.8e-05	 0.004	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 582	 0.000102	 0.001632	 0.0491	 2450.0	 2450.0	 2450.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 583	 0.005291	 0.011338	 0.0102	 2290	 2290	 2290	 0.0	 0.0	 1	 -30.0	 30.0;
	3040	 584	 0.005543	 0.014109	 0.0002	 1948	 1948	 1948	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 585	 0.038196	 0.104182	 0.0012	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	1157	 586	 0.033762	 0.104056	 0.001	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 586	 0.017637	 0.050139	 0.001	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	5278	 586	 0.010078	 0.031494	 0.0	 893	 893	 893	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 587	 0.024213	 0.076921	 0.0015	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	2494	 587	 0.018645	 0.059713	 0.0007	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 588	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 589	 0.027407	 0.071852	 0.0034	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 589	 0.017407	 0.045556	 0.0021	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 590	 0.001027	 0.017738	 0.0101	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 590	 0.000318	 0.002424	 0.0052	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1524	 590	 0.001027	 0.017738	 0.0101	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 590	 0.000397	 0.002657	 0.0051	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 591	 0.000101	 0.00252	 0.0	 11707	 11707	 11707	 0.0	 0.0	 1	 -30.0	 30.0;
	3207	 592	 0.058201	 0.15873	 0.0017	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 592	 0.119602	 0.316553	 0.0038	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 592	 0.119577	 0.316503	 0.004	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	2643	 593	 0.035777	 0.097506	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 595	 0.000637	 0.008255	 0.2123	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 595	 0.000688	 0.009993	 0.257	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 595	 0.000443	 0.006454	 0.1675	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 595	 0.000688	 0.009993	 0.257	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 595	 0.000464	 0.006766	 0.1762	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 595	 0.000464	 0.006773	 0.1762	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 596	 0.008519	 0.016049	 0.0007	 1635	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 597	 0.013328	 0.059864	 0.0006	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 598	 0.001025	 0.004614	 0.0081	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 599	 0.052963	 0.205926	 0.0119	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	1853	 600	 0.045855	 0.116402	 0.0013	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5731	 600	 0.019148	 0.053162	 0.0006	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	2686	 601	 0.007778	 0.028642	 0.0015	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 601	 0.024284	 0.063691	 0.003	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 602	 0.023126	 0.042332	 0.0004	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 602	 0.013354	 0.028219	 0.0398	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	2061	 602	 0.061275	 0.155707	 0.0047	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	3853	 602	 0.001461	 0.004006	 0.0007	 7133	 7133	 7133	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 602	 0.01232	 0.034543	 0.0298	 830	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	3364	 603	 0.001934	 0.01293	 0.024	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 603	 0.004642	 0.03089	 0.0573	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 606	 0.000968	 0.001975	 0.0081	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 605	 0.000968	 0.001975	 0.001	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 604	 0.000968	 0.001975	 0.001	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2379	 607	 0.076846	 0.209373	 0.0024	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3944	 607	 0.091711	 0.258251	 0.0049	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4326	 607	 0.026707	 0.072562	 0.0008	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	2784	 608	 0.00348	 0.023956	 0.0456	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3603	 608	 0.002449	 0.017106	 0.0304	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 608	 0.006001	 0.041452	 0.078	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 609	 0.027715	 0.184429	 0.0025	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4367	 609	 0.006551	 0.04258	 0.0006	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 611	 4e-05	 0.000198	 0.0	 153231	 153231	 153231	 0.0	 0.0	 1	 -30.0	 30.0;
	3339	 612	 0.047407	 0.129383	 0.006	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 613	 0.075082	 0.226757	 0.0026	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 613	 0.03099	 0.114386	 0.0014	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	3089	 614	 0.04006	 0.109095	 0.0009	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2265	 615	 0.001205	 0.005511	 0.0091	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 616	 0.01438	 0.065067	 0.1154	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 616	 0.003538	 0.016484	 0.0273	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 616	 0.012634	 0.056573	 0.1008	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5319	 616	 0.003516	 0.016158	 0.0273	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 616	 0.00316	 0.014914	 0.0253	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 616	 0.007704	 0.034647	 0.0607	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 616	 0.002489	 0.016257	 0.0294	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1007	 616	 0.003457	 0.015467	 0.0273	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 617	 0.006579	 0.049467	 1.0137	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 617	 0.001357	 0.014821	 0.3321	 1171.0	 1171.0	 1171.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 619	 0.000504	 0.003023	 0.0	 9349	 9349	 9349	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 618	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 620	 0.003527	 0.006551	 0.0076	 3851	 3851	 3851	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 621	 0.002771	 0.007307	 0.0077	 3667	 3667	 3667	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 622	 0.022928	 0.060721	 0.0007	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 623	 0.04258	 0.119678	 0.001	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 623	 0.031494	 0.082137	 0.001	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 623	 0.004787	 0.013605	 0.001	 2048	 2048	 2048	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 623	 0.033006	 0.122449	 0.001	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 624	 0.00352	 0.014823	 0.0263	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	823	 625	 0.004334	 0.011489	 0.013	 2405	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 625	 0.009322	 0.058957	 0.0033	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 625	 0.017385	 0.110607	 0.004	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 628	 0.001111	 0.003244	 0.0014	 8880	 8880	 8880	 0.0	 0.0	 1	 -30.0	 30.0;
	5192	 629	 0.018395	 0.050099	 0.0023	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 632	 2e-05	 0.000198	 0.0223	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 631	 9.9e-05	 0.000296	 0.004	 99170	 99170	 99170	 0.0	 0.0	 1	 -30.0	 30.0;
	4231	 633	 0.024389	 0.066516	 0.0007	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 634	 0.000756	 0.002016	 0.0	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 635	 0.157974	 0.39229	 0.0049	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	4282	 635	 0.215495	 0.516578	 0.0058	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	2461	 636	 0.01033	 0.028219	 0.0003	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 636	 0.066264	 0.221718	 0.0027	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 636	 0.027211	 0.08642	 0.001	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 637	 0.084656	 0.214916	 0.003	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 637	 0.049131	 0.124465	 0.001	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 637	 0.066264	 0.147644	 0.002	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 638	 0.035926	 0.100864	 0.0049	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 638	 0.02037	 0.058272	 0.0028	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 639	 0.000504	 0.001008	 0.001	 26199	 26199	 26199	 0.0	 0.0	 1	 -30.0	 30.0;
	5065	 640	 0.000936	 0.006236	 0.0146	 441.0	 441.0	 441.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 645	 0.000217	 0.00079	 0.0	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 644	 0.000217	 0.00079	 0.0	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 643	 0.000237	 0.000988	 0.0	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 642	 0.000237	 0.000988	 0.0	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 641	 0.000257	 0.000988	 0.0	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 646	 0.000111	 0.001026	 0.0884	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 648	 0.010859	 0.033384	 0.0319	 842	 842	 842	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 649	 0.013667	 0.025018	 0.0102	 1036	 1036	 1036	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 650	 0.014521	 0.026581	 0.0111	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 651	 0.039136	 0.164198	 0.0083	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	4282	 652	 0.094054	 0.195112	 0.0064	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 653	 0.025951	 0.083648	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 653	 0.007811	 0.023432	 0.0137	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 653	 0.019652	 0.082892	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	4931	 653	 0.018443	 0.068178	 0.0152	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 653	 0.004283	 0.016881	 0.0005	 1696	 1696	 1696	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 654	 0.006652	 0.028269	 0.0137	 1017	 1017	 1017	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 654	 0.002419	 0.0064	 0.0072	 4316	 4316	 4316	 0.0	 0.0	 1	 -30.0	 30.0;
	3181	 655	 0.039808	 0.101537	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3577	 655	 0.059965	 0.152431	 0.001	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 655	 0.042832	 0.121189	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 656	 0.011358	 0.031852	 0.0015	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 657	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 658	 0.026405	 0.082792	 0.0072	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 658	 0.078962	 0.217737	 0.0167	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	2861	 658	 0.009977	 0.060393	 0.0031	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	4372	 658	 0.035796	 0.065524	 0.0048	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 658	 0.015344	 0.039103	 0.0014	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 658	 0.041572	 0.119426	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	1078	 658	 0.1581	 0.413883	 0.0054	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	2191	 658	 0.043008	 0.113782	 0.0031	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 658	 0.006198	 0.037642	 0.002	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 659	 0.001636	 0.010939	 0.0216	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2173	 660	 0.07677	 0.194835	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 660	 0.071651	 0.131155	 0.0098	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 661	 0.044344	 0.269085	 0.0001	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	1211	 662	 0.004535	 0.026707	 0.0045	 1090	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 662	 0.008062	 0.015369	 0.0117	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	1211	 662	 0.015747	 0.039909	 0.0005	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	2744	 663	 0.000257	 0.001758	 0.003	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 663	 0.00162	 0.011121	 0.0213	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 664	 0.00252	 0.006047	 0.0001	 4374	 4374	 4374	 0.0	 0.0	 1	 -30.0	 30.0;
	1434	 665	 0.03477	 0.094734	 0.001	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 665	 0.003779	 0.008818	 0.0001	 3171	 3171	 3171	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 666	 0.003173	 0.008432	 0.0005	 3297	 3297	 3297	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 667	 0.011185	 0.030482	 0.0014	 934	 934	 934	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 672	 1.4e-05	 0.000173	 0.0982	 183736	 183736	 183736	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 671	 1.4e-05	 0.000187	 0.0809	 170060	 170060	 170060	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 670	 1.4e-05	 0.000201	 0.0058	 158275	 158275	 158275	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 669	 1.4e-05	 0.000201	 0.0058	 158275	 158275	 158275	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 673	 0.038297	 0.171403	 0.0026	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	2530	 673	 0.119929	 0.324767	 0.0003	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	2555	 673	 0.044596	 0.286722	 0.0003	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	2766	 673	 0.131771	 0.295792	 0.0038	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	2230	 673	 0.006551	 0.017133	 0.0002	 1698	 1698	 1698	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 674	 0.005215	 0.035002	 0.0638	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2769	 675	 0.020494	 0.064938	 0.0031	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 675	 0.016914	 0.072593	 0.0036	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 675	 0.021482	 0.067284	 0.0032	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 675	 0.016914	 0.072716	 0.0036	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 676	 0.02037	 0.085185	 0.0044	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 676	 0.015309	 0.066296	 0.0029	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 676	 0.046543	 0.147531	 0.0072	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 677	 0.064349	 0.163291	 0.0018	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	3849	 677	 0.027916	 0.112976	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 677	 0.09229	 0.251852	 0.0033	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 678	 0.038801	 0.079617	 0.0009	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 679	 0.039506	 0.079012	 0.0036	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	1756	 680	 0.045603	 0.12522	 0.001	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 681	 0.001397	 0.009306	 0.0172	 340.0	 340.0	 340.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2713	 681	 0.003415	 0.021827	 0.04	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2822	 682	 0.015815	 0.042765	 0.0038	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 682	 0.01721	 0.046852	 0.0028	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 683	 2e-05	 9.9e-05	 0.0	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4938	 684	 0.012346	 0.034691	 0.0032	 807	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	2681	 685	 0.051111	 0.129383	 0.0062	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 686	 0.00952	 0.017427	 0.016	 1443	 1443	 1443	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 686	 0.009515	 0.017417	 0.0159	 1444	 1444	 1444	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 686	 0.008818	 0.016377	 0.0112	 1541	 1541	 1541	 0.0	 0.0	 1	 -30.0	 30.0;
	1319	 687	 0.043336	 0.082137	 0.0008	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 687	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 688	 0.0194	 0.081885	 0.0013	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	2001	 689	 0.022222	 0.047407	 0.0002	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 689	 0.034568	 0.075062	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 690	 7e-06	 0.000132	 0.0058	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4206	 691	 0.000171	 0.000313	 0.001	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 692	 7e-06	 0.000104	 0.0029	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 693	 0.000525	 0.000961	 0.0032	 27692	 27692	 27692	 0.0	 0.0	 1	 -30.0	 30.0;
	2349	 694	 0.000483	 0.000885	 0.0031	 30077	 30077	 30077	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 695	 0.047871	 0.145377	 0.001	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	4586	 696	 0.000237	 0.000573	 0.078	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 697	 0.00716	 0.023086	 0.0014	 1255	 1255	 1255	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 697	 0.041975	 0.114568	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	2336	 699	 0.000869	 0.003891	 0.0116	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2336	 698	 0.000869	 0.003891	 0.0116	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	741	 700	 0.031099	 0.097333	 0.0045	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 700	 0.016667	 0.087037	 0.0046	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5581	 700	 0.00942	 0.025679	 0.0011	 1266	 1266	 1266	 0.0	 0.0	 1	 -30.0	 30.0;
	4686	 700	 0.013951	 0.057901	 0.0033	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5209	 706	 0.002706	 0.0128	 0.0213	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3896	 708	 0.014074	 0.051235	 0.0119	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 707	 0.023704	 0.064	 0.0031	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 708	 0.009136	 0.05358	 0.0028	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 708	 0.016296	 0.044198	 0.0045	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 707	 0.02337	 0.062988	 0.0053	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 709	 0.00237	 0.015803	 0.0294	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 710	 0.074074	 0.158025	 0.0012	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 710	 0.02321	 0.051852	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 710	 0.044444	 0.09679	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 710	 0.108938	 0.258025	 0.001	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 711	 0.010988	 0.03	 0.0015	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 716	 0.069753	 0.176914	 0.0083	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2731	 716	 0.030741	 0.094568	 0.0082	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	2912	 715	 0.005309	 0.01284	 0.0138	 2138	 2138	 2138	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 715	 0.010321	 0.037247	 0.0019	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	5436	 715	 0.010963	 0.037037	 0.0019	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 715	 0.010321	 0.037235	 0.0019	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 717	 0.003554	 0.024524	 0.0466	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 717	 0.006493	 0.043265	 0.08	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4142	 717	 0.007921	 0.053985	 0.1013	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 717	 0.004543	 0.030262	 0.0557	 485.0	 485.0	 485.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 718	 0.000741	 0.002099	 0.0002	 13344	 13344	 13344	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 719	 0.038095	 0.105115	 0.0012	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 720	 0.001126	 0.004978	 0.0091	 6053	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 721	 0.079869	 0.202822	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 721	 0.079693	 0.202066	 0.0023	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1186	 721	 0.035777	 0.090955	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 721	 0.014865	 0.037793	 0.0004	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 722	 0.002963	 0.012346	 0.0025	 2340	 2340	 2340	 0.0	 0.0	 1	 -30.0	 30.0;
	721	 723	 0.007811	 0.019148	 0.0002	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	3567	 724	 0.032346	 0.088148	 0.004	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 724	 0.024321	 0.06642	 0.0031	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 725	 0.011086	 0.028723	 0.0003	 988	 988	 988	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 725	 0.022424	 0.057445	 0.0032	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 725	 0.027967	 0.071051	 0.0008	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 726	 0.003536	 0.01683	 0.0284	 306.0	 306.0	 306.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 726	 0.001541	 0.009936	 0.0258	 3054	 3054	 3054	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 726	 0.008375	 0.039704	 0.0658	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 727	 0.007901	 0.020123	 0.001	 1403	 1403	 1403	 0.0	 0.0	 1	 -30.0	 30.0;
	5634	 727	 0.001975	 0.005309	 0.0003	 5354	 5354	 5354	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 728	 0.070799	 0.179894	 0.002	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 728	 0.06324	 0.181658	 0.002	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	5677	 728	 0.035273	 0.089947	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	2847	 729	 0.03225	 0.082389	 0.0046	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	4279	 729	 0.001008	 0.003779	 0.0035	 7550	 7550	 7550	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 729	 0.018392	 0.076846	 0.001	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	4278	 729	 0.001008	 0.003779	 0.0006	 7550	 7550	 7550	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 729	 0.0194	 0.079113	 0.001	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	2182	 731	 0.078357	 0.200554	 0.0023	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	2453	 731	 0.081129	 0.214916	 0.0037	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	2723	 730	 0.056185	 0.351474	 0.0047	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 730	 0.024188	 0.098262	 0.0013	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 730	 0.117158	 0.298312	 0.0033	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 730	 0.034014	 0.21542	 0.0027	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 730	 0.035777	 0.081633	 0.0039	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	2182	 731	 0.074326	 0.202066	 0.0023	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 730	 0.02318	 0.094986	 0.0012	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	4591	 730	 0.012598	 0.025951	 0.0003	 1086	 1086	 1086	 0.0	 0.0	 1	 -30.0	 30.0;
	858	 732	 0.011378	 0.053886	 0.0957	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2465	 732	 0.003457	 0.023724	 0.0445	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2655	 732	 0.008415	 0.041422	 0.0739	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 732	 0.003793	 0.017007	 0.0294	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 732	 0.004701	 0.026726	 0.0481	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2466	 732	 0.001877	 0.018252	 0.0638	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2466	 732	 0.001857	 0.017521	 0.0648	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 734	 0.022424	 0.057193	 0.0006	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 733	 0.021164	 0.056689	 0.0006	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 735	 0.021668	 0.05543	 0.0006	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 736	 0.01033	 0.043588	 0.0012	 640	 640	 640	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 736	 0.011338	 0.046359	 0.0013	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 737	 0.037037	 0.100988	 0.0052	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 738	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	5200	 739	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 740	 0.00358	 0.00716	 0.0277	 3789	 3789	 3789	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 743	 0.015679	 0.040123	 0.0015	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	1562	 744	 4.8e-05	 8.8e-05	 0.0051	 308785	 308785	 308785	 0.0	 0.0	 1	 -30.0	 30.0;
	4047	 744	 0.000533	 0.004642	 0.4647	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 747	 0.045024	 0.12522	 0.008	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 747	 0.022827	 0.061804	 0.0073	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 747	 0.034266	 0.095994	 0.001	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	5474	 747	 0.045981	 0.13351	 0.0013	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 748	 0.002827	 0.011058	 0.0192	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2713	 748	 0.002258	 0.00946	 0.0172	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 749	 0.024691	 0.062232	 0.001	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	5043	 749	 0.025951	 0.058453	 0.001	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	3667	 750	 0.03351	 0.068783	 0.001	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3617	 751	 0.00358	 0.009753	 0.0005	 2859	 2859	 2859	 0.0	 0.0	 1	 -30.0	 30.0;
	3429	 752	 0.049383	 0.13933	 0.0015	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 753	 0.000617	 0.001358	 0.0018	 19914	 19914	 19914	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 754	 0.051146	 0.129756	 0.001	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 754	 0.070547	 0.176871	 0.0165	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 754	 0.082389	 0.208869	 0.0024	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	1220	 755	 0.046107	 0.21416	 0.003	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 755	 0.094986	 0.241875	 0.003	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 755	 0.152179	 0.27866	 0.003	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	1477	 757	 0.085412	 0.216427	 0.0025	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	3441	 757	 0.068304	 0.173369	 0.002	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 758	 0.025951	 0.07231	 0.001	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	2550	 759	 0.001363	 0.009126	 0.0172	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4744	 759	 0.0016	 0.010825	 0.0203	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2550	 759	 0.001402	 0.009422	 0.0172	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4744	 759	 0.00162	 0.010963	 0.0213	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 760	 0.001153	 0.010798	 0.283	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 760	 0.00115	 0.010796	 0.283	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 761	 0.03099	 0.078861	 0.0009	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 761	 0.02328	 0.065306	 0.0008	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	4387	 761	 0.009826	 0.018141	 0.0005	 1432	 1432	 1432	 0.0	 0.0	 1	 -30.0	 30.0;
	5700	 761	 0.040312	 0.100025	 0.0011	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 762	 0.000377	 0.00069	 0.0273	 39366	 39366	 39366	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 762	 0.000336	 0.001304	 0.2906	 22986	 22986	 22986	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 763	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 764	 0.005472	 0.024889	 0.0445	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5203	 766	 0.000252	 0.000504	 0.001	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	1847	 769	 0.002137	 0.003912	 0.0002	 6823	 6823	 6823	 0.0	 0.0	 1	 -30.0	 30.0;
	1557	 770	 0.040312	 0.103804	 0.0012	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 770	 0.107811	 0.276493	 0.0035	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 771	 0.040262	 0.155757	 0.0032	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 771	 0.052406	 0.133787	 0.0015	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	340	 772	 0.03358	 0.091728	 0.0042	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 772	 0.002099	 0.005802	 0.0003	 4814	 4814	 4814	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 773	 0.029877	 0.077654	 0.0102	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	1302	 773	 0.023457	 0.066173	 0.0031	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2221	 773	 0.002222	 0.013951	 0.0013	 2103	 2103	 2103	 0.0	 0.0	 1	 -30.0	 30.0;
	2317	 773	 0.026741	 0.067815	 0.0037	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	3060	 773	 0.028272	 0.076914	 0.0045	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4115	 773	 0.006049	 0.015679	 0.0006	 1768	 1768	 1768	 0.0	 0.0	 1	 -30.0	 30.0;
	4548	 773	 0.006667	 0.01679	 0.0008	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 773	 0.004691	 0.012716	 0.0006	 2192	 2192	 2192	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 773	 0.055679	 0.199383	 0.0094	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	1302	 773	 0.022346	 0.062716	 0.0057	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	3060	 773	 0.033704	 0.091852	 0.0053	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 774	 0.002015	 0.013551	 0.0764	 449.0	 449.0	 449.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 774	 0.012484	 0.056454	 0.1002	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 774	 0.000869	 0.003911	 0.0071	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3791	 774	 0.000869	 0.003911	 0.0071	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 774	 0.001001	 0.006712	 0.0121	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 778	 0.003578	 0.013454	 0.0002	 2121	 2121	 2121	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 778	 0.00126	 0.004535	 0.0	 6273	 6273	 6273	 0.0	 0.0	 1	 -30.0	 30.0;
	3717	 778	 0.001688	 0.00446	 0.0041	 6192	 6192	 6192	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 778	 0.017385	 0.071806	 0.001	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	5647	 778	 0.001764	 0.01285	 0.0	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 778	 0.001764	 0.004535	 0.0	 6068	 6068	 6068	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 778	 0.001512	 0.010582	 0.0	 2763	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	2302	 779	 0.069035	 0.192744	 0.0	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	923	 780	 0.026815	 0.072247	 0.0036	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 780	 0.004605	 0.022	 0.0888	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	904	 781	 0.013605	 0.039808	 0.0005	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	2726	 781	 0.019148	 0.057697	 0.0007	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 781	 0.027715	 0.083144	 0.001	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	905	 781	 0.013605	 0.039557	 0.0005	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 782	 0.000614	 0.004093	 0.0278	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 785	 0.002016	 0.005543	 0.0001	 5006	 5006	 5006	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 784	 0.001008	 0.003023	 0.0001	 9266	 9266	 9266	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 783	 0.00126	 0.004787	 0.0001	 5965	 5965	 5965	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 786	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 787	 0.116679	 0.308919	 0.0037	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	2516	 787	 0.102545	 0.271529	 0.0045	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 789	 0.000523	 0.002596	 0.2992	 342.0	 342.0	 342.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5208	 790	 0.000171	 0.000313	 0.0002	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1129	 794	 0.021416	 0.058201	 0.001	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	3424	 793	 0.048123	 0.15747	 0.002	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	3463	 794	 0.03477	 0.097254	 0.002	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 793	 0.066516	 0.17284	 0.0051	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 794	 0.024691	 0.062736	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 793	 0.045603	 0.137566	 0.002	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 794	 0.026959	 0.085664	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 794	 0.001008	 0.004031	 0.0	 7106	 7106	 7106	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 794	 0.032363	 0.059241	 0.001	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 793	 0.027715	 0.089443	 0.001	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 795	 0.00484	 0.021393	 0.0385	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	810	 795	 0.001541	 0.007309	 0.0121	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 795	 0.000672	 0.004602	 0.0152	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1984	 795	 0.00243	 0.011477	 0.0192	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4780	 795	 0.002311	 0.011378	 0.0233	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 795	 0.000474	 0.002331	 0.0081	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 795	 0.002825	 0.019082	 0.0344	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 795	 0.004286	 0.029037	 0.0527	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5209	 795	 0.002074	 0.009758	 0.0162	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	959	 796	 0.001566	 0.015874	 0.4101	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 796	 0.001309	 0.01286	 0.335	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2629	 797	 0.005346	 0.009785	 0.0123	 2728	 2728	 2728	 0.0	 0.0	 1	 -30.0	 30.0;
	2349	 798	 0.030617	 0.077654	 0.006	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 798	 0.019259	 0.05321	 0.0024	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 799	 0.030234	 0.076846	 0.0009	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	4843	 800	 0.045352	 0.11489	 0.0013	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 800	 0.030234	 0.076846	 0.0009	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 801	 0.012547	 0.053666	 0.0118	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	927	 801	 0.000504	 0.001764	 0.0021	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	823	 802	 0.00252	 0.006677	 0.0075	 4138	 4138	 4138	 0.0	 0.0	 1	 -30.0	 30.0;
	3124	 802	 0.001764	 0.003779	 0.0	 7080	 7080	 7080	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 802	 0.004913	 0.012976	 0.0147	 2128	 2128	 2128	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 803	 0.026707	 0.067271	 0.001	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 804	 0.019904	 0.083144	 0.0091	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	3494	 804	 0.0451	 0.131267	 0.0172	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 804	 0.003275	 0.011086	 0.0152	 2555	 2555	 2555	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 804	 0.019652	 0.082892	 0.0091	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	944	 805	 7e-06	 0.000125	 0.0029	 552.0	 552.0	 552.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 805	 0.000693	 0.007687	 0.1704	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5209	 809	 0.000691	 0.003279	 0.0051	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 811	 0.002398	 0.004389	 0.0	 6082	 6082	 6082	 0.0	 0.0	 1	 -30.0	 30.0;
	1766	 812	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 812	 0.053666	 0.152431	 0.0002	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 814	 0.000277	 0.001916	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 813	 0.000277	 0.001936	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 815	 0.07609	 0.179642	 0.0017	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 815	 0.037289	 0.079113	 0.0009	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	850	 816	 0.007811	 0.029	 0.0303	 1013	 1013	 1013	 0.0	 0.0	 1	 -30.0	 30.0;
	5614	 816	 0.010456	 0.02905	 0.0003	 986	 986	 986	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 816	 0.008818	 0.029982	 0.0003	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 817	 0.000217	 0.001205	 0.0086	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 818	 0.00446	 0.009121	 0.0001	 2909	 2909	 2909	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 819	 0.052658	 0.134467	 0.0039	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 819	 0.025598	 0.068405	 0.0012	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 821	 0.000252	 0.001512	 0.0	 19262	 19262	 19262	 0.0	 0.0	 1	 -30.0	 30.0;
	5295	 820	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 822	 0.00162	 0.007447	 0.0132	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3735	 822	 0.000889	 0.005965	 0.0111	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2442	 823	 0.000252	 0.000504	 0.0005	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 824	 0.001008	 0.003527	 0.0043	 8292	 8292	 8292	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 824	 0.010834	 0.042328	 0.0101	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	1072	 825	 0.056941	 0.155203	 0.0017	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 825	 0.066264	 0.139582	 0.0015	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 826	 0.000533	 0.003536	 0.0061	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 827	 0.000178	 0.001185	 0.002	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 828	 0.008148	 0.020247	 0.0008	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 829	 0.002889	 0.0064	 0.0022	 4554	 4554	 4554	 0.0	 0.0	 1	 -30.0	 30.0;
	4248	 830	 0.008062	 0.022172	 0.0002	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 831	 0.13293	 0.358201	 0.0161	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 832	 0.000205	 0.002108	 0.2577	 546.0	 546.0	 546.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 833	 0.002899	 0.029385	 0.7595	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	2786	 833	 0.002045	 0.020735	 0.5343	 1524	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 834	 0.010864	 0.032346	 0.0046	 941	 941	 941	 0.0	 0.0	 1	 -30.0	 30.0;
	3094	 836	 0.028148	 0.076543	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 836	 0.019753	 0.048889	 0.0	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 837	 0.002922	 0.005348	 0.0048	 4845	 4845	 4845	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 838	 0.001906	 0.003489	 0.0	 7650	 7650	 7650	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 839	 0.008889	 0.055185	 0.0031	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	4639	 839	 0.006914	 0.043457	 0.0023	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	2236	 840	 0.021416	 0.110355	 0.0205	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3027	 840	 0.051146	 0.139078	 0.01	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 840	 0.041068	 0.135551	 0.0215	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 841	 0.05039	 0.120937	 0.0014	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 841	 0.017637	 0.048375	 0.0006	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	4778	 841	 0.010582	 0.027967	 0.0003	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	2958	 843	 0.031903	 0.058397	 0.0006	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 842	 0.053666	 0.119174	 0.0013	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5545	 842	 0.001214	 0.002222	 0.0001	 12012	 12012	 12012	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 844	 0.015092	 0.041673	 0.0005	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	2953	 845	 0.081104	 0.188234	 0.0033	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 845	 0.050139	 0.113631	 0.0013	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 846	 0.016543	 0.033951	 0.0016	 803	 803	 803	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 847	 0.000378	 0.001008	 0.0001	 27427	 27427	 27427	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 848	 0.000988	 0.002716	 0.0133	 10493	 10493	 10493	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 848	 0.000988	 0.002716	 0.0133	 10493	 10493	 10493	 0.0	 0.0	 1	 -30.0	 30.0;
	1552	 849	 0.059209	 0.148652	 0.0018	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 849	 0.069539	 0.19098	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	2999	 851	 0.011298	 0.020682	 0.0088	 1253	 1253	 1253	 0.0	 0.0	 1	 -30.0	 30.0;
	2999	 853	 0.008062	 0.017133	 0.0156	 1560	 1560	 1560	 0.0	 0.0	 1	 -30.0	 30.0;
	2999	 852	 0.007811	 0.016125	 0.0148	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 854	 0.075838	 0.19224	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3797	 854	 0.010834	 0.027715	 0.0003	 1023	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	3956	 854	 0.02973	 0.096246	 0.0218	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 854	 0.009826	 0.031242	 0.0004	 929	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 854	 0.043537	 0.154271	 0.0224	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	5548	 854	 0.01285	 0.032754	 0.0004	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 855	 0.00924	 0.060219	 0.1124	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 855	 0.009007	 0.066726	 0.1192	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 855	 0.004543	 0.030479	 0.0547	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 855	 0.004326	 0.029037	 0.0527	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 856	 0.001357	 0.017597	 0.3494	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 856	 0.001343	 0.01741	 0.3437	 1827	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 857	 0.022928	 0.141849	 0.0095	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 857	 0.022424	 0.140086	 0.0026	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 858	 0.003615	 0.024178	 0.0445	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 859	 0.001136	 0.012154	 0.2657	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 859	 0.001309	 0.013996	 0.3061	 1917.0	 1917.0	 1917.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1142	 860	 0.053918	 0.138574	 0.0016	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 861	 0.005039	 0.013102	 0.0002	 2104	 2104	 2104	 0.0	 0.0	 1	 -30.0	 30.0;
	2718	 862	 0.092441	 0.276669	 0.0072	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 862	 0.084152	 0.229781	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 862	 0.036281	 0.092215	 0.001	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 863	 0.011086	 0.038045	 0.0137	 768	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	4911	 863	 0.002268	 0.007559	 0.0075	 3854	 3854	 3854	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 865	 0.000257	 0.001521	 0.162	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 865	 0.000259	 0.000506	 0.042	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2379	 866	 0.103301	 0.282187	 0.0032	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	3450	 866	 0.062106	 0.169463	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	3904	 866	 0.068027	 0.185941	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	4326	 866	 0.078357	 0.213404	 0.0024	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 868	 0.000928	 0.006202	 0.0111	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 867	 0.000928	 0.006202	 0.0111	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 870	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5219	 869	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 871	 0.044344	 0.084656	 0.0015	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	1159	 872	 0.01033	 0.028219	 0.0013	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 873	 0.005679	 0.011358	 0.0005	 2340	 2340	 2340	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 874	 0.114135	 0.237087	 0.0026	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 874	 0.04258	 0.178634	 0.0021	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 874	 0.000756	 0.002268	 0.0	 12351	 12351	 12351	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 876	 0.009245	 0.016923	 0.0002	 1532	 1532	 1532	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 875	 0.006047	 0.011086	 0.0059	 2339	 2339	 2339	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 877	 0.005062	 0.032222	 0.0048	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 877	 0.005802	 0.035926	 0.0019	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 878	 0.031494	 0.085412	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5260	 878	 0.025951	 0.066516	 0.0007	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 878	 0.006803	 0.014361	 0.013	 1859	 1859	 1859	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 879	 0.024213	 0.081355	 0.029	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 879	 0.011338	 0.033006	 0.0133	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 881	 0.014613	 0.03099	 0.0281	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 880	 0.014613	 0.03099	 0.0283	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 882	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 883	 2e-05	 0.000198	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3393	 884	 0.079869	 0.176619	 0.0094	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3732	 884	 0.066667	 0.149232	 0.0017	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	4762	 884	 0.003023	 0.01033	 0.0002	 2662	 2662	 2662	 0.0	 0.0	 1	 -30.0	 30.0;
	5051	 884	 0.068027	 0.128748	 0.0014	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	5670	 885	 0.045352	 0.116906	 0.0013	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 885	 0.120181	 0.240867	 0.0026	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 884	 0.122701	 0.306374	 0.0034	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 886	 0.001067	 0.00723	 0.0132	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 887	 0.003358	 0.022341	 0.0415	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 886	 0.00318	 0.020938	 0.0395	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 886	 0.000928	 0.008968	 0.0314	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 887	 0.004899	 0.022815	 0.0405	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 887	 0.000889	 0.008415	 0.0314	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2210	 888	 0.004444	 0.028395	 0.0151	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 888	 0.004691	 0.029012	 0.0016	 1181	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 889	 0.007055	 0.018392	 0.0002	 1499	 1499	 1499	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 890	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 891	 0.01037	 0.026173	 0.0013	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 891	 0.070864	 0.193457	 0.0091	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 891	 0.022222	 0.056914	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 893	 0.000237	 0.001422	 0.1686	 21471	 21471	 21471	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 892	 0.000277	 0.001086	 0.1417	 27618	 27618	 27618	 0.0	 0.0	 1	 -30.0	 30.0;
	4126	 892	 0.000296	 0.000672	 0.0678	 42153	 42153	 42153	 0.0	 0.0	 1	 -30.0	 30.0;
	1312	 895	 0.002267	 0.007156	 0.0022	 4057	 4057	 4057	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 896	 0.016377	 0.102041	 0.0013	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	5224	 896	 0.008062	 0.050139	 0.0006	 599	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 897	 0.001512	 0.004787	 0.004	 5882	 5882	 5882	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 898	 0.031746	 0.133031	 0.0002	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 898	 0.020912	 0.088939	 0.001	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 899	 0.05543	 0.147644	 0.0017	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 900	 0.000286	 0.004868	 0.1762	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 901	 0.000287	 0.004892	 0.1776	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 902	 0.000283	 0.004814	 0.1762	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 903	 0.000285	 0.004843	 0.1733	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5081	 906	 0.011852	 0.045062	 0.017	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 906	 0.000864	 0.002593	 0.0136	 11095	 11095	 11095	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 907	 0.048249	 0.235702	 0.0035	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 908	 0.044321	 0.121605	 0.001	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	4164	 908	 0.028765	 0.078889	 0.0006	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 909	 0.019652	 0.080877	 0.0014	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 909	 0.017385	 0.073822	 0.0001	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	3574	 910	 0.000514	 0.001383	 0.0952	 20979	 20979	 20979	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 910	 0.000247	 0.001084	 0.1478	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 911	 0.013857	 0.025447	 0.0002	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 912	 0.00284	 0.011235	 0.001	 2617	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	3647	 913	 0.015369	 0.040816	 0.0005	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 913	 0.041068	 0.104812	 0.0012	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	2485	 914	 0.058957	 0.16125	 0.0018	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4441	 914	 0.024439	 0.102293	 0.0012	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 915	 0.006047	 0.016629	 0.014	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 918	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2315	 920	 0.013096	 0.066153	 0.12	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 919	 0.002074	 0.009956	 0.0172	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 919	 0.001533	 0.009225	 0.0172	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 920	 0.00156	 0.009343	 0.0172	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 921	 0.001452	 0.020223	 0.6741	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 921	 0.001672	 0.022177	 0.7607	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 921	 0.001447	 0.020166	 0.6721	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 921	 0.001669	 0.022168	 0.7624	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 922	 0.035525	 0.090199	 0.001	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 923	 0.031568	 0.094272	 0.0992	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	1803	 924	 0.118166	 0.243386	 0.0026	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 924	 0.015621	 0.032754	 0.0003	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 924	 0.05417	 0.183673	 0.0021	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 925	 0.040338	 0.097909	 0.0009	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 925	 0.022424	 0.053918	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 927	 0.02066	 0.088183	 0.0051	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 928	 0.014361	 0.059461	 0.006	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	2561	 928	 0.016377	 0.101537	 0.0023	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 928	 0.014361	 0.059713	 0.006	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	2561	 928	 0.016377	 0.101537	 0.0019	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3154	 929	 0.002874	 0.022174	 0.4476	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3368	 929	 0.000139	 0.001115	 0.0231	 1486.0	 1486.0	 1486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2398	 930	 0.00252	 0.006551	 0.0001	 4207	 4207	 4207	 0.0	 0.0	 1	 -30.0	 30.0;
	3839	 930	 0.011842	 0.052658	 0.001	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 931	 0.089947	 0.390527	 0.0051	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 931	 0.027463	 0.060721	 0.001	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	2173	 932	 0.009877	 0.026959	 0.0003	 1060	 1060	 1060	 0.0	 0.0	 1	 -30.0	 30.0;
	1792	 933	 0.010582	 0.063492	 0.0076	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1792	 933	 0.009902	 0.059007	 0.0157	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	4120	 934	 0.013605	 0.054926	 0.0007	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 935	 0.042328	 0.160998	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 936	 0.00322	 0.021136	 0.0395	 460.0	 460.0	 460.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3556	 936	 0.000553	 0.003694	 0.0071	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 937	 0.000494	 0.005689	 0.0142	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 936	 0.000652	 0.004504	 0.0081	 437.0	 437.0	 437.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 936	 0.000652	 0.004504	 0.0081	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 937	 0.000514	 0.005689	 0.0142	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 938	 0.000869	 0.008435	 0.0339	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 938	 0.000889	 0.008553	 0.039	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 939	 0.000686	 0.007091	 0.1747	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 939	 0.000609	 0.006378	 0.1473	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 940	 0.000686	 0.007119	 0.1747	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4603	 940	 0.000609	 0.006406	 0.1487	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 941	 0.027531	 0.074938	 0.0036	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5675	 941	 0.024198	 0.065802	 0.0031	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 942	 0.090199	 0.246158	 0.0033	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	2551	 942	 0.005291	 0.022172	 0.0006	 1366	 1366	 1366	 0.0	 0.0	 1	 -30.0	 30.0;
	3211	 942	 0.012346	 0.050894	 0.001	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3548	 942	 0.053414	 0.224238	 0.0028	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 942	 0.007811	 0.032502	 0.0004	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 942	 0.034014	 0.142857	 0.0002	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2551	 942	 0.005543	 0.022172	 0.0006	 1363	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 943	 0.002074	 0.013847	 0.0253	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 943	 0.002074	 0.013847	 0.0253	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2559	 945	 0.036533	 0.12522	 0.0014	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 946	 0.009012	 0.025062	 0.0056	 1116	 1116	 1116	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 946	 0.006667	 0.028025	 0.0015	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	3338	 948	 0.031771	 0.081809	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 948	 0.070799	 0.179894	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2462	 947	 0.075586	 0.191736	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 947	 0.070925	 0.179239	 0.0021	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 949	 0.003901	 0.009877	 0.0005	 2856	 2856	 2856	 0.0	 0.0	 1	 -30.0	 30.0;
	2708	 950	 0.003023	 0.008314	 0.0001	 3338	 3338	 3338	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 950	 0.037793	 0.097002	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 950	 0.003023	 0.008314	 0.0001	 3338	 3338	 3338	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 951	 0.020988	 0.058272	 0.0176	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 951	 0.02679	 0.072222	 0.0034	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	2597	 952	 0.018519	 0.047654	 0.0185	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	3432	 952	 0.029877	 0.080864	 0.0039	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 953	 0.016125	 0.067775	 0.0051	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 953	 0.032502	 0.083144	 0.0009	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 953	 0.025447	 0.08642	 0.0079	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 953	 0.02192	 0.04384	 0.0383	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	1047	 954	 0.00083	 0.005649	 0.0111	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 954	 0.002193	 0.014894	 0.0284	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2661	 955	 0.002145	 0.011151	 0.0203	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 955	 0.00638	 0.031486	 0.0537	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 956	 0.01037	 0.020741	 0.002	 1281	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	1374	 957	 0.002346	 0.006296	 0.0003	 4421	 4421	 4421	 0.0	 0.0	 1	 -30.0	 30.0;
	2301	 958	 0.022096	 0.08841	 0.0011	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	2316	 958	 0.025724	 0.105316	 0.0184	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	2913	 958	 0.029957	 0.121013	 0.0046	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	4411	 958	 0.009322	 0.028471	 0.0	 986	 986	 986	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 958	 0.046107	 0.130763	 0.001	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 958	 0.006047	 0.041068	 0.001	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	4411	 958	 0.004334	 0.026732	 0.001	 1091	 1091	 1091	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 959	 0.002877	 0.028829	 0.7494	 1101	 1101	 1101	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 959	 0.002188	 0.024233	 0.5227	 1311	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 959	 0.000997	 0.014175	 0.465	 2245	 2245	 2245	 0.0	 0.0	 1	 -30.0	 30.0;
	2917	 959	 0.000376	 0.002891	 0.0606	 1308.0	 1308.0	 1308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 959	 0.000976	 0.009886	 0.2541	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 959	 0.000389	 0.003951	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 959	 0.001562	 0.01912	 0.4274	 1567.0	 1567.0	 1567.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 959	 0.000998	 0.014177	 0.465	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	2917	 959	 0.000199	 0.002553	 0.0838	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 959	 0.000976	 0.009891	 0.2541	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 959	 0.000388	 0.003954	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 959	 0.000395	 0.004003	 0.104	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 959	 0.000395	 0.004003	 0.104	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 960	 0.000617	 0.001235	 0.0019	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 961	 0.00037	 0.000864	 0.0	 31602	 31602	 31602	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 962	 0.00252	 0.007811	 0.0001	 3706	 3706	 3706	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 963	 0.029383	 0.08037	 0.0037	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	5703	 963	 0.000617	 0.001728	 0.0002	 16188	 16188	 16188	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 964	 0.066264	 0.181154	 0.0024	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 964	 0.086672	 0.222021	 0.0026	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	4439	 964	 0.020584	 0.054523	 0.0006	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	2740	 965	 0.009506	 0.029383	 0.0094	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	3460	 965	 0.014691	 0.038518	 0.0121	 721	 721	 721	 0.0	 0.0	 1	 -30.0	 30.0;
	3769	 965	 0.030494	 0.079136	 0.0134	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 965	 0.022839	 0.059012	 0.0131	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	4050	 965	 0.01716	 0.081975	 0.005	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 965	 0.002593	 0.006173	 0.0042	 4437	 4437	 4437	 0.0	 0.0	 1	 -30.0	 30.0;
	2741	 965	 0.009506	 0.029506	 0.0096	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 965	 0.030494	 0.079012	 0.0153	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 966	 0.003101	 0.020859	 0.0375	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 966	 0.004978	 0.022005	 0.0359	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 966	 0.003121	 0.0208	 0.0506	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 968	 0.000499	 0.005048	 0.13	 1380.0	 1380.0	 1380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 967	 0.000499	 0.005042	 0.13	 1380.0	 1380.0	 1380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 969	 0.010985	 0.027891	 0.0014	 1015	 1015	 1015	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 969	 0.079113	 0.201058	 0.0075	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 971	 0.002193	 0.010884	 0.0197	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4133	 971	 0.004049	 0.018272	 0.0324	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3315	 972	 0.057284	 0.127778	 0.0057	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 972	 0.015309	 0.041728	 0.0019	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	2263	 973	 0.091711	 0.291509	 0.0034	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 973	 0.193139	 0.35354	 0.0037	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 973	 0.056437	 0.143109	 0.0016	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 973	 0.049131	 0.124969	 0.0078	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	4812	 973	 0.021416	 0.054422	 0.0006	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	1248	 974	 0.011032	 0.050442	 0.0871	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2088	 974	 0.001481	 0.013926	 0.0516	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2088	 974	 0.001481	 0.013926	 0.0516	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2773	 975	 0.023935	 0.0645	 0.0007	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 977	 0.000342	 0.000625	 0.0002	 41442	 41442	 41442	 0.0	 0.0	 1	 -30.0	 30.0;
	3345	 977	 0.059713	 0.152179	 0.003	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 978	 0.018645	 0.047871	 0.0013	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	2960	 979	 0.019259	 0.052593	 0.0024	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 979	 0.01716	 0.044938	 0.0021	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	5718	 979	 0.025185	 0.064691	 0.0031	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 979	 0.00716	 0.029753	 0.0016	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 979	 0.046667	 0.125926	 0.006	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 979	 0.00716	 0.02963	 0.0016	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 980	 0.0016	 0.017334	 0.4043	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 980	 0.000312	 0.004044	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 980	 0.000824	 0.010499	 0.3754	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 980	 0.00133	 0.014252	 0.3263	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 980	 0.000312	 0.004044	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 980	 0.000824	 0.010505	 0.3754	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2245	 981	 0.140111	 0.432376	 0.0055	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	2649	 981	 0.1065	 0.298388	 0.0035	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2773	 981	 0.012346	 0.05039	 0.0012	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 981	 0.024994	 0.166415	 0.0019	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 981	 0.033686	 0.073394	 0.0008	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	4282	 981	 0.009347	 0.042404	 0.0163	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	4729	 981	 0.089796	 0.228471	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	4282	 981	 0.0097	 0.04457	 0.0192	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	3810	 982	 0.001936	 0.012879	 0.0243	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 983	 0.023432	 0.074578	 0.001	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	4524	 983	 0.010834	 0.028471	 0.0	 991	 991	 991	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 983	 0.035273	 0.103301	 0.001	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 983	 0.009322	 0.023935	 0.0002	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 983	 0.019728	 0.054548	 0.0006	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	2482	 984	 0.010617	 0.044444	 0.0023	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	2822	 984	 0.044198	 0.120864	 0.0058	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2171	 985	 0.010582	 0.027463	 0.0003	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	3838	 985	 0.011842	 0.030486	 0.0003	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 987	 0.020123	 0.052839	 0.0024	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	2716	 987	 0.011482	 0.023086	 0.001	 1152	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 988	 0.001111	 0.00321	 0.0008	 8928	 8928	 8928	 0.0	 0.0	 1	 -30.0	 30.0;
	4422	 989	 0.000164	 0.001106	 0.002	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 990	 0.024188	 0.067523	 0.0031	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	3469	 991	 0.038765	 0.105062	 0.0049	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	2306	 992	 0.011358	 0.022839	 0.001	 1165	 1165	 1165	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 993	 0.001764	 0.006299	 0.0076	 4380	 4380	 4380	 0.0	 0.0	 1	 -30.0	 30.0;
	3740	 993	 0.004188	 0.007666	 0.006	 3280	 3280	 3280	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 993	 0.004289	 0.007852	 0.0061	 3203	 3203	 3203	 0.0	 0.0	 1	 -30.0	 30.0;
	4796	 993	 0.002016	 0.005039	 0.0054	 5279	 5279	 5279	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 995	 0.000336	 0.000849	 0.1448	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 994	 0.000178	 0.000691	 0.1002	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4917	 995	 0.000316	 0.001304	 0.1863	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4947	 995	 9.9e-05	 0.000612	 0.082	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3559	 996	 0.024691	 0.083648	 0.001	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	3775	 996	 0.070547	 0.239607	 0.0028	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 997	 0.065256	 0.144369	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 997	 0.024943	 0.10456	 0.001	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 998	 0.036029	 0.09675	 0.0045	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 999	 0.074074	 0.201562	 0.0022	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 999	 0.112119	 0.304107	 0.0034	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 1001	 0.019652	 0.081885	 0.0052	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 1001	 0.010078	 0.039305	 0.0	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	1256	 1001	 0.019652	 0.082389	 0.0081	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1001	 0.00252	 0.01033	 0.0	 2777	 2777	 2777	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 1002	 0.001146	 0.007111	 0.2238	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 1003	 0.001136	 0.012874	 0.2917	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 1003	 0.000547	 0.010021	 0.2801	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 1003	 0.001184	 0.012029	 0.309	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1586	 1003	 0.000369	 0.006726	 0.1892	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 1003	 0.001136	 0.012874	 0.2917	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 1003	 0.001177	 0.012029	 0.309	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 1004	 0.007531	 0.019136	 0.0042	 1475	 1475	 1475	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 1004	 0.011975	 0.031975	 0.0065	 889	 889	 889	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 1005	 0.00861	 0.015761	 0.0002	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 1006	 0.008062	 0.022172	 0.0	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	2905	 1006	 0.025951	 0.083144	 0.001	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	5319	 1008	 7.9e-05	 0.000316	 0.001	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 1009	 0.030494	 0.083333	 0.0039	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 1009	 0.031358	 0.085556	 0.004	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 1010	 0.005185	 0.014198	 0.0006	 1966	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 1011	 0.001956	 0.008844	 0.0027	 3362	 3362	 3362	 0.0	 0.0	 1	 -30.0	 30.0;
	4451	 1011	 0.000133	 0.000311	 0.0	 90021	 90021	 90021	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 1013	 0.000198	 0.000672	 0.1509	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 1012	 0.000198	 0.000691	 0.1529	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 1014	 0.000988	 0.001975	 0.0002	 13732	 13732	 13732	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 1015	 0.037284	 0.094815	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 1015	 0.024074	 0.065309	 0.0031	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 1015	 0.025185	 0.064938	 0.0031	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 1016	 0.002822	 0.013404	 0.02	 2161	 2161	 2161	 0.0	 0.0	 1	 -30.0	 30.0;
	3458	 1016	 0.010834	 0.033006	 0.0146	 852	 852	 852	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 1016	 0.000171	 0.000313	 0.0001	 83047	 83047	 83047	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 1016	 0.004082	 0.012295	 0.0107	 2287	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 1016	 0.003956	 0.018569	 0.0074	 1560	 1560	 1560	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 1017	 0.009264	 0.031822	 0.0567	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 1018	 0.023331	 0.055304	 0.0038	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	4791	 1019	 0.024074	 0.063086	 0.0031	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	1756	 1020	 0.062661	 0.158806	 0.0018	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	4147	 1020	 0.058755	 0.186143	 0.0104	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	2277	 1021	 0.003779	 0.011338	 0.0002	 2545	 2545	 2545	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 1021	 0.020282	 0.08385	 0.001	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 1022	 0.026203	 0.066264	 0.0008	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 1022	 0.001409	 0.002579	 0.0012	 10350	 10350	 10350	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 1022	 0.026203	 0.066012	 0.0008	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 1022	 0.027387	 0.067523	 0.0008	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 1024	 2e-05	 0.000198	 0.0051	 154266	 154266	 154266	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 1023	 4e-05	 0.000198	 0.0061	 151981	 151981	 151981	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 1025	 0.024444	 0.074074	 0.0089	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 1026	 0.01037	 0.022222	 0.0	 1065	 1065	 1065	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 1028	 0.00642	 0.022222	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 1027	 0.014815	 0.03358	 0.0	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	4513	 1029	 0.027617	 0.074617	 0.0036	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	2159	 1030	 0.005432	 0.010988	 0.0318	 2424	 2424	 2424	 0.0	 0.0	 1	 -30.0	 30.0;
	2809	 1030	 0.018765	 0.079506	 0.004	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 1032	 0.000756	 0.003527	 0.0053	 8516	 8516	 8516	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 1031	 0.001008	 0.004283	 0.0066	 6981	 6981	 6981	 0.0	 0.0	 1	 -30.0	 30.0;
	4095	 1033	 0.00322	 0.021689	 0.0688	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1359	 1034	 0.015117	 0.027715	 0.0018	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 1035	 0.01037	 0.027778	 0.0013	 1023	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 1036	 0.00963	 0.024815	 0.0016	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 1035	 0.009506	 0.025185	 0.0011	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	4900	 1037	 0.011482	 0.024321	 0.0109	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 1038	 0.014109	 0.046107	 0.0036	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3052	 1038	 0.038801	 0.098262	 0.0038	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 1038	 0.024439	 0.06198	 0.0007	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 1038	 0.014109	 0.046107	 0.0036	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3053	 1038	 0.039053	 0.098765	 0.004	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 1038	 0.024188	 0.060972	 0.0007	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	3782	 1038	 0.011086	 0.030738	 0.0012	 877	 877	 877	 0.0	 0.0	 1	 -30.0	 30.0;
	3782	 1038	 0.011086	 0.028219	 0.0014	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 1039	 0.003516	 0.016415	 0.0273	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3176	 1039	 0.004168	 0.028346	 0.0537	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3351	 1039	 0.001936	 0.00883	 0.0445	 3425	 3425	 3425	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 1039	 0.008099	 0.036603	 0.0901	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5013	 1039	 0.000948	 0.005886	 0.0289	 5192	 5192	 5192	 0.0	 0.0	 1	 -30.0	 30.0;
	5014	 1039	 0.000948	 0.005748	 0.0304	 5314	 5314	 5314	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 1039	 0.002311	 0.015763	 0.0435	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 1039	 0.000336	 0.002331	 0.004	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 1039	 0.000211	 0.001199	 0.0405	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 1039	 0.000209	 0.001189	 0.0405	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 1040	 2.1e-05	 0.000208	 0.0058	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 1040	 0.00126	 0.014141	 0.2845	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 1041	 7.9e-05	 0.000859	 0.0173	 1204.0	 1204.0	 1204.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 1042	 0.001904	 0.021302	 0.4679	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 1041	 0.001517	 0.01687	 0.3494	 1659.0	 1659.0	 1659.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 1042	 2.1e-05	 0.000187	 0.0029	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 1042	 2.1e-05	 0.000208	 0.0058	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 1040	 0.00126	 0.01412	 0.2859	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 1041	 0.000983	 0.010949	 0.2397	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3154	 1041	 0.001711	 0.017348	 0.4476	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 1041	 0.001281	 0.018476	 0.491	 1720	 1720	 1720	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 1041	 0.001274	 0.018324	 0.4837	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 1046	 0.002268	 0.004535	 0.0029	 5823	 5823	 5823	 0.0	 0.0	 1	 -30.0	 30.0;
	2278	 1046	 0.024691	 0.063492	 0.0033	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	3303	 1046	 0.131771	 0.345427	 0.0075	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 1046	 0.056185	 0.182162	 0.0038	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4414	 1046	 0.164777	 0.432855	 0.0096	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 1046	 0.026455	 0.070043	 0.004	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 1045	 0.011086	 0.028219	 0.0003	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	1102	 1046	 0.001738	 0.005442	 0.0058	 5169	 5169	 5169	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 1045	 0.010985	 0.028093	 0.0003	 979	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 1045	 0.002016	 0.004031	 0.0033	 6551	 6551	 6551	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 1045	 0.037793	 0.09801	 0.0017	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 1047	 0.002943	 0.02001	 0.0375	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 1047	 0.005926	 0.04079	 0.077	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3756	 1047	 0.004571	 0.030552	 0.0557	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4886	 1047	 0.002121	 0.009661	 0.0162	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 1047	 0.002969	 0.013217	 0.0233	 400.0	 400.0	 400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 1047	 0.005551	 0.025146	 0.0445	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 1048	 0.01037	 0.028395	 0.0013	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 1048	 0.010247	 0.028395	 0.0013	 1001	 1001	 1001	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 1049	 0.006954	 0.049307	 0.0161	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 1049	 0.00257	 0.015949	 0.0282	 1828	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 1050	 0.000409	 0.005409	 0.1877	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2467	 1050	 0.001371	 0.013871	 0.361	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 1050	 0.002154	 0.021884	 0.566	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 1050	 0.000416	 0.005443	 0.1877	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2467	 1050	 0.001364	 0.01383	 0.3596	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 1050	 0.002154	 0.021877	 0.566	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 1052	 0.000968	 0.002943	 0.3453	 9991	 9991	 9991	 0.0	 0.0	 1	 -30.0	 30.0;
	1270	 1052	 0.000217	 0.000849	 0.0931	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3168	 1052	 0.001205	 0.002746	 0.4668	 10322	 10322	 10322	 0.0	 0.0	 1	 -30.0	 30.0;
	3948	 1052	 0.000454	 0.002331	 0.0516	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 1052	 0.001284	 0.0096	 0.038	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5038	 1051	 0.001225	 0.006104	 0.0203	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1269	 1051	 0.000257	 0.000849	 0.1893	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3947	 1051	 0.000553	 0.002548	 0.0486	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 1052	 0.001284	 0.00956	 0.038	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 1052	 0.000909	 0.00879	 0.039	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 1052	 0.000533	 0.005096	 0.0248	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 1053	 0.001764	 0.003527	 0.0005	 7488	 7488	 7488	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 1054	 0.000277	 0.002618	 0.0693	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2411	 1055	 0.058453	 0.13026	 0.001	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	4424	 1055	 0.069035	 0.16906	 0.0026	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 1056	 0.016629	 0.04258	 0.0005	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 1062	 0.011235	 0.025679	 0.0113	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 1063	 0.045926	 0.11679	 0.0055	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 1063	 0.037284	 0.100617	 0.0049	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 1063	 0.032778	 0.088963	 0.0074	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 1063	 0.029518	 0.074827	 0.0034	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 1064	 0.007802	 0.052444	 0.1018	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 1064	 0.003101	 0.020563	 0.0385	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3756	 1064	 0.003761	 0.025235	 0.0456	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 1064	 0.008889	 0.032197	 0.0537	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 1064	 0.01442	 0.071763	 0.1291	 372.0	 372.0	 372.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4997	 1065	 0.08516	 0.17682	 0.0019	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 1066	 0.000381	 0.007008	 0.2079	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 1067	 0.000374	 0.006434	 0.2209	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2004	 1068	 0.014361	 0.041824	 0.0006	 688	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	2267	 1068	 0.106576	 0.275384	 0.0031	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	4934	 1068	 0.022676	 0.070043	 0.0013	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 1068	 0.021164	 0.057949	 0.0001	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	2831	 1069	 0.001679	 0.017284	 0.0582	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2831	 1069	 0.001501	 0.018568	 0.0562	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 1070	 0.066012	 0.134543	 0.0014	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 1070	 0.06576	 0.166793	 0.0019	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 1071	 0.079113	 0.21542	 0.0024	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	2665	 1071	 0.072058	 0.150668	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 1071	 7.6e-05	 0.000151	 0.0	 179912	 179912	 179912	 0.0	 0.0	 1	 -30.0	 30.0;
	2406	 1072	 0.020408	 0.055682	 0.0006	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 1073	 0.03477	 0.078861	 0.0016	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 1074	 0.058201	 0.120534	 0.0013	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	2220	 1075	 0.168733	 0.377072	 0.004	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	3951	 1075	 0.06329	 0.171429	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	2571	 1076	 0.00079	 0.005345	 0.0354	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2701	 1076	 0.00255	 0.017084	 0.0309	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2571	 1076	 0.000745	 0.005047	 0.0349	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 1077	 0.000741	 0.009716	 0.335	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 1077	 0.000422	 0.004709	 0.0953	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 1077	 0.000741	 0.009709	 0.335	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 1077	 0.000422	 0.004758	 0.0953	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 1077	 0.000644	 0.005035	 0.1112	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2250	 1078	 0.024188	 0.063744	 0.0737	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 1078	 0.107533	 0.274654	 0.0194	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	2836	 1078	 0.017637	 0.051146	 0.0578	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	5602	 1078	 0.047109	 0.086232	 0.0012	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5603	 1078	 0.026203	 0.066516	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 1078	 0.132023	 0.291509	 0.0	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 1079	 0.004514	 0.029863	 0.1096	 439.0	 439.0	 439.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 1081	 1.4e-05	 0.000208	 0.0058	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 1080	 2.1e-05	 0.000242	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 1082	 7.4e-05	 0.001235	 0.0	 24008	 24008	 24008	 0.0	 0.0	 1	 -30.0	 30.0;
	1953	 1084	 0.035853	 0.12517	 0.0031	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	2344	 1084	 0.076594	 0.195011	 0.003	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 1085	 0.012094	 0.066264	 0.0021	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 1085	 0.041824	 0.106576	 0.004	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 1085	 0.037793	 0.122197	 0.0021	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 1085	 0.068531	 0.232804	 0.0027	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 1086	 0.002402	 0.015149	 0.0582	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2299	 1086	 0.000889	 0.005333	 0.0101	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1669	 1087	 0.004787	 0.013354	 0.0002	 2144	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	4984	 1088	 0.066541	 0.175309	 0.002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4984	 1088	 0.066692	 0.174628	 0.002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	1940	 1089	 0.002268	 0.004787	 0.0	 5574	 5574	 5574	 0.0	 0.0	 1	 -30.0	 30.0;
	5681	 1089	 0.002016	 0.004031	 0.0	 6551	 6551	 6551	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 1089	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	2742	 1090	 0.096498	 0.261779	 0.0071	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 1091	 0.057949	 0.147644	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4356	 1091	 0.040564	 0.103301	 0.0012	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 1092	 0.009383	 0.039506	 0.007	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	4288	 1092	 0.003615	 0.006617	 0.019	 4022	 4022	 4022	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 1093	 0.000751	 0.004978	 0.0091	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 1093	 0.001738	 0.011694	 0.0213	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 1093	 0.000652	 0.004346	 0.0081	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 1094	 0.000252	 0.00252	 0.0016	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	1471	 1095	 0.000252	 0.00252	 0.0017	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 1097	 0.000593	 0.002667	 0.0051	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 1096	 0.000591	 0.00268	 0.0046	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4258	 1098	 0.001764	 0.004787	 0.0001	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	1767	 1099	 0.106296	 0.194573	 0.002	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	2675	 1099	 0.05543	 0.187957	 0.0022	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 1100	 0.006047	 0.013605	 0.0152	 2017	 2017	 2017	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 1100	 0.010834	 0.030234	 0.0051	 935	 935	 935	 0.0	 0.0	 1	 -30.0	 30.0;
	3522	 1101	 0.002469	 0.015319	 0.0271	 1903	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	3522	 1101	 0.002771	 0.009322	 0.0121	 3036	 3036	 3036	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 1103	 0.007055	 0.014109	 0.0103	 1872	 1872	 1872	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 1106	 2.5e-05	 0.000252	 0.0003	 113138	 113138	 113138	 0.0	 0.0	 1	 -30.0	 30.0;
	5577	 1107	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 1107	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 1108	 0.059965	 0.158982	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 1108	 0.007811	 0.051146	 0.0006	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 1108	 0.059965	 0.158982	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3581	 1109	 0.000972	 0.012113	 0.1636	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 1110	 0.007811	 0.014361	 0.0107	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	2322	 1111	 0.032099	 0.089506	 0.0044	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1111	 0.002469	 0.007284	 0.0154	 3862	 3862	 3862	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 1112	 0.000493	 0.000902	 0.0001	 28222	 28222	 28222	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 1114	 0.030617	 0.077778	 0.0037	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 1114	 0.048765	 0.13716	 0.0068	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 1114	 0.033827	 0.092222	 0.0044	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 1115	 0.024943	 0.071806	 0.001	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	3577	 1116	 0.009322	 0.038801	 0.0005	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 1116	 0.097002	 0.245654	 0.0028	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 1116	 0.006551	 0.019148	 0.0002	 1503	 1503	 1503	 0.0	 0.0	 1	 -30.0	 30.0;
	5228	 1116	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 1116	 0.135047	 0.342404	 0.0039	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	3577	 1116	 0.010078	 0.041572	 0.0006	 711	 711	 711	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 1116	 0.01877	 0.076266	 0.0016	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 1116	 0.018796	 0.076392	 0.0018	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 1117	 0.003477	 0.023249	 0.0425	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 1117	 0.006341	 0.042232	 0.078	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1958	 1118	 0.012824	 0.032552	 0.0004	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 1119	 0.013681	 0.036029	 0.001	 790	 790	 790	 0.0	 0.0	 1	 -30.0	 30.0;
	1772	 1121	 0.016125	 0.041572	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	2502	 1120	 0.009826	 0.034517	 0.0479	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	4440	 1120	 0.003779	 0.010078	 0.0001	 2826	 2826	 2826	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 1121	 0.025699	 0.066012	 0.0	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	2502	 1120	 0.009826	 0.034517	 0.0479	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 1122	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 1122	 0.001764	 0.010582	 0.0002	 2753	 2753	 2753	 0.0	 0.0	 1	 -30.0	 30.0;
	1501	 1123	 0.014074	 0.038889	 0.0018	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	1919	 1123	 0.026667	 0.072963	 0.0034	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 1123	 0.022099	 0.067778	 0.0033	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 1125	 0.004198	 0.011482	 0.0005	 2430	 2430	 2430	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 1125	 0.038518	 0.103951	 0.005	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 1125	 0.038518	 0.103827	 0.0053	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 1126	 0.015873	 0.04258	 0.0039	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 1127	 0.003754	 0.010557	 0.0129	 2715	 2715	 2715	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 1128	 4.5e-05	 8.9e-05	 0.0007	 320583	 320583	 320583	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 1129	 0.023683	 0.0645	 0.001	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	2321	 1130	 0.014109	 0.060217	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1130	 0.002771	 0.007559	 0.0	 3778	 3778	 3778	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 1131	 0.027778	 0.070494	 0.0032	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 1131	 0.008272	 0.016543	 0.0007	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 1133	 0.043803	 0.118383	 0.0061	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 1134	 0.001008	 0.002771	 0.0001	 10315	 10315	 10315	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 1135	 0.03642	 0.105309	 0.0052	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 1135	 0.009136	 0.024568	 0.0011	 1134	 1134	 1134	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 1135	 0.009259	 0.024568	 0.0011	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	1230	 1136	 0.002601	 0.017284	 0.0324	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 1136	 0.008257	 0.036427	 0.0582	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 1137	 0.033704	 0.10358	 0.0053	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 1137	 0.022222	 0.058395	 0.0028	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 1138	 0.047619	 0.141345	 0.002	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 1138	 0.002016	 0.008566	 0.0013	 3356	 3356	 3356	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 1138	 0.00126	 0.003527	 0.0	 7884	 7884	 7884	 0.0	 0.0	 1	 -30.0	 30.0;
	3100	 1138	 0.013102	 0.05543	 0.001	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	2265	 1139	 0.001857	 0.014461	 0.0481	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 1139	 0.003202	 0.030829	 0.1164	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1359	 1140	 0.084656	 0.189216	 0.0023	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	3245	 1140	 0.098765	 0.269085	 0.003	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	1359	 1140	 0.080373	 0.203326	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	2802	 1142	 0.05543	 0.141597	 0.0018	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 1141	 0.104308	 0.216175	 0.0023	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 1142	 0.006047	 0.016377	 0.0002	 1642	 1642	 1642	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 1141	 0.006475	 0.028395	 0.0436	 984	 984	 984	 0.0	 0.0	 1	 -30.0	 30.0;
	5486	 1142	 0.04384	 0.142101	 0.0017	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	2465	 1143	 0.006005	 0.02878	 0.0496	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 1143	 0.003595	 0.0176	 0.0294	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 1144	 0.002133	 0.014756	 0.0294	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	5260	 1145	 0.016377	 0.044596	 0.0005	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 1146	 0.059965	 0.168556	 0.002	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 1146	 0.018141	 0.05039	 0.0006	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	5225	 1146	 0.051398	 0.2129	 0.0027	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	5446	 1146	 0.094734	 0.259007	 0.0027	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 1146	 0.0451	 0.186193	 0.0023	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 1146	 0.023432	 0.066264	 0.0007	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 1147	 0.00642	 0.043852	 0.083	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 1147	 0.003002	 0.020227	 0.0385	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3712	 1148	 8.9e-05	 0.000751	 0.079	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 1149	 0.039557	 0.107886	 0.0012	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 1151	 0.003477	 0.018074	 0.0304	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 1151	 0.003141	 0.015526	 0.0268	 253.0	 253.0	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 1151	 0.000237	 0.001541	 0.0091	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2586	 1152	 0.068272	 0.212346	 0.0104	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 1152	 0.051975	 0.158025	 0.0076	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 1153	 0.074049	 0.166364	 0.0018	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	3559	 1153	 0.074931	 0.204031	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	3617	 1154	 0.020494	 0.046049	 0.0021	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 1155	 0.004837	 0.017334	 0.0007	 1691	 1691	 1691	 0.0	 0.0	 1	 -30.0	 30.0;
	2138	 1156	 0.022676	 0.075082	 0.0009	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	3021	 1157	 0.006803	 0.018896	 0.0002	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 1157	 0.003779	 0.009826	 0.0	 2805	 2805	 2805	 0.0	 0.0	 1	 -30.0	 30.0;
	3506	 1157	 0.04006	 0.134039	 0.0021	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 1156	 0.006047	 0.028723	 0.0	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 1156	 0.006047	 0.016125	 0.0	 1715	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	5668	 1156	 0.022928	 0.065508	 0.001	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	2139	 1158	 0.001086	 0.00642	 0.0121	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 1158	 0.004464	 0.021452	 0.0385	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 1159	 0.023683	 0.043588	 0.0004	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 1159	 0.004283	 0.021164	 0.0156	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 1159	 0.071554	 0.184177	 0.002	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 1160	 0.00679	 0.018025	 0.0008	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	2454	 1161	 0.000158	 0.000474	 0.0506	 278.0	 278.0	 278.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 1161	 0.000198	 0.00077	 0.0972	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 1162	 1.6e-05	 9.9e-05	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5263	 1163	 1.6e-05	 9.9e-05	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 1164	 0.001358	 0.008148	 0.0005	 3672	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 1165	 0.001481	 0.009012	 0.0005	 3321	 3321	 3321	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 1166	 0.001481	 0.009259	 0.0005	 3234	 3234	 3234	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 1167	 0.004899	 0.033007	 0.0699	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 1167	 0.005531	 0.037215	 0.0678	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 1167	 0.004365	 0.029491	 0.0537	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 1167	 0.005452	 0.036365	 0.0668	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 1168	 0.008314	 0.034266	 0.0004	 813	 813	 813	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 1170	 0.04	 0.088889	 0.0	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	2578	 1171	 0.03477	 0.088183	 0.003	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	4984	 1172	 0.054271	 0.137566	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 1172	 0.111481	 0.204065	 0.0019	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 1173	 0.003002	 0.014163	 0.0253	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 1173	 0.001778	 0.009837	 0.0248	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 1174	 0.031975	 0.089753	 0.0042	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3090	 1174	 0.026296	 0.066667	 0.0031	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 1174	 0.031975	 0.082963	 0.0037	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	4199	 1174	 0.00437	 0.011975	 0.0097	 2331	 2331	 2331	 0.0	 0.0	 1	 -30.0	 30.0;
	4223	 1174	 0.002963	 0.018642	 0.0015	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 1174	 0.009136	 0.024938	 0.0011	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	5622	 1174	 0.009012	 0.022222	 0.001	 1239	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	3090	 1174	 0.026049	 0.071111	 0.0034	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 1174	 0.006667	 0.01679	 0.0008	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 1174	 0.007802	 0.01979	 0.001	 1397	 1397	 1397	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 1175	 0.005491	 0.037076	 0.0658	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4224	 1175	 0.000454	 0.0032	 0.0051	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 1175	 0.00083	 0.005669	 0.0111	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 1175	 0.005412	 0.036543	 0.0658	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 1175	 0.005432	 0.036543	 0.0658	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 1180	 0.109785	 0.20096	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 1181	 0.00877	 0.026489	 0.0435	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 1181	 0.000968	 0.003516	 0.0061	 8488	 8488	 8488	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 1181	 0.008099	 0.028247	 0.0466	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	3540	 1181	 0.001521	 0.00721	 0.0121	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 1182	 0.06358	 0.165802	 0.0079	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	1192	 1183	 0.000335	 0.000613	 0.001	 43410	 43410	 43410	 0.0	 0.0	 1	 -30.0	 30.0;
	2650	 1185	 0.011852	 0.030988	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 1184	 0.019383	 0.052469	 0.0024	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 1186	 0.034266	 0.089947	 0.001	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 1187	 0.000138	 0.000573	 0.0699	 259.0	 259.0	 259.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3914	 1189	 0.006296	 0.016914	 0.0008	 1646	 1646	 1646	 0.0	 0.0	 1	 -30.0	 30.0;
	5404	 1189	 0.03321	 0.087778	 0.0042	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 1190	 0.000198	 0.000731	 0.647	 425.0	 425.0	 425.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 1190	 0.000652	 0.002351	 0.5123	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 1190	 0.000593	 0.005649	 0.0223	 656.0	 656.0	 656.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 1190	 0.000182	 0.000622	 0.5559	 494.0	 494.0	 494.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 1190	 0.000652	 0.00237	 0.5133	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 1190	 0.000612	 0.005669	 0.0278	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 1190	 0.000237	 0.002114	 0.1954	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 1190	 0.000217	 0.002054	 0.0197	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 1190	 0.000217	 0.002035	 0.0147	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 1191	 0.065508	 0.1678	 0.0024	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4620	 1191	 0.036332	 0.092089	 0.001	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 1192	 0.008148	 0.034197	 0.0016	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 1192	 0.005679	 0.021975	 0.0137	 1337	 1337	 1337	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 1192	 0.000753	 0.001379	 0.0026	 19301	 19301	 19301	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 1194	 2.5e-05	 0.151172	 0.0	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 1195	 0.060972	 0.168052	 0.0021	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 1194	 0.03676	 0.081381	 0.0027	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 1193	 2.5e-05	 0.000252	 0.0	 116592	 116592	 116592	 0.0	 0.0	 1	 -30.0	 30.0;
	3523	 1197	 0.00287	 0.017709	 0.0334	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 1196	 0.002015	 0.012879	 0.0243	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 1197	 0.00482	 0.03119	 0.0577	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 1198	 0.000529	 0.008085	 0.2498	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3135	 1198	 0.001142	 0.014569	 0.3855	 1746.0	 1746.0	 1746.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 1199	 0.002884	 0.019358	 0.0714	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 1199	 0.004978	 0.024514	 0.0435	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 1199	 0.015328	 0.102262	 0.1903	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	4343	 1199	 0.005531	 0.02797	 0.0567	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 1199	 0.001067	 0.007289	 0.0486	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1176	 1199	 5.9e-05	 0.000889	 0.003	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 1199	 0.002805	 0.019002	 0.0365	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 1199	 0.001027	 0.006775	 0.0121	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 1199	 7.9e-05	 0.00083	 0.002	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1178	 1199	 5.9e-05	 0.000652	 0.001	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 1200	 0.003102	 0.031524	 0.8202	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 1200	 0.001168	 0.011767	 0.3018	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 1200	 0.00313	 0.031724	 0.8202	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	2606	 1200	 0.001163	 0.011728	 0.3018	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 1200	 0.004905	 0.049964	 1.301	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 1200	 2.1e-05	 0.000249	 0.0058	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3388	 1201	 0.082389	 0.220711	 0.0026	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 1201	 0.083648	 0.172084	 0.0019	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 1201	 0.051398	 0.110355	 0.0015	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	4659	 1202	 0.01479	 0.048677	 0.0187	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 1202	 0.002595	 0.011665	 0.0285	 2398	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 1202	 0.002595	 0.011665	 0.0285	 2398	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 1203	 0.001027	 0.004721	 0.0081	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2966	 1203	 0.001027	 0.004899	 0.0091	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4177	 1205	 0.000741	 0.002346	 0.0002	 12326	 12326	 12326	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 1205	 0.042963	 0.117531	 0.0	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	5092	 1204	 0.01963	 0.051481	 0.0024	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5166	 1204	 0.020247	 0.055556	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 1206	 0.011482	 0.051111	 0.0026	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	3957	 1206	 0.014938	 0.037654	 0.013	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 1206	 0.015185	 0.037531	 0.0133	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 1206	 0.000123	 0.001235	 0.0016	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	4421	 1206	 0.000123	 0.001235	 0.0016	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	2939	 1207	 0.002548	 0.012346	 0.0203	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 1208	 0.021416	 0.054422	 0.0006	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 1208	 0.053414	 0.136306	 0.0015	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 1208	 0.016755	 0.04263	 0.0005	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 1208	 0.0194	 0.049887	 0.0006	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	1248	 1209	 0.004721	 0.031348	 0.0587	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 1209	 0.003556	 0.023585	 0.0435	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 1210	 0.000123	 0.001235	 0.0002	 27851	 27851	 27851	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 1211	 0.03225	 0.148904	 0.0018	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 1211	 0.008314	 0.034014	 0.0245	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 1211	 0.084404	 0.252457	 0.0098	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 1211	 0.032754	 0.15092	 0.0014	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 1211	 0.014361	 0.038801	 0.0004	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 1212	 0.00156	 0.01039	 0.0192	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1918	 1212	 0.001084	 0.005086	 0.0111	 361.0	 361.0	 361.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 1212	 0.002153	 0.012978	 0.0243	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1918	 1212	 0.0011	 0.004978	 0.0142	 353.0	 353.0	 353.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 1212	 0.002173	 0.013017	 0.0243	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 1213	 0.002469	 0.009877	 0.0008	 2918	 2918	 2918	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 1214	 0.00963	 0.025309	 0.0013	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	5718	 1214	 0.037037	 0.094938	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	5272	 1215	 0.000158	 0.000691	 0.001	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3038	 1216	 0.002544	 0.02015	 0.0348	 561.0	 561.0	 561.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4457	 1216	 0.003727	 0.028836	 0.0527	 562.0	 562.0	 562.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 1217	 0.012522	 0.044041	 0.0263	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 1217	 0.044848	 0.110103	 0.0013	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 1218	 0.032704	 0.079542	 0.0022	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 1218	 0.011338	 0.026455	 0.0009	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	1300	 1219	 3.5e-05	 0.000512	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 1219	 0.001887	 0.019088	 0.4938	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 1219	 0.001579	 0.01509	 0.4087	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 1219	 0.000949	 0.009342	 0.2426	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 1219	 3.5e-05	 0.000506	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 1219	 0.001874	 0.018954	 0.491	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 1219	 0.00097	 0.009536	 0.2484	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1299	 1219	 3.5e-05	 0.000547	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 1219	 0.00097	 0.009536	 0.2484	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 1219	 3.5e-05	 0.000547	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1991	 1221	 0.021679	 0.058309	 0.0041	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	1811	 1222	 0.007307	 0.029479	 0.005	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 1222	 0.000756	 0.00252	 0.0037	 10890	 10890	 10890	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 1223	 0.081436	 0.149069	 0.001	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3858	 1223	 0.069287	 0.175611	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	3428	 1224	 0.047161	 0.123827	 0.0058	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 1225	 0.044198	 0.12058	 0.0057	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 1226	 0.049876	 0.126444	 0.006	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 1227	 0.000869	 0.006025	 0.0101	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 1228	 0.035021	 0.091963	 0.0021	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 1229	 0.047901	 0.095926	 0.004	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 1231	 0.006047	 0.018896	 0.0067	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	3053	 1232	 0.070295	 0.178634	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	4439	 1232	 0.061804	 0.156765	 0.0017	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	3496	 1233	 0.001134	 0.002671	 0.0006	 10482	 10482	 10482	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 1233	 0.065079	 0.165004	 0.0019	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 1234	 0.00897	 0.050315	 0.0103	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	1653	 1234	 0.028975	 0.081885	 0.0127	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	2429	 1234	 0.048501	 0.135047	 0.0031	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	2494	 1234	 0.02192	 0.071051	 0.0011	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 1235	 0.034568	 0.087407	 0.004	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	4453	 1235	 0.038642	 0.105309	 0.0049	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	1778	 1237	 0.009506	 0.039259	 0.0021	 736	 736	 736	 0.0	 0.0	 1	 -30.0	 30.0;
	3045	 1237	 0.050124	 0.136543	 0.0073	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	1778	 1237	 0.009506	 0.039259	 0.0021	 736	 736	 736	 0.0	 0.0	 1	 -30.0	 30.0;
	3604	 1239	 0.001764	 0.012346	 0.0011	 2368	 2368	 2368	 0.0	 0.0	 1	 -30.0	 30.0;
	4280	 1239	 0.006803	 0.028975	 0.0	 993	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 1238	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1238	 0.008314	 0.018141	 0.0	 1480	 1480	 1480	 0.0	 0.0	 1	 -30.0	 30.0;
	5651	 1238	 0.004686	 0.019829	 0.0002	 1450	 1450	 1450	 0.0	 0.0	 1	 -30.0	 30.0;
	3604	 1239	 0.007307	 0.028975	 0.0018	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 1242	 0.001027	 0.006677	 0.0121	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 1241	 0.009521	 0.064237	 0.1215	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 1242	 0.002133	 0.023348	 0.0648	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 1240	 0.002232	 0.007802	 0.0142	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 1241	 0.000593	 0.002588	 0.0162	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4083	 1241	 2e-05	 0.015803	 0.0	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4137	 1242	 0.001778	 0.016356	 0.0405	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4528	 1242	 0.011694	 0.078657	 0.1519	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 1242	 0.000237	 0.00156	 0.0142	 19617	 19617	 19617	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 1241	 0.001027	 0.006657	 0.0121	 464.0	 464.0	 464.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3540	 1241	 0.00476	 0.022499	 0.0375	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4083	 1240	 2e-05	 0.000198	 0.0	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 1243	 0.000462	 0.006438	 0.1689	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 1243	 0.000462	 0.006434	 0.1689	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5552	 1244	 0.106551	 0.225649	 0.0024	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 1245	 0.003234	 0.01923	 0.0365	 410.0	 410.0	 410.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 1245	 0.019951	 0.071546	 0.1144	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	3312	 1245	 0.016	 0.053472	 0.0861	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 1246	 0.017637	 0.056185	 0.001	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	1856	 1246	 0.002851	 0.005218	 0.0036	 4966	 4966	 4966	 0.0	 0.0	 1	 -30.0	 30.0;
	1617	 1246	 0.018141	 0.057193	 0.001	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	1855	 1246	 0.00126	 0.004535	 0.0046	 6273	 6273	 6273	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 1247	 0.212444	 0.388876	 0.0042	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	3823	 1247	 0.012598	 0.031998	 0.0004	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 1247	 0.022928	 0.060721	 0.0007	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 1248	 0.005472	 0.037728	 0.0709	 411.0	 411.0	 411.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 1248	 0.000968	 0.00638	 0.0111	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 1248	 0.005669	 0.025639	 0.0456	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 1249	 0.147644	 0.301587	 0.0057	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	4328	 1249	 0.125548	 0.318292	 0.0036	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 1249	 0.179214	 0.32805	 0.0054	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	2264	 1250	 0.082196	 0.171444	 0.0486	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 1253	 0.001008	 0.002771	 0.0021	 10020	 10020	 10020	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 1253	 0.001367	 0.002502	 0.0021	 10362	 10362	 10362	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 1254	 0.032963	 0.083704	 0.0039	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 1254	 0.037901	 0.103457	 0.0049	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1255	 0.017133	 0.071806	 0.0071	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 1258	 0.007037	 0.019012	 0.0002	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 1259	 0.002825	 0.018765	 0.0349	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2524	 1259	 0.000474	 0.003101	 0.0061	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 1259	 0.00173	 0.01154	 0.0213	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 1259	 0.001719	 0.011496	 0.0289	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4206	 1260	 0.074074	 0.187957	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 1260	 0.008163	 0.021769	 0.0002	 1309	 1309	 1309	 0.0	 0.0	 1	 -30.0	 30.0;
	2339	 1261	 0.064752	 0.177375	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5281	 1262	 0.000436	 0.000797	 0.0	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	2257	 1264	 0.060897	 0.161552	 0.0022	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	4716	 1264	 0.020433	 0.06062	 0.0007	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 1263	 0.017611	 0.061779	 0.0101	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 1263	 0.075787	 0.176316	 0.0041	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5777	 1264	 0.076871	 0.206828	 0.0028	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	4716	 1263	 0.009574	 0.038549	 0.0017	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 1264	 0.019148	 0.071051	 0.0075	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 1265	 0.013472	 0.067378	 0.1215	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 1265	 0.004563	 0.02448	 0.0425	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 1265	 0.010627	 0.045511	 0.0749	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 1265	 0.009798	 0.045748	 0.0815	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5660	 1265	 0.011674	 0.053096	 0.0921	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 1266	 0.000812	 0.006278	 0.1271	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3811	 1266	 0.001797	 0.019272	 0.4216	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 1266	 0.003831	 0.029281	 0.592	 1080	 1080	 1080	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 1267	 0.042076	 0.209121	 0.0025	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 1268	 0.145125	 0.32124	 0.0037	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 1268	 0.07609	 0.189468	 0.0021	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 1270	 0.000198	 0.0016	 0.162	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3952	 1270	 0.000454	 0.001106	 0.1002	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 1269	 0.000316	 0.000948	 0.1094	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 1271	 0.00642	 0.026914	 0.0013	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	2263	 1272	 0.037793	 0.118922	 0.0013	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 1273	 0.067926	 0.165331	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 1273	 0.012598	 0.031242	 0.0003	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 1274	 0.008566	 0.019652	 0.0017	 1337	 1337	 1337	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 1275	 0.00077	 0.011178	 0.312	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 1275	 0.00088	 0.012722	 0.3292	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 1275	 0.000312	 0.004467	 0.1155	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 1276	 0.000771	 0.011192	 0.291	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 1276	 0.00088	 0.012715	 0.3292	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 1276	 0.000312	 0.004467	 0.1155	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1547	 1277	 0.028975	 0.073318	 0.0008	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 1277	 0.036785	 0.093222	 0.001	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 1279	 2e-05	 0.000198	 0.003	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	4586	 1278	 0.000178	 0.000632	 0.078	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 1280	 0.007559	 0.020912	 0.0002	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 1281	 0.026914	 0.085062	 0.0049	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 1281	 0.021235	 0.067654	 0.004	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 1284	 0.000675	 0.001235	 0.0036	 21546	 21546	 21546	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 1285	 0.005556	 0.029136	 0.0005	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 1285	 0.012099	 0.059753	 0.0013	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 1286	 0.00077	 0.005195	 0.0091	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3638	 1286	 0.000553	 0.003694	 0.0157	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 1286	 0.000514	 0.001007	 0.1499	 27378	 27378	 27378	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 1286	 0.001679	 0.008296	 0.0152	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 1286	 0.002548	 0.016968	 0.0314	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 1286	 0.000731	 0.004938	 0.0091	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3638	 1286	 0.000533	 0.003635	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3920	 1286	 0.000494	 0.001007	 0.1488	 27596	 27596	 27596	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 1287	 0.000514	 0.001185	 0.0719	 23964	 23964	 23964	 0.0	 0.0	 1	 -30.0	 30.0;
	2049	 1288	 0.016327	 0.049786	 0.0024	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 1288	 0.009574	 0.033006	 0.0017	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	1633	 1289	 0.038889	 0.098889	 0.0047	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 1289	 0.002049	 0.005617	 0.0124	 4968	 4968	 4968	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 1289	 0.002481	 0.006531	 0.0003	 4252	 4252	 4252	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 1290	 0.013144	 0.024059	 0.004	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 1291	 0.006551	 0.016629	 0.0005	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 1292	 0.000756	 0.005795	 0.0001	 5205	 5205	 5205	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 1293	 0.000138	 0.000573	 0.001	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 1294	 0.001008	 0.003527	 0.0001	 8292	 8292	 8292	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 1294	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 1295	 0.048879	 0.100781	 0.0011	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	3944	 1295	 0.085664	 0.234568	 0.0033	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	3944	 1295	 0.091711	 0.240363	 0.0032	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	2661	 1296	 0.000632	 0.004168	 0.0081	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3449	 1301	 0.011518	 0.029173	 0.0014	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	2033	 1302	 0.03679	 0.10037	 0.0047	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 1302	 0.03321	 0.090494	 0.0039	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 1303	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 1304	 0.000504	 0.00252	 0.0001	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 1304	 0.089695	 0.201058	 0.0022	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 1306	 2e-05	 0.000198	 0.003	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 1307	 0.006299	 0.017133	 0.0	 1618	 1618	 1618	 0.0	 0.0	 1	 -30.0	 30.0;
	2641	 1309	 0.0125	 0.025	 0.0	 1236	 1236	 1236	 0.0	 0.0	 1	 -30.0	 30.0;
	5824	 1310	 0.095666	 0.21222	 0.0023	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 1311	 0.011867	 0.030083	 0.0003	 941	 941	 941	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 1311	 0.133787	 0.246914	 0.0025	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 1312	 0.0004	 0.001244	 0.0004	 23302	 23302	 23302	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 1312	 0.019956	 0.0604	 0.0198	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	3910	 1312	 0.017467	 0.063733	 0.0216	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 1313	 0.005543	 0.015621	 0.0015	 1835	 1835	 1835	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 1313	 0.016125	 0.0516	 0.0253	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 1313	 0.028723	 0.062484	 0.0007	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 1314	 0.000252	 0.000756	 0.0	 38166	 38166	 38166	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 1315	 0.019652	 0.082137	 0.001	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	3936	 1315	 0.112875	 0.361048	 0.0037	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 1316	 0.005291	 0.013102	 0.0002	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 1317	 0.035021	 0.094734	 0.0011	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 1317	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 1317	 0.008566	 0.02318	 0.0002	 1231	 1231	 1231	 0.0	 0.0	 1	 -30.0	 30.0;
	1318	 1319	 0.00252	 0.005039	 0.0	 5399	 5399	 5399	 0.0	 0.0	 1	 -30.0	 30.0;
	1987	 1319	 0.039557	 0.078861	 0.0008	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 1320	 0.027901	 0.073951	 0.0036	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 1320	 0.02358	 0.064198	 0.0031	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 1320	 0.019753	 0.052963	 0.0026	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	2941	 1321	 0.047654	 0.121728	 0.0058	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 1323	 0.001975	 0.00642	 0.0001	 3887	 3887	 3887	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 1322	 0.001481	 0.004938	 0.0012	 5064	 5064	 5064	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 1324	 0.066012	 0.167549	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 1325	 0.031494	 0.131015	 0.007	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	4409	 1325	 0.01159	 0.04132	 0.0298	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 1325	 0.028219	 0.117158	 0.0017	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 1326	 0.001233	 0.008227	 0.0147	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 1327	 0.014462	 0.046762	 0.0375	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5652	 1327	 0.002268	 0.005039	 0.011	 5504	 5504	 5504	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 1328	 0.002761	 0.005054	 0.0	 4533	 4533	 4533	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 1329	 0.018519	 0.047901	 0.0104	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 1329	 0.004198	 0.010741	 0.0005	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 1330	 0.077407	 0.154691	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 1330	 0.009136	 0.020617	 0.001	 1345	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 1331	 0.000756	 0.00252	 0.0003	 11223	 11223	 11223	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 1332	 0.086143	 0.234971	 0.0039	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	4271	 1332	 0.035525	 0.095742	 0.0011	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	5746	 1332	 0.035878	 0.096649	 0.002	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 1333	 0.003911	 0.027062	 0.0486	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 1333	 0.000711	 0.006894	 0.0223	 865.0	 865.0	 865.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 1333	 0.007012	 0.030617	 0.0511	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 1333	 0.007639	 0.051542	 0.2291	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 1334	 0.002597	 0.034127	 1.1812	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 1334	 0.002999	 0.033656	 0.6729	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 1334	 0.001302	 0.013172	 0.3408	 1727.0	 1727.0	 1727.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 1334	 0.002597	 0.034127	 1.1783	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 1334	 0.000256	 0.002701	 0.0693	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 1334	 0.001309	 0.013255	 0.3437	 1727.0	 1727.0	 1727.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 1335	 0.004467	 0.008177	 0.0	 2802	 2802	 2802	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 1336	 0.010582	 0.066264	 0.0009	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	5832	 1336	 0.003527	 0.025699	 0.0	 1139	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 1337	 0.031242	 0.080121	 0.0009	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 1337	 0.11615	 0.314437	 0.0036	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 1338	 0.035525	 0.073066	 0.001	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 1338	 0.004787	 0.009574	 0.001	 2759	 2759	 2759	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 1339	 0.002765	 0.01843	 0.0344	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 1340	 0.002114	 0.012662	 0.0233	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 1340	 0.000595	 0.004024	 0.0081	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2088	 1342	 0.001264	 0.008415	 0.0152	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1846	 1343	 0.000504	 0.00252	 0.0021	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	1847	 1343	 0.000504	 0.00252	 0.0021	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	1757	 1345	 0.008987	 0.016452	 0.0116	 1575	 1575	 1575	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 1345	 0.019123	 0.0484	 0.0008	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	4196	 1346	 0.000731	 0.001383	 0.1853	 19787	 19787	 19787	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 1347	 0.019652	 0.049131	 0.0006	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	2362	 1353	 0.000617	 0.001235	 0.0021	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	2362	 1352	 0.000617	 0.001235	 0.0016	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	1598	 1354	 0.07963	 0.159259	 0.0092	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 1355	 0.149205	 0.273119	 0.0029	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	1364	 1356	 0.045062	 0.118519	 0.0057	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 1356	 0.036914	 0.098025	 0.0047	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	1390	 1357	 0.03679	 0.081728	 0.0039	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 1357	 0.005432	 0.03358	 0.0018	 874	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	2623	 1357	 0.001852	 0.012099	 0.0006	 2427	 2427	 2427	 0.0	 0.0	 1	 -30.0	 30.0;
	2691	 1357	 0.046914	 0.118395	 0.0057	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 1357	 0.007654	 0.031975	 0.0016	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	2697	 1357	 0.018765	 0.072099	 0.0036	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	1389	 1357	 0.03679	 0.081852	 0.0039	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 1358	 0.005867	 0.03919	 0.083	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 1358	 0.003812	 0.025482	 0.0466	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5138	 1359	 0.037289	 0.094734	 0.0001	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 1360	 0.00316	 0.021017	 0.0375	 528.0	 528.0	 528.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3810	 1360	 0.004612	 0.030706	 0.0547	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 1361	 0.006299	 0.027715	 0.0007	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 1362	 0.006299	 0.028219	 0.0003	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 1363	 0.0451	 0.082641	 0.0044	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 1364	 0.063333	 0.161605	 0.0076	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 1366	 0.000138	 0.001363	 0.2025	 22551	 22551	 22551	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 1365	 0.000158	 0.001323	 0.1822	 23186	 23186	 23186	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 1367	 0.000741	 0.001481	 0.0021	 17936	 17936	 17936	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 1368	 0.034014	 0.086672	 0.001	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	1708	 1371	 0.011633	 0.021293	 0.0127	 1181	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 1370	 0.008062	 0.016377	 0.0115	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	1715	 1369	 0.007307	 0.014613	 0.0112	 1754	 1754	 1754	 0.0	 0.0	 1	 -30.0	 30.0;
	1799	 1372	 0.000559	 0.001024	 0.0729	 26532	 26532	 26532	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 1373	 0.021083	 0.038593	 0.0279	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	3257	 1373	 0.001512	 0.003779	 0.0001	 7254	 7254	 7254	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 1373	 0.001764	 0.006047	 0.0001	 4688	 4688	 4688	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 1373	 0.031242	 0.127488	 0.0017	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5295	 1373	 0.031494	 0.127992	 0.0023	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 1375	 0.021111	 0.055679	 0.0026	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 1374	 0.044938	 0.12284	 0.0057	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 1376	 0.001235	 0.003704	 0.0002	 7767	 7767	 7767	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 1377	 0.000292	 0.002538	 0.2546	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1776	 1378	 0.058201	 0.116654	 0.0012	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	2539	 1379	 0.069035	 0.233308	 0.0028	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 1380	 0.000123	 0.001235	 0.0002	 27851	 27851	 27851	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 1381	 0.000632	 0.004306	 0.0081	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2347	 1382	 0.071907	 0.195263	 0.0025	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 1382	 0.001764	 0.003275	 0.0025	 8177	 8177	 8177	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 1382	 0.067599	 0.182036	 0.0029	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 1382	 0.015369	 0.04132	 0.0005	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 1385	 0.004787	 0.01285	 0.0232	 2154	 2154	 2154	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 1385	 0.003275	 0.014361	 0.0069	 2005	 2005	 2005	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 1386	 0.041824	 0.180146	 0.0022	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 1386	 0.04132	 0.14059	 0.0017	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 1386	 0.041068	 0.16906	 0.0021	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 1386	 0.067775	 0.174099	 0.0019	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 1386	 0.035928	 0.074502	 0.0135	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 1386	 0.031998	 0.081129	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	2537	 1386	 0.06324	 0.158982	 0.0072	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	4001	 1386	 0.065508	 0.166037	 0.0019	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 1386	 0.039305	 0.102797	 0.0181	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 1386	 0.03094	 0.06382	 0.0116	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	3438	 1388	 0.001244	 0.008415	 0.0309	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4095	 1388	 0.002114	 0.014242	 0.0486	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3412	 1390	 0.001852	 0.004198	 0.0002	 6474	 6474	 6474	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 1389	 0.044198	 0.094074	 0.0044	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2753	 1391	 0.136558	 0.304107	 0.0033	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 1393	 0.023935	 0.060469	 0.0007	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 1393	 0.031494	 0.079869	 0.0009	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	3394	 1394	 0.042983	 0.090073	 0.0047	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 1394	 0.007811	 0.016125	 0.0002	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	2148	 1395	 0.036281	 0.082389	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	3865	 1395	 0.015117	 0.036281	 0.0004	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 1395	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 1395	 0.028723	 0.090451	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1396	 0.000617	 0.001235	 0.0006	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 1397	 0.046359	 0.095994	 0.0011	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 1397	 0.046611	 0.09801	 0.0011	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 1398	 0.001719	 0.008	 0.0132	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5299	 1399	 0.009948	 0.01821	 0.0	 1462	 1462	 1462	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 1400	 0.013354	 0.034266	 0.0004	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 1400	 0.043689	 0.110784	 0.0017	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	5300	 1401	 0.000252	 0.001008	 0.0	 28417	 28417	 28417	 0.0	 0.0	 1	 -30.0	 30.0;
	2344	 1402	 0.091459	 0.249685	 0.0028	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4328	 1403	 0.112634	 0.206176	 0.0021	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 1403	 0.097905	 0.179214	 0.0018	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 1406	 0.012346	 0.024943	 0.0002	 1093	 1093	 1093	 0.0	 0.0	 1	 -30.0	 30.0;
	1953	 1407	 0.019929	 0.079592	 0.0093	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	3701	 1407	 0.051071	 0.160116	 0.0096	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3864	 1407	 0.008566	 0.018896	 0.0213	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	3864	 1407	 0.008566	 0.018896	 0.0213	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 1410	 0.021482	 0.055185	 0.0026	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	1814	 1410	 0.004568	 0.012716	 0.0457	 2199	 2199	 2199	 0.0	 0.0	 1	 -30.0	 30.0;
	4336	 1410	 0.049012	 0.132963	 0.0062	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 1411	 0.000608	 0.004067	 0.0071	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 1411	 0.002054	 0.013689	 0.0253	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2870	 1412	 0.001764	 0.005039	 0.0056	 5697	 5697	 5697	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 1412	 0.063593	 0.161275	 0.0018	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 1413	 0.00126	 0.003779	 0.0001	 7412	 7412	 7412	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 1414	 0.000504	 0.001008	 0.0	 26199	 26199	 26199	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 1415	 0.000504	 0.001764	 0.0018	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	2238	 1416	 0.020937	 0.064651	 0.001	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	4147	 1416	 0.026455	 0.084656	 0.001	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 1416	 0.013605	 0.062938	 0.0076	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 1417	 0.029151	 0.078005	 0.0009	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 1417	 0.031998	 0.083144	 0.001	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	2483	 1418	 0.049568	 0.127321	 0.006	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 1418	 0.028876	 0.078765	 0.0039	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	4630	 1418	 0.058988	 0.149741	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1823	 1419	 0.009826	 0.025951	 0.0003	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	1823	 1419	 0.014865	 0.039808	 0.0005	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	2608	 1421	 0.033086	 0.069383	 0.0032	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	3235	 1420	 0.014938	 0.040494	 0.0018	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 1421	 0.033086	 0.069506	 0.0032	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3234	 1421	 0.014938	 0.040494	 0.0018	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 1422	 0.002716	 0.007519	 0.0391	 3794	 3794	 3794	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 1422	 0.004631	 0.008476	 0.0207	 3140	 3140	 3140	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 1424	 0.010758	 0.044621	 0.0011	 663	 663	 663	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 1423	 0.034713	 0.063542	 0.0007	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 1425	 0.007432	 0.019803	 0.0019	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 1426	 0.000356	 0.000731	 0.0415	 38069	 38069	 38069	 0.0	 0.0	 1	 -30.0	 30.0;
	3887	 1427	 0.065256	 0.173091	 0.0065	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 1427	 0.000252	 0.001008	 0.0001	 29272	 29272	 29272	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 1427	 0.000252	 0.001008	 0.0008	 29272	 29272	 29272	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 1428	 0.001167	 0.002137	 0.0	 12455	 12455	 12455	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 1429	 0.07	 0.188889	 0.0091	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 1429	 0.027654	 0.075309	 0.0036	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 1429	 0.022222	 0.060741	 0.0029	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 1429	 0.023086	 0.062346	 0.0031	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 1430	 0.115646	 0.293777	 0.0033	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 1430	 0.065508	 0.166793	 0.0019	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4050	 1431	 0.02642	 0.099012	 0.005	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 1431	 0.028889	 0.097901	 0.0047	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	1435	 1432	 2e-05	 9.8e-05	 0.0111	 309464	 309464	 309464	 0.0	 0.0	 1	 -30.0	 30.0;
	2550	 1433	 0.000968	 0.005906	 0.0602	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 1433	 0.001331	 0.009015	 0.0906	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1065	 1434	 0.035273	 0.092391	 0.001	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	4539	 1434	 0.000857	 0.002394	 0.0021	 11961	 11961	 11961	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 1434	 0.012094	 0.05165	 0.0006	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	1065	 1434	 0.034064	 0.09093	 0.001	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 1435	 0.00561	 0.030894	 0.0567	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4998	 1435	 0.003812	 0.025383	 0.0471	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	930	 1436	 0.010582	 0.046359	 0.001	 621	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 1436	 0.014109	 0.044596	 0.001	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 1436	 0.035273	 0.099521	 0.001	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 1436	 0.001915	 0.011817	 0.0209	 2467	 2467	 2467	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 1436	 0.005795	 0.023432	 0.004	 1224	 1224	 1224	 0.0	 0.0	 1	 -30.0	 30.0;
	1781	 1437	 0.034321	 0.087037	 0.004	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 1438	 0.000504	 0.001764	 0.0018	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 1439	 0.081381	 0.179894	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 1440	 0.008272	 0.018519	 0.0008	 1496	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	2493	 1441	 0.005039	 0.019148	 0.0268	 1537	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	2735	 1441	 0.070547	 0.192744	 0.0027	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 1441	 0.003275	 0.011086	 0.013	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	4698	 1441	 0.112371	 0.291509	 0.0033	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 1441	 0.038801	 0.098514	 0.001	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	2493	 1441	 0.004031	 0.014109	 0.014	 2073	 2073	 2073	 0.0	 0.0	 1	 -30.0	 30.0;
	2735	 1441	 0.107332	 0.198791	 0.0021	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	2493	 1441	 0.010756	 0.019689	 0.0139	 1356	 1356	 1356	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 1442	 0.005233	 0.024413	 0.0435	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 1442	 0.002252	 0.01037	 0.0182	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 1442	 0.00397	 0.02639	 0.0537	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2960	 1443	 0.034321	 0.088518	 0.0042	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 1443	 0.031482	 0.083333	 0.0039	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 1445	 0.141597	 0.439657	 0.0056	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	1324	 1445	 0.005291	 0.013605	 0.0002	 2023	 2023	 2023	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 1444	 0.048123	 0.121945	 0.0013	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	3070	 1445	 0.062484	 0.139834	 0.0016	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	4585	 1445	 0.028219	 0.071554	 0.0014	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4769	 1444	 0.055682	 0.139078	 0.0016	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 1445	 0.018392	 0.040312	 0.0005	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 1444	 0.012346	 0.037541	 0.0004	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	2661	 1446	 0.005314	 0.024119	 0.0425	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 1446	 0.003398	 0.017541	 0.0314	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2661	 1446	 0.005412	 0.024571	 0.0461	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 1447	 0.006159	 0.011274	 0.0058	 2231	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 1447	 0.004699	 0.008601	 0.0045	 2924	 2924	 2924	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 1448	 0.000247	 0.001235	 0.0	 23584	 23584	 23584	 0.0	 0.0	 1	 -30.0	 30.0;
	3984	 1450	 0.00126	 0.003275	 0.0	 8415	 8415	 8415	 0.0	 0.0	 1	 -30.0	 30.0;
	1002	 1451	 0.001256	 0.008251	 0.2389	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 1451	 0.000158	 0.000652	 0.0729	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 1452	 0.012346	 0.037037	 0.0015	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 1454	 0.008209	 0.015026	 0.0002	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 1453	 0.008209	 0.015026	 0.0002	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 1455	 0.008566	 0.022172	 0.0002	 1280	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 1455	 0.007811	 0.020156	 0.0002	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	3461	 1456	 0.149811	 0.308818	 0.0034	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 1457	 0.001047	 0.006973	 0.0132	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 1458	 0.002771	 0.005795	 0.0056	 4708	 4708	 4708	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 1461	 0.07483	 0.210632	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3265	 1462	 0.027901	 0.076173	 0.0036	 367	 367	 367	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 1462	 0.016914	 0.044691	 0.0021	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	4662	 1462	 0.049383	 0.132222	 0.0063	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	5017	 1462	 0.077037	 0.201605	 0.0094	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 1462	 0.00284	 0.007531	 0.0003	 3691	 3691	 3691	 0.0	 0.0	 1	 -30.0	 30.0;
	4645	 1462	 0.016914	 0.044444	 0.0021	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 1462	 0.015938	 0.040741	 0.0019	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 1463	 0.005393	 0.029649	 0.0638	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2146	 1463	 0.005393	 0.02963	 0.0638	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 1463	 0.001877	 0.012543	 0.0344	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 1464	 0.000589	 0.007708	 0.2628	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 1464	 0.00115	 0.01169	 0.3032	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 1464	 0.00241	 0.024446	 0.6325	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 1464	 0.000589	 0.007708	 0.2628	 2389.0	 2389.0	 2389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 1464	 0.00115	 0.01169	 0.3032	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 1464	 0.00153	 0.015526	 0.4014	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 1465	 0.013605	 0.08516	 0.0011	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 1465	 0.030434	 0.05571	 0.0001	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	3527	 1465	 0.030486	 0.07735	 0.0057	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 1465	 0.012598	 0.079365	 0.0017	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 1465	 0.092215	 0.209121	 0.0022	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 1466	 0.031975	 0.135062	 0.0069	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	3202	 1467	 0.004464	 0.029669	 0.0547	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 1467	 0.005156	 0.034489	 0.0638	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 1468	 0.027595	 0.050512	 0.0004	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 1469	 0.033086	 0.086049	 0.004	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 1469	 0.019753	 0.05	 0.0024	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	3559	 1470	 0.025951	 0.107332	 0.0045	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	3559	 1470	 0.025951	 0.107332	 0.0045	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 1471	 0.005367	 0.029554	 0.0308	 954	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 1472	 0.002771	 0.013605	 0.0249	 2064	 2064	 2064	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 1471	 0.004535	 0.023683	 0.026	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 1473	 0.040312	 0.104056	 0.0023	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	4357	 1473	 0.102797	 0.222978	 0.0025	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 1473	 0.040539	 0.105014	 0.0015	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 1473	 0.04132	 0.090552	 0.0028	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 1474	 0.008122	 0.036857	 0.0655	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 1474	 0.011081	 0.049936	 0.0891	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 1475	 0.000336	 0.002173	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1476	 0.02066	 0.055682	 0.001	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 1477	 0.063744	 0.162006	 0.0018	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 1478	 0.00037	 0.000988	 0.004	 28743	 28743	 28743	 0.0	 0.0	 1	 -30.0	 30.0;
	1890	 1479	 0.000974	 0.001783	 0.0008	 14533	 14533	 14533	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 1479	 0.000403	 0.001386	 0.0001	 20949	 20949	 20949	 0.0	 0.0	 1	 -30.0	 30.0;
	2700	 1479	 0.027967	 0.082137	 0.002	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	2943	 1479	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	2942	 1479	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 1479	 0.011338	 0.044848	 0.0014	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 1480	 0.00156	 0.01041	 0.0192	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 1480	 0.000178	 0.001659	 0.0061	 818.0	 818.0	 818.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 1480	 0.002035	 0.012563	 0.1094	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3767	 1480	 0.000257	 0.001659	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 1480	 0.001432	 0.009557	 0.0223	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3767	 1480	 0.000158	 0.001067	 0.0046	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2516	 1481	 0.059209	 0.159486	 0.0019	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	2516	 1481	 0.059209	 0.159486	 0.0019	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 1483	 0.068959	 0.28511	 0.0156	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	4176	 1483	 0.050214	 0.205996	 0.0246	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	4277	 1483	 0.006727	 0.018141	 0.0009	 1572	 1572	 1572	 0.0	 0.0	 1	 -30.0	 30.0;
	4445	 1483	 0.100126	 0.274402	 0.0092	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 1483	 0.020408	 0.055933	 0.0023	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 1483	 0.050516	 0.173747	 0.0192	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 1483	 0.024439	 0.067019	 0.0023	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 1483	 0.050542	 0.17415	 0.02	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 1484	 0.004787	 0.011338	 0.006	 2713	 2713	 2713	 0.0	 0.0	 1	 -30.0	 30.0;
	4581	 1484	 0.00907	 0.018141	 0.0088	 1647	 1647	 1647	 0.0	 0.0	 1	 -30.0	 30.0;
	3366	 1484	 0.016125	 0.051398	 0.0004	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	4739	 1485	 0.003457	 0.008395	 0.0	 3272	 3272	 3272	 0.0	 0.0	 1	 -30.0	 30.0;
	4739	 1485	 0.000494	 0.008395	 0.0	 3532	 3532	 3532	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 1486	 0.008542	 0.029422	 0.0095	 1044	 1044	 1044	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 1487	 0.003368	 0.036373	 0.0273	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 1488	 0.000375	 0.001383	 0.1711	 313.0	 313.0	 313.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4246	 1489	 0.027337	 0.11678	 0.0047	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 1489	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 1490	 0.003086	 0.006173	 0.01	 4650	 4650	 4650	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 1491	 0.04966	 0.126455	 0.0014	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 1491	 0.052658	 0.143613	 0.0019	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1717	 1492	 0.042076	 0.124213	 0.0028	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 1494	 0.000903	 0.006023	 0.0111	 522.0	 522.0	 522.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 1495	 0.00284	 0.007531	 0.0003	 3691	 3691	 3691	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 1495	 0.039877	 0.104815	 0.0049	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 1500	 0.03284	 0.088765	 0.0042	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2624	 1502	 0.06321	 0.14284	 0.0065	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 1502	 0.024074	 0.053704	 0.0024	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	2280	 1503	 0.063996	 0.161754	 0.0019	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 1503	 0.047956	 0.087783	 0.0025	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	4061	 1503	 0.010532	 0.063719	 0.0019	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 1503	 0.024691	 0.166515	 0.005	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5069	 1503	 0.027816	 0.117662	 0.0028	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4061	 1503	 0.010532	 0.063719	 0.0019	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 1504	 0.002359	 0.016431	 0.0203	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2282	 1505	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4694	 1505	 5.9e-05	 0.001185	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4708	 1505	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 1506	 0.000123	 0.001235	 0.0002	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 1507	 0.010124	 0.043086	 0.0021	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	3371	 1508	 0.014568	 0.089753	 0.0079	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 1508	 0.00716	 0.044074	 0.0024	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 1509	 0.059965	 0.163265	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 1510	 0.063744	 0.153742	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 1510	 0.058705	 0.149156	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	2421	 1511	 0.070093	 0.188461	 0.0025	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 1511	 0.078357	 0.210708	 0.0088	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 1513	 0.110545	 0.202352	 0.0021	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 1513	 0.08642	 0.191232	 0.0021	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 1514	 0.065356	 0.166238	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 1514	 0.033333	 0.090829	 0.0021	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 1515	 0.061476	 0.209625	 0.0025	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	3893	 1515	 0.053918	 0.146888	 0.0017	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 1515	 0.017863	 0.060695	 0.0007	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3429	 1516	 0.049131	 0.204082	 0.0025	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 1516	 0.005543	 0.018896	 0.0002	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 1516	 0.005795	 0.0194	 0.0002	 1459	 1459	 1459	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 1517	 0.000968	 0.00644	 0.0121	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 1518	 0.064815	 0.170741	 0.0081	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 1518	 0.058778	 0.149012	 0.007	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4044	 1518	 0.010247	 0.027778	 0.0013	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	5529	 1518	 0.022469	 0.057407	 0.0028	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	5714	 1518	 0.012222	 0.026914	 0.0021	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	4044	 1518	 0.012346	 0.027407	 0.0021	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 1519	 0.011773	 0.053926	 0.0962	 427.0	 427.0	 427.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2352	 1520	 0.000966	 0.009803	 0.2526	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3416	 1520	 0.002015	 0.020838	 0.5401	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	2351	 1520	 0.000963	 0.009792	 0.2541	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 1521	 0.029383	 0.123951	 0.0065	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 1521	 0.029383	 0.123951	 0.0065	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	1634	 1526	 0.041572	 0.113379	 0.0018	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 1526	 0.014865	 0.061476	 0.0008	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3435	 1526	 0.108088	 0.299824	 0.0027	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 1526	 0.096246	 0.262283	 0.0029	 106	 106	 106	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 1526	 0.058201	 0.161502	 0.0017	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 1526	 0.014865	 0.061476	 0.0008	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 1527	 0.004207	 0.029077	 0.0547	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 1527	 0.002805	 0.019378	 0.0365	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 1528	 0.01285	 0.055933	 0.0035	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 1528	 0.073318	 0.185941	 0.0038	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4919	 1528	 0.074578	 0.22197	 0.007	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 1529	 0.065004	 0.182414	 0.0021	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 1530	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 1531	 0.018392	 0.114386	 0.0015	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	1781	 1532	 0.046049	 0.117284	 0.0058	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	2573	 1532	 0.042469	 0.114321	 0.0055	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 1533	 0.026173	 0.069753	 0.0139	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 1533	 0.062099	 0.167778	 0.0188	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 1534	 0.012099	 0.030617	 0.0013	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	4938	 1533	 0.049383	 0.128148	 0.006	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 1533	 0.011111	 0.028518	 0.0015	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	4113	 1533	 0.017901	 0.048395	 0.0023	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 1535	 0.010311	 0.068543	 0.1276	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 1535	 0.001017	 0.006912	 0.0633	 449.0	 449.0	 449.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 1536	 0.000976	 0.013206	 0.4448	 2406	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 1536	 0.001017	 0.010325	 0.2657	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2947	 1536	 0.001369	 0.017997	 0.6209	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	3624	 1536	 0.002352	 0.025391	 0.5704	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 1536	 0.002021	 0.026575	 0.9197	 1191	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 1536	 0.000976	 0.013213	 0.4448	 2405	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	2606	 1536	 0.001017	 0.010325	 0.2657	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1851	 1537	 0.016661	 0.030497	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	5020	 1537	 0.143109	 0.388511	 0.0044	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	5368	 1537	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 1537	 0.096498	 0.265558	 0.003	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 1538	 0.047115	 0.12774	 0.0013	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5842	 1538	 0.006299	 0.015873	 0.0002	 1981	 1981	 1981	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 1539	 0.023935	 0.082389	 0.001	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 1539	 0.017889	 0.045855	 0.0006	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	3545	 1539	 0.063996	 0.162509	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 1539	 0.012598	 0.043588	 0.0005	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	5368	 1540	 0.071806	 0.194004	 0.0022	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 1541	 0.005223	 0.034671	 0.076	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 1542	 2.1e-05	 0.000301	 0.0116	 2176.0	 2176.0	 2176.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 1542	 0.000697	 0.009107	 0.3114	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 1542	 1.9e-05	 0.00028	 0.0108	 2176.0	 2176.0	 2176.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 1542	 0.001244	 0.016445	 0.5652	 1934	 1934	 1934	 0.0	 0.0	 1	 -30.0	 30.0;
	1933	 1543	 0.008272	 0.021975	 0.001	 1292	 1292	 1292	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 1543	 0.026914	 0.111605	 0.0058	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	3977	 1543	 0.026173	 0.06716	 0.0031	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	5634	 1543	 0.014568	 0.03963	 0.0018	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 1543	 0.026914	 0.111605	 0.0058	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	1737	 1544	 0.005096	 0.033837	 0.0628	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5319	 1544	 0.005057	 0.030084	 0.0567	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3527	 1547	 0.044848	 0.113631	 0.0013	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	2153	 1548	 0.005301	 0.009703	 0.0123	 2751	 2751	 2751	 0.0	 0.0	 1	 -30.0	 30.0;
	2633	 1548	 0.012875	 0.032552	 0.0007	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	2153	 1548	 0.003023	 0.010582	 0.0124	 2764	 2764	 2764	 0.0	 0.0	 1	 -30.0	 30.0;
	2633	 1548	 0.013051	 0.029201	 0.0003	 951	 951	 951	 0.0	 0.0	 1	 -30.0	 30.0;
	4181	 1550	 0.082892	 0.223734	 0.0044	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 1550	 0.044671	 0.121995	 0.0013	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	4181	 1550	 0.059461	 0.162258	 0.0056	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 1551	 0.123457	 0.228521	 0.0025	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 1553	 0.038148	 0.078395	 0.0036	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 1554	 2e-06	 0.000198	 0.0066	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 1555	 0.017654	 0.074444	 0.0039	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	4265	 1555	 0.01	 0.041975	 0.0021	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 1556	 0.05291	 0.134291	 0.001	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 1557	 0.081633	 0.204334	 0.0052	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	2520	 1559	 0.000336	 0.001481	 0.003	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 1559	 0.000652	 0.004346	 0.0081	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 1559	 0.000336	 0.001501	 0.003	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 1561	 0.009776	 0.020635	 0.0187	 1294	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	1849	 1563	 0.000123	 0.000247	 0.001	 109898	 109898	 109898	 0.0	 0.0	 1	 -30.0	 30.0;
	5501	 1563	 0.021975	 0.054815	 0.0026	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	1819	 1563	 0.002335	 0.004274	 0.0002	 6227	 6227	 6227	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 1563	 0.000123	 0.000247	 0.0006	 109898	 109898	 109898	 0.0	 0.0	 1	 -30.0	 30.0;
	1834	 1564	 0.005679	 0.014198	 0.0104	 1984	 1984	 1984	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 1564	 0.033457	 0.086173	 0.0044	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 1564	 0.052346	 0.14037	 0.0168	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 1564	 0.033086	 0.085432	 0.0045	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 1564	 0.033333	 0.085556	 0.004	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	1782	 1565	 0.006202	 0.041343	 0.0759	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 1565	 0.001205	 0.008099	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 1565	 0.001225	 0.008099	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 1567	 0.068758	 0.187579	 0.0021	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4376	 1570	 0.100529	 0.273369	 0.003	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 1570	 0.018645	 0.06576	 0.005	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	5200	 1570	 0.083144	 0.246158	 0.0024	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 1571	 0.02037	 0.049259	 0.0003	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 1572	 0.000988	 0.005709	 0.0101	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4434	 1573	 0.056552	 0.103518	 0.001	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 1573	 0.059965	 0.149156	 0.0041	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 1574	 0.020012	 0.126593	 0.0056	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 1575	 0.001877	 0.012504	 0.0223	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 1575	 0.001462	 0.009758	 0.0182	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 1576	 0.029982	 0.102293	 0.001	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 1576	 0.016377	 0.05543	 0.002	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4454	 1576	 0.00379	 0.006937	 0.0042	 3736	 3736	 3736	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 1576	 0.008566	 0.027463	 0.0	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	3950	 1577	 0.024943	 0.101209	 0.002	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 1577	 0.02973	 0.085412	 0.001	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	5698	 1577	 0.023759	 0.096548	 0.0013	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 1577	 0.056941	 0.154951	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 1578	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 1579	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 1580	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 1581	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 1582	 0.020617	 0.055556	 0.0026	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	2550	 1583	 0.000672	 0.003891	 0.08	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2550	 1583	 0.000632	 0.003812	 0.0911	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 1584	 0.015873	 0.042328	 0.001	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 1584	 0.003023	 0.006047	 0.0001	 4368	 4368	 4368	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 1585	 0.00083	 0.005709	 0.0182	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 1585	 0.001709	 0.016636	 0.0577	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 1585	 0.001758	 0.017442	 0.0547	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 1585	 0.00083	 0.005709	 0.0223	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 1586	 0.000187	 0.00349	 0.0941	 2250.0	 2250.0	 2250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4231	 1587	 0.026833	 0.059889	 0.0007	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	5000	 1587	 0.073797	 0.187075	 0.0021	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	3277	 1588	 0.001605	 0.010247	 0.0005	 3108	 3108	 3108	 0.0	 0.0	 1	 -30.0	 30.0;
	3289	 1588	 0.003086	 0.009012	 0.0153	 3384	 3384	 3384	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 1588	 0.027407	 0.070124	 0.0032	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	5058	 1588	 0.005059	 0.009261	 0.035	 3055	 3055	 3055	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 1588	 0.001975	 0.012222	 0.0006	 2792	 2792	 2792	 0.0	 0.0	 1	 -30.0	 30.0;
	3277	 1588	 0.001481	 0.009383	 0.0005	 3393	 3393	 3393	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 1588	 0.002782	 0.005093	 0.0092	 5554	 5554	 5554	 0.0	 0.0	 1	 -30.0	 30.0;
	5058	 1588	 0.004198	 0.012963	 0.0091	 2366	 2366	 2366	 0.0	 0.0	 1	 -30.0	 30.0;
	2720	 1589	 0.003773	 0.025264	 0.0466	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 1589	 0.005195	 0.023585	 0.0415	 364.0	 364.0	 364.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 1590	 0.031728	 0.12358	 0.0057	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 1591	 0.000617	 0.001235	 0.0019	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 1592	 0.000222	 0.000938	 0.0	 31460	 31460	 31460	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 1593	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 1593	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 1593	 7.9e-05	 0.001284	 0.002	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 1594	 0.024691	 0.059461	 0.0006	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	4541	 1595	 0.102797	 0.280675	 0.0032	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 1595	 0.02318	 0.100529	 0.0046	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4756	 1596	 0.081556	 0.202099	 0.0097	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5345	 1596	 0.031358	 0.082593	 0.004	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	1612	 1597	 0.022676	 0.073318	 0.0008	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 1597	 0.081885	 0.259259	 0.0043	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	2357	 1599	 0.055556	 0.14642	 0.007	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 1598	 0.01	 0.027531	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	5404	 1599	 0.011852	 0.030988	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 1599	 0.042716	 0.112099	 0.0053	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	4982	 1598	 0.01	 0.027531	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 1600	 0.028721	 0.081007	 0.1357	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 1600	 0.012247	 0.062222	 0.1073	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3016	 1600	 0.009067	 0.042884	 0.0861	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 1600	 0.020602	 0.068109	 0.1083	 258.0	 258.0	 258.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 1600	 0.016691	 0.075299	 0.1336	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4304	 1600	 0.008158	 0.03516	 0.0582	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 1600	 0.016612	 0.078676	 0.1316	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 1600	 0.023407	 0.110815	 0.1853	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 1601	 0.001898	 0.021337	 0.4245	 1482	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 1601	 0.001828	 0.020533	 0.4101	 1546	 1546	 1546	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 1601	 0.004633	 0.051018	 1.1581	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 1601	 0.001053	 0.013843	 0.4765	 2287	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 1601	 0.002888	 0.031752	 0.7595	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 1601	 0.001053	 0.01383	 0.4765	 2289	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	2614	 1602	 0.044596	 0.137365	 0.0425	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	3062	 1602	 0.052658	 0.118418	 0.003	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	3426	 1602	 0.023432	 0.070043	 0.0008	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 1602	 0.006803	 0.014109	 0.007	 1858	 1858	 1858	 0.0	 0.0	 1	 -30.0	 30.0;
	2614	 1602	 0.045855	 0.139582	 0.0516	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 1602	 0.043336	 0.113883	 0.0031	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2892	 1603	 0.003319	 0.021472	 0.0405	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 1603	 0.001205	 0.007684	 0.0142	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4209	 1604	 0.002212	 0.014558	 0.0299	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 1604	 0.000435	 0.002923	 0.0091	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5088	 1603	 0.000593	 0.00397	 0.4759	 532.0	 532.0	 532.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 1603	 0.001146	 0.007664	 0.0142	 493.0	 493.0	 493.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 1605	 0.000436	 0.000797	 0.0007	 31538	 31538	 31538	 0.0	 0.0	 1	 -30.0	 30.0;
	5331	 1606	 0.000178	 0.001185	 0.002	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 1607	 0.070799	 0.154951	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4526	 1607	 0.042832	 0.241371	 0.0048	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 1608	 9.9e-05	 0.000454	 0.001	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 1609	 0.03225	 0.097254	 0.0001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 1609	 0.03225	 0.097254	 0.0001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 1610	 0.081129	 0.197531	 0.0019	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 1610	 0.038045	 0.13026	 0.0015	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 1610	 0.036281	 0.098866	 0.0011	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	2096	 1611	 0.024364	 0.10519	 0.0135	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	2308	 1611	 0.026455	 0.104308	 0.0017	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 1612	 0.031242	 0.101537	 0.0012	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 1612	 0.025195	 0.077097	 0.0015	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 1613	 0.015193	 0.061854	 0.0031	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 1614	 0.06324	 0.155077	 0.0017	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 1617	 0.028521	 0.087402	 0.001	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	4016	 1616	 0.041824	 0.153691	 0.002	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 1616	 0.084404	 0.230537	 0.002	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 1616	 0.073621	 0.187352	 0.0023	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	2293	 1618	 0.005669	 0.026094	 0.0476	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 1618	 0.001719	 0.01199	 0.0213	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3371	 1619	 0.006667	 0.042222	 0.0046	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 1619	 0.002593	 0.016049	 0.0008	 1866	 1866	 1866	 0.0	 0.0	 1	 -30.0	 30.0;
	1947	 1620	 0.034517	 0.073318	 0.0009	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	2691	 1621	 0.01284	 0.034444	 0.0016	 809	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 1621	 0.012716	 0.034321	 0.0016	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 1623	 0.018272	 0.041481	 0.0	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 1623	 0.075062	 0.195556	 0.0012	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 1624	 0.028471	 0.116654	 0.0016	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 1625	 0.040464	 0.123684	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 1625	 0.040464	 0.123684	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 1626	 0.018889	 0.050988	 0.0024	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	2263	 1627	 0.161829	 0.34389	 0.0034	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 1630	 1.3e-05	 9.9e-05	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 1631	 0.002741	 0.010506	 0.0005	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	2010	 1632	 0.000138	 0.000336	 0.0314	 85214	 85214	 85214	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 1633	 0.014321	 0.039012	 0.0018	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	3429	 1634	 0.081381	 0.222474	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	2209	 1635	 0.005136	 0.009402	 0.0004	 2839	 2839	 2839	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 1635	 0.001638	 0.004334	 0.0039	 6565	 6565	 6565	 0.0	 0.0	 1	 -30.0	 30.0;
	1857	 1636	 0.038498	 0.097707	 0.0011	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 1636	 0.039557	 0.100529	 0.0011	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 1637	 0.029226	 0.125649	 0.0026	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	2531	 1638	 0.007559	 0.015621	 0.0217	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 1638	 0.006218	 0.011382	 0.0057	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	3582	 1638	 0.01285	 0.048879	 0.0683	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 1638	 0.017637	 0.039808	 0.0067	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	4519	 1638	 0.014109	 0.036281	 0.0102	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	2531	 1638	 0.007055	 0.016881	 0.0194	 1614	 1614	 1614	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 1638	 0.016125	 0.04258	 0.0079	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	4519	 1638	 0.013605	 0.033762	 0.0102	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 1639	 0.001888	 0.013914	 0.403	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 1640	 0.08642	 0.260015	 0.0073	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4361	 1640	 0.048375	 0.132275	 0.0015	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	1808	 1641	 0.031998	 0.137062	 0.001	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 1641	 0.022928	 0.06324	 0.0	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 1642	 0.006979	 0.034316	 0.0531	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 1643	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	2545	 1644	 0.082137	 0.180398	 0.002	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 1644	 0.102646	 0.348652	 0.0041	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 1644	 0.125397	 0.284127	 0.0032	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 1645	 2e-05	 9.9e-05	 0.0	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 1646	 0.063089	 0.153162	 0.0021	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 1646	 0.058957	 0.141849	 0.0014	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 1646	 0.046284	 0.109448	 0.0016	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 1647	 0.018889	 0.057654	 0.0028	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 1647	 0.018395	 0.057531	 0.0005	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 1648	 0.004431	 0.00811	 0.0001	 3291	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 1650	 0.008148	 0.033704	 0.0016	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 1649	 8.6e-05	 0.001235	 0.0	 23993	 23993	 23993	 0.0	 0.0	 1	 -30.0	 30.0;
	1879	 1651	 0.002099	 0.003951	 0.0063	 7204	 7204	 7204	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 1653	 0.022676	 0.070799	 0.0111	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 1657	 0.025432	 0.064444	 0.0031	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 1658	 0.027211	 0.049887	 0.0005	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	2645	 1659	 0.008566	 0.016881	 0.0003	 1607	 1607	 1607	 0.0	 0.0	 1	 -30.0	 30.0;
	2802	 1660	 0.055933	 0.149408	 0.002	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 1661	 0.002481	 0.012134	 0.0218	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 1661	 0.003398	 0.021373	 0.04	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 1661	 0.00081	 0.005551	 0.0101	 565.0	 565.0	 565.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 1662	 0.022676	 0.071554	 0.0021	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 1662	 0.036281	 0.101789	 0.002	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	1792	 1663	 0.00383	 0.017133	 0.0265	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	1792	 1663	 0.005442	 0.015923	 0.0269	 1808	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 1664	 0.101789	 0.280927	 0.0031	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 1664	 0.092467	 0.259033	 0.0068	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5060	 1664	 0.059662	 0.164903	 0.0018	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 1665	 0.020912	 0.090955	 0.0011	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 1666	 0.000756	 0.002268	 0.0	 12351	 12351	 12351	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 1667	 0.095414	 0.176846	 0.0022	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 1668	 0.000336	 0.000672	 0.0469	 41198	 41198	 41198	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 1669	 0.065256	 0.177879	 0.002	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 1669	 0.000512	 0.000938	 0.0005	 28461	 28461	 28461	 0.0	 0.0	 1	 -30.0	 30.0;
	3718	 1669	 0.079315	 0.208944	 0.0023	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3739	 1669	 0.021164	 0.055682	 0.0006	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4232	 1669	 0.084908	 0.2323	 0.0026	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 1669	 0.035777	 0.097758	 0.0029	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 1669	 0.015117	 0.040312	 0.0015	 707	 707	 707	 0.0	 0.0	 1	 -30.0	 30.0;
	3025	 1669	 0.00126	 0.00252	 0.0006	 10795	 10795	 10795	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 1670	 0.005294	 0.036464	 0.0618	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2042	 1671	 0.09297	 0.253716	 0.0028	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 1671	 0.069035	 0.228017	 0.0026	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5343	 1672	 0.002599	 0.004757	 0.0002	 5595	 5595	 5595	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 1673	 0.005518	 0.02197	 0.0033	 1343	 1343	 1343	 0.0	 0.0	 1	 -30.0	 30.0;
	4087	 1673	 0.013756	 0.025179	 0.0011	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 1673	 0.047518	 0.123104	 0.0017	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 1673	 0.005392	 0.02187	 0.0027	 1351	 1351	 1351	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 1674	 0.006558	 0.029807	 0.0516	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1869	 1675	 0.024198	 0.099383	 0.0053	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 1675	 0.046667	 0.199383	 0.017	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	3553	 1677	 0.046822	 0.085707	 0.0021	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	4639	 1678	 0.015803	 0.097531	 0.005	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 1678	 0.012346	 0.056049	 0.0026	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 1678	 0.03642	 0.092469	 0.0044	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 1678	 0.026049	 0.065926	 0.0031	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 1679	 0.008765	 0.022099	 0.001	 1250	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	4521	 1679	 0.037407	 0.094938	 0.0044	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	2483	 1680	 0.062099	 0.157531	 0.0073	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	2514	 1681	 0.118166	 0.32124	 0.0036	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	4627	 1681	 0.058201	 0.147392	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	3941	 1682	 0.002696	 0.007155	 0.0081	 3862	 3862	 3862	 0.0	 0.0	 1	 -30.0	 30.0;
	5534	 1682	 0.009574	 0.038297	 0.0152	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 1682	 0.029378	 0.111287	 0.0018	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 1683	 0.001975	 0.013412	 0.0233	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 1684	 0.018645	 0.041572	 0.0005	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	3656	 1686	 0.022928	 0.058453	 0.0006	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 1686	 0.01348	 0.034467	 0.0004	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 1688	 0.027353	 0.05007	 0.0	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 1689	 0.012144	 0.049332	 0.0012	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	5606	 1689	 0.012094	 0.049206	 0.0009	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 1690	 0.005017	 0.033403	 0.0618	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1726	 1690	 0.003595	 0.019635	 0.0354	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 1690	 0.001422	 0.008217	 0.1007	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3323	 1690	 0.002212	 0.014044	 0.0253	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3712	 1690	 0.001408	 0.008494	 0.2344	 278.0	 278.0	 278.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 1690	 0.002647	 0.01762	 0.0324	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3323	 1690	 0.002212	 0.013985	 0.0263	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 1690	 0.000336	 0.002232	 0.004	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 1691	 0.001512	 0.003779	 0.0001	 7473	 7473	 7473	 0.0	 0.0	 1	 -30.0	 30.0;
	3714	 1692	 1.2e-05	 0.000123	 0.0003	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 1693	 0.000302	 0.001033	 0.0	 28260	 28260	 28260	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 1694	 0.00963	 0.027284	 0.0013	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 1694	 0.00963	 0.024568	 0.0011	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 1694	 0.018642	 0.049876	 0.0021	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 1696	 4.8e-05	 8.8e-05	 0.1993	 322663	 322663	 322663	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 1695	 4.8e-05	 8.8e-05	 0.1993	 322663	 322663	 322663	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 1697	 4.8e-05	 8.8e-05	 0.0001	 303410	 303410	 303410	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 1699	 4.8e-05	 8.8e-05	 0.001	 311307	 311307	 311307	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 1698	 4.8e-05	 8.8e-05	 0.001	 311371	 311371	 311371	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 1700	 0.008314	 0.028471	 0.0003	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	4531	 1702	 0.011332	 0.020743	 0.0007	 1287	 1287	 1287	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 1702	 0.00252	 0.011086	 0.0002	 2676	 2676	 2676	 0.0	 0.0	 1	 -30.0	 30.0;
	5734	 1702	 0.00257	 0.010935	 0.0002	 2708	 2708	 2708	 0.0	 0.0	 1	 -30.0	 30.0;
	4352	 1703	 0.033762	 0.085664	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 1704	 0.008062	 0.027463	 0.0003	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 1705	 0.008768	 0.030209	 0.0003	 967	 967	 967	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 1705	 0.044344	 0.149912	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5304	 1705	 0.043789	 0.148375	 0.0017	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 1705	 0.001285	 0.004107	 0.0	 7068	 7068	 7068	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 1705	 0.01033	 0.028471	 0.0003	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	1715	 1709	 0.000756	 0.007559	 0.0002	 3772	 3772	 3772	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 1708	 0.00315	 0.005766	 0.0047	 4361	 4361	 4361	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 1708	 0.008566	 0.017385	 0.0148	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	3933	 1708	 0.011842	 0.055178	 0.0442	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4073	 1708	 0.001022	 0.001871	 0.0012	 13439	 13439	 13439	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 1708	 0.000756	 0.007559	 0.0002	 3772	 3772	 3772	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 1708	 0.008314	 0.016629	 0.0144	 1542	 1542	 1542	 0.0	 0.0	 1	 -30.0	 30.0;
	3933	 1708	 0.012497	 0.039909	 0.0442	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 1708	 0.009826	 0.019652	 0.0144	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 1708	 0.014024	 0.025671	 0.0148	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 1711	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 1713	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 1710	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 1712	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 1716	 0.000316	 0.001067	 0.2359	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 1716	 0.000395	 0.002706	 0.0253	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 1716	 0.000217	 0.001817	 0.1812	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 1716	 0.002193	 0.014736	 0.0461	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5352	 1716	 0.001225	 0.007822	 0.0324	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 1716	 0.001225	 0.007822	 0.0324	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2236	 1717	 0.053414	 0.145881	 0.0017	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	2253	 1717	 0.011791	 0.040716	 0.0005	 739	 739	 739	 0.0	 0.0	 1	 -30.0	 30.0;
	3130	 1717	 0.000504	 0.002771	 0.0001	 11090	 11090	 11090	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 1717	 0.039557	 0.11489	 0.0002	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	2253	 1717	 0.011842	 0.040816	 0.0005	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 1718	 0.002779	 0.013788	 0.0243	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5352	 1720	 0.000553	 0.001106	 0.163	 25032	 25032	 25032	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 1719	 0.000553	 0.001106	 0.163	 25032	 25032	 25032	 0.0	 0.0	 1	 -30.0	 30.0;
	2238	 1721	 0.00126	 0.003023	 0.0	 9016	 9016	 9016	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 1722	 0.022469	 0.065556	 0.0031	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 1722	 0.032593	 0.100864	 0.005	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 1722	 0.008519	 0.026543	 0.0013	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 1722	 0.028889	 0.078889	 0.0037	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 1722	 0.008148	 0.053333	 0.0026	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 1723	 0.005057	 0.033561	 0.0607	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 1724	 0.031746	 0.08642	 0.001	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5354	 1729	 0.000504	 0.001008	 0.0	 26199	 26199	 26199	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 1731	 0.029259	 0.122346	 0.0164	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 1731	 0.016049	 0.067901	 0.0138	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 1732	 0.001728	 0.007037	 0.0288	 4341	 4341	 4341	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 1733	 0.002446	 0.004477	 0.0	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 1734	 0.057748	 0.157571	 0.0018	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 1735	 0.067775	 0.141597	 0.0016	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 1736	 0.127139	 0.232726	 0.0026	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 1736	 0.000756	 0.103301	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4167	 1735	 0.003779	 0.019652	 0.0002	 1520	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 1735	 0.017637	 0.087176	 0.0007	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 1735	 0.000756	 0.103301	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 1737	 0.004913	 0.032622	 0.0608	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3899	 1739	 0.038395	 0.093951	 0.0158	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3914	 1739	 0.076914	 0.200864	 0.0096	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 1739	 0.015679	 0.039877	 0.0019	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 1740	 0.004535	 0.015369	 0.0194	 1898	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	5527	 1740	 0.027538	 0.063013	 0.0011	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 1743	 0.00033	 0.001503	 0.002	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 1742	 0.000296	 0.001349	 0.002	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 1745	 7e-06	 0.000132	 0.0029	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 1744	 7e-06	 0.000125	 0.0029	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 1746	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 1746	 0.00322	 0.014835	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 1746	 0.00083	 0.00796	 0.0334	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1751	 1746	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 1746	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2333	 1753	 0.004283	 0.014109	 0.0033	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 1754	 0.005291	 0.009826	 0.0044	 2646	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	2332	 1754	 0.006218	 0.011382	 0.0068	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	2862	 1754	 0.001764	 0.003527	 0.0025	 7488	 7488	 7488	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 1753	 0.023683	 0.083396	 0.001	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	2490	 1755	 0.002015	 0.013551	 0.0243	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 1755	 0.001094	 0.011536	 0.036	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 1755	 2e-05	 9.9e-05	 0.0405	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3862	 1755	 0.001205	 0.008	 0.0152	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4254	 1755	 0.00403	 0.027496	 0.0516	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 1755	 0.001096	 0.011575	 0.0359	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 1755	 2e-05	 0.000119	 0.0506	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2934	 1756	 0.060217	 0.230537	 0.003	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 1756	 0.051146	 0.130763	 0.001	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 1756	 0.048123	 0.145629	 0.002	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 1756	 0.078105	 0.22449	 0.002	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 4132	 0.012774	 0.04064	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 1759	 0.001792	 0.00328	 0.0	 7924	 7924	 7924	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 1760	 0.081129	 0.180902	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2516	 1761	 0.041043	 0.108844	 0.0025	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2687	 1762	 0.126016	 0.230672	 0.0025	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 1763	 0.001383	 0.007881	 0.0142	 3869	 3869	 3869	 0.0	 0.0	 1	 -30.0	 30.0;
	2147	 1764	 0.037037	 0.09675	 0.0019	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2335	 1764	 0.022172	 0.056437	 0.0006	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 1765	 0.090703	 0.232048	 0.0026	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	2675	 1767	 0.033258	 0.084908	 0.001	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 1767	 0.036533	 0.093222	 0.001	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 1767	 0.083396	 0.219703	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 1767	 0.070043	 0.177627	 0.002	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2675	 1767	 0.03351	 0.08516	 0.001	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	2849	 1770	 0.000256	 0.004377	 0.156	 1994.0	 1994.0	 1994.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2849	 1769	 0.000263	 0.004377	 0.1574	 1994.0	 1994.0	 1994.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2849	 1771	 0.000263	 0.004384	 0.1588	 997.0	 997.0	 997.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2849	 1768	 0.000263	 0.004391	 0.1588	 1592.0	 1592.0	 1592.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 1772	 0.008818	 0.025951	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 1773	 0.000134	 0.000245	 0.001	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2705	 1774	 0.007861	 0.049509	 0.0006	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	2682	 1775	 0.000178	 0.000711	 0.079	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 1775	 0.000316	 0.001264	 0.1417	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2322	 1777	 0.042099	 0.122963	 0.0062	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	3309	 1778	 0.027654	 0.072593	 0.0034	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 1778	 0.012469	 0.031728	 0.0015	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	3714	 1778	 0.01963	 0.051605	 0.0024	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 1777	 0.064691	 0.164198	 0.0078	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	3909	 1777	 0.028518	 0.077778	 0.0043	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 1777	 0.028025	 0.07642	 0.0036	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	3714	 1778	 0.02037	 0.051852	 0.0024	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 1779	 0.010943	 0.072652	 0.1347	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 1779	 0.014775	 0.052267	 0.083	 566	 566	 566	 0.0	 0.0	 1	 -30.0	 30.0;
	3199	 1779	 0.020543	 0.073482	 0.1174	 279.0	 279.0	 279.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 1779	 0.015921	 0.072375	 0.1281	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 1779	 0.008435	 0.056138	 0.1043	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 1780	 0.042469	 0.115432	 0.0054	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 1780	 0.045679	 0.124691	 0.0058	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	2573	 1781	 0.041728	 0.112346	 0.0053	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	2982	 1781	 0.063951	 0.162346	 0.0076	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 1781	 0.054444	 0.138025	 0.0065	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 1781	 0.018395	 0.047161	 0.0023	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 1782	 0.009912	 0.044701	 0.1817	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 1782	 0.007605	 0.036603	 0.0658	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 1782	 0.005114	 0.03518	 0.0668	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 1783	 0.110355	 0.300076	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2498	 1783	 0.040312	 0.086924	 0.0001	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 1784	 0.035273	 0.089695	 0.001	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	4155	 1785	 0.069539	 0.189972	 0.0002	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	3462	 1786	 0.037037	 0.088183	 0.001	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 1786	 0.003452	 0.021315	 0.0003	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 1786	 0.0161	 0.065533	 0.005	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	5838	 1786	 0.003452	 0.021819	 0.0002	 1337	 1337	 1337	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 1787	 0.00557	 0.03362	 0.0628	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 1788	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 1789	 0.066566	 0.168758	 0.0019	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 1789	 0.047871	 0.121693	 0.0013	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 1790	 0.055808	 0.141471	 0.0016	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 1790	 0.067271	 0.170824	 0.0019	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3276	 1791	 0.075334	 0.19098	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 1791	 0.036785	 0.087679	 0.001	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 1791	 0.013354	 0.036785	 0.0004	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	3973	 1792	 0.059965	 0.152935	 0.0017	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4295	 1792	 0.038851	 0.099975	 0.0058	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	3005	 1793	 0.033704	 0.092222	 0.004	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 1794	 0.002975	 0.019475	 0.0504	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 1794	 0.002627	 0.017975	 0.0324	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 1794	 0.002993	 0.019532	 0.0472	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 1795	 0.049131	 0.139078	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 1795	 0.025397	 0.090728	 0.0016	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	4461	 1796	 0.002923	 0.020543	 0.0365	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 1798	 0.000142	 0.000822	 0.1073	 37106	 37106	 37106	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 1799	 0.000217	 0.000849	 0.1104	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 1800	 0.003779	 0.009826	 0.0112	 2889	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	1800	 1801	 0.003527	 0.009574	 0.0108	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	1802	 4728	 0.000138	 0.000296	 0.0223	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2394	 1803	 0.098262	 0.20257	 0.0022	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4408	 1804	 0.06576	 0.180146	 0.0024	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4470	 1804	 0.046359	 0.124465	 0.001	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4901	 1804	 0.015117	 0.044596	 0.001	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	3841	 1805	 0.005965	 0.039901	 0.0739	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 1805	 0.000889	 0.006104	 0.0111	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 1807	 0.005795	 0.015117	 0.0002	 1879	 1879	 1879	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 1806	 0.005795	 0.015117	 0.0002	 1879	 1879	 1879	 0.0	 0.0	 1	 -30.0	 30.0;
	3376	 1808	 0.041799	 0.175384	 0.0026	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 1809	 0.000756	 0.003275	 0.0046	 8785	 8785	 8785	 0.0	 0.0	 1	 -30.0	 30.0;
	3189	 1809	 0.005795	 0.020408	 0.0002	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 1809	 0.113883	 0.281683	 0.0032	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 1809	 0.065004	 0.217687	 0.0025	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 1809	 0.003275	 0.01348	 0.0002	 2129	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 1809	 0.024943	 0.106576	 0.0013	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 1810	 0.004318	 0.007903	 0.0058	 3579	 3579	 3579	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 1810	 0.004398	 0.00805	 0.0058	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 1811	 0.006551	 0.028219	 0.0003	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	3361	 1811	 0.038549	 0.156966	 0.0021	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 1811	 0.02318	 0.098262	 0.0023	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	3361	 1811	 0.038549	 0.156715	 0.0022	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4541	 1811	 0.032502	 0.134543	 0.0038	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	3273	 1812	 0.004681	 0.021847	 0.1382	 386.0	 386.0	 386.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 1813	 0.000831	 0.001688	 0.0	 16165	 16165	 16165	 0.0	 0.0	 1	 -30.0	 30.0;
	3441	 1815	 0.025951	 0.066516	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 1816	 0.019876	 0.083482	 0.0042	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 1816	 0.022839	 0.062346	 0.0029	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	4817	 1818	 0.018395	 0.048148	 0.0019	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	5372	 1818	 0.023457	 0.059753	 0.0028	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 1820	 0.005543	 0.011338	 0.0002	 2468	 2468	 2468	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 1820	 0.005795	 0.01159	 0.0002	 2403	 2403	 2403	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 1821	 0.020741	 0.055679	 0.0028	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	2481	 1823	 0.032452	 0.110179	 0.0013	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	2565	 1823	 0.071303	 0.193752	 0.0022	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4007	 1823	 0.017259	 0.056941	 0.002	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 1824	 0.002953	 0.019787	 0.0363	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 1824	 0.002963	 0.019733	 0.0365	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 1825	 0.000494	 0.002212	 0.004	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 1825	 0.000474	 0.002193	 0.004	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 1826	 0.013704	 0.061728	 0.0008	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 1826	 0.019383	 0.082963	 0.0015	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 1827	 0.011168	 0.020443	 0.002	 1306	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	3542	 1827	 0.053313	 0.199471	 0.0173	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 1829	 0.002086	 0.025528	 0.4534	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 1829	 0.001432	 0.015665	 0.3754	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 1830	 0.036667	 0.102963	 0.0047	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 1831	 0.020408	 0.085412	 0.0014	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 1832	 0.010582	 0.022928	 0.0231	 1170	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 1832	 0.04132	 0.114135	 0.0022	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	5769	 1832	 0.015117	 0.04006	 0.0005	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 1832	 0.011086	 0.02318	 0.0211	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 1833	 0.002726	 0.018212	 0.0481	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 1833	 0.002765	 0.018212	 0.0486	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4733	 1835	 0.008314	 0.031494	 0.001	 907	 907	 907	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 1836	 0.010753	 0.029321	 0.0014	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 1837	 0.051444	 0.105716	 0.0048	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 1838	 0.034593	 0.087579	 0.0014	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2420	 1838	 0.025185	 0.046101	 0.0005	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 1838	 0.039683	 0.14714	 0.0023	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 1838	 0.003595	 0.00658	 0.0006	 3938	 3938	 3938	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 1838	 0.086168	 0.187453	 0.0021	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 1838	 0.015873	 0.09801	 0.0013	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	2477	 1838	 0.063996	 0.139582	 0.001	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 1839	 0.000375	 0.002548	 0.0061	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5526	 1839	 0.001969	 0.011678	 0.0223	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 1841	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 1840	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 1842	 0.05805	 0.147443	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 1842	 0.041068	 0.104812	 0.0012	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	2023	 1843	 0.168002	 0.377601	 0.0079	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	2329	 1843	 0.037289	 0.098262	 0.0077	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 1843	 0.107987	 0.222827	 0.0057	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 1844	 0.003832	 0.019733	 0.0359	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 1848	 0.011975	 0.03037	 0.0015	 984	 984	 984	 0.0	 0.0	 1	 -30.0	 30.0;
	2882	 1852	 0.08642	 0.218947	 0.0025	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4275	 1853	 0.022172	 0.056437	 0.0006	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 1854	 0.053691	 0.137944	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	2502	 1854	 0.027715	 0.071554	 0.0008	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	2261	 1857	 0.017889	 0.067523	 0.0008	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 1857	 0.064248	 0.166541	 0.0018	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 1857	 0.047569	 0.122575	 0.0019	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	2778	 1858	 0.014865	 0.039305	 0.0005	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 1858	 0.023935	 0.075838	 0.0009	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 1859	 0.019904	 0.085412	 0.0039	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	3070	 1860	 0.026959	 0.061225	 0.0007	 442	 442	 442	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 1860	 0.038801	 0.081885	 0.0009	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 1861	 0.003779	 0.012598	 0.0021	 2313	 2313	 2313	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 1862	 0.010834	 0.052658	 0.001	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	4025	 1862	 0.010293	 0.018841	 0.0002	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	4287	 1862	 0.007055	 0.026707	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	3653	 1863	 0.002066	 0.012018	 0.0148	 2495	 2495	 2495	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 1867	 0.005901	 0.019494	 0.001	 1459	 1459	 1459	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 1868	 0.02321	 0.049259	 0.0023	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 1869	 0.024198	 0.101728	 0.0052	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 1870	 0.051728	 0.099383	 0.0042	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 1870	 0.074815	 0.149753	 0.0066	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 1870	 0.035494	 0.14963	 0.0076	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 1872	 0.053162	 0.173343	 0.0021	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 1873	 0.002771	 0.011338	 0.0002	 2530	 2530	 2530	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 1873	 0.007307	 0.031242	 0.0059	 921	 921	 921	 0.0	 0.0	 1	 -30.0	 30.0;
	1948	 1874	 0.046863	 0.127992	 0.0014	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	2561	 1874	 0.053414	 0.13681	 0.0018	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 1875	 0.034517	 0.144621	 0.0024	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	2683	 1876	 0.009787	 0.017916	 0.0319	 1486	 1486	 1486	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 1877	 0.000123	 0.001235	 0.0	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 1880	 0.018695	 0.036256	 0.0004	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 1881	 0.000247	 0.001235	 0.0006	 23584	 23584	 23584	 0.0	 0.0	 1	 -30.0	 30.0;
	3669	 1882	 0.023432	 0.074074	 0.001	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 1882	 0.04384	 0.109851	 0.001	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	4748	 1882	 0.010078	 0.024439	 0.0003	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 1882	 0.054674	 0.137818	 0.002	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 1883	 0.004321	 0.019876	 0.0172	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 1883	 0.004321	 0.019876	 0.0172	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	3746	 1884	 5.9e-05	 0.000138	 0.0081	 206236	 206236	 206236	 0.0	 0.0	 1	 -30.0	 30.0;
	3060	 1886	 0.036667	 0.098889	 0.0049	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	3060	 1887	 0.036667	 0.098889	 0.0049	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	4226	 1888	 0.012469	 0.031482	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 1891	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 1892	 2e-05	 0.000198	 0.001	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 1893	 0.000217	 0.00081	 0.1002	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 1901	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 1900	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 1899	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 1898	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 1902	 0.03036	 0.087856	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 1902	 0.041068	 0.104308	 0.0012	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 1903	 0.00381	 0.02541	 0.0471	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3970	 1904	 0.007559	 0.050643	 0.001	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	4215	 1904	 0.054422	 0.150214	 0.0844	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4258	 1904	 0.031746	 0.136054	 0.0016	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 1904	 0.023432	 0.126228	 0.002	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	5276	 1904	 0.036281	 0.153943	 0.002	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 1904	 0.021164	 0.073293	 0.0011	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	3984	 1904	 0.008314	 0.035525	 0.0	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	5677	 1904	 0.035273	 0.089947	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	3984	 1904	 0.008314	 0.035525	 0.001	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	2914	 1905	 0.00476	 0.032099	 0.0567	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 1905	 0.002825	 0.019082	 0.0344	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 1905	 0.000593	 0.00403	 0.0071	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 1905	 0.0016	 0.010884	 0.0192	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4457	 1907	 0.018712	 0.063684	 0.1073	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	4932	 1907	 0.01297	 0.04896	 0.079	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	4265	 1908	 0.008519	 0.017037	 0.0008	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 1909	 0.032754	 0.089191	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 1910	 0.049887	 0.127992	 0.0014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 1911	 0.012716	 0.052593	 0.0034	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 1912	 0.010078	 0.018645	 0.0236	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	5653	 1912	 0.075334	 0.13807	 0.0024	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 1912	 0.010078	 0.018645	 0.0236	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 1913	 0.045881	 0.12197	 0.0017	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 1913	 0.038801	 0.080121	 0.0013	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 1913	 0.020912	 0.066767	 0.001	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 1914	 0.001363	 0.009106	 0.0304	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 1914	 0.011437	 0.078084	 0.1377	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 1916	 0.002016	 0.007055	 0.0065	 4122	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 1915	 0.000171	 0.000313	 0.0	 84779	 84779	 84779	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 1917	 0.007307	 0.019904	 0.0002	 1393	 1393	 1393	 0.0	 0.0	 1	 -30.0	 30.0;
	2255	 1918	 0.000869	 0.004407	 0.4212	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 1919	 0.008642	 0.022346	 0.0011	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 1920	 0.003527	 0.015117	 0.0002	 1903	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 1920	 0.001764	 0.006047	 0.006	 4688	 4688	 4688	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 1920	 0.003779	 0.015117	 0.0011	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 1921	 0.003527	 0.009322	 0.0106	 3052	 3052	 3052	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 1922	 0.000756	 0.002016	 0.0	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 1923	 0.001948	 0.003565	 0.0	 7487	 7487	 7487	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 1924	 0.107332	 0.272109	 0.0031	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 1925	 0.00069	 0.001263	 0.0032	 21948	 21948	 21948	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 1925	 0.001728	 0.005679	 0.0003	 5407	 5407	 5407	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 1926	 0.01033	 0.034014	 0.0004	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	2326	 1927	 0.000217	 0.000474	 0.0445	 59375	 59375	 59375	 0.0	 0.0	 1	 -30.0	 30.0;
	2195	 1928	 0.039136	 0.124321	 0.007	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 1928	 0.039383	 0.101358	 0.0057	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	2408	 1928	 0.030247	 0.079383	 0.0046	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	4244	 1928	 0.000741	 0.001728	 0.0011	 16129	 16129	 16129	 0.0	 0.0	 1	 -30.0	 30.0;
	4244	 1928	 0.000741	 0.001728	 0.0012	 16129	 16129	 16129	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 1929	 0.002765	 0.012998	 0.0213	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 1930	 0.012593	 0.078025	 0.004	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 1930	 0.012099	 0.078272	 0.004	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 1931	 0.001205	 0.015845	 0.5487	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 1931	 0.000623	 0.008172	 0.283	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 1931	 0.001205	 0.015852	 0.5487	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 1931	 0.000623	 0.008172	 0.283	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 1932	 0.072814	 0.198287	 0.0022	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 1932	 0.017133	 0.072814	 0.0001	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 1932	 0.017133	 0.072814	 0.0001	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 1933	 0.014938	 0.039012	 0.0018	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 1935	 0.001622	 0.010949	 0.0816	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2972	 1935	 0.004361	 0.019407	 0.0346	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4461	 1935	 0.00644	 0.043615	 0.081	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2972	 1935	 0.002884	 0.019127	 0.0357	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 1936	 0.003553	 0.040406	 0.8776	 787	 787	 787	 0.0	 0.0	 1	 -30.0	 30.0;
	4551	 1936	 0.001413	 0.020512	 0.5314	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 1936	 0.002029	 0.020568	 0.5372	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	2290	 1936	 0.001233	 0.012465	 0.3235	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4551	 1936	 0.00141	 0.019927	 0.5463	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	4292	 1938	 0.000983	 0.012909	 0.4476	 2461	 2461	 2461	 0.0	 0.0	 1	 -30.0	 30.0;
	2659	 1941	 0.028647	 0.075032	 0.0049	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 1942	 0.001058	 0.006576	 0.0116	 4433	 4433	 4433	 0.0	 0.0	 1	 -30.0	 30.0;
	2210	 1943	 0.009617	 0.05921	 0.0071	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 1943	 0.014321	 0.036667	 0.0016	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 1944	 0.010864	 0.06	 0.019	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 1943	 0.011728	 0.029753	 0.0015	 1008	 1008	 1008	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 1944	 0.010988	 0.028518	 0.0003	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	2210	 1943	 0.00963	 0.059247	 0.0071	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 1943	 0.009506	 0.030864	 0.0022	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 1945	 0.011299	 0.051259	 0.0881	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 1945	 0.002232	 0.012286	 0.0218	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 1945	 0.003714	 0.017975	 0.0405	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 1949	 0.017385	 0.044344	 0.0	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 1950	 0.003527	 0.009574	 0.0004	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	2697	 1951	 0.003827	 0.010124	 0.0005	 2745	 2745	 2745	 0.0	 0.0	 1	 -30.0	 30.0;
	2890	 1952	 0.017385	 0.074326	 0.0091	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	2913	 1952	 0.013857	 0.056185	 0.0108	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 1954	 0.000123	 0.000333	 0.0	 83671	 83671	 83671	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 1955	 0.034417	 0.113429	 0.0021	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 1956	 0.004938	 0.01	 0.0005	 2664	 2664	 2664	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 1957	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 1958	 0.026707	 0.070547	 0.0051	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	3272	 1959	 0.065004	 0.171328	 0.0019	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 1959	 0.029226	 0.073066	 0.0035	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 1960	 0.002268	 0.005291	 0.0001	 5284	 5284	 5284	 0.0	 0.0	 1	 -30.0	 30.0;
	4431	 1960	 0.012774	 0.023558	 0.0002	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	2299	 1962	 0.003812	 0.018568	 0.0557	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 1961	 0.003911	 0.01679	 0.0284	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 1962	 0.005057	 0.031131	 0.0587	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 1961	 0.002785	 0.018153	 0.0334	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 1963	 0.002569	 0.036468	 0.9253	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 1963	 0.002569	 0.036468	 0.9253	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 1963	 0.005422	 0.039197	 0.841	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	3013	 1965	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 1966	 0.005039	 0.013857	 0.0016	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 1967	 0.082464	 0.277879	 0.0031	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 1978	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 1977	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 1976	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 1975	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 1974	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 1973	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3814	 1979	 0.054674	 0.149534	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 1979	 0.054926	 0.166289	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 1980	 0.00164	 0.011299	 0.0213	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 1980	 0.002647	 0.018035	 0.0334	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3294	 1982	 0.045855	 0.140338	 0.002	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 1983	 0.031494	 0.076846	 0.001	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 1985	 0.035097	 0.068405	 0.0007	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 1985	 0.040816	 0.092719	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 1986	 0.057697	 0.151927	 0.0034	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 1987	 0.018645	 0.037037	 0.0004	 734	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 1988	 0.059209	 0.153439	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 1989	 0.078357	 0.222726	 0.003	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 1990	 0.154926	 0.396699	 0.0098	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	5192	 1991	 0.013025	 0.037111	 0.0018	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 1991	 0.028568	 0.097111	 0.0062	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 1992	 2e-05	 0.000138	 0.001	 509.0	 509.0	 509.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 1992	 0.000395	 0.002647	 0.0051	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 1993	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 1994	 0.041824	 0.090451	 0.001	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 1995	 0.036533	 0.159486	 0.0021	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 1996	 0.081129	 0.207861	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 1996	 0.095641	 0.247367	 0.0028	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	3203	 1996	 0.056437	 0.148652	 0.0019	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4190	 1997	 0.007055	 0.044596	 0.0006	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 1997	 0.006803	 0.045855	 0.0028	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	4749	 1997	 0.019652	 0.05417	 0.0006	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	4190	 1997	 0.006299	 0.039305	 0.0005	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 1997	 0.007055	 0.047367	 0.0006	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 1997	 0.006979	 0.046813	 0.0006	 643	 643	 643	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 1998	 0.003259	 0.021669	 0.0405	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 1998	 0.00324	 0.021768	 0.0395	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 1999	 0.026102	 0.066087	 0.0011	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 2000	 0.066516	 0.181406	 0.0028	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 2002	 0.05543	 0.141093	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 2002	 0.054422	 0.138574	 0.0016	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 2003	 0.055178	 0.140338	 0.0016	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	4878	 2003	 0.05417	 0.13807	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 2004	 0.000252	 0.00252	 0.0001	 13395	 13395	 13395	 0.0	 0.0	 1	 -30.0	 30.0;
	2679	 2005	 0.002351	 0.011022	 0.0182	 2747	 2747	 2747	 0.0	 0.0	 1	 -30.0	 30.0;
	3288	 2005	 0.002252	 0.015842	 0.079	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 2005	 0.00132	 0.013076	 0.0385	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 2005	 0.005531	 0.027042	 0.0628	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 2006	 0.016755	 0.051348	 0.0053	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	3718	 2007	 0.058453	 0.15747	 0.0022	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 2010	 0.000138	 0.000316	 0.0314	 89765	 89765	 89765	 0.0	 0.0	 1	 -30.0	 30.0;
	4161	 2011	 0.020988	 0.055185	 0.0026	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 2011	 0.016049	 0.040741	 0.0019	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	2817	 2012	 0.076594	 0.194507	 0.0022	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 2012	 0.120106	 0.327186	 0.0042	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 2012	 0.180957	 0.33124	 0.0039	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 2013	 0.009264	 0.038696	 0.0638	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4457	 2013	 0.022084	 0.061906	 0.1013	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 2013	 0.017185	 0.07921	 0.1336	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 2014	 0.089494	 0.244142	 0.0028	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	4310	 2015	 0.001358	 0.003704	 0.0002	 7529	 7529	 7529	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 2016	 0.000296	 0.001936	 0.0137	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 2019	 0.008818	 0.024188	 0.0002	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 2020	 0.00907	 0.024439	 0.0002	 1167	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	5467	 2021	 0.00237	 0.005748	 0.0111	 5013	 5013	 5013	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 2023	 0.072814	 0.15999	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 2023	 0.104157	 0.283522	 0.0038	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 2024	 0.000336	 0.002252	 0.004	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2709	 2026	 0.068531	 0.186697	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 2026	 0.016881	 0.045855	 0.0006	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	2548	 2027	 0.022676	 0.070295	 0.0065	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 2027	 0.035021	 0.081129	 0.0025	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 2028	 0.001008	 0.00252	 0.001	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 2029	 0.002593	 0.006914	 0.0003	 4107	 4107	 4107	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 2030	 0.002099	 0.006173	 0.0003	 4651	 4651	 4651	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 2031	 0.010124	 0.027296	 0.0045	 1021	 1021	 1021	 0.0	 0.0	 1	 -30.0	 30.0;
	2093	 2032	 0.022593	 0.077901	 0.0045	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	2688	 2032	 0.008395	 0.017531	 0.0826	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	3382	 2032	 0.016173	 0.068395	 0.0044	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 2034	 0.046667	 0.119136	 0.0057	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	4756	 2034	 0.017531	 0.040123	 0.0019	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	4885	 2035	 0.00358	 0.00716	 0.0194	 3711	 3711	 3711	 0.0	 0.0	 1	 -30.0	 30.0;
	5564	 2036	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 2036	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 2037	 0.061225	 0.171328	 0.0018	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 2037	 0.072688	 0.199899	 0.0022	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 2038	 0.020988	 0.107155	 0.0126	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 2038	 0.021164	 0.107332	 0.0012	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 2038	 0.021164	 0.107332	 0.0012	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	2434	 2039	 0.047619	 0.129756	 0.0014	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	2061	 2040	 0.117914	 0.298816	 0.0034	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 2040	 0.059234	 0.162761	 0.0018	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3749	 2040	 0.071429	 0.181532	 0.0021	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 2040	 0.03225	 0.081885	 0.0009	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	5224	 2040	 0.008566	 0.053666	 0.0007	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	5219	 2040	 0.03225	 0.081129	 0.001	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	4457	 2041	 0.011556	 0.052998	 0.0942	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 2041	 0.011299	 0.057086	 0.1013	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 2042	 0.075334	 0.243638	 0.0022	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	3869	 2043	 0.109625	 0.278786	 0.0174	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 2044	 0.002173	 0.014519	 0.0273	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2447	 2046	 0.026449	 0.06568	 0.0207	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	2666	 2046	 0.012133	 0.030178	 0.0095	 972	 972	 972	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 2049	 0.013253	 0.051348	 0.0013	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	2235	 2049	 0.010582	 0.063744	 0.001	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	2274	 2049	 0.014588	 0.067498	 0.0008	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	2841	 2049	 0.012169	 0.032779	 0.001	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	2224	 2050	 0.000942	 0.004946	 0.0182	 6148	 6148	 6148	 0.0	 0.0	 1	 -30.0	 30.0;
	2744	 2050	 0.008533	 0.038716	 0.0678	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 2050	 0.002977	 0.014748	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 2050	 0.002483	 0.016496	 0.0304	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 2050	 0.004188	 0.019082	 0.0334	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4180	 2050	 0.001742	 0.01171	 0.038	 457.0	 457.0	 457.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 2050	 0.001414	 0.009527	 0.0172	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 2051	 0.002771	 0.007307	 0.0	 3779	 3779	 3779	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 2053	 0.029479	 0.064248	 0.0007	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 2053	 0.022928	 0.062484	 0.0007	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 2054	 0.008672	 0.04002	 0.084	 256.0	 256.0	 256.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 2054	 0.001237	 0.005636	 0.0256	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4812	 2055	 0.068027	 0.173091	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 2055	 0.012094	 0.031242	 0.0003	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	3198	 2056	 0.003062	 0.020365	 0.0385	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4311	 2056	 0.000786	 0.00524	 0.0273	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 2056	 0.003615	 0.024336	 0.0445	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 2056	 0.001274	 0.008486	 0.0152	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2352	 2057	 0.001634	 0.016835	 0.4361	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 2057	 0.000935	 0.013565	 0.3523	 2335	 2335	 2335	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 2057	 0.001434	 0.01885	 0.6527	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	2351	 2057	 0.001634	 0.016842	 0.4361	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 2057	 0.000934	 0.013565	 0.3523	 2335	 2335	 2335	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 2057	 0.001434	 0.01885	 0.6527	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 2060	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 2059	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 2058	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 2062	 0.000111	 0.001604	 0.0416	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 2063	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 2064	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 2065	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 2066	 0.000111	 0.001606	 0.0416	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 2067	 0.000111	 0.001616	 0.0419	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 2068	 0.000756	 0.004283	 0.0002	 6804	 6804	 6804	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 2070	 0.07357	 0.199647	 0.0022	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	2735	 2070	 0.157697	 0.401864	 0.0045	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	4698	 2070	 0.090955	 0.248425	 0.0058	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 2071	 0.014696	 0.0269	 0.0656	 935	 935	 935	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 2072	 0.000988	 0.006953	 0.0273	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 2073	 0.013102	 0.089947	 0.002	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	3858	 2073	 0.016881	 0.071806	 0.001	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 2073	 0.066012	 0.21542	 0.002	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 2076	 0.001481	 0.005309	 0.0002	 5731	 5731	 5731	 0.0	 0.0	 1	 -30.0	 30.0;
	3973	 2077	 0.049635	 0.127992	 0.0014	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 2077	 0.038549	 0.100277	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 2078	 0.005195	 0.034528	 0.0648	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 2080	 0.018025	 0.047531	 0.0049	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 2080	 0.023457	 0.064074	 0.0029	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 2079	 0.018025	 0.047407	 0.0049	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 2082	 0.0013	 0.005888	 0.0101	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5263	 2081	 0.001306	 0.005912	 0.0101	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2279	 2083	 0.009506	 0.019136	 0.0008	 1391	 1391	 1391	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 2083	 0.010124	 0.026296	 0.0013	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 2084	 0.01321	 0.035185	 0.0018	 791	 791	 791	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 2085	 0.000953	 0.001744	 0.0	 15304	 15304	 15304	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 2086	 0.184933	 0.456034	 0.0052	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 2086	 0.031494	 0.11615	 0.0014	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 2086	 0.111363	 0.3419	 0.0039	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	4526	 2086	 0.039305	 0.161502	 0.002	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4528	 2087	 0.002094	 0.013294	 0.0243	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2113	 2088	 0.006499	 0.043259	 0.08	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2676	 2088	 0.003737	 0.037823	 0.1088	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 2088	 0.001254	 0.008365	 0.0152	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 2089	 0.00247	 0.027208	 0.5747	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 2089	 0.001766	 0.019792	 0.3957	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 2090	 0.008062	 0.019904	 0.0187	 1375	 1375	 1375	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 2090	 0.007811	 0.019652	 0.0187	 1397	 1397	 1397	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 2091	 0.01679	 0.042346	 0.0021	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 2092	 0.039753	 0.106506	 0.0052	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 2093	 0.014568	 0.090123	 0.0146	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	2285	 2095	 0.000401	 0.001817	 0.003	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5850	 2094	 0.0032	 0.014637	 0.0243	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 1496	 2e-05	 0.000198	 0.0	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	3139	 2096	 0.036256	 0.092492	 0.0034	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	2567	 2097	 0.003401	 0.022763	 0.0415	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 2097	 0.004122	 0.027542	 0.0501	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 2098	 0.090955	 0.247669	 0.0069	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 2098	 0.040514	 0.110506	 0.0013	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	2486	 2101	 0.010557	 0.019325	 0.0008	 1378	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 2101	 0.004938	 0.01321	 0.0006	 2151	 2151	 2151	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 2101	 0.004938	 0.01321	 0.0006	 2151	 2151	 2151	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 2102	 0.048395	 0.119753	 0.0248	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 2102	 0.048395	 0.119753	 0.0245	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 2103	 0.006047	 0.016125	 0.0002	 1715	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	2204	 2104	 0.037289	 0.154195	 0.0019	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 2104	 0.017889	 0.045855	 0.0005	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	4699	 2104	 0.00907	 0.025951	 0.0002	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 2104	 0.011338	 0.038801	 0.0005	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 2104	 0.019148	 0.051398	 0.0006	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 2104	 0.023432	 0.09675	 0.0012	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 2104	 0.017133	 0.071051	 0.0009	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	4392	 2105	 0.001817	 0.008198	 0.0142	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 2105	 0.001857	 0.012504	 0.0233	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2876	 2106	 0.065679	 0.209012	 0.0097	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 2106	 0.009136	 0.025556	 0.0011	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 2109	 0.007105	 0.014009	 0.0002	 1937	 1937	 1937	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 2108	 0.00325	 0.00844	 0.0001	 3363	 3363	 3363	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 2111	 0.000252	 0.001613	 0.0002	 18630	 18630	 18630	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 2110	 0.000252	 0.001663	 0.0002	 18082	 18082	 18082	 0.0	 0.0	 1	 -30.0	 30.0;
	2618	 2112	 0.094104	 0.251676	 0.0028	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 2112	 0.066868	 0.185059	 0.0047	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4163	 2112	 0.163517	 0.334593	 0.004	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 2112	 0.069992	 0.202973	 0.002	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 2112	 0.106122	 0.297178	 0.0032	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 2113	 0.002844	 0.018884	 0.0354	 402.0	 402.0	 402.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 2114	 0.079365	 0.221466	 0.0025	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 2114	 0.015293	 0.042328	 0.0005	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 2115	 0.068783	 0.261779	 0.003	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 2116	 0.075838	 0.216679	 0.0024	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	3699	 2116	 0.074074	 0.211136	 0.0024	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	5408	 2117	 0.004787	 0.033938	 0.0003	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 2118	 0.081381	 0.225246	 0.0019	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	3013	 2119	 0.023683	 0.052406	 0.001	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 2120	 0.00025	 0.0025	 0.0	 13742	 13742	 13742	 0.0	 0.0	 1	 -30.0	 30.0;
	2463	 2122	 0.000252	 0.00252	 0.0017	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 2122	 0.0194	 0.05417	 0.0026	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 2123	 0.058453	 0.163517	 0.0018	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	3448	 2123	 0.097002	 0.267826	 0.003	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 2123	 0.040312	 0.109095	 0.0017	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 2124	 0.024691	 0.074326	 0.0009	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	3525	 2124	 0.05543	 0.140842	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 2125	 0.018645	 0.051146	 0.0006	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	3352	 2125	 0.015369	 0.048627	 0.0721	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	3793	 2125	 0.078357	 0.161754	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4059	 2125	 0.087402	 0.222525	 0.0272	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 2125	 0.016629	 0.044092	 0.0006	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	3793	 2125	 0.054926	 0.148652	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 2125	 0.016629	 0.044092	 0.0006	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	5382	 2127	 0.066037	 0.18002	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	2678	 2128	 0.051272	 0.133459	 0.0015	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 2129	 0.075082	 0.193248	 0.003	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 2128	 0.065004	 0.162509	 0.002	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 2129	 0.06198	 0.178634	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 2132	 4e-05	 0.000375	 0.0	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 2131	 5.9e-05	 0.000395	 0.0	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 2130	 5.9e-05	 0.000454	 0.001	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4673	 2133	 0.010988	 0.035432	 0.001	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 2135	 0.000494	 0.003319	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 2135	 0.00318	 0.016237	 0.0289	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 2135	 0.003565	 0.013003	 0.0218	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2239	 2135	 0.001363	 0.006104	 0.0111	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 2135	 0.000514	 0.003496	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 2135	 0.000988	 0.004879	 0.0091	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4192	 2136	 0.001764	 0.004787	 0.0001	 5962	 5962	 5962	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 2136	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	2497	 2137	 0.006914	 0.021235	 0.0013	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	3225	 2137	 0.008395	 0.019753	 0.0047	 1217	 1217	 1217	 0.0	 0.0	 1	 -30.0	 30.0;
	5253	 2138	 0.008314	 0.028219	 0.0	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 2138	 0.010078	 0.054926	 0.0021	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	5523	 2138	 0.081633	 0.229277	 0.003	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5065	 2140	 0.000356	 0.003319	 0.0121	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 2141	 0.00036	 0.003356	 0.0167	 853.0	 853.0	 853.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 2142	 0.003652	 0.006685	 0.0004	 3993	 3993	 3993	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 2142	 0.003652	 0.006685	 0.0004	 3993	 3993	 3993	 0.0	 0.0	 1	 -30.0	 30.0;
	1911	 2143	 0.011605	 0.06358	 0.004	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	2759	 2143	 0.000247	 0.000691	 0.0024	 41324	 41324	 41324	 0.0	 0.0	 1	 -30.0	 30.0;
	4422	 2144	 0.001086	 0.007289	 0.0132	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 2144	 0.00308	 0.020628	 0.0375	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4422	 2144	 0.001067	 0.007289	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 2144	 0.003022	 0.020109	 0.0375	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4834	 2144	 0.003022	 0.020168	 0.0435	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 2147	 0.019904	 0.051902	 0.0106	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 2148	 0.025156	 0.046047	 0.0021	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	4351	 2148	 0.003779	 0.009826	 0.0	 2805	 2805	 2805	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 2148	 0.0194	 0.103553	 0.001	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 2148	 0.008062	 0.034266	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 2148	 0.003023	 0.009826	 0.0	 2872	 2872	 2872	 0.0	 0.0	 1	 -30.0	 30.0;
	5526	 2149	 0.001705	 0.010438	 0.0304	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4162	 2151	 0.027161	 0.070876	 0.0034	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 2151	 0.010741	 0.027531	 0.0013	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 2152	 0.000494	 0.001481	 0.0002	 19026	 19026	 19026	 0.0	 0.0	 1	 -30.0	 30.0;
	3542	 2154	 0.099017	 0.241119	 0.0037	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	5411	 2155	 0.005896	 0.030713	 0.0396	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 2156	 0.01008	 0.018452	 0.0006	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	3542	 2157	 0.037185	 0.068066	 0.0007	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5552	 2157	 0.080747	 0.147806	 0.0015	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	1997	 2158	 0.004031	 0.017637	 0.0243	 1682	 1682	 1682	 0.0	 0.0	 1	 -30.0	 30.0;
	1997	 2158	 0.004535	 0.018392	 0.0252	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 2161	 0.002298	 0.004207	 0.0063	 6326	 6326	 6326	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 2162	 0.000123	 0.001235	 0.0047	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 2163	 0.001106	 0.007546	 0.0354	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 2164	 0.000158	 0.001343	 0.5594	 654.0	 654.0	 654.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 2166	 0.015148	 0.064062	 0.0037	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	3208	 2166	 0.009383	 0.040123	 0.0005	 779	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 2166	 0.001111	 0.007284	 0.0013	 4374	 4374	 4374	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 2166	 0.010617	 0.043704	 0.0016	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	4754	 2166	 0.001235	 0.00642	 0.0013	 4930	 4930	 4930	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 2167	 0.002264	 0.015056	 0.0273	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3707	 2167	 0.002173	 0.014617	 0.0263	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3926	 2167	 0.000375	 0.002509	 0.004	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5065	 2167	 0.001746	 0.011648	 0.0216	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 2167	 0.000909	 0.00478	 0.0086	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 2167	 0.001936	 0.011239	 0.0203	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 2167	 0.001738	 0.011635	 0.0213	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 2167	 0.000751	 0.004148	 0.0101	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 2167	 0.001679	 0.01122	 0.0203	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5686	 2171	 0.024188	 0.066213	 0.0007	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 2172	 0.120862	 0.306551	 0.0035	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4433	 2172	 0.05291	 0.134291	 0.0015	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 2173	 0.031922	 0.135097	 0.0017	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3525	 2174	 0.040564	 0.153187	 0.0018	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 2174	 0.06198	 0.158982	 0.0018	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 2173	 0.031973	 0.135299	 0.0017	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	3525	 2174	 0.040564	 0.146888	 0.0018	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 2177	 0.008889	 0.092593	 0.0151	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 2177	 0.008889	 0.092469	 0.0144	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 2179	 0.005693	 0.01042	 0.0044	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 2178	 0.005693	 0.01042	 0.0044	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	2682	 2180	 0.000381	 0.000697	 0.0486	 38967	 38967	 38967	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 2181	 0.007307	 0.017133	 0.0191	 1633	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	2881	 2182	 0.000756	 0.00252	 0.0001	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 2182	 0.094986	 0.240867	 0.0032	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	2188	 2185	 0.000252	 0.00252	 0.0011	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	2295	 2185	 0.000756	 0.002016	 0.0023	 13307	 13307	 13307	 0.0	 0.0	 1	 -30.0	 30.0;
	3097	 2185	 0.007559	 0.015369	 0.0126	 1673	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	3296	 2185	 0.009964	 0.01824	 0.0118	 1379	 1379	 1379	 0.0	 0.0	 1	 -30.0	 30.0;
	3708	 2185	 0.002217	 0.004059	 0.0026	 6195	 6195	 6195	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 2185	 0.008296	 0.015186	 0.0096	 1656	 1656	 1656	 0.0	 0.0	 1	 -30.0	 30.0;
	2188	 2185	 0.000252	 0.00252	 0.0011	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 2185	 0.006551	 0.01285	 0.0112	 1987	 1987	 1987	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 2185	 0.004283	 0.01033	 0.0111	 2563	 2563	 2563	 0.0	 0.0	 1	 -30.0	 30.0;
	2326	 2186	 0.000158	 0.000593	 0.0688	 50437	 50437	 50437	 0.0	 0.0	 1	 -30.0	 30.0;
	2851	 2186	 0.000336	 0.001304	 0.162	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 2186	 4e-05	 0.000237	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3962	 2186	 0.000296	 0.002667	 0.1863	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2325	 2186	 0.000362	 0.000664	 0.0466	 40928	 40928	 40928	 0.0	 0.0	 1	 -30.0	 30.0;
	3963	 2186	 0.000435	 0.001659	 0.3351	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 2187	 0.017284	 0.06321	 0.0232	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 2189	 0.007055	 0.022676	 0.0002	 1207	 1207	 1207	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 2190	 0.083648	 0.211892	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 2192	 0.000123	 0.001235	 0.0002	 27888	 27888	 27888	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 2193	 0.000988	 0.002469	 0.0	 9817	 9817	 9817	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 2196	 0.001975	 0.004938	 0.0	 5585	 5585	 5585	 0.0	 0.0	 1	 -30.0	 30.0;
	2199	 2197	 2e-05	 0.000198	 0.0233	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 2197	 0.000237	 0.002272	 0.0081	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 2197	 0.000257	 0.002449	 0.0081	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2200	 2197	 2e-05	 0.000198	 0.0132	 870.0	 870.0	 870.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2201	 2198	 1e-05	 0.0001	 0.0462	 895.0	 895.0	 895.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 2198	 0.001143	 0.011399	 0.2946	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 2198	 0.001087	 0.012375	 0.2513	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3812	 2202	 0.043336	 0.109095	 0.0015	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4933	 2202	 0.028471	 0.078861	 0.0264	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 2204	 0.019904	 0.082892	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	2988	 2205	 0.010582	 0.026455	 0.0003	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	3138	 2206	 0.000879	 0.0037	 0.085	 8140	 8140	 8140	 0.0	 0.0	 1	 -30.0	 30.0;
	5417	 2206	 0.000533	 0.003556	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3137	 2206	 0.000869	 0.003437	 0.0851	 8731	 8731	 8731	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 2207	 0.031746	 0.082389	 0.001	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 2210	 0.004444	 0.028148	 0.0211	 1109	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 2211	 0.073066	 0.199043	 0.0022	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 2212	 0.02066	 0.056185	 0.0006	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	2501	 2213	 0.082892	 0.15999	 0.0017	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 2215	 0.047115	 0.08642	 0.0017	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 2215	 0.021164	 0.132275	 0.0017	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 2215	 0.036281	 0.13681	 0.0017	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 2217	 0.000316	 0.002153	 0.004	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 2216	 0.000316	 0.002153	 0.004	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4808	 2220	 0.056941	 0.156211	 0.0073	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 2220	 0.078861	 0.176619	 0.0019	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2580	 2222	 4e-05	 0.000237	 0.0	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2841	 2223	 0.002897	 0.014412	 0.0002	 2069	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	2467	 2225	 0.000852	 0.008636	 0.2224	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 2225	 0.001288	 0.013033	 0.335	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2226	 1498	 0.000595	 0.001089	 0.0	 25273	 25273	 25273	 0.0	 0.0	 1	 -30.0	 30.0;
	4164	 2226	 0.032099	 0.135679	 0.007	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 2226	 0.000988	 0.003951	 0.0002	 8499	 8499	 8499	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 2227	 0.002872	 0.01227	 0.0183	 2414	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	5062	 2228	 0.026959	 0.073318	 0.0009	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 2229	 2e-05	 0.000198	 0.001	 393.0	 393.0	 393.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2499	 2231	 0.06324	 0.176367	 0.002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	2521	 2231	 0.024943	 0.07735	 0.001	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 2232	 0.014412	 0.039305	 0.0415	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 2232	 0.01421	 0.039405	 0.0442	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 2233	 0.033827	 0.086667	 0.0006	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 2233	 0.017407	 0.111728	 0.0013	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 2233	 0.020148	 0.125259	 0.0092	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 2233	 0.035926	 0.102716	 0.0011	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	2584	 2234	 0.001541	 0.010291	 0.0238	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 2234	 0.000178	 0.001225	 0.002	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5065	 2234	 0.002489	 0.016612	 0.0304	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5850	 2234	 0.002805	 0.01282	 0.0223	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2584	 2234	 0.001541	 0.010252	 0.0192	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 2234	 0.000158	 0.001106	 0.002	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 2235	 0.022928	 0.058881	 0.0013	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	2796	 2237	 0.007284	 0.044321	 0.0059	 718	 718	 718	 0.0	 0.0	 1	 -30.0	 30.0;
	3520	 2237	 0.010124	 0.058519	 0.05	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	2796	 2237	 0.00716	 0.044198	 0.0059	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 2238	 0.02192	 0.049131	 0.001	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 2239	 0.00243	 0.01357	 0.0248	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 2240	 0.061365	 0.112327	 0.001	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 2240	 0.062911	 0.115158	 0.001	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 2240	 0.019652	 0.054296	 0.0006	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 2242	 0.001402	 0.005452	 0.0101	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 2243	 0.012346	 0.057949	 0.1202	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 2244	 0.011852	 0.031358	 0.0015	 887	 887	 887	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 2244	 0.006889	 0.020272	 0.001	 1388	 1388	 1388	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 2246	 0.00214	 0.024723	 0.5545	 1286	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 2246	 0.00338	 0.034294	 0.8866	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	3230	 2246	 0.000229	 0.002465	 0.0549	 1487.0	 1487.0	 1487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 2246	 0.000561	 0.006198	 0.1473	 1731.0	 1731.0	 1731.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3154	 2246	 0.00338	 0.034294	 0.8866	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 2248	 0.005533	 0.010128	 0.0	 2636	 2636	 2636	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 2249	 0.008535	 0.038929	 0.0678	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2901	 2249	 0.001106	 0.005136	 0.0081	 5892	 5892	 5892	 0.0	 0.0	 1	 -30.0	 30.0;
	2395	 2250	 0.099521	 0.25296	 0.0029	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 2251	 0.031111	 0.078642	 0.0067	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4771	 2251	 0.038272	 0.101975	 0.0044	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 2252	 5e-05	 0.000227	 0.0002	 130845	 130845	 130845	 0.0	 0.0	 1	 -30.0	 30.0;
	2485	 2254	 0.042832	 0.179894	 0.0022	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	3613	 2256	 0.003081	 0.020109	 0.0375	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 2256	 0.000533	 0.003536	 0.0061	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 2257	 0.007559	 0.0194	 0.0002	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	4834	 2259	 0.001067	 0.004306	 0.08	 6978	 6978	 6978	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 2258	 0.001067	 0.004306	 0.08	 6978	 6978	 6978	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 2260	 0.004059	 0.007429	 0.0057	 3593	 3593	 3593	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 2262	 0.004662	 0.008534	 0.0039	 3315	 3315	 3315	 0.0	 0.0	 1	 -30.0	 30.0;
	2618	 2263	 0.066566	 0.17284	 0.0022	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 2263	 0.090249	 0.228773	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 2264	 0.006444	 0.012667	 0.0036	 2205	 2205	 2205	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 2265	 0.001936	 0.01284	 0.0243	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 2265	 0.001363	 0.015427	 0.0445	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 2266	 0.047901	 0.15	 0.007	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5613	 2266	 0.014284	 0.08858	 0.0049	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	4416	 2266	 0.001926	 0.018247	 0.1021	 1653	 1653	 1653	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 2266	 0.005037	 0.03142	 0.0017	 953	 953	 953	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 2269	 0.012346	 0.051146	 0.0006	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 2270	 0.000233	 0.00156	 0.003	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 2271	 0.017989	 0.07546	 0.0069	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	2208	 2272	 0.007901	 0.039506	 0.0032	 797	 797	 797	 0.0	 0.0	 1	 -30.0	 30.0;
	2184	 2273	 0.000691	 0.003852	 0.0071	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2206	 2273	 0.000454	 0.003121	 0.0061	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5072	 2273	 0.001896	 0.011022	 0.0284	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2183	 2273	 0.000514	 0.002331	 0.0116	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2206	 2273	 0.000474	 0.003101	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5071	 2273	 0.002272	 0.011062	 0.0263	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4489	 2274	 0.016982	 0.096271	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 2275	 0.000123	 0.001235	 0.0002	 27888	 27888	 27888	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 2276	 0.009423	 0.017248	 0.0002	 1548	 1548	 1548	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 2276	 0.009423	 0.017248	 0.0002	 1548	 1548	 1548	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 2280	 0.05506	 0.100786	 0.001	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 2281	 0.044092	 0.119929	 0.0015	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	3243	 2283	 5.9e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4707	 2283	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 2282	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 2284	 0.028471	 0.072562	 0.0008	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 2286	 0.038395	 0.099136	 0.0047	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 2286	 0.034444	 0.110123	 0.008	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 2288	 0.01159	 0.031998	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 2289	 0.068783	 0.23356	 0.0027	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 2289	 0.032754	 0.111363	 0.0013	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 2290	 0.00081	 0.008193	 0.2108	 1694.0	 1694.0	 1694.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 2291	 0.011482	 0.031111	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	3226	 2291	 0.037407	 0.100864	 0.0047	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	2826	 2292	 0.000756	 0.002016	 0.0	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	3414	 2292	 0.02287	 0.041864	 0.0004	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 2292	 0.089947	 0.230537	 0.003	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 2292	 0.196901	 0.539708	 0.006	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	2540	 2293	 0.002528	 0.016731	 0.0304	 469.0	 469.0	 469.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2827	 2293	 4.8e-05	 8.8e-05	 0.0051	 308785	 308785	 308785	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 2293	 0.008988	 0.060563	 0.1043	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 2294	 0.001008	 0.002016	 0.0	 12712	 12712	 12712	 0.0	 0.0	 1	 -30.0	 30.0;
	3292	 2298	 0.058176	 0.132376	 0.0043	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5746	 2300	 0.073822	 0.164928	 0.0026	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	5830	 2300	 0.00252	 0.007055	 0.0001	 4060	 4060	 4060	 0.0	 0.0	 1	 -30.0	 30.0;
	5207	 2301	 0.065256	 0.259259	 0.0031	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	3308	 2302	 0.085132	 0.155833	 0.0058	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 2302	 0.067432	 0.123433	 0.0032	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 2303	 0.038284	 0.070078	 0.0007	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	2731	 2304	 0.013333	 0.026667	 0.0012	 997	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 2306	 0.018148	 0.036296	 0.0016	 732	 732	 732	 0.0	 0.0	 1	 -30.0	 30.0;
	3868	 2306	 0.018148	 0.036296	 0.0016	 732	 732	 732	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 2306	 0.082222	 0.183951	 0.0084	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	2492	 2308	 0.009574	 0.018896	 0.0254	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	3104	 2308	 0.005442	 0.014386	 0.0163	 1978	 1978	 1978	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 2308	 0.013855	 0.025362	 0.0002	 1053	 1053	 1053	 0.0	 0.0	 1	 -30.0	 30.0;
	5062	 2308	 0.097178	 0.252708	 0.0075	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 2308	 0.007256	 0.030637	 0.0008	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 2308	 0.014556	 0.026645	 0.0002	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 2308	 0.007307	 0.030738	 0.0009	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	3401	 2308	 0.005795	 0.018392	 0.0009	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 2309	 0.002193	 0.014716	 0.0263	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 2309	 0.001323	 0.00883	 0.0162	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2287	 2310	 0.039557	 0.087679	 0.001	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 2310	 0.04258	 0.09423	 0.001	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5534	 2312	 0.013102	 0.035525	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 2313	 0.001481	 0.007072	 0.0121	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 2313	 0.001956	 0.013136	 0.0243	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2921	 2314	 0.067523	 0.184429	 0.0021	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 2314	 0.073056	 0.133728	 0.0043	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5036	 2314	 0.065508	 0.271101	 0.0034	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	5036	 2314	 0.065508	 0.271101	 0.0034	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 2315	 0.011	 0.056595	 0.1027	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 2316	 0.038574	 0.10199	 0.0201	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 2317	 0.010222	 0.025914	 0.0013	 1067	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 2318	 0.005795	 0.014361	 0.0135	 1907	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	4519	 2318	 0.006551	 0.016125	 0.0152	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	3647	 2319	 0.02066	 0.052154	 0.0006	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 2320	 0.012716	 0.052469	 0.0026	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 2321	 0.026984	 0.068808	 0.0022	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	3079	 2324	 0.002383	 0.006457	 0.0003	 4316	 4316	 4316	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 2327	 0.028219	 0.194004	 0.0023	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 2328	 0.000691	 0.004563	 0.0081	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 2330	 0.084656	 0.181406	 0.002	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 2331	 0.007332	 0.024842	 0.0003	 1107	 1107	 1107	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 2334	 0.07609	 0.171076	 0.0187	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3247	 2334	 0.036533	 0.093726	 0.001	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	3415	 2335	 0.069035	 0.175359	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 2335	 0.019501	 0.079516	 0.0085	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 2335	 0.095742	 0.282691	 0.0062	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 2335	 0.013605	 0.037541	 0.0019	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	3415	 2334	 0.066264	 0.168304	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 2334	 0.019652	 0.080625	 0.0102	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 2336	 0.002449	 0.016336	 0.0354	 479.0	 479.0	 479.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 2336	 0.006461	 0.021728	 0.0385	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 2336	 0.002568	 0.017146	 0.0405	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 2337	 0.000457	 0.005035	 0.1458	 1841.0	 1841.0	 1841.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 2338	 0.059753	 0.161605	 0.0077	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	3469	 2338	 0.041728	 0.105802	 0.005	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2857	 2339	 0.110355	 0.310658	 0.0037	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 2340	 0.004283	 0.008566	 0.0001	 3176	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	2887	 2341	 0.029479	 0.121945	 0.0015	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 2341	 0.076594	 0.160242	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	2887	 2341	 0.02973	 0.124717	 0.0016	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 2342	 0.04258	 0.079617	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	3353	 2344	 0.015243	 0.050617	 0.0006	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	4206	 2344	 0.055984	 0.153691	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 2345	 0.017561	 0.045906	 0.0035	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 2345	 0.011842	 0.029982	 0.0	 916	 916	 916	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 2346	 0.003	 0.013517	 0.0243	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 2346	 0.003812	 0.013017	 0.0213	 2283	 2283	 2283	 0.0	 0.0	 1	 -30.0	 30.0;
	2570	 2348	 0.020161	 0.05458	 0.0192	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	2976	 2348	 0.012963	 0.036667	 0.0084	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	4297	 2348	 0.015556	 0.039877	 0.007	 709	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	2570	 2348	 0.020123	 0.054444	 0.0187	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	4298	 2348	 0.015383	 0.039642	 0.007	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	4622	 2349	 0.043333	 0.109877	 0.0079	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	2570	 2348	 0.020247	 0.054568	 0.019	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 2353	 0.006223	 0.016956	 0.0002	 1684	 1684	 1684	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 2354	 0.014568	 0.046543	 0.0023	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 2354	 0.079753	 0.250247	 0.0123	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	3559	 2356	 0.085412	 0.289746	 0.0034	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 2357	 0.048518	 0.128025	 0.006	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 2358	 0.004283	 0.008314	 0.0117	 3252	 3252	 3252	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 2359	 0.010617	 0.028518	 0.0013	 977	 977	 977	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 2361	 0.035525	 0.123457	 0.0069	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 2362	 0.000123	 0.001235	 0.0002	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 2363	 0.097758	 0.229025	 0.0025	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2374	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2373	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2372	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2371	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2370	 2e-06	 0.001244	 0.0	 24882	 24882	 24882	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2369	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 2375	 0.081381	 0.248173	 0.0031	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 2375	 0.003779	 0.012346	 0.0161	 2356	 2356	 2356	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 2375	 0.016881	 0.062963	 0.0177	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 2375	 0.010078	 0.040514	 0.0022	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 2376	 0.002449	 0.011141	 0.0203	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4133	 2376	 0.000672	 0.003141	 0.0051	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4181	 2377	 0.01285	 0.027463	 0.0004	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 2378	 0.034014	 0.08642	 0.0017	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 2378	 0.033006	 0.107836	 0.0204	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 2380	 0.056412	 0.18453	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	3551	 2380	 0.012195	 0.032225	 0.0364	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 2380	 0.105518	 0.344898	 0.0039	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 2381	 0.053414	 0.145629	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	3698	 2381	 0.048627	 0.130511	 0.0068	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 2382	 0.001008	 0.00252	 0.001	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 2384	 0.03351	 0.142857	 0.0043	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 2385	 0.039078	 0.106576	 0.0012	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 2386	 0.006299	 0.01159	 0.0125	 2239	 2239	 2239	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 2386	 0.038045	 0.104812	 0.0198	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 2387	 0.108163	 0.234492	 0.0027	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	3303	 2388	 0.001008	 0.002771	 0.0001	 10014	 10014	 10014	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 2389	 0.02318	 0.060972	 0.0007	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 2390	 0.011386	 0.020842	 0.0153	 1281	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	3639	 2390	 0.033485	 0.091333	 0.001	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	2392	 2391	 0.000454	 0.001209	 0.0	 23551	 23551	 23551	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 2391	 0.070043	 0.23356	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	2909	 2392	 0.102797	 0.260771	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	3331	 2392	 0.078861	 0.267826	 0.0031	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 2392	 0.053918	 0.183422	 0.0021	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2909	 2392	 0.103049	 0.261275	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5548	 2392	 0.054926	 0.185941	 0.0021	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 2393	 0.057697	 0.12522	 0.0002	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4928	 2394	 0.058453	 0.120433	 0.0013	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	2501	 2395	 0.07609	 0.241875	 0.0029	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	2643	 2396	 0.098765	 0.239607	 0.0026	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 2397	 0.015672	 0.037591	 0.0066	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 2397	 0.015672	 0.037591	 0.0066	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	3325	 2399	 0.000252	 0.00126	 0.0	 23670	 23670	 23670	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 2399	 0.024439	 0.084656	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 2400	 0.000296	 0.000751	 0.001	 38032	 38032	 38032	 0.0	 0.0	 1	 -30.0	 30.0;
	3012	 2401	 0.008314	 0.024691	 0.0305	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 2401	 0.01033	 0.044848	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	3721	 2401	 0.003145	 0.005757	 0.0079	 4637	 4637	 4637	 0.0	 0.0	 1	 -30.0	 30.0;
	5652	 2401	 0.005039	 0.021416	 0.0002	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 2401	 0.011363	 0.047241	 0.0047	 626	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 2403	 5.9e-05	 0.000198	 0.0091	 148594	 148594	 148594	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 2402	 4e-05	 0.000198	 0.0051	 151981	 151981	 151981	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 2404	 0.069892	 0.190653	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 2405	 0.025556	 0.064691	 0.0032	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	2982	 2405	 0.041543	 0.107901	 0.0316	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 2406	 0.02318	 0.06324	 0.0007	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 2407	 0.018645	 0.078357	 0.001	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 2408	 0.000123	 0.00037	 0.0	 77773	 77773	 77773	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 2408	 0.014198	 0.037654	 0.0019	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 2409	 0.003779	 0.007559	 0.0052	 3391	 3391	 3391	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 2411	 0.113379	 0.252457	 0.003	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 2413	 0.044848	 0.131519	 0.0015	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 2414	 0.036029	 0.081381	 0.0009	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	4841	 2415	 0.005432	 0.014321	 0.0006	 2105	 2105	 2105	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 2415	 0.004815	 0.012222	 0.0006	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 2416	 8e-05	 0.000147	 0.0091	 184947	 184947	 184947	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 2417	 8.7e-05	 0.00016	 0.0091	 169954	 169954	 169954	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 2418	 0.014941	 0.041572	 0.0005	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 2419	 0.00019	 0.00062	 0.001	 48031	 48031	 48031	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 2421	 0.085916	 0.238095	 0.0037	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 2421	 0.091207	 0.235828	 0.0041	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5455	 2422	 0.00284	 0.005802	 0.0003	 4599	 4599	 4599	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 2423	 0.045603	 0.183422	 0.0021	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 2423	 0.053918	 0.137062	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	3369	 2423	 0.004031	 0.011086	 0.0002	 2503	 2503	 2503	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 2423	 0.05291	 0.143109	 0.0016	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 2423	 0.026203	 0.067523	 0.0007	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 2423	 0.051146	 0.139582	 0.0016	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	2595	 2425	 0.003062	 0.020365	 0.0375	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2784	 2425	 0.000435	 0.002607	 0.0051	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2784	 2424	 0.000494	 0.002923	 0.0051	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 2426	 0.057697	 0.147392	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 2427	 0.047921	 0.111968	 0.0059	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 2427	 0.100781	 0.231293	 0.0058	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 2427	 0.038297	 0.097002	 0.0011	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 2427	 0.190843	 0.349335	 0.0091	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 2428	 0.00239	 0.015842	 0.0284	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 2428	 0.002765	 0.018548	 0.0344	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4476	 2428	 0.005539	 0.038098	 0.0719	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 2428	 0.005116	 0.034252	 0.0628	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 2428	 0.004306	 0.019919	 0.0354	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 2429	 0.027967	 0.075435	 0.0039	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	4252	 2431	 0.016881	 0.043084	 0.0054	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 2431	 0.004913	 0.025044	 0.0229	 1192	 1192	 1192	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 2430	 0.023432	 0.09801	 0.0054	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 2431	 0.027463	 0.074326	 0.0009	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 2430	 0.016125	 0.052658	 0.0012	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 2430	 0.016629	 0.057445	 0.0013	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 2430	 0.012673	 0.053792	 0.0037	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	4252	 2431	 0.021466	 0.053616	 0.0102	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 2431	 0.005367	 0.025724	 0.0279	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	4252	 2431	 0.023961	 0.054497	 0.0097	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 2432	 0.007802	 0.036069	 0.0633	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5496	 2432	 0.000257	 0.00164	 0.003	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 2432	 0.005077	 0.023921	 0.0425	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4393	 2433	 0.066767	 0.182162	 0.0021	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2433	 0.074326	 0.20131	 0.0023	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	3904	 2434	 0.096498	 0.218443	 0.0024	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 2434	 0.043336	 0.179138	 0.0022	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 2434	 0.036785	 0.151927	 0.0019	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	2966	 2436	 0.000514	 0.0048	 0.0172	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 2435	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3313	 2437	 0.097279	 0.215092	 0.0025	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	5575	 2437	 0.01326	 0.024272	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 2439	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 2438	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 2440	 0.103301	 0.230033	 0.003	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 2440	 0.040816	 0.090955	 0.001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	3793	 2441	 0.089695	 0.185185	 0.002	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 2441	 0.078055	 0.318443	 0.0378	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4362	 2441	 0.030206	 0.055292	 0.0006	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 2441	 0.043059	 0.174679	 0.0345	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	5761	 2441	 0.000252	 0.00252	 0.0007	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 2443	 0.023935	 0.065508	 0.0007	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 2444	 0.055178	 0.140086	 0.0016	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 2445	 0.050643	 0.139834	 0.0016	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4778	 2446	 0.087176	 0.292265	 0.0013	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	5564	 2446	 0.057949	 0.156966	 0.0018	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 2446	 0.067271	 0.207861	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 2446	 0.014412	 0.037516	 0.0007	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 2446	 0.013102	 0.035903	 0.0007	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 2447	 0.010533	 0.0368	 0.0121	 826	 826	 826	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 2448	 0.011206	 0.050285	 0.0899	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 2449	 0.013857	 0.038045	 0.0004	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 2449	 0.014361	 0.04006	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 2450	 0.023951	 0.060741	 0.0029	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 2452	 0.000176	 0.000504	 0.0	 56971	 56971	 56971	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 2453	 0.048123	 0.193752	 0.0027	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 2456	 0.061225	 0.151675	 0.0027	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4377	 2456	 0.064374	 0.150894	 0.0034	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	2562	 2457	 0.062716	 0.162222	 0.0075	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	3092	 2457	 0.070988	 0.180741	 0.0086	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4161	 2457	 0.020617	 0.056543	 0.0028	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	4214	 2457	 0.00216	 0.013605	 0.0006	 2157	 2157	 2157	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 2457	 0.01716	 0.052839	 0.0026	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 2457	 0.019012	 0.048642	 0.0023	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	4213	 2457	 0.002148	 0.013568	 0.0006	 2163	 2163	 2163	 0.0	 0.0	 1	 -30.0	 30.0;
	4657	 2459	 0.071816	 0.131457	 0.0011	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 2459	 0.006047	 0.011842	 0.0001	 2288	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	5467	 2460	 2e-05	 0.000198	 0.001	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3338	 2462	 0.060469	 0.156715	 0.0017	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 2463	 0.019652	 0.050894	 0.0006	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	3649	 2464	 0.032185	 0.086951	 0.141	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 2464	 0.042086	 0.112951	 0.0054	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 2466	 0.001975	 0.013235	 0.0309	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3925	 2466	 0.001284	 0.00879	 0.0162	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 2467	 0.002119	 0.02151	 0.5545	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	4240	 2468	 0.062716	 0.114815	 0.004	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	4897	 2468	 0.005556	 0.013827	 0.0006	 2035	 2035	 2035	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 2468	 0.021605	 0.092222	 0.0045	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	3737	 2469	 0.011536	 0.054933	 0.0931	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 2470	 0.001136	 0.014935	 0.5198	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 2470	 0.001136	 0.014935	 0.517	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 2471	 0.078105	 0.191232	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 2471	 0.046988	 0.086012	 0.0032	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 2471	 0.030234	 0.073822	 0.0009	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 2472	 0.027211	 0.070547	 0.0008	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 2474	 0.002771	 0.007811	 0.0001	 3563	 3563	 3563	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 2473	 0.003527	 0.010078	 0.0001	 2766	 2766	 2766	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 2475	 0.049131	 0.140338	 0.0017	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 2476	 0.023029	 0.09743	 0.0012	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	3852	 2477	 0.000604	 0.001106	 0.0007	 23430	 23430	 23430	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 2477	 0.03225	 0.070043	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 2478	 0.152734	 0.410481	 0.0048	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 2479	 0.000504	 0.00126	 0.0	 22412	 22412	 22412	 0.0	 0.0	 1	 -30.0	 30.0;
	3742	 2480	 0.009322	 0.017133	 0.0012	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	2822	 2482	 0.053086	 0.158148	 0.0076	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	4267	 2482	 0.044691	 0.113457	 0.0053	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 2482	 0.004802	 0.013457	 0.0483	 2083	 2083	 2083	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 2483	 0.024074	 0.061235	 0.0029	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 2484	 0.003996	 0.027473	 0.0516	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 2484	 0.007111	 0.048909	 0.0921	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 2486	 0.065524	 0.119941	 0.0052	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 2487	 0.06324	 0.16906	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 2488	 0.15092	 0.310229	 0.0036	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2488	 0.094558	 0.194381	 0.0024	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 2489	 0.02066	 0.076594	 0.0009	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 2489	 0.014361	 0.090955	 0.0012	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 2490	 0.000124	 0.001383	 0.0051	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3597	 2490	 0.001047	 0.006953	 0.0132	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3781	 2490	 9.9e-05	 0.000277	 0.0284	 104366	 104366	 104366	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 2490	 0.003417	 0.022696	 0.0425	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3780	 2490	 9.9e-05	 0.000336	 0.0263	 87644	 87644	 87644	 0.0	 0.0	 1	 -30.0	 30.0;
	3779	 2490	 4e-05	 9.9e-05	 0.0	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 2491	 0.044092	 0.121441	 0.0013	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 2491	 0.023432	 0.063492	 0.0007	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	3591	 2493	 0.004031	 0.008314	 0.0057	 3292	 3292	 3292	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 2495	 0.042076	 0.100529	 0.0012	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 2496	 0.026173	 0.067531	 0.0042	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2718	 2499	 0.103049	 0.262535	 0.0029	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 2499	 0.029151	 0.079516	 0.0009	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 2499	 0.065205	 0.153263	 0.0018	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 2499	 0.002268	 0.006047	 0.0001	 4710	 4710	 4710	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 2500	 0.012812	 0.023452	 0.0002	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 2501	 0.058604	 0.159436	 0.018	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 2501	 0.115797	 0.297682	 0.0097	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 2503	 0.004484	 0.021195	 0.0365	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 2503	 0.00324	 0.014894	 0.0243	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 2504	 0.084077	 0.265709	 0.005	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 2505	 0.026914	 0.073457	 0.0034	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 2506	 5e-05	 0.000252	 0.0	 114924	 114924	 114924	 0.0	 0.0	 1	 -30.0	 30.0;
	4197	 2507	 0.063643	 0.173646	 0.002	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 2507	 0.122197	 0.331066	 0.0038	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 2507	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 2507	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 2507	 0.123709	 0.335853	 0.0038	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	4997	 2508	 0.04389	 0.107256	 0.0012	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	4997	 2508	 0.062482	 0.114371	 0.0012	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 2509	 0.017133	 0.054926	 0.0006	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 2510	 0.002143	 0.014358	 0.0264	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2836	 2512	 0.001335	 0.003527	 0.004	 8065	 8065	 8065	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 2512	 0.102041	 0.278156	 0.0031	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 2513	 0.007307	 0.021164	 0.0147	 1359	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 2513	 0.006903	 0.018468	 0.0008	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 2514	 0.029226	 0.079365	 0.0009	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 2514	 0.025195	 0.079365	 0.001	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 2516	 0.012018	 0.051298	 0.0006	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 2516	 0.012094	 0.051474	 0.001	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 2517	 0.00403	 0.018054	 0.0349	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 2517	 0.004484	 0.021156	 0.0365	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 2518	 0.000557	 0.007335	 0.2533	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 2521	 0.020887	 0.068682	 0.0015	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	4778	 2521	 0.075838	 0.202066	 0.0021	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 2521	 0.089443	 0.243386	 0.0029	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 2522	 0.00716	 0.014321	 0.0006	 1856	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	2536	 2525	 0.013354	 0.03477	 0.005	 770	 770	 770	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 2525	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 2526	 0.000116	 0.000212	 0.0142	 128083	 128083	 128083	 0.0	 0.0	 1	 -30.0	 30.0;
	4809	 2527	 0.059012	 0.158642	 0.0077	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3936	 2528	 0.072058	 0.233812	 0.0036	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	2559	 2529	 0.086924	 0.209121	 0.0021	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 2529	 0.026027	 0.062887	 0.0006	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	2559	 2529	 0.060721	 0.207357	 0.0024	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 2530	 0.172084	 0.417737	 0.0047	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 2532	 0.028958	 0.053008	 0.0005	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	2687	 2533	 0.039053	 0.08642	 0.001	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 2533	 0.033258	 0.078357	 0.001	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	4818	 2533	 0.080306	 0.146998	 0.0012	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	5474	 2533	 0.013983	 0.038095	 0.0005	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	2571	 2534	 0.001327	 0.008873	 0.0466	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 2534	 0.002291	 0.01521	 0.0284	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 2535	 0.000179	 0.000327	 0.0233	 83031	 83031	 83031	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 2536	 0.03351	 0.083396	 0.0069	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 2537	 0.013102	 0.034266	 0.0051	 781	 781	 781	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 2538	 0.012094	 0.058957	 0.0172	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 2539	 0.004359	 0.018544	 0.0008	 1550	 1550	 1550	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 2539	 0.030234	 0.08642	 0.001	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 2539	 0.030234	 0.08642	 0.001	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 2540	 0.001244	 0.008296	 0.0142	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 2541	 0.087679	 0.284455	 0.0034	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 2542	 0.008566	 0.026959	 0.0003	 1013	 1013	 1013	 0.0	 0.0	 1	 -30.0	 30.0;
	5478	 2544	 0.004787	 0.014361	 0.0002	 1893	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 2543	 0.00252	 0.007307	 0.0001	 3707	 3707	 3707	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 2545	 0.115898	 0.248173	 0.0027	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 2545	 0.072562	 0.248173	 0.0029	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 2546	 0.005845	 0.012925	 0.0001	 2082	 2082	 2082	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 2547	 0.091774	 0.167992	 0.0017	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	3684	 2548	 0.042328	 0.173595	 0.001	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 2548	 0.008062	 0.047619	 0.0006	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 2548	 0.025447	 0.070295	 0.0008	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 2548	 0.017637	 0.056437	 0.0019	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	5695	 2549	 0.010667	 0.034444	 0.0112	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	3911	 2550	 0.009857	 0.066884	 0.1266	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 2550	 0.000632	 0.003931	 0.0243	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4744	 2550	 0.002153	 0.009758	 0.0172	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4176	 2552	 0.063996	 0.163013	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 2553	 0.097758	 0.247518	 0.0089	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 2554	 0.021482	 0.057407	 0.0032	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 2554	 0.020494	 0.057654	 0.0026	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	2766	 2555	 0.046107	 0.192996	 0.0083	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 2556	 0.100277	 0.276896	 0.0031	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	3699	 2556	 0.026707	 0.076342	 0.0009	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 2557	 0.045926	 0.12358	 0.0058	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 2557	 0.021235	 0.054691	 0.0026	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	3842	 2558	 0.019174	 0.04447	 0.0006	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 2558	 0.080877	 0.187705	 0.002	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	3646	 2559	 0.113076	 0.249786	 0.0028	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5573	 2559	 0.007811	 0.047871	 0.0006	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 2559	 0.007307	 0.022172	 0.0002	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 2559	 0.075586	 0.24641	 0.0024	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 2559	 0.011842	 0.072814	 0.001	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	4461	 2560	 0.003279	 0.022637	 0.0415	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 2562	 0.044815	 0.122222	 0.0057	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 2563	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 2564	 0.015621	 0.043084	 0.0005	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 2565	 0.055933	 0.146888	 0.0	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	4007	 2565	 0.031545	 0.104006	 0.0043	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	3105	 2566	 0.089695	 0.165281	 0.0025	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	3824	 2566	 0.049383	 0.126228	 0.0022	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 2566	 0.090098	 0.249055	 0.0072	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 2566	 0.019425	 0.04898	 0.001	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 2566	 0.027765	 0.082389	 0.0015	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 2567	 0.001932	 0.012802	 0.0233	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 2568	 0.00063	 0.006413	 0.1632	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 2569	 0.014691	 0.049876	 0.0024	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 2569	 0.042716	 0.14963	 0.0071	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 2570	 0.009753	 0.024074	 0.0133	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 2570	 0.010247	 0.025309	 0.0133	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 2571	 0.000593	 0.003951	 0.0339	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 2572	 0.031998	 0.081129	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 2572	 0.009322	 0.02318	 0.0002	 1147	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	5192	 2574	 0.000802	 0.002173	 0.0001	 12824	 12824	 12824	 0.0	 0.0	 1	 -30.0	 30.0;
	2851	 2575	 0.000198	 0.001699	 0.1731	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 2576	 0.04389	 0.139053	 0.014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 2576	 0.04389	 0.139053	 0.014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 2577	 0.02088	 0.03822	 0.0012	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 2577	 0.024296	 0.118963	 0.0004	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 2577	 0.002963	 0.009877	 0.0012	 2532	 2532	 2532	 0.0	 0.0	 1	 -30.0	 30.0;
	5794	 2577	 0.051852	 0.13679	 0.0047	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 2579	 0.010444	 0.032756	 0.0103	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	5049	 2580	 0.000296	 0.001758	 0.003	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 2580	 0.000356	 0.002054	 0.004	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 2580	 0.006696	 0.029985	 0.0527	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 2581	 0.040247	 0.10963	 0.0052	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 2581	 0.044815	 0.122346	 0.0057	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 2582	 0.029136	 0.081605	 0.0037	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	2624	 2583	 0.022963	 0.051728	 0.0023	 566	 566	 566	 0.0	 0.0	 1	 -30.0	 30.0;
	4396	 2583	 0.000988	 0.005926	 0.0863	 5342	 5342	 5342	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 2583	 0.00321	 0.02	 0.0002	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 2583	 0.000988	 0.005926	 0.0002	 5342	 5342	 5342	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 2583	 0.00321	 0.02	 0.0002	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	2738	 2585	 0.074074	 0.177879	 0.001	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 2585	 0.074074	 0.177879	 0.001	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3169	 2587	 0.015839	 0.041543	 0.0019	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 2588	 0.001764	 0.005039	 0.0	 5531	 5531	 5531	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 2589	 0.031494	 0.0645	 0.0007	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 2590	 0.000222	 0.002327	 0.0578	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 2590	 0.001565	 0.020568	 0.7076	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 2590	 0.000914	 0.009875	 0.2238	 1704.0	 1704.0	 1704.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 2590	 0.001641	 0.021544	 0.7451	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 2590	 0.000229	 0.002313	 0.0578	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 2590	 0.001558	 0.020568	 0.7076	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 2590	 0.001634	 0.021503	 0.7451	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 2591	 0.014109	 0.089443	 0.0011	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 2591	 0.014109	 0.089443	 0.0011	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 2592	 0.060972	 0.168808	 0.0019	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 2592	 0.000252	 0.001008	 0.0	 33358	 33358	 33358	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 2593	 0.021852	 0.059753	 0.0028	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 2594	 0.036483	 0.090854	 0.0011	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 2594	 0.050643	 0.140842	 0.0015	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 2594	 0.037995	 0.094835	 0.0011	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 2594	 0.050643	 0.140842	 0.0015	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	2784	 2595	 0.003378	 0.02242	 0.0415	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 2596	 0.002222	 0.004444	 0.0002	 5979	 5979	 5979	 0.0	 0.0	 1	 -30.0	 30.0;
	2600	 2598	 0.000176	 0.000454	 0.0005	 62462	 62462	 62462	 0.0	 0.0	 1	 -30.0	 30.0;
	4675	 2598	 0.021668	 0.052154	 0.0005	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 2599	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 2601	 0.07231	 0.206853	 0.0023	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	4054	 2601	 0.04384	 0.122953	 0.0013	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 2601	 0.072058	 0.206601	 0.0023	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	5489	 2603	 0.026296	 0.071728	 0.0028	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 2604	 0.171076	 0.313152	 0.0033	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 2604	 0.025699	 0.065508	 0.0008	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	2876	 2605	 0.075556	 0.205309	 0.0097	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	3226	 2605	 0.048642	 0.131481	 0.0063	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	3348	 2605	 0.058765	 0.152099	 0.0073	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 2605	 0.087161	 0.224198	 0.0107	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3412	 2608	 0.04284	 0.091728	 0.0042	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 2610	 0.071504	 0.176997	 0.0018	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 2611	 0.039305	 0.102293	 0.0012	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5036	 2612	 0.116906	 0.242126	 0.0026	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 2612	 0.03477	 0.072814	 0.0008	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 2613	 0.021605	 0.091111	 0.0049	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	3360	 2614	 0.011838	 0.02167	 0.0235	 1161	 1161	 1161	 0.0	 0.0	 1	 -30.0	 30.0;
	3977	 2615	 0.033086	 0.089876	 0.0042	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 2615	 0.088642	 0.185679	 0.0079	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 2616	 0.033086	 0.09	 0.0042	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 2616	 0.048889	 0.124321	 0.0059	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 2619	 0.08642	 0.23608	 0.0026	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 2620	 0.018642	 0.050617	 0.0024	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 2621	 0.000756	 0.00252	 0.0001	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 2621	 0.00068	 0.002268	 0.0001	 12845	 12845	 12845	 0.0	 0.0	 1	 -30.0	 30.0;
	2958	 2622	 0.04515	 0.122222	 0.0025	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5806	 2622	 0.00126	 0.003779	 0.0	 7635	 7635	 7635	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 2622	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 2625	 0.010078	 0.04258	 0.0005	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 2625	 0.009826	 0.041068	 0.0016	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	2831	 2626	 0.003826	 0.018665	 0.0334	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 2626	 0.00077	 0.003536	 0.0066	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4476	 2626	 0.005037	 0.034785	 0.0653	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2831	 2626	 0.003615	 0.01762	 0.0314	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 2626	 0.000711	 0.004583	 0.0081	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5573	 2628	 0.004283	 0.025951	 0.0003	 1157	 1157	 1157	 0.0	 0.0	 1	 -30.0	 30.0;
	2637	 2629	 0.133006	 0.305266	 0.0033	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	3559	 2629	 0.129252	 0.306374	 0.004	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	3891	 2629	 0.05039	 0.117158	 0.0013	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 2630	 0.024074	 0.054198	 0.0024	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 2630	 0.048148	 0.108148	 0.005	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 2632	 0.009574	 0.017637	 0.0289	 1516	 1516	 1516	 0.0	 0.0	 1	 -30.0	 30.0;
	2789	 2633	 0.066264	 0.166289	 0.0074	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	3139	 2633	 0.035525	 0.091459	 0.0032	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 2633	 0.020257	 0.117108	 0.0127	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 2634	 0.020433	 0.117914	 0.0121	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	4133	 2635	 0.002726	 0.018193	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4637	 2635	 0.002596	 0.01165	 0.0203	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4133	 2635	 0.002726	 0.018193	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2950	 2636	 0.06125	 0.156866	 0.0017	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4069	 2636	 0.035047	 0.090098	 0.001	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	3441	 2637	 0.080121	 0.194255	 0.0021	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 2638	 0.066012	 0.179894	 0.0	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 2639	 0.003086	 0.008148	 0.0005	 3410	 3410	 3410	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 2639	 0.017037	 0.044691	 0.0021	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 2640	 0.001512	 0.003023	 0.0	 8999	 8999	 8999	 0.0	 0.0	 1	 -30.0	 30.0;
	2644	 2643	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 2643	 0.029226	 0.080625	 0.001	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5219	 2644	 0.031746	 0.080121	 0.0009	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 2645	 0.024439	 0.064752	 0.0016	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 2645	 0.039305	 0.111363	 0.0012	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	3651	 2645	 0.017385	 0.049383	 0.0006	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 2648	 0.004507	 0.013102	 0.0043	 2280	 2280	 2280	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 2648	 0.012933	 0.044356	 0.0144	 684	 684	 684	 0.0	 0.0	 1	 -30.0	 30.0;
	5584	 2648	 0.002711	 0.008889	 0.0032	 3399	 3399	 3399	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 2649	 0.106828	 0.220207	 0.0024	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5821	 2649	 0.034575	 0.063288	 0.0007	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	3769	 2650	 0.036543	 0.096173	 0.0045	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	3376	 2651	 0.095238	 0.206097	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 2651	 0.04384	 0.111867	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4543	 2652	 0.003275	 0.014109	 0.0002	 2100	 2100	 2100	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 2652	 0.01852	 0.033901	 0.0003	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 2653	 0.000198	 0.000909	 0.002	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 2654	 0.036029	 0.15873	 0.0029	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 2654	 0.052658	 0.144117	 0.0016	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 2654	 0.006551	 0.027211	 0.0003	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 2655	 0.002252	 0.010509	 0.0187	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 2655	 0.008	 0.03998	 0.0709	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 2656	 0.000109	 0.000494	 0.001	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 2657	 0.054926	 0.133535	 0.0013	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 2657	 0.024439	 0.058957	 0.0006	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	3987	 2658	 0.06576	 0.17939	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	3688	 2659	 0.007811	 0.027211	 0.0	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	2592	 2660	 0.022928	 0.094734	 0.0012	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 2660	 0.039053	 0.144117	 0.0086	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 2660	 0.014865	 0.033006	 0.0004	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	5431	 2660	 0.012094	 0.033006	 0.0004	 840	 840	 840	 0.0	 0.0	 1	 -30.0	 30.0;
	2592	 2660	 0.02318	 0.093978	 0.0013	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4780	 2661	 0.005827	 0.02703	 0.0476	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3491	 2666	 0.006409	 0.016431	 0.005	 1792	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 2667	 0.024691	 0.067271	 0.0013	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 2667	 0.026203	 0.066516	 0.0013	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 2668	 0.039753	 0.104568	 0.005	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	4162	 2668	 0.006259	 0.020988	 0.0013	 1357	 1357	 1357	 0.0	 0.0	 1	 -30.0	 30.0;
	4885	 2668	 0.001481	 0.006667	 0.0288	 4350	 4350	 4350	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 2672	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 2671	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 2673	 0.013102	 0.03477	 0.0004	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	4892	 2673	 0.074326	 0.157218	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 2673	 0.017889	 0.045855	 0.0006	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 2674	 0.07483	 0.202822	 0.0029	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 2675	 0.007559	 0.021164	 0.0002	 1354	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 2675	 0.047871	 0.125976	 0.0014	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 2676	 0.001956	 0.020958	 0.0871	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2675	 2677	 0.014613	 0.040816	 0.0005	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 2680	 0.057823	 0.168178	 0.0102	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 2681	 0.009136	 0.019259	 0.0062	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 2681	 0.026914	 0.070741	 0.0034	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 2681	 0.047654	 0.124815	 0.0058	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 2681	 0.009012	 0.018889	 0.0062	 1420	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	3483	 2683	 0.013704	 0.043333	 0.0021	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	4698	 2684	 0.059133	 0.16198	 0.0018	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 2685	 5.9e-05	 0.000435	 0.0025	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 2686	 0.002593	 0.010741	 0.0005	 2745	 2745	 2745	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 2687	 0.058026	 0.106216	 0.001	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 2689	 0.036231	 0.098262	 0.0023	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 2690	 0.099622	 0.273217	 0.0149	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 2691	 0.020988	 0.088518	 0.0045	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 2691	 1.2e-05	 0.001235	 0.0002	 24050	 24050	 24050	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 2693	 0.000336	 0.001225	 0.1529	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 2693	 0.000138	 0.00079	 0.1063	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 2693	 0.000138	 0.000889	 0.1215	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 2694	 0.001764	 0.004787	 0.0042	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 2696	 0.02066	 0.052406	 0.0006	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 2696	 0.006551	 0.027463	 0.009	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 2698	 0.015309	 0.031728	 0.0013	 861	 861	 861	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 2699	 0.049887	 0.12648	 0.0014	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	3656	 2700	 0.011086	 0.028471	 0.0003	 967	 967	 967	 0.0	 0.0	 1	 -30.0	 30.0;
	3438	 2701	 0.001041	 0.006967	 0.0152	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 2702	 0.076846	 0.267826	 0.0033	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	4057	 2702	 0.000604	 0.001106	 0.0006	 22736	 22736	 22736	 0.0	 0.0	 1	 -30.0	 30.0;
	4670	 2702	 0.071303	 0.194759	 0.0022	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	4058	 2702	 0.000773	 0.001416	 0.0007	 17760	 17760	 17760	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 2703	 0.019728	 0.057546	 0.0029	 486	 486	 486	 0.0	 0.0	 1	 -30.0	 30.0;
	5208	 2703	 0.006047	 0.020912	 0.0	 1357	 1357	 1357	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 2703	 0.011086	 0.057445	 0.0021	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	3346	 2704	 0.009067	 0.029116	 0.0486	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 2706	 0.024439	 0.101789	 0.001	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	3839	 2705	 0.040539	 0.128168	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 2706	 0.087931	 0.279667	 0.0033	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	4870	 2705	 0.025195	 0.159486	 0.0021	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 2705	 0.009826	 0.047115	 0.001	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 2707	 0.000701	 0.004599	 0.0082	 484.0	 484.0	 484.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 2707	 0.000705	 0.00463	 0.0083	 484.0	 484.0	 484.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 2709	 0.026959	 0.112875	 0.0023	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 2710	 0.001956	 0.008691	 0.0248	 3468	 3468	 3468	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 2711	 0.026543	 0.066296	 0.0031	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	3312	 2713	 0.012496	 0.043621	 0.0734	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 2713	 0.018805	 0.069215	 0.1235	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 2713	 0.012306	 0.062598	 0.1109	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3312	 2713	 0.00717	 0.042726	 0.0749	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 2714	 0.001627	 0.017031	 0.3812	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 2718	 0.018392	 0.045074	 0.0004	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 2718	 0.020106	 0.048828	 0.0046	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 2719	 0.017284	 0.108148	 0.0075	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	4726	 2720	 0.000257	 0.000612	 0.0547	 46632	 46632	 46632	 0.0	 0.0	 1	 -30.0	 30.0;
	4725	 2720	 0.000237	 0.000553	 0.0496	 51447	 51447	 51447	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 2720	 0.000237	 0.000553	 0.0496	 51447	 51447	 51447	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 2721	 0.000395	 0.005229	 0.1791	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 2722	 0.008062	 0.054926	 0.0006	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 2722	 0.008062	 0.054926	 0.0006	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3583	 2724	 0.002963	 0.008642	 0.0024	 3320	 3320	 3320	 0.0	 0.0	 1	 -30.0	 30.0;
	4817	 2724	 0.00679	 0.028642	 0.0034	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	4817	 2724	 0.007284	 0.03037	 0.0028	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	4227	 2725	 0.005017	 0.033521	 0.0607	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3915	 2726	 0.049131	 0.127488	 0.0014	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 2727	 0.001679	 0.007526	 0.0132	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3600	 2728	 0.055595	 0.101765	 0.0043	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 2729	 0.005926	 0.016173	 0.0008	 1725	 1725	 1725	 0.0	 0.0	 1	 -30.0	 30.0;
	4147	 2730	 0.003275	 0.010582	 0.0002	 2699	 2699	 2699	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 2733	 0.018025	 0.045679	 0.0021	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 2737	 0.009753	 0.018272	 0.0008	 1465	 1465	 1465	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 2736	 0.003185	 0.008914	 0.0319	 3204	 3204	 3204	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 2738	 0.054422	 0.127236	 0.0021	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	5651	 2739	 0.000579	 0.001587	 0.0	 17478	 17478	 17478	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 2742	 0.128484	 0.235189	 0.0033	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	3814	 2743	 0.066264	 0.1678	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 2743	 0.060217	 0.164021	 0.0019	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	3121	 2744	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 2744	 0.004326	 0.019694	 0.0344	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 2744	 0.003338	 0.015091	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 2744	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 2744	 0.003338	 0.015091	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 2744	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4629	 2745	 0.008818	 0.022172	 0.0	 1238	 1238	 1238	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 2746	 0.025951	 0.072814	 0.0085	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 2748	 0.000951	 0.003593	 0.0002	 8159	 8159	 8159	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 2749	 0.000138	 0.000593	 0.0	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 2750	 0.041975	 0.106543	 0.0049	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4787	 2750	 0.034568	 0.094444	 0.024	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 2750	 0.031111	 0.084938	 0.004	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	4787	 2750	 0.034568	 0.094444	 0.024	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	2845	 2753	 0.15873	 0.35349	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	4204	 2753	 0.000756	 0.005291	 0.0001	 5525	 5525	 5525	 0.0	 0.0	 1	 -30.0	 30.0;
	4425	 2753	 0.068531	 0.165961	 0.0018	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 2753	 0.096246	 0.238851	 0.0027	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5738	 2753	 0.005039	 0.012598	 0.0002	 2177	 2177	 2177	 0.0	 0.0	 1	 -30.0	 30.0;
	4203	 2753	 0.002771	 0.006047	 0.0001	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 2754	 0.007723	 0.032119	 0.0527	 937	 937	 937	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 2754	 0.009541	 0.039585	 0.0648	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5510	 2755	 0.00397	 0.007268	 0.0102	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	3424	 2756	 0.03094	 0.093298	 0.0011	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 2756	 0.015621	 0.04132	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 2757	 0.000252	 0.001008	 0.0	 27575	 27575	 27575	 0.0	 0.0	 1	 -30.0	 30.0;
	3662	 2758	 0.007055	 0.016629	 0.0007	 1684	 1684	 1684	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 2760	 0.000705	 0.002973	 0.0001	 9377	 9377	 9377	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 2761	 0.00252	 0.004787	 0.0001	 6271	 6271	 6271	 0.0	 0.0	 1	 -30.0	 30.0;
	2952	 2762	 0.001519	 0.010582	 0.0162	 510.0	 510.0	 510.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 2762	 0.002216	 0.014805	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 2762	 0.001529	 0.010637	 0.0162	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 2762	 0.002206	 0.014728	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4068	 2763	 0.000457	 0.006025	 0.2079	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 2763	 0.001856	 0.025166	 0.8563	 1264	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 2764	 0.056941	 0.143613	 0.0016	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	3366	 2765	 0.014865	 0.045855	 0.0002	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	3366	 2765	 0.014865	 0.046107	 0.0002	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 2766	 0.055178	 0.139834	 0.0016	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5688	 2767	 0.090703	 0.190476	 0.0021	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 2767	 0.006551	 0.017637	 0.0002	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	2840	 2769	 0.013086	 0.045803	 0.0021	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	3261	 2769	 0.005185	 0.031975	 0.0023	 917	 917	 917	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 2769	 0.015803	 0.053086	 0.0026	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	4410	 2769	 0.039506	 0.113457	 0.0053	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 2769	 0.025802	 0.106914	 0.0057	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 2769	 0.018519	 0.065679	 0.0036	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 2769	 0.024815	 0.071975	 0.0032	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 2769	 0.025679	 0.106543	 0.0055	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3016	 2770	 0.014914	 0.055309	 0.0896	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	4811	 2770	 0.009383	 0.042607	 0.0759	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 2771	 0.002597	 0.020332	 0.4202	 1408.0	 1408.0	 1408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 2771	 0.001932	 0.021399	 0.4448	 1391.0	 1391.0	 1391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 2772	 0.020988	 0.052469	 0.0024	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 2772	 0.018025	 0.045926	 0.0021	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	3903	 2774	 0.068783	 0.155959	 0.0021	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	5084	 2774	 0.026707	 0.07483	 0.0008	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 2775	 0.000198	 0.000909	 0.001	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 2776	 0.148778	 0.326556	 0.0036	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	5138	 2776	 0.028924	 0.07672	 0.0001	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 2777	 0.001106	 0.007328	 0.0132	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 2778	 0.028471	 0.074326	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	2961	 2779	 0.031973	 0.079441	 0.0041	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 2779	 0.005039	 0.021416	 0.0002	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 2780	 0.071454	 0.242605	 0.0033	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 2780	 0.018267	 0.062031	 0.0007	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 2780	 0.018392	 0.06198	 0.0007	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 2780	 0.022525	 0.13933	 0.0018	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 2779	 0.005039	 0.021668	 0.0002	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 2780	 0.068531	 0.219955	 0.0026	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 2781	 0.015488	 0.067417	 0.1205	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 2783	 0.010247	 0.020494	 0.0015	 1324	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 2784	 0.005985	 0.041383	 0.0739	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 2784	 0.000243	 0.001614	 0.003	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 2787	 0.033762	 0.092215	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 2788	 0.022147	 0.129554	 0.004	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 2788	 0.023658	 0.133686	 0.0041	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 2789	 0.064669	 0.118376	 0.0067	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 2790	 0.054422	 0.143613	 0.0017	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 2790	 0.074779	 0.202444	 0.0048	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 2790	 0.074049	 0.255959	 0.0301	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 2790	 0.077123	 0.256362	 0.0254	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 2790	 0.054422	 0.143865	 0.0017	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 2791	 0.003737	 0.024798	 0.0456	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 2791	 0.000869	 0.005886	 0.0415	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4063	 2792	 0.119224	 0.218238	 0.002	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 2793	 0.004074	 0.028025	 0.0058	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 2794	 0.000514	 0.004247	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 2795	 5.9e-05	 0.000474	 0.002	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3381	 2797	 0.004286	 0.020405	 0.0344	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 2797	 0.007625	 0.035378	 0.0668	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3858	 2799	 0.008818	 0.024943	 0.0	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	4198	 2800	 0.042963	 0.084938	 0.0038	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 2801	 0.038045	 0.116402	 0.0013	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	3798	 2802	 0.000252	 0.00252	 0.0002	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3924	 2802	 0.027715	 0.170824	 0.0132	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 2802	 0.045528	 0.124112	 0.0016	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 2805	 0.010988	 0.042963	 0.0003	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 2806	 0.001146	 0.005551	 0.0101	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 2807	 0.097506	 0.263794	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 2807	 0.054674	 0.112623	 0.0012	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	3699	 2808	 0.00126	 0.00252	 0.0018	 10480	 10480	 10480	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 2809	 0.033827	 0.143333	 0.0073	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	4175	 2809	 0.012716	 0.034321	 0.0058	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	4379	 2809	 0.004198	 0.017407	 0.003	 1659	 1659	 1659	 0.0	 0.0	 1	 -30.0	 30.0;
	4886	 2810	 0.008296	 0.038795	 0.0648	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 2811	 0.024969	 0.106223	 0.0026	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 2813	 0.000756	 0.00252	 0.0001	 12969	 12969	 12969	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 2814	 0.024691	 0.063827	 0.0031	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	4371	 2814	 0.000864	 0.00284	 0.0002	 10216	 10216	 10216	 0.0	 0.0	 1	 -30.0	 30.0;
	4394	 2814	 0.019506	 0.052593	 0.0024	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 2814	 0.034197	 0.093951	 0.0	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	5299	 2814	 0.011358	 0.026914	 0.0013	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 2814	 0.014938	 0.039383	 0.0018	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 2814	 0.014198	 0.039012	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 2814	 0.036667	 0.116049	 0.0057	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	5039	 2814	 0.034321	 0.094691	 0.0	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 2815	 0.00528	 0.029102	 0.0496	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 2816	 0.052593	 0.119012	 0.0039	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 2816	 0.065556	 0.146914	 0.0068	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 2818	 0.033762	 0.137566	 0.0018	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 2818	 0.085528	 0.156557	 0.0016	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 2818	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 2819	 0.011417	 0.020898	 0.0002	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	4347	 2821	 9.9e-05	 0.001007	 0.003	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4347	 2820	 0.000119	 0.001067	 0.004	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 2823	 0.177421	 0.324767	 0.0071	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 2823	 0.084656	 0.216427	 0.0025	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 2824	 0.052154	 0.104308	 0.0011	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	3712	 2825	 0.000395	 0.001126	 0.1043	 25728	 25728	 25728	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 2829	 0.101481	 0.203086	 0.0089	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	3847	 2829	 0.00642	 0.02	 0.0154	 1415	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 2829	 0.005864	 0.036531	 0.0019	 803	 803	 803	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 2829	 0.013951	 0.044321	 0.0021	 640	 640	 640	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 2830	 0.000849	 0.003812	 0.0071	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3808	 2832	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3807	 2832	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3806	 2832	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3805	 2832	 7.6e-05	 0.000568	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 2833	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 2835	 0.003679	 0.018418	 0.0286	 1620	 1620	 1620	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 2837	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 2838	 1.5e-05	 9.9e-05	 0.001	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3345	 2839	 0.044973	 0.126127	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 2840	 0.002963	 0.008889	 0.0005	 3170	 3170	 3170	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 2842	 0.005543	 0.014865	 0.0002	 1862	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	5393	 2843	 0.054568	 0.138519	 0.0065	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 2844	 2.5e-05	 0.000252	 0.0001	 113138	 113138	 113138	 0.0	 0.0	 1	 -30.0	 30.0;
	2953	 2845	 0.125894	 0.230447	 0.0021	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	4564	 2845	 0.109599	 0.26455	 0.003	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	5731	 2847	 0.04006	 0.101033	 0.0068	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	5522	 2848	 0.000277	 0.001244	 0.0886	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 2849	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4650	 2849	 0.000298	 0.003019	 0.078	 1971.0	 1971.0	 1971.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 2849	 0.000505	 0.006637	 0.231	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4650	 2849	 0.000298	 0.003012	 0.078	 1971.0	 1971.0	 1971.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 2849	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 2849	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5253	 2850	 0.074578	 0.210632	 0.0025	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5523	 2850	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3102	 2852	 0.000158	 0.001284	 0.1185	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 2852	 0.000178	 0.001521	 0.1397	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 2853	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	5526	 2855	 1.5e-05	 9.9e-05	 0.0	 309124	 309124	 309124	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2856	 0.000454	 0.001008	 0.0	 27511	 27511	 27511	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 2858	 0.006299	 0.016377	 0.0002	 1734	 1734	 1734	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 2859	 0.001208	 0.002211	 0.0	 12072	 12072	 12072	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 2860	 0.000158	 0.000652	 0.001	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 2861	 0.011262	 0.075762	 0.0018	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	3757	 2863	 0.015148	 0.040877	 0.0019	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 2863	 0.008395	 0.034815	 0.0018	 830	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 2863	 0.028025	 0.174815	 0.0096	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	4142	 2864	 0.002983	 0.020385	 0.0375	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4171	 2864	 0.005136	 0.034548	 0.0628	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2996	 2867	 0.003049	 0.012824	 0.0194	 2240	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 2865	 0.003275	 0.012094	 0.0132	 2369	 2369	 2369	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 2866	 0.005382	 0.009851	 0.0091	 2642	 2642	 2642	 0.0	 0.0	 1	 -30.0	 30.0;
	5529	 2868	 0.000123	 0.001235	 0.0	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	4686	 2869	 0.000247	 0.000741	 0.0005	 38824	 38824	 38824	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 2870	 0.059939	 0.151978	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 2873	 0.002875	 0.005263	 0.0001	 5072	 5072	 5072	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 2874	 0.054568	 0.138889	 0.0065	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	3276	 2875	 0.007004	 0.015142	 0.0002	 1823	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 2876	 0.037494	 0.102284	 0.0049	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 2877	 0.003779	 0.014865	 0.0018	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 2878	 0.010632	 0.026228	 0.0027	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 2882	 0.025447	 0.064575	 0.0007	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	3075	 2883	 0.069035	 0.148652	 0.0021	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 2884	 0.01033	 0.02842	 0.0003	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 2885	 0.005795	 0.022424	 0.0002	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	5534	 2885	 0.000504	 0.002268	 0.0	 12709	 12709	 12709	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 2886	 0.091963	 0.211892	 0.0021	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 2886	 0.048375	 0.10708	 0.0012	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 2887	 0.02973	 0.124969	 0.0027	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	4585	 2888	 0.055682	 0.13933	 0.0016	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 2889	 0.003527	 0.013354	 0.0	 2139	 2139	 2139	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 2891	 0.001323	 0.008824	 0.0339	 411.0	 411.0	 411.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 2892	 0.000731	 0.00484	 0.0091	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 2892	 0.002884	 0.018686	 0.0375	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 2892	 0.001817	 0.012168	 0.0223	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 2892	 0.002785	 0.018884	 0.0334	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 2892	 0.00077	 0.005136	 0.0091	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 2892	 0.003121	 0.020859	 0.0385	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 2892	 0.000731	 0.00482	 0.0091	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3479	 2893	 9.7e-05	 0.00097	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4640	 2893	 0.001468	 0.014903	 0.3841	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 2893	 0.00036	 0.003636	 0.0953	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 2893	 9.7e-05	 0.00097	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 2893	 0.001461	 0.014785	 0.3812	 2147	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 2893	 0.001247	 0.012673	 0.3263	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3477	 2893	 9.7e-05	 0.000983	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3476	 2893	 9.7e-05	 0.001025	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 2894	 0.007037	 0.019259	 0.001	 1449	 1449	 1449	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 2894	 0.003827	 0.010864	 0.0005	 2579	 2579	 2579	 0.0	 0.0	 1	 -30.0	 30.0;
	4016	 2895	 0.024439	 0.096498	 0.0194	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	3181	 2896	 0.046259	 0.11736	 0.0013	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 2897	 0.001638	 0.004334	 0.0048	 6565	 6565	 6565	 0.0	 0.0	 1	 -30.0	 30.0;
	3844	 2898	 0.046687	 0.127387	 0.0014	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5036	 2898	 0.108592	 0.275636	 0.0031	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 2898	 0.0839	 0.23356	 0.0027	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 2902	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	5537	 2902	 0.001461	 0.003704	 0.0001	 7639	 7639	 7639	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 2903	 0.013444	 0.026877	 0.0011	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	4719	 2904	 0.001644	 0.005778	 0.0018	 5259	 5259	 5259	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 2905	 0.038272	 0.114311	 0.0065	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2909	 2908	 0.008844	 0.024112	 0.0003	 1185	 1185	 1185	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 2910	 0.007741	 0.017333	 0.0008	 1565	 1565	 1565	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 2911	 0.047367	 0.131267	 0.0014	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 2911	 0.027841	 0.076594	 0.0008	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 2913	 0.028471	 0.113883	 0.0032	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 2915	 0.011753	 0.05438	 0.0931	 294.0	 294.0	 294.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2998	 2915	 0.00083	 0.008375	 0.0263	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 2915	 0.00241	 0.016435	 0.0273	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 2914	 0.007585	 0.028128	 0.0456	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 2916	 0.000652	 0.005946	 0.0172	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 2914	 0.000632	 0.004346	 0.0233	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2997	 2914	 0.000869	 0.008514	 0.0273	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 2914	 0.000632	 0.00559	 0.0476	 494.0	 494.0	 494.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2920	 2918	 0.000252	 0.000504	 0.0003	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3793	 2919	 0.004443	 0.008133	 0.0048	 3282	 3282	 3282	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 2920	 0.057949	 0.137062	 0.0015	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4253	 2920	 0.011665	 0.066465	 0.0027	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 2920	 0.006475	 0.017259	 0.001	 1602	 1602	 1602	 0.0	 0.0	 1	 -30.0	 30.0;
	4919	 2923	 0.060141	 0.152532	 0.0017	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 2923	 0.078357	 0.21416	 0.0024	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 2924	 0.078105	 0.208617	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 2924	 0.076594	 0.202822	 0.0025	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 2925	 0.046359	 0.100781	 0.0011	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 2926	 0.001981	 0.003626	 0.0025	 7146	 7146	 7146	 0.0	 0.0	 1	 -30.0	 30.0;
	3297	 2927	 0.079365	 0.215923	 0.0025	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5540	 2928	 0.000436	 0.000797	 0.0004	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	3213	 2930	 0.046863	 0.11867	 0.0013	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	3682	 2930	 0.045855	 0.121693	 0.0039	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 2933	 0.007862	 0.038716	 0.0658	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 2933	 0.001719	 0.00881	 0.0203	 358.0	 358.0	 358.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 2934	 0.067775	 0.178382	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 2934	 0.068279	 0.174855	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3849	 2936	 0.022676	 0.06576	 0.001	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	5000	 2935	 0.024188	 0.061728	 0.001	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 2936	 0.003779	 0.024943	 0.0	 1171	 1171	 1171	 0.0	 0.0	 1	 -30.0	 30.0;
	3849	 2935	 0.016377	 0.066264	 0.001	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	5612	 2935	 0.003779	 0.024439	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	5543	 2938	 0.000504	 0.001512	 0.001	 18526	 18526	 18526	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 2940	 0.034266	 0.094482	 0.001	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 2940	 0.084908	 0.220711	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 2941	 0.05037	 0.129877	 0.0062	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 2944	 0.010049	 0.026543	 0.0041	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 2944	 0.005148	 0.013309	 0.0006	 2126	 2126	 2126	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 2944	 0.016914	 0.04642	 0.0021	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 2945	 0.014262	 0.067397	 0.1124	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4304	 2945	 0.021077	 0.088869	 0.1468	 301.0	 301.0	 301.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4405	 2945	 0.00016	 0.000755	 0.0013	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 2945	 0.013452	 0.063625	 0.1063	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3967	 2946	 0.002815	 0.017518	 0.097	 1675	 1675	 1675	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 2946	 0.002395	 0.014938	 0.0828	 1964	 1964	 1964	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 2947	 0.00065	 0.008537	 0.2946	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 2950	 0.013102	 0.081129	 0.001	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	5069	 2950	 0.044041	 0.186369	 0.0022	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 2950	 0.013983	 0.038045	 0.0005	 751	 751	 751	 0.0	 0.0	 1	 -30.0	 30.0;
	4425	 2953	 0.081129	 0.199043	 0.002	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 2954	 0.022235	 0.057469	 0.0047	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5675	 2954	 0.009296	 0.024593	 0.0011	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 2955	 0.056941	 0.148652	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4242	 2956	 0.03679	 0.103704	 0.0053	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5545	 2958	 0.028723	 0.057193	 0.0006	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 2959	 0.000347	 0.000813	 0.0018	 35735	 35735	 35735	 0.0	 0.0	 1	 -30.0	 30.0;
	4671	 2962	 0.011208	 0.020517	 0.0771	 1271	 1271	 1271	 0.0	 0.0	 1	 -30.0	 30.0;
	2967	 2963	 4e-05	 0.000198	 0.0223	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2966	 2964	 2e-05	 0.000198	 0.0152	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4082	 2966	 0.000138	 0.019753	 0.001	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 2966	 0.000494	 0.003002	 0.242	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5038	 2965	 0.002726	 0.013728	 0.084	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5592	 2967	 0.000356	 0.003358	 0.0121	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4082	 2965	 9.9e-05	 0.000198	 0.0091	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 2966	 0.000514	 0.003101	 0.2521	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 2966	 0.000909	 0.006005	 0.0142	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 2968	 0.000166	 0.002749	 0.1069	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 2969	 0.001004	 0.010997	 0.2339	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 2969	 0.000159	 0.002701	 0.0982	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 2970	 0.00126	 0.00252	 0.0	 10795	 10795	 10795	 0.0	 0.0	 1	 -30.0	 30.0;
	3998	 2971	 0.03613	 0.097783	 0.0021	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4911	 2971	 0.028975	 0.07483	 0.0008	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 2971	 0.103049	 0.264802	 0.0132	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	3997	 2971	 0.036004	 0.09743	 0.0011	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3040	 2973	 0.081633	 0.15999	 0.0021	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5203	 2973	 0.040564	 0.110859	 0.001	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 2974	 0.163976	 0.300156	 0.003	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 2974	 0.119224	 0.218238	 0.0021	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 2975	 0.002091	 0.004308	 0.0001	 6352	 6352	 6352	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 2977	 0.024815	 0.063086	 0.0028	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 2977	 0.023679	 0.060074	 0.0028	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 2978	 0.02037	 0.050988	 0.0608	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 2979	 0.023683	 0.09801	 0.0012	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	4356	 2979	 0.074074	 0.1678	 0.0018	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 2979	 0.030738	 0.084354	 0.017	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 2979	 0.010078	 0.041824	 0.0005	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 2980	 0.014865	 0.027211	 0.0001	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 2983	 0.001358	 0.006049	 0.0003	 4892	 4892	 4892	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 2984	 0.023683	 0.083648	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	4096	 2984	 0.054926	 0.145377	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4367	 2984	 0.012598	 0.077853	 0.001	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 2984	 0.024943	 0.071051	 0.0008	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 2984	 0.038549	 0.133031	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	4096	 2984	 0.053918	 0.147392	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 2986	 0.030864	 0.096667	 0.0053	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 2988	 0.004283	 0.026959	 0.0003	 1082	 1082	 1082	 0.0	 0.0	 1	 -30.0	 30.0;
	4160	 2988	 0.042076	 0.093222	 0.001	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 2988	 0.003275	 0.02066	 0.0002	 1412	 1412	 1412	 0.0	 0.0	 1	 -30.0	 30.0;
	5742	 2988	 0.044848	 0.114135	 0.0013	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 2989	 0.000395	 0.002686	 0.0051	 490.0	 490.0	 490.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3553	 2990	 0.000252	 0.000504	 0.0004	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 2991	 0.032754	 0.09675	 0.001	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	5668	 2991	 0.049887	 0.143109	 0.0021	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 2993	 0.021416	 0.054674	 0.001	 503	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	4794	 2993	 0.028219	 0.071303	 0.001	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3287	 2996	 0.005291	 0.028219	 0.0	 1029	 1029	 1029	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2995	 0.01914	 0.035035	 0.0329	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	4315	 2995	 0.001512	 0.005543	 0.0055	 5141	 5141	 5141	 0.0	 0.0	 1	 -30.0	 30.0;
	5543	 2995	 0.007055	 0.029479	 0.001	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	5647	 2995	 0.003023	 0.021164	 0.001	 1382	 1382	 1382	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 2996	 0.003275	 0.022676	 0.001	 1289	 1289	 1289	 0.0	 0.0	 1	 -30.0	 30.0;
	3288	 2998	 0.000316	 0.002351	 0.0061	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3389	 2998	 0.000512	 0.001327	 0.159	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4770	 2999	 0.029479	 0.062988	 0.0015	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 2999	 0.026329	 0.069866	 0.0021	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	4770	 2999	 0.029479	 0.062988	 0.0007	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	3620	 3000	 0.001146	 0.008296	 0.0663	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 3001	 0.039128	 0.099824	 0.0012	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 3001	 0.008062	 0.022424	 0.0002	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 3001	 0.059965	 0.165029	 0.0002	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3046	 3001	 0.023683	 0.099017	 0.0013	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 3001	 0.043865	 0.11038	 0.0016	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	4563	 3002	 0.000711	 0.00324	 0.2916	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 3003	 0.093474	 0.228773	 0.0025	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3648	 3004	 0.001857	 0.008435	 0.0152	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 3004	 0.002647	 0.013254	 0.0243	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3466	 3005	 0.036543	 0.095926	 0.0045	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 3006	 0.001146	 0.010923	 0.1706	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 3006	 0.001185	 0.010844	 0.1671	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5047	 3008	 0.021668	 0.057193	 0.0007	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 3008	 0.026153	 0.066289	 0.0016	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 3010	 0.000852	 0.011233	 0.387	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 3010	 0.000852	 0.011226	 0.387	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 3011	 0.04132	 0.10582	 0.002	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 3012	 0.014084	 0.042001	 0.014	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 3013	 0.011338	 0.048627	 0.001	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 3013	 0.011338	 0.048627	 0.001	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	5455	 3015	 0.018025	 0.047407	 0.0023	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	4931	 3017	 0.047115	 0.196523	 0.0068	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 3018	 0.000176	 0.000504	 0.0	 56971	 56971	 56971	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 3018	 0.027337	 0.074553	 0.0008	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4791	 3019	 0.01321	 0.02642	 0.0011	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	3542	 3020	 0.062736	 0.151424	 0.0075	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4772	 3020	 0.066012	 0.177879	 0.002	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 3022	 0.000252	 0.001008	 0.0	 28556	 28556	 28556	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 3023	 0.00126	 0.003275	 0.0001	 9667	 9667	 9667	 0.0	 0.0	 1	 -30.0	 30.0;
	5784	 3023	 0.007559	 0.019148	 0.0002	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 3027	 0.030486	 0.102545	 0.0012	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 3029	 0.011111	 0.054568	 0.0028	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 3030	 0.049559	 0.13424	 0.002	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 3030	 0.057344	 0.129478	 0.0031	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 3032	 0.001101	 0.012181	 0.2599	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 3033	 0.013303	 0.036306	 0.0053	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 3034	 0.058503	 0.157596	 0.0063	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 3035	 0.325276	 0.595412	 0.0048	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	4461	 3038	 0.003356	 0.026424	 0.0458	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 3039	 0.014046	 0.025712	 0.0002	 978	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	4464	 3040	 0.035273	 0.150164	 0.0021	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4512	 3040	 0.015873	 0.066012	 0.001	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 3040	 0.075586	 0.202822	 0.0021	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 3041	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 3042	 0.007181	 0.044797	 0.0006	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 3042	 0.01615	 0.043638	 0.0046	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	4229	 3043	 0.006551	 0.017889	 0.0002	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 3043	 0.083198	 0.152293	 0.0016	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 3044	 0.00839	 0.023507	 0.0286	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 3044	 0.002973	 0.012673	 0.0189	 2337	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 3047	 0.000573	 0.003832	 0.0071	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 3047	 0.003615	 0.025225	 0.0486	 549.0	 549.0	 549.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4814	 3048	 0.026707	 0.112371	 0.0013	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	4585	 3049	 0.017637	 0.044848	 0.0086	 613	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 3050	 0.033333	 0.089383	 0.0043	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 3052	 0.112371	 0.281179	 0.0032	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	3496	 3053	 0.070295	 0.178131	 0.0027	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3058	 3056	 2.1e-05	 0.000127	 0.1141	 1092.0	 1092.0	 1092.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 3056	 0.000111	 0.001932	 0.0289	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3057	 3056	 2.1e-05	 0.000127	 0.1155	 1053.0	 1053.0	 1053.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 3059	 0.026707	 0.059965	 0.0009	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 3065	 0.049506	 0.125556	 0.0058	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 3065	 0.025442	 0.046572	 0.0018	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 3066	 0.002963	 0.016914	 0.0314	 1766	 1766	 1766	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 3066	 0.004074	 0.025309	 0.0026	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 3067	 0.005432	 0.022222	 0.0073	 1326	 1326	 1326	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 3069	 2e-05	 0.000198	 0.0172	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 3068	 2e-05	 0.000198	 0.0142	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 3071	 0.079718	 0.1935	 0.0031	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 3073	 0.017637	 0.059713	 0.0021	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 3073	 0.027715	 0.086924	 0.001	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 3073	 0.03225	 0.087931	 0.0015	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	3101	 3074	 0.003461	 0.013896	 0.0243	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 3075	 0.013605	 0.033258	 0.003	 822	 822	 822	 0.0	 0.0	 1	 -30.0	 30.0;
	4769	 3076	 0.069035	 0.150416	 0.0016	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 3076	 0.001512	 0.004031	 0.0001	 6858	 6858	 6858	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 3076	 0.004283	 0.011842	 0.0002	 2345	 2345	 2345	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 3077	 0.009826	 0.026455	 0.0003	 1047	 1047	 1047	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 3078	 0.086672	 0.236332	 0.0026	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	4773	 3079	 0.03358	 0.090741	 0.0151	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 3079	 1.2e-05	 0.000123	 0.0	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 3080	 0.005039	 0.010078	 0.01	 2621	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 3083	 0.064752	 0.145629	 0.0016	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 3084	 0.050643	 0.138322	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 3084	 0.026203	 0.071554	 0.0008	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 3085	 0.048879	 0.16125	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5364	 3085	 0.023683	 0.060217	 0.0006	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 3085	 0.04006	 0.101789	 0.0011	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3407	 3086	 0.001462	 0.006677	 0.1488	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 3086	 0.001231	 0.008198	 0.0587	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 3086	 0.000865	 0.005772	 0.0101	 436.0	 436.0	 436.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 3086	 0.002588	 0.015862	 0.0304	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3313	 3087	 0.063316	 0.146813	 0.0025	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 3087	 0.017385	 0.037541	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 3088	 0.011804	 0.05293	 0.0942	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 3089	 0.036533	 0.075334	 0.0008	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	3967	 3090	 0.062963	 0.160123	 0.0075	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 3091	 0.053011	 0.144318	 0.0025	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 3091	 0.042555	 0.1161	 0.002	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	4075	 3092	 0.046049	 0.118025	 0.0057	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 3095	 0.046082	 0.122827	 0.0025	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 3096	 0.00907	 0.022928	 0.0276	 1162	 1162	 1162	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 3098	 0.043457	 0.090864	 0.0011	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 3100	 0.05417	 0.137818	 0.001	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 3100	 0.01285	 0.052658	 0.001	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	4068	 3103	 0.001101	 0.012445	 0.3105	 1488.0	 1488.0	 1488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4134	 3103	 0.0009	 0.007479	 0.0982	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 3103	 0.002209	 0.024924	 0.5733	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 3103	 0.0009	 0.00741	 0.13	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3688	 3107	 0.07609	 0.180146	 0.003	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	3688	 3106	 0.082892	 0.184933	 0.002	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	3457	 3108	 0.024188	 0.091459	 0.0064	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 3108	 0.017637	 0.057445	 0.0012	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 3108	 0.011842	 0.031746	 0.0007	 846	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 3109	 0.000395	 0.002607	 0.0051	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 3110	 0.01022	 0.054673	 0.0997	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 3110	 0.003488	 0.015777	 0.0284	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 3111	 0.041572	 0.112623	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 3111	 0.043084	 0.110103	 0.0013	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 3112	 0.013102	 0.056437	 0.0433	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	5585	 3112	 0.024439	 0.099269	 0.0013	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	3551	 3113	 0.064248	 0.163517	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 3113	 0.041068	 0.103804	 0.0021	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4393	 3113	 0.068279	 0.18972	 0.0021	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	4760	 3113	 0.069287	 0.193248	 0.0024	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 3113	 0.155455	 0.425548	 0.0042	 66	 66	 66	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 3113	 0.05543	 0.153943	 0.0032	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 3115	 0.024938	 0.068395	 0.0032	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 3114	 0.028642	 0.064568	 0.0029	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 3115	 0.022346	 0.061235	 0.0029	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 3114	 0.040741	 0.111358	 0.0052	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 3122	 0.003951	 0.010864	 0.0005	 2570	 2570	 2570	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 3123	 0.003275	 0.007307	 0.0	 3688	 3688	 3688	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 3125	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	4352	 3126	 0.0237	 0.043383	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	5614	 3127	 0.024969	 0.073268	 0.0013	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 3127	 0.025951	 0.090955	 0.001	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 3127	 0.024969	 0.083094	 0.001	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 3128	 0.029978	 0.100778	 0.0366	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 3129	 0.053666	 0.125724	 0.0014	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3812	 3129	 0.078861	 0.206752	 0.0062	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 3131	 0.002016	 0.005291	 0.0001	 5215	 5215	 5215	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 3131	 0.092467	 0.244898	 0.0028	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 3132	 0.027457	 0.074876	 0.0036	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 3134	 0.008566	 0.067523	 0.0496	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 3136	 0.002099	 0.00642	 0.0003	 4490	 4490	 4490	 0.0	 0.0	 1	 -30.0	 30.0;
	4612	 3139	 0.017637	 0.045352	 0.0005	 626	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 3140	 0.001025	 0.008148	 0.0142	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3164	 3141	 0.012371	 0.032199	 0.0049	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 3141	 0.139529	 0.255404	 0.0024	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	3164	 3141	 0.034517	 0.089695	 0.001	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 3142	 0.007386	 0.013519	 0.0001	 1975	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 3143	 0.001512	 0.003779	 0.0001	 7254	 7254	 7254	 0.0	 0.0	 1	 -30.0	 30.0;
	3146	 3144	 4.3e-05	 9e-05	 0.004	 310318	 310318	 310318	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 3145	 0.025195	 0.103804	 0.0015	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 3145	 0.025951	 0.088687	 0.0133	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 3145	 0.027967	 0.085412	 0.001	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 3145	 0.025951	 0.089695	 0.0132	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4047	 3146	 0.00079	 0.003931	 0.0071	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 3146	 0.001442	 0.006696	 0.0121	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 3147	 0.013983	 0.047468	 0.0025	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 3147	 0.087075	 0.287932	 0.0029	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 3148	 0.04006	 0.07735	 0.0008	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 3149	 3.6e-05	 9.3e-05	 0.0121	 655.0	 655.0	 655.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3471	 3150	 2.8e-05	 0.000277	 0.0058	 2187.0	 2187.0	 2187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 3151	 0.067775	 0.171832	 0.0019	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 3152	 0.024321	 0.097901	 0.007	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 3152	 0.033827	 0.143951	 0.0071	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	5021	 3152	 0.018765	 0.07663	 0.0079	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	5050	 3152	 0.000173	 0.00079	 0.0034	 36728	 36728	 36728	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 3154	 0.001734	 0.018573	 0.4072	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 3154	 0.002181	 0.031662	 0.8231	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 3153	 0.001711	 0.017313	 0.4476	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 3153	 0.002181	 0.031648	 0.8202	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 3157	 0.004568	 0.008395	 0.0224	 3291	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	3600	 3159	 0.050988	 0.129259	 0.0062	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 3159	 0.040988	 0.107531	 0.0052	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 3160	 0.035926	 0.091235	 0.0044	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 3160	 0.000988	 0.002716	 0.0002	 10278	 10278	 10278	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 3161	 0.025195	 0.053414	 0.0079	 486	 486	 486	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 3163	 0.000198	 0.000652	 0.5832	 476.0	 476.0	 476.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 3163	 0.000316	 0.001442	 0.1326	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 3163	 0.000237	 0.001422	 0.1873	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 3163	 0.000257	 0.001007	 0.1215	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3385	 3164	 0.083724	 0.227488	 0.0026	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	4433	 3164	 0.050643	 0.13026	 0.0015	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 3164	 0.019904	 0.133031	 0.0015	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 3164	 0.034517	 0.2129	 0.0029	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5573	 3166	 0.004283	 0.012346	 0.0002	 2328	 2328	 2328	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 3169	 0.004568	 0.009259	 0.0003	 2877	 2877	 2877	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 3169	 0.012222	 0.032222	 0.0015	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	5575	 3170	 0.000773	 0.001416	 0.0006	 18302	 18302	 18302	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 3171	 0.000252	 0.00126	 0.0	 23670	 23670	 23670	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 3172	 0.011111	 0.030124	 0.0	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	5345	 3172	 0.034938	 0.092222	 0.0045	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 3173	 0.035979	 0.091207	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 3174	 0.000454	 0.001209	 0.0002	 23551	 23551	 23551	 0.0	 0.0	 1	 -30.0	 30.0;
	4670	 3175	 0.073318	 0.259007	 0.0031	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	4965	 3176	 0.003319	 0.022716	 0.0415	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 3177	 0.030738	 0.084152	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	3266	 3178	 0.024307	 0.078747	 0.0251	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 3179	 3.4e-05	 9.4e-05	 0.002	 286.0	 286.0	 286.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 3179	 0.003297	 0.021902	 0.0466	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 3180	 0.001496	 0.014148	 0.3697	 1537.0	 1537.0	 1537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 3180	 0.001496	 0.014148	 0.3697	 1537.0	 1537.0	 1537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 3180	 0.000942	 0.009536	 0.2455	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3396	 3183	 0.018645	 0.050894	 0.0006	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 3184	 0.024568	 0.066296	 0.0031	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4639	 3184	 0.008642	 0.054198	 0.0061	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	5581	 3185	 0.043012	 0.146025	 0.0071	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5123	 3185	 0.045309	 0.147654	 0.0073	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 3186	 0.095792	 0.23361	 0.0026	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 3187	 0.012346	 0.033258	 0.0004	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 3188	 0.042051	 0.106601	 0.0012	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 3188	 0.015369	 0.04258	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 3190	 0.006803	 0.027715	 0.0004	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	5378	 3190	 0.002771	 0.011338	 0.0002	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 3192	 0.000277	 0.000632	 0.0607	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 3191	 0.000395	 0.000731	 0.0628	 37253	 37253	 37253	 0.0	 0.0	 1	 -30.0	 30.0;
	3514	 3193	 0.028025	 0.114815	 0.0016	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 3194	 0.000178	 0.000928	 0.3564	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4250	 3195	 0.021416	 0.07735	 0.0093	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	4310	 3196	 0.021482	 0.054568	 0.0026	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	4691	 3196	 0.003951	 0.008025	 0.0233	 3321	 3321	 3321	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 3197	 0.007037	 0.017901	 0.0008	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 3197	 0.059876	 0.15284	 0.0071	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4310	 3196	 0.025926	 0.065556	 0.0031	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 3199	 0.012247	 0.044385	 0.0739	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4578	 3198	 9.9e-05	 0.000988	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5563	 3201	 0.006803	 0.018392	 0.0002	 1740	 1740	 1740	 0.0	 0.0	 1	 -30.0	 30.0;
	3270	 3202	 0.006918	 0.046044	 0.0851	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 3204	 0.000158	 0.000289	 0.0203	 93975	 93975	 93975	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 3205	 0.000145	 0.000265	 0.0182	 102466	 102466	 102466	 0.0	 0.0	 1	 -30.0	 30.0;
	5501	 3206	 0.011482	 0.028765	 0.0015	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	4627	 3207	 0.094734	 0.240363	 0.0027	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 3208	 0.005926	 0.016914	 0.0018	 1932	 1932	 1932	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 3209	 0.002771	 0.011086	 0.0002	 2662	 2662	 2662	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 3209	 0.001764	 0.006803	 0.0001	 4328	 4328	 4328	 0.0	 0.0	 1	 -30.0	 30.0;
	5584	 3210	 0.000222	 0.000711	 0.0004	 42408	 42408	 42408	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 3211	 0.029226	 0.119174	 0.0015	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 3212	 0.000968	 0.00644	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 3214	 0.036684	 0.06715	 0.0006	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 3218	 0.008395	 0.021358	 0.001	 1295	 1295	 1295	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 3219	 0.08516	 0.20131	 0.0022	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 3220	 0.047544	 0.093827	 0.001	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 3220	 0.0451	 0.19224	 0.0025	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3924	 3220	 0.045855	 0.194004	 0.0027	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 3221	 0.001481	 0.00358	 0.0002	 7828	 7828	 7828	 0.0	 0.0	 1	 -30.0	 30.0;
	3300	 3222	 0.044848	 0.113379	 0.0013	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	4229	 3222	 0.050894	 0.128748	 0.0014	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3299	 3223	 0.044394	 0.112547	 0.0013	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4228	 3223	 0.05039	 0.128244	 0.0014	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 3224	 0.073318	 0.197531	 0.0035	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 3224	 0.052406	 0.141345	 0.0028	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	3822	 3226	 0.034197	 0.096049	 0.0044	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 3228	 0.008642	 0.021975	 0.0011	 1285	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 3229	 0.022575	 0.071151	 0.0008	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 3233	 0.000229	 0.000419	 0.0527	 64823	 64823	 64823	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 3232	 0.000229	 0.000419	 0.0527	 64823	 64823	 64823	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 3231	 0.000284	 0.00052	 0.0461	 52241	 52241	 52241	 0.0	 0.0	 1	 -30.0	 30.0;
	4608	 3235	 0.027037	 0.055556	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 3234	 0.027037	 0.055556	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 3240	 0.107332	 0.252457	 0.0028	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5540	 3241	 0.028219	 0.062736	 0.0007	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	4181	 3242	 0.014361	 0.028975	 0.0003	 914	 914	 914	 0.0	 0.0	 1	 -30.0	 30.0;
	4695	 3243	 4e-05	 0.001086	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4709	 3243	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4265	 3244	 0.012469	 0.051852	 0.0028	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 3244	 0.01284	 0.037037	 0.0016	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 3245	 0.038549	 0.083144	 0.001	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 3246	 0.031998	 0.068027	 0.0007	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5031	 3246	 0.045352	 0.09675	 0.001	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3247	 0.050894	 0.128748	 0.0014	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 3248	 0.002041	 0.003736	 0.0002	 7124	 7124	 7124	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 3249	 0.124501	 0.227898	 0.0024	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 3250	 0.021605	 0.058765	 0.0028	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	4321	 3250	 0.042469	 0.107778	 0.005	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 3250	 0.029259	 0.074074	 0.0036	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 3251	 0.017637	 0.046611	 0.0006	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	5755	 3251	 0.030234	 0.082389	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	4788	 3252	 0.01	 0.027407	 0.0013	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 3252	 0.008642	 0.022222	 0.001	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 3253	 0.009007	 0.043872	 0.0749	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 3253	 0.002738	 0.018562	 0.04	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 3253	 0.002078	 0.008442	 0.0152	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 3255	 0.004082	 0.00907	 0.0031	 3058	 3058	 3058	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 3254	 0.004082	 0.00907	 0.0031	 3058	 3058	 3058	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 3256	 0.004707	 0.008615	 0.0033	 3099	 3099	 3099	 0.0	 0.0	 1	 -30.0	 30.0;
	3437	 3258	 0.024568	 0.105062	 0.0049	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	4447	 3258	 0.01963	 0.05321	 0.0038	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 3258	 0.047284	 0.121728	 0.0058	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 3260	 0.043457	 0.183457	 0.0094	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 3261	 0.002704	 0.018296	 0.0008	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	4673	 3262	 0.021099	 0.079901	 0.0235	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	3579	 3263	 2.8e-05	 0.000172	 0.0243	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 3264	 0.009582	 0.017539	 0.0002	 1522	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	4559	 3266	 0.020569	 0.065387	 0.0217	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	3948	 3267	 0.000126	 0.000261	 0.0152	 106799	 106799	 106799	 0.0	 0.0	 1	 -30.0	 30.0;
	4236	 3269	 0.008062	 0.034266	 0.0004	 864	 864	 864	 0.0	 0.0	 1	 -30.0	 30.0;
	4238	 3270	 0.00083	 0.003931	 0.0071	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 3270	 0.002825	 0.018943	 0.0344	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 3270	 0.003338	 0.019161	 0.0349	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4237	 3270	 0.00083	 0.003832	 0.0071	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 3270	 0.002588	 0.017264	 0.0314	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 3271	 0.000356	 0.000988	 0.1094	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4772	 3272	 0.119848	 0.219381	 0.0023	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	4979	 3273	 0.002568	 0.011358	 0.1539	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5592	 3273	 0.000454	 0.00399	 0.3675	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4979	 3273	 0.000909	 0.007901	 0.4445	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 3274	 0.090955	 0.301083	 0.0031	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 3274	 0.03351	 0.067271	 0.0007	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5544	 3274	 0.039305	 0.132527	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 3276	 0.067271	 0.186445	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	3284	 3278	 2.5e-05	 0.015117	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 3278	 0.013694	 0.025067	 0.0002	 1065	 1065	 1065	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 3278	 0.018392	 0.078105	 0.001	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	3283	 3278	 2.5e-05	 0.015117	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 3278	 0.003729	 0.007886	 0.0071	 3487	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 3278	 0.018392	 0.078105	 0.001	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 3279	 2e-06	 0.001185	 0.0	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3285	 3279	 2e-06	 0.001185	 0.0	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4038	 3287	 0.000943	 0.001727	 0.0008	 15006	 15006	 15006	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 3291	 0.000425	 0.001934	 0.003	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 3294	 0.045603	 0.140338	 0.002	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 3295	 0.006803	 0.014109	 0.001	 1885	 1885	 1885	 0.0	 0.0	 1	 -30.0	 30.0;
	3500	 3297	 0.009574	 0.051902	 0.0006	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	3869	 3297	 0.015319	 0.073998	 0.0104	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 3298	 0.005798	 0.039696	 0.0724	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5782	 3298	 0.004938	 0.033165	 0.0607	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 3300	 0.048123	 0.122197	 0.0013	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 3299	 0.048123	 0.122197	 0.0013	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	4275	 3301	 0.015569	 0.028499	 0.0003	 923	 923	 923	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 3302	 0.010859	 0.046964	 0.0052	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	4546	 3302	 0.003527	 0.008566	 0.0001	 3284	 3284	 3284	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 3302	 0.048375	 0.191988	 0.0019	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4414	 3303	 0.015369	 0.043336	 0.0373	 643	 643	 643	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 3304	 0.043109	 0.117511	 0.0012	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	4207	 3306	 0.042026	 0.104837	 0.0139	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 3308	 0.028219	 0.071554	 0.0008	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 3308	 0.041068	 0.105568	 0.0012	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 3309	 0.000123	 0.001235	 0.0	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 3311	 0.006853	 0.042454	 0.075	 708	 708	 708	 0.0	 0.0	 1	 -30.0	 30.0;
	5382	 3311	 0.029353	 0.078786	 0.0009	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 3311	 0.007055	 0.02066	 0.0011	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	5751	 3311	 0.035021	 0.089065	 0.0016	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 3312	 0.001058	 0.001937	 0.161	 14024	 14024	 14024	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 3314	 0.003704	 0.008519	 0.0037	 3198	 3198	 3198	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 3315	 0.031728	 0.080494	 0.0037	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 3315	 0.048642	 0.123333	 0.0058	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 3321	 0.004031	 0.013102	 0.0121	 2154	 2154	 2154	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 3321	 0.015621	 0.039808	 0.0017	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	3913	 3322	 0.011842	 0.041824	 0.0472	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 3323	 0.001027	 0.012543	 0.0243	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 3323	 0.006935	 0.036516	 0.0663	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 3323	 0.001798	 0.012089	 0.0223	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3534	 3323	 4.8e-05	 8.8e-05	 0.001	 308192	 308192	 308192	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 3323	 4.8e-05	 8.8e-05	 0.001	 308192	 308192	 308192	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 3324	 0.008062	 0.019904	 0.0002	 1417	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	3428	 3326	 0.02037	 0.053951	 0.0026	 516	 516	 516	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 3327	 0.001111	 0.004568	 0.0002	 6319	 6319	 6319	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 3328	 0.005906	 0.026627	 0.0456	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 3329	 0.005906	 0.026627	 0.0445	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 3331	 0.064979	 0.182263	 0.0021	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 3331	 0.044092	 0.112119	 0.0	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 3333	 0.001039	 0.001902	 0.0048	 13697	 13697	 13697	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 3332	 0.00126	 0.004031	 0.0056	 7028	 7028	 7028	 0.0	 0.0	 1	 -30.0	 30.0;
	4287	 3335	 0.017385	 0.047367	 0.0102	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	5043	 3335	 0.07483	 0.18972	 0.0071	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 3335	 0.008617	 0.035097	 0.0015	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 3337	 0.02066	 0.056437	 0.0006	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 3339	 0.081975	 0.191605	 0.0088	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 3341	 0.003522	 0.006446	 0.0038	 3901	 3901	 3901	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 3340	 0.003522	 0.006446	 0.0036	 3901	 3901	 3901	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 3343	 0.068783	 0.125976	 0.0013	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 3344	 0.000988	 0.001975	 0.0	 11822	 11822	 11822	 0.0	 0.0	 1	 -30.0	 30.0;
	5354	 3345	 0.010582	 0.028219	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	3523	 3346	 0.004573	 0.020316	 0.0405	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 3348	 0.009259	 0.023457	 0.0011	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 3349	 0.028975	 0.194759	 0.0031	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4613	 3349	 0.010834	 0.038801	 0.0005	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 3349	 0.005291	 0.022172	 0.0002	 1257	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 3349	 0.029226	 0.194507	 0.0031	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 3349	 0.009574	 0.037793	 0.0005	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	5772	 3349	 0.041068	 0.104308	 0.0012	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 3350	 0.002825	 0.019239	 0.0476	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5601	 3354	 0.014613	 0.029226	 0.0003	 931	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	5602	 3354	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 3355	 0.007559	 0.025447	 0.0239	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 3356	 0.030738	 0.075586	 0.0009	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 3357	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 3358	 0.013086	 0.035309	 0.0016	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 3358	 0.036173	 0.097654	 0.0047	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	3933	 3359	 0.00952	 0.017427	 0.0134	 1443	 1443	 1443	 0.0	 0.0	 1	 -30.0	 30.0;
	3933	 3359	 0.010756	 0.019689	 0.0156	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 3361	 0.093726	 0.249685	 0.0028	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4457	 3364	 0.007723	 0.044444	 0.082	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3487	 3365	 0.002222	 0.005556	 0.0198	 4964	 4964	 4964	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 3365	 0.015309	 0.065926	 0.0032	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 3365	 0.015309	 0.065926	 0.0032	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	4581	 3366	 0.014916	 0.060544	 0.0006	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	4347	 3367	 0.001659	 0.011575	 0.0091	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4347	 3367	 0.001659	 0.011575	 0.0091	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4181	 3370	 0.03351	 0.084404	 0.001	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	4181	 3370	 0.03351	 0.084656	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 3372	 2.1e-05	 0.000339	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 3372	 2.1e-05	 0.000325	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 3375	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 3376	 0.011338	 0.038549	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 3376	 0.025498	 0.054926	 0.0008	 503	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 3378	 0.006299	 0.018392	 0.0	 1519	 1519	 1519	 0.0	 0.0	 1	 -30.0	 30.0;
	5611	 3379	 2.5e-05	 0.000123	 0.0002	 241598	 241598	 241598	 0.0	 0.0	 1	 -30.0	 30.0;
	3836	 3380	 0.039808	 0.137566	 0.0016	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	4337	 3380	 0.078861	 0.250945	 0.0029	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 3380	 0.033762	 0.143865	 0.0017	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	3836	 3380	 0.039808	 0.13681	 0.0025	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 3381	 0.004741	 0.022124	 0.038	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4406	 3382	 0.03321	 0.071358	 0.0032	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	5542	 3383	 0.014361	 0.039053	 0.0005	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 3384	 0.013857	 0.039808	 0.0001	 805	 805	 805	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 3386	 0.14768	 0.270326	 0.001	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 3387	 0.030738	 0.083648	 0.0009	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 3387	 0.031746	 0.08642	 0.0009	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 3388	 0.199295	 0.440917	 0.005	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 3390	 0.000198	 0.000751	 0.0921	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 3391	 0.01285	 0.032754	 0.0004	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	4843	 3391	 0.041572	 0.105316	 0.0012	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 3396	 0.035273	 0.120181	 0.0014	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5542	 3396	 0.048123	 0.131771	 0.0032	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	3924	 3396	 0.035273	 0.120181	 0.0014	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 3396	 0.045603	 0.131519	 0.0002	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	3925	 3397	 0.002133	 0.009659	 0.0162	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 3398	 0.044848	 0.142857	 0.0017	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 3399	 0.03351	 0.11295	 0.0033	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	4333	 3399	 0.076846	 0.262535	 0.003	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	5304	 3399	 0.044092	 0.149912	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 3399	 0.019652	 0.062232	 0.0007	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 3400	 0.002438	 0.016458	 0.0314	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 3400	 0.00243	 0.016454	 0.0319	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 3402	 0.001764	 0.007811	 0.0001	 3799	 3799	 3799	 0.0	 0.0	 1	 -30.0	 30.0;
	5486	 3403	 0.007307	 0.029982	 0.0004	 929	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 3404	 0.001512	 0.006551	 0.0001	 4524	 4524	 4524	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 3406	 0.057445	 0.119678	 0.0019	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4043	 3407	 0.000356	 0.001422	 0.0	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 3408	 0.000227	 0.000605	 0.0	 45731	 45731	 45731	 0.0	 0.0	 1	 -30.0	 30.0;
	4061	 3411	 0.029982	 0.082892	 0.001	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 3415	 0.077324	 0.210154	 0.0033	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	4972	 3416	 0.000616	 0.006627	 0.1531	 1754.0	 1754.0	 1754.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 3417	 0.004975	 0.009106	 0.0065	 2846	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 3418	 0.009574	 0.026707	 0.0	 1072	 1072	 1072	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 3419	 0.00716	 0.029506	 0.0015	 979	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	4035	 3419	 0.039877	 0.111605	 0.0052	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 3419	 0.00716	 0.029506	 0.0015	 979	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 3420	 0.034517	 0.135551	 0.0025	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 3421	 0.012593	 0.034444	 0.0016	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	5281	 3422	 0.036489	 0.066792	 0.0007	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 3422	 0.049887	 0.126732	 0.0014	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4108	 3423	 0.038272	 0.080494	 0.0037	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 3424	 0.043084	 0.144873	 0.002	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 3426	 0.054674	 0.165281	 0.002	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 3427	 0.000776	 0.004612	 0.1736	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5127	 3427	 0.000119	 0.000691	 0.0076	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 3427	 0.000119	 0.000711	 0.0071	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 3427	 0.001126	 0.005965	 0.0162	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 3429	 0.051146	 0.212094	 0.0081	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	3893	 3429	 0.104208	 0.284303	 0.0028	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 3431	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 3432	 0.013901	 0.039222	 0.002	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 3432	 0.011605	 0.032963	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 3432	 0.01358	 0.039012	 0.0019	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 3434	 0.017778	 0.049753	 0.0023	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	3524	 3437	 0.043827	 0.090247	 0.0454	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 3439	 0.050643	 0.136054	 0.0015	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5588	 3439	 0.034266	 0.093978	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 3441	 0.066112	 0.16775	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 3442	 0.032364	 0.095227	 0.0297	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 3443	 0.028219	 0.078105	 0.0008	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	3447	 3444	 0.063492	 0.168556	 0.002	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 3444	 0.01033	 0.019148	 0.0204	 1358	 1358	 1358	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 3444	 0.017889	 0.045603	 0.0021	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 3445	 0.035273	 0.121693	 0.0014	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 3446	 0.000302	 0.00252	 0.0001	 13366	 13366	 13366	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 3447	 0.102797	 0.27614	 0.003	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 3448	 0.05039	 0.138574	 0.0015	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 3449	 0.008284	 0.020679	 0.001	 1334	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 3451	 0.02066	 0.056689	 0.0006	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 3453	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 3453	 0.000252	 0.00252	 0.0006	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 3453	 0.079012	 0.200277	 0.0023	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 3454	 0.008272	 0.021111	 0.0042	 1338	 1338	 1338	 0.0	 0.0	 1	 -30.0	 30.0;
	4924	 3455	 0.004568	 0.012963	 0.0463	 2162	 2162	 2162	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 3455	 0.004444	 0.018889	 0.0028	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 3455	 0.004444	 0.018765	 0.0028	 1541	 1541	 1541	 0.0	 0.0	 1	 -30.0	 30.0;
	5628	 3456	 0.016377	 0.0451	 0.0005	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 3457	 0.023683	 0.137818	 0.0132	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 3459	 0.00379	 0.015753	 0.0008	 1834	 1834	 1834	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 3460	 0.007407	 0.020247	 0.001	 1378	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	5777	 3461	 0.062988	 0.171328	 0.005	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 3462	 0.042555	 0.090678	 0.001	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 3463	 0.017637	 0.075334	 0.002	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 3466	 0.024568	 0.065432	 0.0031	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 3468	 0.001008	 0.002771	 0.0	 10014	 10014	 10014	 0.0	 0.0	 1	 -30.0	 30.0;
	3514	 3469	 0.022593	 0.102222	 0.005	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 3470	 0.001993	 0.020458	 0.0638	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 3470	 0.001993	 0.020472	 0.0638	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 3473	 0.001966	 0.003599	 0.0024	 6987	 6987	 6987	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 3475	 0.001367	 0.002502	 0.0013	 10050	 10050	 10050	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 3472	 0.001284	 0.00235	 0.0013	 10699	 10699	 10699	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 3474	 0.001025	 0.001876	 0.001	 13403	 13403	 13403	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 3481	 0.003527	 0.007055	 0.0069	 3633	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 3480	 0.003527	 0.007055	 0.0069	 3633	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 3482	 0.027463	 0.092215	 0.001	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 3482	 0.018141	 0.058957	 0.0007	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5478	 3482	 0.002016	 0.01285	 0.0002	 2203	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 3482	 0.027211	 0.0839	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 3482	 0.006551	 0.019652	 0.0002	 1384	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 3482	 0.006803	 0.02066	 0.0002	 1318	 1318	 1318	 0.0	 0.0	 1	 -30.0	 30.0;
	3720	 3484	 0.077161	 0.214321	 0.0341	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3556	 3485	 0.002686	 0.018173	 0.0324	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4227	 3485	 0.005748	 0.03836	 0.0688	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 3486	 0.122222	 0.31804	 0.0041	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	4414	 3486	 0.03477	 0.095238	 0.0012	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	3545	 3488	 0.097254	 0.284455	 0.0034	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 3488	 0.039808	 0.166793	 0.0021	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 3490	 0.005562	 0.010181	 0.0001	 2546	 2546	 2546	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 3492	 0.007037	 0.023951	 0.0011	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	4457	 3493	 0.000277	 0.002588	 0.0051	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 3494	 0.043739	 0.148602	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 3494	 0.044696	 0.118317	 0.0016	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 3494	 0.02973	 0.08516	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 3494	 0.029982	 0.085664	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	5632	 3495	 0.027715	 0.077601	 0.0009	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 3497	 0.008566	 0.055682	 0.0007	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	4752	 3497	 0.052381	 0.142605	 0.0019	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5106	 3497	 0.007559	 0.017385	 0.0015	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 3497	 0.008566	 0.055682	 0.0007	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	3567	 3498	 0.035556	 0.097037	 0.0045	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 3498	 0.024198	 0.064444	 0.0242	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 3498	 0.024198	 0.064444	 0.0242	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 3499	 0.027211	 0.062988	 0.0007	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	3869	 3500	 0.008566	 0.03477	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 1499	 2e-05	 0.000198	 0.0	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5278	 3506	 0.000252	 0.001008	 0.0	 28417	 28417	 28417	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 3507	 0.006608	 0.012096	 0.0002	 2143	 2143	 2143	 0.0	 0.0	 1	 -30.0	 30.0;
	4010	 3508	 0.067422	 0.186621	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 3508	 0.06198	 0.216931	 0.002	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 3508	 0.059965	 0.147896	 0.0017	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 3508	 0.003527	 0.007811	 0.0	 3446	 3446	 3446	 0.0	 0.0	 1	 -30.0	 30.0;
	4011	 3509	 0.002647	 0.011911	 0.0213	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 3510	 0.010582	 0.02973	 0.0003	 936	 936	 936	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 3511	 0.020741	 0.058272	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	4016	 3512	 0.014059	 0.045578	 0.0006	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 3513	 0.108592	 0.296548	 0.0033	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 3514	 0.008272	 0.056173	 0.0028	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 3514	 0.047654	 0.197901	 0.0102	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 3514	 0.011482	 0.072099	 0.0039	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 3514	 0.007531	 0.052593	 0.0028	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 3514	 0.007778	 0.055556	 0.0029	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	4034	 3517	 0.083648	 0.239859	 0.0026	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	4034	 3517	 0.0839	 0.240615	 0.0026	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 3518	 0.001659	 0.011081	 0.0203	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 3518	 0.002509	 0.011319	 0.0203	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3836	 3519	 0.012346	 0.039053	 0.0005	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	4552	 3522	 0.008818	 0.038045	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	5010	 3521	 0.013857	 0.047115	 0.001	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 3522	 0.030486	 0.07735	 0.003	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	5790	 3521	 0.008818	 0.037793	 0.0	 761	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 3523	 0.004523	 0.026983	 0.0506	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 3528	 0.000928	 0.006183	 0.0111	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 3528	 0.000217	 0.001481	 0.003	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5822	 3529	 7e-06	 0.00013	 0.0029	 2694.0	 2694.0	 2694.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4424	 3530	 0.04258	 0.102797	 0.0067	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 3532	 0.001764	 0.003527	 0.0013	 7266	 7266	 7266	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 3535	 0.00068	 0.00126	 0.0	 21242	 21242	 21242	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 3536	 0.004031	 0.01285	 0.0002	 2259	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	4816	 3538	 0.001605	 0.007407	 0.0296	 4085	 4085	 4085	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 3538	 0.016173	 0.061728	 0.0005	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 3538	 0.001235	 0.004938	 0.0141	 6818	 6818	 6818	 0.0	 0.0	 1	 -30.0	 30.0;
	4104	 3539	 0.000111	 0.000741	 0.0014	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 3539	 0.001857	 0.008375	 0.0142	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 3539	 9.9e-05	 0.000711	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4262	 3540	 0.000198	 0.000909	 0.001	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5830	 3541	 0.070547	 0.232552	 0.0026	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 3545	 0.08642	 0.205341	 0.0029	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 3545	 0.032754	 0.137818	 0.0022	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 3545	 0.049131	 0.134039	 0.0015	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 3548	 0.019652	 0.082389	 0.0001	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 3550	 0.016377	 0.041572	 0.0005	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5078	 3550	 0.008566	 0.027715	 0.0006	 1049	 1049	 1049	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 3550	 0.01285	 0.040816	 0.0005	 711	 711	 711	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 3552	 0.000494	 0.001358	 0.0	 20555	 20555	 20555	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 3553	 0.000252	 0.00126	 0.0012	 22978	 22978	 22978	 0.0	 0.0	 1	 -30.0	 30.0;
	4360	 3554	 0.076846	 0.15999	 0.009	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4893	 3555	 0.039305	 0.134039	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 3555	 0.007055	 0.0451	 0.0006	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5478	 3555	 0.033006	 0.10456	 0.005	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 3555	 0.056689	 0.119174	 0.0099	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	5707	 3555	 0.069539	 0.23608	 0.0028	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 3555	 0.007055	 0.044596	 0.0006	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 3558	 0.007811	 0.014297	 0.0088	 1867	 1867	 1867	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 3559	 0.015117	 0.051146	 0.003	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 3559	 0.020912	 0.056941	 0.0007	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 3560	 0.013274	 0.060326	 0.1043	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3564	 3561	 0.000252	 0.00252	 0.001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 3562	 2e-05	 0.000198	 0.0091	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 3563	 2e-05	 0.000198	 0.0051	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 3566	 0.045352	 0.126984	 0.0081	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 3566	 0.114215	 0.20907	 0.0039	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 3567	 0.031605	 0.086173	 0.004	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 3568	 0.023683	 0.0645	 0.0007	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 3569	 0.022728	 0.059679	 0.0032	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	4671	 3570	 0.019136	 0.049012	 0.0023	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	4010	 3571	 0.053918	 0.133787	 0.002	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 3571	 0.023683	 0.056941	 0.001	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	4010	 3571	 0.053666	 0.133787	 0.001	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 3572	 0.105064	 0.214412	 0.002	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 3573	 0.004701	 0.030064	 0.0547	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 3576	 0.105064	 0.275888	 0.0034	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	5632	 3576	 0.044596	 0.125472	 0.0013	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4046	 3579	 0.001343	 0.007862	 0.0142	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4507	 3581	 2.8e-05	 0.000145	 0.0606	 855.0	 855.0	 855.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 3580	 5e-06	 0.0001	 0.0	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3580	 1497	 1e-05	 0.0001	 0.0	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4519	 3582	 0.026455	 0.072562	 0.0008	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 3582	 0.032552	 0.067674	 0.0007	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	3845	 3584	 0.002431	 0.004449	 0.0121	 5982	 5982	 5982	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 3584	 0.052839	 0.133951	 0.0084	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	5343	 3584	 0.020123	 0.051358	 0.0123	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 3584	 0.022839	 0.058025	 0.007	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 3585	 0.000504	 0.00252	 0.0004	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5647	 3588	 0.000252	 0.000504	 0.001	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 3589	 0.000252	 0.000504	 0.001	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 3590	 0.00907	 0.0226	 0.0002	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 3590	 0.003779	 0.015873	 0.0133	 1864	 1864	 1864	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 3592	 9.9e-05	 0.000182	 0.0004	 151236	 151236	 151236	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 3593	 0.00073	 0.001335	 0.1104	 20343	 20343	 20343	 0.0	 0.0	 1	 -30.0	 30.0;
	3430	 3594	 0.002016	 0.005543	 0.0001	 5006	 5006	 5006	 0.0	 0.0	 1	 -30.0	 30.0;
	3987	 3594	 0.028975	 0.121945	 0.0015	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 3595	 0.018038	 0.057792	 0.0916	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 3595	 0.001798	 0.004543	 0.0081	 6284	 6284	 6284	 0.0	 0.0	 1	 -30.0	 30.0;
	3742	 3596	 0.015873	 0.106828	 0.0018	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	5456	 3599	 0.02973	 0.080877	 0.0009	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 3600	 0.016864	 0.057074	 0.0042	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 3600	 0.009136	 0.029136	 0.0015	 994	 994	 994	 0.0	 0.0	 1	 -30.0	 30.0;
	4305	 3602	 0.005039	 0.03351	 0.0009	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 3602	 0.013605	 0.056437	 0.0007	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 3605	 8e-06	 0.0001	 0.002	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4187	 3605	 8e-06	 0.0001	 0.002	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 3606	 0.006543	 0.017284	 0.0008	 1641	 1641	 1641	 0.0	 0.0	 1	 -30.0	 30.0;
	4324	 3607	 0.000909	 0.003299	 0.0051	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4233	 3608	 0.058201	 0.159486	 0.0021	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4191	 3610	 0.02318	 0.078609	 0.0018	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 3610	 0.023935	 0.098765	 0.0019	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 3610	 0.005039	 0.022424	 0.0005	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	5653	 3611	 0.049635	 0.125976	 0.0014	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	3395	 3614	 0.002627	 0.017284	 0.0435	 1771	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 3614	 0.002272	 0.011239	 0.0203	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 3614	 0.002574	 0.013541	 0.0349	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 3612	 0.001817	 0.012207	 0.0223	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 3612	 0.000375	 0.002509	 0.0051	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 3614	 0.000356	 0.002311	 0.004	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 3613	 0.003081	 0.020089	 0.0375	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 3613	 0.000375	 0.002528	 0.0051	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 3614	 0.001798	 0.010133	 0.0182	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 3614	 0.00097	 0.009481	 0.037	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5352	 3612	 0.001067	 0.007091	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 3614	 0.000751	 0.007423	 0.0248	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 3612	 0.001067	 0.007091	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3368	 3615	 0.00099	 0.007576	 0.156	 1486.0	 1486.0	 1486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4049	 3616	 0.000298	 0.003262	 0.0693	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4603	 3616	 0.000561	 0.006288	 0.1574	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 3616	 0.000554	 0.006163	 0.1588	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4603	 3615	 0.000382	 0.005002	 0.1718	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 3615	 0.000381	 0.005	 0.1733	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 3615	 0.000547	 0.006046	 0.1242	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 3618	 0.040741	 0.087161	 0.004	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 3617	 0.003333	 0.008889	 0.0005	 3129	 3129	 3129	 0.0	 0.0	 1	 -30.0	 30.0;
	3406	 3619	 0.026455	 0.054674	 0.002	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	3406	 3619	 0.010859	 0.026153	 0.0501	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 3621	 0.048324	 0.129478	 0.0026	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 3621	 0.078045	 0.142861	 0.0014	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 3621	 0.048803	 0.125926	 0.0021	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 3622	 0.063492	 0.141345	 0.001	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 3623	 0.006262	 0.043595	 0.078	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 3623	 0.001659	 0.011022	 0.0203	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 3623	 0.002744	 0.018746	 0.0349	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 3623	 0.001659	 0.011042	 0.0203	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 3625	 0.001764	 0.004283	 0.0001	 6375	 6375	 6375	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 3627	 0.000936	 0.001713	 0.0023	 15535	 15535	 15535	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 3626	 0.000936	 0.001713	 0.0023	 15535	 15535	 15535	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 3629	 0.022424	 0.054926	 0.0064	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 3628	 0.02318	 0.056437	 0.0066	 484	 484	 484	 0.0	 0.0	 1	 -30.0	 30.0;
	5328	 3630	 0.00284	 0.009877	 0.0018	 2951	 2951	 2951	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 3630	 0.004593	 0.011444	 0.0005	 2460	 2460	 2460	 0.0	 0.0	 1	 -30.0	 30.0;
	4472	 3630	 0.000345	 0.000632	 0.0011	 42115	 42115	 42115	 0.0	 0.0	 1	 -30.0	 30.0;
	3464	 3630	 0.001131	 0.00207	 0.0032	 12856	 12856	 12856	 0.0	 0.0	 1	 -30.0	 30.0;
	3746	 3631	 0.003694	 0.02481	 0.0456	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 3631	 0.002963	 0.019793	 0.0694	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 3631	 0.002647	 0.017659	 0.0324	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 3631	 0.00719	 0.033264	 0.0618	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 3632	 0.016813	 0.030776	 0.0213	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 3634	 0.014361	 0.048375	 0.0006	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 3634	 0.030234	 0.092719	 0.0025	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 3636	 0.006803	 0.015621	 0.0002	 1744	 1744	 1744	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 3637	 0.054321	 0.138148	 0.0063	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 3640	 0.007813	 0.014301	 0.0087	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 3641	 0.007569	 0.013855	 0.0089	 1815	 1815	 1815	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 3643	 0.000123	 0.001235	 0.0002	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 3645	 0.023935	 0.076846	 0.0009	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 3646	 0.096926	 0.251323	 0.0028	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 3647	 0.002771	 0.011842	 0.0177	 2428	 2428	 2428	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 3648	 0.003457	 0.015704	 0.0284	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4575	 3648	 0.00164	 0.021709	 0.0911	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 3650	 0.006327	 0.011581	 0.0051	 2305	 2305	 2305	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 3650	 0.012572	 0.03865	 0.0009	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	3859	 3650	 0.002645	 0.01091	 0.0145	 2710	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 3650	 0.01101	 0.04447	 0.0006	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 3651	 0.022525	 0.063492	 0.0007	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	4489	 3653	 0.007307	 0.035525	 0.0005	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 3653	 0.0097	 0.039632	 0.0004	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	4180	 3655	 2e-05	 9.9e-05	 0.0121	 457.0	 457.0	 457.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 3655	 0.000435	 0.002878	 0.0051	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 3657	 0.017385	 0.044344	 0.0005	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	3659	 3658	 0.00252	 0.005039	 0.0	 5241	 5241	 5241	 0.0	 0.0	 1	 -30.0	 30.0;
	3984	 3658	 0.006922	 0.012671	 0.004	 2045	 2045	 2045	 0.0	 0.0	 1	 -30.0	 30.0;
	3984	 3659	 0.001512	 0.003527	 0.0	 7695	 7695	 7695	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 3661	 0.022676	 0.041824	 0.0004	 621	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	3676	 3662	 0.007559	 0.020156	 0.0002	 1413	 1413	 1413	 0.0	 0.0	 1	 -30.0	 30.0;
	3677	 3662	 0.017889	 0.044344	 0.0005	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 3662	 0.03477	 0.080625	 0.022	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 3663	 0.003931	 0.020365	 0.037	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 3663	 0.002805	 0.012484	 0.0319	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3699	 3664	 0.069035	 0.197531	 0.0021	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 3664	 0.000151	 0.000479	 0.0002	 58788	 58788	 58788	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 3664	 0.029226	 0.080877	 0.0009	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 3664	 0.080373	 0.238095	 0.0649	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 3666	 0.007309	 0.049876	 0.0881	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4611	 3665	 0.006044	 0.042114	 0.0729	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 3667	 0.009826	 0.020912	 0.0009	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 3667	 0.030234	 0.082389	 0.001	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 3668	 0.0052	 0.009518	 0.0	 2723	 2723	 2723	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 3669	 0.043084	 0.135047	 0.002	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	3694	 3670	 0.020864	 0.088765	 0.0064	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 3672	 0.040237	 0.102268	 0.0012	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 3674	 0.016444	 0.060815	 0.0046	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 3674	 0.000988	 0.002099	 0.0006	 13072	 13072	 13072	 0.0	 0.0	 1	 -30.0	 30.0;
	3746	 3675	 0.000612	 0.004128	 0.0081	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3980	 3675	 0.001225	 0.006854	 0.1397	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 3675	 0.001738	 0.011615	 0.0213	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 3678	 0.036105	 0.110809	 0.0021	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	3310	 3679	 0.001059	 0.003597	 0.0458	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 3679	 0.009699	 0.044839	 0.0749	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4398	 3679	 0.001426	 0.009276	 0.0292	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4560	 3679	 0.014143	 0.064395	 0.1134	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 3679	 0.003502	 0.02318	 0.0547	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 3679	 0.004543	 0.024889	 0.0435	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 3681	 0.018645	 0.037037	 0.0183	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 3683	 2e-05	 9.8e-05	 0.0	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 3685	 0.02192	 0.062232	 0.0027	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 3685	 0.016125	 0.044596	 0.0005	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 3686	 0.003275	 0.00907	 0.0	 3062	 3062	 3062	 0.0	 0.0	 1	 -30.0	 30.0;
	5660	 3687	 2e-05	 0.000198	 0.001	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5421	 3688	 0.014361	 0.036029	 0.001	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 3688	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5681	 3688	 0.022172	 0.046107	 0.001	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 3688	 0.014555	 0.026643	 0.0004	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 3689	 5.9e-05	 0.000356	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 3690	 0.016352	 0.067347	 0.0015	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 3695	 0.065004	 0.177375	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 3695	 0.069287	 0.190224	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 3696	 0.048963	 0.089626	 0.0009	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4919	 3697	 0.119678	 0.248929	 0.0034	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	4181	 3700	 0.006803	 0.027967	 0.0073	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	5446	 3700	 0.002771	 0.009826	 0.0001	 2893	 2893	 2893	 0.0	 0.0	 1	 -30.0	 30.0;
	4181	 3700	 0.006803	 0.027967	 0.0073	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 3701	 0.012497	 0.033132	 0.0009	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	4462	 3702	 0.06389	 0.11695	 0.0012	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 3703	 0.001126	 0.005037	 0.0091	 5986	 5986	 5986	 0.0	 0.0	 1	 -30.0	 30.0;
	4243	 3704	 0.004642	 0.030854	 0.0557	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 3704	 0.001578	 0.010526	 0.0192	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 3704	 0.000119	 0.000889	 0.002	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 3710	 0.001351	 0.008986	 0.0303	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 3711	 0.001512	 0.005039	 0.0123	 5613	 5613	 5613	 0.0	 0.0	 1	 -30.0	 30.0;
	4497	 3711	 0.003779	 0.014865	 0.0185	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 3712	 0.001027	 0.006123	 0.2162	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4178	 3714	 0.010741	 0.027407	 0.0013	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	4791	 3714	 0.018272	 0.047901	 0.0023	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 3715	 0.000123	 0.000247	 0.0003	 109898	 109898	 109898	 0.0	 0.0	 1	 -30.0	 30.0;
	5668	 3716	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 3718	 0.084404	 0.230234	 0.0026	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5669	 3719	 0.000454	 0.001235	 0.0001	 22120	 22120	 22120	 0.0	 0.0	 1	 -30.0	 30.0;
	4364	 3723	 0.026455	 0.058957	 0.0092	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 3727	 0.005926	 0.013827	 0.0	 1736	 1736	 1736	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 3727	 0.059259	 0.141284	 0.0005	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 3730	 0.000194	 0.000624	 0.0009	 47367	 47367	 47367	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 3731	 0.015621	 0.066264	 0.0014	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	5670	 3733	 0.019331	 0.035384	 0.0003	 711	 711	 711	 0.0	 0.0	 1	 -30.0	 30.0;
	5772	 3732	 0.062736	 0.175611	 0.0017	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4265	 3734	 0.003333	 0.026667	 0.0959	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	5331	 3735	 0.001146	 0.007625	 0.0142	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3722	 3736	 0.00126	 0.00252	 0.0031	 10480	 10480	 10480	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 3736	 0.007811	 0.043588	 0.0154	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 3736	 0.044596	 0.151927	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 3736	 0.007811	 0.04384	 0.0155	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	3726	 3738	 9.9e-05	 0.000198	 0.0142	 138682	 138682	 138682	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 3738	 9.9e-05	 0.000198	 0.0182	 138682	 138682	 138682	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 3737	 9.9e-05	 0.000988	 0.004	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3724	 3738	 0.000111	 0.000223	 0.0213	 123245	 123245	 123245	 0.0	 0.0	 1	 -30.0	 30.0;
	4796	 3741	 0.001512	 0.002771	 0.0018	 9077	 9077	 9077	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 3743	 0.003477	 0.023822	 0.0456	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 3746	 0.000324	 0.000992	 0.0729	 29661	 29661	 29661	 0.0	 0.0	 1	 -30.0	 30.0;
	5404	 3747	 0.019259	 0.038642	 0.0016	 688	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 3750	 0.017709	 0.032416	 0.0003	 824	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 3751	 0.00081	 0.005472	 0.0101	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 3751	 0.000751	 0.005057	 0.0127	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 3752	 0.001884	 0.019197	 0.4621	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 3752	 0.001891	 0.019134	 0.4621	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4810	 3753	 0.046173	 0.123827	 0.0061	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 3754	 0.029226	 0.076846	 0.0009	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 3755	 0.015667	 0.042753	 0.0019	 653	 653	 653	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 3757	 0.007889	 0.021309	 0.001	 1308	 1308	 1308	 0.0	 0.0	 1	 -30.0	 30.0;
	4491	 3758	 0.047367	 0.19224	 0.0025	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	4529	 3758	 0.083396	 0.277904	 0.0035	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 3759	 0.001462	 0.009817	 0.0177	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 3762	 0.00126	 0.00252	 0.0024	 10170	 10170	 10170	 0.0	 0.0	 1	 -30.0	 30.0;
	3859	 3763	 0.007357	 0.027438	 0.0096	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 3763	 0.056614	 0.174528	 0.0021	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 3763	 0.021794	 0.095692	 0.012	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 3763	 0.042504	 0.080071	 0.0011	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 3765	 0.03545	 0.095036	 0.0018	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 3766	 0.048148	 0.135062	 0.0062	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 3770	 0.000237	 0.001501	 0.003	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4620	 3772	 0.090199	 0.224994	 0.0258	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 3772	 0.016377	 0.067271	 0.0008	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 3773	 0.015923	 0.064727	 0.0034	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 3773	 0.009574	 0.062232	 0.0008	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 3773	 0.01159	 0.073822	 0.001	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 3774	 0.000402	 0.005242	 0.1791	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4603	 3774	 0.000402	 0.005242	 0.1819	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5045	 3775	 0.057697	 0.196271	 0.0023	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 3786	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 3787	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4710	 3786	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4727	 3794	 0.012099	 0.031852	 0.0015	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 3794	 0.020617	 0.054198	 0.0026	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 3795	 0.009826	 0.032754	 0.0037	 864	 864	 864	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 3795	 0.004031	 0.013605	 0.0002	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	4455	 3796	 0.111867	 0.241875	 0.0026	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 3796	 0.02318	 0.062988	 0.0007	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	4120	 3799	 0.023683	 0.101789	 0.0012	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	5677	 3800	 0.038801	 0.073066	 0.0008	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 3802	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4824	 3802	 0.005795	 0.014865	 0.0	 1851	 1851	 1851	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 3802	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 3804	 0.000366	 0.000669	 0.0476	 40590	 40590	 40590	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 3803	 0.000352	 0.000645	 0.0466	 42124	 42124	 42124	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 3809	 0.003779	 0.007055	 0.0001	 3801	 3801	 3801	 0.0	 0.0	 1	 -30.0	 30.0;
	4282	 3809	 0.090627	 0.196951	 0.0022	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 3809	 0.17158	 0.354497	 0.0037	 78	 78	 78	 0.0	 0.0	 1	 -30.0	 30.0;
	5200	 3809	 0.082766	 0.238524	 0.0024	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 3809	 0.066767	 0.18191	 0.002	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 3809	 0.003864	 0.007073	 0.0001	 3774	 3774	 3774	 0.0	 0.0	 1	 -30.0	 30.0;
	4732	 3810	 0.003121	 0.020997	 0.0385	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 3810	 0.004602	 0.0208	 0.0365	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 3811	 0.002694	 0.028476	 0.6599	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 3813	 0.000751	 0.003417	 0.0061	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 3814	 0.075107	 0.190199	 0.0033	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 3815	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3820	 3815	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3819	 3815	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 3824	 0.041245	 0.109851	 0.0051	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 3825	 0.004233	 0.018695	 0.0293	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 3826	 0.018392	 0.117158	 0.0001	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 3827	 0.00083	 0.005491	 0.0101	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 3829	 0.000375	 0.001422	 0.1893	 263.0	 263.0	 263.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 3828	 0.000395	 0.001422	 0.1903	 20973	 20973	 20973	 0.0	 0.0	 1	 -30.0	 30.0;
	3885	 3831	 0.01741	 0.068582	 0.0008	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	3975	 3831	 0.013782	 0.036886	 0.0063	 773	 773	 773	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 3830	 0.00907	 0.038549	 0.0005	 768	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 3830	 0.013706	 0.045931	 0.0042	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 3831	 0.00907	 0.038801	 0.0005	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 3832	 0.000494	 0.002963	 0.0051	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 3835	 0.018889	 0.071482	 0.0006	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4543	 3837	 0.129252	 0.352734	 0.005	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 3838	 0.004006	 0.010129	 0.0054	 2711	 2711	 2711	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 3839	 0.017133	 0.054674	 0.001	 516	 516	 516	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 3839	 0.078105	 0.213656	 0.002	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 3840	 0.02968	 0.124313	 0.0015	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5514	 3840	 0.021164	 0.079365	 0.001	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 3842	 0.029554	 0.078534	 0.0013	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	5681	 3842	 0.005291	 0.011842	 0.0	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 3843	 0.037284	 0.100247	 0.0052	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4744	 3846	 0.000435	 0.0016	 0.1974	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4744	 3846	 0.000435	 0.00162	 0.2005	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 3847	 0.004111	 0.013074	 0.0006	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 3848	 0.008272	 0.022222	 0.0011	 1253	 1253	 1253	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 3850	 0.065356	 0.160494	 0.0078	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	4560	 3851	 0.006499	 0.029472	 0.0506	 301.0	 301.0	 301.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 3855	 0.067271	 0.170824	 0.002	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5796	 3855	 0.012598	 0.054674	 0.001	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 3854	 0.004283	 0.051398	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	4690	 3856	 0.004879	 0.022479	 0.0375	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4973	 3858	 0.017511	 0.074351	 0.0009	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	5514	 3858	 0.008541	 0.023154	 0.0007	 1197	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 3861	 9.9e-05	 0.000573	 0.0511	 53230	 53230	 53230	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 3860	 0.000138	 0.000435	 0.0445	 67824	 67824	 67824	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 3863	 0.046494	 0.092988	 0.0039	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5686	 3864	 0.001864	 0.007508	 0.0001	 3817	 3817	 3817	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 3867	 0.014198	 0.038148	 0.0018	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 3871	 0.019829	 0.137868	 0.0015	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 3873	 0.080877	 0.204334	 0.0043	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 3873	 0.038297	 0.131771	 0.0319	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 3873	 0.014613	 0.037289	 0.0025	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 3874	 0.002943	 0.019773	 0.0354	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4254	 3874	 0.001679	 0.011101	 0.0203	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 3877	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5688	 3877	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4958	 3878	 0.102545	 0.213656	 0.0023	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	4958	 3878	 0.102545	 0.213656	 0.0023	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	5660	 3879	 0.006301	 0.028622	 0.0496	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 3881	 0.002746	 0.014183	 0.1868	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4979	 3882	 0.002469	 0.013827	 0.1757	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 3881	 0.002094	 0.010607	 0.1822	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 3883	 0.074628	 0.18962	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 3884	 0.001008	 0.00252	 0.0027	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	4513	 3890	 0.035062	 0.095679	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4620	 3891	 0.141245	 0.284127	 0.0032	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 3891	 0.065709	 0.181255	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	4253	 3894	 0.000436	 0.000797	 0.001	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	5814	 3896	 0.007901	 0.029877	 0.0257	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 3898	 0.009323	 0.046598	 0.08	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 3900	 0.06261	 0.148501	 0.0072	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 3901	 0.004425	 0.029349	 0.0547	 578.0	 578.0	 578.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4589	 3903	 0.079365	 0.163517	 0.0021	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4393	 3904	 0.069791	 0.190224	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 3906	 0.0032	 0.021472	 0.0385	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4640	 3907	 0.000824	 0.008373	 0.2166	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4664	 3907	 0.001211	 0.017571	 0.4563	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 3907	 0.000824	 0.008373	 0.2166	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4664	 3907	 0.001205	 0.017438	 0.4534	 1825	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	4443	 3910	 0.021244	 0.060489	 0.0193	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 3911	 0.000553	 0.003793	 0.0071	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 3915	 0.033006	 0.086672	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 3916	 0.054699	 0.138675	 0.0016	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	5059	 3916	 0.000504	 0.00252	 0.0004	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 3916	 0.052406	 0.141345	 0.0021	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 3916	 0.06198	 0.157218	 0.0017	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 3917	 0.007546	 0.034173	 0.0607	 273.0	 273.0	 273.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 3918	 0.068027	 0.150416	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 3919	 0.014613	 0.030234	 0.0	 906	 906	 906	 0.0	 0.0	 1	 -30.0	 30.0;
	4035	 3922	 0.022593	 0.058519	 0.0084	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 3922	 0.027901	 0.104444	 0.0099	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	4837	 3924	 0.079113	 0.215671	 0.0024	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4837	 3923	 0.087679	 0.239103	 0.0027	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5695	 3928	 0.009156	 0.040044	 0.0135	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 3930	 0.017133	 0.043336	 0.0005	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 3930	 0.005039	 0.014109	 0.0002	 1971	 1971	 1971	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 3931	 0.000928	 0.004148	 0.0071	 7269	 7269	 7269	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 3931	 0.002844	 0.018627	 0.0334	 468.0	 468.0	 468.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 3931	 0.00257	 0.017083	 0.0314	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 3937	 0.009936	 0.040059	 0.0658	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5272	 3937	 0.001679	 0.011062	 0.0203	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 3937	 0.004958	 0.022716	 0.0395	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 3937	 0.000178	 0.00077	 0.5083	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 3944	 0.071554	 0.192996	 0.0029	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 3944	 0.045352	 0.123961	 0.0014	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 3945	 0.039808	 0.089695	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 3949	 0.000237	 0.001541	 0.003	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 3951	 0.053338	 0.12769	 0.0015	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 3954	 0.025447	 0.063996	 0.001	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 3955	 0.003117	 0.005706	 0.0001	 4542	 4542	 4542	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 3956	 0.013026	 0.0451	 0.0048	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	3960	 3959	 0.014564	 0.026659	 0.0021	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	4462	 3959	 0.066767	 0.212648	 0.0025	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 3959	 0.007811	 0.024943	 0.0003	 1164	 1164	 1164	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 3961	 0.018392	 0.076846	 0.0073	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 3962	 0.000948	 0.009185	 0.0324	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 3963	 0.000889	 0.008652	 0.0304	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4616	 3964	 0.000173	 0.001235	 0.0009	 23818	 23818	 23818	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 3964	 0.008395	 0.021235	 0.001	 1301	 1301	 1301	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 3964	 0.024161	 0.061506	 0.0029	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 3964	 2.5e-05	 0.001235	 0.0	 24046	 24046	 24046	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 3965	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 3967	 0.010617	 0.028765	 0.0013	 969	 969	 969	 0.0	 0.0	 1	 -30.0	 30.0;
	5700	 3972	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 3976	 0.001738	 0.011595	 0.0213	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4085	 3977	 0.00037	 0.050617	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	4085	 3977	 0.00037	 0.050617	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 3979	 0.01321	 0.055926	 0.0029	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 3980	 0.008652	 0.039447	 0.0724	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4198	 3981	 0.040741	 0.104444	 0.0049	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 3981	 0.015185	 0.106049	 0.0053	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 3982	 0.088939	 0.22575	 0.003	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5703	 3986	 0.00358	 0.007284	 0.0003	 3660	 3660	 3660	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 3988	 0.073822	 0.198539	 0.0119	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 3989	 0.107178	 0.196187	 0.0016	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 3990	 0.047048	 0.08612	 0.0009	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 3991	 0.001067	 0.004346	 0.0182	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4931	 3992	 0.023735	 0.043446	 0.0005	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	5704	 3993	 0.017385	 0.031998	 0.0003	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	5354	 3994	 0.041572	 0.133283	 0.001	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 3999	 0.005543	 0.012094	 0.0002	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	4700	 4000	 0.037407	 0.101605	 0.0048	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 4001	 0.037289	 0.094482	 0.001	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 4003	 0.066516	 0.139078	 0.0015	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 4004	 0.025185	 0.098272	 0.0058	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	4469	 4004	 0.003457	 0.008642	 0.0023	 3258	 3258	 3258	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 4006	 0.007206	 0.029252	 0.0019	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 4008	 0.067019	 0.169463	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 4008	 0.056437	 0.143613	 0.0017	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 4009	 0.008332	 0.037879	 0.0663	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 4010	 0.033006	 0.072814	 0.001	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	4690	 4011	 0.008774	 0.031285	 0.0491	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 4013	 0.018395	 0.048395	 0.0023	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 4015	 0.10112	 0.1851	 0.0019	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 4018	 0.002311	 0.015467	 0.0284	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 4020	 0.001264	 0.005136	 0.0091	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 4020	 0.001264	 0.005136	 0.0091	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 4021	 0.039557	 0.087176	 0.0013	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 4022	 0.005886	 0.031546	 0.0567	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 4022	 0.011239	 0.050647	 0.0901	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4023	 0.000705	 0.001663	 0.0006	 16838	 16838	 16838	 0.0	 0.0	 1	 -30.0	 30.0;
	5577	 4023	 0.077097	 0.213656	 0.0024	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 4024	 0.084152	 0.241119	 0.0026	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 4024	 0.0839	 0.241119	 0.0027	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 4026	 0.056992	 0.23167	 0.0042	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 4027	 0.001817	 0.012089	 0.0223	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 4030	 0.037339	 0.123054	 0.0015	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 4030	 0.000504	 0.00126	 0.0	 22412	 22412	 22412	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 4030	 0.037339	 0.123054	 0.0015	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 4030	 0.000504	 0.00126	 0.0	 22412	 22412	 22412	 0.0	 0.0	 1	 -30.0	 30.0;
	4686	 4031	 0.013827	 0.075309	 0.0042	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 4033	 0.000123	 0.001235	 0.0005	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 4036	 0.007785	 0.032955	 0.0036	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 4037	 5.9e-05	 0.000403	 0.001	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 4040	 0.000316	 0.001936	 0.2551	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 4041	 0.146611	 0.40005	 0.0062	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 4042	 0.000221	 0.001357	 0.1974	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 4043	 0.003818	 0.024421	 0.1136	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5714	 4044	 8.6e-05	 0.001235	 0.0	 23993	 23993	 23993	 0.0	 0.0	 1	 -30.0	 30.0;
	4378	 4045	 0.003457	 0.007901	 0.0	 3027	 3027	 3027	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 4045	 0.000335	 0.000613	 0.0	 37370	 37370	 37370	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 4046	 0.00162	 0.009284	 0.0162	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 4047	 0.001956	 0.009146	 0.0152	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 4048	 0.001837	 0.008988	 0.0203	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 4048	 0.000672	 0.004543	 0.0167	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 4049	 0.000242	 0.002735	 0.0549	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 4050	 0.003951	 0.016296	 0.0008	 1772	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 4059	 0.131519	 0.333585	 0.0038	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 4062	 0.000237	 0.000494	 0.0294	 56492	 56492	 56492	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 4063	 0.041068	 0.098765	 0.001	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 4063	 0.004535	 0.010078	 0.0	 2729	 2729	 2729	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 4063	 0.003779	 0.010582	 0.0	 2683	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 4065	 0.027715	 0.075838	 0.0009	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	5069	 4069	 0.096825	 0.303855	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	4605	 4070	 0.016881	 0.036684	 0.0005	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 4070	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4229	 4074	 0.052658	 0.133283	 0.0015	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	4228	 4074	 0.05291	 0.134543	 0.0015	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 4075	 0.022099	 0.056296	 0.0026	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 4078	 0.000316	 0.001132	 0.1529	 297.0	 297.0	 297.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 4078	 0.000316	 0.001132	 0.1529	 297.0	 297.0	 297.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 4078	 0.000563	 0.003372	 0.0116	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 4078	 0.000211	 0.002058	 0.0111	 789.0	 789.0	 789.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4232	 4080	 0.095112	 0.255404	 0.0092	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4377	 4080	 0.061779	 0.156085	 0.02	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 4086	 0.000252	 0.125976	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 4086	 0.000252	 0.125976	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 4087	 0.019652	 0.043588	 0.0005	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	5718	 4090	 0.001235	 0.003333	 0.0002	 8357	 8357	 8357	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 4092	 0.017637	 0.048375	 0.0006	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 4092	 2.5e-05	 0.000252	 0.0	 116592	 116592	 116592	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 4097	 0.036936	 0.093651	 0.001	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 4098	 0.030988	 0.082716	 0.0039	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 4099	 0.066516	 0.16906	 0.0019	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 4101	 0.026707	 0.095994	 0.0264	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 4101	 0.012346	 0.041572	 0.0005	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 4101	 0.016377	 0.042076	 0.0005	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	4654	 4105	 0.002746	 0.018746	 0.0329	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4105	 0.003002	 0.015052	 0.0268	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 4106	 0.002043	 0.022929	 0.4592	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 4106	 0.000776	 0.008497	 0.1805	 1659.0	 1659.0	 1659.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 4107	 0.018896	 0.120433	 0.0014	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 4109	 0.034815	 0.086914	 0.004	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 4112	 0.037541	 0.092467	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 4113	 0.013333	 0.033951	 0.0016	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 4114	 0.036533	 0.092719	 0.001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 4114	 0.010834	 0.030234	 0.0004	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 4116	 0.000512	 0.000938	 0.0	 28461	 28461	 28461	 0.0	 0.0	 1	 -30.0	 30.0;
	4337	 4118	 0.016125	 0.100277	 0.0013	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 4118	 0.010078	 0.06198	 0.0008	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 4120	 0.047115	 0.198287	 0.0024	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 4122	 1e-05	 0.0001	 0.0029	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 4129	 0.036785	 0.118922	 0.001	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	4245	 4131	 0.046863	 0.11867	 0.0013	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 4133	 0.003121	 0.014183	 0.0243	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 4138	 0.113379	 0.253968	 0.0028	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4543	 4139	 0.056437	 0.156966	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 4141	 0.01716	 0.046296	 0.0023	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 4141	 0.044444	 0.115309	 0.0055	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 4141	 0.026543	 0.067531	 0.0032	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 4140	 0.00242	 0.00658	 0.0003	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 4143	 0.059461	 0.146384	 0.0028	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 4143	 0.0451	 0.153187	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 4144	 0.003099	 0.020113	 0.0385	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 4144	 0.002528	 0.016672	 0.0304	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 4145	 0.001605	 0.003333	 0.0017	 8030	 8030	 8030	 0.0	 0.0	 1	 -30.0	 30.0;
	4854	 4146	 0.020962	 0.053162	 0.0006	 533	 533	 533	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 4148	 0.022928	 0.142857	 0.003	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	5796	 4148	 0.011086	 0.047871	 0.001	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 4149	 0.001679	 0.011397	 0.0223	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 4152	 0.000252	 0.00252	 0.0001	 13354	 13354	 13354	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 4153	 0.013152	 0.03487	 0.0021	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 4155	 0.063744	 0.176367	 0.0002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 4155	 0.063492	 0.173847	 0.0031	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 4156	 0.036029	 0.092467	 0.001	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 4156	 0.124717	 0.316201	 0.0036	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 4157	 0.00077	 0.001659	 0.2106	 16924	 16924	 16924	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 4160	 0.01159	 0.031494	 0.0003	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 4163	 0.004157	 0.012094	 0.0002	 2379	 2379	 2379	 0.0	 0.0	 1	 -30.0	 30.0;
	4700	 4164	 0.021482	 0.058148	 0.0028	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 4164	 0.031358	 0.131975	 0.0068	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	5731	 4166	 0.001764	 0.005039	 0.0001	 5531	 5531	 5531	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 4167	 0.014613	 0.07231	 0.0005	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 4168	 0.000227	 0.000605	 0.0	 47067	 47067	 47067	 0.0	 0.0	 1	 -30.0	 30.0;
	4321	 4170	 0.034321	 0.083827	 0.0039	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 4170	 0.030988	 0.064074	 0.003	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 4170	 0.003951	 0.025185	 0.0013	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	4321	 4170	 0.006173	 0.025679	 0.1053	 1125	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 4170	 0.024815	 0.064691	 0.0031	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 4172	 0.006299	 0.026808	 0.0003	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 4172	 0.006299	 0.013605	 0.0002	 2029	 2029	 2029	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 4174	 0.000494	 0.001728	 0.0002	 16527	 16527	 16527	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 4174	 0.004691	 0.015803	 0.0008	 1802	 1802	 1802	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 4177	 0.03963	 0.103951	 0.005	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	4671	 4178	 0.015309	 0.03963	 0.0019	 700	 700	 700	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 4181	 0.037037	 0.099773	 0.0012	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 4181	 0.014109	 0.036029	 0.0004	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	5632	 4181	 0.051398	 0.145629	 0.0033	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 4182	 0.005628	 0.038669	 0.0729	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 4183	 0.138322	 0.372386	 0.0048	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 4184	 0.007307	 0.030335	 0.0018	 967	 967	 967	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 4184	 0.000252	 0.00252	 0.0005	 11909	 11909	 11909	 0.0	 0.0	 1	 -30.0	 30.0;
	4186	 4185	 0.004535	 0.013605	 0.0051	 2059	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 4185	 0.020156	 0.087176	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 4189	 0.050894	 0.138574	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5755	 4190	 0.021416	 0.058453	 0.0006	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 4191	 0.049635	 0.135299	 0.0041	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 4194	 0.067654	 0.145679	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 4194	 0.03716	 0.100247	 0.0049	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 4195	 0.000652	 0.001244	 0.1833	 22038	 22038	 22038	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 4199	 0.026296	 0.066296	 0.012	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 4201	 0.009753	 0.019506	 0.0008	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 4200	 0.009753	 0.019506	 0.0008	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 4203	 0.003731	 0.006829	 0.0	 3795	 3795	 3795	 0.0	 0.0	 1	 -30.0	 30.0;
	4580	 4207	 0.008818	 0.018141	 0.0254	 1421	 1421	 1421	 0.0	 0.0	 1	 -30.0	 30.0;
	4880	 4207	 0.018317	 0.059486	 0.0256	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 4207	 0.014361	 0.044344	 0.014	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 4209	 0.00083	 0.002588	 0.32	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 4208	 0.000395	 0.002291	 0.0182	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 4208	 0.001659	 0.011062	 0.0203	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 4211	 0.009956	 0.035773	 0.0572	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 4211	 0.002102	 0.008286	 0.0142	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 4211	 0.001185	 0.008	 0.0152	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5588	 4212	 0.000252	 0.00252	 0.0003	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	4474	 4217	 0.003117	 0.005706	 0.0028	 4678	 4678	 4678	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 4217	 0.004031	 0.009574	 0.01	 2928	 2928	 2928	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 4216	 0.013354	 0.033258	 0.0004	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 4217	 0.005217	 0.00955	 0.0093	 2795	 2795	 2795	 0.0	 0.0	 1	 -30.0	 30.0;
	4499	 4216	 0.004975	 0.009106	 0.0087	 2932	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 4218	 0.00371	 0.01789	 0.0359	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 4218	 0.001428	 0.019629	 0.0754	 638.0	 638.0	 638.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 4218	 0.001244	 0.016316	 0.0699	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 4218	 0.006728	 0.030596	 0.0587	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 4219	 0.000471	 0.006184	 0.2368	 954.0	 954.0	 954.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 4220	 0.021926	 0.055062	 0.0002	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 4220	 0.019753	 0.05037	 0.0	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 4226	 0.010494	 0.045185	 0.0021	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	5372	 4225	 0.010494	 0.02679	 0.0013	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 4230	 0.016503	 0.044394	 0.0027	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 4234	 0.089695	 0.171832	 0.0018	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 4235	 0.014815	 0.04037	 0.0019	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 4239	 3.7e-05	 0.000148	 0.0002	 194699	 194699	 194699	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 4241	 0.006299	 0.015621	 0.0202	 1753	 1753	 1753	 0.0	 0.0	 1	 -30.0	 30.0;
	4900	 4242	 0.059012	 0.159259	 0.0075	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 4242	 0.021852	 0.058765	 0.0029	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 4242	 0.040494	 0.102963	 0.0047	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 4246	 0.019652	 0.083648	 0.001	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 4248	 0.036029	 0.093222	 0.0011	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 4247	 0.008566	 0.023432	 0.0002	 1184	 1184	 1184	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 4270	 0.008062	 0.022172	 0.0002	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 4249	 0.067523	 0.184177	 0.0021	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	4836	 4250	 0.05417	 0.137314	 0.0019	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	4892	 4250	 0.03351	 0.113631	 0.0013	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 4251	 0.006084	 0.023072	 0.24	 282.0	 282.0	 282.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 4252	 0.006198	 0.011346	 0.0088	 2353	 2353	 2353	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 4255	 0.051524	 0.124313	 0.003	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	5411	 4255	 0.046863	 0.109851	 0.0012	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 4256	 0.004454	 0.01571	 0.0253	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 4257	 0.057697	 0.158982	 0.0021	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 4257	 0.014025	 0.025673	 0.0	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	4824	 4258	 0.032754	 0.083396	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 4260	 0.032502	 0.088939	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 4260	 0.053162	 0.145377	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 4261	 0.009012	 0.023457	 0.001	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 4264	 0.021668	 0.066516	 0.0013	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 4263	 0.020912	 0.063996	 0.0013	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 4267	 0.002877	 0.007284	 0.0003	 3793	 3793	 3793	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 4269	 0.000375	 0.001679	 0.003	 17958	 17958	 17958	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 4271	 0.097048	 0.177645	 0.0018	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 4272	 0.029907	 0.101512	 0.0016	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 4273	 0.001512	 0.004787	 0.0045	 5882	 5882	 5882	 0.0	 0.0	 1	 -30.0	 30.0;
	5695	 4276	 0.019867	 0.059067	 0.0189	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 4281	 0.018796	 0.037365	 0.0178	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 4286	 2.8e-05	 0.000409	 0.0116	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 4285	 2.8e-05	 0.000422	 0.0116	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 4287	 0.029982	 0.075838	 0.0	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	5378	 4289	 0.005795	 0.019652	 0.0002	 1485	 1485	 1485	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 4289	 0.04384	 0.108592	 0.0018	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 4291	 0.010667	 0.052109	 0.0901	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 4294	 0.003931	 0.026686	 0.0506	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 4295	 0.011565	 0.029453	 0.0031	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 4296	 0.008395	 0.022963	 0.0011	 1241	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	4287	 4299	 0.002268	 0.006803	 0.0005	 4118	 4118	 4118	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 4300	 0.000882	 0.002973	 0.0	 9521	 9521	 9521	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 4301	 0.109851	 0.269841	 0.003	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 4301	 0.049887	 0.166767	 0.0019	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5751	 4302	 0.008012	 0.019678	 0.0013	 1432	 1432	 1432	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 4307	 0.007811	 0.019904	 0.0002	 1423	 1423	 1423	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 4307	 0.055682	 0.141345	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5537	 4306	 0.055933	 0.141849	 0.0016	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4309	 4308	 0.017385	 0.039053	 0.004	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	5393	 4310	 0.001111	 0.002963	 0.0002	 9387	 9387	 9387	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 4313	 0.027901	 0.118272	 0.0058	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 4319	 0.010247	 0.032716	 0.0016	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	5540	 4323	 0.024943	 0.053918	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 4323	 0.057445	 0.124465	 0.001	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 4327	 0.022172	 0.057697	 0.001	 478	 478	 478	 0.0	 0.0	 1	 -30.0	 30.0;
	4624	 4330	 0.01285	 0.053968	 0.0006	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 4329	 0.06707	 0.182137	 0.0028	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5347	 4329	 0.011842	 0.039053	 0.0006	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 4329	 0.014059	 0.037868	 0.0005	 753	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 4330	 0.020081	 0.087226	 0.001	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 4330	 0.021416	 0.056689	 0.0006	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 4330	 0.006551	 0.027967	 0.0003	 1059	 1059	 1059	 0.0	 0.0	 1	 -30.0	 30.0;
	5734	 4330	 0.006299	 0.026455	 0.0003	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 4331	 0.000415	 0.002785	 0.0051	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 4332	 0.001225	 0.005981	 0.0111	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 4331	 0.002133	 0.014289	 0.0263	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5375	 4332	 0.000474	 0.003149	 0.0061	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 4333	 0.04772	 0.162081	 0.0019	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4555	 4342	 0.007811	 0.015873	 0.01	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	4553	 4342	 0.007307	 0.0193	 0.0173	 1431	 1431	 1431	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 4343	 0.000644	 0.002929	 0.0051	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4773	 4344	 0.010494	 0.026667	 0.0171	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 4345	 0.013102	 0.025951	 0.0002	 1047	 1047	 1047	 0.0	 0.0	 1	 -30.0	 30.0;
	4899	 4346	 0.115646	 0.315445	 0.0036	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	5078	 4346	 0.007559	 0.023935	 0.0012	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	5078	 4346	 0.007559	 0.023935	 0.0012	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 4347	 0.000849	 0.005728	 0.0101	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 4347	 0.000849	 0.005728	 0.0101	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 4347	 0.000435	 0.002963	 0.0208	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 4348	 0.024198	 0.045679	 0.0021	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 4349	 0.009322	 0.023935	 0.0	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 4349	 0.032502	 0.084152	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 4349	 0.037541	 0.089695	 0.001	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 4352	 0.001764	 0.004283	 0.0001	 6566	 6566	 6566	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 4352	 0.076594	 0.184681	 0.0017	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5380	 4354	 0.000741	 0.002099	 0.0002	 13344	 13344	 13344	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 4355	 5.9e-05	 0.000336	 0.001	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4588	 4357	 0.049887	 0.102293	 0.0011	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 4357	 0.046611	 0.118166	 0.0013	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5228	 4357	 0.069539	 0.191232	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 4359	 0.043034	 0.117309	 0.0053	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 4359	 0.043411	 0.118418	 0.0013	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4441	 4360	 0.057697	 0.120685	 0.0013	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 4361	 0.042328	 0.167297	 0.0021	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 4363	 0.030988	 0.078765	 0.0037	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 4363	 0.020123	 0.050988	 0.0024	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 4364	 0.011086	 0.045352	 0.0043	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 4364	 0.011086	 0.045603	 0.0044	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 4368	 0.084404	 0.214664	 0.0025	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 4369	 0.046863	 0.158982	 0.002	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 4369	 0.012094	 0.033006	 0.0	 840	 840	 840	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 4370	 0.020864	 0.054691	 0.0026	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	4491	 4373	 0.105316	 0.287226	 0.0033	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 4374	 0.001008	 0.002771	 0.0001	 10315	 10315	 10315	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 4376	 0.062988	 0.17158	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 4379	 0.018099	 0.045877	 0.0021	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 4380	 0.070043	 0.177375	 0.002	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 4383	 0.021111	 0.042346	 0.0018	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 4384	 0.03477	 0.064752	 0.0006	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 4389	 0.003927	 0.026153	 0.0486	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 4391	 0.013102	 0.03477	 0.0004	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 4394	 0.03879	 0.102605	 0.0049	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 4398	 0.002035	 0.014025	 0.0263	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4728	 4399	 0.000237	 0.00083	 0.1843	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 4401	 0.051902	 0.118922	 0.0013	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 4402	 0.08642	 0.222222	 0.0	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 4404	 0.000277	 0.001285	 0.0015	 23137	 23137	 23137	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 4406	 0.00037	 0.000988	 0.0002	 30291	 30291	 30291	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 4411	 0.002394	 0.014865	 0.0002	 1961	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 4415	 0.000756	 0.001512	 0.0	 17466	 17466	 17466	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 4417	 0.000151	 0.000428	 0.0	 65055	 65055	 65055	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 4419	 0.000454	 0.002114	 0.0061	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 4418	 0.000454	 0.002114	 0.004	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5012	 4424	 0.069791	 0.171328	 0.0023	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	4999	 4426	 0.103301	 0.241371	 0.003	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 4426	 0.068178	 0.17357	 0.0021	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 4427	 0.007099	 0.017988	 0.0008	 1536	 1536	 1536	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 4429	 0.013481	 0.024677	 0.0002	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	5772	 4430	 0.002771	 0.007055	 0.0001	 3780	 3780	 3780	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 4432	 0.027642	 0.093889	 0.0046	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 4434	 0.014613	 0.049383	 0.001	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 4434	 0.041572	 0.101789	 0.002	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 4434	 0.015873	 0.050643	 0.001	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 4435	 0.054343	 0.099474	 0.001	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 4437	 0.028471	 0.104308	 0.0458	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 4437	 0.085916	 0.17745	 0.0023	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 4438	 0.004031	 0.01033	 0.0001	 2743	 2743	 2743	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 4441	 0.053666	 0.303603	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 4441	 0.053918	 0.303855	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	4758	 4442	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 4442	 0.03933	 0.101789	 0.0025	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	4759	 4442	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 4444	 0.002627	 0.017778	 0.0334	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5276	 4449	 0.006047	 0.025195	 0.0	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 4452	 0.094986	 0.266566	 0.0	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 4455	 0.063265	 0.13613	 0.0015	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 4455	 0.011842	 0.033006	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	5782	 4457	 0.001462	 0.010114	 0.0182	 442.0	 442.0	 442.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4931	 4458	 0.01033	 0.037541	 0.0005	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 4459	 0.006667	 0.012346	 0.0225	 2162	 2162	 2162	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 4460	 0.075334	 0.198639	 0.0041	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 4460	 0.070295	 0.145377	 0.0016	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 4460	 0.042832	 0.10834	 0.0013	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	5751	 4462	 0.061602	 0.156135	 0.0017	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 4463	 0.001008	 0.002016	 0.0	 13494	 13494	 13494	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 4464	 0.006173	 0.025145	 0.0018	 1141	 1141	 1141	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 4465	 0.022676	 0.095994	 0.001	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 4464	 0.044344	 0.189216	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	5151	 4465	 0.048123	 0.206349	 0.003	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 4467	 0.002749	 0.039259	 1.1855	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 4471	 0.014321	 0.040617	 0.0	 705	 705	 705	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 4473	 0.001512	 0.003275	 0.0001	 8432	 8432	 8432	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 4475	 0.058705	 0.159738	 0.0018	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4778	 4477	 0.008314	 0.022424	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 4483	 2.5e-05	 0.015117	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 4487	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 4486	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 4485	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 4484	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 4491	 0.142605	 0.361804	 0.0041	 78	 78	 78	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 4491	 0.120685	 0.404888	 0.0046	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 4493	 0.006758	 0.01237	 0.0087	 2033	 2033	 2033	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 4495	 0.000454	 0.001209	 0.0013	 23415	 23415	 23415	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 4503	 0.006533	 0.022267	 0.0072	 1313	 1313	 1313	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 4503	 0.017067	 0.058356	 0.0193	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 4505	 0.100277	 0.301839	 0.004	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 4509	 0.043333	 0.092099	 0.0042	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4809	 4513	 0.027531	 0.074074	 0.0036	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 4513	 0.031111	 0.084074	 0.004	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 4514	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5782	 4515	 1.4e-05	 9.9e-05	 0.0002	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 4516	 0.033006	 0.204838	 0.0073	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 4516	 0.039305	 0.100529	 0.0011	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 4516	 0.005669	 0.036206	 0.0087	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 4517	 0.002807	 0.014445	 0.0259	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5489	 4521	 0.046914	 0.119012	 0.0055	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 4522	 0.007432	 0.025235	 0.0013	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	5784	 4523	 0.007055	 0.013102	 0.0001	 2280	 2280	 2280	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 4526	 0.114059	 0.346964	 0.004	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 4528	 0.006933	 0.033403	 0.0607	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5785	 4530	 0.004435	 0.008118	 0.0001	 3667	 3667	 3667	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 4531	 0.012346	 0.04384	 0.0006	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 4531	 0.013354	 0.0451	 0.0006	 647	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 4533	 0.046359	 0.117662	 0.0013	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 4534	 0.001383	 0.009343	 0.0172	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 4534	 0.001027	 0.006815	 0.0121	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4836	 4536	 0.014361	 0.039053	 0.0005	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	4892	 4536	 0.012346	 0.03351	 0.0004	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 4541	 0.007307	 0.030738	 0.0019	 907	 907	 907	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 4543	 0.000995	 0.001821	 0.001	 14657	 14657	 14657	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 4544	 0.041481	 0.100494	 0.0047	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 4545	 5.9e-05	 0.000296	 0.0	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 4546	 0.000504	 0.001764	 0.0014	 16578	 16578	 16578	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 4546	 0.000756	 0.001764	 0.0017	 15848	 15848	 15848	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 4549	 0.006047	 0.024691	 0.0003	 1162	 1162	 1162	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 4551	 0.00141	 0.020003	 0.4967	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 4551	 0.00141	 0.02	 0.4967	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 4556	 0.000988	 0.001852	 0.0	 14447	 14447	 14447	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 4558	 0.019778	 0.053943	 0.0006	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 4558	 0.004787	 0.021416	 0.0002	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 4558	 0.012396	 0.033837	 0.0004	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	5824	 4558	 0.011414	 0.031166	 0.0004	 917	 917	 917	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 4560	 0.006696	 0.028583	 0.0496	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5611	 4572	 0.000827	 0.003815	 0.0661	 279.0	 279.0	 279.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4597	 4573	 0.000194	 0.00255	 0.0895	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 4573	 0.000194	 0.00255	 0.0895	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4932	 4576	 0.005709	 0.036049	 0.0881	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4932	 4576	 0.005748	 0.036247	 0.0997	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 4577	 0.000893	 0.008663	 0.2253	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5822	 4577	 0.001707	 0.022772	 0.7812	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 4577	 0.000893	 0.008663	 0.2253	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 4577	 0.00117	 0.010658	 0.2946	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 4577	 0.000409	 0.006946	 0.2513	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 4577	 0.000409	 0.006946	 0.2513	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 4582	 0.003527	 0.00907	 0.0001	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 4583	 0.01033	 0.027463	 0.0003	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	4584	 4585	 0.009574	 0.025195	 0.0003	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	4800	 4585	 0.159234	 0.297304	 0.0033	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 4585	 0.00907	 0.024691	 0.0002	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 4587	 0.016769	 0.030696	 0.0	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	4747	 4588	 0.074931	 0.154195	 0.0023	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 4589	 0.064248	 0.133283	 0.001	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 4595	 0.021728	 0.134321	 0.0075	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4664	 4597	 0.001015	 0.014744	 0.3841	 2158	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	4664	 4596	 0.001018	 0.014778	 0.3841	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	5796	 4600	 0.001008	 0.002016	 0.0	 13100	 13100	 13100	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 4604	 0.017654	 0.048148	 0.0023	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 4606	 0.00284	 0.007901	 0.0003	 3538	 3538	 3538	 0.0	 0.0	 1	 -30.0	 30.0;
	4806	 4610	 0.014613	 0.049383	 0.0025	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 4610	 0.057445	 0.156715	 0.0017	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5588	 4610	 0.014361	 0.036785	 0.0005	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 4610	 0.006299	 0.016881	 0.0002	 1639	 1639	 1639	 0.0	 0.0	 1	 -30.0	 30.0;
	5739	 4610	 0.01033	 0.042328	 0.0006	 678	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 4611	 0.008119	 0.054084	 0.1002	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5061	 4613	 0.003202	 0.00586	 0.0022	 4291	 4291	 4291	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 4613	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 4615	 0.024188	 0.060972	 0.0008	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	4870	 4617	 0.022676	 0.14714	 0.002	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 4617	 0.021164	 0.046359	 0.001	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 4617	 0.06324	 0.11615	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 4618	 0.018896	 0.078357	 0.0013	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 4618	 0.005039	 0.020912	 0.0002	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 4619	 0.001067	 0.004899	 0.0081	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 4619	 0.000119	 0.00077	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 4621	 0.03	 0.076543	 0.0039	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	4645	 4622	 0.04284	 0.112716	 0.0053	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 4628	 0.066767	 0.157344	 0.0185	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	5622	 4630	 0.039136	 0.100741	 0.0045	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 4631	 0.019652	 0.040816	 0.0005	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	5529	 4632	 0.034568	 0.090123	 0.0042	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 4633	 0.02192	 0.055178	 0.0006	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 4633	 0.00708	 0.019325	 0.0002	 1393	 1393	 1393	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 4635	 0.025447	 0.066767	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 4636	 0.001008	 0.00252	 0.0	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	4801	 4639	 0.038148	 0.102099	 0.0049	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	4669	 4646	 0.012346	 0.032593	 0.0016	 853	 853	 853	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 4649	 0.010617	 0.065679	 0.0076	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	4666	 4649	 0.008025	 0.020988	 0.001	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 4649	 0.034938	 0.069876	 0.0032	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	4666	 4649	 0.008148	 0.021235	 0.0021	 1334	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4653	 0.001244	 0.006301	 0.0111	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 4655	 0.000252	 0.00252	 0.0001	 13395	 13395	 13395	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 4658	 0.035803	 0.092469	 0.005	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4813	 4658	 0.038025	 0.099012	 0.0392	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 4661	 0.033667	 0.090667	 0.0044	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	5331	 4663	 0.000612	 0.004069	 0.0071	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4745	 4665	 0.004938	 0.013333	 0.0	 1837	 1837	 1837	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 4667	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 4676	 0.053666	 0.098262	 0.001	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 4677	 0.004464	 0.030933	 0.0547	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5260	 4679	 0.05543	 0.140842	 0.0016	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 4681	 0.030612	 0.077198	 0.0024	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 4682	 0.077601	 0.212396	 0.0024	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5814	 4685	 0.00358	 0.009877	 0.0005	 2828	 2828	 2828	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 4688	 0.061728	 0.148652	 0.0017	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 4689	 0.000252	 0.000504	 0.001	 52720	 52720	 52720	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 4696	 4e-05	 0.000968	 0.003	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 4701	 0.009826	 0.025447	 0.0002	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 4703	 2e-05	 0.000198	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 4704	 2e-05	 0.000198	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 4712	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 4715	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 4718	 0.001008	 0.00252	 0.0	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 4721	 0.03225	 0.087931	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 4721	 0.015369	 0.095339	 0.0012	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 4721	 0.033762	 0.140086	 0.0017	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 4727	 0.010741	 0.028025	 0.0013	 1011	 1011	 1011	 0.0	 0.0	 1	 -30.0	 30.0;
	5821	 4729	 0.003527	 0.00907	 0.0001	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 4730	 0.002016	 0.013354	 0.0002	 2122	 2122	 2122	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 4732	 0.010815	 0.050299	 0.0876	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 4734	 1.2e-05	 0.000123	 0.0002	 245373	 245373	 245373	 0.0	 0.0	 1	 -30.0	 30.0;
	5832	 4741	 0.001512	 0.007307	 0.0	 3957	 3957	 3957	 0.0	 0.0	 1	 -30.0	 30.0;
	5522	 4744	 0.002509	 0.015921	 0.0294	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 4747	 0.065256	 0.165457	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 4747	 0.046863	 0.100277	 0.0011	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 4750	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	4931	 4761	 0.169312	 0.378181	 0.0044	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 4761	 0.070295	 0.177879	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4979	 4764	 0.000316	 0.001971	 0.0273	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 4763	 0.000245	 0.00302	 0.0061	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 4766	 0.078609	 0.2129	 0.0024	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5628	 4776	 0.016677	 0.030527	 0.0003	 875	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 4779	 0.009574	 0.024943	 0.001	 1106	 1106	 1106	 0.0	 0.0	 1	 -30.0	 30.0;
	4809	 4781	 0.010494	 0.028272	 0.0013	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 4782	 0.000356	 0.00241	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 4783	 0.048879	 0.12648	 0.0014	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5670	 4783	 0.073066	 0.187957	 0.0021	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 4784	 0.000375	 0.004741	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5176	 4785	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 4786	 0.000171	 0.000313	 0.0001	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 4788	 0.060494	 0.158889	 0.0073	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 4790	 0.080877	 0.209373	 0.0023	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	4813	 4792	 0.047284	 0.164691	 0.0083	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 4792	 0.001358	 0.003333	 0.0002	 8426	 8426	 8426	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 4794	 0.052028	 0.131872	 0.0017	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 4798	 0.004787	 0.010078	 0.0001	 2647	 2647	 2647	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 4800	 0.042479	 0.09035	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 4802	 0.008818	 0.035777	 0.0005	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 4802	 0.008818	 0.035777	 0.0005	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 4803	 0.145805	 0.502746	 0.0056	 59	 59	 59	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 4805	 0.014361	 0.048879	 0.001	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 4806	 0.008314	 0.032502	 0.0023	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 4808	 0.009801	 0.041144	 0.0005	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 4810	 0.001728	 0.004815	 0.0002	 5807	 5807	 5807	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 4810	 0.019753	 0.053333	 0.0026	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	5300	 4814	 0.070547	 0.17284	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 4815	 0.045679	 0.115802	 0.0055	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 4832	 0.018272	 0.076667	 0.0062	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 4832	 0.00642	 0.04321	 0.0034	 695	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 4832	 0.026667	 0.082222	 0.0039	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	5500	 4832	 0.009259	 0.024568	 0.001	 1155	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 4834	 0.002825	 0.012998	 0.0299	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 4840	 0.004283	 0.010834	 0.002	 2535	 2535	 2535	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 4840	 0.001764	 0.007559	 0.0114	 3804	 3804	 3804	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 4842	 0.029982	 0.076594	 0.0009	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 4844	 0.155732	 0.364676	 0.004	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 4848	 0.011086	 0.024943	 0.0003	 1089	 1089	 1089	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 4849	 0.001481	 0.006696	 0.0111	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 4850	 0.032222	 0.135679	 0.0084	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 4850	 0.021852	 0.055309	 0.0026	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 4850	 0.032222	 0.135062	 0.0083	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 4851	 0.016914	 0.045556	 0.0023	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 4855	 0.120937	 0.267322	 0.003	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	4856	 4857	 0.001184	 0.002167	 0.0003	 10572	 10572	 10572	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 4857	 0.036049	 0.098272	 0.0012	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 4857	 0.064198	 0.139753	 0.0012	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 4865	 0.000561	 0.005658	 0.1444	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4972	 4865	 0.000561	 0.005665	 0.1473	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 4867	 0.046611	 0.099521	 0.0011	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 4869	 0.03477	 0.081381	 0.001	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 4869	 0.017637	 0.039305	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	5832	 4872	 0.000604	 0.001106	 0.0007	 23430	 23430	 23430	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 4877	 0.05039	 0.127715	 0.0014	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 4878	 0.05039	 0.132023	 0.0015	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 4879	 0.005442	 0.023003	 0.0003	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 4883	 0.034014	 0.072814	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 4884	 0.001501	 0.010023	 0.0182	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 4889	 0.002029	 0.013533	 0.025	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 4890	 0.000693	 0.007389	 0.1617	 1704.0	 1704.0	 1704.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 4902	 0.000252	 0.000504	 0.0021	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5628	 4905	 0.176619	 0.324767	 0.0035	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 4906	 0.010864	 0.050469	 0.0845	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 4909	 0.000123	 0.001235	 0.0	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 4910	 0.003457	 0.009383	 0.0005	 3033	 3033	 3033	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 4911	 0.078105	 0.19098	 0.0019	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 4912	 0.001719	 0.011457	 0.0213	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 4912	 0.00079	 0.00798	 0.0284	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5375	 4912	 0.001434	 0.009559	 0.0172	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 4920	 0.027211	 0.068531	 0.0029	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 4920	 0.053893	 0.336558	 0.0056	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 4922	 0.004186	 0.02786	 0.0516	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 4922	 0.002173	 0.014242	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5496	 4922	 0.004109	 0.027417	 0.0486	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 4922	 0.001106	 0.007407	 0.0132	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5704	 4931	 0.010582	 0.04384	 0.0006	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 4931	 0.047871	 0.201058	 0.0068	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 4931	 0.026455	 0.109095	 0.0013	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	4934	 4933	 0.000504	 0.00252	 0.0001	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5838	 4936	 2.5e-05	 0.000252	 0.0	 116592	 116592	 116592	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 4948	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 4951	 0.000988	 0.002469	 0.0	 9817	 9817	 9817	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 4952	 0.000247	 0.003489	 0.0462	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 4957	 0.01159	 0.029479	 0.0	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 4959	 0.011358	 0.034938	 0.0016	 826	 826	 826	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 4959	 0.004074	 0.017407	 0.0026	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 4959	 0.021111	 0.054568	 0.0024	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 4961	 0.00083	 0.007052	 0.0724	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 4960	 0.000731	 0.003121	 0.0051	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 4961	 0.001025	 0.006888	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 4961	 0.000553	 0.003595	 0.0071	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 4961	 0.000533	 0.003575	 0.0061	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 4961	 0.000849	 0.00796	 0.0284	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 4960	 0.000731	 0.003121	 0.0051	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 4960	 0.000849	 0.008237	 0.0284	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 4960	 0.000375	 0.003733	 0.0121	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 4964	 0.023086	 0.062346	 0.0031	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 4965	 0.004109	 0.027911	 0.0516	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 4966	 0.018395	 0.050247	 0.0023	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	5455	 4966	 0.024568	 0.064691	 0.0031	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 4967	 0.055178	 0.150416	 0.0017	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	5841	 4968	 0.005795	 0.011842	 0.0002	 2174	 2174	 2174	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 4970	 0.007284	 0.019383	 0.001	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 4970	 0.007407	 0.019506	 0.001	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 4973	 0.017561	 0.072436	 0.0009	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 4974	 0.030234	 0.078105	 0.0092	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	5842	 4975	 0.000756	 0.00252	 0.0001	 12855	 12855	 12855	 0.0	 0.0	 1	 -30.0	 30.0;
	5841	 4976	 0.086168	 0.179138	 0.0019	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5127	 4979	 0.001916	 0.009323	 0.0223	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5592	 4979	 0.000514	 0.004859	 0.0182	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 4979	 0.002212	 0.010114	 0.0233	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 4979	 0.000948	 0.004602	 0.0081	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 4978	 0.000909	 0.004385	 0.0081	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5166	 4982	 0.022469	 0.061358	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 4986	 0.013354	 0.03477	 0.0	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 4992	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 4991	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 4990	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 4997	 0.083346	 0.172487	 0.0018	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 4997	 0.028597	 0.075712	 0.001	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 5003	 0.004258	 0.011338	 0.0029	 2438	 2438	 2438	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 5005	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 5006	 0.006551	 0.043084	 0.001	 678	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 5006	 0.006803	 0.017637	 0.0	 1562	 1562	 1562	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 5006	 0.003023	 0.020156	 0.0	 1449	 1449	 1449	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 5008	 0.077118	 0.141163	 0.001	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 5008	 0.012245	 0.032527	 0.0004	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 5010	 0.034845	 0.116528	 0.0013	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 5011	 0.057447	 0.105156	 0.0011	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 5012	 0.015621	 0.066767	 0.0008	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 5016	 0.009012	 0.017975	 0.0008	 1478	 1478	 1478	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 5019	 0.003779	 0.009322	 0.0001	 3024	 3024	 3024	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 5019	 0.004031	 0.009826	 0.0001	 2864	 2864	 2864	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 5023	 0.056437	 0.116049	 0.0012	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 5024	 0.028975	 0.096498	 0.0011	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 5030	 0.001481	 0.002716	 0.0002	 9602	 9602	 9602	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 5032	 0.017889	 0.048879	 0.0006	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 5033	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 5036	 0.089191	 0.183422	 0.002	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 5037	 0.001008	 0.003023	 0.0016	 8991	 8991	 8991	 0.0	 0.0	 1	 -30.0	 30.0;
	5092	 5039	 0.020741	 0.054444	 0.0026	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 5041	 0.015369	 0.044848	 0.0061	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 5042	 0.040161	 0.101815	 0.0048	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 5048	 0.000988	 0.001975	 0.0002	 13450	 13450	 13450	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 5053	 0.009826	 0.032578	 0.0038	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 5053	 0.037339	 0.126455	 0.0048	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5523	 5057	 0.016629	 0.046107	 0.0006	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 5066	 0.001127	 0.014433	 0.3408	 2203	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	5850	 5077	 0.000217	 0.000988	 0.002	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 5079	 0.055169	 0.100986	 0.001	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5343	 5081	 0.033827	 0.084444	 0.0049	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 5081	 0.016049	 0.048765	 0.0048	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 5087	 0.03043	 0.055702	 0.0023	 478	 478	 478	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 5091	 2.5e-05	 0.001235	 0.0	 24046	 24046	 24046	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 5096	 0.021164	 0.054674	 0.0006	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 5109	 0.015394	 0.030008	 0.0003	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 5109	 0.036861	 0.075762	 0.0008	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 5117	 0.025185	 0.08	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	5584	 5122	 0.002756	 0.007867	 0.0022	 3790	 3790	 3790	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 5130	 0.006299	 0.025472	 0.0173	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 5136	 0.067523	 0.166289	 0.0017	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	5606	 5137	 0.00126	 0.004787	 0.0001	 5965	 5965	 5965	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 5168	 0.048879	 0.117158	 0.0012	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 5176	 0.083144	 0.200756	 0.0019	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 5202	 0.009383	 0.024938	 0.0013	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 5210	 0.021416	 0.048879	 0.0006	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	5500	 5216	 0.002963	 0.008025	 0.0003	 3545	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 5217	 0.065004	 0.15747	 0.0016	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 5224	 0.031746	 0.083648	 0.001	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 5225	 0.000101	 0.00252	 0.0	 11707	 11707	 11707	 0.0	 0.0	 1	 -30.0	 30.0;
	5467	 5272	 0.000356	 0.00241	 0.004	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 5281	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 5299	 0.015803	 0.035679	 0.0016	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 5360	 0.03284	 0.089753	 0.0042	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 5364	 0.015369	 0.039808	 0.0005	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 5380	 0.012469	 0.031605	 0.0015	 875	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	5612	 5398	 0.003527	 0.022928	 0.0	 1273	 1273	 1273	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 5413	 0.004444	 0.012222	 0.0006	 2284	 2284	 2284	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 5421	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 5434	 0.002771	 0.008314	 0.0001	 3270	 3270	 3270	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 5694	 0.131796	 0.441093	 0.0047	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 5477	 0.007559	 0.018896	 0.0002	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	5585	 5479	 0.004031	 0.016125	 0.0002	 2052	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 5490	 0.042026	 0.178735	 0.0022	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 5498	 0.040383	 0.110198	 0.0053	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 5510	 0.015923	 0.067372	 0.0008	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	5669	 5510	 0.006198	 0.021819	 0.0112	 1284	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	5785	 5511	 0.00252	 0.004787	 0.0001	 6303	 6303	 6303	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 5524	 0.043739	 0.10582	 0.001	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 5527	 0.037541	 0.082389	 0.0009	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 5544	 0.009322	 0.031494	 0.0004	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	5575	 5635	 0.163559	 0.299393	 0.003	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	5601	 5603	 0.014613	 0.029226	 0.0003	 931	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	5613	 5611	 1.2e-05	 0.000123	 0.0002	 245373	 245373	 245373	 0.0	 0.0	 1	 -30.0	 30.0;
	5769	 5621	 0.102041	 0.22323	 0.0025	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 5643	 0.00126	 0.003023	 0.0	 9287	 9287	 9287	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 5653	 0.046107	 0.116906	 0.0013	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 5667	 0.000691	 0.004681	 0.0091	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 5682	 0.008395	 0.022716	 0.0011	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 5756	 0.030234	 0.082389	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5842	 5785	 0.00252	 0.004787	 0.0001	 6303	 6303	 6303	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 5957	 0.001087	 0.013684	 0.3523	 1474.0	 1474.0	 1474.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6066	 5957	 0.00079	 0.008375	 0.2042	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6054	 5958	 0.000402	 0.004307	 0.1022	 7982	 7982	 7982	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 5958	 0.000997	 0.011039	 0.2632	 3115	 3115	 3115	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 5959	 0.001593	 0.015104	 0.3904	 334.0	 334.0	 334.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 5959	 0.001593	 0.015104	 0.3904	 334.0	 334.0	 334.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6045	 5959	 0.000298	 0.002805	 0.0661	 12240	 12240	 12240	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 5959	 0.001094	 0.012098	 0.277	 2843	 2843	 2843	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 5959	 0.001551	 0.01509	 0.3841	 2276	 2276	 2276	 0.0	 0.0	 1	 -30.0	 30.0;
	6150	 5959	 0.001517	 0.015533	 0.3631	 2213	 2213	 2213	 0.0	 0.0	 1	 -30.0	 30.0;
	4416	 5960	 0.001457	 0.002852	 0.0121	 10754	 10754	 10754	 0.0	 0.0	 1	 -30.0	 30.0;
	140	 5961	 0.004444	 0.028249	 0.0587	 504.0	 504.0	 504.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 5961	 0.001521	 0.007467	 0.0239	 308.0	 308.0	 308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 5961	 0.001501	 0.007407	 0.024	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 5962	 0.001205	 0.011669	 0.2917	 569.0	 569.0	 569.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6154	 5962	 0.003026	 0.029875	 0.7447	 629.0	 629.0	 629.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 5962	 0.003199	 0.030803	 0.8002	 684.0	 684.0	 684.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 5962	 0.003199	 0.030803	 0.8002	 684.0	 684.0	 684.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 5962	 0.000796	 0.007798	 0.2032	 4405	 4405	 4405	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 5962	 0.000796	 0.007798	 0.2032	 4405	 4405	 4405	 0.0	 0.0	 1	 -30.0	 30.0;
	4134	 5963	 0.000644	 0.006295	 0.2022	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 5963	 0.000893	 0.009709	 0.2373	 3541	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 5963	 0.00054	 0.004979	 0.1786	 6894	 6894	 6894	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 5963	 0.00047	 0.00528	 0.1219	 6513	 6513	 6513	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 5964	 0.001562	 0.012494	 0.0213	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3140	 5964	 0.000464	 0.003712	 0.0061	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5994	 5966	 0.00204	 0.02166	 0.5788	 1587	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 5967	 0.001323	 0.016184	 0.6007	 1474.0	 1474.0	 1474.0	 0.0	 0.0	 1	 -30.0	 30.0;
	264	 5967	 0.000741	 0.009398	 0.2238	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 5967	 0.000852	 0.009017	 0.2123	 718.0	 718.0	 718.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5866	 5967	 0.00117	 0.012223	 0.3004	 701.0	 701.0	 701.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 5968	 0.008312	 0.049213	 0.0872	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 5968	 0.003747	 0.022341	 0.0429	 1525	 1525	 1525	 0.0	 0.0	 1	 -30.0	 30.0;
	6238	 5968	 0.000618	 0.002706	 0.0074	 12439	 12439	 12439	 0.0	 0.0	 1	 -30.0	 30.0;
	6054	 5969	 0.001198	 0.012597	 0.2888	 559.0	 559.0	 559.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 5969	 0.000596	 0.006004	 0.1374	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5990	 5970	 0.000286	 0.004044	 0.1418	 757.0	 757.0	 757.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 5970	 0.000152	 0.002175	 0.0741	 451.0	 451.0	 451.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 5970	 0.000538	 0.007833	 0.2593	 723.0	 723.0	 723.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6169	 5970	 0.001731	 0.01662	 0.0	 2067	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	6218	 5970	 0.00034	 0.004993	 0.1619	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6037	 5971	 0.000593	 0.070993	 0.001	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 5971	 0.000395	 0.11121	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 5971	 0.000395	 0.083751	 0.001	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 5971	 0.000592	 0.38957	 0.001	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 5972	 0.003006	 0.026904	 0.8404	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	6074	 5972	 0.001198	 0.012396	 0.2882	 283.0	 283.0	 283.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 5972	 0.001898	 0.017299	 0.5141	 717.0	 717.0	 717.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6111	 5972	 0.001219	 0.011711	 0.3408	 2933	 2933	 2933	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 5972	 0.00223	 0.022922	 0.5256	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 5974	 0.001087	 0.011378	 0.2498	 1253.0	 1253.0	 1253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4134	 5974	 0.000914	 0.010325	 0.2296	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 5973	 0.000861	 0.010961	 0.0479	 3141	 3141	 3141	 0.0	 0.0	 1	 -30.0	 30.0;
	5985	 5974	 0.001053	 0.012119	 0.2726	 2839	 2839	 2839	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 5974	 0.00147	 0.01699	 0.3812	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 5975	 0.001462	 0.010351	 0.0213	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 5975	 0.001681	 0.011068	 0.0203	 3084	 3084	 3084	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 5975	 0.002467	 0.014972	 0.0294	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 5976	 0.008435	 0.033165	 0.1033	 1009	 1009	 1009	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 5976	 0.000593	 0.003733	 0.0119	 9134	 9134	 9134	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 5977	 0.001586	 0.015422	 0.387	 672.0	 672.0	 672.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 5977	 0.000796	 0.008663	 0.2079	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6154	 5977	 0.000554	 0.005187	 0.1271	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 5977	 0.000699	 0.006801	 0.1687	 5050	 5050	 5050	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 5978	 0.001086	 0.012632	 0.2902	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 5978	 0.00183	 0.02106	 0.491	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	2666	 5979	 0.010933	 0.033333	 0.005	 977	 977	 977	 0.0	 0.0	 1	 -30.0	 30.0;
	6087	 5980	 0.002943	 0.018035	 0.0333	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 5980	 0.004998	 0.030578	 0.0553	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 5981	 0.00142	 0.014529	 0.4488	 626.0	 626.0	 626.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 5981	 0.000741	 0.007645	 0.2343	 4495	 4495	 4495	 0.0	 0.0	 1	 -30.0	 30.0;
	5992	 5982	 0.000803	 0.008906	 0.2079	 824.0	 824.0	 824.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 5982	 0.000301	 0.003384	 0.0797	 10163	 10163	 10163	 0.0	 0.0	 1	 -30.0	 30.0;
	6103	 5982	 0.000139	 0.00214	 0.0632	 765.0	 765.0	 765.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 5982	 0.000215	 0.002285	 0.0522	 15043	 15043	 15043	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 5984	 0.005899	 0.068291	 0.1799	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 5983	 0.005899	 0.067267	 0.1882	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 5984	 0.004081	 0.027771	 0.0474	 1230	 1230	 1230	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 5983	 0.004798	 0.032109	 0.0581	 1064	 1064	 1064	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 5985	 0.001553	 0.017918	 0.4069	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 5986	 0.008751	 0.040276	 0.0654	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 5986	 0.002864	 0.011378	 0.0179	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5992	 5987	 0.002249	 0.025153	 0.5805	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	6117	 5987	 0.000353	 0.003945	 0.0915	 371.0	 371.0	 371.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 5987	 0.000281	 0.003141	 0.0728	 308.0	 308.0	 308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 5987	 0.000277	 0.003137	 0.0727	 308.0	 308.0	 308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 5987	 0.000547	 0.00624	 0.1444	 5512	 5512	 5512	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 5988	 0.001648	 0.019287	 0.5958	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 5988	 0.00088	 0.00982	 0.2714	 897.0	 897.0	 897.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 5989	 0.007409	 0.028518	 0.0894	 1172	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 5989	 0.0064	 0.034193	 0.0682	 993	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	5996	 5990	 0.000435	 0.005367	 0.1219	 6412	 6412	 6412	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 5990	 0.00022	 0.00322	 0.105	 627.0	 627.0	 627.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 5990	 0.001385	 0.01108	 0.0	 770.0	 770.0	 770.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 5990	 0.000194	 0.002771	 0.0952	 796.0	 796.0	 796.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6169	 5990	 0.001385	 0.014197	 0.0	 295.0	 295.0	 295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 5991	 0.000699	 0.008116	 0.2498	 4239	 4239	 4239	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 5991	 0.00097	 0.011288	 0.3483	 3048	 3048	 3048	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 5992	 0.001098	 0.012329	 0.2859	 2790	 2790	 2790	 0.0	 0.0	 1	 -30.0	 30.0;
	6117	 5992	 0.001895	 0.021197	 0.491	 1623	 1623	 1623	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 5992	 0.002071	 0.023103	 0.5343	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 5993	 0.00031	 0.0032	 0.0783	 10739	 10739	 10739	 0.0	 0.0	 1	 -30.0	 30.0;
	5869	 5993	 0.00042	 0.00354	 0.0864	 9685	 9685	 9685	 0.0	 0.0	 1	 -30.0	 30.0;
	5868	 5993	 0.00034	 0.00361	 0.0884	 9522	 9522	 9522	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 5993	 0.00102	 0.01074	 0.2625	 281.0	 281.0	 281.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6010	 5994	 4e-05	 0.00045	 0.0113	 259.0	 259.0	 259.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6009	 5994	 4e-05	 0.00045	 0.0113	 445.0	 445.0	 445.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6066	 5994	 0.00095	 0.01006	 0.231	 253.0	 253.0	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6066	 5994	 0.000907	 0.009626	 0.2429	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6022	 5995	 0.004757	 0.023662	 0.0811	 341.0	 341.0	 341.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6249	 5995	 0.003358	 0.01681	 0.0566	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 5996	 0.001644	 0.019926	 0.4375	 696.0	 696.0	 696.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 5997	 0.002148	 0.018414	 0.6671	 1863	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 5997	 0.002278	 0.019508	 0.7042	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 5997	 0.002278	 0.019508	 0.7042	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 5998	 0.000256	 0.003788	 0.1238	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 5998	 0.000425	 0.006233	 0.2037	 517.0	 517.0	 517.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6000	 5999	 0.006044	 0.04399	 0.0809	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	6246	 5999	 0.003526	 0.024948	 0.0597	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5522	 6197	 0.001521	 0.009047	 0.0172	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 6001	 0.000977	 0.009199	 0.2111	 3733	 3733	 3733	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 6001	 0.000672	 0.009862	 0.3233	 3493	 3493	 3493	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 6001	 0.000564	 0.006641	 0.1565	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 6003	 0.002171	 0.033086	 0.8404	 1033	 1033	 1033	 0.0	 0.0	 1	 -30.0	 30.0;
	6072	 6002	 0.00499	 0.029882	 0.053	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6002	 0.011619	 0.075838	 0.1313	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 6002	 0.000168	 0.002564	 0.0077	 13437	 13437	 13437	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 6002	 0.000442	 0.003311	 0.006	 10336	 10336	 10336	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 6002	 0.000442	 0.003311	 0.006	 10336	 10336	 10336	 0.0	 0.0	 1	 -30.0	 30.0;
	6132	 6004	 0.00144	 0.007267	 0.014	 4661	 4661	 4661	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 6004	 0.001699	 0.006835	 0.0207	 4902	 4902	 4902	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6004	 0.004595	 0.023202	 0.0448	 1460	 1460	 1460	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 6005	 0.00697	 0.028385	 0.0825	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 6005	 0.002121	 0.00944	 0.025	 3569	 3569	 3569	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 6006	 0.000208	 0.001994	 0.0458	 691.0	 691.0	 691.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 6008	 0.001464	 0.005926	 0.018	 5656	 5656	 5656	 0.0	 0.0	 1	 -30.0	 30.0;
	6238	 6008	 0.001867	 0.007704	 0.0228	 4356	 4356	 4356	 0.0	 0.0	 1	 -30.0	 30.0;
	6135	 6011	 0.002765	 0.015802	 0.0284	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6011	 0.001481	 0.008435	 0.0153	 4032	 4032	 4032	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 6011	 0.007546	 0.023803	 0.0719	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 6012	 0.000949	 0.010021	 0.2458	 649.0	 649.0	 649.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6066	 6012	 0.000693	 0.007271	 0.1793	 879.0	 879.0	 879.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 6013	 0.002449	 0.009363	 0.0294	 3568	 3568	 3568	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 6013	 0.006281	 0.025146	 0.078	 1333	 1333	 1333	 0.0	 0.0	 1	 -30.0	 30.0;
	6136	 6014	 0.001018	 0.011565	 0.3581	 2974	 2974	 2974	 0.0	 0.0	 1	 -30.0	 30.0;
	6136	 6014	 0.001018	 0.011537	 0.361	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6014	 0.000125	 0.001627	 0.0549	 21158	 21158	 21158	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6014	 0.000125	 0.001627	 0.0549	 21158	 21158	 21158	 0.0	 0.0	 1	 -30.0	 30.0;
	1762	 6015	 0.05359	 0.118644	 0.0025	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5474	 6015	 0.097506	 0.227891	 0.0026	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 6016	 0.00072	 0.007589	 0.1851	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 6016	 0.00027	 0.00286	 0.0702	 552.0	 552.0	 552.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 6016	 1e-05	 0.0001	 0.0	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 6016	 1e-05	 0.0001	 0.0	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6002	 6017	 0.002887	 0.021424	 0.0407	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	6002	 6017	 0.002887	 0.021424	 0.0407	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	6216	 6018	 0.000826	 0.012161	 0.3935	 2833	 2833	 2833	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 6018	 0.000489	 0.007064	 0.2338	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 6018	 0.000118	 0.001725	 0.057	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 6020	 0.001189	 0.010138	 0.3687	 402.0	 402.0	 402.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 6019	 0.001189	 0.010138	 0.3672	 398.0	 398.0	 398.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6139	 6020	 0.001236	 0.010554	 0.3821	 508.0	 508.0	 508.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6139	 6019	 0.001236	 0.010554	 0.3821	 511.0	 511.0	 511.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 6021	 0.001165	 0.008938	 0.0484	 436.0	 436.0	 436.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 6024	 0.002507	 0.02106	 0.7903	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 6023	 0.002508	 0.021481	 0.7829	 480.0	 480.0	 480.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6024	 0.004181	 0.035773	 1.2967	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6023	 0.000407	 0.006051	 0.2001	 655.0	 655.0	 655.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6024	 0.000407	 0.006051	 0.2001	 917.0	 917.0	 917.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6250	 6024	 0.000609	 0.005665	 0.2079	 6060	 6060	 6060	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 6025	 0.000731	 0.003457	 0.0077	 9771	 9771	 9771	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 6025	 0.00077	 0.003457	 0.0077	 9748	 9748	 9748	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 6026	 0.024931	 0.154432	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 6026	 0.018006	 0.119806	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 6026	 0.031856	 0.161357	 0.0	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 6027	 0.000963	 0.01117	 0.3449	 3080	 3080	 3080	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 6027	 0.000838	 0.009778	 0.3018	 3518	 3518	 3518	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 6027	 0.000838	 0.009778	 0.3018	 3518	 3518	 3518	 0.0	 0.0	 1	 -30.0	 30.0;
	6142	 6027	 0.00024	 0.00296	 0.0921	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 6028	 0.000769	 0.00865	 0.2718	 343.0	 343.0	 343.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 6028	 0.000769	 0.00865	 0.2718	 343.0	 343.0	 343.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 6028	 0.001662	 0.019321	 0.5969	 1781	 1781	 1781	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 6029	 0.00157	 0.01564	 0.3832	 795.0	 795.0	 795.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6029	 0.00049	 0.00518	 0.1271	 714.0	 714.0	 714.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6029	 0.00049	 0.00518	 0.1271	 714.0	 714.0	 714.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6029	 0.00055	 0.00474	 0.1157	 779.0	 779.0	 779.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6252	 6029	 0.00017	 0.00166	 0.0347	 706.0	 706.0	 706.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 6030	 0.00099	 0.011177	 0.3515	 673.0	 673.0	 673.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 6030	 0.00099	 0.011177	 0.3515	 673.0	 673.0	 673.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 6031	 0.00026	 0.00273	 0.067	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 6032	 0.00026	 0.002717	 0.067	 12649	 12649	 12649	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 6033	 0.00212	 0.011757	 0.0051	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 6035	 0.000528	 0.005682	 0.1011	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6076	 6034	 0.009193	 0.044869	 0.1296	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 6033	 0.009193	 0.044869	 0.1296	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	6249	 6034	 0.002892	 0.022074	 0.1215	 1551	 1551	 1551	 0.0	 0.0	 1	 -30.0	 30.0;
	6248	 6033	 0.005687	 0.02834	 0.0952	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 6035	 0.001732	 0.014836	 0.5408	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6035	 0.001731	 0.014547	 0.5457	 2357	 2357	 2357	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 6036	 0.00106	 0.012389	 0.3827	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 6036	 0.00106	 0.012389	 0.3827	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 6036	 0.00106	 0.012389	 0.3827	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 6036	 0.00081	 0.009439	 0.2916	 3645	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 6036	 0.00081	 0.009439	 0.2916	 3645	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	6073	 6037	 0.000593	 0.171854	 0.001	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 6037	 0.00162	 0.013057	 0.0391	 2624	 2624	 2624	 0.0	 0.0	 1	 -30.0	 30.0;
	6243	 6037	 0.000395	 0.036148	 0.001	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 6037	 0.000592	 0.001679	 0.001	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 6038	 0.000596	 0.006247	 0.2108	 639.0	 639.0	 639.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 6038	 0.000769	 0.010215	 0.3422	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 6038	 0.000596	 0.006219	 0.2079	 637.0	 637.0	 637.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6217	 6038	 0.000526	 0.006881	 0.2313	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 6042	 0.000512	 0.007112	 0.2585	 1790.0	 1790.0	 1790.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 6041	 0.000506	 0.007112	 0.2585	 1790.0	 1790.0	 1790.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 6040	 0.000705	 0.003692	 0.0118	 9186	 9186	 9186	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 6040	 0.00067	 0.003579	 0.012	 9482	 9482	 9482	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 6039	 0.000119	 0.007901	 0.0	 779.0	 779.0	 779.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6042	 0.000443	 0.004077	 0.1429	 295.0	 295.0	 295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6041	 0.000443	 0.004078	 0.1429	 8417	 8417	 8417	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 6043	 0.000353	 0.004072	 0.1257	 8447	 8447	 8447	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 6043	 0.000353	 0.004072	 0.1257	 8447	 8447	 8447	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6043	 0.00054	 0.006094	 0.1916	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6043	 0.00054	 0.006094	 0.1916	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 6044	 0.00099	 0.007918	 0.014	 4327	 4327	 4327	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 6044	 0.003899	 0.025983	 0.0509	 1315	 1315	 1315	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6045	 7.3e-05	 0.003959	 0.0029	 8719	 8719	 8719	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 6045	 7.3e-05	 0.003635	 0.0029	 9496	 9496	 9496	 0.0	 0.0	 1	 -30.0	 30.0;
	6121	 6046	 0.000593	 0.549393	 0.001	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	6153	 6046	 0.000593	 0.274647	 0.001	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 6046	 9.9e-05	 0.000672	 0.001	 50827	 50827	 50827	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 6048	 0.000751	 0.002609	 0.0006	 12717	 12717	 12717	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 6048	 0.00124	 0.004622	 0.0016	 7215	 7215	 7215	 0.0	 0.0	 1	 -30.0	 30.0;
	6167	 6049	 0.00111	 0.0124	 0.2946	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 6049	 0.000368	 0.004359	 0.0947	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 6050	 0.001039	 0.007479	 0.0	 4573	 4573	 4573	 0.0	 0.0	 1	 -30.0	 30.0;
	6146	 6050	 0.017313	 0.182133	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	6169	 6050	 0.002424	 0.019391	 0.0	 1767	 1767	 1767	 0.0	 0.0	 1	 -30.0	 30.0;
	6194	 6050	 0.002424	 0.01385	 0.0	 2456	 2456	 2456	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 6128	 0.006104	 0.044405	 0.0552	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6229	 6051	 0.001659	 0.0064	 0.0237	 5222	 5222	 5222	 0.0	 0.0	 1	 -30.0	 30.0;
	6229	 6051	 0.001659	 0.0064	 0.0237	 5222	 5222	 5222	 0.0	 0.0	 1	 -30.0	 30.0;
	6148	 6052	 0.0016	 0.011773	 0.0203	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 6052	 0.002173	 0.015388	 0.0172	 347.0	 347.0	 347.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6053	 0.001828	 0.019868	 0.4794	 602.0	 602.0	 602.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6074	 6054	 0.000796	 0.008698	 0.201	 883.0	 883.0	 883.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 6055	 0.000568	 0.006586	 0.205	 5223	 5223	 5223	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 6055	 0.000568	 0.006586	 0.205	 5223	 5223	 5223	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 6055	 0.00113	 0.01283	 0.3286	 2681	 2681	 2681	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 6056	 0.000418	 0.006302	 0.1928	 5467	 5467	 5467	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 6056	 0.0016	 0.023587	 0.68	 498.0	 498.0	 498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6099	 6057	 0.001284	 0.014657	 0.0554	 2347	 2347	 2347	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6058	 0.000422	 0.005118	 0.1184	 517.0	 517.0	 517.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6058	 0.000637	 0.009162	 0.2316	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6058	 0.000852	 0.009571	 0.2189	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6061	 6060	 0.005329	 0.016298	 0.0056	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6061	 6059	 0.005329	 0.016298	 0.0056	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 6060	 0.004529	 0.020129	 0.0072	 1674	 1674	 1674	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 6059	 0.004529	 0.020129	 0.0072	 1674	 1674	 1674	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 6061	 0.003818	 0.0204	 0.0074	 1664	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 6061	 0.003818	 0.0204	 0.0074	 1664	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 6065	 0.038781	 0.237535	 0.0	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	6146	 6065	 0.025623	 0.202909	 0.0	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 6065	 0.024931	 0.09903	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6065	 0.022161	 0.168283	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 6066	 0.00087	 0.00968	 0.2313	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 6066	 0.00121	 0.01281	 0.3145	 886.0	 886.0	 886.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6215	 6066	 6e-05	 0.00059	 0.0144	 465.0	 465.0	 465.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6073	 6067	 0.000395	 0.145778	 0.001	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	6083	 6069	 0.001295	 0.011302	 0.3812	 3035	 3035	 3035	 0.0	 0.0	 1	 -30.0	 30.0;
	6083	 6069	 0.000104	 0.003904	 0.0029	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 6069	 7.3e-05	 0.039586	 0.0029	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 6069	 7.3e-05	 0.016832	 0.0029	 2052	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6069	 7.3e-05	 0.009151	 0.0029	 3773	 3773	 3773	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6069	 7.3e-05	 0.069075	 0.0029	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	6245	 6069	 0.000547	 0.004696	 1.2794	 980.0	 980.0	 980.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 6070	 0.032549	 0.126731	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	6182	 6070	 0.033934	 0.182133	 0.0	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 6071	 0.000407	 0.004079	 0.1162	 812.0	 812.0	 812.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 6071	 0.000407	 0.004079	 0.1162	 812.0	 812.0	 812.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 6071	 4.8e-05	 0.001177	 0.0029	 29308	 29308	 29308	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6072	 0.006744	 0.045697	 0.0819	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	6242	 6073	 0.000395	 0.202864	 0.001	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 6073	 0.000593	 0.087308	 0.001	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 6074	 0.000298	 0.003006	 0.0713	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 6074	 0.00162	 0.016378	 0.3829	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6121	 6075	 0.000593	 0.32164	 0.001	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	6149	 6075	 0.000593	 0.023506	 0.001	 1469	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6075	 0.010588	 0.054894	 0.1043	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6098	 6076	 0.001754	 0.012251	 0.0484	 2790	 2790	 2790	 0.0	 0.0	 1	 -30.0	 30.0;
	6099	 6077	 0.001762	 0.012148	 0.049	 2813	 2813	 2813	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6078	 0.004508	 0.017357	 0.0537	 1926	 1926	 1926	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 6078	 0.0093	 0.045353	 0.1033	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6079	 0.001018	 0.011454	 0.3604	 3003	 3003	 3003	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6079	 0.001018	 0.011454	 0.3604	 3003	 3003	 3003	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 6080	 0.003133	 0.026821	 0.6166	 1279	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 6080	 0.002718	 0.024668	 0.5747	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6080	 0.00277	 0.01662	 0.0	 2050	 2050	 2050	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 6082	 0.001088	 0.01173	 0.2548	 1624.0	 1624.0	 1624.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 6081	 0.004583	 0.024	 0.0701	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 6081	 0.004583	 0.025185	 0.0701	 267.0	 267.0	 267.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 6082	 0.000796	 0.007999	 0.1863	 1044.0	 1044.0	 1044.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6111	 6083	 0.000873	 0.007825	 0.2541	 4385	 4385	 4385	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 6083	 7.3e-05	 0.058542	 0.0029	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6083	 7.3e-05	 0.032502	 0.0029	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6083	 7.3e-05	 0.024529	 0.0029	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 6083	 0.00153	 0.014349	 0.3379	 392.0	 392.0	 392.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 6084	 0.000184	 0.002407	 0.0079	 14302	 14302	 14302	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6084	 0.002299	 0.020665	 0.0	 342.0	 342.0	 342.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6085	 0.011477	 0.037472	 0.1077	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6085	 0.007763	 0.037649	 0.1241	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 6085	 0.000573	 0.003911	 0.0071	 8735	 8735	 8735	 0.0	 0.0	 1	 -30.0	 30.0;
	6245	 6086	 0.000796	 0.0075	 0.1952	 784.0	 784.0	 784.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 6087	 0.007921	 0.048632	 0.0885	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6089	 3.7e-05	 9.3e-05	 0.0029	 344932	 344932	 344932	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6089	 3.7e-05	 9.3e-05	 0.0029	 344932	 344932	 344932	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6088	 8.3e-05	 0.000152	 0.0029	 607.0	 607.0	 607.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6088	 3.7e-05	 9.3e-05	 0.0029	 1053.0	 1053.0	 1053.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 6090	 6.9e-05	 0.000139	 0.0029	 222473	 222473	 222473	 0.0	 0.0	 1	 -30.0	 30.0;
	6142	 6091	 0.0012	 0.014039	 0.4369	 2451	 2451	 2451	 0.0	 0.0	 1	 -30.0	 30.0;
	6099	 6093	 0.001126	 0.005707	 0.0166	 5936	 5936	 5936	 0.0	 0.0	 1	 -30.0	 30.0;
	6097	 6092	 0.001286	 0.006688	 0.0202	 5070	 5070	 5070	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 6095	 0.001066	 0.012292	 0.4641	 2799	 2799	 2799	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6094	 0.00018	 0.001517	 0.0578	 22600	 22600	 22600	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 6095	 0.00018	 0.001517	 0.0578	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6094	 0.00018	 0.001517	 0.0578	 22600	 22600	 22600	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 6096	 1.6e-05	 0.000136	 0.0007	 252116	 252116	 252116	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 6101	 0.000938	 0.010451	 0.2253	 1487.0	 1487.0	 1487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6107	 6097	 0.005965	 0.04239	 0.1009	 807	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 6098	 0.003315	 0.023518	 0.0665	 1454	 1454	 1454	 0.0	 0.0	 1	 -30.0	 30.0;
	6103	 6100	 0.000202	 0.003026	 0.0921	 717.0	 717.0	 717.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 6100	 0.000558	 0.004985	 0.1219	 6883	 6883	 6883	 0.0	 0.0	 1	 -30.0	 30.0;
	6217	 6101	 0.001205	 0.014626	 0.5164	 2353	 2353	 2353	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6102	 0.002119	 0.023913	 0.0052	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 6102	 0.001177	 0.012465	 0.3177	 816.0	 816.0	 816.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6132	 6105	 0.010317	 0.052128	 0.099	 650	 650	 650	 0.0	 0.0	 1	 -30.0	 30.0;
	6173	 6105	 0.001126	 0.010031	 0.0313	 283.0	 283.0	 283.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6105	 0.0096	 0.078696	 0.1357	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	6156	 6106	 0.000341	 0.005024	 0.3259	 6857	 6857	 6857	 0.0	 0.0	 1	 -30.0	 30.0;
	6156	 6106	 0.000341	 0.005024	 0.3259	 6857	 6857	 6857	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 6106	 0.000268	 0.003944	 0.1279	 588.0	 588.0	 588.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6107	 0.005432	 0.036524	 0.0651	 935	 935	 935	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 6109	 0.00032	 0.00305	 0.0723	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6108	 0.00045	 0.00479	 0.1066	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6109	 0.00045	 0.00479	 0.1066	 7176	 7176	 7176	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 6110	 0.00022	 0.00232	 0.0544	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 6112	 0.001644	 0.01558	 0.4807	 974.0	 974.0	 974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6187	 6113	 0.000693	 0.00682	 0.2072	 763.0	 763.0	 763.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 6112	 0.000225	 0.002472	 0.071	 782.0	 782.0	 782.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6207	 6113	 0.000222	 0.00247	 0.0817	 1109.0	 1109.0	 1109.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6150	 6114	 0.00196	 0.020187	 0.4812	 1703	 1703	 1703	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6114	 0.000533	 0.005305	 0.1304	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6114	 0.001517	 0.015623	 0.3738	 2200	 2200	 2200	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6114	 0.00196	 0.019813	 0.4881	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 6115	 0.000832	 0.012165	 0.3939	 2832	 2832	 2832	 0.0	 0.0	 1	 -30.0	 30.0;
	6247	 6115	 0.000819	 0.013667	 0.3493	 2522	 2522	 2522	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 6116	 0.000533	 0.004564	 0.1069	 359.0	 359.0	 359.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 6116	 0.00286	 0.029584	 0.6931	 569.0	 569.0	 569.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 6118	 0.0007	 0.007379	 0.1808	 618.0	 618.0	 618.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6118	 0.00076	 0.008	 0.1779	 4297	 4297	 4297	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6119	 0.001101	 0.017299	 0.7474	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6119	 0.001101	 0.017299	 0.7474	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 6120	 0.001233	 0.013054	 0.3191	 1097.0	 1097.0	 1097.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 6123	 0.000542	 0.007881	 0.2605	 299.0	 299.0	 299.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6218	 6123	 0.000357	 0.005187	 0.1718	 6641	 6641	 6641	 0.0	 0.0	 1	 -30.0	 30.0;
	5866	 6124	 0.00074	 0.007769	 0.1906	 844.0	 844.0	 844.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5869	 6124	 0.00041	 0.00348	 0.0846	 349.0	 349.0	 349.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5868	 6124	 0.00033	 0.00352	 0.0864	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 6126	 2e-05	 9.8e-05	 0.0	 345173	 345173	 345173	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6126	 0.000414	 0.003537	 0.2573	 9695	 9695	 9695	 0.0	 0.0	 1	 -30.0	 30.0;
	6250	 6126	 0.002424	 0.021053	 0.7624	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 6127	 0.00332	 0.010222	 0.0143	 3213	 3213	 3213	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 6129	 0.003351	 0.012302	 0.0042	 2708	 2708	 2708	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 6130	 0.000155	 0.001518	 0.3148	 22626	 22626	 22626	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 6131	 0.000198	 0.001975	 0.0	 17394	 17394	 17394	 0.0	 0.0	 1	 -30.0	 30.0;
	6192	 6131	 0.004429	 0.025092	 0.0871	 1355	 1355	 1355	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 6131	 0.001414	 0.020346	 0.0707	 1693	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 6133	 0.001033	 0.013049	 0.0551	 2638	 2638	 2638	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6135	 0.002923	 0.016731	 0.0304	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6144	 6137	 0.000942	 0.008047	 0.2917	 4262	 4262	 4262	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6137	 0.00194	 0.016614	 0.6003	 2064	 2064	 2064	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 6138	 3.5e-05	 0.000139	 0.0058	 240858	 240858	 240858	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 6138	 0.000807	 0.008383	 0.281	 849.0	 849.0	 849.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 6139	 0.000408	 0.003572	 0.1288	 1235.0	 1235.0	 1235.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6182	 6139	 0.000846	 0.007839	 0.2833	 4379	 4379	 4379	 0.0	 0.0	 1	 -30.0	 30.0;
	6182	 6139	 0.000846	 0.007839	 0.2823	 4379	 4379	 4379	 0.0	 0.0	 1	 -30.0	 30.0;
	6187	 6139	 0.000455	 0.00419	 0.1532	 914.0	 914.0	 914.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 6141	 0.004523	 0.022716	 0.0699	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	6195	 6141	 0.001146	 0.005669	 0.0172	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6195	 6143	 0.004405	 0.022756	 0.0697	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6144	 0.001004	 0.008546	 0.309	 4013	 4013	 4013	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6146	 0.000554	 0.007756	 0.0	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6169	 6146	 0.018006	 0.189058	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6146	 0.00277	 0.01662	 0.0	 598.0	 598.0	 598.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 6147	 0.00025	 0.002292	 0.0829	 1298.0	 1298.0	 1298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6148	 0.001561	 0.011595	 0.0172	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 6151	 0.00094	 0.012774	 0.412	 2696	 2696	 2696	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 6151	 0.00094	 0.012762	 0.411	 2698	 2698	 2698	 0.0	 0.0	 1	 -30.0	 30.0;
	6194	 6152	 0.00042	 0.006343	 0.1933	 5431	 5431	 5431	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6154	 0.000921	 0.009017	 0.2236	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6154	 0.000956	 0.008996	 0.2224	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6154	 0.002424	 0.024785	 0.621	 692.0	 692.0	 692.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 6154	 0.001537	 0.016662	 0.3851	 757.0	 757.0	 757.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 6156	 0.000341	 0.005024	 0.3259	 6857	 6857	 6857	 0.0	 0.0	 1	 -30.0	 30.0;
	6226	 6157	 0.000861	 0.009919	 0.2325	 904.0	 904.0	 904.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6158	 7.3e-05	 0.011484	 0.0029	 3007	 3007	 3007	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6158	 7.3e-05	 0.008668	 0.0029	 3983	 3983	 3983	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6158	 0.003303	 0.035104	 0.7903	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	5865	 6160	 0.000945	 0.010861	 0.226	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 6161	 0.00081	 0.008386	 0.2801	 844.0	 844.0	 844.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6182	 6161	 0.019391	 0.119806	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6161	 0.00277	 0.16205	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 6162	 0.000118	 0.001725	 0.057	 19968	 19968	 19968	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 6163	 0.006791	 0.019711	 0.0099	 1752	 1752	 1752	 0.0	 0.0	 1	 -30.0	 30.0;
	1197	 6165	 0.011176	 0.069403	 0.1286	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 6165	 0.00127	 0.019504	 0.0592	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6165	 0.007526	 0.044761	 0.0829	 761	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	5865	 6166	 0.00062	 0.00665	 0.1707	 501.0	 501.0	 501.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6194	 6167	 0.000796	 0.011669	 0.3166	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 6168	 0.004978	 0.036425	 0.0648	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5866	 6170	 0.0	 0.0005	 0.0012	 69049	 69049	 69049	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 6205	 0.001724	 0.039197	 0.5453	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 6204	 0.001724	 0.039197	 0.5453	 950	 950	 950	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 6171	 0.000527	 0.008085	 0.0244	 4262	 4262	 4262	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 6171	 0.001679	 0.025659	 0.0779	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 6172	 0.000438	 0.003941	 0.1411	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6205	 6174	 2.1e-05	 0.000139	 0.0	 245589	 245589	 245589	 0.0	 0.0	 1	 -30.0	 30.0;
	6216	 6174	 0.000275	 0.004076	 0.1317	 8451	 8451	 8451	 0.0	 0.0	 1	 -30.0	 30.0;
	6218	 6174	 0.000958	 0.014044	 0.4598	 480.0	 480.0	 480.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6175	 0.002881	 0.02894	 0.7249	 520.0	 520.0	 520.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6176	 7.3e-05	 0.000789	 0.0029	 43571	 43571	 43571	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 6177	 0.015585	 0.053156	 0.1438	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 6177	 0.007388	 0.039506	 0.0658	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 6181	 0.004648	 0.037179	 0.0658	 922	 922	 922	 0.0	 0.0	 1	 -30.0	 30.0;
	6246	 6181	 0.000277	 0.003773	 0.0175	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 6182	 0.000241	 0.002382	 0.078	 1179.0	 1179.0	 1179.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 6186	 0.001427	 0.014647	 0.3362	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5865	 6188	 0.000855	 0.010109	 0.2201	 3404	 3404	 3404	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 6188	 0.001187	 0.012493	 0.2917	 707.0	 707.0	 707.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1196	 6190	 0.008751	 0.05361	 0.0972	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 6190	 0.000689	 0.010295	 0.0336	 3347	 3347	 3347	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6191	 0.006341	 0.033679	 0.0557	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 6191	 0.005472	 0.030775	 0.0557	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 6192	 0.007955	 0.045827	 0.0843	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	6026	 6202	 0.000474	 0.005325	 0.1567	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6026	 6201	 0.000474	 0.005325	 0.1567	 1317.0	 1317.0	 1317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 6209	 4.2e-05	 0.004848	 0.0289	 1009.0	 1009.0	 1009.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 6211	 0.00016	 0.0017	 0.04	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 6218	 0.00034	 0.004993	 0.1619	 590.0	 590.0	 590.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 6219	 0.001884	 0.010078	 0.0338	 3368	 3368	 3368	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 6219	 0.001881	 0.01006	 0.0338	 3374	 3374	 3374	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 6220	 0.000415	 0.003543	 0.2573	 9679	 9679	 9679	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 6223	 0.000859	 0.009605	 0.2181	 781.0	 781.0	 781.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6229	 6225	 0.002272	 0.033284	 0.1153	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 6226	 0.000665	 0.008026	 0.1256	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5869	 6228	 0.00046	 0.00479	 0.1207	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5868	 6227	 0.00047	 0.00493	 0.1207	 6972	 6972	 6972	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 6229	 0.002785	 0.018588	 0.0354	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 6229	 0.002785	 0.018607	 0.0354	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 6230	 0.000125	 0.001711	 0.0462	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	323	 6233	 0.002087	 0.022763	 0.6108	 1498	 1498	 1498	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 6237	 0.000312	 0.002645	 0.1129	 12963	 12963	 12963	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 6241	 0.000395	 0.198321	 0.001	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 6247	 0.000855	 0.014271	 0.3697	 666.0	 666.0	 666.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 6248	 0.002815	 0.02159	 0.1187	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 27	 0.00318	 0.114765	 0.0	 266	 266	 266	 0.976558	 0.0	 1	 -30.0	 30.0;
	26	 27	 0.003062	 0.115753	 0.0	 264	 264	 264	 0.968992	 0.0	 1	 -30.0	 30.0;
	26	 27	 0.00318	 0.117926	 0.0	 259	 259	 259	 0.967118	 0.0	 1	 -30.0	 30.0;
	31	 33	 0.001975	 0.126617	 0.0	 243	 243	 243	 1.001002	 0.0	 1	 -30.0	 30.0;
	31	 34	 0.003635	 0.123062	 0.0	 250	 250	 250	 0.976559	 0.0	 1	 -30.0	 30.0;
	32	 33	 0.003556	 0.120296	 0.0	 265	 265	 265	 0.983284	 0.0	 1	 -30.0	 30.0;
	33	 5899	 0.00018	 -0.006163	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	34	 5923	 0.00018	 -0.006163	 0.0	 1188.0	 1188.0	 1188.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	35	 5899	 0.000291	 0.030817	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 5923	 0.000291	 0.030817	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	50	 51	 0.00316	 0.125432	 0.0	 246	 246	 246	 1.040584	 0.0	 1	 -30.0	 30.0;
	50	 51	 0.003951	 0.125235	 0.0	 246	 246	 246	 1.026695	 0.0	 1	 -30.0	 30.0;
	50	 51	 0.00316	 0.125432	 0.0	 246	 246	 246	 1.026695	 0.0	 1	 -30.0	 30.0;
	103	 104	 0.003951	 0.110025	 0.0	 281	 281	 281	 0.97561	 0.0	 1	 -30.0	 30.0;
	103	 104	 0.00397	 0.111605	 0.0	 277	 277	 277	 0.973708	 0.0	 1	 -30.0	 30.0;
	109	 110	 0.003556	 0.119309	 0.0	 258	 258	 258	 1.053742	 0.0	 1	 -30.0	 30.0;
	109	 110	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.040584	 0.0	 1	 -30.0	 30.0;
	112	 113	 0.003279	 0.11358	 0.0	 271	 271	 271	 0.98619	 0.0	 1	 -30.0	 30.0;
	112	 113	 0.00324	 0.117531	 0.0	 262	 262	 262	 0.98912	 0.0	 1	 -30.0	 30.0;
	112	 113	 0.003753	 0.112395	 0.0	 273	 273	 273	 0.97561	 0.0	 1	 -30.0	 30.0;
	128	 130	 0.003338	 0.116543	 0.0	 262	 262	 262	 0.999001	 0.0	 1	 -30.0	 30.0;
	129	 130	 0.003595	 0.128593	 0.0	 237	 237	 237	 0.999001	 0.0	 1	 -30.0	 30.0;
	137	 138	 0.002178	 0.149156	 0.0	 203	 203	 203	 0.974664	 0.0	 1	 -30.0	 30.0;
	139	 140	 0.001719	 0.122074	 0.0	 253	 253	 253	 0.98912	 0.0	 1	 -30.0	 30.0;
	140	 141	 0.000332	 0.025	 0.0	 1187.0	 1187.0	 1187.0	 1.001	 0.0	 1	 -30.0	 30.0;
	142	 143	 0.001857	 0.114963	 0.0	 269	 269	 269	 0.987165	 0.0	 1	 -30.0	 30.0;
	142	 143	 0.001936	 0.117926	 0.0	 262	 262	 262	 0.986189	 0.0	 1	 -30.0	 30.0;
	144	 145	 0.003062	 0.112593	 0.0	 285	 285	 285	 0.986197	 0.0	 1	 -30.0	 30.0;
	144	 146	 0.003158	 0.160111	 0.0	 201	 201	 201	 0.982323	 0.0	 1	 -30.0	 30.0;
	144	 146	 0.003144	 0.160319	 0.0	 201	 201	 201	 0.982323	 0.0	 1	 -30.0	 30.0;
	145	 5871	 0.000145	 -0.006302	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	145	 5924	 0.000125	 -0.006787	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	146	 5871	 0.000194	 0.031302	 0.0	 1094	 1094	 1094	 0.0	 0.0	 1	 -30.0	 30.0;
	146	 5924	 0.000215	 0.031995	 0.0	 1070	 1070	 1070	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 152	 0.000252	 0.00252	 0.0003	 11659	 11659	 11659	 1.0	 -1.3	 1	 -30.0	 30.0;
	153	 154	 0.003437	 0.094815	 0.0	 324	 324	 324	 0.98912	 0.0	 1	 -30.0	 30.0;
	157	 159	 0.025195	 0.195515	 0.0	 150	 150	 150	 0.888893	 0.0	 1	 -30.0	 30.0;
	165	 168	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	166	 168	 0.00316	 0.10884	 0.0	 281	 281	 281	 0.983282	 0.0	 1	 -30.0	 30.0;
	166	 168	 0.00316	 0.11358	 0.0	 269	 269	 269	 0.983282	 0.0	 1	 -30.0	 30.0;
	166	 168	 0.00318	 0.113185	 0.0	 270	 270	 270	 0.983282	 0.0	 1	 -30.0	 30.0;
	167	 168	 0.003121	 0.116148	 0.0	 263	 263	 263	 0.985226	 0.0	 1	 -30.0	 30.0;
	171	 172	 0.003951	 0.113185	 0.0	 273	 273	 273	 0.973708	 0.0	 1	 -30.0	 30.0;
	171	 172	 0.003951	 0.113185	 0.0	 273	 273	 273	 0.985226	 0.0	 1	 -30.0	 30.0;
	179	 5900	 0.000909	 -0.006716	 0.0	 444.0	 444.0	 444.0	 0.974656	 0.0	 1	 -30.0	 30.0;
	179	 5925	 0.001304	 -0.006123	 0.0	 444.0	 444.0	 444.0	 0.94697	 0.0	 1	 -30.0	 30.0;
	180	 5900	 0.002252	 0.11358	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 5925	 0.002449	 0.127407	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	203	 204	 0.001758	 0.091062	 0.0	 346	 346	 346	 1.006036	 0.0	 1	 -30.0	 30.0;
	203	 204	 0.001758	 0.091062	 0.0	 346	 346	 346	 1.006036	 0.0	 1	 -30.0	 30.0;
	204	 205	 0.000665	 0.048338	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	204	 205	 0.000783	 0.039612	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	210	 212	 0.000277	 0.009481	 0.001	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	211	 213	 0.000277	 0.009481	 0.001	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	211	 213	 0.000277	 0.009481	 0.0	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	214	 215	 0.00324	 0.117728	 0.0	 262	 262	 262	 1.009082	 0.0	 1	 -30.0	 30.0;
	214	 215	 0.003101	 0.118321	 0.0	 261	 261	 261	 1.009082	 0.0	 1	 -30.0	 30.0;
	214	 215	 0.00324	 0.117728	 0.0	 262	 262	 262	 0.985226	 0.0	 1	 -30.0	 30.0;
	221	 222	 0.004741	 0.156049	 0.0	 198	 198	 198	 0.946073	 0.0	 1	 -30.0	 30.0;
	233	 234	 0.015309	 0.465432	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	246	 247	 0.004543	 0.160988	 0.0	 191	 191	 191	 0.978477	 0.0	 1	 -30.0	 30.0;
	256	 257	 0.003378	 0.105679	 0.0	 292	 292	 292	 0.968054	 0.0	 1	 -30.0	 30.0;
	259	 260	 0.014262	 0.231111	 0.0	 134	 134	 134	 0.978474	 0.0	 1	 -30.0	 30.0;
	259	 260	 0.012504	 0.325926	 0.0	 95	 95	 95	 0.957851	 0.0	 1	 -30.0	 30.0;
	262	 264	 0.000346	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	262	 264	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	263	 264	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 273	 0.003437	 0.122469	 0.0	 249	 249	 249	 1.011122	 0.0	 1	 -30.0	 30.0;
	272	 273	 0.003733	 0.122667	 0.0	 249	 249	 249	 0.990101	 0.0	 1	 -30.0	 30.0;
	275	 276	 0.000803	 0.042452	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	277	 278	 0.003062	 0.116148	 0.0	 263	 263	 263	 0.973708	 0.0	 1	 -30.0	 30.0;
	277	 278	 0.003279	 0.110222	 0.0	 277	 277	 277	 0.972763	 0.0	 1	 -30.0	 30.0;
	313	 314	 0.003872	 0.123852	 0.0	 249	 249	 249	 0.974664	 0.0	 1	 -30.0	 30.0;
	313	 314	 0.003872	 0.123852	 0.0	 249	 249	 249	 0.956938	 0.0	 1	 -30.0	 30.0;
	321	 323	 0.002916	 0.161475	 0.0	 196	 196	 196	 1.033058	 0.0	 1	 -30.0	 30.0;
	321	 323	 0.001801	 0.100416	 0.0	 316	 316	 316	 0.994033	 0.0	 1	 -30.0	 30.0;
	321	 323	 0.002825	 0.153927	 0.0	 206	 206	 206	 1.023541	 0.0	 1	 -30.0	 30.0;
	322	 323	 0.000734	 0.045014	 0.0	 593.0	 593.0	 593.0	 0.956938	 0.0	 1	 -30.0	 30.0;
	322	 323	 0.000727	 0.044668	 0.0	 593.0	 593.0	 593.0	 0.956938	 0.0	 1	 -30.0	 30.0;
	326	 327	 0.003931	 0.12484	 0.0	 247	 247	 247	 1.037344	 0.0	 1	 -30.0	 30.0;
	326	 327	 0.004662	 0.160988	 0.0	 192	 192	 192	 1.012146	 0.0	 1	 -30.0	 30.0;
	330	 331	 0.003516	 0.12563	 0.0	 246	 246	 246	 1.012146	 0.0	 1	 -30.0	 30.0;
	330	 331	 0.003536	 0.126617	 0.0	 244	 244	 244	 1.012146	 0.0	 1	 -30.0	 30.0;
	342	 343	 0.003081	 0.118123	 0.0	 261	 261	 261	 1.012146	 0.0	 1	 -30.0	 30.0;
	360	 361	 0.016	 0.324444	 0.0	 97	 97	 97	 0.984252	 0.0	 1	 -30.0	 30.0;
	360	 361	 0.013333	 0.328889	 0.0	 96	 96	 96	 0.971817	 0.0	 1	 -30.0	 30.0;
	360	 361	 0.016889	 0.398222	 0.0	 79	 79	 79	 0.984252	 0.0	 1	 -30.0	 30.0;
	360	 362	 0.003852	 0.123457	 0.0	 250	 250	 250	 0.978474	 0.0	 1	 -30.0	 30.0;
	378	 379	 0.003951	 0.123457	 0.0	 249	 249	 249	 1.001002	 0.0	 1	 -30.0	 30.0;
	378	 379	 0.003753	 0.12563	 0.0	 245	 245	 245	 1.001002	 0.0	 1	 -30.0	 30.0;
	379	 380	 0.000803	 0.03892	 0.0	 600.0	 600.0	 600.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	379	 380	 0.000845	 0.03982	 0.0	 598.0	 598.0	 598.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	379	 5926	 0.000374	 -0.009003	 0.0	 600.0	 600.0	 600.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	380	 5926	 0.000471	 0.048892	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 423	 0.003062	 0.117136	 0.0	 264	 264	 264	 0.978474	 0.0	 1	 -30.0	 30.0;
	422	 423	 0.003615	 0.114568	 0.0	 270	 270	 270	 0.968054	 0.0	 1	 -30.0	 30.0;
	424	 425	 0.003911	 0.111012	 0.0	 278	 278	 278	 0.953289	 0.0	 1	 -30.0	 30.0;
	424	 425	 0.003911	 0.111012	 0.0	 278	 278	 278	 0.987167	 0.0	 1	 -30.0	 30.0;
	424	 425	 0.003911	 0.111012	 0.0	 278	 278	 278	 0.986189	 0.0	 1	 -30.0	 30.0;
	445	 446	 0.00318	 0.117728	 0.0	 272	 272	 272	 1.089325	 0.0	 1	 -30.0	 30.0;
	443	 446	 0.003062	 0.115753	 0.0	 277	 277	 277	 1.075269	 0.0	 1	 -30.0	 30.0;
	444	 446	 0.002983	 0.118716	 0.0	 270	 270	 270	 1.075269	 0.0	 1	 -30.0	 30.0;
	448	 449	 0.004365	 0.168296	 0.0	 185	 185	 185	 0.968054	 0.0	 1	 -30.0	 30.0;
	448	 449	 0.004464	 0.169284	 0.0	 184	 184	 184	 0.94697	 0.0	 1	 -30.0	 30.0;
	449	 450	 0.000893	 0.043767	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	449	 450	 0.000693	 0.048615	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	452	 453	 0.001936	 0.116148	 0.0	 263	 263	 263	 0.985226	 0.0	 1	 -30.0	 30.0;
	452	 453	 0.001936	 0.117728	 0.0	 260	 260	 260	 0.985226	 0.0	 1	 -30.0	 30.0;
	457	 458	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.910747	 0.0	 1	 -30.0	 30.0;
	458	 5872	 0.000249	 -0.004501	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	458	 5901	 0.000152	 -0.00644	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	459	 5872	 6.9e-05	 0.029294	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 5901	 0.00018	 0.03151	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	464	 465	 0.011111	 0.384074	 0.0	 94	 94	 94	 1.103753	 0.0	 1	 -30.0	 30.0;
	478	 479	 0.013354	 0.299824	 0.0	 98	 98	 98	 1.02564	 0.0	 1	 -30.0	 30.0;
	480	 481	 0.003951	 0.124444	 0.0	 247	 247	 247	 1.0142	 0.0	 1	 -30.0	 30.0;
	480	 481	 0.003753	 0.124642	 0.0	 247	 247	 247	 1.0142	 0.0	 1	 -30.0	 30.0;
	480	 481	 0.002568	 0.164346	 0.0	 187	 187	 187	 1.001002	 0.0	 1	 -30.0	 30.0;
	504	 505	 0.00397	 0.120296	 0.0	 266	 266	 266	 0.997009	 0.0	 1	 -30.0	 30.0;
	504	 505	 0.0032	 0.117333	 0.0	 273	 273	 273	 0.997009	 0.0	 1	 -30.0	 30.0;
	512	 513	 0.003527	 0.103804	 0.0	 284	 284	 284	 0.933707	 0.0	 1	 -30.0	 30.0;
	521	 523	 0.003951	 0.118519	 0.0	 260	 260	 260	 1.0142	 0.0	 1	 -30.0	 30.0;
	522	 523	 0.003358	 0.118519	 0.0	 260	 260	 260	 1.001002	 0.0	 1	 -30.0	 30.0;
	523	 524	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	523	 524	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	526	 527	 0.001679	 0.122272	 0.0	 250	 250	 250	 0.964324	 0.0	 1	 -30.0	 30.0;
	526	 527	 0.00316	 0.117333	 0.0	 260	 260	 260	 0.975606	 0.0	 1	 -30.0	 30.0;
	526	 527	 0.001679	 0.122272	 0.0	 250	 250	 250	 0.975606	 0.0	 1	 -30.0	 30.0;
	535	 536	 0.003042	 0.116148	 0.0	 263	 263	 263	 0.997009	 0.0	 1	 -30.0	 30.0;
	535	 536	 0.00316	 0.11437	 0.0	 267	 267	 267	 0.992064	 0.0	 1	 -30.0	 30.0;
	535	 536	 0.003101	 0.118321	 0.0	 258	 258	 258	 0.997009	 0.0	 1	 -30.0	 30.0;
	544	 545	 0.003516	 0.122469	 0.0	 252	 252	 252	 0.973708	 0.0	 1	 -30.0	 30.0;
	550	 551	 0.012963	 0.267901	 0.0	 114	 114	 114	 1.002005	 0.0	 1	 -30.0	 30.0;
	563	 564	 0.004899	 0.162173	 0.0	 188	 188	 188	 0.968054	 0.0	 1	 -30.0	 30.0;
	581	 579	 2e-05	 0.004741	 0.004	 935.0	 935.0	 935.0	 1.0	 4.66	 1	 -30.0	 30.0;
	581	 582	 0.000319	 0.024307	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	581	 582	 0.000319	 0.024307	 0.0	 1188.0	 1188.0	 1188.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	594	 595	 0.000886	 0.043837	 0.0	 632.0	 632.0	 632.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	602	 603	 0.003081	 0.125432	 0.0	 246	 246	 246	 0.974664	 0.0	 1	 -30.0	 30.0;
	602	 603	 0.003121	 0.125037	 0.0	 247	 247	 247	 0.974664	 0.0	 1	 -30.0	 30.0;
	607	 608	 0.004346	 0.164938	 0.0	 185	 185	 185	 0.978474	 0.0	 1	 -30.0	 30.0;
	607	 608	 0.004543	 0.162568	 0.0	 188	 188	 188	 0.978474	 0.0	 1	 -30.0	 30.0;
	610	 611	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	616	 5902	 0.000519	 -0.007825	 0.0	 606.0	 606.0	 606.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	617	 5902	 0.000277	 0.047507	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	627	 628	 0.003733	 0.175822	 0.0	 173	 173	 173	 0.938971	 0.0	 1	 -30.0	 30.0;
	658	 659	 0.00162	 0.122272	 0.0	 253	 253	 253	 1.0	 0.0	 1	 -30.0	 30.0;
	658	 659	 0.001798	 0.119506	 0.0	 258	 258	 258	 1.0	 0.0	 1	 -30.0	 30.0;
	673	 674	 0.004346	 0.169877	 0.0	 184	 184	 184	 0.978474	 0.0	 1	 -30.0	 30.0;
	682	 683	 0.001393	 0.097699	 0.0	 313	 313	 313	 1.020408	 0.0	 1	 -30.0	 30.0;
	700	 701	 0.00316	 0.112	 0.0	 281	 281	 281	 1.002004	 0.0	 1	 -30.0	 30.0;
	700	 701	 0.003931	 0.115951	 0.0	 272	 272	 272	 1.002004	 0.0	 1	 -30.0	 30.0;
	702	 705	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	703	 705	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	704	 706	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	707	 709	 0.003022	 0.115951	 0.0	 264	 264	 264	 0.996016	 0.0	 1	 -30.0	 30.0;
	707	 709	 0.003536	 0.121877	 0.0	 251	 251	 251	 0.984254	 0.0	 1	 -30.0	 30.0;
	714	 717	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	713	 717	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	712	 717	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	716	 717	 0.0032	 0.113185	 0.0	 270	 270	 270	 0.981358	 0.0	 1	 -30.0	 30.0;
	715	 717	 0.0032	 0.113185	 0.0	 270	 270	 270	 0.974655	 0.0	 1	 -30.0	 30.0;
	715	 717	 0.003062	 0.116148	 0.0	 263	 263	 263	 0.973708	 0.0	 1	 -30.0	 30.0;
	730	 732	 0.003062	 0.116741	 0.0	 268	 268	 268	 1.0	 0.0	 1	 -30.0	 30.0;
	731	 732	 0.00318	 0.115753	 0.0	 270	 270	 270	 1.0142	 0.0	 1	 -30.0	 30.0;
	730	 732	 0.003062	 0.117728	 0.0	 266	 266	 266	 1.0	 0.0	 1	 -30.0	 30.0;
	747	 748	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.97561	 0.0	 1	 -30.0	 30.0;
	747	 748	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.97371	 0.0	 1	 -30.0	 30.0;
	759	 5873	 0.000249	 -0.004501	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	759	 5903	 0.000152	 -0.00644	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	760	 5873	 6.9e-05	 0.029294	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 5903	 0.00018	 0.03151	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	767	 768	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	773	 774	 0.003733	 0.120296	 0.0	 254	 254	 254	 0.996016	 0.0	 1	 -30.0	 30.0;
	773	 774	 0.003081	 0.116938	 0.0	 261	 261	 261	 0.984254	 0.0	 1	 -30.0	 30.0;
	773	 774	 0.003615	 0.123654	 0.0	 247	 247	 247	 0.996016	 0.0	 1	 -30.0	 30.0;
	775	 778	 0.012346	 0.453263	 0.0	 77	 77	 77	 1.001	 0.0	 1	 -30.0	 30.0;
	776	 778	 0.012346	 0.456286	 0.0	 76	 76	 76	 1.001	 0.0	 1	 -30.0	 30.0;
	777	 778	 0.012598	 0.456034	 0.0	 76	 76	 76	 1.001	 0.0	 1	 -30.0	 30.0;
	781	 782	 0.003635	 0.119704	 0.0	 258	 258	 258	 0.97561	 0.0	 1	 -30.0	 30.0;
	792	 793	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	791	 794	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	793	 795	 0.001975	 0.124444	 0.0	 247	 247	 247	 1.001002	 0.0	 1	 -30.0	 30.0;
	794	 795	 0.00316	 0.125037	 0.001	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	804	 805	 0.002832	 0.155817	 0.0	 203	 203	 203	 0.971818	 0.0	 1	 -30.0	 30.0;
	808	 810	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	807	 810	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	806	 809	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	832	 833	 0.000312	 0.024979	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	854	 855	 0.003062	 0.117136	 0.0	 264	 264	 264	 0.98912	 0.0	 1	 -30.0	 30.0;
	854	 855	 0.003615	 0.114568	 0.0	 270	 270	 270	 0.98912	 0.0	 1	 -30.0	 30.0;
	854	 855	 0.004563	 0.161975	 0.0	 191	 191	 191	 0.98912	 0.0	 1	 -30.0	 30.0;
	855	 856	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	855	 856	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	857	 858	 0.003378	 0.122864	 0.0	 255	 255	 255	 0.987167	 0.0	 1	 -30.0	 30.0;
	857	 858	 0.003338	 0.122667	 0.0	 255	 255	 255	 1.012146	 0.0	 1	 -30.0	 30.0;
	858	 859	 6.9e-05	 0.056094	 0.0	 566	 566	 566	 1.0	 0.0	 1	 -30.0	 30.0;
	884	 886	 0.003121	 0.12484	 0.0	 246	 246	 246	 1.0	 0.0	 1	 -30.0	 30.0;
	885	 886	 0.003081	 0.125412	 0.0	 245	 245	 245	 0.987167	 0.0	 1	 -30.0	 30.0;
	884	 886	 0.003575	 0.126222	 0.0	 244	 244	 244	 0.96432	 0.0	 1	 -30.0	 30.0;
	894	 895	 0.006133	 0.237422	 0.0	 145	 145	 145	 0.938967	 0.0	 1	 -30.0	 30.0;
	920	 5874	 0.000499	 -0.008379	 0.0	 606.0	 606.0	 606.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	919	 5904	 0.000325	 -0.008726	 0.0	 557.0	 557.0	 557.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	921	 5874	 0.000298	 0.048407	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	921	 5904	 0.000381	 0.047715	 0.0	 557.0	 557.0	 557.0	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 929	 0.001814	 0.099308	 0.0	 320	 320	 320	 0.966188	 0.0	 1	 -30.0	 30.0;
	928	 929	 0.001814	 0.099308	 0.0	 320	 320	 320	 0.973709	 0.0	 1	 -30.0	 30.0;
	937	 5875	 0.000166	 -0.005062	 0.0	 1168.0	 1168.0	 1168.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	938	 5927	 0.000166	 -0.010873	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	938	 5941	 0.000152	 -0.007756	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	937	 5951	 0.000118	 -0.007618	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	939	 5875	 0.000201	 0.026437	 0.0	 1168.0	 1168.0	 1168.0	 0.0	 0.0	 1	 -30.0	 30.0;
	940	 5927	 0.000166	 0.038296	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	939	 5941	 0.000187	 0.03518	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	940	 5951	 0.00018	 0.034695	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 943	 0.00397	 0.11121	 0.0	 281	 281	 281	 1.037344	 0.0	 1	 -30.0	 30.0;
	942	 943	 0.003773	 0.123457	 0.0	 253	 253	 253	 1.038422	 0.0	 1	 -30.0	 30.0;
	942	 943	 0.003279	 0.118914	 0.0	 263	 263	 263	 1.02459	 0.0	 1	 -30.0	 30.0;
	953	 954	 0.003556	 0.111605	 0.0	 274	 274	 274	 0.98619	 0.0	 1	 -30.0	 30.0;
	953	 954	 0.003378	 0.121481	 0.0	 251	 251	 251	 0.989123	 0.0	 1	 -30.0	 30.0;
	958	 959	 0.001801	 0.09903	 0.0	 320	 320	 320	 0.981355	 0.0	 1	 -30.0	 30.0;
	958	 959	 0.001801	 0.099723	 0.0	 318	 318	 318	 0.991081	 0.0	 1	 -30.0	 30.0;
	965	 966	 0.001778	 0.091062	 0.0	 335	 335	 335	 0.994038	 0.0	 1	 -30.0	 30.0;
	965	 966	 0.001738	 0.092444	 0.0	 330	 330	 330	 0.994038	 0.0	 1	 -30.0	 30.0;
	965	 966	 0.001758	 0.092049	 0.0	 332	 332	 332	 0.994038	 0.0	 1	 -30.0	 30.0;
	966	 968	 0.000325	 0.026801	 0.0	 1177	 1177	 1177	 1.0	 0.0	 1	 -30.0	 30.0;
	966	 967	 0.000319	 0.026593	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	970	 971	 0.007664	 0.250785	 0.0	 137	 137	 137	 1.0	 0.0	 1	 -30.0	 30.0;
	970	 971	 0.007664	 0.250785	 0.0	 137	 137	 137	 1.0	 0.0	 1	 -30.0	 30.0;
	970	 971	 0.007664	 0.250785	 0.0	 137	 137	 137	 1.0	 0.0	 1	 -30.0	 30.0;
	973	 974	 0.001936	 0.117926	 0.0	 262	 262	 262	 1.009082	 0.0	 1	 -30.0	 30.0;
	973	 974	 0.001995	 0.118716	 0.0	 260	 260	 260	 1.009082	 0.0	 1	 -30.0	 30.0;
	979	 980	 0.001849	 0.101524	 0.0	 310	 310	 310	 0.974656	 0.0	 1	 -30.0	 30.0;
	979	 980	 0.001794	 0.100831	 0.0	 313	 313	 313	 0.974656	 0.0	 1	 -30.0	 30.0;
	981	 982	 0.001837	 0.140247	 0.0	 220	 220	 220	 0.998004	 0.0	 1	 -30.0	 30.0;
	993	 995	 0.003378	 0.105481	 0.0	 291	 291	 291	 0.956938	 0.0	 1	 -30.0	 30.0;
	993	 995	 0.003338	 0.113185	 0.0	 272	 272	 272	 0.952382	 0.0	 1	 -30.0	 30.0;
	1001	 1002	 0.001778	 0.119309	 0.0	 258	 258	 258	 0.95329	 0.0	 1	 -30.0	 30.0;
	1000	 5876	 0.004224	 0.148199	 0.0	 233	 233	 233	 1.0	 0.0	 1	 -30.0	 30.0;
	1001	 1003	 0.001801	 0.101108	 0.0	 313	 313	 313	 0.971818	 0.0	 1	 -30.0	 30.0;
	1001	 1003	 0.001399	 0.101177	 0.0	 313	 313	 313	 0.971818	 0.0	 1	 -30.0	 30.0;
	1002	 5876	 0.000388	 -0.009003	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	1002	 5905	 0.00063	 -0.005194	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	1003	 5876	 0.000395	 0.049169	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1003	 5905	 3.5e-05	 0.048476	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 1017	 0.003556	 0.114568	 0.0	 269	 269	 269	 1.0142	 0.0	 1	 -30.0	 30.0;
	1016	 1017	 0.003951	 0.124444	 0.0	 247	 247	 247	 1.0142	 0.0	 1	 -30.0	 30.0;
	1031	 1033	 0.003101	 0.124049	 0.0	 249	 249	 249	 1.023541	 0.0	 1	 -30.0	 30.0;
	1038	 1039	 0.001699	 0.122864	 0.0	 250	 250	 250	 0.953285	 0.0	 1	 -30.0	 30.0;
	1038	 1039	 0.001699	 0.122469	 0.0	 251	 251	 251	 1.046025	 0.0	 1	 -30.0	 30.0;
	1039	 1040	 0.000325	 0.027147	 0.0	 1168	 1168	 1168	 0.999001	 0.0	 1	 -30.0	 30.0;
	1039	 1040	 0.000319	 0.027216	 0.0	 1165	 1165	 1165	 0.999001	 0.0	 1	 -30.0	 30.0;
	1039	 5928	 0.000229	 -0.008102	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1042	 5928	 8.3e-05	 0.035734	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	1046	 1047	 0.00125	 0.11844	 0.0	 258	 258	 258	 0.975614	 0.0	 1	 -30.0	 30.0;
	1046	 1047	 0.001294	 0.118222	 0.0	 258	 258	 258	 0.994036	 0.0	 1	 -30.0	 30.0;
	1045	 1047	 0.003911	 0.110815	 0.0	 275	 275	 275	 0.987167	 0.0	 1	 -30.0	 30.0;
	1063	 1064	 0.003101	 0.117531	 0.0	 260	 260	 260	 0.973708	 0.0	 1	 -30.0	 30.0;
	1063	 1064	 0.00322	 0.11358	 0.0	 269	 269	 269	 0.974655	 0.0	 1	 -30.0	 30.0;
	1063	 1064	 0.003081	 0.115753	 0.0	 264	 264	 264	 0.992063	 0.0	 1	 -30.0	 30.0;
	1063	 1064	 0.003101	 0.115556	 0.0	 264	 264	 264	 0.983282	 0.0	 1	 -30.0	 30.0;
	1068	 1069	 0.007704	 0.229136	 0.0	 135	 135	 135	 1.001002	 0.0	 1	 -30.0	 30.0;
	1068	 1069	 0.007388	 0.234074	 0.0	 132	 132	 132	 0.989123	 0.0	 1	 -30.0	 30.0;
	1068	 1069	 0.007486	 0.229136	 0.0	 135	 135	 135	 1.001002	 0.0	 1	 -30.0	 30.0;
	1076	 1077	 0.000339	 0.027285	 0.0	 1162	 1162	 1162	 1.0	 0.0	 1	 -30.0	 30.0;
	1076	 1077	 0.000339	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	1076	 5929	 0.000132	 -0.007479	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1077	 5929	 0.000173	 0.034764	 0.0	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	1078	 1079	 0.003773	 0.119506	 0.0	 258	 258	 258	 0.956938	 0.0	 1	 -30.0	 30.0;
	1078	 1079	 0.003516	 0.125037	 0.0	 247	 247	 247	 0.956938	 0.0	 1	 -30.0	 30.0;
	1092	 1093	 0.00316	 0.112988	 0.0	 273	 273	 273	 0.983282	 0.0	 1	 -30.0	 30.0;
	1113	 1114	 0.014568	 0.185185	 0.0	 186	 186	 186	 1.0	 0.0	 1	 -30.0	 30.0;
	1116	 1117	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.012146	 0.0	 1	 -30.0	 30.0;
	1116	 1117	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.035197	 0.0	 1	 -30.0	 30.0;
	1135	 1136	 0.003951	 0.113383	 0.0	 269	 269	 269	 0.973708	 0.0	 1	 -30.0	 30.0;
	1135	 1136	 0.003062	 0.118321	 0.0	 258	 258	 258	 0.973708	 0.0	 1	 -30.0	 30.0;
	1141	 1143	 0.004286	 0.164741	 0.0	 187	 187	 187	 0.978474	 0.0	 1	 -30.0	 30.0;
	1142	 1143	 0.005077	 0.17284	 0.0	 178	 178	 178	 0.978474	 0.0	 1	 -30.0	 30.0;
	1146	 1147	 0.003595	 0.120889	 0.0	 253	 253	 253	 0.987167	 0.0	 1	 -30.0	 30.0;
	1146	 1147	 0.003121	 0.130963	 0.0	 233	 233	 233	 0.987167	 0.0	 1	 -30.0	 30.0;
	1150	 1151	 0.002469	 0.533333	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	1157	 1158	 0.00316	 0.125037	 0.0	 246	 246	 246	 0.989123	 0.0	 1	 -30.0	 30.0;
	1157	 1158	 0.004741	 0.161185	 0.0	 191	 191	 191	 0.978477	 0.0	 1	 -30.0	 30.0;
	1156	 1158	 0.004938	 0.16237	 0.0	 190	 190	 190	 0.978477	 0.0	 1	 -30.0	 30.0;
	1164	 1167	 0.00162	 0.099279	 0.0	 311	 311	 311	 0.980391	 0.0	 1	 -30.0	 30.0;
	1165	 1167	 0.001679	 0.099457	 0.0	 310	 310	 310	 0.980391	 0.0	 1	 -30.0	 30.0;
	1166	 1167	 0.001659	 0.099496	 0.0	 310	 310	 310	 0.98619	 0.0	 1	 -30.0	 30.0;
	1174	 1175	 0.001778	 0.092385	 0.0	 331	 331	 331	 0.985226	 0.0	 1	 -30.0	 30.0;
	1174	 1175	 0.001817	 0.091654	 0.0	 333	 333	 333	 0.982323	 0.0	 1	 -30.0	 30.0;
	1174	 1175	 0.001798	 0.091457	 0.0	 334	 334	 334	 0.982323	 0.0	 1	 -30.0	 30.0;
	1174	 1175	 0.001817	 0.091654	 0.0	 333	 333	 333	 0.982323	 0.0	 1	 -30.0	 30.0;
	1195	 1196	 0.003556	 0.123654	 0.0	 249	 249	 249	 0.965249	 0.0	 1	 -30.0	 30.0;
	1194	 1196	 0.003753	 0.120494	 0.0	 255	 255	 255	 0.976559	 0.0	 1	 -30.0	 30.0;
	1195	 1197	 0.00316	 0.12563	 0.0	 245	 245	 245	 0.965249	 0.0	 1	 -30.0	 30.0;
	1196	 1198	 0.000325	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1197	 1198	 0.000325	 0.025346	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1199	 1200	 0.000332	 0.027078	 0.0	 1165	 1165	 1165	 1.0	 0.0	 1	 -30.0	 30.0;
	1199	 1200	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 0.999001	 0.0	 1	 -30.0	 30.0;
	1199	 1200	 0.000817	 0.042313	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1199	 1200	 0.000686	 0.043075	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1202	 1203	 0.001896	 0.120296	 0.0	 256	 256	 256	 0.974661	 0.0	 1	 -30.0	 30.0;
	1202	 1203	 0.002153	 0.116543	 0.0	 264	 264	 264	 0.986189	 0.0	 1	 -30.0	 30.0;
	1208	 1209	 0.00324	 0.116543	 0.0	 265	 265	 265	 0.956938	 0.0	 1	 -30.0	 30.0;
	1208	 1209	 0.001679	 0.122667	 0.0	 252	 252	 252	 0.986189	 0.0	 1	 -30.0	 30.0;
	1211	 1212	 0.003417	 0.126222	 0.0	 242	 242	 242	 0.987167	 0.0	 1	 -30.0	 30.0;
	1211	 1212	 0.003812	 0.111605	 0.0	 274	 274	 274	 1.0	 0.0	 1	 -30.0	 30.0;
	1211	 1212	 0.002035	 0.111605	 0.0	 274	 274	 274	 1.0	 0.0	 1	 -30.0	 30.0;
	1229	 1230	 0.003575	 0.123062	 0.0	 248	 248	 248	 0.951472	 0.0	 1	 -30.0	 30.0;
	1237	 1236	 0.000494	 0.005222	 0.0	 6597	 6597	 6597	 1.0	 0.0	 1	 -30.0	 30.0;
	1239	 1241	 0.003753	 0.122864	 0.0	 250	 250	 250	 0.95329	 0.0	 1	 -30.0	 30.0;
	1238	 1241	 0.003556	 0.127802	 0.0	 241	 241	 241	 0.95329	 0.0	 1	 -30.0	 30.0;
	1239	 1242	 0.003951	 0.125235	 0.0	 246	 246	 246	 0.965249	 0.0	 1	 -30.0	 30.0;
	1242	 1243	 0.000319	 0.024723	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1241	 1243	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1244	 1245	 0.004523	 0.16	 0.0	 193	 193	 193	 0.956938	 0.0	 1	 -30.0	 30.0;
	1247	 1248	 0.004622	 0.159012	 0.0	 194	 194	 194	 1.023541	 0.0	 1	 -30.0	 30.0;
	1247	 1248	 0.004622	 0.16	 0.0	 193	 193	 193	 1.012147	 0.0	 1	 -30.0	 30.0;
	1247	 1248	 0.004286	 0.165333	 0.0	 187	 187	 187	 1.023541	 0.0	 1	 -30.0	 30.0;
	1249	 1250	 0.009956	 0.365333	 0.0	 86	 86	 86	 1.035197	 0.0	 1	 -30.0	 30.0;
	1249	 1250	 0.016578	 0.457778	 0.0	 69	 69	 69	 1.037345	 0.0	 1	 -30.0	 30.0;
	1251	 1252	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	1258	 1259	 0.003575	 0.121481	 0.0	 264	 264	 264	 1.009082	 0.0	 1	 -30.0	 30.0;
	1258	 1259	 0.003081	 0.115951	 0.0	 276	 276	 276	 0.997009	 0.0	 1	 -30.0	 30.0;
	1263	 1265	 0.003279	 0.117926	 0.0	 262	 262	 262	 1.0	 0.0	 1	 -30.0	 30.0;
	1264	 1265	 0.00324	 0.116543	 0.0	 265	 265	 265	 1.0	 0.0	 1	 -30.0	 30.0;
	1263	 1265	 0.003042	 0.116938	 0.0	 264	 264	 264	 1.0	 0.0	 1	 -30.0	 30.0;
	5952	 1265	 0.000402	 -0.007341	 0.0	 581.0	 581.0	 581.0	 1.049318	 0.0	 1	 -30.0	 30.0;
	1265	 1266	 0.000263	 0.025277	 0.0	 585.0	 585.0	 585.0	 0.959693	 0.0	 1	 -30.0	 30.0;
	1265	 1266	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1266	 5952	 0.000242	 0.03144	 0.0	 581.0	 581.0	 581.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1308	 1310	 0.070799	 1.73847	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	1309	 1310	 0.075586	 1.51172	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	1325	 1326	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.999001	 0.0	 1	 -30.0	 30.0;
	1325	 1326	 0.004286	 0.162765	 0.0	 188	 188	 188	 1.0	 0.0	 1	 -30.0	 30.0;
	1332	 1333	 0.004642	 0.163556	 0.0	 189	 189	 189	 0.96712	 0.0	 1	 -30.0	 30.0;
	1332	 1333	 0.004642	 0.163556	 0.0	 189	 189	 189	 0.980392	 0.0	 1	 -30.0	 30.0;
	1333	 1334	 0.000332	 0.024654	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1333	 1334	 0.000312	 0.024654	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1335	 1336	 0.012598	 0.307382	 0.0	 96	 96	 96	 0.951479	 0.0	 1	 -30.0	 30.0;
	1343	 1344	 0.002094	 0.115753	 0.0	 268	 268	 268	 0.96432	 0.0	 1	 -30.0	 30.0;
	1345	 1346	 0.003951	 0.124642	 0.0	 247	 247	 247	 0.965249	 0.0	 1	 -30.0	 30.0;
	1345	 1346	 0.001975	 0.108642	 0.0	 283	 283	 283	 0.978477	 0.0	 1	 -30.0	 30.0;
	1349	 1350	 0.006133	 0.237422	 0.0	 145	 145	 145	 0.938967	 0.0	 1	 -30.0	 30.0;
	1357	 1358	 0.001758	 0.090469	 0.0	 338	 338	 338	 1.006036	 0.0	 1	 -30.0	 30.0;
	1357	 1358	 0.001936	 0.092049	 0.0	 332	 332	 332	 0.995025	 0.0	 1	 -30.0	 30.0;
	1357	 1358	 0.001857	 0.092444	 0.0	 330	 330	 330	 1.006036	 0.0	 1	 -30.0	 30.0;
	1359	 1360	 0.004346	 0.169481	 0.0	 182	 182	 182	 1.012146	 0.0	 1	 -30.0	 30.0;
	1359	 1360	 0.004247	 0.169086	 0.0	 183	 183	 183	 1.012146	 0.0	 1	 -30.0	 30.0;
	1359	 1360	 0.004267	 0.169679	 0.0	 182	 182	 182	 1.012146	 0.0	 1	 -30.0	 30.0;
	1380	 1381	 0.003496	 0.111407	 0.0	 288	 288	 288	 1.009082	 0.0	 1	 -30.0	 30.0;
	1386	 1387	 0.001699	 0.122469	 0.0	 251	 251	 251	 1.046025	 0.0	 1	 -30.0	 30.0;
	1386	 1387	 0.001956	 0.117531	 0.0	 262	 262	 262	 0.998004	 0.0	 1	 -30.0	 30.0;
	1386	 1387	 0.003101	 0.125235	 0.0	 245	 245	 245	 1.010101	 0.0	 1	 -30.0	 30.0;
	1407	 1408	 0.003062	 0.125432	 0.0	 245	 245	 245	 0.978473	 0.0	 1	 -30.0	 30.0;
	1409	 1411	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	1410	 1411	 0.002588	 0.115358	 0.0	 265	 265	 265	 1.008064	 0.0	 1	 -30.0	 30.0;
	1410	 1411	 0.003081	 0.115358	 0.0	 265	 265	 265	 0.996016	 0.0	 1	 -30.0	 30.0;
	1434	 1435	 0.003081	 0.117531	 0.0	 263	 263	 263	 0.953289	 0.0	 1	 -30.0	 30.0;
	1434	 1435	 0.003911	 0.111605	 0.0	 277	 277	 277	 0.96432	 0.0	 1	 -30.0	 30.0;
	1441	 1442	 0.001679	 0.122667	 0.0	 252	 252	 252	 0.998004	 0.0	 1	 -30.0	 30.0;
	1441	 1442	 0.001995	 0.118716	 0.0	 260	 260	 260	 0.998004	 0.0	 1	 -30.0	 30.0;
	1445	 1446	 0.003852	 0.12642	 0.0	 242	 242	 242	 0.987165	 0.0	 1	 -30.0	 30.0;
	1444	 1446	 0.003812	 0.12484	 0.0	 245	 245	 245	 0.987165	 0.0	 1	 -30.0	 30.0;
	1456	 1457	 0.003812	 0.146963	 0.0	 210	 210	 210	 0.952382	 0.0	 1	 -30.0	 30.0;
	1459	 1460	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	1462	 1463	 0.003002	 0.115951	 0.0	 264	 264	 264	 0.939847	 0.0	 1	 -30.0	 30.0;
	1462	 1463	 0.003615	 0.123062	 0.0	 248	 248	 248	 0.939847	 0.0	 1	 -30.0	 30.0;
	1463	 5877	 0.000263	 -0.005471	 0.0	 1184.0	 1184.0	 1184.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1464	 5877	 6.2e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 1466	 0.001358	 0.10963	 0.0	 293	 293	 293	 1.001002	 0.0	 1	 -30.0	 30.0;
	1465	 1467	 0.00324	 0.111605	 0.0	 280	 280	 280	 1.048219	 0.0	 1	 -30.0	 30.0;
	1465	 1467	 0.004148	 0.112	 0.0	 279	 279	 279	 1.038422	 0.0	 1	 -30.0	 30.0;
	1473	 1474	 0.003891	 0.129185	 0.0	 239	 239	 239	 0.98619	 0.0	 1	 -30.0	 30.0;
	1479	 1480	 0.003931	 0.125373	 0.0	 244	 244	 244	 0.963394	 0.0	 1	 -30.0	 30.0;
	1479	 1480	 0.003931	 0.125373	 0.0	 244	 244	 244	 0.963394	 0.0	 1	 -30.0	 30.0;
	1485	 1487	 0.003081	 0.117728	 0.0	 261	 261	 261	 0.984254	 0.0	 1	 -30.0	 30.0;
	1503	 1504	 0.002607	 0.115279	 0.0	 268	 268	 268	 1.090512	 0.0	 1	 -30.0	 30.0;
	1518	 1519	 0.000768	 0.089185	 0.0	 343	 343	 343	 0.971818	 0.0	 1	 -30.0	 30.0;
	1518	 1519	 0.004306	 0.158025	 0.0	 193	 193	 193	 0.968992	 0.0	 1	 -30.0	 30.0;
	1518	 1519	 0.004306	 0.159407	 0.0	 192	 192	 192	 0.968992	 0.0	 1	 -30.0	 30.0;
	1519	 1520	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 0.999001	 0.0	 1	 -30.0	 30.0;
	1519	 1520	 0.000796	 0.041551	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1519	 1520	 0.000727	 0.048753	 0.0	 607.0	 607.0	 607.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1519	 1520	 0.000325	 0.027562	 0.0	 1145	 1145	 1145	 1.0	 0.0	 1	 -30.0	 30.0;
	1523	 1525	 0.003714	 0.086361	 0.001	 403	 403	 403	 0.883392	 0.0	 1	 -30.0	 30.0;
	1522	 1525	 0.00156	 0.048494	 0.001	 717	 717	 717	 1.0101	 0.0	 1	 -30.0	 30.0;
	1526	 1527	 0.003121	 0.117531	 0.0	 260	 260	 260	 0.952382	 0.0	 1	 -30.0	 30.0;
	1526	 1527	 0.003635	 0.122469	 0.0	 249	 249	 249	 0.952382	 0.0	 1	 -30.0	 30.0;
	1533	 1535	 0.00316	 0.11516	 0.0	 265	 265	 265	 0.966187	 0.0	 1	 -30.0	 30.0;
	1534	 1535	 0.003042	 0.117728	 0.0	 260	 260	 260	 0.962466	 0.0	 1	 -30.0	 30.0;
	1533	 1535	 0.003891	 0.111407	 0.0	 274	 274	 274	 0.973708	 0.0	 1	 -30.0	 30.0;
	1533	 1536	 0.001357	 0.09973	 0.0	 316	 316	 316	 0.984249	 0.0	 1	 -30.0	 30.0;
	1535	 5942	 0.000159	 -0.007133	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1535	 5953	 0.000277	 -0.005609	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1536	 5942	 0.000173	 0.033726	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 5953	 6.2e-05	 0.032964	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 1542	 0.000325	 0.024792	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1543	 1544	 0.001778	 0.101333	 0.0	 305	 305	 305	 0.996016	 0.0	 1	 -30.0	 30.0;
	1543	 1544	 0.001778	 0.101136	 0.0	 305	 305	 305	 0.996016	 0.0	 1	 -30.0	 30.0;
	1564	 1565	 0.00316	 0.108049	 0.0	 286	 286	 286	 1.002004	 0.0	 1	 -30.0	 30.0;
	1564	 1565	 0.003002	 0.118519	 0.0	 260	 260	 260	 0.997009	 0.0	 1	 -30.0	 30.0;
	1564	 1565	 0.00316	 0.109037	 0.0	 283	 283	 283	 1.002004	 0.0	 1	 -30.0	 30.0;
	1585	 1586	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1585	 1586	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1588	 1589	 0.003062	 0.116543	 0.0	 275	 275	 275	 1.02145	 0.0	 1	 -30.0	 30.0;
	1588	 1589	 0.003101	 0.116938	 0.0	 274	 274	 274	 1.009082	 0.0	 1	 -30.0	 30.0;
	1598	 1600	 0.003042	 0.115753	 0.0	 264	 264	 264	 0.939847	 0.0	 1	 -30.0	 30.0;
	1599	 1600	 0.003951	 0.112395	 0.0	 272	 272	 272	 0.929369	 0.0	 1	 -30.0	 30.0;
	1600	 5878	 0.000145	 -0.007548	 0.0	 1187.0	 1187.0	 1187.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1600	 5906	 0.000533	 -0.004848	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1601	 5878	 0.000187	 0.03428	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 5906	 0.000173	 0.053186	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1602	 1603	 0.00241	 0.126222	 0.0	 244	 244	 244	 0.995025	 0.0	 1	 -30.0	 30.0;
	1602	 1603	 0.003852	 0.12563	 0.0	 245	 245	 245	 0.999001	 0.0	 1	 -30.0	 30.0;
	1602	 1604	 0.003793	 0.120889	 0.0	 254	 254	 254	 1.012146	 0.0	 1	 -30.0	 30.0;
	1614	 1615	 0.005378	 0.132356	 0.0	 229	 229	 229	 0.919963	 0.0	 1	 -30.0	 30.0;
	1614	 1615	 0.004356	 0.137467	 0.0	 221	 221	 221	 0.932835	 0.0	 1	 -30.0	 30.0;
	1617	 1618	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.0142	 0.0	 1	 -30.0	 30.0;
	1616	 1618	 0.003951	 0.12563	 0.0	 245	 245	 245	 1.026695	 0.0	 1	 -30.0	 30.0;
	1616	 1618	 0.001778	 0.111012	 0.0	 277	 277	 277	 1.0142	 0.0	 1	 -30.0	 30.0;
	1620	 1621	 0.011482	 0.318519	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	1638	 1639	 0.001778	 0.121481	 0.0	 251	 251	 251	 1.02459	 0.0	 1	 -30.0	 30.0;
	1638	 1639	 0.001778	 0.121481	 0.0	 251	 251	 251	 1.02459	 0.0	 1	 -30.0	 30.0;
	1638	 1639	 0.001778	 0.121481	 0.0	 251	 251	 251	 1.02459	 0.0	 1	 -30.0	 30.0;
	1669	 1670	 0.003358	 0.121481	 0.0	 254	 254	 254	 0.976559	 0.0	 1	 -30.0	 30.0;
	1669	 1670	 0.003694	 0.120494	 0.0	 256	 256	 256	 0.976559	 0.0	 1	 -30.0	 30.0;
	1673	 1674	 0.001857	 0.114963	 0.0	 269	 269	 269	 0.965246	 0.0	 1	 -30.0	 30.0;
	1673	 1674	 0.001857	 0.115358	 0.0	 268	 268	 268	 0.999001	 0.0	 1	 -30.0	 30.0;
	1682	 1683	 0.00316	 0.125827	 0.0	 245	 245	 245	 1.001002	 0.0	 1	 -30.0	 30.0;
	1682	 1683	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	1689	 1690	 0.003931	 0.111605	 0.0	 273	 273	 273	 0.990104	 0.0	 1	 -30.0	 30.0;
	1689	 1690	 0.003931	 0.111605	 0.0	 273	 273	 273	 0.978473	 0.0	 1	 -30.0	 30.0;
	1708	 1711	 0.003279	 0.110222	 0.0	 279	 279	 279	 0.968054	 0.0	 1	 -30.0	 30.0;
	1709	 1713	 0.003338	 0.113975	 0.0	 270	 270	 270	 0.96432	 0.0	 1	 -30.0	 30.0;
	1709	 1710	 0.00318	 0.125432	 0.0	 245	 245	 245	 0.97561	 0.0	 1	 -30.0	 30.0;
	1708	 1712	 0.003002	 0.107062	 0.0	 287	 287	 287	 0.947871	 0.0	 1	 -30.0	 30.0;
	1717	 1718	 0.00399	 0.113383	 0.0	 276	 276	 276	 1.037344	 0.0	 1	 -30.0	 30.0;
	1717	 1718	 0.003872	 0.110617	 0.0	 283	 283	 283	 1.037344	 0.0	 1	 -30.0	 30.0;
	1722	 1723	 0.003556	 0.122864	 0.0	 249	 249	 249	 0.962466	 0.0	 1	 -30.0	 30.0;
	1722	 1723	 0.00316	 0.112593	 0.0	 271	 271	 271	 0.957856	 0.0	 1	 -30.0	 30.0;
	1728	 1729	 0.045352	 0.942555	 0.0	 37	 37	 37	 1.001	 0.0	 1	 -30.0	 30.0;
	1735	 1737	 0.003101	 0.118519	 0.0	 261	 261	 261	 1.011122	 0.0	 1	 -30.0	 30.0;
	1735	 1737	 0.003101	 0.118914	 0.0	 260	 260	 260	 0.999001	 0.0	 1	 -30.0	 30.0;
	1749	 1752	 0.007901	 0.341728	 0.0	 101	 101	 101	 1.0	 0.0	 1	 -30.0	 30.0;
	1748	 1751	 0.007901	 0.341728	 0.0	 101	 101	 101	 1.0	 0.0	 1	 -30.0	 30.0;
	1747	 1750	 0.007901	 0.341728	 0.0	 101	 101	 101	 1.0	 0.0	 1	 -30.0	 30.0;
	1753	 1755	 0.003635	 0.123654	 0.0	 247	 247	 247	 0.952382	 0.0	 1	 -30.0	 30.0;
	1754	 1755	 0.004484	 0.118716	 0.0	 257	 257	 257	 0.96432	 0.0	 1	 -30.0	 30.0;
	1776	 1779	 0.004286	 0.165531	 0.0	 185	 185	 185	 0.978474	 0.0	 1	 -30.0	 30.0;
	1777	 1779	 0.00316	 0.112395	 0.0	 272	 272	 272	 0.992063	 0.0	 1	 -30.0	 30.0;
	1778	 1779	 0.003042	 0.116938	 0.0	 261	 261	 261	 1.009082	 0.0	 1	 -30.0	 30.0;
	1778	 1779	 0.003951	 0.111605	 0.0	 274	 274	 274	 1.009082	 0.0	 1	 -30.0	 30.0;
	1778	 1779	 0.003931	 0.112198	 0.0	 272	 272	 272	 1.02145	 0.0	 1	 -30.0	 30.0;
	1781	 1782	 0.001778	 0.100148	 0.0	 308	 308	 308	 1.01833	 0.0	 1	 -30.0	 30.0;
	1781	 1782	 0.001778	 0.100346	 0.0	 308	 308	 308	 1.01833	 0.0	 1	 -30.0	 30.0;
	1781	 1782	 0.000968	 0.105481	 0.0	 293	 293	 293	 1.00705	 0.0	 1	 -30.0	 30.0;
	1786	 1787	 0.00316	 0.12563	 0.0	 245	 245	 245	 1.001002	 0.0	 1	 -30.0	 30.0;
	1786	 1787	 0.00316	 0.125432	 0.0	 245	 245	 245	 1.001002	 0.0	 1	 -30.0	 30.0;
	1792	 1793	 0.012963	 0.267901	 0.0	 114	 114	 114	 1.020408	 0.0	 1	 -30.0	 30.0;
	1792	 1794	 0.004563	 0.161975	 0.0	 191	 191	 191	 0.978474	 0.0	 1	 -30.0	 30.0;
	1792	 1794	 0.003081	 0.106272	 0.0	 291	 291	 291	 0.968054	 0.0	 1	 -30.0	 30.0;
	1792	 1794	 0.003852	 0.116543	 0.0	 265	 265	 265	 0.974664	 0.0	 1	 -30.0	 30.0;
	1793	 1794	 0.001778	 0.12721	 0.0	 243	 243	 243	 0.996016	 0.0	 1	 -30.0	 30.0;
	1795	 1796	 0.003635	 0.118519	 0.0	 261	 261	 261	 0.999001	 0.0	 1	 -30.0	 30.0;
	1795	 1796	 0.003279	 0.125235	 0.0	 247	 247	 247	 0.974664	 0.0	 1	 -30.0	 30.0;
	1804	 1805	 0.00316	 0.125037	 0.0	 246	 246	 246	 0.989123	 0.0	 1	 -30.0	 30.0;
	1811	 1812	 0.003477	 0.145185	 0.0	 212	 212	 212	 0.96618	 0.0	 1	 -30.0	 30.0;
	1811	 1812	 0.003536	 0.147556	 0.0	 208	 208	 208	 0.974659	 0.0	 1	 -30.0	 30.0;
	1823	 1824	 0.003081	 0.125037	 0.0	 247	 247	 247	 1.023541	 0.0	 1	 -30.0	 30.0;
	1823	 1824	 0.001956	 0.126025	 0.0	 245	 245	 245	 0.974664	 0.0	 1	 -30.0	 30.0;
	1827	 1828	 0.003121	 0.125432	 0.0	 246	 246	 246	 0.97561	 0.0	 1	 -30.0	 30.0;
	1828	 1829	 0.000735	 0.044668	 0.0	 593.0	 593.0	 593.0	 0.959693	 0.0	 1	 -30.0	 30.0;
	1832	 1833	 0.001857	 0.121086	 0.0	 252	 252	 252	 1.02459	 0.0	 1	 -30.0	 30.0;
	1832	 1833	 0.001857	 0.121086	 0.0	 252	 252	 252	 1.02459	 0.0	 1	 -30.0	 30.0;
	1838	 1839	 0.004543	 0.112395	 0.0	 274	 274	 274	 0.989123	 0.0	 1	 -30.0	 30.0;
	1838	 1839	 0.00316	 0.116938	 0.0	 263	 263	 263	 1.001002	 0.0	 1	 -30.0	 30.0;
	1843	 1844	 0.003654	 0.122074	 0.0	 253	 253	 253	 1.010101	 0.0	 1	 -30.0	 30.0;
	1843	 1844	 0.003496	 0.122074	 0.0	 253	 253	 253	 0.999001	 0.0	 1	 -30.0	 30.0;
	1883	 1884	 0.003536	 0.122864	 0.0	 251	 251	 251	 0.929369	 0.0	 1	 -30.0	 30.0;
	1897	 1901	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1896	 1900	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1895	 1899	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1894	 1898	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1904	 1905	 0.001778	 0.122864	 0.0	 250	 250	 250	 1.022495	 0.0	 1	 -30.0	 30.0;
	1904	 1905	 0.00158	 0.122272	 0.0	 252	 252	 252	 1.010101	 0.0	 1	 -30.0	 30.0;
	1906	 1907	 0.004543	 0.163556	 0.0	 189	 189	 189	 0.95511	 0.0	 1	 -30.0	 30.0;
	1913	 1914	 0.003595	 0.126222	 0.0	 245	 245	 245	 0.97561	 0.0	 1	 -30.0	 30.0;
	1913	 1914	 0.003615	 0.125432	 0.0	 246	 246	 246	 0.97561	 0.0	 1	 -30.0	 30.0;
	1928	 1929	 0.004267	 0.165136	 0.0	 187	 187	 187	 0.989122	 0.0	 1	 -30.0	 30.0;
	1928	 1929	 0.005926	 0.23763	 0.0	 130	 130	 130	 0.989122	 0.0	 1	 -30.0	 30.0;
	1930	 1931	 0.003026	 0.155471	 0.0	 203	 203	 203	 0.956942	 0.0	 1	 -30.0	 30.0;
	1934	 5907	 0.003435	 0.08608	 0.0	 401	 401	 401	 1.0	 0.0	 1	 -30.0	 30.0;
	1935	 1936	 0.000803	 0.034418	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1935	 5907	 0.000277	 -0.004709	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1936	 5907	 4.8e-05	 0.029571	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 1938	 0.001807	 0.100554	 0.0	 313	 313	 313	 0.939851	 0.0	 1	 -30.0	 30.0;
	1943	 1945	 0.00316	 0.115753	 0.0	 277	 277	 277	 1.070664	 0.0	 1	 -30.0	 30.0;
	1943	 1946	 0.001835	 0.099792	 0.0	 323	 323	 323	 0.994038	 0.0	 1	 -30.0	 30.0;
	1944	 1946	 0.001842	 0.10097	 0.0	 319	 319	 319	 1.043841	 0.0	 1	 -30.0	 30.0;
	1945	 1946	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1962	 1963	 0.000332	 0.024723	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1962	 1963	 0.000305	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1972	 1978	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1971	 1976	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1970	 1975	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1969	 1974	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1968	 1973	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1981	 1984	 0.001975	 0.157432	 0.0	 218	 218	 218	 1.0	 0.0	 1	 -30.0	 30.0;
	1990	 1991	 0.01284	 0.265432	 0.0	 113	 113	 113	 0.968053	 0.0	 1	 -30.0	 30.0;
	1990	 1992	 0.002449	 0.118736	 0.0	 257	 257	 257	 0.939847	 0.0	 1	 -30.0	 30.0;
	1991	 1992	 0.003002	 0.116543	 0.0	 262	 262	 262	 1.009082	 0.0	 1	 -30.0	 30.0;
	1991	 1992	 0.003042	 0.116148	 0.0	 263	 263	 263	 1.009082	 0.0	 1	 -30.0	 30.0;
	1997	 1998	 0.001798	 0.122667	 0.0	 252	 252	 252	 0.98619	 0.0	 1	 -30.0	 30.0;
	1997	 1998	 0.001798	 0.119704	 0.0	 258	 258	 258	 0.98619	 0.0	 1	 -30.0	 30.0;
	1997	 1998	 0.002173	 0.119783	 0.0	 258	 258	 258	 0.987165	 0.0	 1	 -30.0	 30.0;
	2012	 2013	 0.003595	 0.119506	 0.0	 258	 258	 258	 0.974664	 0.0	 1	 -30.0	 30.0;
	2012	 2013	 0.004642	 0.160988	 0.0	 192	 192	 192	 0.968054	 0.0	 1	 -30.0	 30.0;
	2040	 2041	 0.003891	 0.124444	 0.0	 248	 248	 248	 0.94697	 0.0	 1	 -30.0	 30.0;
	2040	 2041	 0.003911	 0.11279	 0.0	 274	 274	 274	 0.956938	 0.0	 1	 -30.0	 30.0;
	2049	 2050	 0.003141	 0.110775	 0.0	 279	 279	 279	 0.97656	 0.0	 1	 -30.0	 30.0;
	2048	 2050	 0.00324	 0.116543	 0.0	 265	 265	 265	 0.968054	 0.0	 1	 -30.0	 30.0;
	2056	 2057	 0.000319	 0.02687	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	2056	 2057	 0.000339	 0.02687	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	2056	 2057	 0.00036	 0.027285	 0.0	 1156	 1156	 1156	 1.0	 0.0	 1	 -30.0	 30.0;
	2073	 2075	 0.002909	 0.158587	 0.0	 200	 200	 200	 1.031993	 0.0	 1	 -30.0	 30.0;
	2073	 2074	 0.002832	 0.157202	 0.0	 202	 202	 202	 1.021451	 0.0	 1	 -30.0	 30.0;
	2077	 2078	 0.003812	 0.121481	 0.0	 254	 254	 254	 0.999001	 0.0	 1	 -30.0	 30.0;
	2077	 2078	 0.004642	 0.163556	 0.0	 189	 189	 189	 1.00705	 0.0	 1	 -30.0	 30.0;
	2086	 2087	 0.003437	 0.128395	 0.0	 238	 238	 238	 0.978473	 0.0	 1	 -30.0	 30.0;
	2086	 2087	 0.003437	 0.128395	 0.0	 238	 238	 238	 0.978473	 0.0	 1	 -30.0	 30.0;
	5879	 2088	 0.000152	 -0.006163	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2088	 2089	 0.000312	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2089	 5879	 0.000159	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	1496	 2095	 0.000119	 0.00796	 0.0	 418.0	 418.0	 418.0	 1.0	 -1.94	 1	 -30.0	 30.0;
	2093	 2095	 0.00322	 0.112	 0.0	 286	 286	 286	 1.047121	 0.0	 1	 -30.0	 30.0;
	2093	 2095	 0.003081	 0.116346	 0.0	 275	 275	 275	 1.047121	 0.0	 1	 -30.0	 30.0;
	2096	 2097	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.974664	 0.0	 1	 -30.0	 30.0;
	2096	 2097	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.963394	 0.0	 1	 -30.0	 30.0;
	2104	 2105	 0.00399	 0.110815	 0.0	 276	 276	 276	 0.96432	 0.0	 1	 -30.0	 30.0;
	2104	 2105	 0.00397	 0.110222	 0.0	 277	 277	 277	 0.96432	 0.0	 1	 -30.0	 30.0;
	2104	 2105	 0.003951	 0.111012	 0.0	 275	 275	 275	 0.96432	 0.0	 1	 -30.0	 30.0;
	2112	 2113	 0.001995	 0.125432	 0.0	 246	 246	 246	 1.012146	 0.0	 1	 -30.0	 30.0;
	2112	 2113	 0.001936	 0.117926	 0.0	 262	 262	 262	 1.011122	 0.0	 1	 -30.0	 30.0;
	2112	 2113	 0.003753	 0.123654	 0.0	 250	 250	 250	 1.011122	 0.0	 1	 -30.0	 30.0;
	2125	 2126	 0.003852	 0.126815	 0.0	 244	 244	 244	 1.011122	 0.0	 1	 -30.0	 30.0;
	2125	 2126	 0.003022	 0.116741	 0.0	 265	 265	 265	 1.011122	 0.0	 1	 -30.0	 30.0;
	2129	 2132	 0.003951	 0.124444	 0.0	 247	 247	 247	 1.001002	 0.0	 1	 -30.0	 30.0;
	2128	 2131	 0.003358	 0.118519	 0.0	 260	 260	 260	 0.989123	 0.0	 1	 -30.0	 30.0;
	2128	 2130	 0.00316	 0.112593	 0.0	 273	 273	 273	 1.001002	 0.0	 1	 -30.0	 30.0;
	2133	 2135	 0.002193	 0.126914	 0.0	 248	 248	 248	 1.034126	 0.0	 1	 -30.0	 30.0;
	2134	 2135	 0.005096	 0.143921	 0.0	 221	 221	 221	 1.0	 0.0	 1	 -30.0	 30.0;
	2134	 2135	 0.005531	 0.188247	 0.0	 169	 169	 169	 1.012149	 0.0	 1	 -30.0	 30.0;
	2137	 2138	 0.013354	 0.302343	 0.0	 98	 98	 98	 0.919967	 0.0	 1	 -30.0	 30.0;
	2137	 2138	 0.013354	 0.302343	 0.0	 98	 98	 98	 0.919967	 0.0	 1	 -30.0	 30.0;
	2137	 2139	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.909091	 0.0	 1	 -30.0	 30.0;
	2137	 2139	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.909091	 0.0	 1	 -30.0	 30.0;
	2143	 2144	 0.003279	 0.109827	 0.0	 281	 281	 281	 0.957856	 0.0	 1	 -30.0	 30.0;
	2143	 2144	 0.003121	 0.117728	 0.0	 262	 262	 262	 0.939847	 0.0	 1	 -30.0	 30.0;
	2148	 2149	 0.004741	 0.164148	 0.0	 188	 188	 188	 0.990101	 0.0	 1	 -30.0	 30.0;
	2148	 2149	 0.003358	 0.106667	 0.0	 288	 288	 288	 1.001002	 0.0	 1	 -30.0	 30.0;
	2149	 2150	 0.000713	 0.043283	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	2149	 2150	 0.000769	 0.043837	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	2162	 2163	 0.001877	 0.093037	 0.0	 332	 332	 332	 0.995025	 0.0	 1	 -30.0	 30.0;
	2166	 2167	 0.003259	 0.109235	 0.0	 292.0	 292.0	 292.0	 1.002004	 0.0	 1	 -30.0	 30.0;
	2166	 2167	 0.00322	 0.109235	 0.0	 292.0	 292.0	 292.0	 0.992064	 0.0	 1	 -30.0	 30.0;
	2166	 2167	 0.00316	 0.113778	 0.0	 282	 282	 282	 0.997009	 0.0	 1	 -30.0	 30.0;
	2173	 2176	 0.003832	 0.11437	 0.0	 270	 270	 270	 1.086957	 0.0	 1	 -30.0	 30.0;
	2173	 2175	 0.003832	 0.11437	 0.0	 270	 270	 270	 1.074114	 0.0	 1	 -30.0	 30.0;
	2185	 2186	 0.003635	 0.114963	 0.0	 267	 267	 267	 0.942507	 0.0	 1	 -30.0	 30.0;
	2185	 5930	 0.001343	 -0.004543	 0.0	 446.0	 446.0	 446.0	 0.94697	 0.0	 1	 -30.0	 30.0;
	2185	 5943	 0.001679	 0.012642	 0.0	 446.0	 446.0	 446.0	 0.937207	 0.0	 1	 -30.0	 30.0;
	2186	 5930	 0.001817	 0.123654	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 5943	 0.001877	 0.098765	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	2197	 2198	 0.000319	 0.027424	 0.0	 1157	 1157	 1157	 1.0	 0.0	 1	 -30.0	 30.0;
	2197	 2198	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	2223	 2224	 0.002983	 0.115951	 0.0	 266	 266	 266	 0.970878	 0.0	 1	 -30.0	 30.0;
	2228	 2229	 0.003358	 0.109827	 0.0	 281	 281	 281	 0.995025	 0.0	 1	 -30.0	 30.0;
	2233	 2234	 0.003852	 0.11279	 0.0	 284	 284	 284	 0.997009	 0.0	 1	 -30.0	 30.0;
	2233	 2234	 0.003852	 0.11279	 0.0	 284	 284	 284	 1.004017	 0.0	 1	 -30.0	 30.0;
	2236	 2237	 0.005679	 0.116173	 0.0	 276	 276	 276	 1.001002	 0.0	 1	 -30.0	 30.0;
	2241	 2242	 0.002074	 0.161778	 0.0	 193	 193	 193	 0.7446	 0.0	 1	 -30.0	 30.0;
	2241	 2242	 0.002074	 0.161778	 0.0	 193	 193	 193	 0.875657	 0.0	 1	 -30.0	 30.0;
	2247	 5880	 0.002864	 0.068543	 0.0	 504	 504	 504	 1.0	 0.0	 1	 -30.0	 30.0;
	2248	 5880	 0.0	 0.001185	 0.0	 29046	 29046	 29046	 0.968054	 0.0	 1	 -30.0	 30.0;
	2249	 5880	 0.006499	 0.143802	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 2255	 0.001896	 0.119704	 0.0	 255	 255	 255	 1.012146	 0.0	 1	 -30.0	 30.0;
	2254	 2255	 0.001896	 0.119704	 0.0	 255	 255	 255	 1.0	 0.0	 1	 -30.0	 30.0;
	2263	 2264	 0.009733	 0.388889	 0.0	 81	 81	 81	 1.061571	 0.0	 1	 -30.0	 30.0;
	2263	 2265	 0.003911	 0.147161	 0.0	 210	 210	 210	 0.97561	 0.0	 1	 -30.0	 30.0;
	2263	 2265	 0.003951	 0.118519	 0.0	 261	 261	 261	 0.97561	 0.0	 1	 -30.0	 30.0;
	2264	 2265	 0.005472	 0.190025	 0.0	 166	 166	 166	 1.0	 0.0	 1	 -30.0	 30.0;
	2268	 2270	 0.003338	 0.12484	 0.0	 263	 263	 263	 1.03627	 0.0	 1	 -30.0	 30.0;
	2272	 2273	 0.00316	 0.113778	 0.0	 282	 282	 282	 1.029866	 0.0	 1	 -30.0	 30.0;
	2272	 2273	 0.00316	 0.113778	 0.0	 282	 282	 282	 1.02145	 0.0	 1	 -30.0	 30.0;
	2272	 2273	 0.003635	 0.120494	 0.0	 266	 266	 266	 1.034126	 0.0	 1	 -30.0	 30.0;
	2289	 2290	 0.00295	 0.163504	 0.0	 194	 194	 194	 0.984249	 0.0	 1	 -30.0	 30.0;
	2292	 2293	 0.003951	 0.112988	 0.0	 272	 272	 272	 1.0142	 0.0	 1	 -30.0	 30.0;
	2292	 2293	 0.003951	 0.124247	 0.0	 248	 248	 248	 1.001002	 0.0	 1	 -30.0	 30.0;
	2298	 2299	 0.003121	 0.125037	 0.0	 247	 247	 247	 1.026695	 0.0	 1	 -30.0	 30.0;
	2298	 2299	 0.003556	 0.119309	 0.0	 258	 258	 258	 1.026695	 0.0	 1	 -30.0	 30.0;
	2308	 2309	 0.003338	 0.121679	 0.0	 254	 254	 254	 0.963394	 0.0	 1	 -30.0	 30.0;
	2308	 2309	 0.003279	 0.117531	 0.0	 263	 263	 263	 0.963394	 0.0	 1	 -30.0	 30.0;
	2314	 2315	 0.003635	 0.126222	 0.0	 245	 245	 245	 0.968054	 0.0	 1	 -30.0	 30.0;
	2314	 2315	 0.003635	 0.126222	 0.0	 245	 245	 245	 0.968054	 0.0	 1	 -30.0	 30.0;
	2314	 2315	 0.003101	 0.12484	 0.0	 247	 247	 247	 0.956938	 0.0	 1	 -30.0	 30.0;
	2327	 2328	 0.003496	 0.118123	 0.0	 261	 261	 261	 0.97561	 0.0	 1	 -30.0	 30.0;
	2334	 2336	 0.00397	 0.124049	 0.0	 246	 246	 246	 1.012147	 0.0	 1	 -30.0	 30.0;
	2335	 2336	 0.003062	 0.117728	 0.0	 259	 259	 259	 0.999001	 0.0	 1	 -30.0	 30.0;
	2335	 2336	 0.003101	 0.125432	 0.0	 243	 243	 243	 0.999001	 0.0	 1	 -30.0	 30.0;
	2336	 2337	 0.000319	 0.024307	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2344	 2346	 0.004543	 0.120691	 0.0	 255	 255	 255	 1.001002	 0.0	 1	 -30.0	 30.0;
	2344	 2346	 0.004346	 0.120691	 0.0	 255	 255	 255	 1.001002	 0.0	 1	 -30.0	 30.0;
	2345	 2346	 0.004741	 0.157432	 0.0	 196	 196	 196	 0.990101	 0.0	 1	 -30.0	 30.0;
	2350	 2352	 0.000693	 0.048753	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2350	 2351	 0.000796	 0.042452	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2368	 2374	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2367	 2372	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2366	 2371	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2365	 2370	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2364	 2369	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2375	 2376	 0.003556	 0.111407	 0.0	 277	 277	 277	 0.963394	 0.0	 1	 -30.0	 30.0;
	2375	 2376	 0.003496	 0.122469	 0.0	 252	 252	 252	 0.956938	 0.0	 1	 -30.0	 30.0;
	2423	 2425	 0.001144	 0.13043	 0.0	 234	 234	 234	 0.985218	 0.0	 1	 -30.0	 30.0;
	2423	 2424	 0.001237	 0.119565	 0.0	 255	 255	 255	 0.996016	 0.0	 1	 -30.0	 30.0;
	2427	 2428	 0.004286	 0.168889	 0.0	 183	 183	 183	 0.968054	 0.0	 1	 -30.0	 30.0;
	2431	 2432	 0.00324	 0.116543	 0.0	 265	 265	 265	 0.978474	 0.0	 1	 -30.0	 30.0;
	2431	 2432	 0.003338	 0.111605	 0.0	 277	 277	 277	 0.974664	 0.0	 1	 -30.0	 30.0;
	2430	 2432	 0.003872	 0.11121	 0.0	 278	 278	 278	 0.987167	 0.0	 1	 -30.0	 30.0;
	2430	 2432	 0.003062	 0.116741	 0.0	 265	 265	 265	 0.97561	 0.0	 1	 -30.0	 30.0;
	2446	 2447	 0.001473	 0.177164	 0.0	 178	 178	 178	 0.905801	 0.0	 1	 -30.0	 30.0;
	2446	 2448	 0.003496	 0.10884	 0.0	 284	 284	 284	 0.963394	 0.0	 1	 -30.0	 30.0;
	2446	 2448	 0.003279	 0.111802	 0.0	 276	 276	 276	 0.963394	 0.0	 1	 -30.0	 30.0;
	2447	 2448	 0.0032	 0.124444	 0.0	 253	 253	 253	 1.0	 0.0	 1	 -30.0	 30.0;
	2457	 2458	 0.00187	 0.104571	 0.0	 301	 301	 301	 0.974656	 0.0	 1	 -30.0	 30.0;
	2457	 2458	 0.001842	 0.099931	 0.0	 315	 315	 315	 0.974656	 0.0	 1	 -30.0	 30.0;
	2466	 2467	 0.000332	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2466	 5908	 0.000145	 -0.006371	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2465	 5931	 0.000132	 -0.006302	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2467	 5908	 0.000187	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	2467	 5931	 0.000187	 0.03144	 0.0	 1089	 1089	 1089	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 2469	 0.003022	 0.115951	 0.0	 266	 266	 266	 0.997009	 0.0	 1	 -30.0	 30.0;
	2468	 2469	 0.003832	 0.111802	 0.0	 276	 276	 276	 0.985226	 0.0	 1	 -30.0	 30.0;
	2468	 2470	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.948768	 0.0	 1	 -30.0	 30.0;
	2468	 2470	 0.001759	 0.101177	 0.0	 313	 313	 313	 0.974656	 0.0	 1	 -30.0	 30.0;
	2469	 2470	 0.000845	 0.042729	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2482	 2484	 0.001778	 0.091062	 0.0	 336	 336	 336	 0.971818	 0.0	 1	 -30.0	 30.0;
	2483	 2484	 0.001758	 0.092247	 0.0	 331	 331	 331	 0.992063	 0.0	 1	 -30.0	 30.0;
	2482	 2484	 0.001798	 0.092049	 0.0	 332	 332	 332	 0.970871	 0.0	 1	 -30.0	 30.0;
	2489	 2490	 0.003951	 0.124247	 0.0	 246	 246	 246	 0.98619	 0.0	 1	 -30.0	 30.0;
	2489	 2490	 0.003062	 0.124444	 0.0	 245	 245	 245	 0.97561	 0.0	 1	 -30.0	 30.0;
	2502	 2503	 0.001778	 0.118519	 0.0	 261	 261	 261	 0.978474	 0.0	 1	 -30.0	 30.0;
	2502	 2503	 0.003931	 0.12484	 0.0	 247	 247	 247	 0.978474	 0.0	 1	 -30.0	 30.0;
	2509	 2510	 0.001936	 0.115358	 0.0	 268	 268	 268	 1.023541	 0.0	 1	 -30.0	 30.0;
	2514	 2515	 0.022222	 0.37037	 0.0	 82	 82	 82	 0.985227	 0.0	 1	 -30.0	 30.0;
	2514	 2515	 0.022222	 0.37037	 0.0	 82	 82	 82	 0.982319	 0.0	 1	 -30.0	 30.0;
	2516	 2517	 0.001798	 0.122667	 0.0	 252	 252	 252	 0.98619	 0.0	 1	 -30.0	 30.0;
	2516	 2517	 0.001798	 0.122667	 0.0	 252	 252	 252	 1.011122	 0.0	 1	 -30.0	 30.0;
	2517	 2518	 0.000332	 0.024238	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	2517	 2518	 0.000332	 0.024238	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	2523	 2524	 0.00318	 0.114765	 0.0	 295	 295	 295	 1.082251	 0.0	 1	 -30.0	 30.0;
	2539	 2540	 0.001975	 0.117531	 0.0	 262	 262	 262	 1.0142	 0.0	 1	 -30.0	 30.0;
	2548	 2549	 0.003867	 0.109333	 0.0	 277	 277	 277	 1.028807	 0.0	 1	 -30.0	 30.0;
	2548	 2550	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.963394	 0.0	 1	 -30.0	 30.0;
	2548	 2550	 0.003852	 0.112	 0.0	 273	 273	 273	 0.97561	 0.0	 1	 -30.0	 30.0;
	2549	 2550	 0.004543	 0.137284	 0.0	 224	 224	 224	 0.952381	 0.0	 1	 -30.0	 30.0;
	2559	 2560	 0.000636	 0.120237	 0.0	 257	 257	 257	 0.926784	 0.0	 1	 -30.0	 30.0;
	2559	 2560	 0.000636	 0.120237	 0.0	 257	 257	 257	 0.937207	 0.0	 1	 -30.0	 30.0;
	2566	 2567	 0.003714	 0.124642	 0.0	 248	 248	 248	 0.987167	 0.0	 1	 -30.0	 30.0;
	2566	 2567	 0.003081	 0.116346	 0.0	 265	 265	 265	 0.987167	 0.0	 1	 -30.0	 30.0;
	2566	 2567	 0.003121	 0.118519	 0.0	 261	 261	 261	 0.953289	 0.0	 1	 -30.0	 30.0;
	2567	 2568	 0.00081	 0.039266	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2567	 2568	 0.00081	 0.039612	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2570	 2571	 0.001778	 0.100148	 0.0	 308	 308	 308	 0.983284	 0.0	 1	 -30.0	 30.0;
	2570	 2571	 0.001778	 0.100148	 0.0	 308	 308	 308	 0.995025	 0.0	 1	 -30.0	 30.0;
	2577	 2578	 0.007055	 0.203578	 0.0	 145	 145	 145	 0.981352	 0.0	 1	 -30.0	 30.0;
	2577	 2580	 0.00322	 0.165926	 0.0	 189	 189	 189	 0.901711	 0.0	 1	 -30.0	 30.0;
	2578	 2580	 0.002686	 0.169877	 0.0	 181	 181	 181	 0.978477	 0.0	 1	 -30.0	 30.0;
	2578	 2580	 0.002686	 0.169877	 0.0	 181	 181	 181	 0.967124	 0.0	 1	 -30.0	 30.0;
	2579	 2580	 0.003338	 0.158025	 0.0	 202	 202	 202	 0.98912	 0.0	 1	 -30.0	 30.0;
	2583	 2584	 0.001778	 0.092049	 0.0	 348	 348	 348	 1.01833	 0.0	 1	 -30.0	 30.0;
	2583	 2584	 0.001837	 0.093827	 0.0	 341	 341	 341	 1.01833	 0.0	 1	 -30.0	 30.0;
	2594	 2595	 0.003951	 0.111605	 0.0	 273	 273	 273	 0.963394	 0.0	 1	 -30.0	 30.0;
	2594	 2595	 0.00316	 0.116148	 0.0	 263	 263	 263	 0.96432	 0.0	 1	 -30.0	 30.0;
	2594	 2595	 0.003279	 0.11516	 0.0	 265	 265	 265	 0.963394	 0.0	 1	 -30.0	 30.0;
	2594	 2595	 0.003081	 0.118123	 0.0	 259	 259	 259	 0.96432	 0.0	 1	 -30.0	 30.0;
	2605	 2607	 0.001842	 0.101731	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	2605	 2606	 0.001821	 0.100762	 0.0	 313	 313	 313	 0.996016	 0.0	 1	 -30.0	 30.0;
	2625	 2626	 0.00399	 0.111605	 0.0	 280	 280	 280	 0.988142	 0.0	 1	 -30.0	 30.0;
	2633	 2635	 0.003615	 0.123062	 0.0	 251	 251	 251	 1.0	 0.0	 1	 -30.0	 30.0;
	2634	 2635	 0.003141	 0.116741	 0.0	 265	 265	 265	 0.987167	 0.0	 1	 -30.0	 30.0;
	2633	 2635	 0.003516	 0.121679	 0.0	 254	 254	 254	 0.978474	 0.0	 1	 -30.0	 30.0;
	2647	 2648	 0.001956	 0.003956	 0.0	 974.0	 974.0	 974.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2654	 2655	 0.003062	 0.116741	 0.0	 268	 268	 268	 1.02459	 0.0	 1	 -30.0	 30.0;
	2660	 2661	 0.003852	 0.12642	 0.0	 242	 242	 242	 1.0	 0.0	 1	 -30.0	 30.0;
	2660	 2661	 0.003852	 0.12642	 0.0	 242	 242	 242	 0.978474	 0.0	 1	 -30.0	 30.0;
	2663	 2665	 0.002016	 0.004031	 0.0	 7637	 7637	 7637	 1.0	 0.0	 1	 -30.0	 30.0;
	2662	 5932	 0.012444	 0.152889	 0.0	 226	 226	 226	 1.0	 0.0	 1	 -30.0	 30.0;
	2664	 2666	 0.003956	 0.039511	 0.0	 863	 863	 863	 1.0	 0.0	 1	 -30.0	 30.0;
	2665	 5932	 0.000889	 0.002667	 0.0	 12244	 12244	 12244	 0.95238	 0.0	 1	 -30.0	 30.0;
	2666	 5932	 0.005333	 0.308444	 0.0	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 2668	 0.002099	 0.116049	 0.0	 256	 256	 256	 0.978469	 0.0	 1	 -30.0	 30.0;
	2669	 2670	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	2675	 2676	 0.00399	 0.124642	 0.0	 248	 248	 248	 1.0	 0.0	 1	 -30.0	 30.0;
	2675	 2676	 0.003556	 0.126025	 0.0	 245	 245	 245	 1.0	 0.0	 1	 -30.0	 30.0;
	2675	 2676	 0.001936	 0.117926	 0.0	 262	 262	 262	 0.999001	 0.0	 1	 -30.0	 30.0;
	2684	 2685	 0.003121	 0.125235	 0.0	 247	 247	 247	 0.974664	 0.0	 1	 -30.0	 30.0;
	2703	 2704	 0.003753	 0.12879	 0.0	 239	 239	 239	 0.989123	 0.0	 1	 -30.0	 30.0;
	2703	 2704	 0.00316	 0.125235	 0.0	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	2705	 2707	 0.00158	 0.117531	 0.0	 262	 262	 262	 1.037345	 0.0	 1	 -30.0	 30.0;
	2705	 2707	 0.001975	 0.11358	 0.0	 271	 271	 271	 1.053742	 0.0	 1	 -30.0	 30.0;
	2706	 2707	 0.001778	 0.118716	 0.0	 259	 259	 259	 1.053742	 0.0	 1	 -30.0	 30.0;
	2713	 2714	 0.000665	 0.043075	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2713	 2714	 0.000672	 0.04356	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	5933	 2713	 0.000554	 -0.004224	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2714	 5933	 0.000118	 0.047576	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2720	 2721	 0.000679	 0.04536	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2720	 2721	 0.000686	 0.045083	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2724	 2725	 0.003259	 0.123852	 0.0	 249	 249	 249	 0.978474	 0.0	 1	 -30.0	 30.0;
	2724	 2725	 0.003081	 0.117728	 0.0	 262	 262	 262	 0.982323	 0.0	 1	 -30.0	 30.0;
	2753	 2754	 0.00316	 0.162963	 0.0	 189	 189	 189	 0.965253	 0.0	 1	 -30.0	 30.0;
	2753	 2754	 0.002765	 0.170864	 0.0	 180	 180	 180	 0.967124	 0.0	 1	 -30.0	 30.0;
	2762	 2763	 0.000332	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2762	 2763	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2762	 2763	 0.000319	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2769	 2770	 0.001758	 0.092247	 0.0	 331	 331	 331	 0.971818	 0.0	 1	 -30.0	 30.0;
	2768	 5881	 0.004993	 0.223892	 0.0	 155	 155	 155	 1.0	 0.0	 1	 -30.0	 30.0;
	2769	 2771	 0.001828	 0.102562	 0.0	 307	 307	 307	 0.956942	 0.0	 1	 -30.0	 30.0;
	2769	 2771	 0.001807	 0.100416	 0.0	 314	 314	 314	 0.948768	 0.0	 1	 -30.0	 30.0;
	2770	 5881	 0.000651	 -0.005055	 0.0	 547.0	 547.0	 547.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2771	 5881	 4.2e-05	 0.05374	 0.0	 547.0	 547.0	 547.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 2775	 0.004938	 0.163556	 0.0	 188	 188	 188	 1.024591	 0.0	 1	 -30.0	 30.0;
	2776	 2777	 0.003654	 0.173235	 0.0	 178	 178	 178	 0.974661	 0.0	 1	 -30.0	 30.0;
	2780	 2781	 0.003378	 0.105679	 0.0	 292	 292	 292	 0.968054	 0.0	 1	 -30.0	 30.0;
	2780	 2781	 0.003299	 0.107654	 0.0	 287	 287	 287	 0.978474	 0.0	 1	 -30.0	 30.0;
	2779	 2782	 0.001807	 0.100831	 0.0	 314	 314	 314	 0.965248	 0.0	 1	 -30.0	 30.0;
	2779	 2782	 0.00178	 0.100139	 0.0	 316	 316	 316	 0.965248	 0.0	 1	 -30.0	 30.0;
	2781	 2782	 0.000759	 0.035838	 0.0	 885	 885	 885	 1.001	 0.0	 1	 -30.0	 30.0;
	2784	 5882	 0.000145	 -0.011219	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2784	 5909	 0.000139	 -0.007687	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2785	 5882	 0.000194	 0.038781	 0.0	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	2786	 5909	 0.000187	 0.034903	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 2791	 0.002074	 0.116741	 0.0	 265	 265	 265	 0.978474	 0.0	 1	 -30.0	 30.0;
	2790	 2791	 0.001936	 0.115951	 0.0	 266	 266	 266	 0.978474	 0.0	 1	 -30.0	 30.0;
	2796	 2798	 0.001752	 0.100485	 0.0	 320	 320	 320	 1.029866	 0.0	 1	 -30.0	 30.0;
	2797	 2798	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2797	 2798	 0.000325	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2803	 2806	 0.003081	 0.117728	 0.0	 261	 261	 261	 0.93985	 0.0	 1	 -30.0	 30.0;
	2804	 2806	 0.004504	 0.162568	 0.0	 189	 189	 189	 0.93985	 0.0	 1	 -30.0	 30.0;
	2805	 2806	 0.003575	 0.121481	 0.0	 259	 259	 259	 1.054854	 0.0	 1	 -30.0	 30.0;
	2809	 2810	 0.003062	 0.116148	 0.0	 263	 263	 263	 0.970872	 0.0	 1	 -30.0	 30.0;
	2809	 2810	 0.003595	 0.123654	 0.0	 247	 247	 247	 0.961535	 0.0	 1	 -30.0	 30.0;
	2814	 2815	 0.003062	 0.116543	 0.0	 265	 265	 265	 1.022495	 0.0	 1	 -30.0	 30.0;
	2814	 2815	 0.003101	 0.115753	 0.0	 267	 267	 267	 1.010101	 0.0	 1	 -30.0	 30.0;
	2831	 5883	 0.000443	 -0.004848	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2831	 5910	 0.000305	 -0.007133	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2831	 2832	 0.000734	 0.024654	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2832	 5883	 0.000249	 0.047992	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 5910	 0.000506	 0.046814	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2847	 2848	 0.003081	 0.12563	 0.0	 243	 243	 243	 0.964324	 0.0	 1	 -30.0	 30.0;
	2863	 2864	 0.001778	 0.099753	 0.0	 306	 306	 306	 1.033059	 0.0	 1	 -30.0	 30.0;
	2863	 2864	 0.001778	 0.098765	 0.0	 309	 309	 309	 1.033059	 0.0	 1	 -30.0	 30.0;
	2892	 5884	 0.000152	 -0.011219	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2892	 5911	 0.000443	 -0.011011	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2892	 5934	 0.000215	 -0.005194	 0.0	 1186.0	 1186.0	 1186.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2892	 5944	 0.000145	 -0.011496	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2893	 5884	 0.000187	 0.038296	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 5911	 0.000374	 0.053463	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 5934	 9.7e-05	 0.032064	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 5944	 0.000194	 0.038435	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 5885	 0.002568	 0.070124	 0.0	 493	 493	 493	 1.0	 0.0	 1	 -30.0	 30.0;
	2900	 5885	 0.000494	 0.013037	 0.0	 2626	 2626	 2626	 1.023541	 0.0	 1	 -30.0	 30.0;
	2901	 5885	 0.002765	 0.132148	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	2913	 2914	 0.003556	 0.118321	 0.0	 260	 260	 260	 1.001002	 0.0	 1	 -30.0	 30.0;
	2914	 5886	 0.000229	 -0.004571	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2915	 5912	 0.000215	 -0.004432	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2916	 2917	 0.000312	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2917	 5886	 9.7e-05	 0.029363	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	2917	 5912	 9.7e-05	 0.029086	 0.0	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 2932	 0.002983	 0.117926	 0.0	 262	 262	 262	 0.976562	 0.0	 1	 -30.0	 30.0;
	2930	 2931	 0.00322	 0.115951	 0.0	 266	 266	 266	 0.988142	 0.0	 1	 -30.0	 30.0;
	2936	 2937	 0.00316	 0.12484	 0.0	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	2935	 2937	 0.003753	 0.128	 0.0	 240	 240	 240	 1.001002	 0.0	 1	 -30.0	 30.0;
	2935	 2937	 0.003556	 0.121877	 0.0	 252	 252	 252	 1.0142	 0.0	 1	 -30.0	 30.0;
	2944	 2945	 0.004306	 0.159605	 0.0	 194	 194	 194	 0.974655	 0.0	 1	 -30.0	 30.0;
	2944	 2945	 0.003022	 0.115358	 0.0	 268	 268	 268	 0.973708	 0.0	 1	 -30.0	 30.0;
	2946	 2947	 0.001385	 0.099162	 0.0	 318	 318	 318	 0.956942	 0.0	 1	 -30.0	 30.0;
	2950	 2952	 0.001857	 0.115358	 0.0	 268	 268	 268	 0.999001	 0.0	 1	 -30.0	 30.0;
	2950	 2951	 0.001857	 0.115358	 0.0	 268	 268	 268	 0.987165	 0.0	 1	 -30.0	 30.0;
	2958	 2959	 0.0164	 0.342222	 0.0	 92	 92	 92	 0.971817	 0.0	 1	 -30.0	 30.0;
	2966	 2968	 0.000325	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	2967	 5913	 0.000152	 -0.011357	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2966	 5935	 0.000145	 -0.00741	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2966	 5945	 0.000125	 -0.007756	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2968	 5913	 0.000187	 0.038435	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	2969	 5935	 0.000194	 0.034626	 0.0	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	2969	 5945	 0.000215	 0.034903	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 2972	 0.003121	 0.125037	 0.0	 247	 247	 247	 0.968054	 0.0	 1	 -30.0	 30.0;
	2971	 2972	 0.003793	 0.12642	 0.0	 244	 244	 244	 0.98912	 0.0	 1	 -30.0	 30.0;
	2984	 2985	 0.001936	 0.116741	 0.0	 263	 263	 263	 0.986189	 0.0	 1	 -30.0	 30.0;
	2984	 2985	 0.001936	 0.116741	 0.0	 263	 263	 263	 0.974661	 0.0	 1	 -30.0	 30.0;
	2994	 2995	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	2995	 2998	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.013172	 0.0	 1	 -30.0	 30.0;
	2996	 2998	 0.001679	 0.121679	 0.0	 253	 253	 253	 1.008064	 0.0	 1	 -30.0	 30.0;
	2999	 3000	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.987167	 0.0	 1	 -30.0	 30.0;
	2999	 3000	 0.003398	 0.118716	 0.0	 257	 257	 257	 0.987165	 0.0	 1	 -30.0	 30.0;
	2999	 3000	 0.003852	 0.11121	 0.0	 274	 274	 274	 1.0	 0.0	 1	 -30.0	 30.0;
	3001	 3002	 0.001719	 0.122074	 0.0	 253	 253	 253	 1.0	 0.0	 1	 -30.0	 30.0;
	3001	 3002	 0.001758	 0.122469	 0.0	 252	 252	 252	 0.999001	 0.0	 1	 -30.0	 30.0;
	3001	 3002	 0.001758	 0.122469	 0.0	 252	 252	 252	 0.98912	 0.0	 1	 -30.0	 30.0;
	3008	 3009	 0.003338	 0.11121	 0.0	 278	 278	 278	 0.974664	 0.0	 1	 -30.0	 30.0;
	3008	 3009	 0.003121	 0.119704	 0.0	 258	 258	 258	 0.974664	 0.0	 1	 -30.0	 30.0;
	3009	 3010	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	3009	 3010	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	3015	 3016	 0.003081	 0.116543	 0.0	 262	 262	 262	 1.009082	 0.0	 1	 -30.0	 30.0;
	3015	 3016	 0.003101	 0.116148	 0.0	 263	 263	 263	 1.009082	 0.0	 1	 -30.0	 30.0;
	3030	 3031	 0.004543	 0.160395	 0.0	 193	 193	 193	 0.978474	 0.0	 1	 -30.0	 30.0;
	3030	 3031	 0.002825	 0.170469	 0.0	 181	 181	 181	 0.978474	 0.0	 1	 -30.0	 30.0;
	3031	 5887	 0.00045	 -0.014404	 0.0	 567.0	 567.0	 567.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3031	 5914	 0.000471	 -0.013712	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3031	 3032	 0.000803	 0.034903	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3032	 5887	 0.000381	 0.050623	 0.0	 567.0	 567.0	 567.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 5914	 0.000367	 0.050554	 0.0	 581.0	 581.0	 581.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 3064	 0.003911	 0.112	 0.0	 273	 273	 273	 0.985226	 0.0	 1	 -30.0	 30.0;
	3063	 3064	 0.003062	 0.117136	 0.0	 261	 261	 261	 0.997009	 0.0	 1	 -30.0	 30.0;
	3073	 3074	 0.004346	 0.165136	 0.0	 186	 186	 186	 1.001002	 0.0	 1	 -30.0	 30.0;
	3073	 3074	 0.00316	 0.126025	 0.0	 244	 244	 244	 0.989123	 0.0	 1	 -30.0	 30.0;
	3081	 3082	 0.000395	 0.130568	 0.0	 237	 237	 237	 0.946073	 0.0	 1	 -30.0	 30.0;
	3081	 3082	 0.000395	 0.130568	 0.0	 237	 237	 237	 0.956935	 0.0	 1	 -30.0	 30.0;
	3085	 3086	 0.003279	 0.113383	 0.0	 272	 272	 272	 0.98912	 0.0	 1	 -30.0	 30.0;
	3085	 3086	 0.003931	 0.12484	 0.0	 247	 247	 247	 0.98912	 0.0	 1	 -30.0	 30.0;
	3085	 3086	 0.003891	 0.11279	 0.0	 274	 274	 274	 0.98912	 0.0	 1	 -30.0	 30.0;
	3087	 3088	 0.00316	 0.118519	 0.0	 260	 260	 260	 0.976559	 0.0	 1	 -30.0	 30.0;
	3100	 3101	 0.003753	 0.129778	 0.0	 237	 237	 237	 0.989123	 0.0	 1	 -30.0	 30.0;
	3100	 3101	 0.004741	 0.16079	 0.0	 191	 191	 191	 0.967124	 0.0	 1	 -30.0	 30.0;
	3118	 3121	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3117	 3120	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3116	 3119	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3127	 3128	 0.003067	 0.132444	 0.0	 237	 237	 237	 1.106195	 0.0	 1	 -30.0	 30.0;
	3127	 3128	 0.003067	 0.132444	 0.0	 237	 237	 237	 1.118569	 0.0	 1	 -30.0	 30.0;
	3134	 3135	 0.001918	 0.160035	 0.0	 198	 198	 198	 1.004016	 0.0	 1	 -30.0	 30.0;
	3134	 3135	 0.001918	 0.160035	 0.0	 198	 198	 198	 0.994036	 0.0	 1	 -30.0	 30.0;
	3145	 3146	 0.003812	 0.122469	 0.0	 251	 251	 251	 0.987167	 0.0	 1	 -30.0	 30.0;
	3145	 3146	 0.003812	 0.122469	 0.0	 251	 251	 251	 0.987167	 0.0	 1	 -30.0	 30.0;
	3152	 3153	 0.003158	 0.158795	 0.0	 200	 200	 200	 0.948768	 0.0	 1	 -30.0	 30.0;
	3152	 3154	 0.003137	 0.159834	 0.0	 198	 198	 198	 0.9311	 0.0	 1	 -30.0	 30.0;
	3152	 3154	 0.001364	 0.112881	 0.0	 281	 281	 281	 0.9311	 0.0	 1	 -30.0	 30.0;
	3164	 3165	 0.001995	 0.126025	 0.0	 245	 245	 245	 0.937207	 0.0	 1	 -30.0	 30.0;
	3164	 3165	 0.003951	 0.125432	 0.0	 246	 246	 246	 0.926784	 0.0	 1	 -30.0	 30.0;
	3175	 3176	 0.003081	 0.110617	 0.0	 278	 278	 278	 1.02459	 0.0	 1	 -30.0	 30.0;
	3175	 3176	 0.001995	 0.12642	 0.0	 243	 243	 243	 0.987167	 0.0	 1	 -30.0	 30.0;
	3179	 5888	 0.000235	 -0.004294	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3179	 5915	 0.000145	 -0.006233	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3180	 5888	 9e-05	 0.029086	 0.0	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 5915	 0.000194	 0.031233	 0.0	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	4578	 3199	 0.000119	 0.009086	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3197	 3199	 0.003062	 0.116938	 0.0	 261	 261	 261	 0.985226	 0.0	 1	 -30.0	 30.0;
	3197	 3199	 0.00316	 0.109037	 0.0	 280	 280	 280	 0.983282	 0.0	 1	 -30.0	 30.0;
	3197	 3199	 0.003911	 0.111407	 0.0	 274	 274	 274	 0.985226	 0.0	 1	 -30.0	 30.0;
	3201	 3202	 0.003141	 0.115556	 0.0	 266	 266	 266	 1.012146	 0.0	 1	 -30.0	 30.0;
	3201	 3202	 0.003141	 0.115556	 0.0	 266	 266	 266	 1.012146	 0.0	 1	 -30.0	 30.0;
	3215	 3217	 0.003081	 0.116543	 0.0	 264	 264	 264	 1.02459	 0.0	 1	 -30.0	 30.0;
	3258	 3259	 0.001699	 0.099358	 0.0	 308	 308	 308	 0.983284	 0.0	 1	 -30.0	 30.0;
	3258	 3259	 0.001679	 0.098765	 0.0	 309	 309	 309	 0.983284	 0.0	 1	 -30.0	 30.0;
	3269	 3270	 0.00316	 0.116543	 0.0	 265	 265	 265	 1.02459	 0.0	 1	 -30.0	 30.0;
	3269	 3270	 0.004365	 0.167704	 0.0	 184	 184	 184	 1.023541	 0.0	 1	 -30.0	 30.0;
	3269	 3270	 0.00401	 0.111012	 0.0	 278	 278	 278	 1.02459	 0.0	 1	 -30.0	 30.0;
	3278	 3279	 0.007348	 0.24	 0.0	 129	 129	 129	 0.968054	 0.0	 1	 -30.0	 30.0;
	3278	 3279	 0.003714	 0.123062	 0.0	 251	 251	 251	 0.96432	 0.0	 1	 -30.0	 30.0;
	3282	 3284	 0.015873	 0.256992	 0.0	 134	 134	 134	 1.001	 0.0	 1	 -30.0	 30.0;
	3281	 3283	 0.015873	 0.256992	 0.0	 134	 134	 134	 1.001	 0.0	 1	 -30.0	 30.0;
	3280	 3286	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3290	 3291	 0.000198	 0.118716	 0.0	 263	 263	 263	 1.006036	 0.0	 1	 -30.0	 30.0;
	3297	 3298	 0.003417	 0.116543	 0.0	 265	 265	 265	 1.0	 0.0	 1	 -30.0	 30.0;
	3311	 3312	 0.003378	 0.112988	 0.0	 273	 273	 273	 1.0	 0.0	 1	 -30.0	 30.0;
	3311	 3312	 0.003832	 0.125037	 0.0	 247	 247	 247	 1.02459	 0.0	 1	 -30.0	 30.0;
	3311	 3312	 0.003911	 0.123457	 0.0	 250	 250	 250	 1.023541	 0.0	 1	 -30.0	 30.0;
	3321	 3323	 0.004049	 0.124049	 0.0	 246	 246	 246	 0.964324	 0.0	 1	 -30.0	 30.0;
	3321	 3323	 0.003358	 0.124247	 0.0	 246	 246	 246	 0.978473	 0.0	 1	 -30.0	 30.0;
	3322	 3323	 0.001956	 0.124642	 0.0	 245	 245	 245	 0.955109	 0.0	 1	 -30.0	 30.0;
	3335	 3336	 0.00397	 0.113383	 0.0	 271	 271	 271	 0.989123	 0.0	 1	 -30.0	 30.0;
	3335	 3336	 0.003951	 0.119111	 0.0	 258	 258	 258	 0.987172	 0.0	 1	 -30.0	 30.0;
	3334	 3336	 0.001975	 0.116938	 0.0	 263	 263	 263	 0.989123	 0.0	 1	 -30.0	 30.0;
	3344	 3345	 0.013857	 0.312421	 0.0	 95	 95	 95	 0.947864	 0.0	 1	 -30.0	 30.0;
	3344	 3345	 0.02066	 0.410935	 0.0	 72	 72	 72	 0.933703	 0.0	 1	 -30.0	 30.0;
	3345	 3346	 0.004543	 0.120691	 0.001	 255	 255	 255	 1.001002	 0.0	 1	 -30.0	 30.0;
	3345	 3346	 0.003951	 0.124247	 0.0	 248	 248	 248	 1.001002	 0.0	 1	 -30.0	 30.0;
	3349	 3350	 0.003556	 0.120296	 0.0	 256	 256	 256	 0.97561	 0.0	 1	 -30.0	 30.0;
	3349	 3350	 0.003081	 0.116346	 0.0	 264	 264	 264	 0.97561	 0.0	 1	 -30.0	 30.0;
	3363	 3364	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.0	 0.0	 1	 -30.0	 30.0;
	3363	 3364	 0.001719	 0.122272	 0.0	 253	 253	 253	 0.98619	 0.0	 1	 -30.0	 30.0;
	3366	 3367	 0.00399	 0.11121	 0.0	 298	 298	 298	 1.037344	 0.0	 1	 -30.0	 30.0;
	3366	 3367	 0.00399	 0.11121	 0.0	 298	 298	 298	 1.037344	 0.0	 1	 -30.0	 30.0;
	3366	 3367	 0.003733	 0.123654	 0.0	 268	 268	 268	 1.037344	 0.0	 1	 -30.0	 30.0;
	3371	 3372	 0.001738	 0.100139	 0.0	 320	 320	 320	 0.956942	 0.0	 1	 -30.0	 30.0;
	3371	 3372	 0.001738	 0.100139	 0.0	 320	 320	 320	 0.939851	 0.0	 1	 -30.0	 30.0;
	3380	 3381	 0.004405	 0.165926	 0.0	 189	 189	 189	 0.98912	 0.0	 1	 -30.0	 30.0;
	3380	 3381	 0.004484	 0.166321	 0.0	 188	 188	 188	 1.0	 0.0	 1	 -30.0	 30.0;
	3380	 3381	 0.003674	 0.162568	 0.0	 193	 193	 193	 0.98912	 0.0	 1	 -30.0	 30.0;
	3396	 3397	 0.003556	 0.126815	 0.0	 247	 247	 247	 1.02459	 0.0	 1	 -30.0	 30.0;
	3396	 3397	 0.003556	 0.126815	 0.0	 247	 247	 247	 1.012146	 0.0	 1	 -30.0	 30.0;
	3399	 3400	 0.003279	 0.125235	 0.0	 247	 247	 247	 1.011122	 0.0	 1	 -30.0	 30.0;
	3399	 3400	 0.003773	 0.116543	 0.0	 265	 265	 265	 1.012146	 0.0	 1	 -30.0	 30.0;
	3399	 3400	 0.001141	 0.12083	 0.0	 256	 256	 256	 1.009082	 0.0	 1	 -30.0	 30.0;
	3432	 3433	 0.003047	 0.155125	 0.0	 204	 204	 204	 0.953289	 0.0	 1	 -30.0	 30.0;
	3432	 3433	 0.003186	 0.160873	 0.0	 197	 197	 197	 0.965248	 0.0	 1	 -30.0	 30.0;
	3441	 3442	 0.009556	 0.309778	 0.0	 102	 102	 102	 1.015229	 0.0	 1	 -30.0	 30.0;
	3441	 3442	 0.009911	 0.307556	 0.0	 102	 102	 102	 1.015229	 0.0	 1	 -30.0	 30.0;
	3470	 3471	 0.000284	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.046025	 0.0	 1	 -30.0	 30.0;
	3482	 3485	 0.001679	 0.122074	 0.0	 252	 252	 252	 0.953285	 0.0	 1	 -30.0	 30.0;
	3482	 3485	 0.001679	 0.122074	 0.0	 252	 252	 252	 0.96432	 0.0	 1	 -30.0	 30.0;
	3484	 3485	 0.002963	 0.085531	 0.0	 351.0	 351.0	 351.0	 1.004017	 0.0	 1	 -30.0	 30.0;
	3483	 3485	 0.003042	 0.117531	 0.0	 263	 263	 263	 0.992063	 0.0	 1	 -30.0	 30.0;
	1499	 3504	 0.003951	 0.029126	 0.0162	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 3504	 0.003081	 0.125452	 0.0	 246	 246	 246	 0.974664	 0.0	 1	 -30.0	 30.0;
	3505	 3506	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	3508	 3509	 0.004148	 0.165531	 0.0	 186	 186	 186	 0.978477	 0.0	 1	 -30.0	 30.0;
	3514	 3516	 0.00187	 0.101731	 0.0	 310	 310	 310	 0.994033	 0.0	 1	 -30.0	 30.0;
	3514	 3515	 0.001773	 0.099862	 0.0	 316	 316	 316	 0.994033	 0.0	 1	 -30.0	 30.0;
	3517	 3518	 0.004662	 0.16	 0.0	 193	 193	 193	 0.98912	 0.0	 1	 -30.0	 30.0;
	3517	 3518	 0.00476	 0.166123	 0.0	 186	 186	 186	 0.968054	 0.0	 1	 -30.0	 30.0;
	3517	 3518	 0.004523	 0.160988	 0.0	 192	 192	 192	 0.968054	 0.0	 1	 -30.0	 30.0;
	3519	 3520	 0.005679	 0.116173	 0.0	 266	 266	 266	 1.001002	 0.0	 1	 -30.0	 30.0;
	3521	 3523	 0.00316	 0.125432	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	3522	 3523	 0.00316	 0.125827	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	3522	 3523	 0.001817	 0.118716	 0.0	 259	 259	 259	 1.001002	 0.0	 1	 -30.0	 30.0;
	3538	 3539	 0.00316	 0.112	 0.0	 277	 277	 277	 1.029866	 0.0	 1	 -30.0	 30.0;
	3538	 3539	 0.00316	 0.112	 0.0	 277	 277	 277	 1.029866	 0.0	 1	 -30.0	 30.0;
	3542	 3543	 0.004543	 0.163951	 0.0	 188	 188	 188	 1.0	 0.0	 1	 -30.0	 30.0;
	3545	 3546	 0.003556	 0.111407	 0.0	 274	 274	 274	 1.011122	 0.0	 1	 -30.0	 30.0;
	3545	 3546	 0.00401	 0.110222	 0.0	 277	 277	 277	 1.010101	 0.0	 1	 -30.0	 30.0;
	3545	 3546	 0.003338	 0.109037	 0.0	 280	 280	 280	 1.011122	 0.0	 1	 -30.0	 30.0;
	3555	 3556	 0.003891	 0.12484	 0.0	 246	 246	 246	 0.999001	 0.0	 1	 -30.0	 30.0;
	3555	 3556	 0.003674	 0.124642	 0.0	 247	 247	 247	 0.974664	 0.0	 1	 -30.0	 30.0;
	3559	 3560	 0.003556	 0.111605	 0.0	 277	 277	 277	 0.974664	 0.0	 1	 -30.0	 30.0;
	3559	 3560	 0.004405	 0.165926	 0.0	 186	 186	 186	 0.968059	 0.0	 1	 -30.0	 30.0;
	3559	 3560	 0.004227	 0.169481	 0.0	 182	 182	 182	 0.968054	 0.0	 1	 -30.0	 30.0;
	3561	 3562	 0.002311	 0.119506	 0.0	 257	 257	 257	 0.974664	 0.0	 1	 -30.0	 30.0;
	3561	 3563	 0.002311	 0.119506	 0.0	 257	 257	 257	 0.96246	 0.0	 1	 -30.0	 30.0;
	3564	 3565	 0.003595	 0.126815	 0.0	 242	 242	 242	 0.953289	 0.0	 1	 -30.0	 30.0;
	3572	 3573	 0.004326	 0.167506	 0.0	 185	 185	 185	 0.990101	 0.0	 1	 -30.0	 30.0;
	3572	 3573	 0.004583	 0.162963	 0.0	 190	 190	 190	 0.990101	 0.0	 1	 -30.0	 30.0;
	1497	 3581	 4.2e-05	 0.000339	 0.0061	 1184.0	 1184.0	 1184.0	 1.0	 -9.95	 1	 -30.0	 30.0;
	3578	 3579	 0.00316	 0.125037	 0.0	 246	 246	 246	 0.990101	 0.0	 1	 -30.0	 30.0;
	3579	 3581	 0.000679	 0.042867	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	3586	 3588	 0.002016	 0.239355	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	3587	 3589	 0.002016	 0.239355	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	3594	 3595	 0.004622	 0.227951	 0.0	 134	 134	 134	 0.926784	 0.0	 1	 -30.0	 30.0;
	3596	 3597	 0.00484	 0.165926	 0.0	 184	 184	 184	 0.968054	 0.0	 1	 -30.0	 30.0;
	3600	 3601	 0.00316	 0.113185	 0.0	 273	 273	 273	 1.002004	 0.0	 1	 -30.0	 30.0;
	3602	 3603	 0.001481	 0.128395	 0.0	 238	 238	 238	 0.97561	 0.0	 1	 -30.0	 30.0;
	3608	 3609	 0.003951	 0.12484	 0.0	 246	 246	 246	 0.990101	 0.0	 1	 -30.0	 30.0;
	3612	 5889	 0.000111	 -0.007895	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3614	 5916	 0.00027	 -0.005402	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3612	 5936	 0.000152	 -0.007964	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3613	 5946	 0.000152	 -0.007271	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3614	 3615	 0.000325	 0.027078	 0.0	 1171	 1171	 1171	 1.0	 0.0	 1	 -30.0	 30.0;
	3616	 5889	 0.000222	 0.03518	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 5916	 5.5e-05	 0.032756	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	3615	 5936	 0.000201	 0.034764	 0.0	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	3615	 5946	 0.000194	 0.034141	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 3620	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.974664	 0.0	 1	 -30.0	 30.0;
	3619	 3620	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.974664	 0.0	 1	 -30.0	 30.0;
	3619	 3620	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.963394	 0.0	 1	 -30.0	 30.0;
	3623	 3624	 0.000339	 0.027285	 0.0	 1156	 1156	 1156	 1.0	 0.0	 1	 -30.0	 30.0;
	3630	 3631	 0.002983	 0.117333	 0.0	 263	 263	 263	 0.973708	 0.0	 1	 -30.0	 30.0;
	3630	 3631	 0.004444	 0.159407	 0.0	 194	 194	 194	 0.965253	 0.0	 1	 -30.0	 30.0;
	3630	 3631	 0.003694	 0.116148	 0.0	 266	 266	 266	 0.985226	 0.0	 1	 -30.0	 30.0;
	3647	 3648	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.999001	 0.0	 1	 -30.0	 30.0;
	3647	 3648	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.999001	 0.0	 1	 -30.0	 30.0;
	3654	 3655	 0.003081	 0.116286	 0.0	 266	 266	 266	 1.040583	 0.0	 1	 -30.0	 30.0;
	3653	 3655	 0.003081	 0.116563	 0.0	 265	 265	 265	 1.040583	 0.0	 1	 -30.0	 30.0;
	3662	 3663	 0.005926	 0.114568	 0.0	 269	 269	 269	 0.974656	 0.0	 1	 -30.0	 30.0;
	3664	 3665	 0.001956	 0.117136	 0.0	 261	 261	 261	 0.987167	 0.0	 1	 -30.0	 30.0;
	3664	 3666	 0.001896	 0.11516	 0.0	 265	 265	 265	 0.953289	 0.0	 1	 -30.0	 30.0;
	3664	 3665	 0.001916	 0.116543	 0.0	 262	 262	 262	 0.97561	 0.0	 1	 -30.0	 30.0;
	3664	 3666	 0.000766	 0.116583	 0.0	 262	 262	 262	 0.95238	 0.0	 1	 -30.0	 30.0;
	3670	 3671	 0.00316	 0.112988	 0.0	 284	 284	 284	 1.011122	 0.0	 1	 -30.0	 30.0;
	3670	 3671	 0.003951	 0.112198	 0.0	 286	 286	 286	 0.985219	 0.0	 1	 -30.0	 30.0;
	3674	 3675	 0.003259	 0.109037	 0.0	 283	 283	 283	 0.992064	 0.0	 1	 -30.0	 30.0;
	3674	 3675	 0.00316	 0.112988	 0.0	 273	 273	 273	 0.992064	 0.0	 1	 -30.0	 30.0;
	3674	 3675	 0.0032	 0.114568	 0.0	 269	 269	 269	 0.974655	 0.0	 1	 -30.0	 30.0;
	3678	 3679	 0.001817	 0.118716	 0.0	 260	 260	 260	 1.012146	 0.0	 1	 -30.0	 30.0;
	3678	 3679	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.012146	 0.0	 1	 -30.0	 30.0;
	3678	 3679	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.012146	 0.0	 1	 -30.0	 30.0;
	3704	 5890	 0.000215	 -0.00554	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3704	 3705	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 1.0	 0.0	 1	 -30.0	 30.0;
	3705	 5890	 0.000125	 0.033241	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 3710	 0.003121	 0.125432	 0.0	 246	 246	 246	 0.98912	 0.0	 1	 -30.0	 30.0;
	3711	 3712	 0.00397	 0.124049	 0.0	 246	 246	 246	 0.941619	 0.0	 1	 -30.0	 30.0;
	3711	 3712	 0.003121	 0.125827	 0.0	 243	 243	 243	 0.931096	 0.0	 1	 -30.0	 30.0;
	3727	 3728	 0.007055	 0.203578	 0.0	 145	 145	 145	 0.914916	 0.0	 1	 -30.0	 30.0;
	3727	 3729	 0.004489	 0.280756	 0.0	 117	 117	 117	 0.860587	 0.0	 1	 -30.0	 30.0;
	3728	 3730	 0.004543	 0.120691	 0.0	 255	 255	 255	 0.94251	 0.0	 1	 -30.0	 30.0;
	3734	 3735	 0.00164	 0.090864	 0.0	 340	 340	 340	 0.950567	 0.0	 1	 -30.0	 30.0;
	4579	 3738	 0.000119	 0.009086	 0.0	 473.0	 473.0	 473.0	 1.0	 -6.32	 1	 -30.0	 30.0;
	3736	 3738	 0.003062	 0.117136	 0.0	 261	 261	 261	 1.0	 0.0	 1	 -30.0	 30.0;
	3736	 3738	 0.003852	 0.123654	 0.0	 247	 247	 247	 1.0	 0.0	 1	 -30.0	 30.0;
	3736	 3738	 0.003615	 0.124444	 0.0	 245	 245	 245	 0.999001	 0.0	 1	 -30.0	 30.0;
	3736	 3738	 0.003615	 0.124444	 0.0	 245	 245	 245	 1.011122	 0.0	 1	 -30.0	 30.0;
	3742	 3743	 0.00484	 0.162568	 0.0	 188	 188	 188	 0.956938	 0.0	 1	 -30.0	 30.0;
	3745	 3746	 0.003062	 0.116741	 0.0	 264	 264	 264	 0.985226	 0.0	 1	 -30.0	 30.0;
	3745	 3746	 0.003062	 0.116741	 0.0	 264	 264	 264	 0.985226	 0.0	 1	 -30.0	 30.0;
	3751	 3752	 0.000319	 0.024307	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3751	 3752	 0.000339	 0.025	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3751	 3752	 0.000325	 0.024584	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3758	 3759	 0.003832	 0.121284	 0.0	 254	 254	 254	 1.0	 0.0	 1	 -30.0	 30.0;
	3758	 3759	 0.004464	 0.156049	 0.0	 197	 197	 197	 1.0	 0.0	 1	 -30.0	 30.0;
	3763	 3764	 0.003081	 0.116286	 0.0	 266	 266	 266	 0.985218	 0.0	 1	 -30.0	 30.0;
	3763	 3764	 0.003081	 0.116563	 0.0	 265	 265	 265	 0.987172	 0.0	 1	 -30.0	 30.0;
	3763	 3764	 0.003081	 0.114983	 0.0	 269	 269	 269	 0.995025	 0.0	 1	 -30.0	 30.0;
	3773	 3774	 0.001766	 0.10097	 0.0	 314	 314	 314	 0.956942	 0.0	 1	 -30.0	 30.0;
	3773	 3774	 0.001787	 0.100208	 0.0	 317	 317	 317	 0.956942	 0.0	 1	 -30.0	 30.0;
	3777	 3781	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3778	 3780	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3777	 3781	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3776	 3779	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3790	 3792	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	3789	 3792	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	3788	 3791	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	3809	 3810	 0.001837	 0.11516	 0.0	 268	 268	 268	 0.953285	 0.0	 1	 -30.0	 30.0;
	3809	 3810	 0.001817	 0.11516	 0.0	 268	 268	 268	 0.96432	 0.0	 1	 -30.0	 30.0;
	3810	 3811	 0.000817	 0.04349	 0.0	 608.0	 608.0	 608.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3810	 3811	 0.000319	 0.027978	 0.0	 1134	 1134	 1134	 1.005027	 0.0	 1	 -30.0	 30.0;
	3818	 3821	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3817	 3820	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3816	 3819	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3830	 3832	 0.000395	 0.13037	 0.0	 237	 237	 237	 0.946073	 0.0	 1	 -30.0	 30.0;
	3831	 3832	 0.000395	 0.127407	 0.0	 243	 243	 243	 0.925928	 0.0	 1	 -30.0	 30.0;
	3840	 3841	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	3850	 3851	 0.00478	 0.163358	 0.0	 189	 189	 189	 0.978474	 0.0	 1	 -30.0	 30.0;
	3850	 3851	 0.004286	 0.164346	 0.0	 188	 188	 188	 0.968054	 0.0	 1	 -30.0	 30.0;
	3854	 3856	 0.00316	 0.126025	 0.0	 244	 244	 244	 1.001002	 0.0	 1	 -30.0	 30.0;
	3855	 3856	 0.00316	 0.124049	 0.0	 248	 248	 248	 1.0142	 0.0	 1	 -30.0	 30.0;
	3873	 3874	 0.003358	 0.124049	 0.0	 246	 246	 246	 0.974664	 0.0	 1	 -30.0	 30.0;
	3873	 3874	 0.003911	 0.111407	 0.0	 274	 274	 274	 0.974664	 0.0	 1	 -30.0	 30.0;
	3878	 3879	 0.004346	 0.16158	 0.0	 191	 191	 191	 0.968054	 0.0	 1	 -30.0	 30.0;
	3878	 3879	 0.004365	 0.167901	 0.0	 184	 184	 184	 0.968054	 0.0	 1	 -30.0	 30.0;
	3878	 3879	 0.004642	 0.164741	 0.0	 188	 188	 188	 0.94697	 0.0	 1	 -30.0	 30.0;
	3880	 3881	 0.003793	 0.119309	 0.0	 258	 258	 258	 0.942507	 0.0	 1	 -30.0	 30.0;
	3880	 5937	 0.001481	 0.00316	 0.0	 482.0	 482.0	 482.0	 0.937207	 0.0	 1	 -30.0	 30.0;
	3881	 5937	 0.001956	 0.108444	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	3888	 3889	 0.002099	 0.116049	 0.0	 261	 261	 261	 0.999001	 0.0	 1	 -30.0	 30.0;
	3897	 3898	 0.003714	 0.119506	 0.0	 258	 258	 258	 0.98619	 0.0	 1	 -30.0	 30.0;
	3900	 3901	 0.001159	 0.118874	 0.0	 257	 257	 257	 0.975614	 0.0	 1	 -30.0	 30.0;
	3900	 3901	 0.001254	 0.119427	 0.0	 256	 256	 256	 0.975614	 0.0	 1	 -30.0	 30.0;
	3906	 3907	 0.000713	 0.048546	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	3905	 3907	 0.000332	 0.026939	 0.0	 1177	 1177	 1177	 1.0	 0.0	 1	 -30.0	 30.0;
	3905	 3907	 0.000319	 0.026385	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3916	 3917	 0.003635	 0.124444	 0.0	 248	 248	 248	 1.024591	 0.0	 1	 -30.0	 30.0;
	3916	 3917	 0.002983	 0.12484	 0.0	 247	 247	 247	 1.010101	 0.0	 1	 -30.0	 30.0;
	3916	 3917	 0.003674	 0.129778	 0.0	 238	 238	 238	 0.978474	 0.0	 1	 -30.0	 30.0;
	3923	 3925	 0.003556	 0.126815	 0.0	 247	 247	 247	 1.05042	 0.0	 1	 -30.0	 30.0;
	3924	 3925	 0.003635	 0.120691	 0.0	 259	 259	 259	 1.02459	 0.0	 1	 -30.0	 30.0;
	3927	 3928	 0.005911	 0.119689	 0.0	 253	 253	 253	 0.976562	 0.0	 1	 -30.0	 30.0;
	3930	 3931	 0.00164	 0.116938	 0.0	 261	 261	 261	 0.98912	 0.0	 1	 -30.0	 30.0;
	3930	 3931	 0.001699	 0.122212	 0.0	 250	 250	 250	 0.987167	 0.0	 1	 -30.0	 30.0;
	3936	 3937	 0.004286	 0.165333	 0.0	 187	 187	 187	 0.978474	 0.0	 1	 -30.0	 30.0;
	3937	 5891	 0.000519	 -0.00831	 0.0	 600.0	 600.0	 600.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	3937	 5917	 0.000471	 -0.008033	 0.0	 600.0	 600.0	 600.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	3938	 5891	 0.000277	 0.047922	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 5917	 0.00036	 0.049584	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 3943	 0.000796	 0.041413	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	3942	 3943	 0.000831	 0.039681	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	3969	 3970	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	3968	 3971	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	3978	 3980	 0.002963	 0.118321	 0.0	 261	 261	 261	 0.985226	 0.0	 1	 -30.0	 30.0;
	3979	 3980	 0.003595	 0.123654	 0.0	 250	 250	 250	 0.985226	 0.0	 1	 -30.0	 30.0;
	4004	 4005	 0.00316	 0.11437	 0.0	 270	 270	 270	 0.974655	 0.0	 1	 -30.0	 30.0;
	4004	 4005	 0.003101	 0.116543	 0.0	 265	 265	 265	 0.970872	 0.0	 1	 -30.0	 30.0;
	4008	 4009	 0.001995	 0.118123	 0.0	 261	 261	 261	 1.011122	 0.0	 1	 -30.0	 30.0;
	4008	 4009	 0.002035	 0.116741	 0.0	 265	 265	 265	 1.011122	 0.0	 1	 -30.0	 30.0;
	4010	 4011	 0.004346	 0.164543	 0.0	 187	 187	 187	 1.037345	 0.0	 1	 -30.0	 30.0;
	4017	 4018	 0.00399	 0.143407	 0.0	 215	 215	 215	 0.97561	 0.0	 1	 -30.0	 30.0;
	4017	 4018	 0.003872	 0.146173	 0.0	 211	 211	 211	 0.97561	 0.0	 1	 -30.0	 30.0;
	4026	 4027	 0.003773	 0.111802	 0.0	 276	 276	 276	 0.94697	 0.0	 1	 -30.0	 30.0;
	4026	 4027	 0.00399	 0.112988	 0.0	 273	 273	 273	 0.98912	 0.0	 1	 -30.0	 30.0;
	4027	 4028	 0.000332	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4027	 4028	 0.000332	 0.024792	 0.0	 1182.0	 1182.0	 1182.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4036	 4037	 0.004227	 0.169481	 0.0	 182	 182	 182	 0.968054	 0.0	 1	 -30.0	 30.0;
	4045	 4046	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.912407	 0.0	 1	 -30.0	 30.0;
	4048	 5892	 0.000118	 -0.005956	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4047	 4049	 0.000325	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4049	 5892	 0.000187	 0.032964	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	4063	 4064	 0.004346	 0.158025	 0.0	 195	 195	 195	 1.013172	 0.0	 1	 -30.0	 30.0;
	4067	 4068	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4077	 5893	 0.001284	 0.126973	 0.0	 276	 276	 276	 0.956935	 0.0	 1	 -30.0	 30.0;
	4076	 5918	 0.001284	 0.126973	 0.0	 276	 276	 276	 0.975606	 0.0	 1	 -30.0	 30.0;
	4078	 5893	 0.00081	 -0.007802	 0.0	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 5918	 0.00081	 -0.007802	 0.0	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 4089	 0.003951	 0.115951	 0.0	 266	 266	 266	 1.016261	 0.0	 1	 -30.0	 30.0;
	4088	 4089	 0.003951	 0.117965	 0.0	 262	 262	 262	 1.016261	 0.0	 1	 -30.0	 30.0;
	4092	 4093	 0.001975	 0.126025	 0.0	 244	 244	 244	 1.022496	 0.0	 1	 -30.0	 30.0;
	4094	 4095	 0.003595	 0.123062	 0.0	 250	 250	 250	 0.921656	 0.0	 1	 -30.0	 30.0;
	4101	 4102	 0.003951	 0.125235	 0.0	 244	 244	 244	 0.987165	 0.0	 1	 -30.0	 30.0;
	4101	 4102	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.987165	 0.0	 1	 -30.0	 30.0;
	5894	 4105	 0.000277	 -0.00464	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4105	 4106	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4106	 5894	 6.2e-05	 0.029571	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 4111	 0.00316	 0.124642	 0.0	 247	 247	 247	 0.976559	 0.0	 1	 -30.0	 30.0;
	4110	 4111	 0.004741	 0.161975	 0.0	 190	 190	 190	 0.978477	 0.0	 1	 -30.0	 30.0;
	4118	 4119	 0.003081	 0.115358	 0.0	 271	 271	 271	 1.0	 0.0	 1	 -30.0	 30.0;
	4118	 4119	 0.003556	 0.122864	 0.0	 255	 255	 255	 1.012146	 0.0	 1	 -30.0	 30.0;
	4120	 4121	 0.005309	 0.110123	 0.0	 291	 291	 291	 1.001002	 0.0	 1	 -30.0	 30.0;
	4121	 4122	 0.002015	 0.158657	 0.0	 203	 203	 203	 1.018331	 0.0	 1	 -30.0	 30.0;
	4133	 4134	 0.001177	 0.042382	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5938	 4133	 0.000499	 -0.006925	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5947	 4133	 0.000353	 -0.010873	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4134	 5938	 0.000201	 0.055402	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 5947	 0.000429	 0.05374	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4140	 4142	 0.003062	 0.116938	 0.0	 261	 261	 261	 0.985226	 0.0	 1	 -30.0	 30.0;
	4141	 4142	 0.00316	 0.116741	 0.0	 262	 262	 262	 1.009082	 0.0	 1	 -30.0	 30.0;
	4141	 4142	 0.003733	 0.115753	 0.0	 264	 264	 264	 1.009082	 0.0	 1	 -30.0	 30.0;
	4141	 4142	 0.003931	 0.111802	 0.0	 273	 273	 273	 0.997009	 0.0	 1	 -30.0	 30.0;
	4143	 4144	 0.004484	 0.168494	 0.0	 181	 181	 181	 0.956938	 0.0	 1	 -30.0	 30.0;
	4143	 4144	 0.004484	 0.168494	 0.0	 181	 181	 181	 0.978474	 0.0	 1	 -30.0	 30.0;
	4148	 4149	 0.003951	 0.12563	 0.0	 245	 245	 245	 1.026695	 0.0	 1	 -30.0	 30.0;
	4147	 4149	 0.003951	 0.118123	 0.0	 261	 261	 261	 1.026695	 0.0	 1	 -30.0	 30.0;
	4147	 4149	 0.00316	 0.12484	 0.0	 247	 247	 247	 1.026695	 0.0	 1	 -30.0	 30.0;
	4164	 4165	 0.003081	 0.116543	 0.0	 275	 275	 275	 1.034126	 0.0	 1	 -30.0	 30.0;
	4164	 4165	 0.003022	 0.116938	 0.0	 274	 274	 274	 1.034126	 0.0	 1	 -30.0	 30.0;
	4170	 4171	 0.001778	 0.098765	 0.0	 309	 309	 309	 0.939847	 0.0	 1	 -30.0	 30.0;
	4172	 4173	 0.001333	 0.002667	 0.0	 10522	 10522	 10522	 0.964319	 0.0	 1	 -30.0	 30.0;
	4181	 4182	 0.001837	 0.114765	 0.0	 266	 266	 266	 0.986189	 0.0	 1	 -30.0	 30.0;
	4181	 4182	 0.001857	 0.114963	 0.0	 266	 266	 266	 0.974661	 0.0	 1	 -30.0	 30.0;
	4207	 4209	 0.003694	 0.123852	 0.0	 248	 248	 248	 0.974664	 0.0	 1	 -30.0	 30.0;
	4207	 4209	 0.004543	 0.16	 0.0	 192	 192	 192	 0.968054	 0.0	 1	 -30.0	 30.0;
	4210	 4211	 0.003358	 0.11121	 0.0	 275	 275	 275	 0.999001	 0.0	 1	 -30.0	 30.0;
	4210	 4211	 0.003812	 0.130963	 0.0	 233	 233	 233	 1.0	 0.0	 1	 -30.0	 30.0;
	4216	 4218	 0.003042	 0.111407	 0.0	 279	 279	 279	 0.985222	 0.0	 1	 -30.0	 30.0;
	4217	 4218	 0.005965	 0.11121	 0.0	 279	 279	 279	 0.953289	 0.0	 1	 -30.0	 30.0;
	4217	 4218	 0.002963	 0.110815	 0.0	 280	 280	 280	 0.97561	 0.0	 1	 -30.0	 30.0;
	4216	 4218	 0.00397	 0.111605	 0.0	 278	 278	 278	 0.953289	 0.0	 1	 -30.0	 30.0;
	4218	 4219	 0.000291	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4224	 4221	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4226	 4227	 0.003121	 0.114765	 0.0	 269	 269	 269	 1.002004	 0.0	 1	 -30.0	 30.0;
	4225	 4227	 0.00316	 0.115358	 0.0	 268	 268	 268	 1.002004	 0.0	 1	 -30.0	 30.0;
	4242	 4243	 0.001758	 0.100543	 0.0	 304	 304	 304	 0.950567	 0.0	 1	 -30.0	 30.0;
	4248	 4270	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 1.0	 6.48	 1	 -30.0	 30.0;
	4250	 4251	 0.003891	 0.112198	 0.0	 272	 272	 272	 0.999001	 0.0	 1	 -30.0	 30.0;
	4250	 4251	 0.003556	 0.124642	 0.0	 245	 245	 245	 0.999001	 0.0	 1	 -30.0	 30.0;
	4253	 4254	 0.003931	 0.125373	 0.0	 244	 244	 244	 1.012146	 0.0	 1	 -30.0	 30.0;
	4255	 4256	 0.001699	 0.122469	 0.0	 252	 252	 252	 1.0	 0.0	 1	 -30.0	 30.0;
	4255	 4256	 0.001679	 0.122469	 0.0	 252	 252	 252	 1.0	 0.0	 1	 -30.0	 30.0;
	4274	 5895	 0.013911	 0.133333	 0.0	 258	 258	 258	 1.0	 0.0	 1	 -30.0	 30.0;
	4275	 5895	 0.008933	 0.147111	 0.0	 235	 235	 235	 1.0	 0.0	 1	 -30.0	 30.0;
	4276	 5895	 0.0036	 0.008933	 0.0	 3573	 3573	 3573	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 4291	 0.004267	 0.238617	 0.0	 136	 136	 136	 1.035197	 0.0	 1	 -30.0	 30.0;
	4289	 4291	 0.004642	 0.22321	 0.0	 139	 139	 139	 0.956938	 0.0	 1	 -30.0	 30.0;
	4289	 4291	 0.004523	 0.216296	 0.0	 143	 143	 143	 0.956938	 0.0	 1	 -30.0	 30.0;
	4289	 4291	 0.00484	 0.237037	 0.0	 131	 131	 131	 0.968054	 0.0	 1	 -30.0	 30.0;
	5954	 4291	 0.000457	 -0.005194	 0.0	 557.0	 557.0	 557.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4291	 4292	 0.000796	 0.048199	 0.0	 557.0	 557.0	 557.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4292	 5954	 0.000242	 0.047438	 0.0	 557.0	 557.0	 557.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 4294	 0.003911	 0.111407	 0.0	 274	 274	 274	 0.984254	 0.0	 1	 -30.0	 30.0;
	4303	 4304	 0.002331	 0.132741	 0.0	 233	 233	 233	 0.973708	 0.0	 1	 -30.0	 30.0;
	4310	 4311	 0.002015	 0.106667	 0.0	 286	 286	 286	 0.960618	 0.0	 1	 -30.0	 30.0;
	4310	 4312	 0.001363	 0.098528	 0.0	 310	 310	 310	 0.963387	 0.0	 1	 -30.0	 30.0;
	4323	 4324	 0.004741	 0.160593	 0.0	 192	 192	 192	 0.946073	 0.0	 1	 -30.0	 30.0;
	4329	 4332	 0.003338	 0.109037	 0.0	 283	 283	 283	 0.963394	 0.0	 1	 -30.0	 30.0;
	4330	 4332	 0.003042	 0.118519	 0.0	 261	 261	 261	 0.953289	 0.0	 1	 -30.0	 30.0;
	4330	 4331	 0.003694	 0.111407	 0.0	 277	 277	 277	 0.941619	 0.0	 1	 -30.0	 30.0;
	4329	 4331	 0.004089	 0.12484	 0.0	 247	 247	 247	 0.96432	 0.0	 1	 -30.0	 30.0;
	4341	 4343	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4340	 4343	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4339	 4343	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4342	 4343	 0.00316	 0.118321	 0.0	 258	 258	 258	 0.987167	 0.0	 1	 -30.0	 30.0;
	4342	 4343	 0.00324	 0.116543	 0.0	 262	 262	 262	 0.981351	 0.0	 1	 -30.0	 30.0;
	4346	 4347	 0.003753	 0.122074	 0.0	 254	 254	 254	 0.97561	 0.0	 1	 -30.0	 30.0;
	4346	 4347	 0.00399	 0.109235	 0.0	 283	 283	 283	 0.953289	 0.0	 1	 -30.0	 30.0;
	4346	 4347	 0.00399	 0.11121	 0.0	 278	 278	 278	 0.96432	 0.0	 1	 -30.0	 30.0;
	4355	 4353	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4388	 4389	 0.00318	 0.117333	 0.0	 263	 263	 263	 0.97561	 0.0	 1	 -30.0	 30.0;
	4388	 4389	 0.003338	 0.122469	 0.0	 252	 252	 252	 0.97561	 0.0	 1	 -30.0	 30.0;
	4390	 4392	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4397	 4398	 0.003595	 0.118716	 0.0	 260	 260	 260	 0.97561	 0.0	 1	 -30.0	 30.0;
	4397	 4398	 0.003753	 0.119309	 0.0	 259	 259	 259	 0.978474	 0.0	 1	 -30.0	 30.0;
	1498	 4406	 0.055185	 0.114444	 0.0052	 239	 239	 239	 1.0	 -0.9	 1	 -30.0	 30.0;
	4420	 4422	 0.003575	 0.123457	 0.0	 250	 250	 250	 0.997009	 0.0	 1	 -30.0	 30.0;
	4421	 4422	 0.003022	 0.117728	 0.0	 262	 262	 262	 0.985226	 0.0	 1	 -30.0	 30.0;
	4442	 4444	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.96432	 0.0	 1	 -30.0	 30.0;
	4442	 4444	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.957851	 0.0	 1	 -30.0	 30.0;
	4443	 4444	 0.003556	 0.127407	 0.0	 243	 243	 243	 1.02459	 0.0	 1	 -30.0	 30.0;
	4455	 4457	 0.003141	 0.117136	 0.0	 264	 264	 264	 0.974664	 0.0	 1	 -30.0	 30.0;
	4460	 4461	 0.003319	 0.108444	 0.0	 285	 285	 285	 0.978474	 0.0	 1	 -30.0	 30.0;
	4460	 4461	 0.003753	 0.124642	 0.0	 248	 248	 248	 0.978474	 0.0	 1	 -30.0	 30.0;
	4460	 4461	 0.003081	 0.116346	 0.0	 265	 265	 265	 0.978474	 0.0	 1	 -30.0	 30.0;
	4465	 4466	 0.004938	 0.161383	 0.0	 191	 191	 191	 1.001002	 0.0	 1	 -30.0	 30.0;
	4465	 4466	 0.004938	 0.163951	 0.0	 188	 188	 188	 1.001002	 0.0	 1	 -30.0	 30.0;
	4464	 4466	 0.004346	 0.118914	 0.0	 259	 259	 259	 0.989123	 0.0	 1	 -30.0	 30.0;
	4475	 4476	 0.004286	 0.164938	 0.0	 187	 187	 187	 0.978474	 0.0	 1	 -30.0	 30.0;
	4475	 4476	 0.007368	 0.229136	 0.0	 135	 135	 135	 0.978474	 0.0	 1	 -30.0	 30.0;
	4478	 4483	 0.012598	 0.428319	 0.0	 81	 81	 81	 1.001	 0.0	 1	 -30.0	 30.0;
	4482	 4487	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4481	 4486	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4480	 4485	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4479	 4484	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4501	 4503	 0.004356	 0.137467	 0.0	 231	 231	 231	 1.036269	 0.0	 1	 -30.0	 30.0;
	4502	 4503	 0.008711	 0.1592	 0.0	 200	 200	 200	 1.036269	 0.0	 1	 -30.0	 30.0;
	4504	 4505	 0.019652	 0.553288	 0.0	 63	 63	 63	 1.0	 0.0	 1	 -30.0	 30.0;
	4511	 4512	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	4516	 4517	 0.00397	 0.118123	 0.0	 261	 261	 261	 1.02459	 0.0	 1	 -30.0	 30.0;
	4516	 4517	 0.003654	 0.146765	 0.0	 211	 211	 211	 1.0	 0.0	 1	 -30.0	 30.0;
	4526	 4528	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.978474	 0.0	 1	 -30.0	 30.0;
	4527	 4528	 0.00164	 0.118519	 0.0	 259	 259	 259	 1.007049	 0.0	 1	 -30.0	 30.0;
	4534	 4535	 0.000783	 0.042936	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4534	 4535	 0.000776	 0.043075	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4538	 4539	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	4543	 4544	 0.021975	 0.446914	 0.0	 68	 68	 68	 1.035197	 0.0	 1	 -30.0	 30.0;
	4543	 4544	 0.021975	 0.446914	 0.0	 68	 68	 68	 1.035197	 0.0	 1	 -30.0	 30.0;
	4543	 4545	 0.003259	 0.119506	 0.0	 258	 258	 258	 0.98912	 0.0	 1	 -30.0	 30.0;
	4550	 5896	 0.000159	 -0.006025	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4550	 5919	 0.000229	 -0.004571	 0.0	 1174.0	 1174.0	 1174.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4550	 4551	 0.000332	 0.025623	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4551	 5896	 0.000173	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	4551	 5919	 9e-05	 0.029363	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 4559	 0.001222	 0.132	 0.0	 238	 238	 238	 0.980394	 0.0	 1	 -30.0	 30.0;
	4558	 4560	 0.003911	 0.12484	 0.0	 247	 247	 247	 0.98912	 0.0	 1	 -30.0	 30.0;
	4559	 4560	 0.003186	 0.137758	 0.0	 229	 229	 229	 0.987167	 0.0	 1	 -30.0	 30.0;
	4572	 4573	 0.000996	 0.10831	 0.0	 293	 293	 293	 0.984249	 0.0	 1	 -30.0	 30.0;
	4575	 4577	 0.000686	 0.047922	 0.0	 606.0	 606.0	 606.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4576	 4577	 0.000325	 0.027493	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	4576	 4577	 0.000325	 0.027493	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	4595	 4597	 0.001835	 0.101524	 0.0	 312	 312	 312	 1.022495	 0.0	 1	 -30.0	 30.0;
	4595	 4596	 0.001828	 0.102078	 0.0	 310	 310	 310	 1.003009	 0.0	 1	 -30.0	 30.0;
	4598	 4599	 0.00397	 0.125235	 0.0	 244	 244	 244	 1.02459	 0.0	 1	 -30.0	 30.0;
	4598	 4599	 0.00397	 0.125235	 0.0	 244	 244	 244	 1.02459	 0.0	 1	 -30.0	 30.0;
	4601	 4602	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	4601	 4603	 0.000339	 0.029778	 0.0	 1065	 1065	 1065	 1.0	 0.0	 1	 -30.0	 30.0;
	4610	 4611	 0.001244	 0.137877	 0.0	 222	 222	 222	 0.985218	 0.0	 1	 -30.0	 30.0;
	4610	 4611	 0.000731	 0.153284	 0.0	 199	 199	 199	 0.973708	 0.0	 1	 -30.0	 30.0;
	4610	 4611	 0.001244	 0.137284	 0.0	 223	 223	 223	 0.987165	 0.0	 1	 -30.0	 30.0;
	4618	 4619	 0.003081	 0.115556	 0.0	 271	 271	 271	 1.037344	 0.0	 1	 -30.0	 30.0;
	4618	 4619	 0.003081	 0.115556	 0.0	 271	 271	 271	 1.02459	 0.0	 1	 -30.0	 30.0;
	4639	 4641	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.974656	 0.0	 1	 -30.0	 30.0;
	4639	 4640	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	4649	 4650	 0.003068	 0.155609	 0.0	 204	 204	 204	 0.984249	 0.0	 1	 -30.0	 30.0;
	4649	 4650	 0.001364	 0.100069	 0.0	 317	 317	 317	 0.974656	 0.0	 1	 -30.0	 30.0;
	4649	 4650	 0.003061	 0.156163	 0.0	 203	 203	 203	 0.974656	 0.0	 1	 -30.0	 30.0;
	4652	 4654	 0.003931	 0.124247	 0.0	 249	 249	 249	 0.96432	 0.0	 1	 -30.0	 30.0;
	4652	 4653	 0.003101	 0.124642	 0.0	 248	 248	 248	 0.96432	 0.0	 1	 -30.0	 30.0;
	4663	 5939	 0.00018	 -0.007687	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4663	 5948	 0.000125	 -0.007618	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4664	 5939	 0.000166	 0.035111	 0.0	 976	 976	 976	 0.0	 0.0	 1	 -30.0	 30.0;
	4664	 5948	 0.000201	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 4675	 0.002016	 0.004031	 0.0	 7637	 7637	 7637	 1.0	 0.0	 1	 -30.0	 30.0;
	4676	 4677	 0.001857	 0.121086	 0.0	 252	 252	 252	 1.0	 0.0	 1	 -30.0	 30.0;
	4676	 4677	 0.003773	 0.122667	 0.0	 249	 249	 249	 0.999001	 0.0	 1	 -30.0	 30.0;
	4676	 4677	 0.001857	 0.121086	 0.0	 252	 252	 252	 0.987167	 0.0	 1	 -30.0	 30.0;
	4677	 4678	 6.2e-05	 0.031787	 0.0	 993	 993	 993	 1.0	 0.0	 1	 -30.0	 30.0;
	4677	 4678	 6.2e-05	 0.031856	 0.0	 991	 991	 991	 1.0	 0.0	 1	 -30.0	 30.0;
	4682	 4684	 0.003556	 0.112	 0.0	 273	 273	 273	 0.974664	 0.0	 1	 -30.0	 30.0;
	4682	 4684	 0.003556	 0.118519	 0.0	 258	 258	 258	 0.974664	 0.0	 1	 -30.0	 30.0;
	4682	 4684	 0.003615	 0.113185	 0.0	 270	 270	 270	 0.974664	 0.0	 1	 -30.0	 30.0;
	4682	 4684	 0.003674	 0.123062	 0.0	 248	 248	 248	 0.97561	 0.0	 1	 -30.0	 30.0;
	4689	 4690	 0.00316	 0.125432	 0.0	 245	 245	 245	 1.040584	 0.0	 1	 -30.0	 30.0;
	4689	 4690	 0.003951	 0.112988	 0.0	 272	 272	 272	 1.040584	 0.0	 1	 -30.0	 30.0;
	4713	 4714	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4712	 4714	 0.000208	 0.014751	 0.0	 1746.0	 1746.0	 1746.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4711	 4714	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4710	 4714	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4709	 4714	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4708	 4714	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4707	 4714	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4706	 4714	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4705	 4714	 0.000319	 0.024307	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4721	 4722	 0.003121	 0.125827	 0.0	 245	 245	 245	 1.049318	 0.0	 1	 -30.0	 30.0;
	4721	 4722	 0.003852	 0.126815	 0.0	 244	 244	 244	 1.036269	 0.0	 1	 -30.0	 30.0;
	4743	 4744	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.963394	 0.0	 1	 -30.0	 30.0;
	4743	 4744	 0.001956	 0.125037	 0.0	 244	 244	 244	 0.963394	 0.0	 1	 -30.0	 30.0;
	4743	 4744	 0.001956	 0.125037	 0.0	 244	 244	 244	 0.974664	 0.0	 1	 -30.0	 30.0;
	4745	 4746	 0.005057	 0.160988	 0.0	 194	 194	 194	 0.912407	 0.0	 1	 -30.0	 30.0;
	4745	 4746	 0.005057	 0.160988	 0.0	 194	 194	 194	 0.912407	 0.0	 1	 -30.0	 30.0;
	4767	 4768	 0.017333	 0.441333	 0.0	 69	 69	 69	 0.971818	 0.0	 1	 -30.0	 30.0;
	4773	 4774	 0.004247	 0.159407	 0.0	 192	 192	 192	 0.95057	 0.0	 1	 -30.0	 30.0;
	4774	 5897	 0.000699	 -0.004709	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4774	 4775	 0.000686	 0.048546	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4775	 5897	 1.4e-05	 0.052839	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 4780	 0.00316	 0.125235	 0.0	 246	 246	 246	 1.026695	 0.0	 1	 -30.0	 30.0;
	4779	 4780	 0.001675	 0.121284	 0.0	 254	 254	 254	 1.0142	 0.0	 1	 -30.0	 30.0;
	4783	 4784	 0.003812	 0.120099	 0.0	 256	 256	 256	 0.987167	 0.0	 1	 -30.0	 30.0;
	4803	 4804	 0.003556	 0.118519	 0.0	 262	 262	 262	 0.946073	 0.0	 1	 -30.0	 30.0;
	4803	 4804	 0.003279	 0.113185	 0.0	 274	 274	 274	 0.95329	 0.0	 1	 -30.0	 30.0;
	4809	 4811	 0.001679	 0.099753	 0.0	 306	 306	 306	 0.961535	 0.0	 1	 -30.0	 30.0;
	4809	 4811	 0.001659	 0.099556	 0.0	 307	 307	 307	 0.961535	 0.0	 1	 -30.0	 30.0;
	4820	 4822	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	4819	 4821	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	4825	 4831	 0.002431	 0.093213	 0.0	 368	 368	 368	 1.0	 0.0	 1	 -30.0	 30.0;
	4826	 4831	 0.002431	 0.092874	 0.0	 369	 369	 369	 1.0	 0.0	 1	 -30.0	 30.0;
	4829	 4831	 0.002431	 0.093428	 0.0	 367	 367	 367	 1.0	 0.0	 1	 -30.0	 30.0;
	4830	 4831	 0.002431	 0.09349	 0.0	 367	 367	 367	 1.0	 0.0	 1	 -30.0	 30.0;
	4827	 4831	 0.002431	 0.093428	 0.0	 367	 367	 367	 1.0	 0.0	 1	 -30.0	 30.0;
	4828	 4831	 0.008906	 0.093352	 0.0	 366	 366	 366	 1.0	 0.0	 1	 -30.0	 30.0;
	4832	 4834	 0.003062	 0.115951	 0.0	 266	 266	 266	 0.997009	 0.0	 1	 -30.0	 30.0;
	4832	 4833	 0.004267	 0.15763	 0.0	 196	 196	 196	 1.043841	 0.0	 1	 -30.0	 30.0;
	4832	 4833	 0.003101	 0.117531	 0.0	 263	 263	 263	 0.997009	 0.0	 1	 -30.0	 30.0;
	4832	 4833	 0.003615	 0.121284	 0.0	 254	 254	 254	 0.973708	 0.0	 1	 -30.0	 30.0;
	4834	 4835	 0.000339	 0.027008	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	4833	 4835	 0.000395	 0.027216	 0.0	 1165	 1165	 1165	 1.0	 0.0	 1	 -30.0	 30.0;
	4833	 4835	 0.000325	 0.027632	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	4852	 4853	 0.00316	 0.110617	 0.0	 278	 278	 278	 1.013172	 0.0	 1	 -30.0	 30.0;
	4852	 4853	 0.00316	 0.118519	 0.0	 260	 260	 260	 1.013172	 0.0	 1	 -30.0	 30.0;
	4857	 4858	 0.005136	 0.160988	 0.0	 194	 194	 194	 0.872599	 0.0	 1	 -30.0	 30.0;
	4862	 4863	 0.001975	 0.165926	 0.0	 186	 186	 186	 0.993049	 0.0	 1	 -30.0	 30.0;
	4862	 4863	 0.003002	 0.173235	 0.0	 178	 178	 178	 0.968059	 0.0	 1	 -30.0	 30.0;
	4863	 4864	 0.000332	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4863	 5920	 0.000229	 -0.004363	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4864	 5920	 9.7e-05	 0.029155	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 4868	 0.003911	 0.124642	 0.0	 248	 248	 248	 0.97182	 0.0	 1	 -30.0	 30.0;
	4867	 4868	 0.003951	 0.124247	 0.0	 249	 249	 249	 0.97182	 0.0	 1	 -30.0	 30.0;
	4867	 4868	 0.003556	 0.126222	 0.0	 245	 245	 245	 0.97182	 0.0	 1	 -30.0	 30.0;
	4885	 4886	 0.003516	 0.122667	 0.0	 249	 249	 249	 0.973708	 0.0	 1	 -30.0	 30.0;
	4885	 4886	 0.003062	 0.116741	 0.0	 262	 262	 262	 0.973708	 0.0	 1	 -30.0	 30.0;
	4889	 4890	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4889	 4890	 0.000319	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4905	 4907	 0.003062	 0.12484	 0.0	 247	 247	 247	 0.966188	 0.0	 1	 -30.0	 30.0;
	4905	 4906	 0.003121	 0.12484	 0.0	 247	 247	 247	 0.96432	 0.0	 1	 -30.0	 30.0;
	4906	 4908	 0.000803	 0.039335	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4907	 4908	 0.000325	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4906	 4908	 0.000796	 0.039266	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4912	 4914	 0.000305	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4920	 4922	 0.005037	 0.159012	 0.0	 194	 194	 194	 0.968054	 0.0	 1	 -30.0	 30.0;
	4919	 4922	 0.004523	 0.156049	 0.0	 198	 198	 198	 0.978474	 0.0	 1	 -30.0	 30.0;
	4920	 4922	 0.004919	 0.159012	 0.0	 194	 194	 194	 0.978474	 0.0	 1	 -30.0	 30.0;
	4921	 4922	 0.002212	 0.125432	 0.0	 251	 251	 251	 0.928505	 0.0	 1	 -30.0	 30.0;
	4922	 4923	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4922	 4923	 0.000325	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4926	 4927	 0.003002	 0.118716	 0.0	 257	 257	 257	 0.968054	 0.0	 1	 -30.0	 30.0;
	4926	 4927	 0.003002	 0.118716	 0.0	 257	 257	 257	 1.0	 0.0	 1	 -30.0	 30.0;
	4931	 4932	 0.003121	 0.12563	 0.0	 243	 243	 243	 0.999001	 0.0	 1	 -30.0	 30.0;
	4931	 4932	 0.003951	 0.125235	 0.0	 244	 244	 244	 0.999001	 0.0	 1	 -30.0	 30.0;
	4931	 4932	 0.003121	 0.12563	 0.0	 243	 243	 243	 0.999001	 0.0	 1	 -30.0	 30.0;
	4945	 4946	 0.003378	 0.121481	 0.0	 254	 254	 254	 0.974664	 0.0	 1	 -30.0	 30.0;
	4959	 4961	 0.00316	 0.11516	 0.0	 268	 268	 268	 1.020408	 0.0	 1	 -30.0	 30.0;
	4959	 4961	 0.003595	 0.120889	 0.0	 255	 255	 255	 1.029866	 0.0	 1	 -30.0	 30.0;
	4960	 5898	 0.00027	 -0.005332	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4960	 5921	 0.000249	 -0.005471	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4961	 5940	 0.000125	 -0.007687	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4960	 5949	 0.000173	 -0.007895	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4960	 5955	 0.000132	 -0.010942	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4962	 5898	 5.5e-05	 0.032756	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 5921	 6.9e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 5940	 0.000201	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 5949	 0.000166	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 5955	 0.000208	 0.038643	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	4963	 4965	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4964	 4965	 0.004207	 0.160988	 0.0	 190	 190	 190	 1.010101	 0.0	 1	 -30.0	 30.0;
	4964	 4965	 0.004227	 0.159012	 0.0	 192	 192	 192	 1.0	 0.0	 1	 -30.0	 30.0;
	4964	 4965	 0.003516	 0.121086	 0.0	 252	 252	 252	 1.009082	 0.0	 1	 -30.0	 30.0;
	4970	 4972	 0.001925	 0.101801	 0.0	 310	 310	 310	 0.939851	 0.0	 1	 -30.0	 30.0;
	4970	 4971	 0.001835	 0.101177	 0.0	 311	 311	 311	 0.956942	 0.0	 1	 -30.0	 30.0;
	4976	 4978	 0.001956	 0.126025	 0.0	 244	 244	 244	 1.0	 0.0	 1	 -30.0	 30.0;
	4977	 4978	 0.001956	 0.125037	 0.0	 246	 246	 246	 0.97561	 0.0	 1	 -30.0	 30.0;
	4979	 5922	 0.000145	 -0.011288	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4978	 4980	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	4979	 5950	 0.000291	 -0.00554	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4978	 4980	 0.000693	 0.048615	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4978	 5956	 0.000471	 -0.005263	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4980	 5922	 0.000187	 0.038712	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 5950	 2.8e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 5956	 0.000235	 0.053324	 0.0	 605.0	 605.0	 605.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4984	 4985	 0.004563	 0.160988	 0.0	 192	 192	 192	 0.978477	 0.0	 1	 -30.0	 30.0;
	4984	 4985	 0.00721	 0.231704	 0.0	 134	 134	 134	 0.946073	 0.0	 1	 -30.0	 30.0;
	4989	 4992	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	4988	 4991	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	4987	 4990	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	4993	 4995	 0.003378	 0.121481	 0.0	 254	 254	 254	 0.964319	 0.0	 1	 -30.0	 30.0;
	4997	 4998	 0.003378	 0.121936	 0.0	 253	 253	 253	 0.953289	 0.0	 1	 -30.0	 30.0;
	5001	 5002	 0.001975	 0.115951	 0.0	 265	 265	 265	 1.040584	 0.0	 1	 -30.0	 30.0;
	5003	 5004	 0.001817	 0.118716	 0.0	 259	 259	 259	 1.0142	 0.0	 1	 -30.0	 30.0;
	5008	 5009	 0.003358	 0.12563	 0.0	 245	 245	 245	 1.026695	 0.0	 1	 -30.0	 30.0;
	5008	 5009	 0.00316	 0.116938	 0.0	 264	 264	 264	 1.0142	 0.0	 1	 -30.0	 30.0;
	5037	 5038	 0.003536	 0.12563	 0.0	 245	 245	 245	 0.953289	 0.0	 1	 -30.0	 30.0;
	5055	 5056	 0.001679	 0.089482	 0.0	 341	 341	 341	 0.983284	 0.0	 1	 -30.0	 30.0;
	5065	 5067	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5065	 5066	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5064	 5066	 0.000339	 0.024446	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5064	 5067	 0.000332	 0.025069	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5073	 5074	 0.000346	 0.025346	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5073	 5074	 0.000332	 0.025208	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5081	 5082	 0.003042	 0.118321	 0.0	 261	 261	 261	 0.985226	 0.0	 1	 -30.0	 30.0;
	5088	 5089	 0.000325	 0.027701	 0.0	 1145	 1145	 1145	 1.0	 0.0	 1	 -30.0	 30.0;
	5965	 5966	 0.000694	 0.05125	 0.0	 674	 674	 674	 1.035197	 0.0	 1	 -30.0	 30.0;
	5964	 5966	 0.000631	 0.05	 0.0	 691	 691	 691	 0.967118	 0.0	 1	 -30.0	 30.0;
	5971	 5972	 0.0006	 0.028981	 0.0	 1192	 1192	 1192	 0.980392	 0.0	 1	 -30.0	 30.0;
	5973	 5974	 0.000419	 0.025313	 0.0	 1364	 1364	 1364	 1.001	 0.0	 1	 -30.0	 30.0;
	5980	 5981	 0.000212	 0.018819	 0.0	 599.0	 599.0	 599.0	 0.929366	 0.0	 1	 -30.0	 30.0;
	5983	 5985	 0.000403	 0.025619	 0.0	 1348	 1348	 1348	 1.001	 0.0	 1	 -30.0	 30.0;
	5984	 5985	 0.000403	 0.025619	 0.0	 1348	 1348	 1348	 1.001	 0.0	 1	 -30.0	 30.0;
	6000	 6197	 0.003714	 0.012701	 0.0	 425.0	 425.0	 425.0	 1.0	 -16.6	 1	 -30.0	 30.0;
	6198	 6003	 0.000125	 0.003125	 0.0	 11039	 11039	 11039	 1.04384	 0.0	 1	 -30.0	 30.0;
	6002	 6198	 0.000198	 0.004938	 0.0	 6986	 6986	 6986	 1.126727	 -6.75	 1	 -30.0	 30.0;
	6021	 6023	 6.8e-05	 0.01825	 0.0	 1892	 1892	 1892	 0.989122	 0.0	 1	 -30.0	 30.0;
	6022	 6024	 0.000151	 0.017549	 0.0	 1968	 1968	 1968	 0.989122	 0.0	 1	 -30.0	 30.0;
	6034	 6035	 9.3e-05	 0.01825	 0.0	 1892	 1892	 1892	 1.004018	 0.0	 1	 -30.0	 30.0;
	6039	 6041	 0.0004	 0.03	 0.0	 1151	 1151	 1151	 0.971818	 0.0	 1	 -30.0	 30.0;
	6199	 6040	 0.000119	 0.013827	 0.0	 599.0	 599.0	 599.0	 1.0	 -2.9	 1	 -30.0	 30.0;
	6057	 6058	 0.000139	 0.013299	 0.0	 2596	 2596	 2596	 1.013171	 0.0	 1	 -30.0	 30.0;
	6061	 6064	 0.000719	 0.04375	 0.0	 790	 790	 790	 1.071811	 0.0	 1	 -30.0	 30.0;
	6062	 6063	 0.000719	 0.04375	 0.0	 790	 790	 790	 0.998004	 0.0	 1	 -30.0	 30.0;
	6067	 6069	 0.000125	 0.046125	 0.0	 749	 749	 749	 1.0142	 0.0	 1	 -30.0	 30.0;
	6068	 6069	 0.000125	 0.046125	 0.0	 749	 749	 749	 1.0142	 0.0	 1	 -30.0	 30.0;
	6071	 6200	 4.4e-05	 0.001063	 0.0	 1947.0	 1947.0	 1947.0	 1.0	 1.91	 1	 -30.0	 30.0;
	6073	 6074	 0.0006	 0.030687	 0.0	 1125	 1125	 1125	 0.980393	 0.0	 1	 -30.0	 30.0;
	6073	 6074	 0.000381	 0.026838	 0.0	 1287	 1287	 1287	 0.971819	 0.0	 1	 -30.0	 30.0;
	6081	 6082	 0.0005	 0.03015	 0.0	 1145	 1145	 1145	 0.980392	 0.0	 1	 -30.0	 30.0;
	6085	 6086	 0.0006	 0.030081	 0.0	 1148	 1148	 1148	 0.932835	 0.0	 1	 -30.0	 30.0;
	6085	 6086	 0.0005	 0.026231	 0.0	 1316	 1316	 1316	 0.980393	 0.0	 1	 -30.0	 30.0;
	6093	 6095	 0.000136	 0.015151	 0.0	 2279	 2279	 2279	 0.949669	 0.0	 1	 -30.0	 30.0;
	6098	 6100	 0.000313	 0.01875	 0.0	 1842	 1842	 1842	 0.990095	 0.0	 1	 -30.0	 30.0;
	6105	 6106	 0.0003	 0.027769	 0.0	 1244	 1244	 1244	 0.971821	 0.0	 1	 -30.0	 30.0;
	6202	 6119	 2.7e-05	 0.009838	 0.0	 999.0	 999.0	 999.0	 0.950029	 0.0	 1	 -30.0	 30.0;
	6201	 6119	 2.7e-05	 0.009838	 0.0	 999.0	 999.0	 999.0	 0.950029	 0.0	 1	 -30.0	 30.0;
	6121	 6122	 0.0004	 0.044413	 0.0	 778	 778	 778	 0.92937	 0.0	 1	 -30.0	 30.0;
	6203	 6128	 0.000119	 0.014321	 0.0	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6135	 6136	 0.0002	 0.0188	 0.0	 1837	 1837	 1837	 0.939853	 0.0	 1	 -30.0	 30.0;
	6149	 6150	 0.000731	 0.045162	 0.0	 765	 765	 765	 0.947864	 0.0	 1	 -30.0	 30.0;
	6149	 6150	 0.000731	 0.045231	 0.0	 764	 764	 764	 0.94877	 0.0	 1	 -30.0	 30.0;
	6153	 6154	 0.0003	 0.022881	 0.0	 1509	 1509	 1509	 0.978474	 0.0	 1	 -30.0	 30.0;
	6173	 6174	 0.000338	 0.020438	 0.0	 1689	 1689	 1689	 0.971821	 0.0	 1	 -30.0	 30.0;
	6204	 6174	 6.2e-05	 0.00675	 0.0	 1629.0	 1629.0	 1629.0	 1.133606	 -15.01	 1	 -30.0	 30.0;
	6179	 6180	 0.000554	 0.031524	 0.0	 1096	 1096	 1096	 0.966184	 0.0	 1	 -30.0	 30.0;
	6183	 6184	 0.0004	 0.025687	 0.0	 1344	 1344	 1344	 0.950569	 0.0	 1	 -30.0	 30.0;
	6183	 6184	 0.0003	 0.025487	 0.0	 1355	 1355	 1355	 0.955109	 0.0	 1	 -30.0	 30.0;
	6183	 6184	 0.0004	 0.025413	 0.0	 1359	 1359	 1359	 0.946974	 0.0	 1	 -30.0	 30.0;
	6185	 6186	 0.0005	 0.02805	 0.0	 1231	 1231	 1231	 0.980392	 0.0	 1	 -30.0	 30.0;
	6127	 6203	 2.1e-05	 0.016116	 0.0	 399.0	 399.0	 399.0	 1.026694	 0.0	 1	 -30.0	 30.0;
	6210	 6211	 0.00055	 0.04302	 0.0	 803	 803	 803	 0.990093	 0.0	 1	 -30.0	 30.0;
	6206	 6220	 6e-06	 0.000625	 0.0	 55237	 55237	 55237	 0.97561	 0.0	 1	 -30.0	 30.0;
	6206	 6219	 0.000632	 0.015684	 0.0	 2200	 2200	 2200	 1.014351	 1.32	 1	 -30.0	 30.0;
	6224	 6207	 7.5e-05	 0.007931	 0.0	 1399.0	 1399.0	 1399.0	 1.0	 -2.93	 1	 -30.0	 30.0;
	6223	 6208	 7.5e-05	 0.007931	 0.0	 1399.0	 1399.0	 1399.0	 1.0	 -2.93	 1	 -30.0	 30.0;
	6229	 6230	 0.000181	 0.01425	 0.0	 1866.0	 1866.0	 1866.0	 0.991083	 0.0	 1	 -30.0	 30.0;
	6232	 6233	 0.0012	 0.08215	 0.0	 421	 421	 421	 0.971818	 0.0	 1	 -30.0	 30.0;
	6232	 6233	 0.000397	 0.049841	 0.0	 693	 693	 693	 0.995025	 0.0	 1	 -30.0	 30.0;
	6232	 6233	 0.0002	 0.018669	 0.0	 1850	 1850	 1850	 0.956943	 0.0	 1	 -30.0	 30.0;
	6234	 6235	 0.000312	 0.028362	 0.0	 399.0	 399.0	 399.0	 0.97182	 0.0	 1	 -30.0	 30.0;
	6244	 6245	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6242	 6245	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6243	 6245	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6241	 6245	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6246	 6247	 0.00015	 0.023481	 0.0	 1471	 1471	 1471	 0.971817	 0.0	 1	 -30.0	 30.0;
	6246	 6247	 0.000287	 0.026931	 0.0	 1282	 1282	 1282	 0.971817	 0.0	 1	 -30.0	 30.0;
	6252	 6209	 3.8e-05	 0.00375	 0.0	 1399.0	 1399.0	 1399.0	 1.0	 5.86	 1	 -30.0	 30.0;
	115	 6255	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	116	 6256	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	200	 6257	 0.0	 0.54184	 0.0	 64	 64	 64	 1.044444	 0.0	 1	 -30.0	 30.0;
	200	 6258	 0.0	 0.54184	 0.0	 64	 64	 64	 1.044444	 0.0	 1	 -30.0	 30.0;
	200	 6259	 0.0	 0.54184	 0.0	 64	 64	 64	 1.044444	 0.0	 1	 -30.0	 30.0;
	230	 6260	 0.0	 0.142857	 0.0	 241	 241	 241	 1.111111	 0.0	 1	 -30.0	 30.0;
	230	 6261	 0.0	 0.219149	 0.0	 157	 157	 157	 1.111111	 0.0	 1	 -30.0	 30.0;
	247	 6262	 0.0	 0.090928	 0.0	 378	 378	 378	 1.066667	 0.0	 1	 -30.0	 30.0;
	271	 6263	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	271	 6264	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	270	 6265	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	270	 6266	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	366	 6267	 0.0	 0.128409	 0.0	 268	 268	 268	 1.048889	 0.0	 1	 -30.0	 30.0;
	366	 6268	 0.0	 0.128409	 0.0	 268	 268	 268	 1.048889	 0.0	 1	 -30.0	 30.0;
	367	 6269	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	367	 6270	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	368	 6271	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	368	 6272	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	494	 6273	 0.0	 0.012611	 0.0	 1095.0	 1095.0	 1095.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	495	 6274	 0.0	 0.012611	 0.0	 1139.0	 1139.0	 1139.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	496	 6275	 0.0	 0.012611	 0.0	 1131.0	 1131.0	 1131.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	497	 6276	 0.0	 0.012611	 0.0	 1087.0	 1087.0	 1087.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	500	 6278	 0.0	 0.048207	 0.0	 261.0	 261.0	 261.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	499	 6279	 0.0	 0.048207	 0.0	 264.0	 264.0	 264.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	501	 6280	 0.0	 0.043965	 0.0	 779	 779	 779	 1.065789	 0.0	 1	 -30.0	 30.0;
	501	 6281	 0.0	 0.03442	 0.0	 292.0	 292.0	 292.0	 1.060526	 0.0	 1	 -30.0	 30.0;
	501	 6282	 0.0	 0.06506	 0.0	 527	 527	 527	 1.060526	 0.0	 1	 -30.0	 30.0;
	527	 6283	 0.0	 0.161429	 0.0	 213	 213	 213	 1.054667	 0.0	 1	 -30.0	 30.0;
	527	 6284	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	527	 6285	 0.0	 0.161429	 0.0	 213	 213	 213	 1.054667	 0.0	 1	 -30.0	 30.0;
	527	 6286	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	527	 6287	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	2797	 6288	 0.0	 0.044965	 0.0	 764	 764	 764	 1.080978	 0.0	 1	 -30.0	 30.0;
	616	 6289	 0.0	 0.112429	 0.0	 306	 306	 306	 1.042667	 0.0	 1	 -30.0	 30.0;
	616	 6290	 0.0	 0.183397	 0.0	 188	 188	 188	 1.093334	 0.0	 1	 -30.0	 30.0;
	616	 6291	 0.0	 0.183397	 0.0	 188	 188	 188	 1.088889	 0.0	 1	 -30.0	 30.0;
	623	 6292	 0.0	 0.33346	 0.0	 104	 104	 104	 0.985494	 0.0	 1	 -30.0	 30.0;
	624	 6293	 0.0	 0.166743	 0.0	 206	 206	 206	 1.026879	 0.0	 1	 -30.0	 30.0;
	624	 6294	 0.0	 0.300114	 0.0	 115	 115	 115	 1.020096	 0.0	 1	 -30.0	 30.0;
	672	 6295	 0.0	 0.012685	 0.0	 1101.0	 1101.0	 1101.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	671	 6296	 0.0	 0.012685	 0.0	 1092.0	 1092.0	 1092.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	670	 6297	 0.0	 0.012685	 0.0	 1070.0	 1070.0	 1070.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	669	 6298	 0.0	 0.012685	 0.0	 1017.0	 1017.0	 1017.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	690	 6299	 0.0	 0.009303	 0.0	 1545.0	 1545.0	 1545.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	692	 6300	 0.0	 0.009303	 0.0	 1546.0	 1546.0	 1546.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	699	 6301	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	699	 6302	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	699	 6303	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	698	 6304	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	698	 6305	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	698	 6306	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	720	 6307	 0.0	 0.453182	 0.0	 76	 76	 76	 1.088889	 0.0	 1	 -30.0	 30.0;
	900	 6308	 0.0	 0.008909	 0.0	 1568.0	 1568.0	 1568.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	902	 6309	 0.0	 0.008909	 0.0	 1585.0	 1585.0	 1585.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	903	 6310	 0.0	 0.008909	 0.0	 1535.0	 1535.0	 1535.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1008	 6311	 0.0	 0.128889	 0.0	 267	 267	 267	 1.088445	 0.0	 1	 -30.0	 30.0;
	1007	 6312	 0.0	 0.133372	 0.0	 258	 258	 258	 1.043111	 0.0	 1	 -30.0	 30.0;
	1007	 6313	 0.0	 0.133372	 0.0	 258	 258	 258	 1.088445	 0.0	 1	 -30.0	 30.0;
	1047	 6314	 0.0	 0.048207	 0.0	 713	 713	 713	 1.080978	 0.0	 1	 -30.0	 30.0;
	1054	 6315	 0.0	 0.054074	 0.0	 255.0	 255.0	 255.0	 1.077631	 0.0	 1	 -30.0	 30.0;
	1054	 6316	 0.0	 0.054074	 0.0	 260.0	 260.0	 260.0	 1.077631	 0.0	 1	 -30.0	 30.0;
	1057	 6317	 0.0	 0.012685	 0.0	 1114.0	 1114.0	 1114.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1061	 6319	 0.0	 0.012611	 0.0	 1122.0	 1122.0	 1122.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1060	 6320	 0.0	 0.012611	 0.0	 1120.0	 1120.0	 1120.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1066	 6321	 0.0	 0.009257	 0.0	 1906.0	 1906.0	 1906.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1067	 6322	 0.0	 0.009257	 0.0	 1849.0	 1849.0	 1849.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1081	 6323	 0.0	 0.009257	 0.0	 1797.0	 1797.0	 1797.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	1080	 6324	 0.0	 0.009257	 0.0	 1796.0	 1796.0	 1796.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	73	 6325	 0.0	 0.06579	 0.0	 522	 522	 522	 1.096667	 0.0	 1	 -30.0	 30.0;
	72	 6326	 0.0	 0.06579	 0.0	 522	 522	 522	 1.096667	 0.0	 1	 -30.0	 30.0;
	2107	 6327	 0.0	 0.1	 0.0	 344	 344	 344	 1.057778	 0.0	 1	 -30.0	 30.0;
	1176	 6328	 0.0	 0.01954	 0.0	 1759	 1759	 1759	 1.088844	 0.0	 1	 -30.0	 30.0;
	1177	 6329	 0.0	 0.020227	 0.0	 659.0	 659.0	 659.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1178	 6330	 0.0	 0.01954	 0.0	 667.0	 667.0	 667.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1179	 6332	 0.0	 0.021576	 0.0	 1588	 1588	 1588	 1.092105	 0.0	 1	 -30.0	 30.0;
	1446	 6333	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1446	 6334	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1446	 6335	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1446	 6336	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1446	 6337	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1446	 6338	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1300	 6339	 0.0	 0.012685	 0.0	 1128.0	 1128.0	 1128.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1297	 6340	 0.0	 0.012685	 0.0	 1148.0	 1148.0	 1148.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1299	 6341	 0.0	 0.012611	 0.0	 1154.0	 1154.0	 1154.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1298	 6342	 0.0	 0.012611	 0.0	 1100.0	 1100.0	 1100.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1340	 6343	 0.0	 0.181818	 0.0	 189	 189	 189	 1.044444	 0.0	 1	 -30.0	 30.0;
	1340	 6344	 0.0	 0.181818	 0.0	 189	 189	 189	 1.044444	 0.0	 1	 -30.0	 30.0;
	1366	 6345	 0.0	 0.041231	 0.0	 833	 833	 833	 1.0948	 0.0	 1	 -30.0	 30.0;
	1365	 6346	 0.0	 0.273494	 0.0	 126	 126	 126	 1.062667	 0.0	 1	 -30.0	 30.0;
	1432	 6347	 0.0	 0.032831	 0.0	 485.0	 485.0	 485.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	1578	 6348	 0.0	 0.012685	 0.0	 1075.0	 1075.0	 1075.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1579	 6349	 0.0	 0.012685	 0.0	 1075.0	 1075.0	 1075.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1580	 6350	 0.0	 0.012685	 0.0	 1083.0	 1083.0	 1083.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1581	 6351	 0.0	 0.012685	 0.0	 1097.0	 1097.0	 1097.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1608	 6352	 0.0	 0.345838	 0.0	 100	 100	 100	 1.044444	 0.0	 1	 -30.0	 30.0;
	1770	 6353	 0.0	 0.009303	 0.0	 1590.0	 1590.0	 1590.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	1769	 6354	 0.0	 0.009303	 0.0	 1447.0	 1447.0	 1447.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	1872	 6355	 0.0	 0.3396	 0.0	 103	 103	 103	 1.0	 0.0	 1	 -30.0	 30.0;
	1961	 6356	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	1962	 6357	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	1962	 6358	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	1962	 6359	 0.0	 0.148375	 0.0	 232	 232	 232	 1.057778	 0.0	 1	 -30.0	 30.0;
	1961	 6360	 0.0	 0.148375	 0.0	 232	 232	 232	 1.057778	 0.0	 1	 -30.0	 30.0;
	2017	 6361	 0.0	 0.008909	 0.0	 1579.0	 1579.0	 1579.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	2018	 6362	 0.0	 0.008909	 0.0	 1584.0	 1584.0	 1584.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	2021	 6363	 0.0	 0.457282	 0.0	 76	 76	 76	 1.066667	 0.0	 1	 -30.0	 30.0;
	2021	 6364	 0.0	 0.457282	 0.0	 76	 76	 76	 1.066667	 0.0	 1	 -30.0	 30.0;
	2047	 6365	 0.0	 0.042476	 0.0	 493.0	 493.0	 493.0	 1.062222	 0.0	 1	 -30.0	 30.0;
	2054	 6366	 0.0	 0.302795	 0.0	 114	 114	 114	 1.053333	 0.0	 1	 -30.0	 30.0;
	2062	 6367	 0.0	 0.012685	 0.0	 1116.0	 1116.0	 1116.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2063	 6368	 0.0	 0.012685	 0.0	 1117.0	 1117.0	 1117.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2064	 6369	 0.0	 0.012685	 0.0	 1125.0	 1125.0	 1125.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2065	 6370	 0.0	 0.012685	 0.0	 1119.0	 1119.0	 1119.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2066	 6371	 0.0	 0.012685	 0.0	 1117.0	 1117.0	 1117.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2067	 6372	 0.0	 0.012685	 0.0	 997.0	 997.0	 997.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2135	 6373	 0.0	 0.041112	 0.0	 835	 835	 835	 1.081067	 0.0	 1	 -30.0	 30.0;
	2164	 6374	 0.0	 0.029081	 0.0	 510.0	 510.0	 510.0	 1.080888	 0.0	 1	 -30.0	 30.0;
	2199	 6375	 0.0	 0.044965	 0.0	 307.0	 307.0	 307.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	2200	 6376	 0.0	 0.020227	 0.0	 1697	 1697	 1697	 1.088844	 0.0	 1	 -30.0	 30.0;
	2201	 6377	 0.0	 0.021197	 0.0	 1616	 1616	 1616	 1.103079	 0.0	 1	 -30.0	 30.0;
	2222	 6379	 0.0	 0.203226	 0.0	 169	 169	 169	 1.048889	 0.0	 1	 -30.0	 30.0;
	2222	 6380	 0.0	 0.203226	 0.0	 169	 169	 169	 1.048889	 0.0	 1	 -30.0	 30.0;
	2242	 6381	 0.0	 0.372846	 0.0	 93	 93	 93	 1.076889	 0.0	 1	 -30.0	 30.0;
	2242	 6382	 0.0	 0.372846	 0.0	 93	 93	 93	 1.076889	 0.0	 1	 -30.0	 30.0;
	2400	 6383	 0.0	 0.525174	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	2400	 6384	 0.0	 0.525174	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	2460	 6385	 0.0	 0.460144	 0.0	 75	 75	 75	 1.035556	 0.0	 1	 -30.0	 30.0;
	2661	 6386	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2661	 6387	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2661	 6388	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2661	 6389	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2617	 6390	 0.0	 0.048207	 0.0	 712	 712	 712	 1.080978	 0.0	 1	 -30.0	 30.0;
	2653	 6391	 0.0	 0.220078	 0.0	 156	 156	 156	 1.07511	 0.0	 1	 -30.0	 30.0;
	2653	 6392	 0.0	 0.220078	 0.0	 156	 156	 156	 1.07511	 0.0	 1	 -30.0	 30.0;
	2704	 6393	 0.0	 0.120375	 0.0	 286	 286	 286	 1.053333	 0.0	 1	 -30.0	 30.0;
	2704	 6394	 0.0	 0.17125	 0.0	 201	 201	 201	 1.053333	 0.0	 1	 -30.0	 30.0;
	2704	 6395	 0.0	 0.13875	 0.0	 248	 248	 248	 1.049777	 0.0	 1	 -30.0	 30.0;
	2704	 6396	 0.0	 0.120375	 0.0	 286	 286	 286	 1.053333	 0.0	 1	 -30.0	 30.0;
	2710	 6397	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	2710	 6398	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	2710	 6399	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	2727	 6400	 0.0	 0.181636	 0.0	 189	 189	 189	 1.088889	 0.0	 1	 -30.0	 30.0;
	2749	 6401	 0.0	 0.360113	 0.0	 96	 96	 96	 1.075556	 0.0	 1	 -30.0	 30.0;
	2749	 6402	 0.0	 0.360113	 0.0	 96	 96	 96	 1.075556	 0.0	 1	 -30.0	 30.0;
	2749	 6403	 0.0	 0.360113	 0.0	 96	 96	 96	 1.075556	 0.0	 1	 -30.0	 30.0;
	2749	 6404	 0.0	 0.360113	 0.0	 96	 96	 96	 1.075556	 0.0	 1	 -30.0	 30.0;
	2821	 6405	 0.0	 0.044965	 0.0	 763	 763	 763	 1.080978	 0.0	 1	 -30.0	 30.0;
	2820	 6406	 0.0	 0.044965	 0.0	 763	 763	 763	 1.080978	 0.0	 1	 -30.0	 30.0;
	2860	 6407	 0.0	 0.482751	 0.0	 72	 72	 72	 1.137778	 0.0	 1	 -30.0	 30.0;
	2860	 6408	 0.0	 0.482751	 0.0	 72	 72	 72	 1.137778	 0.0	 1	 -30.0	 30.0;
	4405	 6409	 0.0	 0.084636	 0.0	 406	 406	 406	 1.097778	 0.0	 1	 -30.0	 30.0;
	379	 6410	 0.0	 0.031723	 0.0	 451.0	 451.0	 451.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	3038	 6411	 0.0	 0.25608	 0.0	 135	 135	 135	 1.072445	 0.0	 1	 -30.0	 30.0;
	3038	 6412	 0.0	 0.25608	 0.0	 135	 135	 135	 1.072445	 0.0	 1	 -30.0	 30.0;
	3055	 6413	 0.0	 0.0516	 0.0	 666	 666	 666	 1.07511	 0.0	 1	 -30.0	 30.0;
	3054	 6414	 0.0	 0.0516	 0.0	 666	 666	 666	 1.07511	 0.0	 1	 -30.0	 30.0;
	3058	 6415	 0.0	 0.0592	 0.0	 579	 579	 579	 1.092105	 0.0	 1	 -30.0	 30.0;
	3058	 6416	 0.0	 0.0596	 0.0	 575	 575	 575	 1.092105	 0.0	 1	 -30.0	 30.0;
	3057	 6417	 0.0	 0.0596	 0.0	 575	 575	 575	 1.092105	 0.0	 1	 -30.0	 30.0;
	3057	 6418	 0.0	 0.05972	 0.0	 574	 574	 574	 1.092105	 0.0	 1	 -30.0	 30.0;
	3088	 6419	 0.0	 0.15879	 0.0	 217	 217	 217	 1.052889	 0.0	 1	 -30.0	 30.0;
	3088	 6420	 0.0	 0.15879	 0.0	 217	 217	 217	 1.052889	 0.0	 1	 -30.0	 30.0;
	1745	 6421	 0.0	 0.012685	 0.0	 1110.0	 1110.0	 1110.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1744	 6422	 0.0	 0.012685	 0.0	 1065.0	 1065.0	 1065.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3149	 6423	 0.0	 0.03299	 0.0	 276.0	 276.0	 276.0	 1.04	 0.0	 1	 -30.0	 30.0;
	3149	 6424	 0.0	 0.04269	 0.0	 804	 804	 804	 1.081	 0.0	 1	 -30.0	 30.0;
	3150	 6425	 0.0	 0.034269	 0.0	 1000	 1000	 1000	 1.060526	 0.0	 1	 -30.0	 30.0;
	3236	 6426	 0.0	 0.009303	 0.0	 1573.0	 1573.0	 1573.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3253	 6427	 0.0	 0.144154	 0.0	 239	 239	 239	 1.066667	 0.0	 1	 -30.0	 30.0;
	3253	 6428	 0.0	 0.144154	 0.0	 239	 239	 239	 1.066667	 0.0	 1	 -30.0	 30.0;
	3263	 6429	 0.0	 0.297059	 0.0	 116	 116	 116	 1.066667	 0.0	 1	 -30.0	 30.0;
	3318	 6430	 0.0	 0.008909	 0.0	 1585.0	 1585.0	 1585.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3319	 6431	 0.0	 0.008909	 0.0	 1643.0	 1643.0	 1643.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3320	 6432	 0.0	 0.008909	 0.0	 1638.0	 1638.0	 1638.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3317	 6433	 0.0	 0.008909	 0.0	 1645.0	 1645.0	 1645.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3346	 6434	 0.0	 0.389792	 0.0	 89	 89	 89	 1.044444	 0.0	 1	 -30.0	 30.0;
	3373	 6435	 0.0	 0.009303	 0.0	 1637.0	 1637.0	 1637.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3374	 6436	 0.0	 0.009303	 0.0	 1599.0	 1599.0	 1599.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3479	 6437	 0.0	 0.021485	 0.0	 1594	 1594	 1594	 1.103079	 0.0	 1	 -30.0	 30.0;
	3478	 6438	 0.0	 0.021485	 0.0	 1594	 1594	 1594	 1.103079	 0.0	 1	 -30.0	 30.0;
	3477	 6439	 0.0	 0.021485	 0.0	 779.0	 779.0	 779.0	 1.103079	 0.0	 1	 -30.0	 30.0;
	3476	 6440	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	3493	 6441	 0.0	 0.314388	 0.0	 110	 110	 110	 1.048889	 0.0	 1	 -30.0	 30.0;
	3493	 6442	 0.0	 0.314388	 0.0	 110	 110	 110	 1.048889	 0.0	 1	 -30.0	 30.0;
	3493	 6443	 0.0	 0.314388	 0.0	 110	 110	 110	 1.048889	 0.0	 1	 -30.0	 30.0;
	3504	 6444	 0.0	 0.156299	 0.0	 220	 220	 220	 1.053333	 0.0	 1	 -30.0	 30.0;
	3534	 6445	 0.0	 0.044965	 0.0	 288.0	 288.0	 288.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	3533	 6446	 0.0	 0.020227	 0.0	 488.0	 488.0	 488.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	3595	 6447	 0.0	 0.214367	 0.0	 161	 161	 161	 1.026667	 0.0	 1	 -30.0	 30.0;
	3595	 6448	 0.0	 0.214367	 0.0	 161	 161	 161	 1.026667	 0.0	 1	 -30.0	 30.0;
	3607	 6449	 0.0	 0.733548	 0.0	 47	 47	 47	 1.044444	 0.0	 1	 -30.0	 30.0;
	3688	 6450	 0.0	 0.431133	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	3688	 6451	 0.0	 0.431017	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	3671	 6452	 0.0	 0.046748	 0.0	 523.0	 523.0	 523.0	 1.066667	 0.0	 1	 -30.0	 30.0;
	3703	 6453	 0.0	 0.283636	 0.0	 122	 122	 122	 1.022222	 0.0	 1	 -30.0	 30.0;
	3726	 6454	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	3725	 6455	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	3724	 6456	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	3729	 6457	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3729	 6458	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3729	 6459	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3729	 6460	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3808	 6461	 0.0	 0.0774	 0.0	 443	 443	 443	 1.052632	 0.0	 1	 -30.0	 30.0;
	3807	 6462	 0.0	 0.06037	 0.0	 568	 568	 568	 1.031422	 0.0	 1	 -30.0	 30.0;
	3806	 6463	 0.0	 0.0774	 0.0	 443	 443	 443	 1.052632	 0.0	 1	 -30.0	 30.0;
	3805	 6464	 0.0	 0.0774	 0.0	 443	 443	 443	 1.052632	 0.0	 1	 -30.0	 30.0;
	645	 6465	 0.0	 0.330403	 0.0	 104	 104	 104	 1.044444	 0.0	 1	 -30.0	 30.0;
	644	 6466	 0.0	 0.330403	 0.0	 104	 104	 104	 1.044444	 0.0	 1	 -30.0	 30.0;
	643	 6467	 0.0	 0.330403	 0.0	 104	 104	 104	 1.044444	 0.0	 1	 -30.0	 30.0;
	642	 6468	 0.0	 0.330403	 0.0	 104	 104	 104	 1.044444	 0.0	 1	 -30.0	 30.0;
	641	 6469	 0.0	 0.330403	 0.0	 104	 104	 104	 1.044444	 0.0	 1	 -30.0	 30.0;
	3991	 6470	 0.0	 0.317591	 0.0	 109	 109	 109	 1.022222	 0.0	 1	 -30.0	 30.0;
	3996	 6471	 0.0	 0.329412	 0.0	 105	 105	 105	 1.044444	 0.0	 1	 -30.0	 30.0;
	3996	 6472	 0.0	 0.329412	 0.0	 105	 105	 105	 1.044444	 0.0	 1	 -30.0	 30.0;
	4020	 6473	 0.0	 0.302312	 0.0	 114	 114	 114	 1.034667	 0.0	 1	 -30.0	 30.0;
	4020	 6474	 0.0	 0.290091	 0.0	 119	 119	 119	 1.04	 0.0	 1	 -30.0	 30.0;
	4020	 6475	 0.0	 0.290101	 0.0	 119	 119	 119	 1.04	 0.0	 1	 -30.0	 30.0;
	4020	 6476	 0.0	 0.175059	 0.0	 196	 196	 196	 1.103555	 0.0	 1	 -30.0	 30.0;
	4046	 6477	 0.0	 0.167949	 0.0	 205	 205	 205	 1.048889	 0.0	 1	 -30.0	 30.0;
	4046	 6478	 0.0	 0.167949	 0.0	 205	 205	 205	 1.048889	 0.0	 1	 -30.0	 30.0;
	4052	 6479	 0.0	 0.733625	 0.0	 47	 47	 47	 1.08	 0.0	 1	 -30.0	 30.0;
	4137	 6480	 0.0	 0.124444	 0.0	 276	 276	 276	 1.046222	 0.0	 1	 -30.0	 30.0;
	4137	 6481	 0.0	 0.124444	 0.0	 276	 276	 276	 1.046222	 0.0	 1	 -30.0	 30.0;
	4137	 6482	 0.0	 0.124444	 0.0	 276	 276	 276	 1.046222	 0.0	 1	 -30.0	 30.0;
	4137	 6483	 0.0	 0.124444	 0.0	 276	 276	 276	 1.046222	 0.0	 1	 -30.0	 30.0;
	4144	 6484	 0.0	 0.088828	 0.0	 387	 387	 387	 1.022222	 0.0	 1	 -30.0	 30.0;
	4188	 6485	 0.0	 0.009303	 0.0	 1606.0	 1606.0	 1606.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	4187	 6486	 0.0	 0.009303	 0.0	 1577.0	 1577.0	 1577.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1699	 6487	 0.0	 0.035942	 0.0	 335.0	 335.0	 335.0	 1.081023	 0.0	 1	 -30.0	 30.0;
	1698	 6488	 0.0	 0.019697	 0.0	 642.0	 642.0	 642.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1696	 6489	 0.0	 0.037419	 0.0	 484.0	 484.0	 484.0	 1.11579	 0.0	 1	 -30.0	 30.0;
	1695	 6490	 0.0	 0.037117	 0.0	 512.0	 512.0	 512.0	 1.11579	 0.0	 1	 -30.0	 30.0;
	4254	 6491	 0.0	 0.244364	 0.0	 141	 141	 141	 1.044444	 0.0	 1	 -30.0	 30.0;
	4254	 6492	 0.0	 0.244364	 0.0	 141	 141	 141	 1.044444	 0.0	 1	 -30.0	 30.0;
	4264	 6493	 0.0	 0.3396	 0.0	 103	 103	 103	 1.069841	 0.0	 1	 -30.0	 30.0;
	4263	 6494	 0.0	 0.3396	 0.0	 103	 103	 103	 1.069841	 0.0	 1	 -30.0	 30.0;
	4269	 6495	 0.0	 0.148936	 0.0	 231	 231	 231	 1.073333	 0.0	 1	 -30.0	 30.0;
	4269	 6496	 0.0	 0.21875	 0.0	 157	 157	 157	 1.073333	 0.0	 1	 -30.0	 30.0;
	4286	 6497	 0.0	 0.012611	 0.0	 1082.0	 1082.0	 1082.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	4285	 6498	 0.0	 0.012611	 0.0	 1074.0	 1074.0	 1074.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	4294	 6499	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	4294	 6500	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	4294	 6501	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	4507	 6502	 0.0	 0.092765	 0.0	 370	 370	 370	 1.065789	 0.0	 1	 -30.0	 30.0;
	4528	 6503	 0.0	 0.1195	 0.0	 288	 288	 288	 1.044444	 0.0	 1	 -30.0	 30.0;
	4528	 6504	 0.0	 0.1195	 0.0	 288	 288	 288	 1.044444	 0.0	 1	 -30.0	 30.0;
	4694	 6505	 0.0	 0.012769	 0.0	 1113.0	 1113.0	 1113.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4695	 6506	 0.0	 0.012769	 0.0	 1079.0	 1079.0	 1079.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4696	 6507	 0.0	 0.012769	 0.0	 1149.0	 1149.0	 1149.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4697	 6508	 0.0	 0.012769	 0.0	 1140.0	 1140.0	 1140.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4764	 6509	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	4764	 6510	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	4763	 6511	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	4795	 6512	 0.0	 0.16148	 0.0	 213	 213	 213	 1.155555	 0.0	 1	 -30.0	 30.0;
	4795	 6513	 0.0	 0.16148	 0.0	 213	 213	 213	 1.155555	 0.0	 1	 -30.0	 30.0;
	4795	 6514	 0.0	 0.16148	 0.0	 213	 213	 213	 1.155555	 0.0	 1	 -30.0	 30.0;
	4944	 6515	 0.0	 0.044965	 0.0	 326.0	 326.0	 326.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	4943	 6516	 0.0	 0.044965	 0.0	 287.0	 287.0	 287.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	4952	 6517	 0.0	 0.070769	 0.0	 484	 484	 484	 1.026316	 0.0	 1	 -30.0	 30.0;
	5009	 6518	 0.0	 0.15125	 0.0	 227	 227	 227	 1.044444	 0.0	 1	 -30.0	 30.0;
	5009	 6519	 0.0	 0.15125	 0.0	 227	 227	 227	 1.044444	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Line Capacity Model:         ub
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% INFO    : Line Capacity PAB:           15.0 (deg.)
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    336 -     2.66
% INFO    : NUC    13  -    12.84
% INFO    : SYNC   20  -     0.00
% INFO    : COW    259 -    61.48
% INFO    : NG     760 -    23.02
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 13.409395493 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.1073437045 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.9255253422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4844649923 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.925421142 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.2882030136 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.056804976 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.3409779669 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.6622059919 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.703932932 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.557086815 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 50.0265092704 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.7352975897 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5717936346 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.370381787 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.662993067 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.8807962947 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7339663102 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.732518823 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.970100914 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.6463500613 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.5661929825 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.5442167517 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.6794178778 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3938777436 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8308823235 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.4247252051 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2728200138 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4609027203 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 129.749889759 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.2625473551 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.213206299 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 22.9853093452 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 129.405681016 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3346977534 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.4366390929 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3188138321 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 94.8560540248 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.508935356 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.8169674972 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.5777819991 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.0741945261 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.067001727 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0405618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3196222295 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 53.3758291072 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.8042578506 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.4294693454 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.7206937034 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 62.3660230932 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.750648609 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.509795052 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 119.781152747 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.846762859 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.1981635327 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.7201269589 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3205851661 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.326679179 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1688616577 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 11.1474213441 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.2033793224 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.4759489599 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.8956221507 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6821967235 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.2012724947 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.185353469 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7095755349 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.154841657 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.1267076696 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.200206086 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.0286807668 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.2147310395 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 103.22692206 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.113675918 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.856159731 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 100.708099076 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.648629893 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 15.9023676686 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.1571630439 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.28124866 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.373445508 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.3805671392 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.4291545971 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.6413276627 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.0650151884 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.8845846032 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6110762691 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.0382606934 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.4237402186 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.2144753355 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.270388176 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.720651793 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.4045522071 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.6071971441 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.4305956798 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 16.7334300325 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.624427082 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.34040207 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.1113795152 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 125.429813719 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 12.8460559799 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.485380536 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0251216142 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4024172667 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.5370087803 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.14463897 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.7408580226 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.3824537238 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 34.2860698452 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.753632449 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.1444167522 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.0519892081 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.3209517867 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.4218841215 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.5883890192 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.298353685 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.050420396 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6654823656 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 50.4289635667 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.8446484999 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.66467968 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.3145614885 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.4248995612 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.476685827 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.031232193 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.394023961 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.4172678593 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5307740058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7899366595 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.6427325742 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.2485293261 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.815060535 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.6729774474 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 126.98283238 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.1504941395 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.3411770534 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6580109054 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.745883302 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.8896673863 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.41598532 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.729573299 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 54.3517716155 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.5276480574 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.460931056 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.3997268265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.3691940813 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9960494117 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6709523159 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8712012748 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.579564126 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.5768551091 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5500687704 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.7955373282 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.559823673 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.215905486 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.716487375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.2253073079 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.8885646977 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.3514466304 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.2911152546 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.264680716 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.4782379641 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.9557599537 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3978635896 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.4797408888 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.477258215 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 101.034318295 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.1160006003 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.700923895 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.0900419439 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.103189517 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.0496751446 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 91.065150929 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.340308337 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 39.4474349078 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4600493056 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.209897738 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 14.1003243695 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.687082525 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.028476398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.9738039733 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.873140348 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.6667926436 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5645027332 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.8677483731 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.0153860891 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3004275555 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.8327103888 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3918407155 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.7014072601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.477873417 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4788324229 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.4746337999 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.4314781951 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.338369459 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.6190400827 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.18650586 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.393833657 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.711325191 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6296770403 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.508800373 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.1917203866 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.2032975783 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.9014101869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0946415599 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3341387256 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.7753389726 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.2030111836 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.167838922 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.5911456137 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.5824354407 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 98.254207157 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.2923777874 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.306702705 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 122.957279079 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.235538956 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.6573723287 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.5636913301 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.080952752 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.530628541 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.8995924006 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.8109590758 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.738826824 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.495725015 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.576543333 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.884377315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.4821348667 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.379420435 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.2284264307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1736887507 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.230452371 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8853404596 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.9972492692 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.3429534127 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6568927172 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.5829708576 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.957755204 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.43661776232 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.715019875 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0900779536 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.100909352 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.2046826995 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 101.6937907 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.9111358827 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.5067739107 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.3270357298 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 22.5076085054 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5611172914 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8182614059 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.5483491861 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.8908980415 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.1274829049 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.9507533004 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.520038069 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7455717898 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.6049595881 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 100.410678904 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 14.3702637303 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.335248772 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.098831242 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.49746081 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.030861096 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4437338703 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.360172215 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 53.0004465759 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.0072239745 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 103.425229517 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.8770740275 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.1942534653 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.0647311608 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.9518294285 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.9147787939 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.5162611143 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.9297876564 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.2528905331 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7646510433 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.9431355335 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2105948908 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3732311475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.654882354 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.143823127 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8031965595 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.328351417 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.888357368 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0233003603 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 119.570682006 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.4500022777 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.6778467613 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.9472723556 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.855855835 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 54.6332478385 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.7684180452 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.5945725391 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.161428119 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.6821709907 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.075102836 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9325766719 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0220430353 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.7885173012 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.8013659096 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7669090392 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.8873209875 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.530475014 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.5917262215 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 11.4898439075 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.394165949 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.050036014 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.4530180771 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3141885391 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.1409786043 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2333395337 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.212121599 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9804918139 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.1983837556 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.6943134337 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 11.9697014217 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.8098868425 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.259587488 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.145116636 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5792269695 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.246384025 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.6687431634 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.5469277013 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.573984423 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.559870294 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.003408004 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.555590717 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 12.4939291263 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.5464660804 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.6994669902 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.9302197294 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2141610045 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.793600277 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.6770162559 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.2797208966 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 103.203803495 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.277095765 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.9885077671 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0465005711 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 87.8671832154 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 125.915956679 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 35.9546755121 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.332116438 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 9.12983478484 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.4824878286 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.1650227122 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6188404861 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2525740518 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.2428191559 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.0163067525 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0578567544 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.6348913964 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 122.330194272 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.6081560894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8360115139 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.222937685 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.298519208 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.305333064 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 11.9680270915 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.5536722307 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2545700995 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5121617071 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9811760639 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 14.7783653868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6356486425 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.2446569884 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.6498287215 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 54.6089640757 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5227662065 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7371066934 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0022035171 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2285740516 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 87.9467198645 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.3746987828 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 122.077659523 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 16.828307157 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.41587724 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.9858418033 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 128.680257043 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 132.992010472 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2846564112 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1170222641 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.7312373162 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.027326063 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.498380566 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.206225341 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.7915743339 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.45825876 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.453445848 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.2310027493 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 10.7266052749 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.0542873921 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0964216712 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 142.396153054 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2582572034 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 132.81296294 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.1953216925 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.085267962 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.7388436302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0835892286 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.9873701823 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.4232148538 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.173745813 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.973984052 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1330921922 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.1561257338 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.4575584411 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.9099862826 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0304002005 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.4776821949 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7528503963 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.2577800861 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.6643424125 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 101.016299373 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.5917653282 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.8340030484 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.779682791 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.9927693029 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.0019403798 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1636404884 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.6368528488 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.0563487805 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.3142981043 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.220210028 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.118768013 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.966395333 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.6430721229 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 16.2304090605 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 79.8736593034 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.9708695614 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.9517351083 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.7162042126 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.5623697206 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.2628892062 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.0754727971 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8739587022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9776291613 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.9343643832 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.534615698 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.0876758419 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.0634866585 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.036805064 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.501243518 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6150828877 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.096763095 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0752293216 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.585088088 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4421020179 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3360055958 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.6114343843 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5411823129 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.994338922 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.369055809 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.1405112614 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.0396358945 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.2834360038 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.812944946 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.381000667 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.999555372 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.7935887758 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 59.0346585575 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.9582011343 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 125.757569304 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 51.5734176745 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.8569189106 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.8634422036 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.7782848674 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.3713342998 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 132.304748755 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.2387842174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7123287429 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4115334203 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.23583411 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 45.6781590309 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.9862754622 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 17.1011914621 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9403268285 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.936138251 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.8703007132 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.0557248405 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0948803291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.0888554247 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.8446258965 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 91.6514738246 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 35.9103463665 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.1374836113 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.662349452 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.442180278 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.067684872 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.403664427 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.252689884 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.176012521 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.684856382 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.7049145534 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.833541585 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0117325718 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5785149704 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.936540667 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.1198671587 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.0824011231 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.87580468 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.51413620173 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.054941771 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.3563233407 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1257452007 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.763823529 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.5983609071 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.1038356198 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.7586334291 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.634329196 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.1568861664 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.519102434 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6263908515 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.604014129 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.782722777 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 14.8427314571 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.4884236505 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.9821460271 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 41.7214142401 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.38835652 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.330400971 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.2933468257 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.344514913 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.1186073478 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.5914690072 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.1736671501 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.8484044427 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.0501538 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.303825509 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.134568998 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 131.047825091 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8109439805 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.516401937 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.4924926299 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 32.5654694944 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7403710684 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.8285993112 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.112175417 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0005528794 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 30.2247695926 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 131.143234401 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8328045649 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.7814247611 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.46269477 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.9967710885 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.4126821368 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.9845303099 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.9375263927 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 5.40994817219 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 2.7739014217 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.888443708 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0708895415 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.684172323 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.184905503 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.1170784896 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.8928307079 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 36.621534154 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 8.02230851971 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.5788747179 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.1875516643 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 7.98476328558 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 12.4086671535 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 7.79664177771 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.8423289523 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.121933603 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.5571256906 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 7.8739166975 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 63.8387696654 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.729737701 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.248189349 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.4281979458 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.951410843 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0783302474 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 13.0419851493 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 94.7765097757 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0360105618 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.434125171 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.973731857 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.2368889829 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6975491055 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 50.0367679875 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.580108201 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.2011871857 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.8451111272 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.684726277 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.3902838624 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.2429483186 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.234340968 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0305443156 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3436630356 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.1519674577 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.9039922436 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.4346725856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9972411848 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.971616206 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.7290287015 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.472128955 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 91.8306864625 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.019230099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4377472461 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.5152945791 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.3714008 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.950602264 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.6679040105 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6531269165 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.979662614 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8844182049 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0145769034 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.886769385 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.229170224 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.2353497441 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.832643057 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.3604047662 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.5842635528 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.643939776 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.0366343554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7444047966 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.927603004 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.5159686406 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 103.291911048 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4500041634 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.5199671474 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.2805054737 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.98167976 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.7582812686 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.628249787 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0735180851 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 127.297401347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.1964564415 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 32.1094044938 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.9004783801 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4630576525 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.9777903172 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 5.6036814122 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.874643092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5093629706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9464538276 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 132.093485334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9956560256 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2296206409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0002220514 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.1265986175 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9649809043 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.929259692 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.1825457478 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.780402935 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.4521926793 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.823284682 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.7556944504 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.0966418178 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.0025341663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3431471315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3386926301 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.86211726 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.6725186316 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 36.5663366545 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.991896875 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.1145260997 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.799272947 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.5976106648 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.733305791 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1241073112 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.2664364136 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 94.532070212 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 15.5111766436 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 37.9184944759 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.3840810967 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.012240133 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.7895036701 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.122247023 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.0583026997 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.020239188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2849061344 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.465969792 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.560598433 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.224424986 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2175560907 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.3468505289 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.128600368 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.5429144258 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2775419934 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 91.1518489589 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.4833556684 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.006588581 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7719890869 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.521626178 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 17.1891139785 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.6051501441 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.4588082578 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 101.548011078 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.0319988699 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6966579335 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5256382168 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.126097259 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.677476073 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.175963228 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 96.0563059644 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2395270027 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8495126178 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.164934387 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.91462883 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.4094301067 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.1495993332 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.4481706907 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.7749837922 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 16.4927251128 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.1109975199 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.9936741833 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.941762743 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.2643047635 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.7765700822 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.1761650792 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.038434138 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.5816878 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.4842466784 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.9303095169 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.8604489129 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.1251782111 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.893913382 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.404940077 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.594799771 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.6392751363 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 54.2149353089 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.560313599 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5187015348 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.3442166826 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7297760927 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 96.6139060086 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7625019252 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.2128078804 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 19.4419895795 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7584404722 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6067622869 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.2026086732 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 124.301658899 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 128.097225635 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.895615234 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8785409263 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7667438348 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.9986034539 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.0508086184 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.2664000463 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5343629005 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1820989532 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4074381815 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.5810423895 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4539359576 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 127.894101742 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 38.4490555929 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 6.46704614799 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.179315011 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.70734317 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 34.0284001927 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.4546320632 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.0874215864 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.784269098 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1680918791 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.1288952924 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.8362182607 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.3575810598 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.604054638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3561938371 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9744519323 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.0605508583 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9287910894 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.987214093 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.7999685047 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.691382288 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.647624207 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.165037186 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.7949026816 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3996422234 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 15.7308304836 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.457659503 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 130.162854763 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.011327518 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.326491343 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.8437855251 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.029653164 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.0988970375 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.68121554 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.7572554375 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.736391226 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 60.8423899057 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.9462649533 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1839805746 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.1821526546 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0674118309 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.1290498274 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.7271386517 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.709461658 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 12.1026697101 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.2152680716 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.172079709 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 14.7848879417 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.4230832089 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.95119926 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.7136526031 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1729532401 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.4628258741 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.1388775862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6262309713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.1887069432 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.8670972753 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.7144667393 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.9416051399 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7087725729 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.891347947 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.41040675 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.295450172 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.5579504891 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.2926919117 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.3446794568 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.074041037 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.7639114494 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 54.2972616054 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.2302555804 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.4878322042 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2368658999 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.2404280829 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.195300475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.432100377 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.1100170847 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.141931398 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.348422047 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.336293329 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 19.8203875339 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.0635704076 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.481789615 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.6587755145 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.9047192767 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.434150916 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 98.6118267612 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.3870263522 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.4984970613 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 124.725262069 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.4226840242 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.9386519069 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.0163994394 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6010487555 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6694832195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9792429197 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3993757378 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 8.43202136712 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.2238391047 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8076032911 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.5994992893 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 127.541847033 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5847222647 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 134.093034493 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.452783171 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 96.8956975683 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.473723726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6633033268 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1805228578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3170528606 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 87.3117506214 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.4249426879 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.3151928 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.3273315491 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 57.9465257183 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 9.17006061109 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9397082903 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.4037409133 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4960487566 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.821032241 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.0789300851 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.5887470606 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.5183745445 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.1457290353 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.198155576 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8851040632 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.9729412124 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 103.321571897 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.8244812555 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.470211306 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.6836563715 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 96.089034389 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.1920644917 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.3074813556 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.5023482109 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.6618330325 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.769854153 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 103.092645522 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.0535023698 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.230911622 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2970535753 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.944271269 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 103.005986743 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.674022032 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 90.6065110977 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.1146731616 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4123867359 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.48140259 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.2172148831 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.9950894866 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.276141392 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2393542026 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9051081077 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.271629882 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.2362647123 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.5249266599 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3703551838 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5081177009 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5077269618 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.126471327 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.8157792708 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 13.8427642212 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9224112431 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.6295140431 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.7590470721 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8051740627 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.7971189661 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.0764380159 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9981990656 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2809513832 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3172006291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0280135508 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.9612314176 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2326756352 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5762034965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0342046412 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.3681967438 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1152379955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8342817901 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.4619690967 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.494225807 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6444844881 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.0402468673 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6759795292 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.7776796821 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.827025305 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.9758766354 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.4360336051 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.1978047179 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.3270228224 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.4879473871 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.183247274 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5848618064 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6273566447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8102731503 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 7.59183775307 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.5472392929 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1480382184 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.2610020446 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.637687513 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.550321511 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4742049155 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.7281264269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1782311374 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.206765688 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.590228909 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.738870116 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 19.0384089564 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1196935646 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.954982749 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1857979954 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.003316365 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4278752975 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.8183443981 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.6264778253 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4700620054 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9006418806 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.90164923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.081827577 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.4997063462 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5092918934 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.2045442652 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.3374051805 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.2333938469 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.3287472214 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.908253736 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 91.8590190887 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 98.0685502143 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.2764464753 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.155005035 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.937581217 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.9838481659 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.3593900506 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.294916415 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.6612909075 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 35.1555650741 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.2619639536 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.3607356784 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.4562086023 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 22.8225872475 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.9559512044 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 11.4572740984 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 7.9769831328 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5244212699 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4263667912 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.9357215994 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.8542686859 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.272045604 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 128.288110762 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.4164922554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.3528234714 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.2791727183 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 11.5468127819 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 32.4129308694 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0447421831 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.062908495 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 26.6457229338 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 39.9163252092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2919750352 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.5571999291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3489949002 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0764687633 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 47.310369081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7999359397 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1045403952 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 3.71032319122 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.4880886151 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.4825663773 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.3259500922 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.7036221346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9240957056 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4833391375 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2497766254 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 36.5664578888 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8795769867 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4075595793 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.6798768483 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 36.9050546966 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.36889854 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3883624346 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.5877182333 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.5338089479 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.17918528419 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.2931607626 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.0674659416 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.2179309786 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 17.0557546719 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.2800105545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.3296855404 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.3229416492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2425499839 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.4877998464 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 126.008160654 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.4615597497 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5379179402 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0480268321 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4933270024 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.741399774 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.9095448633 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9445110436 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1905344331 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3577688251 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.1587575484 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.7156337102 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.10812434 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.7371969547 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.3835422834 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.5276678488 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.8694857318 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.3383264267 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.228686488 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.736391031 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.2942139167 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.4715599436 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.9001602806 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3553153691 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5730147301 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.8039661964 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.576680082 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 36.2249314489 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 33.8456754547 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 38.2980454929 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.0056711864 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6261859035 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3778650157 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.2207949599 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.18546642386 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.791370696 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.4840048971 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.9622635098 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.6514462887 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.6156350269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.392413179 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4084171589 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.2962728727 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6710547301 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.8088001137 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 30.0723077474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5583004103 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 35.0456756201 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.3501179553 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.4352585043 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.7448205446 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.826439035 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.9410210845 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3923845224 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4526181681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3185432292 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.6372975083 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.213302566 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8872543561 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.3712938039 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5334524648 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2928612091 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9392479615 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7335686275 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.6651198095 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.5747617776 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.1586244529 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7826526508 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9720058048 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 36.7180909964 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.3192593781 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.0862714341 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.944503109 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.785289788 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.5904478914 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 124.514858335 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6808727042 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.4591815362 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.3571632118 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9852297355 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.09136148 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.545577472 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.0452862979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8266502864 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8057145913 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.7660788 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.0642174014 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.8992277177 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.56275651834 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8068716776 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.6204866091 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3242491656 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8079817914 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8850459073 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6000782933 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.4442666692 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3436679893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3806773468 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.979182268 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8967468002 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.721466585 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0299182718 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6408093919 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5911278039 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.1665700034 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.033995114 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.3737854612 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6528269323 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.17172289394 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.33942026651 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3886433482 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4732267323 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7214128402 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.8069674255 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.075307246 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.3897115187 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.1214695541 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.6249130261 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.026215595 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.290205378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2202089986 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.836569025 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.294370302 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.8001761155 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.5890322474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.0217936844 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.7752920957 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.86432467 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.1829475722 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.0800346263 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6799943875 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2658168938 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4811654015 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7144611335 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8768741312 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3151425749 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.66779929687 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.626034499 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4114227331 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.75890084533 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.7626412427 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5188095898 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.203367993 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.2032255983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.314280102 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.285941505 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6225301856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1670956762 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9567567784 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6266313344 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8260784234 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.2346100489 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.25743286535 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4146585112 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.489119344 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6775054273 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.9971196573 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.9830487856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8904346435 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.1878893169 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6363259368 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.7059723375 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0115992984 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.291800039 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9522945932 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.9623089853 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.0742350291 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.4032498397 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.6428433299 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.4595173463 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8976392236 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5218116986 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2828202197 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9912288655 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.4147170663 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.731178484 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0645938683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2786270709 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4268603818 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.305975472 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2195162567 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.867981199 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8904172722 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.6150599144 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.6001440621 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.50230174592 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8267319486 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.9440222991 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.3841993626 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.5210468561 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.416943501 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8500759138 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1966399281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4852478504 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4638133027 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 88.0910185416 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.153126126 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.2017516163 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.103436017 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.735019021 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.147275245 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.618613742 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.8504505448 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.856145747 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9177093089 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.5735738889 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.9630131294 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.918869146 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.554255986 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.955866419 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.1838273083 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.275183015 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2020229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.7220364188 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.695132242 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3064872425 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8902617932 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.739291313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8771672095 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.5961383819 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.1674427244 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.64062968 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.060256713 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.8427972693 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.6054743239 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0223695909 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.5492184068 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.1490166391 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9306545481 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9326315109 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.075538218 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.3876916498 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6557562955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9732935823 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.9072338312 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.4248086685 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3406409663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5884531523 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.358937347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4787417612 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.19499531004 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4877633986 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.207638738 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5873367187 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2642244168 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1635917022 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1758953242 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 101.867276117 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 26.1923613227 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4745404598 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.8972536118 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6614947786 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5128106728 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 133.90354554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.7653861987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9841375066 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1200736647 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.8936103599 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5139603628 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.3422756442 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1521444976 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 131.617140902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.896535271 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5451407346 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.5090074366 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.0849503678 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.0461479789 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.059551726 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0497051243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.3770123549 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.6321637243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.7931402964 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1191194876 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.9924749246 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6165587598 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2406007707 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 126.47907582 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.824742081 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.8866309599 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.686026926 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2815287365 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5767222676 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.054800174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7331143085 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.278278339 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2111896086 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4362170298 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1410534427 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3374299648 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.234870636 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.615460036 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1168780285 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6650766692 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.9412388027 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.7015082663 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.8311877643 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.37581064687 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.6373863534 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1333307899 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5941766451 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.2656280424 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.6619818894 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.6205767068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9583039015 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8584617596 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8991839468 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.8948262359 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3582584938 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.242383383 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.7824548789 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.799605663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5142217065 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.3411659025 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.150141754 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.271372512 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3555962244 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9077647054 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8074531241 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.045543915 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.6943024401 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.1925388319 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.2662872522 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.964270929 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.224895726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.1454503109 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.2756805617 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.032414539 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4105824574 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.0945824374 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7495095593 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Transformer 4647-1 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5244-1 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1682-2 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1673-3 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2303-3 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 700-4 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3939-4 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5046-4 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4413-5 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2779-6 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2780-7 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2466-8 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 470-9 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 11-10 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 11-10 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 30-11 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2929-11 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2181-12 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4017-12 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4019-12 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 115-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2337-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 116-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1225-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2874-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4955-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5230-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2874-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2906-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4124-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4455-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 249-16 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 337-16 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5834-17 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3727-18 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5094-19 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3727-20 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-21 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1598-21 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1843-22 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5023-22 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1157-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2703-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3425-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 144-24 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-24 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 490-25 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2093-25 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 612-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1866-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2602-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2922-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3339-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4632-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2922-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 536-27 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2350-27 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2684-28 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-28 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2887-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 144-30 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1553-30 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4841-30 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 150-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3162-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3692-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4741-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 150-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3729-32 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 366-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1017-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1158-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2580-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2704-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4746-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5671-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 368-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1109-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3135-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 367-36 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-36 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5229-37 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5515-37 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-38 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1229-39 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5809-39 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1229-39 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2251-40 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-40 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 430-41 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3953-41 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1484-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2765-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2724-43 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3488-44 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-44 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5097-45 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1085-46 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2194-46 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3305-46 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1085-47 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5363-48 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1223-49 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2345-49 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 470-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1676-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3553-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4629-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3553-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4629-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1196-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1197-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 166-52 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5489-52 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-53 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2769-54 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 373-55 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2693-56 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3427-56 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5098-57 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-58 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-58 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 142-59 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1652-59 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2476-60 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3525-60 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2228-61 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2634-61 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2048-62 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2950-62 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 371-63 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3081-63 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 145-64 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5108-64 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-65 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-65 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1546-66 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2292-66 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3249-66 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3030-67 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2883-68 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4537-68 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5151-68 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-69 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5099-70 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2165-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3145-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5100-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3145-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3746-72 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3746-73 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5108-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5128-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 145-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4964-75 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2084-75 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3082-76 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3832-76 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2344-77 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 240-78 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4562-78 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 630-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1871-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2410-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4077-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 630-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4076-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-81 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-80 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 680-82 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 803-82 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2073-82 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3485-83 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2129-84 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3802-84 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5103-85 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2809-86 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3511-86 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3771-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4346-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3771-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1617-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1706-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3642-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5559-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2496-89 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4226-89 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5104-90 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3727-91 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 653-92 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4056-92 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5729-92 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2137-93 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3768-94 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5844-94 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 283-95 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1174-95 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5705-95 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-96 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4176-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4445-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1252-98 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3517-98 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4652-98 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2633-99 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2634-99 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 552-100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1194-100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1195-100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1904-101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4449-101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1479-102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1964-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2487-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4281-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1964-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1670-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5494-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 263-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1559-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2095-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3539-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2208-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2272-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3262-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3000-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3000-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3979-108 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3978-108 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 633-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 677-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 765-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5203-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5207-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4740-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 481-110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5405-110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5509-110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 719-111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1168-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1656-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2296-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5314-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1169-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1655-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2296-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1654-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1033-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1076-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5264-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1033-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1076-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5263-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1076-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3521-114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3994-114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1244-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5409-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5531-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4964-118 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1001-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4557-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1001-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2703-120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5234-121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5461-121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5106-122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5106-123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5107-124 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1264-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4309-126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5738-126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 179-127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2746-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4259-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5296-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5742-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2746-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5295-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2989-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3413-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4575-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4576-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4576-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 788-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1148-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4042-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2195-132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2734-132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1709-133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1190-135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1716-134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1885-136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4815-136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 626-137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3048-137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-138 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5185-138 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3557-139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4751-139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 856-141 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 185-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1652-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2218-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2219-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3891-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5725-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3891-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1674-143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4133-143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1553-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1560-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3693-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5046-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5665-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1560-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 505-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 701-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 764-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1050-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2721-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3372-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1050-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2721-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3372-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4603-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4981-147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 480-148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4242-149 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1995-150 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4268-152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4520-151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4702-152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 156-151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3575-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5484-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5726-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5485-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-154 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5109-155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 689-157 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4745-158 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5810-157 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1727-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2764-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2839-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3692-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5073-161 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5073-160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4623-162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4669-162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2223-164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2223-163 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1410-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1590-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3618-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3785-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4179-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4496-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5143-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5193-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5410-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3449-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5854-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3704-168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5666-168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3704-168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5110-169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2570-170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5590-170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1563-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4621-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5801-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1563-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5678-172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5679-172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5113-173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 445-174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5369-174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1944-174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5153-175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5168-175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4719-176 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5122-176 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 180-177 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 180-178 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 916-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1493-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3467-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4937-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4942-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5674-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 917-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4940-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4941-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 994-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1051-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1124-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1269-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2107-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2966-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4386-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4947-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5038-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 994-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2966-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4944-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4943-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5114-181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4411-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5115-183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1036-184 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5388-185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5116-186 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5406-187 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2900-188 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2248-189 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5604-189 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5117-190 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2750-191 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4838-191 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 317-192 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5098-192 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4095-193 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2504-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2780-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5337-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3215-195 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3215-196 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 321-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 573-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 935-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 321-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 831-198 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1760-198 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5118-199 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2455-200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4560-200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1381-201 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1487-201 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 392-202 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1074-202 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 834-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1925-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2069-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2719-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2992-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 834-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1925-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1589-204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2720-204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5696-204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2721-205 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5066-205 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 392-206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5137-206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 563-207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 563-207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5587-208 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5852-208 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1797-211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4839-210 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1797-211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3874-212 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3874-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 525-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1182-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1738-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1885-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4071-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4915-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 352-215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1136-215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2892-215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4625-215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1990-216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5420-216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-217 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1582-217 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2769-218 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5121-219 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5119-220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 255-221 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2045-221 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4400-221 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1600-222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2314-223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4154-223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2314-223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5122-224 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3833-226 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3833-225 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1550-228 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1550-227 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 422-229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3141-229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4565-229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 422-229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2490-230 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 520-231 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1869-232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4887-232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3671-235 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 504-236 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1016-237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3945-237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2697-238 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5017-238 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2381-239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5447-239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5739-239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 360-240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4561-240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 697-241 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4453-241 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5498-241 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5692-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3155-243 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-243 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1928-244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2355-244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5124-245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 282-246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 479-246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 756-246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2451-246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4733-246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3579-247 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3167-248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2115-249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3568-249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1272-250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1627-250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2263-250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-251 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-252 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5116-252 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3517-253 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3517-253 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1118-254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3823-254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4642-254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 559-255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1687-255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4169-256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4558-256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4560-257 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1114-258 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 768-259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1460-259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4985-260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5805-260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5125-261 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1381-263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1629-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4849-263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5417-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1628-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2206-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1946-264 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-264 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5074-264 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-264 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5067-264 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 733-265 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 744-266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1278-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1377-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3528-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3881-266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1906-268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2680-268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 549-269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5288-269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2989-271 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2989-270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1414-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1701-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4450-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4842-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5255-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5802-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4450-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1326-273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2989-273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1944-274 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1944-274 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 278-275 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1057-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2458-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2458-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1061-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1060-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 745-277 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 986-277 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1059-277 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 746-277 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1058-277 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-278 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3704-278 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2987-279 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2468-280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4955-280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5085-280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2468-280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5722-283 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 448-284 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2670-284 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3645-284 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5127-285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5126-286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 965-287 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2323-288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2912-288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4634-288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5436-288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2626-289 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2796-290 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2172-291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2631-291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3155-291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5205-291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 292-293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 480-293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1569-293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1244-294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5128-295 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1304-296 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1756-297 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4323-298 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2166-299 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2167-300 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5129-301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 197-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4594-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5747-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 197-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4594-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4836-304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5411-304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 695-305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4689-305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3897-306 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2483-307 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4938-307 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1310-308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4582-308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1638-310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1638-309 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5623-311 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3152-312 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2642-313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5162-313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5161-313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 659-314 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3031-314 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1036-315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5131-315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2289-316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5288-316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5290-316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2289-316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3297-317 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3275-318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5132-319 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1258-320 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1657-320 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 835-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2311-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3127-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4571-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2311-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3127-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3127-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4150-322 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4151-322 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1936-323 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1936-323 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2312-324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1682-324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 522-325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 521-325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1845-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2610-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2925-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4117-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5377-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4117-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1796-327 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3086-327 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1795-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1795-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2272-329 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2272-329 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4397-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4656-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4749-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4672-331 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-331 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-331 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3684-332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1011-333 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1615-333 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2549-333 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4768-333 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5267-334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1138-335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2824-336 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4928-336 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2504-337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2646-337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1700-338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1864-338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3297-339 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3501-339 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5804-339 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3063-340 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3385-341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3238-342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3888-342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5408-342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5134-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1865-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4526-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5300-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 676-345 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1731-345 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1283-346 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5457-346 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-347 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 444-348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3382-348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3318-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3372-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3774-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3907-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4835-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3319-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3372-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3774-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3907-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4603-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4835-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3320-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3317-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4027-351 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 558-352 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 885-353 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2695-353 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5849-353 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5136-354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1359-355 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 358-356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1355-357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3151-357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3878-357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2300-358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3030-358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5139-358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5618-358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4023-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4561-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4929-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5157-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2447-361 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2448-362 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 490-363 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5113-363 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5112-363 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4741-365 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2139-366 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 864-369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 865-370 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3011-371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3081-371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2176-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2762-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2175-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-373 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3551-374 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-374 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1174-375 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1780-375 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2582-375 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2100-376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2104-376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2104-376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 652-377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2329-377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2773-377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 401-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1257-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1537-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1909-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4092-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4901-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5020-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4901-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5020-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 469-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3101-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3942-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4093-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5002-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5159-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1938-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2075-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2771-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3943-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2074-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2771-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4292-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4012-381 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5280-381 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2430-382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3697-382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5425-382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 942-383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3799-383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 942-383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3799-383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2441-384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5233-384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5761-384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2930-385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5778-385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3031-386 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1596-387 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2944-387 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2712-388 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3538-388 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1405-389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1882-389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3854-389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4689-389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1404-389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4598-390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5730-390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1725-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1823-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2330-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2471-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3940-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5608-392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1913-393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 395-394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1792-395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4567-395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1792-395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3871-396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4088-396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2399-397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5196-398 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 854-399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2243-400 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-400 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2306-402 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2814-402 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2774-403 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5174-403 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2298-404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3293-404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1084-405 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1025-406 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1867-406 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-406 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2362-407 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2457-407 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2818-408 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3927-409 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 487-410 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1063-410 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1870-411 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3197-411 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1637-412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2048-412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3240-412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4080-412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1146-413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1146-413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4193-414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5144-414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3672-415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4446-415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 545-416 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 862-417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4128-417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3741-418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4314-419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5147-419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5145-419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5145-420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-421 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1483-422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1483-422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 855-423 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2781-423 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1567-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3411-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4021-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4533-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1567-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4021-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4021-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2762-425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5708-425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5146-426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1156-427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-428 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3873-429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5211-429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3873-429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1666-429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1052-430 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1270-430 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3297-431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3207-432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 884-433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1450-434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5476-434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 987-435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2846-435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3063-435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5274-435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3063-435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3987-436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5704-436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2551-437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2984-438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1673-439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2219-439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5011-439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5150-440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5148-441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2758-442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4216-442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1558-443 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1651-445 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2032-443 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4875-445 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5339-443 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1651-445 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2032-444 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4875-445 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4849-446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5152-446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3594-447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1234-448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2907-448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3983-448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2907-448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1344-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1435-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4804-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5605-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 500-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4804-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 499-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2246-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2763-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4913-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2246-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 501-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5156-451 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 462-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2339-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2699-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3713-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2339-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3440-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3546-453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3665-453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5157-454 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4066-456 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4066-455 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4245-457 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3000-458 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3620-458 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4678-459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4678-459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3174-460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4021-461 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5483-462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5158-463 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2712-465 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5160-466 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2185-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3481-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3561-468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2185-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3480-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3561-468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2185-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2987-470 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 977-471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3345-471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3744-471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2721-473 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2721-472 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4297-474 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4298-474 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2174-475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3875-475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5576-476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3763-477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3763-477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4045-478 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 647-479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1835-479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3578-479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 976-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1568-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2148-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2168-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3156-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1569-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2169-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2170-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-481 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2014-482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2509-483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5443-483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5599-483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5604-483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 965-484 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4174-484 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3545-485 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5161-486 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1030-487 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1063-487 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 658-488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3639-488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2263-489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2618-489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2203-490 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5163-491 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3571-492 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5086-492 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 594-493 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 595-494 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 595-495 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 595-496 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 595-497 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2158-498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2457-502 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2562-502 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5201-502 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3979-503 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3978-503 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 741-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1817-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5123-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5363-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2667-506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4342-506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5164-507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5165-507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3982-508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1564-509 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5230-509 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5620-510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5621-510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3000-511 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3093-512 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2578-513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2968-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3153-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3236-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2969-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3154-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3237-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1082-515 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2587-515 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1195-516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5456-517 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2267-518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3213-518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 565-519 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4198-520 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4310-520 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1407-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2890-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2926-522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3673-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3838-522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4266-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5658-522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2926-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1346-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1408-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2880-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2891-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4466-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5442-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1346-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 959-524 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2917-524 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1132-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1922-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2957-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3036-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3316-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4248-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4693-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4769-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5556-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5700-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4692-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1283-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1446-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4705-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1283-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3537-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4705-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 529-528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1355-528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1843-528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1085-530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 532-531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1397-531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1397-531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3880-534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3880-533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 668-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1356-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2879-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3459-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5682-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5683-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 668-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3459-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5539-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3259-536 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-536 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-536 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 651-537 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1321-537 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1357-537 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1194-538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5386-538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1135-539 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2101-540 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1346-542 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1346-543 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2091-544 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2683-544 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2986-544 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5776-544 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2892-545 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5678-545 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1685-546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5169-546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5578-547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5599-547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2598-548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5133-548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3071-549 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3200-550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1543-551 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2734-551 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3569-551 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5198-551 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1543-551 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1193-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1556-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3394-553 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5707-553 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4346-554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4899-554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4346-554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-556 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-555 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1794-557 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3906-558 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1138-559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3073-559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3642-559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4375-559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5409-560 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1133-562 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2468-562 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2658-563 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4800-563 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1446-564 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3088-564 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 857-565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2981-565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 857-565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1015-566 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4235-566 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2446-567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5806-567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4536-568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2311-569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5031-569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 585-570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4217-570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1073-571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3324-571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1904-572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4871-572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1185-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3890-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3114-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5703-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1576-575 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2045-575 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1826-576 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 659-577 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5172-578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1212-580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1726-581 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3253-581 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3648-581 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-581 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 580-579 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3529-582 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5037-583 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3040-584 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1461-585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1157-586 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4986-586 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5278-586 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2430-587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2494-587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5174-588 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5341-589 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5693-589 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2167-590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1524-590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2167-590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5175-591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3207-592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2643-593 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3516-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1334-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3515-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1334-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1334-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5791-596 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3517-597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-598 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-599 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1853-600 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5731-600 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2686-601 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5353-601 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 742-602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1889-602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2061-602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3853-602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1889-602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3364-603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 608-606 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 608-605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 608-604 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2379-607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3944-607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4326-607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2784-608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3603-608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5266-608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 885-609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4367-609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5509-611 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3339-612 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2190-613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5376-613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3089-614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2265-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2013-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3601-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5319-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5332-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5787-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1007-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2771-617 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-617 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5178-619 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5182-618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5037-620 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5037-621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5041-623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5246-623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5836-623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2704-624 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 823-625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1108-625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2594-625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5185-628 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5192-629 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5183-632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5186-631 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4231-633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5184-634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4282-635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2461-636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2541-636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5597-636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2792-637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4570-637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5706-637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1111-638 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3981-638 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5160-639 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5065-640 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-645 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-644 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-643 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-642 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-641 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-646 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1001-648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1357-651 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4282-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1741-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4458-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1741-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4931-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5789-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1786-654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5189-654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3181-655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3577-655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5227-655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5190-656 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5191-657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2006-658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2752-658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2861-658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4372-658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5162-658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5433-658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1078-658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2191-658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5161-658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3400-659 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2173-660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3763-660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4118-661 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1211-662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1211-662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2744-663 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3815-663 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1625-664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1434-665 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5248-665 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5642-666 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-667 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4468-672 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-671 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4468-670 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-669 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2530-673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2555-673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2766-673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2230-673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3671-674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2769-675 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4851-675 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5819-675 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4851-675 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1508-676 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2025-676 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5414-676 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1392-677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3849-677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4916-677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3380-678 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3063-679 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1756-680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1674-681 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2713-681 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2822-682 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5399-682 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5194-683 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4938-684 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2681-685 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3561-686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3561-686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3561-686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1319-687 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5195-687 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3902-688 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2001-689 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5416-689 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1938-690 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4206-691 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1938-692 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2348-693 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2349-694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5488-695 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4586-696 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 891-697 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2814-697 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2336-699 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2336-698 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 741-700 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4031-700 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5581-700 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4686-700 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5209-706 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3896-708 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4317-707 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5196-708 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5722-708 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4317-707 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5265-709 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4029-710 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5416-710 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5839-710 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-710 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5721-711 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2616-716 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2731-716 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2912-715 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-715 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5436-715 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-715 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1723-717 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2056-717 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4142-717 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5401-717 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5197-718 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5232-719 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 962-721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5007-721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1186-721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3037-721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1930-722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 721-723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3567-724 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5815-724 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5348-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5532-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4329-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 966-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4284-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4738-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5198-727 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5634-727 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1392-728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1904-728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5677-728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2847-729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4279-729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4278-729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2182-731 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2453-731 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2723-730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4138-730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4146-730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5508-730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5580-730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2182-731 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4138-730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4591-730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 858-732 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2465-732 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2655-732 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4119-732 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5697-732 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2466-732 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2466-732 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-734 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-733 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 928-736 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 928-736 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-737 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5199-738 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5200-739 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2162-740 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4832-743 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1562-744 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4047-744 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2533-747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3660-747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4777-747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5474-747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1674-748 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2713-748 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 750-749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5043-749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3667-750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3617-751 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3429-752 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 487-753 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2012-754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2043-754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5054-754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1220-755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4092-755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1477-757 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3441-757 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4689-758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2550-759 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4744-759 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2550-759 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4744-759 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 459-760 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 459-760 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2746-761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2957-761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4387-761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5700-761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3633-762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3881-762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 764-763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4165-764 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5203-766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1847-769 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1557-770 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-770 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3809-771 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4032-771 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 340-772 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5121-772 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 666-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1302-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2221-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2317-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3060-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4115-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4548-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5412-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5624-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1302-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3060-773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1535-774 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3738-774 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3792-774 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3791-774 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5759-774 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1758-778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1878-778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3717-778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4852-778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5647-778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1878-778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5649-778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2302-779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 923-780 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4832-780 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 904-781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2726-781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3765-781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 905-781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5204-782 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 953-785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 953-784 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 953-783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5206-786 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1761-787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2516-787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1690-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5208-790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1129-794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3424-793 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3463-794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4327-793 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4542-794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4779-793 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5808-794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5829-794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4542-793 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 705-795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 810-795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 926-795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1984-795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4780-795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5235-795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5275-795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1905-795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5209-795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 959-796 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1219-796 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2629-797 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2349-798 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4623-798 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4905-799 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4843-800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4905-800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 480-801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 927-801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 823-802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3124-802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4403-802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1223-803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1989-804 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3494-804 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4407-804 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1989-804 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 944-805 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1963-805 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5209-809 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1766-812 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-812 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1480-814 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1480-813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1613-815 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-815 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 850-816 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5614-816 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5609-816 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3751-817 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4936-818 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4925-819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5296-821 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5295-820 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1565-822 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3735-822 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2442-823 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 825-824 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4325-824 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1072-825 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5535-825 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1690-826 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5212-827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4832-828 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2134-829 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4248-830 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2012-831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-832 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1200-833 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2786-833 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2719-834 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3094-836 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4045-836 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4679-837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5215-838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1678-839 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4639-839 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2236-840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3027-840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3380-840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3452-841 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3657-841 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4778-841 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2958-843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5406-842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5545-842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5214-844 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2953-845 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4124-845 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4832-846 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5210-847 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1883-848 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1883-848 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1552-849 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5044-849 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2999-851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2999-853 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2999-852 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1924-854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3797-854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3956-854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5547-854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5268-854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5548-854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2781-855 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-855 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3165-855 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3165-855 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4028-856 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4028-856 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3671-858 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2590-859 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-859 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1142-860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5690-861 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2718-862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3111-862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5757-862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2971-863 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4911-863 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3217-865 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3342-865 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2379-866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3450-866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3904-866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4326-866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4105-868 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4105-867 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5222-870 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5219-869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4217-871 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1159-872 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5392-873 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1613-874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2254-874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4494-874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2489-876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2489-875 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-877 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4651-877 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4598-878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5260-878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4598-878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2667-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4342-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2254-881 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2254-880 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5223-882 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5220-883 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3393-884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3732-884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4762-884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5051-884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5670-885 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5773-885 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4783-884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2044-886 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2985-887 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3612-886 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4601-886 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5828-887 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4601-887 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2210-888 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5297-888 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5449-889 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5226-890 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3307-891 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4680-891 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5557-891 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2186-893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3006-892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4126-892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1312-895 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2040-896 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5224-896 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2538-897 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3380-898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4152-898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4783-899 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4913-900 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4913-901 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-902 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-903 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5081-906 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5851-906 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4721-907 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3939-908 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4164-908 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3380-909 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4152-909 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3574-910 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-910 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5802-911 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5230-912 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3647-913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5803-913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2485-914 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4441-914 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1754-915 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5233-918 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2315-920 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2448-919 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2448-919 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2448-920 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2782-921 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-921 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2782-921 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-921 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5234-922 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4832-923 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1803-924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5672-924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5170-925 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5753-925 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5562-927 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2561-928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2561-928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3154-929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3368-929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2398-930 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3839-930 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2706-931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5324-931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2173-932 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1792-933 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1792-933 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4120-934 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5818-935 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3485-936 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3556-936 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5424-937 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5473-936 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5475-936 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5422-937 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5365-938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5366-938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-939 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-939 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-940 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4603-940 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2812-941 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5675-941 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2118-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2551-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3211-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3548-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5479-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5644-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2551-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4889-943 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4889-943 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2559-945 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1533-946 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1533-946 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3338-948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3916-948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2462-947 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3916-947 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3307-949 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2708-950 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-950 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5502-950 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2214-951 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2812-951 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2597-952 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3432-952 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1045-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1103-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2361-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3072-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1047-954 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1199-954 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2661-955 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5235-955 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1374-957 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2301-958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2316-958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2913-958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4411-958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4638-958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4874-958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4411-958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1219-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2917-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2917-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4468-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4468-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5241-961 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2949-962 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1184-963 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5703-963 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2948-964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3916-964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4439-964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2740-965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3460-965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3769-965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4050-965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5311-965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2741-965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3768-965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1463-966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1463-966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1463-966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-968 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 973-969 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2949-969 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1746-971 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4133-971 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3315-972 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5786-972 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2263-973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2604-973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4097-973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1852-973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4812-973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1248-974 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2088-974 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2088-974 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2773-975 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3051-977 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3345-977 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5242-978 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2960-979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3365-979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5718-979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3365-979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5362-979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3365-979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2458-980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4971-980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2458-980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2245-981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2649-981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2773-981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3809-981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4032-981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4282-981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4729-981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4282-981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3810-982 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1115-983 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4524-983 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5553-983 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5783-983 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5008-983 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2482-984 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2822-984 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2171-985 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3838-985 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1384-987 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2716-987 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1206-988 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4422-989 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3469-991 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2306-992 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2297-993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3740-993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4797-993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4796-993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1124-995 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1187-994 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4917-995 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4947-995 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3559-996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3775-996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2073-997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5238-998 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1090-999 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-999 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1043-1001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1083-1001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1256-1001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5279-1001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4765-1002 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2075-1003 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-1003 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-1003 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1586-1003 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2074-1003 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4468-1003 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-1004 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5713-1004 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4638-1005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2128-1006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2905-1006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5319-1008 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1730-1009 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5355-1009 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5481-1010 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3928-1011 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4451-1011 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5685-1013 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5684-1012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5243-1014 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2214-1015 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2863-1015 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2863-1015 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1253-1016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3458-1016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5239-1016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5358-1016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1253-1016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1961-1017 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5239-1018 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4791-1019 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1756-1020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4147-1020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2277-1021 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4289-1021 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 973-1022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2627-1022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 973-1022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 973-1022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1358-1024 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1358-1023 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5392-1025 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5244-1026 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3344-1028 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3344-1027 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4513-1029 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2159-1030 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2809-1030 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-1032 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-1031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4095-1033 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1359-1034 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-1035 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-1036 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-1035 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4900-1037 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2160-1038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3052-1038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4366-1038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2160-1038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3053-1038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4365-1038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3782-1038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3782-1038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1387-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3176-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3351-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3917-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5013-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5014-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1387-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3783-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3055-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3054-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1044-1040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-1040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3784-1041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-1042 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4954-1041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5245-1042 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1044-1042 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-1040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2968-1041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3154-1041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-1041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-1041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1105-1046 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2278-1046 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3303-1046 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4401-1046 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4414-1046 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5175-1046 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5690-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1102-1046 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5691-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1104-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2667-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1199-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2864-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3756-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4886-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5321-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5448-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1229-1048 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1229-1048 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3134-1049 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4981-1049 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1946-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2467-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5066-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1946-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2467-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5067-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1188-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1270-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3168-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3948-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5038-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1269-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3947-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5513-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5246-1053 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-1054 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2411-1055 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4424-1055 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-1056 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4395-1062 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2214-1063 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2812-1063 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5190-1063 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5381-1063 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-1064 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2810-1064 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3756-1064 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5056-1064 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-1064 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4997-1065 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2590-1066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2590-1067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2004-1068 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2267-1068 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4934-1068 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5367-1068 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2831-1069 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2831-1069 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5034-1070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5249-1070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2036-1071 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2665-1071 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5554-1071 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2406-1072 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3003-1073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5717-1074 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2220-1075 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3951-1075 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2571-1076 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2701-1076 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2571-1076 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-1077 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-1077 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-1077 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-1077 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-1077 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2250-1078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2752-1078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2836-1078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5602-1078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5603-1078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5833-1078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3031-1079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-1081 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-1080 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5313-1082 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1953-1084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2344-1084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2298-1085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-1085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5553-1085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5720-1085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1787-1086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2299-1086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1669-1087 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4984-1088 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4984-1088 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1940-1089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5681-1089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1939-1089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2742-1090 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2511-1091 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4356-1091 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1206-1092 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4288-1092 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2144-1093 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2725-1093 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2144-1093 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1472-1094 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1471-1095 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1487-1097 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1487-1096 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4258-1098 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1767-1099 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2675-1099 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2298-1100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2298-1100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3522-1101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3522-1101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4554-1103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5251-1106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5577-1107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5578-1107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2423-1108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2594-1108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2423-1108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3581-1109 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2746-1110 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2322-1111 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3193-1111 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5254-1112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-1114 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4506-1114 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5083-1114 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3293-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3577-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5044-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5227-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5228-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5846-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3577-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3599-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3599-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1541-1117 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2126-1117 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1958-1118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2566-1119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1772-1121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2502-1120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4440-1120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-1121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2502-1120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3547-1122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5255-1122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1501-1123 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1919-1123 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2083-1123 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1545-1125 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4964-1125 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4964-1125 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2566-1126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2566-1127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5257-1128 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1307-1129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2321-1130 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1130 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1384-1131 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3392-1131 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4687-1133 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5259-1134 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1229-1135 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2715-1135 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5504-1135 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1230-1136 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5101-1136 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2457-1137 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5650-1137 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3073-1138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3748-1138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5258-1138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3100-1138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2265-1139 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4906-1139 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1359-1140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3245-1140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1359-1140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2802-1142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2984-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5111-1142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5251-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5486-1142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2465-1143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2985-1143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5002-1144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5260-1145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2383-1146 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2842-1146 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5225-1146 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5446-1146 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5449-1146 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5267-1146 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-1147 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4182-1147 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3712-1148 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5262-1149 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-1151 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2937-1151 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3336-1151 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2586-1152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-1152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1815-1153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3559-1153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3617-1154 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3809-1155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2138-1156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3021-1157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3465-1157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3506-1157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5551-1156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5630-1156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5668-1156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2139-1158 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2704-1158 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3362-1159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-1159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5770-1159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5261-1160 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2454-1161 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3006-1161 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5264-1162 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5263-1163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-1164 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-1165 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-1166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1565-1167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3905-1167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4663-1167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3905-1167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4566-1168 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5117-1170 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2578-1171 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4984-1172 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5595-1172 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1487-1173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1945-1173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2828-1174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3090-1174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3637-1174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4199-1174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4223-1174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4685-1174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5622-1174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3090-1174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4222-1174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5705-1174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-1175 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4224-1175 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5265-1175 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-1175 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-1175 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3363-1180 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3607-1181 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4052-1181 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5699-1181 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3540-1181 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5022-1182 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1192-1183 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2650-1185 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5844-1184 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3227-1186 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1707-1187 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3914-1189 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5404-1189 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3163-1190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-1190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5424-1190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3163-1190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-1190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5422-1190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3163-1190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5365-1190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5366-1190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1964-1191 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4620-1191 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-1192 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2162-1192 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4158-1192 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4081-1194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4318-1195 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5750-1194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4081-1193 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3523-1197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5287-1196 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1961-1197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1963-1198 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3135-1198 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2105-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3546-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3665-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4343-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5638-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1176-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3546-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5448-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1177-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1178-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-1200 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2607-1200 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-1200 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2606-1200 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2785-1200 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1179-1200 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3388-1201 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4003-1201 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5583-1201 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4659-1202 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5440-1202 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5439-1202 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1207-1203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2966-1203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4177-1205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4983-1205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5092-1204 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5166-1204 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2724-1206 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3957-1206 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3958-1206 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4420-1206 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4421-1206 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2939-1207 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3886-1208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5007-1208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1988-1208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3391-1208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1248-1209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-1209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5270-1210 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2254-1211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-1211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4136-1211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2254-1211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5727-1211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1639-1212 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1918-1212 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3179-1212 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1918-1212 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3179-1212 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4609-1213 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5029-1214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5718-1214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5272-1215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3038-1216 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4457-1216 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3709-1217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4358-1217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2660-1218 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2888-1218 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1300-1219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-1219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-1219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-1219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1297-1219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-1219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-1219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1299-1219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-1219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1298-1219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1991-1221 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1811-1222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2751-1222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-1223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3858-1223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3428-1224 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5085-1225 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5269-1226 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5275-1227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-1228 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5413-1229 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-1231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3053-1232 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4439-1232 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3496-1233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4438-1233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1343-1234 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1653-1234 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2429-1234 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2494-1234 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-1235 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4453-1235 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1778-1237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3045-1237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1778-1237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3604-1239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4280-1239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5242-1238 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5748-1238 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5651-1238 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3604-1239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-1242 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2087-1241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2937-1242 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3336-1240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3966-1241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4083-1241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4137-1242 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4528-1242 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5699-1242 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-1241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3540-1241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4083-1240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4831-1243 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4831-1243 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5552-1244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1828-1245 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1961-1245 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3312-1245 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1616-1246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1856-1246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1617-1246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1855-1246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2873-1247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3823-1247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5179-1247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3573-1248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4574-1248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5497-1248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4289-1249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4328-1249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4289-1249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2264-1250 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4568-1253 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4626-1253 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5118-1254 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5631-1254 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5279-1255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1657-1258 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2095-1259 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2524-1259 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5073-1259 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5073-1259 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4206-1260 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5495-1260 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2339-1261 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5281-1262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2257-1264 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4716-1264 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-1263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5549-1263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5777-1264 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4716-1263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-1264 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1844-1265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3898-1265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5134-1265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5512-1265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5660-1265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3153-1266 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3811-1266 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-1266 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4092-1267 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1512-1268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2660-1268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2009-1270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3952-1270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4648-1269 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5280-1271 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2263-1272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4216-1273 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5221-1273 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5283-1274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1963-1275 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-1275 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4468-1275 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1963-1276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-1276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-1276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1547-1277 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-1277 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1775-1279 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4586-1278 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5284-1280 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3630-1281 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3979-1281 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-1284 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2272-1285 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2712-1285 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2273-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3638-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3921-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5073-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2273-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3638-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3920-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-1287 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2049-1288 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3763-1288 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1633-1289 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5180-1289 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5791-1289 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5146-1290 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5812-1291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2012-1292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2013-1293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5217-1294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5218-1294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2307-1295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3944-1295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3944-1295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2661-1296 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3449-1301 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2033-1302 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4644-1302 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5843-1303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1305-1304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4905-1304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5287-1306 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2119-1307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2641-1309 connects the same voltage levels (20.0, 20.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5824-1310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5150-1311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5389-1311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1350-1312 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1615-1312 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3910-1312 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3347-1313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3709-1313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4846-1313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5290-1314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-1315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3936-1315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5289-1316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2619-1317 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5289-1317 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5291-1317 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1318-1319 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1987-1319 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2605-1320 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5631-1320 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2605-1320 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2941-1321 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2137-1323 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2137-1322 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3431-1324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-1325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4409-1325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5589-1325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5441-1326 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-1327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5652-1327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4045-1328 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3258-1329 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3526-1329 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2101-1330 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5243-1330 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4428-1331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1667-1332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4271-1332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5746-1332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2078-1333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3031-1333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3064-1333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4722-1333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1542-1334 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3433-1334 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4028-1334 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1542-1334 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-1334 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4028-1334 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5105-1335 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5356-1336 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5832-1336 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2136-1337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5008-1337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-1338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5174-1338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4889-1339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2087-1340 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5163-1340 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2088-1342 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1846-1343 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1847-1343 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1757-1345 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5282-1345 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4196-1346 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-1347 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2362-1353 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2362-1352 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1598-1354 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3878-1355 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1364-1356 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2359-1356 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1390-1357 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1951-1357 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2623-1357 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2691-1357 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2692-1357 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2697-1357 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1389-1357 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1463-1358 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5336-1358 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5138-1359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3759-1360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3810-1360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-1361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-1362 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4475-1363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5360-1364 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3833-1366 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3833-1365 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2457-1367 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5770-1368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1708-1371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1714-1370 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1715-1369 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1799-1372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1383-1373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3257-1373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5294-1373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5296-1373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5295-1373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5311-1375 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2079-1374 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4004-1376 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-1377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1776-1378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2539-1379 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5297-1380 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4849-1381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2347-1382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3706-1382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3916-1382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5238-1382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4450-1385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5277-1385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1665-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2052-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3275-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4002-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5521-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5760-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2537-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4001-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4950-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5520-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3438-1388 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4095-1388 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3412-1390 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2609-1389 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2753-1391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2660-1393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3049-1393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3394-1394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5530-1394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2148-1395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3865-1395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5142-1395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5298-1395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3193-1396 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-1397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4976-1397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4978-1398 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5299-1399 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5256-1400 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2566-1400 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5300-1401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2344-1402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4328-1403 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5595-1403 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5301-1406 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1953-1407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3701-1407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3864-1407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3864-1407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-1410 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1814-1410 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4336-1410 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5101-1411 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5666-1411 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2870-1412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3173-1412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5572-1413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5803-1414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5302-1415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2238-1416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4147-1416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5797-1416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-1417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5768-1417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2483-1418 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2872-1418 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4630-1418 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1823-1419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1823-1419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2608-1421 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3235-1420 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2609-1421 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3234-1421 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3674-1422 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3674-1422 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3878-1424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3878-1423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3606-1425 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2009-1426 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3887-1427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5305-1427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5306-1427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5308-1428 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 979-1429 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5029-1429 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5097-1429 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5362-1429 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4003-1430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5320-1430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4050-1431 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4522-1431 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1435-1432 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2550-1433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3000-1433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1065-1434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4539-1434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5035-1434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1065-1434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2432-1435 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4998-1435 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 930-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1246-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1616-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1774-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2538-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1781-1437 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5310-1438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1684-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4225-1440 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2493-1441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2735-1441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4205-1441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4698-1441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5284-1441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2493-1441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2735-1441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2493-1441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-1442 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5497-1442 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4906-1442 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2960-1443 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5798-1443 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1268-1445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1324-1445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3049-1444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3070-1445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4585-1445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4769-1444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5673-1445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5793-1444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2661-1446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4705-1446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2661-1446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-1447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-1447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5311-1448 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3984-1450 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1002-1451 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4765-1451 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 973-1452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4803-1454 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4803-1453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2684-1455 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5284-1455 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3461-1456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5312-1457 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-1458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4329-1461 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3265-1462 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4646-1462 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4662-1462 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5017-1462 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5116-1462 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4645-1462 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5247-1462 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2145-1463 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2146-1463 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5336-1463 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-1464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-1464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5089-1464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-1464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-1464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-1464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1622-1465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2747-1465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3527-1465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5333-1465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-1465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4887-1466 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3202-1467 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4889-1467 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2533-1468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5022-1469 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5749-1469 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3559-1470 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3559-1470 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1709-1471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3561-1472 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1709-1471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3035-1473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4357-1473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5044-1473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3035-1473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4722-1474 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4868-1474 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2144-1475 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5279-1476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4945-1477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3630-1478 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1890-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2008-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2700-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2943-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2942-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5533-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1755-1480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2047-1480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3743-1480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3767-1480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1755-1480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3767-1480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2516-1481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2516-1481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2552-1483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4176-1483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4277-1483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4445-1483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5114-1483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5273-1483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5694-1483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5268-1483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3549-1484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4581-1484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3366-1484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4739-1485 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4739-1485 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2134-1486 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-1487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-1488 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4246-1489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5315-1489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2805-1490 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1673-1491 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5725-1491 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1717-1492 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-1494 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3015-1495 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4966-1495 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2605-1500 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2624-1502 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4000-1502 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2280-1503 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-1503 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4061-1503 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4717-1503 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5069-1503 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4061-1503 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2762-1504 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2282-1505 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4694-1505 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4708-1505 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5316-1506 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4832-1507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3371-1508 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5676-1508 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3076-1509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3041-1510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3251-1510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2421-1511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5099-1511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4210-1513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4210-1513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-1514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3644-1514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3736-1515 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3893-1515 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4540-1515 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3429-1516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3736-1516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3736-1516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5813-1517 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2360-1518 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2602-1518 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4044-1518 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5529-1518 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5714-1518 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4044-1518 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3259-1519 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2352-1520 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3416-1520 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2351-1520 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-1521 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-1521 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1634-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2414-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3435-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4125-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5188-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2414-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3738-1527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4684-1527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2327-1528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4920-1528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4919-1528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4428-1529 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5317-1530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1838-1531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1781-1532 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2573-1532 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1549-1533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1566-1533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4873-1534 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4938-1533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5723-1533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4113-1533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5448-1535 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5759-1535 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2470-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2607-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2947-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3624-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2470-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2606-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1851-1537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5020-1537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5368-1537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5853-1537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2930-1538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5842-1538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2104-1539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3080-1539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3545-1539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5187-1539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5368-1540 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4868-1541 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2017-1542 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2518-1542 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2018-1542 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-1542 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1933-1543 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3606-1543 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3977-1543 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5634-1543 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3606-1543 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1737-1544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5319-1544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3527-1547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2153-1548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2633-1548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2153-1548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2633-1548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4181-1550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5741-1550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4181-1550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5320-1551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1837-1553 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5321-1554 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-1555 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4265-1555 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2745-1556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-1557 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2520-1559 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4849-1559 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2519-1559 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4676-1561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1849-1563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5501-1563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1819-1563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1850-1563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1834-1564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-1564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3377-1564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-1564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-1564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1782-1565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4663-1565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4663-1565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2014-1567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4376-1570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4861-1570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5200-1570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5270-1571 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5322-1572 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4434-1573 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4689-1573 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5323-1574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3751-1575 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3874-1575 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3073-1576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4335-1576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4454-1576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5325-1576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3950-1577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5149-1577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5698-1577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2984-1577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-1578 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-1579 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-1580 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-1581 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-1582 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2550-1583 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2550-1583 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3335-1584 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5326-1584 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-1585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3856-1585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4149-1585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-1585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-1586 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4231-1587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5000-1587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3277-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3289-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4000-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5058-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5593-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3277-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3598-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5058-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2720-1589 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4165-1589 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2620-1590 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5705-1591 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5327-1592 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3787-1593 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-1593 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4697-1593 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5758-1594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4541-1595 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5329-1595 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4756-1596 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5345-1596 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1612-1597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-1597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2357-1599 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4983-1598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5404-1599 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4370-1599 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4982-1598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2770-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2815-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3016-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3074-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3259-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4304-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4738-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2771-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3433-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2614-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3062-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3426-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2614-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3061-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2892-1603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4040-1603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4209-1604 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4866-1604 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5088-1603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4040-1603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5330-1605 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5331-1606 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3048-1607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4526-1607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5332-1608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4346-1609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4346-1609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2628-1610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-1610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5156-1610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2096-1611 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2308-1611 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-1612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-1612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4676-1613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2121-1614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3512-1617 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4016-1616 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5568-1616 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5771-1616 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2293-1618 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5002-1618 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3371-1619 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5676-1619 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1947-1620 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2691-1621 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5499-1621 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5104-1623 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5744-1623 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3961-1624 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5440-1625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5439-1625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5645-1626 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2263-1627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5334-1630 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3630-1631 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2010-1632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5399-1633 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3429-1634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2209-1635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5419-1635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1857-1636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5119-1636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2048-1637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2531-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3028-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3582-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4127-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4519-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2531-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4127-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4519-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3179-1639 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4136-1640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4361-1640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1808-1641 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4757-1641 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3134-1642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5335-1643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2545-1644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2971-1644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4757-1644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5336-1645 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1725-1646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3409-1646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-1646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1943-1647 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1943-1647 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5337-1648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2863-1650 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5338-1649 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1879-1651 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5463-1653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5339-1657 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5340-1658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2645-1659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2802-1660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1718-1661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2806-1661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4782-1661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2128-1662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3608-1662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1792-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1792-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2427-1664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4861-1664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5060-1664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3275-1665 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5342-1666 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5028-1667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1945-1668 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2007-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3026-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3718-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3739-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4232-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5052-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5763-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3025-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5766-1670 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2042-1671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4730-1671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5343-1672 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3405-1673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4087-1673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5011-1673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3405-1673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5428-1674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1869-1675 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3152-1675 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3553-1677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4639-1678 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5308-1678 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5503-1678 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5749-1678 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1680-1679 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4521-1679 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2483-1680 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2514-1681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4627-1681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3941-1682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5534-1682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5662-1682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5465-1683 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3048-1684 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3656-1686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4520-1686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5335-1688 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5608-1689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5606-1689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1639-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1726-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2825-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3323-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3712-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3751-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3323-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5212-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5348-1691 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3714-1692 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5349-1693 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2457-1694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2457-1694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2457-1694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4219-1696 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4219-1695 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4216-1697 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4218-1699 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4218-1698 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5337-1700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4531-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5736-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5734-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4352-1703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-1704 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-1705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5303-1705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5304-1705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5350-1705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5461-1705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1715-1709 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2732-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3216-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3933-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4073-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1714-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3216-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3933-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3216-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3216-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1716-1711 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1716-1713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1716-1710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1716-1712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3217-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4643-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3217-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3612-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5352-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5351-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2236-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2253-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3130-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4618-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2253-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2135-1718 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5352-1720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5351-1719 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2238-1721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3867-1722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4634-1722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4731-1722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5110-1722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5107-1722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2056-1723 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3111-1724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5354-1729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3978-1731 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5327-1731 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2805-1732 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5356-1733 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5357-1734 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1994-1735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4015-1736 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4084-1736 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4167-1735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5570-1735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4084-1735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4545-1737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3899-1739 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3914-1739 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5360-1739 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1801-1740 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5527-1740 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1746-1743 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1746-1742 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3103-1745 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3103-1744 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1752-1746 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3279-1746 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4994-1746 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1751-1746 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-1746 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2333-1753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5826-1754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2332-1754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2862-1754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5533-1753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2490-1755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3470-1755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3833-1755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3862-1755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4254-1755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3470-1755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3833-1755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2934-1756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3095-1756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3099-1756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5582-1756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1758-4132 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5358-1759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2012-1760 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2516-1761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2687-1762 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2313-1763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2147-1764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2335-1764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-1765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2675-1767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4099-1767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5843-1767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1784-1767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2675-1767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2849-1770 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2849-1769 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2849-1771 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2849-1768 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-1772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5073-1773 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2705-1774 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2682-1775 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3881-1775 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2322-1777 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3309-1778 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3570-1778 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3714-1778 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3866-1777 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3909-1777 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5121-1777 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3714-1778 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3031-1779 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3064-1779 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3199-1779 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-1779 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5401-1779 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4930-1780 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5193-1780 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2573-1781 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2982-1781 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4935-1781 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5309-1781 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2469-1782 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4625-1782 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5194-1782 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2314-1783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2498-1783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4953-1784 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4155-1785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3462-1786 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4936-1786 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5189-1786 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5838-1786 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5009-1787 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5330-1788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4652-1789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5384-1789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4306-1790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4652-1790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3276-1791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4590-1791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4975-1791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3973-1792 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4295-1792 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3005-1793 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3031-1794 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3400-1794 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3031-1794 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3409-1795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-1795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4461-1796 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-1798 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-1799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5452-1800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1800-1801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1802-4728 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2394-1803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4408-1804 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4470-1804 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4901-1804 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3841-1805 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5159-1805 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2758-1807 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2758-1806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3376-1808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-1809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3189-1809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3932-1809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5420-1809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5583-1809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5825-1809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2166-1810 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2166-1810 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2751-1811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3361-1811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5283-1811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3361-1811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4541-1811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3273-1812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5361-1813 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3441-1815 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5459-1816 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5645-1816 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4817-1818 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5372-1818 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-1820 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-1820 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5362-1821 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2481-1823 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2565-1823 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4007-1823 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4550-1824 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4550-1824 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2167-1825 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2167-1825 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-1826 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-1826 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3014-1827 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3542-1827 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1963-1829 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-1829 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4072-1830 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3085-1831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4412-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5769-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4677-1833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4677-1833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4733-1835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5809-1836 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5426-1837 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2022-1838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2420-1838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2854-1838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3635-1838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4869-1838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5318-1838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2477-1838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5465-1839 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5526-1839 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5365-1841 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5366-1840 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2136-1842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2604-1842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2023-1843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2329-1843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4888-1843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5334-1844 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1944-1848 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2882-1852 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4275-1853 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2305-1854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2502-1854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2261-1857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2427-1857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4329-1857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2778-1858 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-1858 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-1859 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3070-1860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3076-1860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3035-1861 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3335-1862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4025-1862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4287-1862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3653-1863 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-1867 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4510-1868 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4130-1869 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1730-1870 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2304-1870 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3196-1870 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5142-1872 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5277-1873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5589-1873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1948-1874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2561-1874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-1875 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2683-1876 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5370-1877 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3654-1880 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5371-1881 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3669-1882 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3855-1882 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4748-1882 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5403-1882 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4004-1883 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4004-1883 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3746-1884 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3060-1886 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3060-1887 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4226-1888 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5373-1891 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5374-1892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2693-1893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-1901 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-1900 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-1899 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-1898 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3875-1902 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-1902 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4089-1903 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3970-1904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4215-1904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4258-1904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4871-1904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5276-1904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5476-1904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3984-1904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5677-1904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3984-1904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2914-1905 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3609-1905 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3971-1905 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5275-1905 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4457-1907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4932-1907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4265-1908 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5094-1909 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4783-1910 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5080-1911 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2086-1912 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5653-1912 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2086-1912 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4289-1913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5141-1913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5320-1913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4291-1914 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5385-1914 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5302-1916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5310-1915 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5727-1917 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2255-1918 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5181-1919 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-1920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5302-1920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-1920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5377-1921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5129-1922 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5019-1923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3929-1924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2099-1925 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3834-1925 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5434-1926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2326-1927 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2195-1928 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2355-1928 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2408-1928 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4244-1928 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4244-1928 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5332-1929 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3423-1930 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3423-1930 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1938-1931 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-1931 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1938-1931 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-1931 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3876-1932 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4118-1932 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4118-1932 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5341-1933 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2560-1935 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2972-1935 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4461-1935 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2972-1935 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-1936 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4551-1936 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-1936 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2290-1936 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4551-1936 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4292-1938 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2659-1941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4101-1942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2210-1943 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2929-1943 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3133-1944 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4066-1943 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5369-1944 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2210-1943 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4066-1943 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3397-1945 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4849-1945 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4849-1945 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3502-1949 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2048-1950 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2697-1951 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2890-1952 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2913-1952 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5381-1954 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-1955 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5286-1956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5726-1957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2684-1958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3272-1959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-1959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3452-1960 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4431-1960 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2299-1962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4111-1961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5009-1962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5287-1961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-1963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-1963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-1963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3013-1965 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3608-1966 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3517-1967 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1980-1978 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1980-1977 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1980-1976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1980-1975 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1980-1974 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1980-1973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3814-1979 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-1979 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3815-1980 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4490-1980 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3294-1982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4112-1983 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4320-1985 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4757-1985 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4342-1986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2248-1987 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3227-1988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4257-1989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3932-1990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5192-1991 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5371-1991 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5385-1992 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5390-1992 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5386-1993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3200-1994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5735-1995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2305-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2314-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3203-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4190-1997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-1997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4749-1997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4190-1997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-1997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-1997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2517-1998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2517-1998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5388-1999 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4945-2000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4074-2002 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4877-2002 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4074-2003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4878-2003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5367-2004 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2679-2005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3288-2005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2915-2005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4149-2005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5518-2006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3718-2007 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4648-2010 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4161-2011 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5181-2011 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2817-2012 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5054-2012 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5215-2012 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-2013 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4457-2013 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4868-2013 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-2014 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4310-2015 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5394-2016 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5845-2019 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5846-2020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5467-2021 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3186-2023 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4945-2023 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3614-2024 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2709-2026 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4293-2026 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2548-2027 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-2027 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5655-2028 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5397-2029 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5396-2030 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5399-2031 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2093-2032 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2688-2032 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3382-2032 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2944-2034 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4756-2034 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4885-2035 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5564-2036 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5565-2036 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4125-2037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5188-2037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5315-2038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5569-2038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5570-2038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2434-2039 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2061-2040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2824-2040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3749-2040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5222-2040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5224-2040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5219-2040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4457-2041 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-2041 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4730-2042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3869-2043 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3612-2044 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2447-2046 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2666-2046 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2223-2049 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2235-2049 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2274-2049 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2841-2049 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2224-2050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2744-2050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2762-2050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-2050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4067-2050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4180-2050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4490-2050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5403-2051 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2984-2053 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2984-2053 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3509-2054 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5464-2054 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4812-2055 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5306-2055 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3198-2056 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4311-2056 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5401-2056 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4312-2056 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2352-2057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3516-2057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-2057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2351-2057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3515-2057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-2057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3619-2060 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3619-2059 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3619-2058 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5067-2062 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5066-2063 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5066-2064 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5067-2065 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5066-2066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5067-2067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5400-2068 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2127-2070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2735-2070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4698-2070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4094-2071 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2915-2072 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3840-2073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3858-2073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5582-2073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2805-2076 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3973-2077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4402-2077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2126-2078 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-2080 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5721-2080 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-2079 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5264-2082 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5263-2081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2279-2083 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3258-2083 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4964-2084 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5406-2085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3048-2086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3611-2086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4051-2086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4526-2086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4528-2087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2113-2088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2676-2088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5293-2088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4468-2089 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-2089 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3619-2090 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3619-2090 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2733-2091 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2616-2092 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2203-2093 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2285-2095 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5850-2094 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2094-1496 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3139-2096 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2567-2097 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4995-2097 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2449-2098 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5466-2098 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2486-2101 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4303-2101 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4303-2101 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4381-2102 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4381-2102 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3113-2103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2204-2104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3080-2104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4699-2104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5187-2104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3080-2104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4391-2104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5764-2104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4392-2105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5638-2105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2876-2106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5624-2106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-2109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-2108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-2111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-2110 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2618-2112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3644-2112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4163-2112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5115-2112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5206-2112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2617-2113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3900-2114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5407-2114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-2115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-2116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3699-2116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5408-2117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-2118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3013-2119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2994-2120 connects the same voltage levels (20.0, 20.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2463-2122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3175-2122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3177-2123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3448-2123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4183-2123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-2124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3525-2124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2767-2125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3352-2125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3793-2125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4059-2125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5389-2125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3793-2125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5387-2125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5382-2127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2678-2128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3608-2129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3954-2128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4014-2129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-2132 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-2131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-2130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4673-2133 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-2135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4782-2135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5817-2135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2239-2135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-2135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-2135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4192-2136 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4193-2136 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2497-2137 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3225-2137 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5253-2138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5356-2138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5523-2138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5065-2140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-2141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2430-2142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2430-2142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1911-2143 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2759-2143 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4422-2144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4833-2144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4422-2144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4833-2144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4834-2144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3195-2147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3544-2148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4351-2148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5298-2148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5562-2148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4350-2148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5526-2149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4162-2151 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5740-2151 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5410-2152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3542-2154 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5411-2155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3654-2156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3542-2157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5552-2157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1997-2158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1997-2158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2162-2161 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5316-2162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4833-2163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2105-2164 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2069-2166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3208-2166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4755-2166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5270-2166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4754-2166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2234-2167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3707-2167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3926-2167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5065-2167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5076-2167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5322-2167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-2167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5075-2167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-2167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5686-2171 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2780-2172 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4433-2172 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-2173 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3525-2174 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3875-2174 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-2173 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3525-2174 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-2177 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-2177 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2223-2179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2223-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2682-2180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4017-2181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2881-2182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3876-2182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2188-2185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2295-2185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3097-2185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3296-2185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3708-2185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4807-2185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2188-2185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4807-2185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4807-2185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2326-2186 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2851-2186 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3006-2186 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3962-2186 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2325-2186 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3963-2186 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5414-2187 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5415-2189 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3923-2190 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5432-2192 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5416-2193 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2803-2196 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2199-2197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3675-2197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3675-2197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2200-2197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2201-2198 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3907-2198 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3907-2198 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3812-2202 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4933-2202 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5764-2204 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2988-2205 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3138-2206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5417-2206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3137-2206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4021-2207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3133-2210 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5420-2211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5423-2212 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2501-2213 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2871-2215 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5178-2215 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5182-2215 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5424-2217 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5422-2216 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4808-2220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5425-2220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2580-2222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2841-2223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2467-2225 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-2225 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2226-1498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4164-2226 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5426-2226 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5427-2227 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5062-2228 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5428-2229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2499-2231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2521-2231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3763-2232 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3763-2232 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2992-2233 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3835-2233 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5068-2233 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5271-2233 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2584-2234 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3946-2234 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5065-2234 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5850-2234 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2584-2234 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5696-2234 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3763-2235 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2796-2237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3520-2237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2796-2237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4014-2238 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4782-2239 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3489-2240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3489-2240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2858-2240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5528-2242 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4026-2243 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3326-2244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3459-2244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2568-2246 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3153-2246 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3230-2246 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4923-2246 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3154-2246 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5335-2248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2781-2249 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2901-2249 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2395-2250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-2251 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4771-2251 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5427-2252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2485-2254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3613-2256 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5475-2256 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3897-2257 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4834-2259 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4833-2258 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5429-2260 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2272-2262 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2618-2263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5115-2263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5648-2264 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2617-2265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5293-2265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4651-2266 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5613-2266 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4416-2266 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5269-2266 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4330-2269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5430-2270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-2271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2208-2272 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2184-2273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2206-2273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5072-2273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2183-2273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2206-2273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5071-2273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4489-2274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5432-2275 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4021-2276 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4021-2276 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-2280 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3566-2281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3243-2283 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4707-2283 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4706-2282 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5689-2284 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4012-2286 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-2286 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5433-2288 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-2289 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3801-2289 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-2290 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2605-2291 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3226-2291 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2826-2292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3414-2292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4570-2292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5617-2292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2540-2293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2827-2293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3509-2293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5434-2294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3292-2298 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5746-2300 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5830-2300 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5207-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3308-2302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4091-2302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5301-2303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2731-2304 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2343-2306 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3868-2306 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5623-2306 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2492-2308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3104-2308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3857-2308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5062-2308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5616-2308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3857-2308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5615-2308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3401-2308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2635-2309 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3279-2309 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2287-2310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-2310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5534-2312 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3856-2313 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4149-2313 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2921-2314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4091-2314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5036-2314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5036-2314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2517-2315 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4874-2316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3218-2317 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4127-2318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4519-2318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3647-2319 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5435-2320 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3363-2321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3079-2324 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4388-2327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5394-2328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3083-2330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5440-2331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3195-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3247-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3415-2335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4615-2335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4702-2335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5572-2335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3415-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4615-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4251-2336 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5441-2336 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4251-2336 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-2337 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3063-2338 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3469-2338 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2857-2339 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2427-2340 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2887-2341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-2341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2887-2341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5820-2342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3353-2344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4206-2344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4316-2345 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5102-2345 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2880-2346 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5442-2346 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2570-2348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2976-2348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4297-2348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2570-2348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4298-2348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4622-2349 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2570-2348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4017-2353 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2814-2354 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-2354 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3559-2356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5762-2357 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-2358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5197-2359 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4342-2361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5444-2362 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5445-2363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2373 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2371 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2370 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2634-2375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3895-2375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5427-2375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3895-2375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3279-2376 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4133-2376 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4181-2377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2758-2378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4017-2378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3113-2380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3551-2380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3713-2380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5447-2381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3698-2381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5346-2382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-2384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2511-2385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2591-2386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-2386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4905-2387 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3303-2388 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4993-2389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2752-2390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3639-2390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2392-2391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5472-2391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2909-2392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3331-2392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5547-2392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2909-2392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5548-2392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2824-2393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4928-2394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2501-2395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2643-2396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2779-2397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2779-2397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3325-2399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-2399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5457-2400 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3012-2401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-2401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3721-2401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5652-2401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-2401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4705-2403 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4705-2402 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5458-2404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2468-2405 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2982-2405 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5737-2406 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4721-2407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2412-2408 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4544-2408 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3216-2409 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5808-2411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-2413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5768-2414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4841-2415 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5665-2415 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3163-2416 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3163-2417 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5350-2418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5464-2419 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4217-2421 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4217-2421 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5455-2422 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2426-2423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2511-2423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3369-2423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3445-2423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5774-2423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2511-2423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2595-2425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2784-2425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2784-2424 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5607-2426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-2427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3081-2427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4720-2427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4861-2427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3009-2428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3082-2428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4476-2428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4912-2428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5430-2428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2430-2429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4252-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4742-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5317-2430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5463-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5491-2430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5492-2430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5536-2430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4252-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4742-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4252-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4492-2432 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5496-2432 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5712-2432 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4393-2433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4683-2433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3904-2434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5449-2434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5716-2434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2966-2436 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5462-2435 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3313-2437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5575-2437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4920-2439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4920-2438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3508-2440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5706-2440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3793-2441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4026-2441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4362-2441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5237-2441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5761-2441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5466-2443 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2594-2444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2594-2445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4778-2446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5564-2446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5153-2446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5136-2446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5133-2446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5546-2447 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3504-2448 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3900-2449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3900-2449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2944-2450 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5450-2452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3420-2453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2566-2456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4377-2456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2562-2457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3092-2457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4161-2457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4214-2457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5444-2457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5680-2457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4213-2457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4657-2459 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5215-2459 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5467-2460 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3338-2462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3175-2463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3649-2464 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5042-2464 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3397-2466 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3925-2466 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-2467 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4240-2468 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4897-2468 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5459-2468 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3737-2469 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4573-2470 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4573-2470 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2906-2471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4456-2471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4660-2471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2834-2472 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2489-2474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2489-2473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4569-2475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4088-2476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3852-2477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4869-2477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4867-2478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5191-2479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3742-2480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2822-2482 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4267-2482 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4614-2482 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5118-2483 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5194-2484 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5265-2484 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2728-2486 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3497-2487 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4757-2488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5525-2488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3033-2489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2834-2489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3470-2490 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3597-2490 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3781-2490 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-2490 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3780-2490 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3779-2490 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4867-2491 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5289-2491 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3591-2493 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4688-2495 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2724-2496 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2718-2499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3007-2499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-2499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5169-2499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5468-2500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5450-2501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-2501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2517-2503 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-2503 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2780-2504 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2922-2505 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5469-2506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4197-2507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4867-2507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5229-2507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5231-2507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4867-2507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4997-2508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4997-2508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-2509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2781-2510 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2836-2512 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5732-2512 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2835-2513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4397-2513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-2514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-2514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3251-2516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3251-2516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4868-2517 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4868-2517 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-2518 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2717-2521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4778-2521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5169-2521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5721-2522 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2536-2525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5470-2525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-2526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4809-2527 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3936-2528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2559-2529 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5349-2529 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2559-2529 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2930-2530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2533-2532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2687-2533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3660-2533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4818-2533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5474-2533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2571-2534 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4961-2534 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5473-2535 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5760-2536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5470-2537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2706-2538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2895-2539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3158-2539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3158-2539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3942-2540 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4210-2541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-2542 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5478-2544 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5507-2543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2971-2545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2971-2545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5476-2546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5477-2547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3684-2548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4736-2548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4845-2548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4736-2548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5695-2549 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3911-2550 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4737-2550 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4744-2550 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4176-2552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3188-2553 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-2554 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-2554 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2766-2555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-2556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3699-2556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3377-2557 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4915-2557 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3842-2558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4323-2558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3646-2559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5573-2559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5574-2559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5847-2559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2628-2559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4461-2560 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5481-2562 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5482-2563 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5483-2564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3940-2565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4007-2565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3105-2566 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3824-2566 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4080-2566 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5256-2566 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5767-2566 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5494-2567 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3103-2568 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4109-2569 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-2569 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5713-2570 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5711-2570 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5480-2571 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4002-2572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4366-2572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5192-2574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2851-2575 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-2576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-2576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-2577 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5391-2577 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5754-2577 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5794-2577 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5257-2579 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5049-2580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5848-2580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5671-2580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3436-2581 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4141-2581 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2828-2582 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2624-2583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4396-2583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5113-2583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4395-2583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5112-2583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2738-2585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5753-2585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3169-2587 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5485-2588 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2984-2589 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3010-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5724-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3010-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-2591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-2591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5383-2592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5633-2592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5487-2593 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4403-2594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4413-2594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4403-2594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4413-2594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2784-2595 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5402-2596 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2600-2598 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4675-2598 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5488-2599 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3113-2601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4054-2601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3113-2601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5489-2603 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3572-2604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4448-2604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2876-2605 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3226-2605 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3348-2605 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4072-2605 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3412-2608 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3409-2610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3619-2611 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5036-2612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5458-2612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-2613 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3360-2614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3977-2615 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4680-2615 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3024-2616 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5815-2616 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4867-2619 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5097-2620 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5491-2621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5492-2621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2958-2622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5806-2622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5807-2622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2930-2625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4590-2625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2831-2626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2932-2626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4476-2626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2831-2626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2931-2626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5573-2628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2637-2629 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3559-2629 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3891-2629 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2910-2630 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5250-2630 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5493-2632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2789-2633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3139-2633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-2633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-2634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4133-2635 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4637-2635 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4133-2635 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2950-2636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4069-2636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3441-2637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5233-2638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5505-2639 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5834-2639 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5535-2640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2644-2643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5222-2643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5219-2644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3502-2645 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4172-2645 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3651-2645 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4173-2648 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5546-2648 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5584-2648 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4996-2649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5821-2649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3769-2650 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3376-2651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3489-2651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4543-2652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5191-2652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5787-2653 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4146-2654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4516-2654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5357-2654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4517-2655 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4896-2655 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3539-2656 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2717-2657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3452-2657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3987-2658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3688-2659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2592-2660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3530-2660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4039-2660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5431-2660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2592-2660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4780-2661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3491-2666 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5690-2667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5691-2667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3511-2668 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4162-2668 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4885-2668 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3572-2672 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3572-2671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4255-2673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4892-2673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4255-2673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4401-2674 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5495-2675 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3883-2675 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5442-2676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2675-2677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4358-2680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3015-2681 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5402-2681 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5762-2681 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3015-2681 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3483-2683 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4698-2684 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5497-2685 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5498-2686 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3761-2687 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4783-2689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3517-2690 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2692-2691 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5499-2691 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3167-2693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3882-2693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4918-2693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2834-2694 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3897-2696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-2696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4832-2698 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-2699 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3656-2700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3438-2701 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3175-2702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4057-2702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4670-2702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4058-2702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-2703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5208-2703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5836-2703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3346-2704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2895-2706 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3839-2705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4617-2706 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4870-2705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5400-2705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3942-2707 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3942-2707 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-2709 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-2710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5503-2711 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3312-2713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3543-2713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3560-2713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3312-2713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4135-2714 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5170-2718 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5172-2718 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3029-2719 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4726-2720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4725-2720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4724-2720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5067-2721 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-2722 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-2722 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3583-2724 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4817-2724 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4817-2724 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4227-2725 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3915-2726 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-2727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3600-2728 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5505-2729 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4147-2730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4225-2733 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-2737 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-2736 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-2738 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5651-2739 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3644-2742 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3814-2743 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4993-2743 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3121-2744 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4067-2744 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4995-2744 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3120-2744 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4995-2744 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3119-2744 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4629-2745 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3422-2746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2944-2748 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-2749 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4731-2750 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4787-2750 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5110-2750 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4787-2750 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2845-2753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4204-2753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4425-2753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5103-2753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5738-2753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4203-2753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3509-2754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-2754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5510-2755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3424-2756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4805-2756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5507-2757 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3662-2758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5506-2760 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5511-2761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2952-2762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-2762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2951-2762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-2762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4068-2763 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4913-2763 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4628-2764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3366-2765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3366-2765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5508-2766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5688-2767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5387-2767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2840-2769 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3261-2769 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4283-2769 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4410-2769 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-2769 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5819-2769 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4283-2769 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5241-2769 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3016-2770 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4811-2770 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-2771 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-2771 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5503-2772 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5776-2772 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3903-2774 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5084-2774 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5509-2775 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3809-2776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5138-2776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5512-2777 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-2778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2961-2779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3330-2779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5443-2780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5453-2780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5454-2780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5600-2780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3330-2779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-2780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3504-2781 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3484-2783 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4182-2784 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5813-2784 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5423-2787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-2788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-2788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-2789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-2790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5450-2790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5471-2790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5472-2790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-2790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3400-2791 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5135-2791 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4063-2792 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-2793 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4961-2794 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5513-2795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3381-2797 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3671-2797 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3858-2799 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4198-2800 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4867-2801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3798-2802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3924-2802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5252-2802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-2805 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3671-2806 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4929-2807 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5458-2807 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3699-2808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3511-2809 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4175-2809 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4379-2809 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4886-2810 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4255-2811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5516-2813 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3307-2814 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4371-2814 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4394-2814 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5040-2814 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5299-2814 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5555-2814 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5557-2814 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5571-2814 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5039-2814 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3601-2815 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2944-2816 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5752-2816 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4721-2818 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5214-2818 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5460-2818 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4346-2819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4347-2821 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4347-2820 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4314-2823 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4334-2823 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5451-2824 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3712-2825 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3182-2829 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3847-2829 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5323-2829 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5819-2829 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5152-2830 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3808-2832 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3807-2832 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3806-2832 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3805-2832 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5674-2833 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4397-2835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5517-2837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5519-2838 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3345-2839 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5095-2840 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5267-2842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5393-2843 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5521-2844 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2953-2845 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4564-2845 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5731-2847 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5522-2848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4573-2849 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4650-2849 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4573-2849 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4650-2849 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4573-2849 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4573-2849 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5253-2850 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5523-2850 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3102-2852 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-2852 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5792-2853 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5526-2855 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5525-2856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5524-2858 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5524-2859 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5528-2860 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3399-2861 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3757-2863 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5338-2863 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5786-2863 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4142-2864 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4171-2864 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2996-2867 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4852-2865 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4852-2866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5529-2868 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4686-2869 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4448-2870 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5531-2873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4935-2874 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3276-2875 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5619-2876 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5533-2877 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5532-2878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3037-2882 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3075-2883 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-2884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5318-2885 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5534-2885 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3035-2886 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5535-2886 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4293-2887 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4585-2888 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4568-2889 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2916-2891 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3485-2892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4866-2892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5566-2892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3212-2892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3485-2892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5679-2892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3485-2892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3479-2893 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4640-2893 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5089-2893 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3478-2893 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4641-2893 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-2893 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3477-2893 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3476-2893 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3326-2894 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5656-2894 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4016-2895 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3181-2896 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5536-2897 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3844-2898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5036-2898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5493-2898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5538-2902 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5537-2902 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5683-2903 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4719-2904 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4132-2905 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2909-2908 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5623-2910 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3900-2911 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5407-2911 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4859-2913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2937-2915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2998-2915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3609-2915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4466-2914 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-2916 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5405-2914 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2997-2914 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-2914 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2920-2918 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3793-2919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-2920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4253-2920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5779-2920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4919-2923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4945-2923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-2924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-2924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3085-2925 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4382-2926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3297-2927 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5540-2928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3213-2930 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3682-2930 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2985-2933 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3612-2933 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3099-2934 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5781-2934 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3849-2936 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5000-2935 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5610-2936 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3849-2935 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5612-2935 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5543-2938 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5291-2940 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5845-2940 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4850-2941 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3239-2944 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5027-2944 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5083-2944 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-2945 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4304-2945 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4405-2945 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-2945 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3967-2946 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4930-2946 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-2947 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3240-2950 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5069-2950 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5445-2950 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4425-2953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5055-2954 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5675-2954 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4346-2955 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4242-2956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5545-2958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5546-2959 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4671-2962 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2967-2963 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2966-2964 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4082-2966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4157-2966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5038-2965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5592-2967 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4082-2965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4157-2966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5462-2966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-2968 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5245-2969 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-2969 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5547-2970 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3998-2971 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4911-2971 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5218-2971 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3997-2971 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3040-2973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5203-2973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3982-2974 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4257-2974 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5549-2975 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5619-2977 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5642-2977 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-2978 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3602-2979 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4356-2979 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5466-2979 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5607-2979 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5644-2980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4004-2983 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3403-2984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4096-2984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4367-2984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5149-2984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5849-2984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4096-2984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3484-2986 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4055-2988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4160-2988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5255-2988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5742-2988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3908-2989 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3553-2990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4986-2991 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5668-2991 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-2993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4794-2993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3287-2996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3680-2995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4315-2995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5543-2995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5647-2995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5649-2996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3288-2998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3389-2998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4770-2999 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5620-2999 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4770-2999 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3620-3000 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3174-3001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5171-3001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5775-3001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3046-3001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3174-3001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4563-3002 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-3003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3648-3004 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-3004 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3466-3005 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-3006 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-3006 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5047-3008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5119-3008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4913-3010 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-3010 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3081-3011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-3012 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4779-3013 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4779-3013 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5455-3015 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4931-3017 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5171-3018 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5579-3018 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4791-3019 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3542-3020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4772-3020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5553-3022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5778-3023 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5784-3023 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3519-3027 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5593-3029 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5028-3030 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5139-3030 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4028-3032 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3596-3033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3399-3034 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4721-3035 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4461-3038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-3039 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4464-3040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4512-3040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4638-3040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4867-3041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4867-3042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4867-3042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4229-3043 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4844-3043 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-3044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4302-3044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4849-3047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5128-3047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4814-3048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4585-3049 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3063-3050 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3268-3052 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3496-3053 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3058-3056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-3056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3057-3056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5559-3059 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5198-3065 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5307-3065 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3674-3066 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3978-3066 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-3067 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5560-3069 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5561-3068 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-3071 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4335-3073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5325-3073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5637-3073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3101-3074 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5658-3075 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4769-3076 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5827-3076 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4799-3076 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5562-3077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-3078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4773-3079 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5438-3079 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5160-3080 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4660-3083 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5231-3084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5737-3084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3709-3085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5364-3085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5377-3085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3407-3086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4550-3086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5659-3086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4550-3086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3313-3087 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5661-3087 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3509-3088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5262-3089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3967-3090 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5144-3091 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5629-3091 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4075-3092 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5003-3095 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3561-3096 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3344-3098 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-3100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5258-3100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4068-3103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4134-3103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4923-3103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4135-3103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3688-3107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3688-3106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3457-3108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5379-3108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5359-3108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5566-3109 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4922-3110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5334-3110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-3111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-3111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-3112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5585-3112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3551-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3760-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4393-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4760-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5625-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5482-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-3115 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5095-3114 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5286-3115 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4966-3114 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5567-3122 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3508-3123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5568-3125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4352-3126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5614-3127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5818-3127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5609-3127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3178-3128 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2930-3129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3812-3129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4268-3131 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5120-3131 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4363-3132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4981-3134 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5571-3136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4612-3139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3009-3140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3164-3141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3929-3141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3164-3141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5361-3142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5572-3143 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3146-3144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3902-3145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-3145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5100-3145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4976-3145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4047-3146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4978-3146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3985-3147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5847-3147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5779-3148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3470-3149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3471-3150 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3878-3151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3889-3152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4130-3152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5021-3152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5050-3152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4890-3154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-3154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5245-3153 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-3153 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-3157 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3600-3159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-3159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3258-3160 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3526-3160 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3275-3161 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-3163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3935-3163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-3163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3934-3163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3385-3164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4433-3164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5205-3164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5493-3164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5573-3166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4525-3169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5505-3169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5575-3170 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5576-3171 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4723-3172 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5345-3172 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3672-3173 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5579-3174 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4670-3175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4965-3176 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5627-3177 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3266-3178 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4876-3179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4927-3179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3752-3180 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3752-3180 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4678-3180 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3396-3183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4109-3184 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4639-3184 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5581-3185 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5123-3185 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4888-3186 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5582-3187 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5617-3188 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5788-3188 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4289-3190 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5378-3190 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-3192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-3191 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3514-3193 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4251-3194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4250-3195 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4310-3196 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4691-3196 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5240-3197 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5355-3197 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4310-3196 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5056-3199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4578-3198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5563-3201 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3270-3202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3881-3204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3882-3205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5501-3206 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4627-3207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5271-3208 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4217-3209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4500-3209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5584-3210 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-3211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5566-3212 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5586-3214 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4873-3218 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5580-3219 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3825-3220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3923-3220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3924-3220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-3221 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3300-3222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4229-3222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3299-3223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4228-3223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4766-3224 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5827-3224 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3822-3226 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3630-3228 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5491-3229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3427-3233 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3427-3232 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3427-3231 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4608-3235 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4609-3234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5445-3240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5540-3241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4181-3242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4695-3243 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4709-3243 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4265-3244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5280-3244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5333-3245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4635-3246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5031-3246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5589-3247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5590-3248 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4617-3249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3436-3250 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4321-3250 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5567-3250 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5840-3251 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5755-3251 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4788-3252 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5650-3252 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4144-3253 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-3253 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5519-3253 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3650-3255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3650-3254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3650-3256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3437-3258 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4447-3258 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5197-3258 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-3260 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5323-3261 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4673-3262 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3579-3263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5591-3264 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4559-3266 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3948-3267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4236-3269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4238-3270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4889-3270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4896-3270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4237-3270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4889-3270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-3271 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4772-3272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4979-3273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5592-3273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4979-3273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5114-3274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5132-3274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5544-3274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4475-3276 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3284-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3652-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5616-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3283-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3652-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5615-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3286-3279 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3285-3279 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4038-3287 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4331-3291 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4871-3294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5594-3295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3500-3297 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3869-3297 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-3298 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5782-3298 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4652-3300 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4652-3299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4275-3301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3399-3302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4546-3302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3399-3302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4414-3303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5407-3304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4207-3306 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5172-3308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5757-3308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5834-3309 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4302-3311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5382-3311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5586-3311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5751-3311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3691-3312 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4823-3314 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5177-3315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5740-3315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5310-3321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5692-3321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3913-3322 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-3323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-3323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-3323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3534-3323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3533-3323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-3324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3428-3326 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4283-3327 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3704-3328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3704-3329 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5471-3331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5576-3331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4852-3333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4852-3332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4287-3335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5043-3335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5326-3335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5596-3337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5250-3339 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5037-3341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5037-3340 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-3343 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5244-3344 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5354-3345 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3523-3346 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5619-3348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3773-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4613-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5096-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3773-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5639-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5772-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4601-3350 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5601-3354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5602-3354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-3355 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5600-3356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5599-3357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5487-3358 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4964-3358 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3933-3359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3933-3359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5329-3361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4457-3364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3487-3365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4668-3365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4668-3365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4581-3366 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4347-3367 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4347-3367 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4181-3370 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4181-3370 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3373-3372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3374-3372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5608-3375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5125-3376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5226-3376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5610-3378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5611-3379 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3836-3380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4337-3380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5728-3380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3836-3380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4119-3381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4406-3382 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5542-3383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5541-3384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5093-3386 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3900-3387 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3900-3387 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5141-3388 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4592-3390 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3886-3391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4843-3391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3923-3396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5542-3396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3924-3396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5541-3396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3925-3397 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4293-3398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3541-3399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4333-3399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5304-3399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5517-3399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4027-3400 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4027-3400 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5615-3402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5486-3403 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3405-3404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4131-3406 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4043-3407 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5617-3408 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4061-3411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3912-3415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4972-3416 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5620-3417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4456-3418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3981-3419 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4035-3419 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3981-3419 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4146-3420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5765-3421 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5281-3422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5556-3422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4108-3423 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4327-3424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5415-3426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3882-3427 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5127-3427 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5126-3427 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5373-3427 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3736-3429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3893-3429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5129-3431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-3432 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5396-3432 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-3432 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5624-3434 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3524-3437 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-3439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5588-3439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3772-3441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-3442 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5625-3443 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3447-3444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4241-3444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-3444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5774-3445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5626-3446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-3447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-3448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5143-3449 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5627-3451 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5236-3453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5237-3453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5344-3453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5801-3454 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4924-3455 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-3455 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-3455 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5628-3456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3555-3457 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5539-3459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-3460 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5777-3461 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5629-3462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4779-3463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5274-3466 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5630-3468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3514-3469 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3751-3470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3751-3470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-3473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-3475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-3472 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-3474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4881-3481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4881-3480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5330-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5379-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5478-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5359-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5507-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5558-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3720-3484 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3556-3485 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4227-3485 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4401-3486 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4414-3486 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3545-3488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4123-3488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5550-3490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5631-3492 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4457-3493 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4318-3494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4407-3494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5484-3494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5485-3494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5632-3495 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4388-3497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4752-3497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5106-3497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4388-3497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3567-3498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5055-3498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5055-3498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5633-3499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3869-3500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3503-1499 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5278-3506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5637-3507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4010-3508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4569-3508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5103-3508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5635-3508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4011-3509 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-3510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4789-3511 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4016-3512 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3878-3513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3981-3514 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4838-3514 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5799-3514 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3981-3514 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3981-3514 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4034-3517 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4034-3517 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4105-3518 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4105-3518 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3836-3519 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4552-3522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5010-3521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5386-3522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5790-3521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4795-3523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4048-3528 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5715-3528 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5822-3529 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4424-3530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5639-3532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5641-3535 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4172-3536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4816-3538 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-3538 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5432-3538 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4104-3539 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-3539 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4103-3539 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4262-3540 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5830-3541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4060-3545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4123-3545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5423-3545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5644-3548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4346-3550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5078-3550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4346-3550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5645-3552 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5018-3553 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4360-3554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4893-3555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5178-3555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5478-3555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5530-3555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5707-3555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5182-3555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-3558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4891-3559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4891-3559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3879-3560 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3564-3561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-3562 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-3563 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4017-3566 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4216-3566 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5338-3567 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5132-3568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4723-3569 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4671-3570 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4010-3571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4569-3571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4010-3571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3982-3572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5009-3573 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3370-3576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5632-3576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4046-3579 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4507-3581 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5646-3580 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3580-1497 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4519-3582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5717-3582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3845-3584 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5285-3584 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5343-3584 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5837-3584 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4652-3585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5647-3588 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5649-3589 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3391-3590 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3886-3590 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5648-3592 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5480-3593 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3430-3594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3987-3594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3509-3595 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5457-3595 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3742-3596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5456-3599 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5370-3600 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5571-3600 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4305-3602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5607-3602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4188-3605 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4187-3605 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5307-3606 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4324-3607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4233-3608 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4191-3610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4618-3610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5626-3610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5653-3611 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3395-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4048-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4643-3612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5026-3612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5395-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5473-3613 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5025-3613 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5183-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5352-3612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5186-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5351-3612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3368-3615 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4049-3616 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4603-3616 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-3616 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4603-3615 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-3615 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-3615 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4510-3618 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5202-3617 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3406-3619 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3406-3619 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3363-3621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5804-3621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3363-3621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4617-3622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3901-3623 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4684-3623 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5266-3623 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4684-3623 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5655-3625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3630-3627 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3630-3626 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-3629 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-3628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5328-3630 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5587-3630 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4472-3630 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3464-3630 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3746-3631 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3906-3631 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-3631 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4833-3631 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3880-3632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5340-3634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4101-3634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5811-3636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4072-3637 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5521-3640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5520-3641 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5656-3643 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4803-3645 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5574-3646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5210-3647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-3648 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4575-3648 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3531-3650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3654-3650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3859-3650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3654-3650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4172-3651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4489-3653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-3653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4180-3655 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4490-3655 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5565-3657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3659-3658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3984-3658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3984-3659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5768-3661 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3676-3662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3677-3662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4216-3662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4018-3663 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4218-3663 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3699-3664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4436-3664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5625-3664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5482-3664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4182-3666 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4611-3665 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4423-3667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5199-3667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5657-3668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4689-3669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3694-3670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-3672 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4004-3674 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4159-3674 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3746-3675 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3980-3675 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-3675 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4128-3678 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3310-3679 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3851-3679 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4398-3679 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4560-3679 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-3679 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-3679 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4852-3681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5659-3683 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-3685 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5586-3685 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5661-3686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5660-3687 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5421-3688 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5662-3688 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5681-3688 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4949-3688 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5664-3689 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4618-3690 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-3695 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-3695 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5559-3696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4919-3697 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4181-3700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5446-3700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4181-3700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4230-3701 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4462-3702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5667-3703 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4243-3704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5101-3704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5666-3704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4550-3710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4498-3711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4497-3711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5212-3712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4178-3714 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4791-3714 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4313-3715 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5668-3716 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4920-3718 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5669-3719 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4364-3723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5093-3727 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5104-3727 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5671-3730 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4329-3731 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5670-3733 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5772-3732 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4265-3734 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5331-3735 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3722-3736 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4428-3736 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4540-3736 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4428-3736 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3726-3738 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3725-3738 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4579-3737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3724-3738 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4796-3741 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-3743 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3872-3746 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5404-3747 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5672-3750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-3751 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-3751 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-3752 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-3752 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4810-3753 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5673-3754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5190-3755 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5437-3757 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4491-3758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4529-3758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5292-3759 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5674-3762 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3859-3763 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3875-3763 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4717-3763 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-3763 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4329-3765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5413-3766 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4804-3770 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4620-3772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4388-3772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5506-3773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5835-3773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4730-3773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-3774 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4603-3774 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5045-3775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4753-3786 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4711-3787 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4710-3786 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4727-3794 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5693-3794 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-3795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5597-3795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4455-3796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5812-3796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4120-3799 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5677-3800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4822-3802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4824-3802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4821-3802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-3804 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-3803 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3995-3809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4282-3809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4373-3809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5200-3809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5516-3809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3995-3809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4732-3810 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5512-3810 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-3811 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4995-3813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4080-3814 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3821-3815 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3820-3815 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3819-3815 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4080-3824 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5251-3825 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4118-3826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5679-3827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4157-3829 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4157-3828 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3885-3831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3975-3831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4330-3830 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3974-3830 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4330-3831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4331-3832 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5068-3835 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4543-3837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5282-3838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5001-3839 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5094-3839 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5469-3840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5514-3840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5140-3842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5681-3842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3890-3843 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4744-3846 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4744-3846 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4283-3847 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5683-3848 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5452-3850 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4560-3851 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4349-3855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5796-3855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5797-3854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4690-3856 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4973-3858 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5514-3858 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5685-3861 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5684-3860 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5765-3863 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5686-3864 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4731-3867 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3875-3871 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4508-3873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4939-3873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5342-3873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-3874 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4254-3874 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5687-3877 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5688-3877 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4958-3878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4958-3878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5660-3879 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4978-3881 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4979-3882 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5374-3881 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4316-3883 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5689-3884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4513-3890 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4620-3891 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5388-3891 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4253-3894 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5814-3896 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5312-3898 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5627-3900 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5266-3901 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4589-3903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4393-3904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5082-3906 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4640-3907 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4664-3907 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4641-3907 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4664-3907 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4443-3910 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5745-3911 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5532-3915 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4100-3916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5059-3916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5238-3916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5719-3916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4105-3917 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5694-3918 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4757-3919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4035-3922 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5799-3922 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4837-3924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4837-3923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5695-3928 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4508-3930 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5120-3930 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3996-3931 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4294-3931 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5441-3931 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4064-3937 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5272-3937 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5464-3937 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5709-3937 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5741-3944 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5774-3944 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-3945 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5697-3949 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5418-3951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4014-3954 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4014-3955 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5273-3956 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3960-3959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4462-3959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5179-3959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4566-3961 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-3962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-3963 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4616-3964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5177-3964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5437-3964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5800-3964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5701-3965 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4930-3967 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5700-3972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4912-3976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4085-3977 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4085-3977 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5327-3979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5082-3980 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4198-3981 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5107-3981 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5008-3982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5703-3986 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-3988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5086-3989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5531-3990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5702-3991 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4931-3992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5704-3993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5354-3994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5706-3999 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4700-4000 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4365-4001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5825-4003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4313-4004 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4469-4004 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5506-4006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4334-4008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4368-4008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4722-4009 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5488-4010 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4690-4011 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5247-4013 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5214-4015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5708-4018 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5709-4020 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5709-4020 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5418-4021 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4105-4022 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-4022 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5490-4023 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5577-4023 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-4024 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-4024 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5236-4026 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5135-4027 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-4030 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5156-4030 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-4030 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5155-4030 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4686-4031 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5711-4033 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5099-4036 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5712-4037 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4882-4040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4905-4041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-4042 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4550-4043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5714-4044 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4378-4045 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5795-4045 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5848-4046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4978-4047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5395-4048 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5715-4048 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-4049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5435-4050 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4721-4059 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5715-4062 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4308-4063 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4547-4063 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5788-4063 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5716-4065 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5069-4069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4605-4070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5234-4070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4229-4074 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4228-4074 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5780-4075 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-4078 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-4078 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5183-4078 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5186-4078 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4232-4080 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4377-4080 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-4086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4683-4086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4777-4087 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5718-4090 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5090-4092 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5853-4092 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5305-4097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4621-4098 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4953-4099 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4939-4101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5340-4101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5502-4101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4654-4105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5805-4105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-4106 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4954-4106 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4730-4107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5837-4109 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4449-4112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5723-4113 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4936-4114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5720-4114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4117-4116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4337-4118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5580-4118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5015-4120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5724-4122 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5726-4129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4245-4131 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5428-4133 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4146-4138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4543-4139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5177-4141 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5567-4141 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5800-4141 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5815-4140 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4210-4143 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-4143 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5163-4144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5702-4144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5261-4145 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4854-4146 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5003-4148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5796-4148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5004-4149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5728-4152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5727-4153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4475-4155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4475-4155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4255-4156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5729-4156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4385-4157 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5730-4160 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5206-4163 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4700-4164 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5426-4164 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5731-4166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5569-4167 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5732-4168 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4321-4170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4381-4170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5786-4170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4321-4170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4381-4170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5733-4172 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5641-4172 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5392-4174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5435-4174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5040-4177 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4671-4178 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5184-4181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5346-4181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5632-4181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5813-4182 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-4183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4330-4184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5736-4184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4186-4185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5298-4185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5737-4189 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5755-4190 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5032-4191 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4851-4194 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5158-4194 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4765-4195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5196-4199 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4966-4201 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4966-4200 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4202-4203 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4580-4207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4880-4207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5792-4207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4882-4209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4969-4208 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5561-4208 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-4211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5519-4211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5702-4211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5588-4212 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4474-4217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4500-4217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5221-4216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4500-4217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4499-4216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4492-4218 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4912-4218 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5708-4218 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5712-4218 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-4219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5391-4220 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5744-4220 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5308-4226 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5372-4225 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4957-4230 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4349-4234 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5740-4235 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5459-4239 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-4241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4900-4242 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5167-4242 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5410-4242 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4325-4246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4679-4248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5213-4247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4247-4270 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5743-4249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4836-4250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4892-4250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4256-4251 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4742-4252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4847-4255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5411-4255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5659-4256 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5008-4257 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5657-4257 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4824-4258 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5184-4260 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5741-4260 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5444-4261 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5242-4264 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5242-4263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5791-4267 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5745-4269 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5028-4271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5747-4272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5717-4273 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5695-4276 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5763-4281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-4286 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-4285 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5006-4287 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5378-4289 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5596-4289 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4985-4291 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-4294 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5618-4295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5749-4296 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4287-4299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5750-4300 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4320-4301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4571-4301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5751-4302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5384-4307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5538-4307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5537-4306 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4309-4308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5393-4310 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5851-4313 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5752-4319 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5540-4323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5594-4323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4423-4327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4624-4330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4720-4329 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5347-4329 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5348-4329 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5429-4330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5689-4330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5736-4330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5734-4330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5204-4331 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5430-4332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4912-4331 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5375-4332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5303-4333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4555-4342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4553-4342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5321-4343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4773-4344 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5757-4345 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4899-4346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5078-4346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5078-4346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4912-4347 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4912-4347 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4912-4347 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5397-4348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5403-4349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5781-4349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5831-4349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5758-4352 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5154-4352 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5380-4354 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5759-4355 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4588-4357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5044-4357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5228-4357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5419-4359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5579-4359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4441-4360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4802-4361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5240-4363 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5250-4363 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4428-4364 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4428-4364 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4721-4368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4916-4369 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5199-4369 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5402-4370 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4491-4373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5763-4374 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5259-4376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5381-4379 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5596-4380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5181-4383 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5816-4384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5766-4389 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5764-4391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-4394 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-4398 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4728-4399 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5175-4401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5124-4402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5767-4404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4593-4406 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4874-4411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5770-4415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5771-4417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-4419 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-4418 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5012-4424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4999-4426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5771-4426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5313-4427 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5773-4429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5772-4430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5370-4432 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4689-4434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4883-4434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4689-4434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4628-4435 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-4437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4967-4437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5719-4438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4676-4441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4676-4441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4758-4442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4925-4442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4759-4442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5667-4444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5276-4449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5775-4452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5098-4455 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5820-4455 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5782-4457 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4931-4458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5776-4459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-4460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5672-4460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5155-4460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5751-4462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5833-4463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4537-4464 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4638-4465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5148-4464 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5151-4465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-4467 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4680-4471 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4500-4473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5778-4475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4778-4477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-4483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4490-4487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4490-4486 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4490-4485 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4490-4484 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5015-4491 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5516-4491 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4807-4493 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5779-4495 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5185-4503 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5257-4503 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5568-4505 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4609-4509 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4809-4513 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5261-4513 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5781-4514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5782-4515 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4053-4516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4146-4516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5249-4516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5697-4517 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5489-4521 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5371-4522 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5784-4523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-4526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4144-4528 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5785-4530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4330-4531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4330-4531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5710-4533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5385-4534 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5390-4534 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4836-4536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4892-4536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5283-4541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5743-4543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5752-4544 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5787-4545 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5517-4546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5518-4546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5789-4549 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-4551 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-4551 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5396-4556 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5525-4558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5701-4558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5823-4558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5824-4558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5528-4560 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5611-4572 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4597-4573 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4596-4573 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4932-4576 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4932-4576 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-4577 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5822-4577 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-4577 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-4577 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-4577 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-4577 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5591-4582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5637-4583 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4584-4585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4800-4585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5793-4585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5795-4587 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4747-4588 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5148-4589 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5269-4595 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4664-4597 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4664-4596 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5796-4600 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5798-4604 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5799-4606 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4806-4610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5483-4610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5588-4610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5636-4610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5739-4610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5638-4611 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5061-4613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5639-4613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5468-4615 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4870-4617 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5324-4617 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5477-4617 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5626-4618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5663-4618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4782-4619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5664-4619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5801-4621 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4645-4622 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4981-4628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5622-4630 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5802-4631 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5529-4632 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5111-4633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5252-4633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5226-4635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5804-4636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4801-4639 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4669-4646 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4651-4649 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4666-4649 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5131-4649 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4666-4649 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5805-4653 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5511-4655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-4658 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4813-4658 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5247-4661 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5331-4663 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4745-4665 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5808-4667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-4676 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4927-4677 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5260-4679 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5144-4681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5188-4682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5814-4685 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-4688 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5811-4689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4753-4696 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5816-4701 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5817-4703 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5817-4704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4753-4712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5818-4715 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5820-4718 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5147-4721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5145-4721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5460-4721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5353-4727 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5821-4729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5835-4730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4804-4732 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4621-4734 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5832-4741 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5522-4744 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5150-4747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5687-4747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5775-4750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4931-4761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5468-4761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4979-4764 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4978-4763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5213-4766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5628-4776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5550-4779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4809-4781 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5664-4782 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5376-4783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5670-4783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5828-4784 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5176-4785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5826-4786 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5680-4788 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5325-4790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4813-4792 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5285-4792 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5239-4794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5827-4798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5661-4800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-4802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-4802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4996-4803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5829-4805 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5636-4806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5536-4808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5201-4810 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5780-4810 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5300-4814 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5309-4815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5080-4832 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5316-4832 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5414-4832 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5500-4832 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5082-4834 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5003-4840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5003-4840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5730-4842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4905-4844 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5811-4848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5152-4849 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-4850 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5798-4850 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-4850 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5158-4851 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4894-4855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4856-4857 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5810-4857 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5839-4857 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4971-4865 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4972-4865 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5515-4867 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5140-4869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5594-4869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5832-4872 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4905-4877 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4905-4878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5254-4879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5086-4883 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5073-4884 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5292-4889 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5724-4890 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5836-4902 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5628-4905 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5312-4906 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5241-4909 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5837-4910 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5173-4911 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5204-4912 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5605-4912 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5375-4912 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5425-4920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4945-4920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4946-4922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5394-4922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5496-4922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5766-4922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5704-4931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5729-4931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5789-4931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4934-4933 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5838-4936 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5673-4948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5839-4951 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5646-4952 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5102-4957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5590-4959 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5640-4959 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5711-4959 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4969-4961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5223-4960 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5480-4961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5560-4961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5561-4961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5685-4961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5220-4960 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5684-4960 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5513-4960 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5487-4964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5390-4965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5286-4966 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5455-4966 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5840-4967 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5841-4968 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5164-4970 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5165-4970 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5469-4973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5314-4974 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5842-4975 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5841-4976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5127-4979 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5592-4979 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5126-4979 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5373-4979 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5374-4978 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5166-4982 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5551-4986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4994-4992 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4994-4991 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4995-4990 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5248-4997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5259-4997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5831-5003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5843-5005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5610-5006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5655-5006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5398-5006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5657-5008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5783-5008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5750-5010 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5301-5011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5633-5012 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5844-5016 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5845-5019 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5846-5019 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5549-5023 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5100-5024 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5680-5030 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5663-5032 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5847-5033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5262-5036 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5146-5037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5092-5039 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5246-5041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5809-5042 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5650-5048 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4993-5053 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5767-5053 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5523-5057 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5074-5066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5850-5077 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5492-5079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5343-5081 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5852-5081 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5851-5087 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5854-5091 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5773-5096 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5361-5109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5554-5109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5754-5117 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5584-5122 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5400-5130 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5154-5136 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5606-5137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5758-5168 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5290-5176 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5854-5202 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5232-5210 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5500-5216 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5349-5217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5451-5224 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5716-5225 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5467-5272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5294-5281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5243-5299 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5438-5360 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5598-5364 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5723-5380 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5612-5398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5504-5413 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5748-5421 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5558-5434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5453-5694 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5654-5477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5585-5479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5733-5490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5555-5498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5254-5510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5669-5510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5785-5511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5591-5524 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5823-5527 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5454-5544 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5575-5635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5601-5603 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5613-5611 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5769-5621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5641-5643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5816-5653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5745-5667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5765-5682 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5840-5756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5842-5785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2590-5957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6066-5957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6054-5958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6086-5958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5962-5959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5962-5959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6045-5959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6122-5959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6130-5959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6150-5959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4416-5960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 140-5961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6081-5961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6081-5961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6047-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6154-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6184-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6184-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4134-5963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6058-5963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6095-5963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-5963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3009-5964 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3140-5964 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5994-5966 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-5967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 264-5967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5856-5967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5866-5967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6165-5968 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-5968 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6238-5968 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6054-5969 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6082-5969 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5990-5970 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6145-5970 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6162-5970 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6169-5970 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6218-5970 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6037-5971 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6068-5971 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6244-5971 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6253-5971 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6069-5972 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6074-5972 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6086-5972 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6111-5972 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6193-5972 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-5974 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4134-5974 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6155-5973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5985-5974 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-5974 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4795-5975 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6165-5975 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6190-5975 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6051-5976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6171-5976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6047-5977 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6053-5977 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6154-5977 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6175-5977 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-5978 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6188-5978 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2666-5979 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6087-5980 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6232-5980 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6184-5981 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6233-5981 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5992-5982 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6100-5982 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6103-5982 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6214-5982 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6017-5984 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6017-5983 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-5984 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6140-5983 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6100-5985 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3503-5986 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6177-5986 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5992-5987 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6117-5987 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6188-5987 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6188-5987 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6196-5987 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6055-5988 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6251-5988 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-5989 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6190-5989 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5996-5990 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6007-5990 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6056-5990 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6145-5990 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6169-5990 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6028-5991 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6112-5991 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-5992 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6117-5992 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6196-5992 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5855-5993 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5869-5993 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5868-5993 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6016-5993 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6010-5994 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6009-5994 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6066-5994 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6066-5994 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6022-5995 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6249-5995 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6189-5996 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5862-5997 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6084-5997 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6084-5997 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6007-5998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6134-5998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6000-5999 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6246-5999 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5522-6197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6006-6001 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6115-6001 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6157-6001 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 805-6003 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6072-6002 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-6002 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6165-6002 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6165-6002 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6165-6002 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6132-6004 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6164-6004 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-6004 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6171-6005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6190-6005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6174-6006 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6164-6008 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6238-6008 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6135-6011 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6143-6011 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6178-6011 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6016-6012 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6066-6012 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6051-6013 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6171-6013 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6136-6014 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6136-6014 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6186-6014 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6186-6014 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1762-6015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5474-6015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5855-6016 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5867-6016 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6064-6016 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6063-6016 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6002-6017 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6002-6017 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6216-6018 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6235-6018 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6239-6018 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6137-6020 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6137-6019 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6139-6020 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6139-6019 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5860-6021 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6035-6024 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6035-6023 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6094-6024 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6023 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6024 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6250-6024 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5858-6025 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5857-6025 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6070-6026 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6071-6026 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6172-6026 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6091-6027 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6104-6027 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6104-6027 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6142-6027 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6030-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6030-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6113-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5856-6029 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6124-6029 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6124-6029 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6124-6029 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6252-6029 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6079-6030 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6079-6030 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5855-6031 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5856-6032 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4994-6033 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3103-6035 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6076-6034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6077-6033 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6249-6034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6248-6033 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6095-6035 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6094-6035 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6055-6036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6055-6036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6055-6036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6113-6036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6112-6036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6073-6037 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6085-6037 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6243-6037 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6253-6037 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5864-6038 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5870-6038 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6138-6038 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6217-6038 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4913-6042 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-6041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5858-6040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5857-6040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6199-6039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6220-6042 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6220-6041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6104-6043 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6104-6043 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-6043 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-6043 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5863-6044 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6234-6044 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6069-6045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6130-6045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6121-6046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6153-6046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6213-6046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6159-6048 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6210-6048 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6167-6049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6188-6049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6056-6050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6146-6050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6169-6050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6194-6050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1069-6128 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6229-6051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6229-6051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6148-6052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6168-6052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-6053 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6074-6054 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6091-6055 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6091-6055 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6251-6055 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6152-6056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6166-6056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6099-6057 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6100-6058 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-6058 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-6058 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6061-6060 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6061-6059 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6210-6060 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6210-6059 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6127-6061 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6127-6061 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6070-6065 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6146-6065 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6161-6065 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6240-6065 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5861-6066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5867-6066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6215-6066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6073-6067 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6083-6069 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6083-6069 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6130-6069 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6158-6069 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6176-6069 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-6069 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6245-6069 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6071-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6182-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6079-6071 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6079-6071 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6200-6071 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-6072 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6242-6073 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6253-6073 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6180-6074 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6236-6074 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6121-6075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6149-6075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6177-6075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6098-6076 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6099-6077 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-6078 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6190-6078 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-6079 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-6079 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6084-6080 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6214-6080 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6240-6080 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 141-6082 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6085-6081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6085-6081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6086-6082 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6111-6083 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6158-6083 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6176-6083 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-6083 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6236-6083 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6161-6084 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6240-6084 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6143-6085 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6143-6085 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6253-6085 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6245-6086 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6232-6087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6089 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6089 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6088 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6088 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5859-6090 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6142-6091 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6099-6093 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6097-6092 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5870-6095 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6100-6094 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-6095 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6100-6094 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5860-6096 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4135-6101 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6107-6097 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6140-6098 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6103-6100 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6214-6100 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6217-6101 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-6102 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6134-6102 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6132-6105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6173-6105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-6105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6156-6106 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6156-6106 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6174-6106 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-6107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6118-6109 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6124-6108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6124-6109 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5861-6110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6172-6112 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6187-6113 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6208-6112 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6207-6113 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6150-6114 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6176-6114 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6186-6114 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-6114 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6157-6115 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6247-6115 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6122-6116 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6175-6116 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6120-6118 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6124-6118 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-6119 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-6119 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6224-6120 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6134-6123 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6218-6123 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5866-6124 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5869-6124 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5868-6124 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5862-6126 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6220-6126 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6250-6126 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6129-6127 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6159-6129 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6158-6130 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5863-6131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6192-6131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6234-6131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6155-6133 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6143-6135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6144-6137 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6220-6137 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5864-6138 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6161-6138 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6147-6139 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6182-6139 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6182-6139 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6187-6139 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6185-6141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6195-6141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6195-6143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6220-6144 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6160-6146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6169-6146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6240-6146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6172-6147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6183-6148 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6161-6151 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6161-6151 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6194-6152 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6184-6154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6184-6154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-6154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6233-6154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6157-6156 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6226-6157 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6176-6158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-6158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-6158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5865-6160 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5864-6161 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6182-6161 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6240-6161 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6239-6162 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2241-6163 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1197-6165 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6190-6165 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-6165 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5865-6166 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6194-6167 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6232-6168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5866-6170 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 36-6205 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 35-6204 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6225-6171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6231-6171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5859-6172 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6205-6174 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6216-6174 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6218-6174 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-6175 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-6176 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6178-6177 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6213-6177 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5863-6181 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6246-6181 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5859-6182 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6193-6186 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5865-6188 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6189-6188 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1196-6190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6231-6190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6183-6191 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6232-6191 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6234-6192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6026-6202 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6026-6201 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6251-6209 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5867-6211 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6145-6218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5858-6219 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5857-6219 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5862-6220 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5861-6223 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6229-6225 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-6226 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5869-6228 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5868-6227 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-6229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-6229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 805-6230 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 323-6233 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5870-6237 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6253-6241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6235-6247 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5860-6248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 35-5899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 35-5923 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 146-5871 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 146-5924 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 180-5900 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 180-5925 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 380-5926 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 459-5872 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 459-5901 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 617-5902 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 760-5873 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 760-5903 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 921-5874 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 921-5904 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 939-5875 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 940-5927 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 939-5941 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 940-5951 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1003-5876 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1003-5905 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1042-5928 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-5929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1266-5952 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1464-5877 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1536-5942 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1536-5953 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1601-5878 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1601-5906 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1936-5907 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2089-5879 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2186-5930 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2186-5943 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2249-5880 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2467-5908 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2467-5931 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2666-5932 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-5933 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2771-5881 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2785-5882 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2786-5909 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-5883 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-5910 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-5884 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-5911 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-5934 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-5944 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2901-5885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2917-5886 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2917-5912 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2968-5913 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2969-5935 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2969-5945 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-5887 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-5914 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3180-5888 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3180-5915 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4578-3199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1499-3504 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3616-5889 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3616-5916 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3615-5936 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3615-5946 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-5890 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3881-5937 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-5891 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-5917 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4049-5892 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-5893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-5918 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4106-5894 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4134-5938 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4135-5947 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4276-5895 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4292-5954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4551-5896 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4551-5919 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4664-5939 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4664-5948 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-5897 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-5920 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-5898 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-5921 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-5940 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-5949 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-5955 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-5922 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-5950 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-5956 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6203-6128 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% INFO    : 
% INFO    : === Line Capacity UB Model Notes ===
% INFO    : Updated Thermal Rating: on line 4647-1 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2186
% INFO    : Updated Thermal Rating: on line 5244-1 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 1682-2 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2441
% INFO    : Updated Thermal Rating: on line 1673-3 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 2303-3 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 700-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 3939-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 5046-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 4413-5 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2779-6 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1398
% INFO    : Updated Thermal Rating: on line 2780-7 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 884
% INFO    : Updated Thermal Rating: on line 470-9 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 11-10 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24078
% INFO    : Updated Thermal Rating: on line 11-10 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24078
% INFO    : Updated Thermal Rating: on line 30-11 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 2929-11 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 2181-12 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 4017-12 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4019-12 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60355
% INFO    : Updated Thermal Rating: on line 1225-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 2874-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 4595-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 4955-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5230-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 2874-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 4595-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 2906-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 4124-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 4455-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 249-16 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 337-16 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 5834-17 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 3727-18 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 5094-19 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 3727-20 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5369
% INFO    : Updated Thermal Rating: on line 1354-21 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 1598-21 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 1843-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5023-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 1157-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 2703-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 3425-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 144-24 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 1282-24 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 490-25 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1048
% INFO    : Updated Thermal Rating: on line 2093-25 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 612-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1866-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2731
% INFO    : Updated Thermal Rating: on line 2602-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 2922-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 3339-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4632-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 2922-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 2684-28 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 3892-28 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 2887-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 3321-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3321-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 144-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 1553-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4841-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 150-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 3162-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3692-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4741-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 150-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 3729-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 4746-33 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3441
% INFO    : Updated Thermal Rating: on line 4858-34 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9629
% INFO    : Updated Thermal Rating: on line 5229-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5515-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 730-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4462
% INFO    : Updated Thermal Rating: on line 1229-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 5809-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 1229-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 2251-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4595-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 1484-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 2765-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3668
% INFO    : Updated Thermal Rating: on line 2724-43 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4689
% INFO    : Updated Thermal Rating: on line 3488-44 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4322-44 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5097-45 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38027
% INFO    : Updated Thermal Rating: on line 1085-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 2194-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 3305-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 1085-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 5363-48 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 1223-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 2345-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 470-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 1676-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3553-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 4629-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 3553-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 4629-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 166-52 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 5489-52 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 3349-53 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 2769-54 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 373-55 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53862
% INFO    : Updated Thermal Rating: on line 5098-57 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 142-59 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 1652-59 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1124
% INFO    : Updated Thermal Rating: on line 2476-60 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 3525-60 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 2228-61 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 2634-61 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 2048-62 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 2950-62 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 996
% INFO    : Updated Thermal Rating: on line 371-63 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 3081-63 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 4607-65 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 4607-65 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 889
% INFO    : Updated Thermal Rating: on line 1546-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 2292-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 3249-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 3030-67 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 2883-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 4537-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5151-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 4610-69 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5099-70 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303410
% INFO    : Updated Thermal Rating: on line 2165-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3145-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5100-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1625
% INFO    : Updated Thermal Rating: on line 3145-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4964-75 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 2084-75 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1945
% INFO    : Updated Thermal Rating: on line 2344-77 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 240-78 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3471
% INFO    : Updated Thermal Rating: on line 4562-78 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90076
% INFO    : Updated Thermal Rating: on line 630-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 1871-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on line 2410-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1510
% INFO    : Updated Thermal Rating: on line 4077-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16079
% INFO    : Updated Thermal Rating: on line 630-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 4076-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18009
% INFO    : Updated Thermal Rating: on line 680-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 803-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 2073-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 2129-84 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 3802-84 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 5103-85 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 2809-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 3511-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 3771-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 4346-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 3771-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 1617-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1706-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 3642-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5559-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 2496-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 4226-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 5104-90 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21404
% INFO    : Updated Thermal Rating: on line 3727-91 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 653-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4056-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 5729-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 2137-93 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 3768-94 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1339
% INFO    : Updated Thermal Rating: on line 5844-94 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 283-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 1174-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 5705-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 4110-96 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 3001-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 4176-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4445-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 3001-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 1252-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 3517-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 4652-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2633-99 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 2634-99 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 552-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 1194-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1195-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 1904-101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4449-101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 1479-102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5495
% INFO    : Updated Thermal Rating: on line 1964-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2487-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4281-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 1964-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2208-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1225
% INFO    : Updated Thermal Rating: on line 2272-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on line 3262-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 5070-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 3979-108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 3978-108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 633-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 677-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 765-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5203-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 5207-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 4740-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 481-110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 719-111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 4442-111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 1168-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1009
% INFO    : Updated Thermal Rating: on line 1656-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 2296-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 5314-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 1169-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 1655-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 2296-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 1654-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 3521-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 3994-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 1244-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 1247-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 5409-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5531-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 4964-118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4034
% INFO    : Updated Thermal Rating: on line 1001-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4557-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 1001-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 2703-120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 5234-121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 5461-121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 5106-122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1677
% INFO    : Updated Thermal Rating: on line 5106-123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1677
% INFO    : Updated Thermal Rating: on line 5107-124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 1264-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 1263-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 4309-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5738-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 179-127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13220
% INFO    : Updated Thermal Rating: on line 2746-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 4259-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 5296-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on line 5742-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 901
% INFO    : Updated Thermal Rating: on line 2746-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 5295-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 788-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29203
% INFO    : Updated Thermal Rating: on line 2195-132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 2734-132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 1709-133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 1885-136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4815-136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 626-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 3048-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4527-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5185-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 3557-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4751-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 185-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 1652-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 2218-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 2219-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 3891-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5725-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 3891-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 1553-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 1560-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16510
% INFO    : Updated Thermal Rating: on line 3693-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5046-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on line 5665-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 1560-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4881
% INFO    : Updated Thermal Rating: on line 2721-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1470
% INFO    : Updated Thermal Rating: on line 3372-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2245
% INFO    : Updated Thermal Rating: on line 4602-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2077
% INFO    : Updated Thermal Rating: on line 2721-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1470
% INFO    : Updated Thermal Rating: on line 3372-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2247
% INFO    : Updated Thermal Rating: on line 4603-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2074
% INFO    : Updated Thermal Rating: on line 4981-147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on line 480-148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 4242-149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1995-150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 942
% INFO    : Updated Thermal Rating: on line 4268-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4520-151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 4702-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 156-151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3575-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5484-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 5726-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 5485-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 5109-155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16165
% INFO    : Updated Thermal Rating: on line 689-157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 4745-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7261
% INFO    : Updated Thermal Rating: on line 5810-157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1058
% INFO    : Updated Thermal Rating: on line 1727-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2764-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 2839-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3692-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 4623-162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 4669-162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 2223-164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7864
% INFO    : Updated Thermal Rating: on line 2223-163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7864
% INFO    : Updated Thermal Rating: on line 1410-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 1590-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3618-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 3785-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 4179-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 4496-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 5143-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 5193-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 5410-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 3449-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 5854-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5110-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 2570-170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5167
% INFO    : Updated Thermal Rating: on line 5590-170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1501
% INFO    : Updated Thermal Rating: on line 1563-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 4621-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5801-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 1563-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on line 5679-172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2348
% INFO    : Updated Thermal Rating: on line 5113-173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8279
% INFO    : Updated Thermal Rating: on line 445-174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 5369-174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 1944-174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 5153-175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 5168-175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3471
% INFO    : Updated Thermal Rating: on line 4719-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2959
% INFO    : Updated Thermal Rating: on line 5122-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3941
% INFO    : Updated Thermal Rating: on line 916-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11544
% INFO    : Updated Thermal Rating: on line 1449-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3780
% INFO    : Updated Thermal Rating: on line 1493-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 3467-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1551
% INFO    : Updated Thermal Rating: on line 4937-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2172
% INFO    : Updated Thermal Rating: on line 4942-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5543
% INFO    : Updated Thermal Rating: on line 5674-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2118
% INFO    : Updated Thermal Rating: on line 917-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9717
% INFO    : Updated Thermal Rating: on line 1449-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4305
% INFO    : Updated Thermal Rating: on line 1449-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3667
% INFO    : Updated Thermal Rating: on line 4940-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11985
% INFO    : Updated Thermal Rating: on line 4941-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14102
% INFO    : Updated Thermal Rating: on line 994-180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31961
% INFO    : Updated Thermal Rating: on line 2107-180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169660
% INFO    : Updated Thermal Rating: on line 994-180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31961
% INFO    : Updated Thermal Rating: on line 5114-181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 4411-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16578
% INFO    : Updated Thermal Rating: on line 5115-183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 1036-184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3370
% INFO    : Updated Thermal Rating: on line 5388-185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1163
% INFO    : Updated Thermal Rating: on line 5116-186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3901
% INFO    : Updated Thermal Rating: on line 5406-187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1466
% INFO    : Updated Thermal Rating: on line 2900-188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 2248-189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 5604-189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5117-190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23633
% INFO    : Updated Thermal Rating: on line 2750-191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 4838-191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 317-192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5098-192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2504-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 2780-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 5337-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3215-195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3377
% INFO    : Updated Thermal Rating: on line 3215-196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3235
% INFO    : Updated Thermal Rating: on line 321-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 573-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53974
% INFO    : Updated Thermal Rating: on line 935-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 321-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 831-198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1760-198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 5118-199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 392-202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 1074-202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 685
% INFO    : Updated Thermal Rating: on line 834-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1051
% INFO    : Updated Thermal Rating: on line 1925-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 2069-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 2719-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 2992-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 834-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 1925-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on line 392-206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 1689-206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5137-206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 563-207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 563-207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 5587-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 5852-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 3930-209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 1797-211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 4839-210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 1797-211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 525-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19602
% INFO    : Updated Thermal Rating: on line 1182-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 1420-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 1738-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 1885-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 4071-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4915-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 1990-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 5420-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 1518-217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 1582-217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 2769-218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23039
% INFO    : Updated Thermal Rating: on line 5121-219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on line 5119-220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 255-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 2045-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 4400-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 2314-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on line 4154-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 2314-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 5122-224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24440
% INFO    : Updated Thermal Rating: on line 3833-226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17970
% INFO    : Updated Thermal Rating: on line 3833-225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17970
% INFO    : Updated Thermal Rating: on line 1550-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 1550-227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 422-229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 3141-229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 4565-229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 422-229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 2490-230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48541
% INFO    : Updated Thermal Rating: on line 520-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 1869-232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on line 4887-232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 3670-234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 504-236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 1016-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 3945-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 2697-238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 5017-238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 2381-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4610-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5447-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1618
% INFO    : Updated Thermal Rating: on line 5739-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 360-240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4561-240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 697-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 4453-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 5498-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 1689-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 5692-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 3155-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 3356-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 1928-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 2355-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5124-245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 282-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 479-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 756-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2322
% INFO    : Updated Thermal Rating: on line 2451-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 4733-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on line 2115-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 3568-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 1272-250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1627-250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2263-250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 2946-251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 4013-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5116-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1070
% INFO    : Updated Thermal Rating: on line 3517-253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 3517-253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 1118-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3823-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 4642-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2181
% INFO    : Updated Thermal Rating: on line 559-255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 1687-255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4169-256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 4558-256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 1114-258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1871
% INFO    : Updated Thermal Rating: on line 768-259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 1460-259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11497
% INFO    : Updated Thermal Rating: on line 5125-261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5067-264 : Rate A, Rate B, Rate C , 2275.0, 2275.0, 2275.0 -> 1648
% INFO    : Updated Thermal Rating: on line 733-265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7450
% INFO    : Updated Thermal Rating: on line 1906-268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 2680-268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 549-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5288-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 1414-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 1701-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 4450-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2987
% INFO    : Updated Thermal Rating: on line 4842-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1519
% INFO    : Updated Thermal Rating: on line 5255-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5802-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 4450-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3057
% INFO    : Updated Thermal Rating: on line 1944-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 1944-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 745-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 986-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 1059-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 746-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 1058-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 2987-279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 2468-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4955-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 5085-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 2468-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 1263-281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 5722-283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16188
% INFO    : Updated Thermal Rating: on line 448-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 2670-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32529
% INFO    : Updated Thermal Rating: on line 3645-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 5126-286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306461
% INFO    : Updated Thermal Rating: on line 965-287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 2323-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 2912-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 4634-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 5436-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 2796-290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4503
% INFO    : Updated Thermal Rating: on line 2172-291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 2631-291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 3155-291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5205-291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 292-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3677
% INFO    : Updated Thermal Rating: on line 480-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 1569-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 1244-294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 1304-296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 1756-297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3394
% INFO    : Updated Thermal Rating: on line 4323-298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 2166-299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8155
% INFO    : Updated Thermal Rating: on line 5129-301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 1345-302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 1345-302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 197-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4594-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 5747-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 197-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4594-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 4836-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5411-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 695-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4689-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 3897-306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 2483-307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4938-307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 1310-308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 4582-308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on line 1638-310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2898
% INFO    : Updated Thermal Rating: on line 1638-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 5623-311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3363
% INFO    : Updated Thermal Rating: on line 3152-312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24326
% INFO    : Updated Thermal Rating: on line 2642-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2640
% INFO    : Updated Thermal Rating: on line 5162-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 5161-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 1036-315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 5131-315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15203
% INFO    : Updated Thermal Rating: on line 2289-316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 5288-316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5290-316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4334
% INFO    : Updated Thermal Rating: on line 2289-316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 3297-317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 3275-318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5314
% INFO    : Updated Thermal Rating: on line 5132-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22178
% INFO    : Updated Thermal Rating: on line 1258-320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 1657-320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 835-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1681
% INFO    : Updated Thermal Rating: on line 2311-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 3127-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 3147-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4571-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2311-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 3127-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 3147-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 3127-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 4150-322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11556
% INFO    : Updated Thermal Rating: on line 4151-322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11556
% INFO    : Updated Thermal Rating: on line 2312-324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2963
% INFO    : Updated Thermal Rating: on line 1682-324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2641
% INFO    : Updated Thermal Rating: on line 522-325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 521-325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 1845-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 2610-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 2925-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 4117-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 5377-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4117-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 1795-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 1795-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 2272-329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3207
% INFO    : Updated Thermal Rating: on line 2272-329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4803
% INFO    : Updated Thermal Rating: on line 4397-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 4656-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23670
% INFO    : Updated Thermal Rating: on line 4749-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 1368-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 3684-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 1011-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 1615-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 2549-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 4768-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 5267-334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 1138-335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 2824-336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 4928-336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 871
% INFO    : Updated Thermal Rating: on line 2504-337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 2646-337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 1700-338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 1864-338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3297-339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 3501-339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 5804-339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3063-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3385-341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3238-342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 3888-342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5408-342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 1865-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4526-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 5300-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 676-345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 1731-345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 1283-346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 5457-346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 4926-347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 444-348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 3382-348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 3774-350 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2026
% INFO    : Updated Thermal Rating: on line 4602-349 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1636
% INFO    : Updated Thermal Rating: on line 3774-349 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2043
% INFO    : Updated Thermal Rating: on line 4603-350 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1634
% INFO    : Updated Thermal Rating: on line 885-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2695-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3014
% INFO    : Updated Thermal Rating: on line 5849-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 5136-354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 1359-355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 358-356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2802
% INFO    : Updated Thermal Rating: on line 1355-357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 3151-357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 3878-357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 2300-358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 3030-358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5139-358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5527
% INFO    : Updated Thermal Rating: on line 5618-358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1680
% INFO    : Updated Thermal Rating: on line 1689-359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 4023-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 4561-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1216
% INFO    : Updated Thermal Rating: on line 4929-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 5157-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 2447-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 490-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 5113-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3419
% INFO    : Updated Thermal Rating: on line 5112-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3460
% INFO    : Updated Thermal Rating: on line 4399-364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 4741-365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12708
% INFO    : Updated Thermal Rating: on line 864-369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 3011-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 416
% INFO    : Updated Thermal Rating: on line 3081-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 3551-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 3664-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 1174-375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 1780-375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 2582-375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 2100-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 2104-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2104-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 652-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2329-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 2773-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 401-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 1257-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 1537-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 1909-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4092-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 4901-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 5020-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 4901-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5020-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 1938-380 : Rate A, Rate B, Rate C , 2040.0, 2040.0, 2040.0 -> 1087
% INFO    : Updated Thermal Rating: on line 2771-380 : Rate A, Rate B, Rate C , 1487.0, 1487.0, 1487.0 -> 1128
% INFO    : Updated Thermal Rating: on line 2771-380 : Rate A, Rate B, Rate C , 1487.0, 1487.0, 1487.0 -> 1127
% INFO    : Updated Thermal Rating: on line 4292-380 : Rate A, Rate B, Rate C , 2040.0, 2040.0, 2040.0 -> 1979
% INFO    : Updated Thermal Rating: on line 4012-381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 5280-381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 2430-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 3697-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 5425-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 942-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3799-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 942-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3799-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 2441-384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 5233-384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5761-384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 2930-385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5778-385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 3031-386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13045
% INFO    : Updated Thermal Rating: on line 1596-387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 2944-387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 2712-388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 3538-388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1405-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6238
% INFO    : Updated Thermal Rating: on line 1882-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 3854-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4689-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 1404-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6629
% INFO    : Updated Thermal Rating: on line 4598-390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5730-390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 1725-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 1823-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 2330-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 2471-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 3940-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5608-392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 1913-393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 395-394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12255
% INFO    : Updated Thermal Rating: on line 1792-395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1953
% INFO    : Updated Thermal Rating: on line 4567-395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 1792-395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1958
% INFO    : Updated Thermal Rating: on line 3871-396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 4088-396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 2399-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3850-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 5196-398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 854-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 2243-400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2790-400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2306-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 2814-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 2774-403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 5174-403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2298-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 3293-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1859
% INFO    : Updated Thermal Rating: on line 1084-405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on line 1025-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 1867-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 4013-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 2362-407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 2457-407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 2818-408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 3927-409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 487-410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 1063-410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2155
% INFO    : Updated Thermal Rating: on line 1870-411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3197-411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 1637-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 2048-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 3240-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 4080-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 1146-413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 1146-413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4193-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 5144-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60637
% INFO    : Updated Thermal Rating: on line 1247-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 3672-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4446-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8876
% INFO    : Updated Thermal Rating: on line 862-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3678-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 4128-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 3741-418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4314-419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5147-419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 5145-419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 5145-420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 3554-421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8736
% INFO    : Updated Thermal Rating: on line 1483-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1483-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1567-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 3411-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4021-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 4533-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 1567-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 4021-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 4021-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 5146-426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8185
% INFO    : Updated Thermal Rating: on line 1156-427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 4682-428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 3873-429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1739
% INFO    : Updated Thermal Rating: on line 5211-429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4352
% INFO    : Updated Thermal Rating: on line 3873-429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 1666-429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 3297-431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 3207-432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 4008-432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 884-433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5888
% INFO    : Updated Thermal Rating: on line 1450-434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 5476-434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 987-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 2846-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 3063-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5274-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 3063-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 3987-436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5704-436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 2551-437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 2984-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 1673-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 2219-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 5011-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5150-440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25776
% INFO    : Updated Thermal Rating: on line 5148-441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 2758-442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4216-442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 1558-443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 1651-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 2032-443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 4875-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 5339-443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1672
% INFO    : Updated Thermal Rating: on line 1651-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 2032-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on line 4875-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2767
% INFO    : Updated Thermal Rating: on line 3594-447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 1234-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 2907-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 3983-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 2907-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 2763-450 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 899
% INFO    : Updated Thermal Rating: on line 5156-451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 462-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2339-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 2699-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3713-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 2339-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 3440-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 5157-454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 4066-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4777
% INFO    : Updated Thermal Rating: on line 4066-455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4695
% INFO    : Updated Thermal Rating: on line 4245-457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6068
% INFO    : Updated Thermal Rating: on line 3174-460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1465
% INFO    : Updated Thermal Rating: on line 4021-461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5483-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 5158-463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3473
% INFO    : Updated Thermal Rating: on line 2712-465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4634
% INFO    : Updated Thermal Rating: on line 5160-466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11716
% INFO    : Updated Thermal Rating: on line 2185-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5279
% INFO    : Updated Thermal Rating: on line 3481-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 606
% INFO    : Updated Thermal Rating: on line 3561-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 2185-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5207
% INFO    : Updated Thermal Rating: on line 3480-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 3561-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 2185-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5279
% INFO    : Updated Thermal Rating: on line 2987-470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 977-471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 3345-471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 3744-471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on line 4297-474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 4298-474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 2174-475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 3875-475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5576-476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 3763-477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 3763-477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 4045-478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 647-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 1835-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 3578-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22978
% INFO    : Updated Thermal Rating: on line 976-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 1568-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on line 2148-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 2168-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 3156-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 1569-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 2169-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 2170-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2196
% INFO    : Updated Thermal Rating: on line 2014-482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 2509-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 5443-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2109
% INFO    : Updated Thermal Rating: on line 5599-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6697
% INFO    : Updated Thermal Rating: on line 5604-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7777
% INFO    : Updated Thermal Rating: on line 965-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 641
% INFO    : Updated Thermal Rating: on line 4174-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 3545-485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5161-486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 1030-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 1063-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 658-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1016
% INFO    : Updated Thermal Rating: on line 3639-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 2263-489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 2618-489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 2203-490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 3571-492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 5086-492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2158-498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 2457-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 2562-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5201-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 3979-503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 3978-503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 741-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 1282-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 1817-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1243
% INFO    : Updated Thermal Rating: on line 5123-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27851
% INFO    : Updated Thermal Rating: on line 5363-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1243
% INFO    : Updated Thermal Rating: on line 2667-506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 4342-506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 5164-507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 5165-507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 3982-508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 1564-509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 5230-509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5620-510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5621-510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3093-512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34920
% INFO    : Updated Thermal Rating: on line 2578-513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 2968-514 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 2232
% INFO    : Updated Thermal Rating: on line 2969-514 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2175
% INFO    : Updated Thermal Rating: on line 1082-515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 2587-515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 1195-516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5456-517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 2267-518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 3213-518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 565-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 4198-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 4310-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 1407-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2890-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 2926-522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 3673-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1260
% INFO    : Updated Thermal Rating: on line 3838-522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 4266-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5658-522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1557
% INFO    : Updated Thermal Rating: on line 2926-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 1132-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 1922-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 2957-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 3036-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 3316-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 4248-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 4693-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 4769-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5556-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 5700-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 4692-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on line 3537-527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5617
% INFO    : Updated Thermal Rating: on line 529-528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3553
% INFO    : Updated Thermal Rating: on line 1355-528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 1843-528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1085-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3109
% INFO    : Updated Thermal Rating: on line 532-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113138
% INFO    : Updated Thermal Rating: on line 1397-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 1397-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 3880-534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1527
% INFO    : Updated Thermal Rating: on line 3880-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1549
% INFO    : Updated Thermal Rating: on line 668-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 1356-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 2879-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39543
% INFO    : Updated Thermal Rating: on line 3459-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 5682-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on line 5683-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2989
% INFO    : Updated Thermal Rating: on line 668-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 3459-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 5539-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 651-537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 1321-537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1357-537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 1194-538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 5386-538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 1135-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 2101-540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 1345-541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1745
% INFO    : Updated Thermal Rating: on line 2091-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 2683-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 2986-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7234
% INFO    : Updated Thermal Rating: on line 5776-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1798
% INFO    : Updated Thermal Rating: on line 1685-546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 5169-546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5578-547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 5599-547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 2598-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5133-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 3071-549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5697
% INFO    : Updated Thermal Rating: on line 3200-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1543-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 2734-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3569-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5198-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 1543-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 1193-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 1556-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 3394-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 5707-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 4346-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 4899-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 4346-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 1794-557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20021
% INFO    : Updated Thermal Rating: on line 1138-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 3073-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 3642-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 4375-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2807
% INFO    : Updated Thermal Rating: on line 5409-560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 3001-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 1133-562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 2468-562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 2658-563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4800-563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 857-565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 2981-565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2826
% INFO    : Updated Thermal Rating: on line 857-565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 1015-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 4235-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2446-567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 5806-567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 4536-568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 2311-569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 5031-569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 585-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4217-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 1073-571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 3324-571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 1904-572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4871-572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 1185-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 3890-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4860-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4909-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 3114-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5703-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 1576-575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 2045-575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 1826-576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8751
% INFO    : Updated Thermal Rating: on line 659-577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19054
% INFO    : Updated Thermal Rating: on line 5172-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4152
% INFO    : Updated Thermal Rating: on line 1212-580 : Rate A, Rate B, Rate C , 935.0, 935.0, 935.0 -> 892
% INFO    : Updated Thermal Rating: on line 5037-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2290
% INFO    : Updated Thermal Rating: on line 3040-584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1948
% INFO    : Updated Thermal Rating: on line 1461-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 1157-586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 4986-586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 5278-586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 893
% INFO    : Updated Thermal Rating: on line 2430-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 2494-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 5174-588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5341-589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5693-589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 1525-590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 1524-590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 5175-591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11707
% INFO    : Updated Thermal Rating: on line 3207-592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 4008-592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 4008-592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 2643-593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 5791-596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 3517-597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 1518-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 1853-600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5731-600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 2686-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 5353-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 742-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 1889-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 2061-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 3853-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7133
% INFO    : Updated Thermal Rating: on line 1889-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 2379-607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3944-607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 4326-607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 885-609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4367-609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 5509-611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153231
% INFO    : Updated Thermal Rating: on line 3339-612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 2190-613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5376-613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 3089-614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2771-617 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 639
% INFO    : Updated Thermal Rating: on line 5178-619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9349
% INFO    : Updated Thermal Rating: on line 5182-618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 5037-620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3851
% INFO    : Updated Thermal Rating: on line 5037-621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3667
% INFO    : Updated Thermal Rating: on line 1247-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 4903-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5041-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5246-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2048
% INFO    : Updated Thermal Rating: on line 5836-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 2704-624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 823-625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2405
% INFO    : Updated Thermal Rating: on line 1108-625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 2594-625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5185-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8880
% INFO    : Updated Thermal Rating: on line 5192-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 5183-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 5186-631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99170
% INFO    : Updated Thermal Rating: on line 4231-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 5184-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 1263-635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 4282-635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 2461-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 2541-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5597-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 2792-637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 4570-637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5706-637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 1111-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 3981-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 5160-639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26199
% INFO    : Updated Thermal Rating: on line 1001-648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 842
% INFO    : Updated Thermal Rating: on line 1345-649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1036
% INFO    : Updated Thermal Rating: on line 1345-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 1357-651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 4282-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 1741-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 4458-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 1741-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 4931-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 5789-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on line 1786-654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on line 5189-654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4316
% INFO    : Updated Thermal Rating: on line 3181-655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3577-655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 5227-655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5190-656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 5191-657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2006-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 2752-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 2861-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 4372-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 5162-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 5433-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 1078-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 2191-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5161-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 2173-660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 3763-660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 4118-661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 1211-662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 3870-662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 1211-662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 1625-664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4374
% INFO    : Updated Thermal Rating: on line 1434-665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5248-665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3171
% INFO    : Updated Thermal Rating: on line 5642-666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3297
% INFO    : Updated Thermal Rating: on line 4895-667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 934
% INFO    : Updated Thermal Rating: on line 4468-672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183736
% INFO    : Updated Thermal Rating: on line 4467-671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170060
% INFO    : Updated Thermal Rating: on line 4468-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158275
% INFO    : Updated Thermal Rating: on line 4467-669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158275
% INFO    : Updated Thermal Rating: on line 1822-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 2530-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 2555-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 2766-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 2230-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1698
% INFO    : Updated Thermal Rating: on line 2769-675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 4851-675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 5819-675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4851-675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 1508-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 2025-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 5414-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 1392-677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 3849-677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4916-677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 3380-678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 3063-679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 1756-680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 2822-682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 5399-682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 4938-684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 2681-685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 3561-686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1443
% INFO    : Updated Thermal Rating: on line 3561-686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1444
% INFO    : Updated Thermal Rating: on line 3561-686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on line 1319-687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5195-687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 3902-688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 2001-689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 5416-689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 4206-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2348-693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27692
% INFO    : Updated Thermal Rating: on line 2349-694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30077
% INFO    : Updated Thermal Rating: on line 5488-695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 891-697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1255
% INFO    : Updated Thermal Rating: on line 2814-697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 741-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 4031-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5581-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on line 4686-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 3896-708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 4317-707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 5196-708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 5722-708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 4317-707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 4029-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5416-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 5839-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 4857-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 5721-711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 2616-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2731-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 2912-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2138
% INFO    : Updated Thermal Rating: on line 3314-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 5436-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 3314-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 5197-718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13344
% INFO    : Updated Thermal Rating: on line 5232-719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4444-720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 962-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5007-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 1186-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3037-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 1930-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2340
% INFO    : Updated Thermal Rating: on line 721-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 3567-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 5815-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 5348-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 988
% INFO    : Updated Thermal Rating: on line 5532-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 4329-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 4284-726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3054
% INFO    : Updated Thermal Rating: on line 5198-727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1403
% INFO    : Updated Thermal Rating: on line 5634-727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5354
% INFO    : Updated Thermal Rating: on line 1392-728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 1904-728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 5677-728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 2847-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4279-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7550
% INFO    : Updated Thermal Rating: on line 4743-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 4278-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7550
% INFO    : Updated Thermal Rating: on line 4743-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 2182-731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 2453-731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 2723-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 4138-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4146-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5508-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 5580-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 2182-731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 4138-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 4591-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on line 3349-734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3349-733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 3349-735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 928-736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on line 928-736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 972-737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5199-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 5200-739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2162-740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3789
% INFO    : Updated Thermal Rating: on line 4832-743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 1562-744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308785
% INFO    : Updated Thermal Rating: on line 2533-747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 3660-747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 4777-747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 5474-747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 750-749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 5043-749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 3667-750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3617-751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2859
% INFO    : Updated Thermal Rating: on line 3429-752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 487-753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19914
% INFO    : Updated Thermal Rating: on line 2012-754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 2043-754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 5054-754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 1220-755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 4092-755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 4956-755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 1477-757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 3441-757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4689-758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 2746-761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 2957-761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 4387-761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1432
% INFO    : Updated Thermal Rating: on line 5700-761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3633-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39366
% INFO    : Updated Thermal Rating: on line 3881-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22986
% INFO    : Updated Thermal Rating: on line 5203-766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 1847-769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6823
% INFO    : Updated Thermal Rating: on line 1557-770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3311-770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 3809-771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 4032-771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 340-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 5121-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4814
% INFO    : Updated Thermal Rating: on line 666-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 1302-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2221-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2103
% INFO    : Updated Thermal Rating: on line 2317-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 3060-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4115-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1768
% INFO    : Updated Thermal Rating: on line 4548-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 5412-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2192
% INFO    : Updated Thermal Rating: on line 5624-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 1302-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 3060-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 1758-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2121
% INFO    : Updated Thermal Rating: on line 1878-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6273
% INFO    : Updated Thermal Rating: on line 3717-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6192
% INFO    : Updated Thermal Rating: on line 4852-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 5647-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 1878-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6068
% INFO    : Updated Thermal Rating: on line 5649-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 2302-779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 923-780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 4832-780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 904-781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 2726-781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 3765-781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 905-781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 953-785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5006
% INFO    : Updated Thermal Rating: on line 953-784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9266
% INFO    : Updated Thermal Rating: on line 953-783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5965
% INFO    : Updated Thermal Rating: on line 5206-786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 1761-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 2516-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 5208-790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 1129-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 3424-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 3463-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4327-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 4542-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 4779-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 5808-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 5829-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7106
% INFO    : Updated Thermal Rating: on line 1341-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 4542-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 2629-797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2728
% INFO    : Updated Thermal Rating: on line 2349-798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 4623-798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 4905-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 4843-800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 4905-800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 480-801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 927-801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 823-802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4138
% INFO    : Updated Thermal Rating: on line 3124-802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7080
% INFO    : Updated Thermal Rating: on line 4403-802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2128
% INFO    : Updated Thermal Rating: on line 1223-803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 1989-804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 3494-804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 4407-804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2555
% INFO    : Updated Thermal Rating: on line 1989-804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3678-811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6082
% INFO    : Updated Thermal Rating: on line 1766-812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 3147-812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 1613-815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 4926-815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 850-816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1013
% INFO    : Updated Thermal Rating: on line 5614-816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 986
% INFO    : Updated Thermal Rating: on line 5609-816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 4936-818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2909
% INFO    : Updated Thermal Rating: on line 4442-819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4925-819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5296-821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19262
% INFO    : Updated Thermal Rating: on line 5295-820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2442-823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 825-824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8292
% INFO    : Updated Thermal Rating: on line 4325-824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 1072-825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5535-825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 4832-828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 2134-829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4554
% INFO    : Updated Thermal Rating: on line 4248-830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 2012-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 1200-833 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1075
% INFO    : Updated Thermal Rating: on line 2786-833 : Rate A, Rate B, Rate C , 1987.0, 1987.0, 1987.0 -> 1524
% INFO    : Updated Thermal Rating: on line 2719-834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on line 3094-836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 4045-836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 4679-837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4845
% INFO    : Updated Thermal Rating: on line 5215-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7650
% INFO    : Updated Thermal Rating: on line 1678-839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 4639-839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 2236-840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3027-840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3380-840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3452-841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 3657-841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 4778-841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 2958-843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 5406-842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5545-842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12012
% INFO    : Updated Thermal Rating: on line 5214-844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 2953-845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4124-845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 4832-846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on line 5210-847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27427
% INFO    : Updated Thermal Rating: on line 1883-848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10493
% INFO    : Updated Thermal Rating: on line 1883-848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10493
% INFO    : Updated Thermal Rating: on line 1552-849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5044-849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 2999-851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on line 2999-853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1560
% INFO    : Updated Thermal Rating: on line 2999-852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1648
% INFO    : Updated Thermal Rating: on line 1924-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3797-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 3956-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5547-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 5268-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 5548-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 3002-855 : Rate A, Rate B, Rate C , 736.0, 736.0, 736.0 -> 460
% INFO    : Updated Thermal Rating: on line 4028-856 : Rate A, Rate B, Rate C , 1932.0, 1932.0, 1932.0 -> 1807
% INFO    : Updated Thermal Rating: on line 4028-856 : Rate A, Rate B, Rate C , 1932.0, 1932.0, 1932.0 -> 1827
% INFO    : Updated Thermal Rating: on line 1822-857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 1822-857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 1142-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5690-861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2104
% INFO    : Updated Thermal Rating: on line 2718-862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 3111-862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5757-862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 2971-863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 4911-863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3854
% INFO    : Updated Thermal Rating: on line 2379-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 3450-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 3904-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 4326-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5222-870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5219-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4217-871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 1159-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 5392-873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2340
% INFO    : Updated Thermal Rating: on line 1613-874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 2254-874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 4494-874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12351
% INFO    : Updated Thermal Rating: on line 2489-876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1532
% INFO    : Updated Thermal Rating: on line 2489-875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2339
% INFO    : Updated Thermal Rating: on line 4649-877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 4651-877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 4598-878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5260-878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 4598-878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1859
% INFO    : Updated Thermal Rating: on line 2667-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 4342-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 2254-881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 2254-880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 3393-884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3732-884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 4762-884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2662
% INFO    : Updated Thermal Rating: on line 5051-884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 5670-885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5773-885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 4783-884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 2210-888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 5297-888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 5449-889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1499
% INFO    : Updated Thermal Rating: on line 5226-890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 3307-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 4680-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 5557-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 2186-893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21471
% INFO    : Updated Thermal Rating: on line 3006-892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27618
% INFO    : Updated Thermal Rating: on line 4126-892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42153
% INFO    : Updated Thermal Rating: on line 1312-895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4057
% INFO    : Updated Thermal Rating: on line 2040-896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 5224-896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 2538-897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5882
% INFO    : Updated Thermal Rating: on line 3380-898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 4152-898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 4783-899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5081-906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 5851-906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11095
% INFO    : Updated Thermal Rating: on line 4721-907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 3939-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 4164-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 3380-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 4152-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 3574-910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20979
% INFO    : Updated Thermal Rating: on line 5802-911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 5230-912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 3647-913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 5803-913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 2485-914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4441-914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 1754-915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 5233-918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2782-921 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1573
% INFO    : Updated Thermal Rating: on line 4864-921 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1434
% INFO    : Updated Thermal Rating: on line 2782-921 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1578
% INFO    : Updated Thermal Rating: on line 4864-921 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1435
% INFO    : Updated Thermal Rating: on line 5234-922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 4832-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 1803-924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5672-924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4460-924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5170-925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5753-925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 5562-927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 1348-928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 2561-928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 1348-928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2561-928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2398-930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4207
% INFO    : Updated Thermal Rating: on line 3839-930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 2706-931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 5324-931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 2173-932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1060
% INFO    : Updated Thermal Rating: on line 1792-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1792-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 4120-934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5818-935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 2812-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5675-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2118-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 2551-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on line 3211-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3548-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5479-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 5644-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2551-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 2559-945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 1533-946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on line 1533-946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 3338-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3916-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2462-947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3916-947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3307-949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2856
% INFO    : Updated Thermal Rating: on line 2708-950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3338
% INFO    : Updated Thermal Rating: on line 3321-950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 5502-950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3338
% INFO    : Updated Thermal Rating: on line 2214-951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 2812-951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 2597-952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 3432-952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 1045-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 1103-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2361-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 3072-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 1518-956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 1374-957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4421
% INFO    : Updated Thermal Rating: on line 2301-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 2316-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 2913-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 4411-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 986
% INFO    : Updated Thermal Rating: on line 4638-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 4874-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 4411-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on line 1219-959 : Rate A, Rate B, Rate C , 1611.0, 1611.0, 1611.0 -> 1101
% INFO    : Updated Thermal Rating: on line 1243-959 : Rate A, Rate B, Rate C , 1567.0, 1567.0, 1567.0 -> 1311
% INFO    : Updated Thermal Rating: on line 2150-959 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2245
% INFO    : Updated Thermal Rating: on line 2150-959 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2244
% INFO    : Updated Thermal Rating: on line 4909-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 5241-961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31602
% INFO    : Updated Thermal Rating: on line 2949-962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3706
% INFO    : Updated Thermal Rating: on line 1184-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 5703-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16188
% INFO    : Updated Thermal Rating: on line 2948-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3916-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 4439-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 2740-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 3460-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 721
% INFO    : Updated Thermal Rating: on line 3769-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 4013-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 4050-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5311-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4437
% INFO    : Updated Thermal Rating: on line 2741-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 3768-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 973-969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1015
% INFO    : Updated Thermal Rating: on line 2949-969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 3315-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5786-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 2263-973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 2604-973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 4097-973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 1852-973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 4812-973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 2773-975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 3051-977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41442
% INFO    : Updated Thermal Rating: on line 3345-977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5242-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 2960-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 3365-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 5718-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 3365-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 5362-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3365-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 2245-981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 2649-981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2773-981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 3809-981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4032-981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 4282-981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 4729-981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 4282-981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 1115-983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 4524-983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 991
% INFO    : Updated Thermal Rating: on line 5553-983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 5783-983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 5008-983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 2482-984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 2822-984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2171-985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 3838-985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 1384-987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 2716-987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 1206-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8928
% INFO    : Updated Thermal Rating: on line 3201-990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 3469-991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 2306-992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1165
% INFO    : Updated Thermal Rating: on line 2297-993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4380
% INFO    : Updated Thermal Rating: on line 3740-993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3280
% INFO    : Updated Thermal Rating: on line 4797-993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3203
% INFO    : Updated Thermal Rating: on line 4796-993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5279
% INFO    : Updated Thermal Rating: on line 3559-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 3775-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 1351-997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2073-997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 5238-998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 1090-999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 2112-999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 1043-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 1083-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 1256-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 5279-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2777
% INFO    : Updated Thermal Rating: on line 4959-1004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1475
% INFO    : Updated Thermal Rating: on line 5713-1004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 889
% INFO    : Updated Thermal Rating: on line 4638-1005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 2128-1006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 2905-1006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1730-1009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 5355-1009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 5481-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 3928-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3362
% INFO    : Updated Thermal Rating: on line 4451-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90021
% INFO    : Updated Thermal Rating: on line 5243-1014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13732
% INFO    : Updated Thermal Rating: on line 2214-1015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 2863-1015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 2863-1015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 1253-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2161
% INFO    : Updated Thermal Rating: on line 3458-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 852
% INFO    : Updated Thermal Rating: on line 5239-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83047
% INFO    : Updated Thermal Rating: on line 5358-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2287
% INFO    : Updated Thermal Rating: on line 1253-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1560
% INFO    : Updated Thermal Rating: on line 5239-1018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 4791-1019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 1756-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 4147-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 2277-1021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2545
% INFO    : Updated Thermal Rating: on line 4289-1021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 973-1022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 2627-1022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10350
% INFO    : Updated Thermal Rating: on line 973-1022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 973-1022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 1358-1024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154266
% INFO    : Updated Thermal Rating: on line 1358-1023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151981
% INFO    : Updated Thermal Rating: on line 5392-1025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 5244-1026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on line 3344-1028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 3344-1027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 4513-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 2159-1030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2424
% INFO    : Updated Thermal Rating: on line 2809-1030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 1482-1032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8516
% INFO    : Updated Thermal Rating: on line 1482-1031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6981
% INFO    : Updated Thermal Rating: on line 1359-1034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 4649-1035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 4649-1036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 4649-1035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 4900-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 2160-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3052-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 4366-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 2160-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3053-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 4365-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 3782-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 877
% INFO    : Updated Thermal Rating: on line 3782-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 3351-1039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3425
% INFO    : Updated Thermal Rating: on line 5013-1039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5192
% INFO    : Updated Thermal Rating: on line 5014-1039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5314
% INFO    : Updated Thermal Rating: on line 4535-1042 : Rate A, Rate B, Rate C , 1566.0, 1566.0, 1566.0 -> 1490
% INFO    : Updated Thermal Rating: on line 4535-1041 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1720
% INFO    : Updated Thermal Rating: on line 4535-1041 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1735
% INFO    : Updated Thermal Rating: on line 1105-1046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5823
% INFO    : Updated Thermal Rating: on line 2278-1046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 3303-1046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 4401-1046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4414-1046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 5175-1046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5690-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 1102-1046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5169
% INFO    : Updated Thermal Rating: on line 5691-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 1104-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6551
% INFO    : Updated Thermal Rating: on line 2667-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 1229-1048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 1229-1048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1001
% INFO    : Updated Thermal Rating: on line 3134-1049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 4981-1049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 5066-1050 : Rate A, Rate B, Rate C , 1917.0, 1917.0, 1917.0 -> 1451
% INFO    : Updated Thermal Rating: on line 5067-1050 : Rate A, Rate B, Rate C , 1917.0, 1917.0, 1917.0 -> 1451
% INFO    : Updated Thermal Rating: on line 1188-1052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9991
% INFO    : Updated Thermal Rating: on line 3168-1052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10322
% INFO    : Updated Thermal Rating: on line 5246-1053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7488
% INFO    : Updated Thermal Rating: on line 2411-1055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 4424-1055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 3201-1056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 4395-1062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 2214-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 2812-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5190-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 5381-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 4997-1065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 2004-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 2267-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 4934-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 5367-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 5034-1070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 5249-1070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 2036-1071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 2665-1071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5554-1071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179912
% INFO    : Updated Thermal Rating: on line 2406-1072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 3003-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 5717-1074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 2220-1075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 3951-1075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 2250-1078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 2752-1078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 2836-1078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 5602-1078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5603-1078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 5833-1078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5313-1082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24008
% INFO    : Updated Thermal Rating: on line 1953-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 2344-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2298-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 4681-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 5553-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 5720-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 1669-1087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 4984-1088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4984-1088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 1940-1089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5574
% INFO    : Updated Thermal Rating: on line 5681-1089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6551
% INFO    : Updated Thermal Rating: on line 1939-1089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 2742-1090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 2511-1091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4356-1091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 1206-1092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 4288-1092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4022
% INFO    : Updated Thermal Rating: on line 1472-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 1471-1095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4258-1098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 1767-1099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 2675-1099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 2298-1100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2017
% INFO    : Updated Thermal Rating: on line 2298-1100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 935
% INFO    : Updated Thermal Rating: on line 3522-1101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 3522-1101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3036
% INFO    : Updated Thermal Rating: on line 4554-1103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1872
% INFO    : Updated Thermal Rating: on line 5251-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113138
% INFO    : Updated Thermal Rating: on line 5577-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5578-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2423-1108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2594-1108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 2423-1108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2746-1110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1807
% INFO    : Updated Thermal Rating: on line 2322-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 3193-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3862
% INFO    : Updated Thermal Rating: on line 5254-1112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28222
% INFO    : Updated Thermal Rating: on line 2450-1114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4506-1114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5083-1114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 3293-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 3577-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 5044-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 5227-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1503
% INFO    : Updated Thermal Rating: on line 5228-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5846-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 3577-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on line 3599-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 3599-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 1958-1118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 2566-1119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on line 1772-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 2502-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 4440-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2826
% INFO    : Updated Thermal Rating: on line 4518-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 2502-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 3547-1122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5255-1122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2753
% INFO    : Updated Thermal Rating: on line 1501-1123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 1919-1123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 2083-1123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 1545-1125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2430
% INFO    : Updated Thermal Rating: on line 4964-1125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 4964-1125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 2566-1126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 2566-1127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2715
% INFO    : Updated Thermal Rating: on line 5257-1128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320583
% INFO    : Updated Thermal Rating: on line 1307-1129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 2321-1130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 4532-1130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3778
% INFO    : Updated Thermal Rating: on line 1384-1131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 3392-1131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 4687-1133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5259-1134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10315
% INFO    : Updated Thermal Rating: on line 1229-1135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 2715-1135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on line 5504-1135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 2457-1137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 5650-1137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 3073-1138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 3748-1138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3356
% INFO    : Updated Thermal Rating: on line 5258-1138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7884
% INFO    : Updated Thermal Rating: on line 3100-1138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 1359-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3245-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 1359-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 2802-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 2984-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5111-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1642
% INFO    : Updated Thermal Rating: on line 5251-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 984
% INFO    : Updated Thermal Rating: on line 5486-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5002-1144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2077
% INFO    : Updated Thermal Rating: on line 5260-1145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 2383-1146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 2842-1146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 5225-1146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 5446-1146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 5449-1146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5267-1146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 5262-1149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 2586-1152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4348-1152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 1815-1153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 3559-1153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 3617-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 3809-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1691
% INFO    : Updated Thermal Rating: on line 2138-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 3021-1157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 3465-1157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2805
% INFO    : Updated Thermal Rating: on line 3506-1157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5551-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5630-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 5668-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 3362-1159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 4743-1159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 5770-1159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5261-1160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1543
% INFO    : Updated Thermal Rating: on line 4793-1164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 4792-1165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3321
% INFO    : Updated Thermal Rating: on line 4793-1166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3234
% INFO    : Updated Thermal Rating: on line 4566-1168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 813
% INFO    : Updated Thermal Rating: on line 5117-1170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 2578-1171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 4984-1172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5595-1172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 2828-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3090-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 3637-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 4199-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2331
% INFO    : Updated Thermal Rating: on line 4223-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 4685-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 5622-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 3090-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 4222-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 5705-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1397
% INFO    : Updated Thermal Rating: on line 3363-1180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3607-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 4052-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8488
% INFO    : Updated Thermal Rating: on line 5699-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 5022-1182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 1192-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43410
% INFO    : Updated Thermal Rating: on line 2650-1185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 5844-1184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3227-1186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 3914-1189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1646
% INFO    : Updated Thermal Rating: on line 5404-1189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 1964-1191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4620-1191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 2143-1192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 2162-1192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1337
% INFO    : Updated Thermal Rating: on line 4158-1192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19301
% INFO    : Updated Thermal Rating: on line 4081-1194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 4318-1195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 5750-1194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 4081-1193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116592
% INFO    : Updated Thermal Rating: on line 3665-1199 : Rate A, Rate B, Rate C , 558.0, 558.0, 558.0 -> 297
% INFO    : Updated Thermal Rating: on line 1520-1200 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1002
% INFO    : Updated Thermal Rating: on line 1520-1200 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 996
% INFO    : Updated Thermal Rating: on line 2785-1200 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 633
% INFO    : Updated Thermal Rating: on line 3388-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4003-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5583-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 4659-1202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 5440-1202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 5439-1202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 4177-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12326
% INFO    : Updated Thermal Rating: on line 4983-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 5092-1204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5166-1204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 2724-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3957-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 3958-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 4420-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 4421-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 3886-1208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 5007-1208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 1988-1208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 3391-1208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 5270-1210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27851
% INFO    : Updated Thermal Rating: on line 2254-1211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 3870-1211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 4136-1211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 2254-1211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 5727-1211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 4609-1213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2918
% INFO    : Updated Thermal Rating: on line 5029-1214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 5718-1214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 3709-1217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 4358-1217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 2660-1218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 2888-1218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 1991-1221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 1811-1222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 2751-1222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10890
% INFO    : Updated Thermal Rating: on line 1351-1223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3858-1223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 3428-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5085-1225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5269-1226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 1247-1228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5413-1229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 1385-1231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 3053-1232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 4439-1232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 3496-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10482
% INFO    : Updated Thermal Rating: on line 4438-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1343-1234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 1653-1234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 2429-1234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 2494-1234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 4348-1235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 4453-1235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 1778-1237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on line 3045-1237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 1778-1237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on line 3604-1239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2368
% INFO    : Updated Thermal Rating: on line 4280-1239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 5242-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5748-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1480
% INFO    : Updated Thermal Rating: on line 5651-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1450
% INFO    : Updated Thermal Rating: on line 3604-1239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 5699-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19617
% INFO    : Updated Thermal Rating: on line 4083-1240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 5552-1244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 1961-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 3312-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 1616-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 1856-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4966
% INFO    : Updated Thermal Rating: on line 1617-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 1855-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6273
% INFO    : Updated Thermal Rating: on line 2873-1247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 3823-1247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 5179-1247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 4289-1249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 4328-1249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 4289-1249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 2264-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4568-1253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10020
% INFO    : Updated Thermal Rating: on line 4626-1253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10362
% INFO    : Updated Thermal Rating: on line 5118-1254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5631-1254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5279-1255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 1657-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 4206-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5495-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1309
% INFO    : Updated Thermal Rating: on line 2339-1261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5281-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 2257-1264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 4716-1264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 4735-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 5549-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5777-1264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 4716-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 4735-1264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 3811-1266 : Rate A, Rate B, Rate C , 1711.0, 1711.0, 1711.0 -> 1648
% INFO    : Updated Thermal Rating: on line 4908-1266 : Rate A, Rate B, Rate C , 1307.0, 1307.0, 1307.0 -> 1080
% INFO    : Updated Thermal Rating: on line 4092-1267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 1512-1268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 2660-1268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5280-1271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 2263-1272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 4216-1273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5221-1273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 5283-1274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1337
% INFO    : Updated Thermal Rating: on line 1547-1277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3201-1277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 1775-1279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 5284-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 3630-1281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 3979-1281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 4793-1284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21546
% INFO    : Updated Thermal Rating: on line 2272-1285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 2712-1285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 3921-1286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27378
% INFO    : Updated Thermal Rating: on line 3920-1286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27596
% INFO    : Updated Thermal Rating: on line 1839-1287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23964
% INFO    : Updated Thermal Rating: on line 2049-1288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 3763-1288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 1633-1289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 5180-1289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4968
% INFO    : Updated Thermal Rating: on line 5791-1289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4252
% INFO    : Updated Thermal Rating: on line 5146-1290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on line 5812-1291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 2012-1292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5205
% INFO    : Updated Thermal Rating: on line 5217-1294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8292
% INFO    : Updated Thermal Rating: on line 5218-1294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 2307-1295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 3944-1295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 3944-1295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 3449-1301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 2033-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4644-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 5843-1303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 1305-1304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4905-1304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 2119-1307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1618
% INFO    : Updated Thermal Rating: on line 2641-1309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1236
% INFO    : Updated Thermal Rating: on line 5824-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5150-1311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on line 5389-1311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 1350-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23302
% INFO    : Updated Thermal Rating: on line 1615-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 3910-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 3347-1313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1835
% INFO    : Updated Thermal Rating: on line 3709-1313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 4846-1313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 5290-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38166
% INFO    : Updated Thermal Rating: on line 2927-1315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 3936-1315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5289-1316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2153
% INFO    : Updated Thermal Rating: on line 2619-1317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5289-1317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5291-1317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on line 1318-1319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5399
% INFO    : Updated Thermal Rating: on line 1987-1319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 2605-1320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 5631-1320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 2605-1320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 2941-1321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 2137-1323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3887
% INFO    : Updated Thermal Rating: on line 2137-1322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5064
% INFO    : Updated Thermal Rating: on line 3431-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 1385-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 4409-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 5589-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 3678-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5652-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5504
% INFO    : Updated Thermal Rating: on line 4045-1328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4533
% INFO    : Updated Thermal Rating: on line 3258-1329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3526-1329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 2101-1330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5243-1330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 4428-1331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11223
% INFO    : Updated Thermal Rating: on line 1667-1332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 4271-1332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 5746-1332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1542-1334 : Rate A, Rate B, Rate C , 2280.0, 2280.0, 2280.0 -> 932
% INFO    : Updated Thermal Rating: on line 3433-1334 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 944
% INFO    : Updated Thermal Rating: on line 1542-1334 : Rate A, Rate B, Rate C , 2280.0, 2280.0, 2280.0 -> 932
% INFO    : Updated Thermal Rating: on line 5105-1335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2802
% INFO    : Updated Thermal Rating: on line 5356-1336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 5832-1336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 2136-1337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 5008-1337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 4110-1338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 5174-1338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2759
% INFO    : Updated Thermal Rating: on line 1846-1343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 1847-1343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 1757-1345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1575
% INFO    : Updated Thermal Rating: on line 5282-1345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 4196-1346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19787
% INFO    : Updated Thermal Rating: on line 3008-1347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 2362-1353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 2362-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 1598-1354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 3878-1355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 1364-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 2359-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 1390-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 1951-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 2623-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2427
% INFO    : Updated Thermal Rating: on line 2691-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 2692-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 2697-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 1389-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5138-1359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4110-1361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 4110-1362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 4475-1363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5360-1364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 3833-1366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22551
% INFO    : Updated Thermal Rating: on line 3833-1365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23186
% INFO    : Updated Thermal Rating: on line 2457-1367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17936
% INFO    : Updated Thermal Rating: on line 5770-1368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 1708-1371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 1714-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 1715-1369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1754
% INFO    : Updated Thermal Rating: on line 1799-1372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26532
% INFO    : Updated Thermal Rating: on line 1383-1373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 3257-1373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7254
% INFO    : Updated Thermal Rating: on line 5294-1373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4688
% INFO    : Updated Thermal Rating: on line 5296-1373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5295-1373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 5311-1375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 2079-1374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 4004-1376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7767
% INFO    : Updated Thermal Rating: on line 1776-1378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 2539-1379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5297-1380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27851
% INFO    : Updated Thermal Rating: on line 2347-1382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3706-1382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8177
% INFO    : Updated Thermal Rating: on line 3916-1382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5238-1382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 4450-1385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2154
% INFO    : Updated Thermal Rating: on line 5277-1385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2005
% INFO    : Updated Thermal Rating: on line 1665-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 2052-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 3275-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 4002-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 5521-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5760-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 2537-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 4001-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 4950-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 5520-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 3412-1390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6474
% INFO    : Updated Thermal Rating: on line 2609-1389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2753-1391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 2660-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 3049-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 3394-1394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5530-1394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 2148-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 3865-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 5142-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 5298-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3193-1396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 4977-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4976-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5299-1399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1462
% INFO    : Updated Thermal Rating: on line 5256-1400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 2566-1400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 5300-1401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28417
% INFO    : Updated Thermal Rating: on line 2344-1402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4328-1403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5595-1403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 5301-1406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1093
% INFO    : Updated Thermal Rating: on line 1953-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 3701-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3864-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 3864-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 1301-1410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 1814-1410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2199
% INFO    : Updated Thermal Rating: on line 4336-1410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 2870-1412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5697
% INFO    : Updated Thermal Rating: on line 3173-1412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5572-1413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7412
% INFO    : Updated Thermal Rating: on line 5803-1414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26199
% INFO    : Updated Thermal Rating: on line 5302-1415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 2238-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 4147-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5797-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 4682-1417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5768-1417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 2483-1418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 2872-1418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 4630-1418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 1823-1419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 1823-1419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 2608-1421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 3235-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 2609-1421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3234-1421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 3674-1422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3794
% INFO    : Updated Thermal Rating: on line 3674-1422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3140
% INFO    : Updated Thermal Rating: on line 3878-1424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on line 3878-1423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 3606-1425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 2009-1426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38069
% INFO    : Updated Thermal Rating: on line 3887-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5305-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29272
% INFO    : Updated Thermal Rating: on line 5306-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29272
% INFO    : Updated Thermal Rating: on line 5308-1428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12455
% INFO    : Updated Thermal Rating: on line 979-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 5029-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 5097-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 5362-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 4003-1430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5320-1430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 4050-1431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4522-1431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 1435-1432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309464
% INFO    : Updated Thermal Rating: on line 1065-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 4539-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11961
% INFO    : Updated Thermal Rating: on line 5035-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 1065-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 930-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 1246-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 1616-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 1774-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2467
% INFO    : Updated Thermal Rating: on line 2538-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1224
% INFO    : Updated Thermal Rating: on line 1781-1437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5310-1438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 1684-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 4225-1440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 2493-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 2735-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4205-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 4698-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5284-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 2493-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2073
% INFO    : Updated Thermal Rating: on line 2735-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 2493-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1356
% INFO    : Updated Thermal Rating: on line 2960-1443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 5798-1443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 1268-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 1324-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2023
% INFO    : Updated Thermal Rating: on line 3049-1444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 3070-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 4585-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 4769-1444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 5673-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 5793-1444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 1449-1447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2231
% INFO    : Updated Thermal Rating: on line 1449-1447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2924
% INFO    : Updated Thermal Rating: on line 5311-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23584
% INFO    : Updated Thermal Rating: on line 3984-1450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8415
% INFO    : Updated Thermal Rating: on line 973-1452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 4803-1454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 4803-1453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 2684-1455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 5284-1455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 3461-1456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 3201-1458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4708
% INFO    : Updated Thermal Rating: on line 4329-1461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3265-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on line 4646-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 4662-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 5017-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 5116-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3691
% INFO    : Updated Thermal Rating: on line 4645-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 5247-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 5089-1464 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 1297
% INFO    : Updated Thermal Rating: on line 1622-1465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 2747-1465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 3527-1465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 5333-1465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 3269-1465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 4887-1466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2533-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 5022-1469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 5749-1469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 3559-1470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 3559-1470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 1709-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 3561-1472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2064
% INFO    : Updated Thermal Rating: on line 1709-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 3035-1473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 4357-1473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5044-1473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 3035-1473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5279-1476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 4945-1477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 3630-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28743
% INFO    : Updated Thermal Rating: on line 1890-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14533
% INFO    : Updated Thermal Rating: on line 2008-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20949
% INFO    : Updated Thermal Rating: on line 2700-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 2943-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 2942-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 5533-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 2516-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 2516-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 2552-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 4176-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 4277-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1572
% INFO    : Updated Thermal Rating: on line 4445-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 5114-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5273-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 5694-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 5268-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 3549-1484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2713
% INFO    : Updated Thermal Rating: on line 4581-1484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1647
% INFO    : Updated Thermal Rating: on line 3366-1484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 4739-1485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3272
% INFO    : Updated Thermal Rating: on line 4739-1485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3532
% INFO    : Updated Thermal Rating: on line 2134-1486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1044
% INFO    : Updated Thermal Rating: on line 4246-1489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5315-1489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 2805-1490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4650
% INFO    : Updated Thermal Rating: on line 1673-1491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 5725-1491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1717-1492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 3015-1495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3691
% INFO    : Updated Thermal Rating: on line 4966-1495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 2605-1500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 2624-1502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4000-1502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 2280-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 3410-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 4061-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 4717-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5069-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4061-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5316-1506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 4832-1507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 3371-1508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 5676-1508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 3076-1509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 3041-1510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 3251-1510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 2421-1511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 5099-1511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4210-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4210-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2112-1514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 3644-1514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 3736-1515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 3893-1515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 4540-1515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3429-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 3736-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 3736-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1459
% INFO    : Updated Thermal Rating: on line 2360-1518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 2602-1518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4044-1518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 5529-1518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 5714-1518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 4044-1518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 3416-1520 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1517
% INFO    : Updated Thermal Rating: on line 4792-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 4793-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 1634-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2414-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3435-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4125-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on line 5188-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 2414-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2327-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 4920-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4919-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4428-1529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5317-1530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 1838-1531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 1781-1532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 2573-1532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 1549-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 1566-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4873-1534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 4938-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 5723-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 4113-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 5448-1535 : Rate A, Rate B, Rate C , 541.0, 541.0, 541.0 -> 443
% INFO    : Updated Thermal Rating: on line 2470-1536 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2406
% INFO    : Updated Thermal Rating: on line 2947-1536 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1759
% INFO    : Updated Thermal Rating: on line 3624-1536 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1245
% INFO    : Updated Thermal Rating: on line 3705-1536 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1191
% INFO    : Updated Thermal Rating: on line 2470-1536 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2405
% INFO    : Updated Thermal Rating: on line 1851-1537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 5020-1537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5368-1537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5853-1537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 2930-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5842-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1981
% INFO    : Updated Thermal Rating: on line 2104-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 3080-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 3545-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5187-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 5368-1540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 4864-1542 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1934
% INFO    : Updated Thermal Rating: on line 1933-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1292
% INFO    : Updated Thermal Rating: on line 3606-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 3977-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 5634-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 3606-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 3527-1547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 2153-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2751
% INFO    : Updated Thermal Rating: on line 2633-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 2153-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2764
% INFO    : Updated Thermal Rating: on line 2633-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 951
% INFO    : Updated Thermal Rating: on line 4181-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5741-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 4181-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5320-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 1837-1553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 3244-1555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 4265-1555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 2745-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 3311-1557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 4676-1561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 1849-1563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109898
% INFO    : Updated Thermal Rating: on line 5501-1563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 1819-1563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6227
% INFO    : Updated Thermal Rating: on line 1850-1563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109898
% INFO    : Updated Thermal Rating: on line 1834-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1984
% INFO    : Updated Thermal Rating: on line 3244-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 3377-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 3244-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 3244-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2014-1567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4376-1570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 4861-1570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 5200-1570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5270-1571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 4434-1573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 4689-1573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5323-1574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 3073-1576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 4335-1576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4454-1576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3736
% INFO    : Updated Thermal Rating: on line 5325-1576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 3950-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5149-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 5698-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 2984-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 1518-1582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 3335-1584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 5326-1584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4368
% INFO    : Updated Thermal Rating: on line 4231-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 5000-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3277-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3108
% INFO    : Updated Thermal Rating: on line 3289-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3384
% INFO    : Updated Thermal Rating: on line 4000-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 5058-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3055
% INFO    : Updated Thermal Rating: on line 5593-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2792
% INFO    : Updated Thermal Rating: on line 3277-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3393
% INFO    : Updated Thermal Rating: on line 3598-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5554
% INFO    : Updated Thermal Rating: on line 5058-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2366
% INFO    : Updated Thermal Rating: on line 2620-1590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5705-1591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 5327-1592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31460
% INFO    : Updated Thermal Rating: on line 5758-1594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 4541-1595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5329-1595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4756-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5345-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 1612-1597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 3930-1597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 2357-1599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 4983-1598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 5404-1599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 4370-1599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 4982-1598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 2770-1600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 2945-1600 : Rate A, Rate B, Rate C , 325.0, 325.0, 325.0 -> 274
% INFO    : Updated Thermal Rating: on line 2771-1601 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1482
% INFO    : Updated Thermal Rating: on line 3433-1601 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1546
% INFO    : Updated Thermal Rating: on line 3938-1601 : Rate A, Rate B, Rate C , 1263.0, 1263.0, 1263.0 -> 622
% INFO    : Updated Thermal Rating: on line 4775-1601 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2287
% INFO    : Updated Thermal Rating: on line 4865-1601 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 996
% INFO    : Updated Thermal Rating: on line 4775-1601 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2289
% INFO    : Updated Thermal Rating: on line 2614-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 3062-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 3426-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 4879-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1858
% INFO    : Updated Thermal Rating: on line 2614-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 3061-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 5330-1605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31538
% INFO    : Updated Thermal Rating: on line 3048-1607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4526-1607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4346-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 4346-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 2628-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 4460-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5156-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 2096-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 2308-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 3321-1612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 3321-1612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 4676-1613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 2121-1614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 3512-1617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 4016-1616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 5568-1616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5771-1616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3371-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 5676-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1866
% INFO    : Updated Thermal Rating: on line 1947-1620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 2691-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 5499-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 5104-1623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 5744-1623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 3961-1624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 5440-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5439-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5645-1626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 2263-1627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 3630-1631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 2010-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85214
% INFO    : Updated Thermal Rating: on line 5399-1633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 3429-1634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 2209-1635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2839
% INFO    : Updated Thermal Rating: on line 5419-1635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6565
% INFO    : Updated Thermal Rating: on line 1857-1636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 5119-1636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 2048-1637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 2531-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 3028-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 3582-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 4127-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 4519-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 2531-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1614
% INFO    : Updated Thermal Rating: on line 4127-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 4519-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 4136-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 4361-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 1808-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4757-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 3134-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 5335-1643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 2545-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2971-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 4757-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 1725-1646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 3409-1646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4460-1646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 1943-1647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 1943-1647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 5337-1648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 2863-1650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 5338-1649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23993
% INFO    : Updated Thermal Rating: on line 1879-1651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7204
% INFO    : Updated Thermal Rating: on line 5463-1653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 5339-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 5340-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 2645-1659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1607
% INFO    : Updated Thermal Rating: on line 2802-1660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 2128-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 3608-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 1792-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 1792-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 2427-1664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 4861-1664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5060-1664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3275-1665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5342-1666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12351
% INFO    : Updated Thermal Rating: on line 5028-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 1945-1668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41198
% INFO    : Updated Thermal Rating: on line 2007-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 3026-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28461
% INFO    : Updated Thermal Rating: on line 3718-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3739-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4232-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 5052-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 5763-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on line 3025-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10795
% INFO    : Updated Thermal Rating: on line 2042-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 4730-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5343-1672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5595
% INFO    : Updated Thermal Rating: on line 3405-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1343
% INFO    : Updated Thermal Rating: on line 4087-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 5011-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 3405-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1351
% INFO    : Updated Thermal Rating: on line 1869-1675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 3152-1675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 3553-1677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 4639-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5308-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 5503-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5749-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 1680-1679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 4521-1679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 2483-1680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 2514-1681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 4627-1681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 3941-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3862
% INFO    : Updated Thermal Rating: on line 5534-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 5662-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 3048-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 3656-1686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 4520-1686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 5335-1688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 5608-1689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 5606-1689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 5348-1691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7473
% INFO    : Updated Thermal Rating: on line 3714-1692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 5349-1693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28260
% INFO    : Updated Thermal Rating: on line 2457-1694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 2457-1694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 2457-1694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 4219-1696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322663
% INFO    : Updated Thermal Rating: on line 4219-1695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322663
% INFO    : Updated Thermal Rating: on line 4216-1697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303410
% INFO    : Updated Thermal Rating: on line 4218-1699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311307
% INFO    : Updated Thermal Rating: on line 4218-1698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311371
% INFO    : Updated Thermal Rating: on line 5337-1700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 4531-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on line 5736-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2676
% INFO    : Updated Thermal Rating: on line 5734-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2708
% INFO    : Updated Thermal Rating: on line 4352-1703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2790-1704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 2790-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 967
% INFO    : Updated Thermal Rating: on line 5303-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5304-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 5350-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7068
% INFO    : Updated Thermal Rating: on line 5461-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 1715-1709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3772
% INFO    : Updated Thermal Rating: on line 2732-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4361
% INFO    : Updated Thermal Rating: on line 3216-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 4073-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13439
% INFO    : Updated Thermal Rating: on line 1714-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3772
% INFO    : Updated Thermal Rating: on line 3216-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1542
% INFO    : Updated Thermal Rating: on line 3933-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 3216-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 3216-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 1716-1711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1716-1713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1716-1710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1716-1712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 2236-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 2253-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on line 3130-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11090
% INFO    : Updated Thermal Rating: on line 4618-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 2253-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 5352-1720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25032
% INFO    : Updated Thermal Rating: on line 5351-1719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25032
% INFO    : Updated Thermal Rating: on line 2238-1721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9016
% INFO    : Updated Thermal Rating: on line 3867-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4634-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 4731-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 5110-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 5107-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 3111-1724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5354-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26199
% INFO    : Updated Thermal Rating: on line 3978-1731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5327-1731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 2805-1732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4341
% INFO    : Updated Thermal Rating: on line 5356-1733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 5357-1734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 1994-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 4015-1736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 4084-1736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4167-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 5570-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 4084-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 3899-1739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3914-1739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5360-1739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 1801-1740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 5527-1740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 1752-1746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1751-1746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1750-1746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2333-1753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 5826-1754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 2332-1754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 2862-1754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7488
% INFO    : Updated Thermal Rating: on line 5533-1753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 2934-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3095-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3099-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5582-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1758-4132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 5358-1759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7924
% INFO    : Updated Thermal Rating: on line 2012-1760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2516-1761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2687-1762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 2313-1763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3869
% INFO    : Updated Thermal Rating: on line 2147-1764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2335-1764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 3269-1765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 2675-1767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4099-1767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 5843-1767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 1784-1767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 2675-1767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4518-1772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 2705-1774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 2322-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 3309-1778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 3570-1778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 3714-1778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 3866-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 3909-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 5121-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 3714-1778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 3031-1779 : Rate A, Rate B, Rate C , 509.0, 509.0, 509.0 -> 421
% INFO    : Updated Thermal Rating: on line 3064-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 566
% INFO    : Updated Thermal Rating: on line 4930-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5193-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 2573-1781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 2982-1781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4935-1781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 5309-1781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 2314-1783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2498-1783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 4953-1784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 4155-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 3462-1786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 4936-1786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 5189-1786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 5838-1786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1337
% INFO    : Updated Thermal Rating: on line 5330-1788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4652-1789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 5384-1789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 4306-1790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4652-1790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3276-1791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4590-1791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 4975-1791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 3973-1792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4295-1792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 3005-1793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 3409-1795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 4898-1795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 3565-1798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37106
% INFO    : Updated Thermal Rating: on line 5452-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 1800-1801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 2394-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4408-1804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4470-1804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 4901-1804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 2758-1807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1879
% INFO    : Updated Thermal Rating: on line 2758-1806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1879
% INFO    : Updated Thermal Rating: on line 3376-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 1937-1809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8785
% INFO    : Updated Thermal Rating: on line 3189-1809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 3932-1809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5420-1809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5583-1809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 5825-1809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 2166-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3579
% INFO    : Updated Thermal Rating: on line 2166-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 2751-1811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 3361-1811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 5283-1811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 3361-1811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4541-1811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5361-1813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16165
% INFO    : Updated Thermal Rating: on line 3441-1815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 5459-1816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5645-1816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 4817-1818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 5372-1818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1822-1820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2468
% INFO    : Updated Thermal Rating: on line 1822-1820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2403
% INFO    : Updated Thermal Rating: on line 5362-1821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 2481-1823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 2565-1823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4007-1823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 3670-1826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 3670-1826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 3014-1827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 3542-1827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 1963-1829 : Rate A, Rate B, Rate C , 1253.0, 1253.0, 1253.0 -> 1246
% INFO    : Updated Thermal Rating: on line 4072-1830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3085-1831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3554-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 4412-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 5769-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 3554-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 4733-1835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on line 5809-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 5426-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 2022-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 2420-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 2854-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 3635-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3938
% INFO    : Updated Thermal Rating: on line 4869-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5318-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 2477-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 2136-1842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 2604-1842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 2023-1843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 2329-1843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4888-1843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 1944-1848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 984
% INFO    : Updated Thermal Rating: on line 2882-1852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4275-1853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 2305-1854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 2502-1854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 2261-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 2427-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 4329-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 2778-1858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 4008-1858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 4743-1859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 3070-1860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on line 3076-1860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 3035-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2313
% INFO    : Updated Thermal Rating: on line 3335-1862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 4025-1862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 4287-1862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 3653-1863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2495
% INFO    : Updated Thermal Rating: on line 4013-1867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1459
% INFO    : Updated Thermal Rating: on line 4510-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 4130-1869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 1730-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 2304-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 3196-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 5142-1872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 5277-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2530
% INFO    : Updated Thermal Rating: on line 5589-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on line 1948-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 2561-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 1822-1875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 2683-1876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1486
% INFO    : Updated Thermal Rating: on line 5370-1877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 3654-1880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 5371-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23584
% INFO    : Updated Thermal Rating: on line 3669-1882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 3855-1882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 4748-1882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on line 5403-1882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4004-1883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 4004-1883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 3746-1884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206236
% INFO    : Updated Thermal Rating: on line 3060-1886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 3060-1887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 4226-1888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 5374-1892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1903-1901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1903-1900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1903-1899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1903-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3875-1902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5063-1902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3970-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 4215-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4258-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4871-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 5276-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5476-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 3984-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 5677-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 3984-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 4457-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 4932-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 4265-1908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 5094-1909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 4783-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5080-1911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 2086-1912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 5653-1912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 2086-1912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 4289-1913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5141-1913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 5320-1913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 5302-1916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 5310-1915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84779
% INFO    : Updated Thermal Rating: on line 5727-1917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1393
% INFO    : Updated Thermal Rating: on line 5181-1919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 3321-1920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 5302-1920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4688
% INFO    : Updated Thermal Rating: on line 3321-1920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 5377-1921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3052
% INFO    : Updated Thermal Rating: on line 5129-1922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 5019-1923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7487
% INFO    : Updated Thermal Rating: on line 3929-1924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 2099-1925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21948
% INFO    : Updated Thermal Rating: on line 3834-1925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5407
% INFO    : Updated Thermal Rating: on line 5434-1926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on line 2326-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59375
% INFO    : Updated Thermal Rating: on line 2195-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 2355-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2408-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 4244-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16129
% INFO    : Updated Thermal Rating: on line 4244-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16129
% INFO    : Updated Thermal Rating: on line 3423-1930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 3423-1930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 1938-1931 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1998
% INFO    : Updated Thermal Rating: on line 1938-1931 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1997
% INFO    : Updated Thermal Rating: on line 3876-1932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 4118-1932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 4118-1932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 5341-1933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 3938-1936 : Rate A, Rate B, Rate C , 1695.0, 1695.0, 1695.0 -> 787
% INFO    : Updated Thermal Rating: on line 4551-1936 : Rate A, Rate B, Rate C , 2362.0, 2362.0, 2362.0 -> 1552
% INFO    : Updated Thermal Rating: on line 4864-1936 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1543
% INFO    : Updated Thermal Rating: on line 4551-1936 : Rate A, Rate B, Rate C , 2362.0, 2362.0, 2362.0 -> 1597
% INFO    : Updated Thermal Rating: on line 4292-1938 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2461
% INFO    : Updated Thermal Rating: on line 2659-1941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 4101-1942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4433
% INFO    : Updated Thermal Rating: on line 2210-1943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 2929-1943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 3133-1944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 4066-1943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1008
% INFO    : Updated Thermal Rating: on line 5369-1944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 2210-1943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 4066-1943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 3502-1949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 2048-1950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 2697-1951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2745
% INFO    : Updated Thermal Rating: on line 2890-1952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 2913-1952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5381-1954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83671
% INFO    : Updated Thermal Rating: on line 3311-1955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 5286-1956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2664
% INFO    : Updated Thermal Rating: on line 5726-1957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2684-1958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 3272-1959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3311-1959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 3452-1960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5284
% INFO    : Updated Thermal Rating: on line 4431-1960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 4908-1963 : Rate A, Rate B, Rate C , 1750.0, 1750.0, 1750.0 -> 873
% INFO    : Updated Thermal Rating: on line 4908-1963 : Rate A, Rate B, Rate C , 2197.0, 2197.0, 2197.0 -> 873
% INFO    : Updated Thermal Rating: on line 4908-1963 : Rate A, Rate B, Rate C , 1192.0, 1192.0, 1192.0 -> 806
% INFO    : Updated Thermal Rating: on line 3013-1965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3608-1966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 3517-1967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 1980-1978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1980-1977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1980-1976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1980-1975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1980-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1980-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3814-1979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4488-1979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3294-1982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4112-1983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 4320-1985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 4757-1985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 4342-1986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 2248-1987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 3227-1988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4257-1989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 3932-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 5192-1991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 5371-1991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 5386-1993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 3200-1994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5735-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 2305-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 2314-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 3203-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4190-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 4518-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 4749-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 4190-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 4518-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 4518-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on line 5388-1999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4945-2000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 4074-2002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 4877-2002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4074-2003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 4878-2003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5367-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13395
% INFO    : Updated Thermal Rating: on line 2679-2005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on line 5518-2006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 3718-2007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 4648-2010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89765
% INFO    : Updated Thermal Rating: on line 4161-2011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 5181-2011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 2817-2012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5054-2012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 5215-2012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 4457-2013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 3410-2014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 4310-2015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7529
% INFO    : Updated Thermal Rating: on line 5845-2019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 5846-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 5467-2021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5013
% INFO    : Updated Thermal Rating: on line 3186-2023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4945-2023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 2709-2026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4293-2026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 2548-2027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 4743-2027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 5655-2028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 5397-2029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4107
% INFO    : Updated Thermal Rating: on line 5396-2030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4651
% INFO    : Updated Thermal Rating: on line 5399-2031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1021
% INFO    : Updated Thermal Rating: on line 2093-2032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 2688-2032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 3382-2032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 2944-2034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 4756-2034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 4885-2035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3711
% INFO    : Updated Thermal Rating: on line 5564-2036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5565-2036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4125-2037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 5188-2037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5315-2038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5569-2038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5570-2038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2434-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 2061-2040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 2824-2040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3749-2040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 5222-2040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 5224-2040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 5219-2040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 4730-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 3869-2043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 2447-2046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 2666-2046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on line 2223-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 2235-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 2274-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 2841-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 2224-2050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6148
% INFO    : Updated Thermal Rating: on line 5403-2051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3779
% INFO    : Updated Thermal Rating: on line 2984-2053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 2984-2053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 4812-2055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 5306-2055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 3516-2057 : Rate A, Rate B, Rate C , 2368.0, 2368.0, 2368.0 -> 2335
% INFO    : Updated Thermal Rating: on line 4775-2057 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1679
% INFO    : Updated Thermal Rating: on line 3515-2057 : Rate A, Rate B, Rate C , 2368.0, 2368.0, 2368.0 -> 2335
% INFO    : Updated Thermal Rating: on line 4775-2057 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1679
% INFO    : Updated Thermal Rating: on line 3619-2060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 3619-2059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 3619-2058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 5400-2068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6804
% INFO    : Updated Thermal Rating: on line 2127-2070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 2735-2070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 4698-2070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 4094-2071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 935
% INFO    : Updated Thermal Rating: on line 3840-2073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 3858-2073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 5582-2073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 2805-2076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5731
% INFO    : Updated Thermal Rating: on line 3973-2077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4402-2077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 4970-2080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 5721-2080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4970-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 2279-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1391
% INFO    : Updated Thermal Rating: on line 3258-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 4964-2084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 791
% INFO    : Updated Thermal Rating: on line 5406-2085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15304
% INFO    : Updated Thermal Rating: on line 3048-2086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 3611-2086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 4051-2086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 4526-2086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4468-2089 : Rate A, Rate B, Rate C , 1662.0, 1662.0, 1662.0 -> 1168
% INFO    : Updated Thermal Rating: on line 4908-2089 : Rate A, Rate B, Rate C , 1659.0, 1659.0, 1659.0 -> 1605
% INFO    : Updated Thermal Rating: on line 3619-2090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1375
% INFO    : Updated Thermal Rating: on line 3619-2090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1397
% INFO    : Updated Thermal Rating: on line 2733-2091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 2616-2092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2203-2093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 2094-1496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 3139-2096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 2449-2098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 5466-2098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 2486-2101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 4303-2101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2151
% INFO    : Updated Thermal Rating: on line 4303-2101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2151
% INFO    : Updated Thermal Rating: on line 4381-2102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 4381-2102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 3113-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 2204-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3080-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 4699-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 5187-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 3080-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 4391-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5764-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 2876-2106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5624-2106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 2112-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1937
% INFO    : Updated Thermal Rating: on line 2112-2108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3363
% INFO    : Updated Thermal Rating: on line 2112-2111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18630
% INFO    : Updated Thermal Rating: on line 2112-2110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18082
% INFO    : Updated Thermal Rating: on line 2618-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 3644-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4163-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 5115-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5206-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 3900-2114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 5407-2114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 3001-2115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 3664-2116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 3699-2116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 5408-2117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 3269-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 3013-2119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 2994-2120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13742
% INFO    : Updated Thermal Rating: on line 2463-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3175-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 3177-2123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 3448-2123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 4183-2123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 3410-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 3525-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 2767-2125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 3352-2125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 3793-2125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 4059-2125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5389-2125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 3793-2125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 5387-2125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 5382-2127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 2678-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 3608-2129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 3954-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4014-2129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4673-2133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 4192-2136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5962
% INFO    : Updated Thermal Rating: on line 4193-2136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 2497-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 3225-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1217
% INFO    : Updated Thermal Rating: on line 5253-2138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 5356-2138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 5523-2138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 2430-2142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3993
% INFO    : Updated Thermal Rating: on line 2430-2142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3993
% INFO    : Updated Thermal Rating: on line 1911-2143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 2759-2143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41324
% INFO    : Updated Thermal Rating: on line 3195-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3544-2148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 4351-2148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2805
% INFO    : Updated Thermal Rating: on line 5298-2148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 5562-2148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4350-2148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2872
% INFO    : Updated Thermal Rating: on line 4162-2151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 5740-2151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5410-2152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19026
% INFO    : Updated Thermal Rating: on line 3542-2154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 5411-2155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 3654-2156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 3542-2157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5552-2157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 1997-2158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1682
% INFO    : Updated Thermal Rating: on line 1997-2158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 2162-2161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6326
% INFO    : Updated Thermal Rating: on line 5316-2162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 2069-2166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 3208-2166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 4755-2166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4374
% INFO    : Updated Thermal Rating: on line 5270-2166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 4754-2166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4930
% INFO    : Updated Thermal Rating: on line 5686-2171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2780-2172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4433-2172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3410-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 3525-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 3875-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 3410-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 3525-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4649-2177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 4649-2177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 2223-2179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 2223-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 2682-2180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38967
% INFO    : Updated Thermal Rating: on line 4017-2181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 2881-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 3876-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 2188-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 2295-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13307
% INFO    : Updated Thermal Rating: on line 3097-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 3296-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1379
% INFO    : Updated Thermal Rating: on line 3708-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6195
% INFO    : Updated Thermal Rating: on line 4807-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1656
% INFO    : Updated Thermal Rating: on line 2188-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4807-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1987
% INFO    : Updated Thermal Rating: on line 4807-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2563
% INFO    : Updated Thermal Rating: on line 2326-2186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50437
% INFO    : Updated Thermal Rating: on line 2325-2186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40928
% INFO    : Updated Thermal Rating: on line 5414-2187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 5415-2189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1207
% INFO    : Updated Thermal Rating: on line 3923-2190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 5432-2192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27888
% INFO    : Updated Thermal Rating: on line 5416-2193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9817
% INFO    : Updated Thermal Rating: on line 2803-2196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5585
% INFO    : Updated Thermal Rating: on line 3812-2202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4933-2202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 5764-2204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 2988-2205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 3138-2206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8140
% INFO    : Updated Thermal Rating: on line 3137-2206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8731
% INFO    : Updated Thermal Rating: on line 4021-2207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 3133-2210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 5420-2211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5423-2212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 2501-2213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 2871-2215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 5178-2215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 5182-2215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4808-2220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5425-2220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2841-2223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 2226-1498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25273
% INFO    : Updated Thermal Rating: on line 4164-2226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5426-2226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8499
% INFO    : Updated Thermal Rating: on line 5427-2227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 5062-2228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 2499-2231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 2521-2231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 3763-2232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 3763-2232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 2992-2233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 3835-2233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5068-2233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 5271-2233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 3763-2235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 2796-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on line 3520-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 2796-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 4014-2238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 3489-2240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 3489-2240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 2858-2240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 4026-2243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 3326-2244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 887
% INFO    : Updated Thermal Rating: on line 3459-2244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1388
% INFO    : Updated Thermal Rating: on line 2568-2246 : Rate A, Rate B, Rate C , 1617.0, 1617.0, 1617.0 -> 1286
% INFO    : Updated Thermal Rating: on line 3153-2246 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 926
% INFO    : Updated Thermal Rating: on line 3154-2246 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 926
% INFO    : Updated Thermal Rating: on line 5335-2248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2636
% INFO    : Updated Thermal Rating: on line 2901-2249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5892
% INFO    : Updated Thermal Rating: on line 2395-2250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4649-2251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 4771-2251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5427-2252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130845
% INFO    : Updated Thermal Rating: on line 2485-2254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 3897-2257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 4834-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6978
% INFO    : Updated Thermal Rating: on line 4833-2258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6978
% INFO    : Updated Thermal Rating: on line 5429-2260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3593
% INFO    : Updated Thermal Rating: on line 2272-2262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3315
% INFO    : Updated Thermal Rating: on line 2618-2263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5115-2263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5648-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2205
% INFO    : Updated Thermal Rating: on line 4651-2266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5613-2266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 4416-2266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1653
% INFO    : Updated Thermal Rating: on line 5269-2266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 953
% INFO    : Updated Thermal Rating: on line 4330-2269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3147-2271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 2208-2272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 797
% INFO    : Updated Thermal Rating: on line 4489-2274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 5432-2275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27888
% INFO    : Updated Thermal Rating: on line 4021-2276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1548
% INFO    : Updated Thermal Rating: on line 4021-2276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1548
% INFO    : Updated Thermal Rating: on line 3410-2280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 3566-2281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 5689-2284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 4012-2286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4595-2286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 5433-2288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 4785-2289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 3801-2289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 2605-2291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 3226-2291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 2826-2292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 3414-2292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 4570-2292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5617-2292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 2827-2293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308785
% INFO    : Updated Thermal Rating: on line 5434-2294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12712
% INFO    : Updated Thermal Rating: on line 3292-2298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5746-2300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 5830-2300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4060
% INFO    : Updated Thermal Rating: on line 5207-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 3308-2302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4091-2302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 5301-2303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 2731-2304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 2343-2306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on line 3868-2306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on line 5623-2306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 2492-2308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 3104-2308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1978
% INFO    : Updated Thermal Rating: on line 3857-2308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1053
% INFO    : Updated Thermal Rating: on line 5062-2308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5616-2308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 3857-2308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 5615-2308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 3401-2308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 2287-2310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 4767-2310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5534-2312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 2921-2314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4091-2314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5036-2314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 5036-2314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 4874-2316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 3218-2317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 4127-2318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 4519-2318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 3647-2319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 5435-2320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 3363-2321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 3079-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4316
% INFO    : Updated Thermal Rating: on line 4388-2327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 3083-2330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 5440-2331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on line 3195-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3247-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 3415-2335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4615-2335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 4702-2335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 5572-2335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 3415-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4615-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3063-2338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 3469-2338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2857-2339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 2427-2340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 2887-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 4442-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 2887-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5820-2342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 3353-2344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 4206-2344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4316-2345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 5102-2345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 916
% INFO    : Updated Thermal Rating: on line 5442-2346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2283
% INFO    : Updated Thermal Rating: on line 2570-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 2976-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 4297-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 2570-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 4298-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 4622-2349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 2570-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 4017-2353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1684
% INFO    : Updated Thermal Rating: on line 2814-2354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 4348-2354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 3559-2356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 5762-2357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4518-2358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3252
% INFO    : Updated Thermal Rating: on line 5197-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 977
% INFO    : Updated Thermal Rating: on line 4342-2361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 5444-2362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 5445-2363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 2376-2374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2376-2373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2376-2372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2376-2371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2376-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24882
% INFO    : Updated Thermal Rating: on line 2376-2369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2634-2375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 3895-2375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2356
% INFO    : Updated Thermal Rating: on line 5427-2375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3895-2375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 4181-2377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 2758-2378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 4017-2378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 3113-2380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 3551-2380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 3713-2380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 5447-2381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 3698-2381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5346-2382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 3664-2384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 2511-2385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 2591-2386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2239
% INFO    : Updated Thermal Rating: on line 3664-2386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4905-2387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 3303-2388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10014
% INFO    : Updated Thermal Rating: on line 4993-2389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2752-2390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 3639-2390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 2392-2391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23551
% INFO    : Updated Thermal Rating: on line 5472-2391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 2909-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 3331-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5547-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 2909-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5548-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2824-2393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4928-2394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 2501-2395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 2643-2396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 2779-2397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 2779-2397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 3325-2399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23670
% INFO    : Updated Thermal Rating: on line 3850-2399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 5457-2400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38032
% INFO    : Updated Thermal Rating: on line 3012-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 3678-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 3721-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4637
% INFO    : Updated Thermal Rating: on line 5652-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 3678-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 4705-2403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148594
% INFO    : Updated Thermal Rating: on line 4705-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151981
% INFO    : Updated Thermal Rating: on line 5458-2404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 2468-2405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 2982-2405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 5737-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 4721-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 2412-2408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77773
% INFO    : Updated Thermal Rating: on line 4544-2408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 3216-2409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3391
% INFO    : Updated Thermal Rating: on line 5808-2411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 3930-2413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5768-2414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 4841-2415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2105
% INFO    : Updated Thermal Rating: on line 5665-2415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 3163-2416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184947
% INFO    : Updated Thermal Rating: on line 3163-2417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169954
% INFO    : Updated Thermal Rating: on line 5350-2418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 5464-2419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48031
% INFO    : Updated Thermal Rating: on line 4217-2421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4217-2421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5455-2422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4599
% INFO    : Updated Thermal Rating: on line 2426-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2511-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 3369-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2503
% INFO    : Updated Thermal Rating: on line 3445-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 5774-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 2511-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5607-2426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3008-2427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 3081-2427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4720-2427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4861-2427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 2430-2429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 4252-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 4742-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on line 5317-2430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5463-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 5491-2430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 5492-2430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5536-2430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 4252-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 4742-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 4252-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4393-2433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4683-2433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 3904-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5449-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5716-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 3313-2437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 5575-2437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 4920-2439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4920-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 3508-2440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5706-2440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 3793-2441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4026-2441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4362-2441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5237-2441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5761-2441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5466-2443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2594-2444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 2594-2445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4778-2446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 5564-2446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5153-2446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5136-2446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 5133-2446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 5546-2447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on line 3900-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 3900-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 2944-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5450-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56971
% INFO    : Updated Thermal Rating: on line 3420-2453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 2566-2456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4377-2456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 2562-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 3092-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4161-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 4214-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2157
% INFO    : Updated Thermal Rating: on line 5444-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 5680-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 4213-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2163
% INFO    : Updated Thermal Rating: on line 4657-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 5215-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 3338-2462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 3175-2463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 3649-2464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 5042-2464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 4980-2467 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1476
% INFO    : Updated Thermal Rating: on line 4240-2468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 4897-2468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2035
% INFO    : Updated Thermal Rating: on line 5459-2468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 4573-2470 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2130
% INFO    : Updated Thermal Rating: on line 4573-2470 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2130
% INFO    : Updated Thermal Rating: on line 2906-2471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4456-2471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 4660-2471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 2834-2472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 2489-2474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3563
% INFO    : Updated Thermal Rating: on line 2489-2473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2766
% INFO    : Updated Thermal Rating: on line 4569-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4088-2476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 3852-2477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23430
% INFO    : Updated Thermal Rating: on line 4869-2477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 4867-2478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 5191-2479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22412
% INFO    : Updated Thermal Rating: on line 3742-2480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 2822-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 4267-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 4614-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2083
% INFO    : Updated Thermal Rating: on line 5118-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 2728-2486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3497-2487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4757-2488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 5525-2488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 3033-2489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 2834-2489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 3781-2490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104366
% INFO    : Updated Thermal Rating: on line 3780-2490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87644
% INFO    : Updated Thermal Rating: on line 4867-2491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5289-2491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 3591-2493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3292
% INFO    : Updated Thermal Rating: on line 4688-2495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 2724-2496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2718-2499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 3007-2499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 4079-2499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5169-2499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4710
% INFO    : Updated Thermal Rating: on line 5468-2500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 5450-2501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 2790-2501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2780-2504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 2922-2505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 5469-2506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114924
% INFO    : Updated Thermal Rating: on line 4197-2507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 4867-2507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 5229-2507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5231-2507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4867-2507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 4997-2508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 4997-2508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 3356-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 2836-2512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8065
% INFO    : Updated Thermal Rating: on line 5732-2512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 2835-2513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 4397-2513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1543
% INFO    : Updated Thermal Rating: on line 4008-2514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 4008-2514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 3251-2516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 3251-2516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 2717-2521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 4778-2521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5169-2521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5721-2522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 2536-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on line 5470-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3390-2526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128083
% INFO    : Updated Thermal Rating: on line 4809-2527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3936-2528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 2559-2529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 5349-2529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 2559-2529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2930-2530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 2533-2532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 2687-2533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 3660-2533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 4818-2533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5474-2533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 5473-2535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83031
% INFO    : Updated Thermal Rating: on line 5760-2536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 5470-2537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on line 2706-2538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 2895-2539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1550
% INFO    : Updated Thermal Rating: on line 3158-2539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 3158-2539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 4210-2541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 3482-2542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1013
% INFO    : Updated Thermal Rating: on line 5478-2544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 5507-2543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3707
% INFO    : Updated Thermal Rating: on line 2971-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 2971-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5476-2546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2082
% INFO    : Updated Thermal Rating: on line 5477-2547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 3684-2548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 4736-2548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 4845-2548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 4736-2548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 5695-2549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 3911-2550 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 455
% INFO    : Updated Thermal Rating: on line 4176-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3188-2553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 4793-2554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 4793-2554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 2766-2555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 3664-2556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 3699-2556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 3377-2557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 4915-2557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 3842-2558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 4323-2558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 3646-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5573-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5574-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 5847-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 2628-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5481-2562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5482-2563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 5483-2564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 3940-2565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 4007-2565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 3105-2566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 3824-2566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 4080-2566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5256-2566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 5767-2566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 4109-2569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 4793-2569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5713-2570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 5711-2570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on line 4002-2572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 4366-2572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 5192-2574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12824
% INFO    : Updated Thermal Rating: on line 3008-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 3008-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 4338-2577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 5391-2577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 5754-2577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2532
% INFO    : Updated Thermal Rating: on line 5794-2577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5257-2579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 3436-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 4141-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 2828-2582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 2624-2583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 566
% INFO    : Updated Thermal Rating: on line 4396-2583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5342
% INFO    : Updated Thermal Rating: on line 5113-2583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 4395-2583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5342
% INFO    : Updated Thermal Rating: on line 5112-2583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 2738-2585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 5753-2585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3169-2587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 5485-2588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5531
% INFO    : Updated Thermal Rating: on line 2984-2589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 3010-2590 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1547
% INFO    : Updated Thermal Rating: on line 2798-2590 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1476
% INFO    : Updated Thermal Rating: on line 3010-2590 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1547
% INFO    : Updated Thermal Rating: on line 2798-2590 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1479
% INFO    : Updated Thermal Rating: on line 3664-2591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 3664-2591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 5383-2592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 5633-2592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33358
% INFO    : Updated Thermal Rating: on line 5487-2593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 4403-2594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 4413-2594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4403-2594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4413-2594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 5402-2596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5979
% INFO    : Updated Thermal Rating: on line 2600-2598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62462
% INFO    : Updated Thermal Rating: on line 4675-2598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 5488-2599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3113-2601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 4054-2601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 3113-2601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 5489-2603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 3572-2604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 4448-2604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 2876-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 3226-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 3348-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 4072-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3412-2608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 3409-2610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 3619-2611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5036-2612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 5458-2612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 4793-2613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 3360-2614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1161
% INFO    : Updated Thermal Rating: on line 3977-2615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 4680-2615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3024-2616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5815-2616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 4867-2619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5097-2620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5491-2621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 5492-2621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12845
% INFO    : Updated Thermal Rating: on line 2958-2622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5806-2622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7635
% INFO    : Updated Thermal Rating: on line 5807-2622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 2930-2625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 4590-2625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 5573-2628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on line 2637-2629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 3559-2629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 3891-2629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 2910-2630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 5250-2630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5493-2632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1516
% INFO    : Updated Thermal Rating: on line 2789-2633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 3139-2633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4607-2633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 4607-2634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 2950-2636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4069-2636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 3441-2637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5233-2638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5505-2639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3410
% INFO    : Updated Thermal Rating: on line 5834-2639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5535-2640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8999
% INFO    : Updated Thermal Rating: on line 2644-2643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5222-2643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5219-2644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 3502-2645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 4172-2645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 3651-2645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 4173-2648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on line 5546-2648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 684
% INFO    : Updated Thermal Rating: on line 5584-2648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3399
% INFO    : Updated Thermal Rating: on line 4996-2649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5821-2649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 3769-2650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 3376-2651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 3489-2651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4543-2652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2100
% INFO    : Updated Thermal Rating: on line 5191-2652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 4146-2654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4516-2654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 5357-2654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 2717-2657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3452-2657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 3987-2658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 3688-2659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 2592-2660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3530-2660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4039-2660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 5431-2660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on line 2592-2660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 3491-2666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 5690-2667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5691-2667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 3511-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 4162-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1357
% INFO    : Updated Thermal Rating: on line 4885-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4350
% INFO    : Updated Thermal Rating: on line 3572-2672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 3572-2671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4255-2673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 4892-2673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4255-2673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 4401-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 5495-2675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 3883-2675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 2675-2677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 4358-2680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 3015-2681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 5402-2681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5762-2681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 3015-2681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 3483-2683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 4698-2684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5498-2686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2745
% INFO    : Updated Thermal Rating: on line 3761-2687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4783-2689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3517-2690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 2692-2691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 5499-2691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24050
% INFO    : Updated Thermal Rating: on line 2834-2694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 3897-2696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 4735-2696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 4832-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on line 4322-2699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 3656-2700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 967
% INFO    : Updated Thermal Rating: on line 3175-2702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 4057-2702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22736
% INFO    : Updated Thermal Rating: on line 4670-2702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 4058-2702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17760
% INFO    : Updated Thermal Rating: on line 4903-2703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 486
% INFO    : Updated Thermal Rating: on line 5208-2703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1357
% INFO    : Updated Thermal Rating: on line 5836-2703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 2895-2706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 3839-2705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4617-2706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 4870-2705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5400-2705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 3930-2709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 3931-2710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3468
% INFO    : Updated Thermal Rating: on line 5503-2711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 3543-2713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5170-2718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 5172-2718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 3029-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 4726-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46632
% INFO    : Updated Thermal Rating: on line 4725-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51447
% INFO    : Updated Thermal Rating: on line 4724-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51447
% INFO    : Updated Thermal Rating: on line 3664-2722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3664-2722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3583-2724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3320
% INFO    : Updated Thermal Rating: on line 4817-2724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 4817-2724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 3915-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 3600-2728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 5505-2729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1725
% INFO    : Updated Thermal Rating: on line 4147-2730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2699
% INFO    : Updated Thermal Rating: on line 4225-2733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 4959-2737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1465
% INFO    : Updated Thermal Rating: on line 4959-2736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3204
% INFO    : Updated Thermal Rating: on line 3678-2738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 5651-2739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17478
% INFO    : Updated Thermal Rating: on line 3644-2742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 3814-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4993-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 3121-2744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3120-2744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3119-2744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4629-2745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on line 3422-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 2944-2748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8159
% INFO    : Updated Thermal Rating: on line 4731-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 4787-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5110-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 4787-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 2845-2753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 4204-2753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5525
% INFO    : Updated Thermal Rating: on line 4425-2753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5103-2753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5738-2753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2177
% INFO    : Updated Thermal Rating: on line 4203-2753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 3509-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 937
% INFO    : Updated Thermal Rating: on line 5510-2755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 3424-2756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 4805-2756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 5507-2757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27575
% INFO    : Updated Thermal Rating: on line 3662-2758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1684
% INFO    : Updated Thermal Rating: on line 5506-2760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9377
% INFO    : Updated Thermal Rating: on line 5511-2761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6271
% INFO    : Updated Thermal Rating: on line 4913-2763 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1264
% INFO    : Updated Thermal Rating: on line 4628-2764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 3366-2765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 3366-2765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 5508-2766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 5688-2767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5387-2767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 2840-2769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 3261-2769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 917
% INFO    : Updated Thermal Rating: on line 4283-2769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 4410-2769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 4909-2769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 5819-2769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4283-2769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 5241-2769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3016-2770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 5503-2772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 5776-2772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 3903-2774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 5084-2774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 3809-2776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 5138-2776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 4008-2778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 2961-2779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3330-2779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 5443-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5453-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5454-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5600-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 3330-2779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 3356-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3484-2783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 5423-2787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 4862-2788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4862-2788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 4607-2789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4070-2790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5450-2790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5471-2790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5472-2790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 4070-2790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4063-2792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4959-2793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 3858-2799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on line 4198-2800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 4867-2801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 3798-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3924-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 5252-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 3670-2805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 4929-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5458-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 3699-2808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10480
% INFO    : Updated Thermal Rating: on line 3511-2809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 4175-2809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 4379-2809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1659
% INFO    : Updated Thermal Rating: on line 4255-2811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5516-2813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12969
% INFO    : Updated Thermal Rating: on line 3307-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 4371-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10216
% INFO    : Updated Thermal Rating: on line 4394-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 5040-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 5299-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 5555-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 5557-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 5571-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 5039-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 2944-2816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5752-2816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 4721-2818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 5214-2818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5460-2818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4346-2819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 4314-2823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 4334-2823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5451-2824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 3712-2825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25728
% INFO    : Updated Thermal Rating: on line 3182-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 3847-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 5323-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on line 5819-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on line 5674-2833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4397-2835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1620
% INFO    : Updated Thermal Rating: on line 5517-2837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 3345-2839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5095-2840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3170
% INFO    : Updated Thermal Rating: on line 5267-2842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 5393-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5521-2844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113138
% INFO    : Updated Thermal Rating: on line 2953-2845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 4564-2845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 5731-2847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 5253-2850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5523-2850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5792-2853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 5526-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309124
% INFO    : Updated Thermal Rating: on line 5525-2856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27511
% INFO    : Updated Thermal Rating: on line 5524-2858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1734
% INFO    : Updated Thermal Rating: on line 5524-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12072
% INFO    : Updated Thermal Rating: on line 3399-2861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 3757-2863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 5338-2863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 5786-2863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 2996-2867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 4852-2865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2369
% INFO    : Updated Thermal Rating: on line 4852-2866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2642
% INFO    : Updated Thermal Rating: on line 5529-2868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 4686-2869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38824
% INFO    : Updated Thermal Rating: on line 4448-2870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5531-2873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5072
% INFO    : Updated Thermal Rating: on line 4935-2874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 3276-2875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 5619-2876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 5533-2877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 5532-2878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 3037-2882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 3075-2883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 3008-2884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5318-2885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 5534-2885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12709
% INFO    : Updated Thermal Rating: on line 3035-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 5535-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 4293-2887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 4585-2888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 4568-2889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2139
% INFO    : Updated Thermal Rating: on line 4640-2893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 4641-2893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 3326-2894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1449
% INFO    : Updated Thermal Rating: on line 5656-2894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2579
% INFO    : Updated Thermal Rating: on line 4016-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 3181-2896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5536-2897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6565
% INFO    : Updated Thermal Rating: on line 3844-2898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5036-2898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 5493-2898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 5538-2902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 5537-2902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7639
% INFO    : Updated Thermal Rating: on line 5683-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 4719-2904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5259
% INFO    : Updated Thermal Rating: on line 4132-2905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2909-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on line 5623-2910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on line 3900-2911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5407-2911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4859-2913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4466-2914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 2920-2918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 3793-2919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3282
% INFO    : Updated Thermal Rating: on line 3930-2920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4253-2920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 5779-2920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1602
% INFO    : Updated Thermal Rating: on line 4919-2923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4945-2923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 3850-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3850-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 3085-2925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 4382-2926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7146
% INFO    : Updated Thermal Rating: on line 3297-2927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5540-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 3213-2930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 3682-2930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 3099-2934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5781-2934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3849-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 5000-2935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 5610-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1171
% INFO    : Updated Thermal Rating: on line 3849-2935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 5612-2935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 5543-2938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18526
% INFO    : Updated Thermal Rating: on line 5291-2940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 5845-2940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4850-2941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 3239-2944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 5027-2944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2126
% INFO    : Updated Thermal Rating: on line 5083-2944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 3967-2946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1675
% INFO    : Updated Thermal Rating: on line 4930-2946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1964
% INFO    : Updated Thermal Rating: on line 3240-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 5069-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5445-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 751
% INFO    : Updated Thermal Rating: on line 4425-2953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 5055-2954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5675-2954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 4346-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4242-2956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5545-2958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 5546-2959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35735
% INFO    : Updated Thermal Rating: on line 4671-2962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1271
% INFO    : Updated Thermal Rating: on line 5547-2970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10795
% INFO    : Updated Thermal Rating: on line 3998-2971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4911-2971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 5218-2971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 3997-2971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3040-2973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5203-2973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 3982-2974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 4257-2974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 5549-2975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6352
% INFO    : Updated Thermal Rating: on line 5619-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 5642-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 3314-2978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 3602-2979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 4356-2979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5466-2979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 5607-2979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 5644-2980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 4004-2983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4892
% INFO    : Updated Thermal Rating: on line 3403-2984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 4096-2984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4367-2984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 5149-2984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 5849-2984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 4096-2984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 3484-2986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 4055-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1082
% INFO    : Updated Thermal Rating: on line 4160-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 5255-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1412
% INFO    : Updated Thermal Rating: on line 5742-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 3553-2990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4986-2991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 5668-2991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 4110-2993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 4794-2993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3287-2996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1029
% INFO    : Updated Thermal Rating: on line 3680-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 4315-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5141
% INFO    : Updated Thermal Rating: on line 5543-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 5647-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1382
% INFO    : Updated Thermal Rating: on line 5649-2996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on line 4770-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 5620-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 4770-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 3174-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 5171-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 5775-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3046-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 3174-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 3678-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3466-3005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5047-3008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 5119-3008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 3081-3011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 3678-3012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 4779-3013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 4779-3013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 5455-3015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 4931-3017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 5171-3018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56971
% INFO    : Updated Thermal Rating: on line 5579-3018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 4791-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 3542-3020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4772-3020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5553-3022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28556
% INFO    : Updated Thermal Rating: on line 5778-3023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9667
% INFO    : Updated Thermal Rating: on line 5784-3023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1648
% INFO    : Updated Thermal Rating: on line 3519-3027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5593-3029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5028-3030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5139-3030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 3596-3033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 3399-3034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4721-3035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 3482-3039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 4464-3040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4512-3040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 4638-3040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 4867-3041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 4867-3042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 4867-3042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 4229-3043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 4844-3043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3311-3044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 4302-3044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 4814-3048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 4585-3049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 3063-3050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3268-3052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 3496-3053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 5559-3059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 5198-3065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5307-3065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 3674-3066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1766
% INFO    : Updated Thermal Rating: on line 3978-3066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 4959-3067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1326
% INFO    : Updated Thermal Rating: on line 3678-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4335-3073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 5325-3073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 5637-3073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 5658-3075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 822
% INFO    : Updated Thermal Rating: on line 4769-3076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5827-3076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6858
% INFO    : Updated Thermal Rating: on line 4799-3076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2345
% INFO    : Updated Thermal Rating: on line 5562-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1047
% INFO    : Updated Thermal Rating: on line 3201-3078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 4773-3079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5438-3079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 5160-3080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 4660-3083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5231-3084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5737-3084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 3709-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5364-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5377-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3313-3087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5661-3087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 5262-3089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 3967-3090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 5144-3091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5629-3091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 4075-3092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 5003-3095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 3561-3096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1162
% INFO    : Updated Thermal Rating: on line 3344-3098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 4956-3100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5258-3100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 4923-3103 : Rate A, Rate B, Rate C , 1617.0, 1617.0, 1617.0 -> 1275
% INFO    : Updated Thermal Rating: on line 3688-3107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 3688-3106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 3457-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 5379-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 5359-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 3678-3111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 3678-3111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 3269-3112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 5585-3112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 3551-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 3760-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4393-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 4760-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5625-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on line 5482-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4860-3115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 5095-3114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 5286-3115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 4966-3114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5567-3122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2570
% INFO    : Updated Thermal Rating: on line 3508-3123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3688
% INFO    : Updated Thermal Rating: on line 5568-3125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 4352-3126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 5614-3127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5818-3127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 5609-3127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 3178-3128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 2930-3129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3812-3129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4268-3131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5215
% INFO    : Updated Thermal Rating: on line 5120-3131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 4363-3132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 4981-3134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 5571-3136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4490
% INFO    : Updated Thermal Rating: on line 4612-3139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 3164-3141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 3929-3141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 3164-3141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 5361-3142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 5572-3143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7254
% INFO    : Updated Thermal Rating: on line 3146-3144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310318
% INFO    : Updated Thermal Rating: on line 3902-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4977-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5100-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 4976-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 3985-3147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 5847-3147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 5779-3148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 3878-3151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 3889-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4130-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 5021-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 5050-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36728
% INFO    : Updated Thermal Rating: on line 4908-3154 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1005
% INFO    : Updated Thermal Rating: on line 4908-3153 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5070-3157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 3600-3159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4895-3159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 3258-3160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 3526-3160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10278
% INFO    : Updated Thermal Rating: on line 3275-3161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 486
% INFO    : Updated Thermal Rating: on line 3385-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 4433-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 5205-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 5493-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5573-3166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2328
% INFO    : Updated Thermal Rating: on line 4525-3169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2877
% INFO    : Updated Thermal Rating: on line 5505-3169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 5575-3170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18302
% INFO    : Updated Thermal Rating: on line 5576-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23670
% INFO    : Updated Thermal Rating: on line 4723-3172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 5345-3172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 3672-3173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5579-3174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23551
% INFO    : Updated Thermal Rating: on line 4670-3175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 4965-3176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 5627-3177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 3266-3178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 3396-3183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 4109-3184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4639-3184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 5581-3185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5123-3185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4888-3186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5582-3187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 5617-3188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 5788-3188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 4289-3190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 5378-3190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 4399-3191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37253
% INFO    : Updated Thermal Rating: on line 3514-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4250-3195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 4310-3196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 4691-3196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3321
% INFO    : Updated Thermal Rating: on line 5240-3197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 5355-3197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4310-3196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 5563-3201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1740
% INFO    : Updated Thermal Rating: on line 3881-3204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93975
% INFO    : Updated Thermal Rating: on line 3882-3205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102466
% INFO    : Updated Thermal Rating: on line 5501-3206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 4627-3207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5271-3208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1932
% INFO    : Updated Thermal Rating: on line 4217-3209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2662
% INFO    : Updated Thermal Rating: on line 4500-3209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4328
% INFO    : Updated Thermal Rating: on line 5584-3210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42408
% INFO    : Updated Thermal Rating: on line 3269-3211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 5586-3214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 4873-3218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1295
% INFO    : Updated Thermal Rating: on line 5580-3219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 3825-3220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 3923-3220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3924-3220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 4959-3221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7828
% INFO    : Updated Thermal Rating: on line 3300-3222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 4229-3222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 3299-3223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4228-3223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4766-3224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5827-3224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 3822-3226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 3630-3228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 5491-3229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 3427-3233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64823
% INFO    : Updated Thermal Rating: on line 3427-3232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64823
% INFO    : Updated Thermal Rating: on line 3427-3231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52241
% INFO    : Updated Thermal Rating: on line 4608-3235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 4609-3234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 5445-3240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5540-3241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 4181-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 914
% INFO    : Updated Thermal Rating: on line 4265-3244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 5280-3244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 5333-3245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 4635-3246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5031-3246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5589-3247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 5590-3248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7124
% INFO    : Updated Thermal Rating: on line 4617-3249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 3436-3250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 4321-3250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 5567-3250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5840-3251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 5755-3251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 4788-3252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 5650-3252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 3650-3255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3058
% INFO    : Updated Thermal Rating: on line 3650-3254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3058
% INFO    : Updated Thermal Rating: on line 3650-3256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3099
% INFO    : Updated Thermal Rating: on line 3437-3258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 4447-3258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 5197-3258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 4793-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5323-3261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 4673-3262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 5591-3264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 4559-3266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 3948-3267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106799
% INFO    : Updated Thermal Rating: on line 4236-3269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 864
% INFO    : Updated Thermal Rating: on line 4772-3272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5114-3274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 5132-3274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5544-3274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4475-3276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 3284-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 3652-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on line 5616-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 3283-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 3652-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 5615-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 4038-3287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15006
% INFO    : Updated Thermal Rating: on line 4871-3294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5594-3295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1885
% INFO    : Updated Thermal Rating: on line 3500-3297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 3869-3297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 4652-3300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4652-3299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4275-3301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on line 3399-3302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 4546-3302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3284
% INFO    : Updated Thermal Rating: on line 3399-3302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4414-3303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on line 5407-3304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 4207-3306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5172-3308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 5757-3308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 5834-3309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 4302-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on line 5382-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 5586-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 5751-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 3691-3312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14024
% INFO    : Updated Thermal Rating: on line 4823-3314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3198
% INFO    : Updated Thermal Rating: on line 5177-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 5740-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5310-3321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2154
% INFO    : Updated Thermal Rating: on line 5692-3321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 3913-3322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 3534-3323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308192
% INFO    : Updated Thermal Rating: on line 3533-3323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308192
% INFO    : Updated Thermal Rating: on line 3850-3324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 3428-3326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 516
% INFO    : Updated Thermal Rating: on line 4283-3327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6319
% INFO    : Updated Thermal Rating: on line 5471-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 5576-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 4852-3333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13697
% INFO    : Updated Thermal Rating: on line 4852-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7028
% INFO    : Updated Thermal Rating: on line 4287-3335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 5043-3335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5326-3335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 5596-3337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 5250-3339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5037-3341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3901
% INFO    : Updated Thermal Rating: on line 5037-3340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3901
% INFO    : Updated Thermal Rating: on line 4442-3343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5244-3344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11822
% INFO    : Updated Thermal Rating: on line 5354-3345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 5619-3348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1178
% INFO    : Updated Thermal Rating: on line 3773-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4613-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 5096-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 3773-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5639-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 5772-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 5601-3354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 5602-3354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 3356-3355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 5600-3356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5599-3357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5487-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 4964-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 3933-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1443
% INFO    : Updated Thermal Rating: on line 3933-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 5329-3361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 3487-3365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4964
% INFO    : Updated Thermal Rating: on line 4668-3365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 4668-3365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 4581-3366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 4181-3370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 4181-3370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5608-3375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5125-3376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 5226-3376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 5610-3378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1519
% INFO    : Updated Thermal Rating: on line 5611-3379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241598
% INFO    : Updated Thermal Rating: on line 3836-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 4337-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 5728-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 3836-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4406-3382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 5542-3383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 5541-3384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 805
% INFO    : Updated Thermal Rating: on line 5093-3386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 3900-3387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 3900-3387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 5141-3388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 3886-3391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 4843-3391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 3923-3396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5542-3396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 3924-3396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5541-3396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 4293-3398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 3541-3399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 4333-3399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 5304-3399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5517-3399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 5615-3402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3799
% INFO    : Updated Thermal Rating: on line 5486-3403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 3405-3404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4524
% INFO    : Updated Thermal Rating: on line 4131-3406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 5617-3408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45731
% INFO    : Updated Thermal Rating: on line 4061-3411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 3912-3415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 5620-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 4456-3418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1072
% INFO    : Updated Thermal Rating: on line 3981-3419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 4035-3419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 3981-3419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 4146-3420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 5765-3421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 5281-3422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 5556-3422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4108-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4327-3424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 5415-3426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3736-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 3893-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5129-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4348-3432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 5396-3432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 4348-3432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 5624-3434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 3524-3437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 4610-3439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 5588-3439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 3772-3441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4921-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 5625-3443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3447-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4241-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on line 4682-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5774-3445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5626-3446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13366
% INFO    : Updated Thermal Rating: on line 4682-3447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 4682-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5143-3449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 5627-3451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 5236-3453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5237-3453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5344-3453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5801-3454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1338
% INFO    : Updated Thermal Rating: on line 4924-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2162
% INFO    : Updated Thermal Rating: on line 4970-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 4970-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on line 5628-3456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 3555-3457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 5539-3459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1834
% INFO    : Updated Thermal Rating: on line 4013-3460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 5777-3461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 5629-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4779-3463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 5274-3466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 5630-3468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10014
% INFO    : Updated Thermal Rating: on line 3514-3469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 3482-3473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6987
% INFO    : Updated Thermal Rating: on line 3482-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10050
% INFO    : Updated Thermal Rating: on line 3482-3472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10699
% INFO    : Updated Thermal Rating: on line 3482-3474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13403
% INFO    : Updated Thermal Rating: on line 4881-3481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 4881-3480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 5330-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 5379-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5478-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2203
% INFO    : Updated Thermal Rating: on line 5359-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5507-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 5558-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1318
% INFO    : Updated Thermal Rating: on line 3720-3484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4401-3486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 4414-3486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 3545-3488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 4123-3488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 5550-3490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2546
% INFO    : Updated Thermal Rating: on line 5631-3492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 4318-3494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 4407-3494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5484-3494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5485-3494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 5632-3495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 4388-3497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 4752-3497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5106-3497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on line 4388-3497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 3567-3498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5055-3498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5055-3498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5633-3499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 3869-3500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 5278-3506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28417
% INFO    : Updated Thermal Rating: on line 5637-3507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2143
% INFO    : Updated Thermal Rating: on line 4010-3508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4569-3508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5103-3508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 5635-3508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3446
% INFO    : Updated Thermal Rating: on line 4610-3510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 936
% INFO    : Updated Thermal Rating: on line 4789-3511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 4016-3512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 3878-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 3981-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 4838-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5799-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 3981-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 3981-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 4034-3517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 4034-3517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 3836-3519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 4552-3522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 5010-3521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 5386-3522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 5790-3521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 4424-3530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 5639-3532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7266
% INFO    : Updated Thermal Rating: on line 5641-3535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21242
% INFO    : Updated Thermal Rating: on line 4172-3536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 4816-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4085
% INFO    : Updated Thermal Rating: on line 5070-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 5432-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6818
% INFO    : Updated Thermal Rating: on line 5830-3541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 4060-3545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 4123-3545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5423-3545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5644-3548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 4346-3550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5078-3550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1049
% INFO    : Updated Thermal Rating: on line 4346-3550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on line 5645-3552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20555
% INFO    : Updated Thermal Rating: on line 5018-3553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22978
% INFO    : Updated Thermal Rating: on line 4360-3554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4893-3555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5178-3555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5478-3555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 5530-3555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 5707-3555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 5182-3555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 4518-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1867
% INFO    : Updated Thermal Rating: on line 4891-3559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 4891-3559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 3564-3561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4017-3566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4216-3566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5338-3567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 5132-3568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 4723-3569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 4671-3570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 4010-3571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4569-3571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 4010-3571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 3982-3572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 3370-3576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 5632-3576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4519-3582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 5717-3582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 3845-3584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5982
% INFO    : Updated Thermal Rating: on line 5285-3584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 5343-3584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 5837-3584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 4652-3585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5647-3588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5649-3589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 3391-3590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 3886-3590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1864
% INFO    : Updated Thermal Rating: on line 5648-3592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151236
% INFO    : Updated Thermal Rating: on line 5480-3593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20343
% INFO    : Updated Thermal Rating: on line 3430-3594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5006
% INFO    : Updated Thermal Rating: on line 3987-3594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 3509-3595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5457-3595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6284
% INFO    : Updated Thermal Rating: on line 3742-3596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 5456-3599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 5370-3600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 5571-3600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 994
% INFO    : Updated Thermal Rating: on line 4305-3602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 5607-3602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5307-3606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1641
% INFO    : Updated Thermal Rating: on line 4233-3608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4191-3610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 4618-3610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5626-3610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1476
% INFO    : Updated Thermal Rating: on line 5653-3611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 3395-3614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 4510-3618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 5202-3617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3129
% INFO    : Updated Thermal Rating: on line 3406-3619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 3406-3619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 3363-3621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5804-3621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3363-3621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4617-3622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5655-3625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6375
% INFO    : Updated Thermal Rating: on line 3630-3627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15535
% INFO    : Updated Thermal Rating: on line 3630-3626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15535
% INFO    : Updated Thermal Rating: on line 4743-3629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 4743-3628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on line 5328-3630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2951
% INFO    : Updated Thermal Rating: on line 5587-3630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2460
% INFO    : Updated Thermal Rating: on line 4472-3630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42115
% INFO    : Updated Thermal Rating: on line 3464-3630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12856
% INFO    : Updated Thermal Rating: on line 3880-3632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 5340-3634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 4101-3634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 5811-3636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1744
% INFO    : Updated Thermal Rating: on line 4072-3637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5521-3640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on line 5520-3641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1815
% INFO    : Updated Thermal Rating: on line 5656-3643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 4803-3645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 5574-3646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5210-3647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2428
% INFO    : Updated Thermal Rating: on line 3531-3650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2305
% INFO    : Updated Thermal Rating: on line 3654-3650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 3859-3650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 3654-3650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 4172-3651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 4489-3653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4488-3653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 5565-3657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 3659-3658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5241
% INFO    : Updated Thermal Rating: on line 3984-3658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2045
% INFO    : Updated Thermal Rating: on line 3984-3659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7695
% INFO    : Updated Thermal Rating: on line 5768-3661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 3676-3662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1413
% INFO    : Updated Thermal Rating: on line 3677-3662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 4216-3662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3699-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 4436-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58788
% INFO    : Updated Thermal Rating: on line 5625-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 5482-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 4423-3667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 5199-3667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 5657-3668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2723
% INFO    : Updated Thermal Rating: on line 4689-3669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 3694-3670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 3892-3672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 4004-3674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 4159-3674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13072
% INFO    : Updated Thermal Rating: on line 4128-3678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 4560-3679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 4852-3681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 3311-3685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 5586-3685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 5661-3686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3062
% INFO    : Updated Thermal Rating: on line 5421-3688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 5662-3688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5681-3688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 4949-3688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 4618-3690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 4322-3695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4610-3695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5559-3696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4919-3697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 4181-3700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 5446-3700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2893
% INFO    : Updated Thermal Rating: on line 4181-3700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 4230-3701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 4462-3702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5667-3703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5986
% INFO    : Updated Thermal Rating: on line 4498-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5613
% INFO    : Updated Thermal Rating: on line 4497-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 4178-3714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 4791-3714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 4313-3715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109898
% INFO    : Updated Thermal Rating: on line 5668-3716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 4920-3718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5669-3719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22120
% INFO    : Updated Thermal Rating: on line 4364-3723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 5093-3727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1736
% INFO    : Updated Thermal Rating: on line 5104-3727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5671-3730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47367
% INFO    : Updated Thermal Rating: on line 4329-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 5670-3733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on line 5772-3732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4265-3734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 3722-3736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10480
% INFO    : Updated Thermal Rating: on line 4428-3736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 4540-3736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4428-3736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 3726-3738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138682
% INFO    : Updated Thermal Rating: on line 3725-3738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138682
% INFO    : Updated Thermal Rating: on line 3724-3738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123245
% INFO    : Updated Thermal Rating: on line 4796-3741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9077
% INFO    : Updated Thermal Rating: on line 3872-3746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29661
% INFO    : Updated Thermal Rating: on line 5404-3747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 5672-3750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 4810-3753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5673-3754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 5190-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on line 5437-3757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1308
% INFO    : Updated Thermal Rating: on line 4491-3758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 4529-3758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 5674-3762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10170
% INFO    : Updated Thermal Rating: on line 3859-3763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 3875-3763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 4717-3763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5063-3763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 4329-3765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 5413-3766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 4620-3772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 4388-3772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 5506-3773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 5835-3773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 4730-3773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 5045-3775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4727-3794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 5693-3794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 4442-3795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 864
% INFO    : Updated Thermal Rating: on line 5597-3795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 4455-3796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5812-3796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 4120-3799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 5677-3800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 4822-3802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4824-3802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1851
% INFO    : Updated Thermal Rating: on line 4821-3802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4078-3804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40590
% INFO    : Updated Thermal Rating: on line 4078-3803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42124
% INFO    : Updated Thermal Rating: on line 3995-3809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3801
% INFO    : Updated Thermal Rating: on line 4282-3809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 4373-3809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on line 5200-3809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5516-3809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3995-3809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3774
% INFO    : Updated Thermal Rating: on line 4914-3811 : Rate A, Rate B, Rate C , 1708.0, 1708.0, 1708.0 -> 1117
% INFO    : Updated Thermal Rating: on line 4080-3814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 3821-3815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3820-3815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3819-3815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4080-3824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 5251-3825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 4118-3826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 4157-3828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20973
% INFO    : Updated Thermal Rating: on line 3885-3831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 3975-3831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on line 4330-3830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 3974-3830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 4330-3831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 5068-3835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4543-3837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5282-3838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2711
% INFO    : Updated Thermal Rating: on line 5001-3839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 516
% INFO    : Updated Thermal Rating: on line 5094-3839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5469-3840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 5514-3840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 5140-3842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 5681-3842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 3890-3843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4283-3847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 5683-3848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on line 5452-3850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 4349-3855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5796-3855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 5797-3854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 4973-3858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 5514-3858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 5685-3861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53230
% INFO    : Updated Thermal Rating: on line 5684-3860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67824
% INFO    : Updated Thermal Rating: on line 5765-3863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5686-3864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3817
% INFO    : Updated Thermal Rating: on line 4731-3867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 3875-3871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4508-3873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 4939-3873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 5342-3873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 5687-3877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5688-3877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4958-3878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4958-3878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4316-3883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 5689-3884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 4513-3890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4620-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5388-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 4253-3894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 5814-3896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 5627-3900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 4589-3903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4393-3904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4664-3907 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1811
% INFO    : Updated Thermal Rating: on line 4664-3907 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1825
% INFO    : Updated Thermal Rating: on line 4443-3910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 5532-3915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 4100-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 5059-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5238-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 5719-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 5694-3918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4757-3919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 906
% INFO    : Updated Thermal Rating: on line 4035-3922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 5799-3922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 4837-3924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4837-3923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5695-3928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 4508-3930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 5120-3930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1971
% INFO    : Updated Thermal Rating: on line 3996-3931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7269
% INFO    : Updated Thermal Rating: on line 5741-3944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5774-3944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 4110-3945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 5418-3951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 4014-3954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4014-3955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4542
% INFO    : Updated Thermal Rating: on line 5273-3956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 3960-3959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 4462-3959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 5179-3959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on line 4566-3961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4616-3964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23818
% INFO    : Updated Thermal Rating: on line 5177-3964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1301
% INFO    : Updated Thermal Rating: on line 5437-3964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 5800-3964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24046
% INFO    : Updated Thermal Rating: on line 5701-3965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4930-3967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 969
% INFO    : Updated Thermal Rating: on line 5700-3972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 4085-3977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 4085-3977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 5327-3979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 4198-3981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5107-3981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 5008-3982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5703-3986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3660
% INFO    : Updated Thermal Rating: on line 4926-3988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5086-3989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5531-3990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4931-3992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 5704-3993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 811
% INFO    : Updated Thermal Rating: on line 5354-3994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5706-3999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 4700-4000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4365-4001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 5825-4003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4313-4004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 4469-4004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3258
% INFO    : Updated Thermal Rating: on line 5506-4006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 4334-4008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4368-4008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 5488-4010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 5247-4013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 5214-4015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5418-4021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 5490-4023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16838
% INFO    : Updated Thermal Rating: on line 5577-4023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4610-4024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 4610-4024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 5236-4026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 4460-4030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5156-4030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22412
% INFO    : Updated Thermal Rating: on line 4460-4030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5155-4030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22412
% INFO    : Updated Thermal Rating: on line 4686-4031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 5711-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 5099-4036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 899
% INFO    : Updated Thermal Rating: on line 4905-4041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5714-4044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23993
% INFO    : Updated Thermal Rating: on line 4378-4045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3027
% INFO    : Updated Thermal Rating: on line 5795-4045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37370
% INFO    : Updated Thermal Rating: on line 5435-4050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 4721-4059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 5715-4062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56492
% INFO    : Updated Thermal Rating: on line 4308-4063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 4547-4063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2729
% INFO    : Updated Thermal Rating: on line 5788-4063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 5716-4065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 5069-4069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 4605-4070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 5234-4070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4229-4074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 4228-4074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 5780-4075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 4232-4080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4377-4080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 4682-4086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4683-4086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4777-4087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 5718-4090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8357
% INFO    : Updated Thermal Rating: on line 5090-4092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 5853-4092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116592
% INFO    : Updated Thermal Rating: on line 5305-4097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 4621-4098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 4953-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 4939-4101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5340-4101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5502-4101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 4908-4106 : Rate A, Rate B, Rate C , 1659.0, 1659.0, 1659.0 -> 1386
% INFO    : Updated Thermal Rating: on line 4730-4107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5837-4109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 4449-4112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5723-4113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 4936-4114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5720-4114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 4117-4116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28461
% INFO    : Updated Thermal Rating: on line 4337-4118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5580-4118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 5015-4120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5726-4129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 4245-4131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4146-4138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4543-4139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5177-4141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 5567-4141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 5800-4141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 5815-4140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 4210-4143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4855-4143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5261-4145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8030
% INFO    : Updated Thermal Rating: on line 4854-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on line 5003-4148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 5796-4148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 5728-4152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13354
% INFO    : Updated Thermal Rating: on line 5727-4153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 4475-4155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4475-4155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 4255-4156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 5729-4156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 4385-4157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16924
% INFO    : Updated Thermal Rating: on line 5730-4160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 5206-4163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2379
% INFO    : Updated Thermal Rating: on line 4700-4164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 5426-4164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 5731-4166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5531
% INFO    : Updated Thermal Rating: on line 5569-4167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5732-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47067
% INFO    : Updated Thermal Rating: on line 4321-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 4381-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 5786-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1166
% INFO    : Updated Thermal Rating: on line 4321-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 4381-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 5733-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 5641-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2029
% INFO    : Updated Thermal Rating: on line 5392-4174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16527
% INFO    : Updated Thermal Rating: on line 5435-4174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1802
% INFO    : Updated Thermal Rating: on line 5040-4177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 4671-4178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on line 5184-4181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 5346-4181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 5632-4181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4682-4183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 4330-4184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 967
% INFO    : Updated Thermal Rating: on line 5736-4184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11909
% INFO    : Updated Thermal Rating: on line 4186-4185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 5298-4185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5737-4189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5755-4190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 5032-4191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4851-4194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5158-4194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4765-4195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22038
% INFO    : Updated Thermal Rating: on line 5196-4199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 4966-4201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 4966-4200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 4202-4203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3795
% INFO    : Updated Thermal Rating: on line 4580-4207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1421
% INFO    : Updated Thermal Rating: on line 4880-4207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 5792-4207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 5588-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 4474-4217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4678
% INFO    : Updated Thermal Rating: on line 4500-4217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2928
% INFO    : Updated Thermal Rating: on line 5221-4216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 4500-4217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2795
% INFO    : Updated Thermal Rating: on line 4499-4216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 5391-4220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 5744-4220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5308-4226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 5372-4225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 4957-4230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 4349-4234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5740-4235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 5459-4239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194699
% INFO    : Updated Thermal Rating: on line 4682-4241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1753
% INFO    : Updated Thermal Rating: on line 4900-4242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5167-4242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 5410-4242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4325-4246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 4679-4248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5213-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1184
% INFO    : Updated Thermal Rating: on line 4247-4270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 5743-4249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 4836-4250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 4892-4250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 4742-4252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2353
% INFO    : Updated Thermal Rating: on line 4847-4255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 5411-4255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 5008-4257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5657-4257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 4824-4258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5184-4260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 5741-4260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5444-4261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 5242-4264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 5242-4263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 5791-4267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3793
% INFO    : Updated Thermal Rating: on line 5745-4269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17958
% INFO    : Updated Thermal Rating: on line 5028-4271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 5747-4272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5717-4273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5882
% INFO    : Updated Thermal Rating: on line 5695-4276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 5763-4281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 5006-4287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 5378-4289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1485
% INFO    : Updated Thermal Rating: on line 5596-4289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 5618-4295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 5749-4296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 4287-4299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4118
% INFO    : Updated Thermal Rating: on line 5750-4300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9521
% INFO    : Updated Thermal Rating: on line 4320-4301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 4571-4301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5751-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1432
% INFO    : Updated Thermal Rating: on line 5384-4307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1423
% INFO    : Updated Thermal Rating: on line 5538-4307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5537-4306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4309-4308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 5393-4310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9387
% INFO    : Updated Thermal Rating: on line 5851-4313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 5752-4319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 5540-4323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 5594-4323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 4423-4327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on line 4624-4330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 4720-4329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5347-4329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 5348-4329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 5429-4330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 5689-4330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 5736-4330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on line 5734-4330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 5303-4333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4555-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 4553-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1431
% INFO    : Updated Thermal Rating: on line 4773-4344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 5757-4345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1047
% INFO    : Updated Thermal Rating: on line 4899-4346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 5078-4346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 5078-4346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 5397-4348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 5403-4349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 5781-4349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5831-4349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 5758-4352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6566
% INFO    : Updated Thermal Rating: on line 5154-4352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5380-4354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13344
% INFO    : Updated Thermal Rating: on line 4588-4357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 5044-4357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5228-4357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5419-4359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 5579-4359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4441-4360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4802-4361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 5240-4363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 5250-4363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 4428-4364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 4428-4364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 4721-4368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 4916-4369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5199-4369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on line 5402-4370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 4491-4373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 5763-4374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10315
% INFO    : Updated Thermal Rating: on line 5259-4376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 5381-4379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5596-4380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 5181-4383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5816-4384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 5764-4391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 4895-4394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5175-4401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 5124-4402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5767-4404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23137
% INFO    : Updated Thermal Rating: on line 4593-4406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30291
% INFO    : Updated Thermal Rating: on line 4874-4411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 5770-4415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17466
% INFO    : Updated Thermal Rating: on line 5771-4417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65055
% INFO    : Updated Thermal Rating: on line 5012-4424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 4999-4426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5771-4426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5313-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1536
% INFO    : Updated Thermal Rating: on line 5773-4429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 5772-4430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3780
% INFO    : Updated Thermal Rating: on line 5370-4432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4689-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 4883-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4689-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 4628-4435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 4862-4437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 4967-4437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5719-4438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2743
% INFO    : Updated Thermal Rating: on line 4676-4441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 4676-4441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 4758-4442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 4925-4442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 4759-4442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 5276-4449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 5775-4452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 5098-4455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 5820-4455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 4931-4458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 5776-4459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2162
% INFO    : Updated Thermal Rating: on line 4898-4460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5672-4460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 5155-4460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 5751-4462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5833-4463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13494
% INFO    : Updated Thermal Rating: on line 4537-4464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1141
% INFO    : Updated Thermal Rating: on line 4638-4465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 5148-4464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 5151-4465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 4908-4467 : Rate A, Rate B, Rate C , 1711.0, 1711.0, 1711.0 -> 811
% INFO    : Updated Thermal Rating: on line 4680-4471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 705
% INFO    : Updated Thermal Rating: on line 4500-4473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8432
% INFO    : Updated Thermal Rating: on line 5778-4475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4778-4477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 4488-4483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 4490-4487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4490-4486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4490-4485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4490-4484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 5015-4491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on line 5516-4491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 4807-4493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2033
% INFO    : Updated Thermal Rating: on line 5779-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23415
% INFO    : Updated Thermal Rating: on line 5185-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1313
% INFO    : Updated Thermal Rating: on line 5257-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 5568-4505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4609-4509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4809-4513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 5261-4513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 5781-4514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 4053-4516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4146-4516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 5249-4516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 926
% INFO    : Updated Thermal Rating: on line 5489-4521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5371-4522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 5784-4523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on line 4855-4526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5785-4530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3667
% INFO    : Updated Thermal Rating: on line 4330-4531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 4330-4531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 5710-4533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 4836-4536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 4892-4536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 5283-4541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on line 5743-4543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14657
% INFO    : Updated Thermal Rating: on line 5752-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5517-4546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16578
% INFO    : Updated Thermal Rating: on line 5518-4546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15848
% INFO    : Updated Thermal Rating: on line 5789-4549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1162
% INFO    : Updated Thermal Rating: on line 4577-4551 : Rate A, Rate B, Rate C , 2961.0, 2961.0, 2961.0 -> 1589
% INFO    : Updated Thermal Rating: on line 4577-4551 : Rate A, Rate B, Rate C , 2961.0, 2961.0, 2961.0 -> 1589
% INFO    : Updated Thermal Rating: on line 5396-4556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14447
% INFO    : Updated Thermal Rating: on line 5525-4558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 5701-4558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 5823-4558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 5824-4558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 917
% INFO    : Updated Thermal Rating: on line 5822-4577 : Rate A, Rate B, Rate C , 2450.0, 2450.0, 2450.0 -> 1390
% INFO    : Updated Thermal Rating: on line 5591-4582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 5637-4583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 4584-4585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 4800-4585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 5793-4585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 5795-4587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 4747-4588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 5148-4589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5269-4595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 4664-4597 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2158
% INFO    : Updated Thermal Rating: on line 4664-4596 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2153
% INFO    : Updated Thermal Rating: on line 5796-4600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13100
% INFO    : Updated Thermal Rating: on line 5798-4604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 5799-4606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3538
% INFO    : Updated Thermal Rating: on line 4806-4610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 5483-4610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5588-4610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 5636-4610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1639
% INFO    : Updated Thermal Rating: on line 5739-4610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 5061-4613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4291
% INFO    : Updated Thermal Rating: on line 5639-4613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 5468-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 4870-4617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5324-4617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 5477-4617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 5626-4618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 5663-4618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 5801-4621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 4645-4622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 4981-4628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 5622-4630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5802-4631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 5529-4632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 5111-4633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5252-4633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1393
% INFO    : Updated Thermal Rating: on line 5226-4635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 5804-4636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 4801-4639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 4669-4646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on line 4651-4649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 4666-4649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 5131-4649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 4666-4649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 5511-4655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13395
% INFO    : Updated Thermal Rating: on line 4793-4658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 4813-4658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5247-4661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 4745-4665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1837
% INFO    : Updated Thermal Rating: on line 5808-4667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4904-4676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5260-4679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 5144-4681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 5188-4682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5814-4685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2828
% INFO    : Updated Thermal Rating: on line 4855-4688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5811-4689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52720
% INFO    : Updated Thermal Rating: on line 5816-4701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 5818-4715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 5820-4718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 5147-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5145-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 5460-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5353-4727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1011
% INFO    : Updated Thermal Rating: on line 5821-4729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 5835-4730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2122
% INFO    : Updated Thermal Rating: on line 4621-4734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245373
% INFO    : Updated Thermal Rating: on line 5832-4741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3957
% INFO    : Updated Thermal Rating: on line 5150-4747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5687-4747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5775-4750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 4931-4761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5468-4761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5213-4766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5628-4776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 5550-4779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1106
% INFO    : Updated Thermal Rating: on line 4809-4781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 985
% INFO    : Updated Thermal Rating: on line 5376-4783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5670-4783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5176-4785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5826-4786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5680-4788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5325-4790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 4813-4792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5285-4792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8426
% INFO    : Updated Thermal Rating: on line 5239-4794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5827-4798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2647
% INFO    : Updated Thermal Rating: on line 5661-4800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 4926-4802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 4926-4802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 4996-4803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59
% INFO    : Updated Thermal Rating: on line 5829-4805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 5636-4806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 5536-4808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 5201-4810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5807
% INFO    : Updated Thermal Rating: on line 5780-4810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 5300-4814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5309-4815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 5080-4832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 5316-4832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 5414-4832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 5500-4832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 5003-4840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2535
% INFO    : Updated Thermal Rating: on line 5003-4840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3804
% INFO    : Updated Thermal Rating: on line 5730-4842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 4905-4844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 5811-4848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1089
% INFO    : Updated Thermal Rating: on line 4970-4850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5798-4850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 4970-4850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 5158-4851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 4894-4855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 4856-4857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10572
% INFO    : Updated Thermal Rating: on line 5810-4857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 5839-4857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5515-4867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5140-4869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 5594-4869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 5832-4872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23430
% INFO    : Updated Thermal Rating: on line 4905-4877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4905-4878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 5254-4879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 5086-4883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 5836-4902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5628-4905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 5241-4909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 5837-4910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3033
% INFO    : Updated Thermal Rating: on line 5173-4911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 5425-4920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 4945-4920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 5704-4931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 5729-4931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5789-4931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 4934-4933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5838-4936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116592
% INFO    : Updated Thermal Rating: on line 5673-4948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5839-4951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9817
% INFO    : Updated Thermal Rating: on line 5102-4957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 5590-4959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on line 5640-4959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 5711-4959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 5487-4964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 5286-4966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 5455-4966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 5840-4967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 5841-4968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2174
% INFO    : Updated Thermal Rating: on line 5164-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on line 5165-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 5469-4973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 5314-4974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 5842-4975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12855
% INFO    : Updated Thermal Rating: on line 5841-4976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5166-4982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5551-4986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 4994-4992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4994-4991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4995-4990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 5248-4997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5259-4997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 5831-5003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2438
% INFO    : Updated Thermal Rating: on line 5843-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 5610-5006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 5655-5006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1562
% INFO    : Updated Thermal Rating: on line 5398-5006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1449
% INFO    : Updated Thermal Rating: on line 5657-5008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5783-5008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 5750-5010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 5301-5011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5633-5012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 5844-5016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1478
% INFO    : Updated Thermal Rating: on line 5845-5019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3024
% INFO    : Updated Thermal Rating: on line 5846-5019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2864
% INFO    : Updated Thermal Rating: on line 5549-5023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5100-5024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5680-5030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9602
% INFO    : Updated Thermal Rating: on line 5663-5032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 5847-5033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5262-5036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5146-5037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8991
% INFO    : Updated Thermal Rating: on line 5092-5039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 5246-5041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 5809-5042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 5650-5048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13450
% INFO    : Updated Thermal Rating: on line 4993-5053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 5767-5053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5523-5057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5074-5066 : Rate A, Rate B, Rate C , 2275.0, 2275.0, 2275.0 -> 2203
% INFO    : Updated Thermal Rating: on line 5492-5079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5343-5081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 5852-5081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 5851-5087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on line 5854-5091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24046
% INFO    : Updated Thermal Rating: on line 5773-5096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 5361-5109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 5554-5109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 5754-5117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 5584-5122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3790
% INFO    : Updated Thermal Rating: on line 5400-5130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 5154-5136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5606-5137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5965
% INFO    : Updated Thermal Rating: on line 5758-5168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5290-5176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5854-5202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 5232-5210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 5500-5216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 5349-5217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5451-5224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 5716-5225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11707
% INFO    : Updated Thermal Rating: on line 5294-5281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 5243-5299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 5438-5360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5598-5364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 5723-5380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 5612-5398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1273
% INFO    : Updated Thermal Rating: on line 5504-5413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2284
% INFO    : Updated Thermal Rating: on line 5748-5421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 5558-5434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3270
% INFO    : Updated Thermal Rating: on line 5453-5694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 5654-5477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1451
% INFO    : Updated Thermal Rating: on line 5585-5479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 5733-5490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 5555-5498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 5254-5510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 5669-5510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 5785-5511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6303
% INFO    : Updated Thermal Rating: on line 5591-5524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 5823-5527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5454-5544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 926
% INFO    : Updated Thermal Rating: on line 5575-5635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 5601-5603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 5613-5611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245373
% INFO    : Updated Thermal Rating: on line 5769-5621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5641-5643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9287
% INFO    : Updated Thermal Rating: on line 5816-5653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 5765-5682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 5840-5756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5842-5785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6303
% INFO    : Updated Thermal Rating: on line 6054-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7982
% INFO    : Updated Thermal Rating: on line 6086-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3115
% INFO    : Updated Thermal Rating: on line 6045-5959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12240
% INFO    : Updated Thermal Rating: on line 6122-5959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2843
% INFO    : Updated Thermal Rating: on line 6130-5959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2276
% INFO    : Updated Thermal Rating: on line 6150-5959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2213
% INFO    : Updated Thermal Rating: on line 4416-5960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10754
% INFO    : Updated Thermal Rating: on line 6222-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4405
% INFO    : Updated Thermal Rating: on line 6222-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4405
% INFO    : Updated Thermal Rating: on line 6058-5963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 6095-5963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6894
% INFO    : Updated Thermal Rating: on line 6101-5963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6513
% INFO    : Updated Thermal Rating: on line 5994-5966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 6165-5968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 6221-5968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1525
% INFO    : Updated Thermal Rating: on line 6238-5968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12439
% INFO    : Updated Thermal Rating: on line 6169-5970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 6037-5971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 6068-5971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 6244-5971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 6253-5971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 6069-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 6111-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2933
% INFO    : Updated Thermal Rating: on line 6155-5973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3141
% INFO    : Updated Thermal Rating: on line 5985-5974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2839
% INFO    : Updated Thermal Rating: on line 6165-5975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3084
% INFO    : Updated Thermal Rating: on line 6051-5976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1009
% INFO    : Updated Thermal Rating: on line 6171-5976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9134
% INFO    : Updated Thermal Rating: on line 6175-5977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5050
% INFO    : Updated Thermal Rating: on line 6188-5978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 2666-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 977
% INFO    : Updated Thermal Rating: on line 6232-5980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 6233-5981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4495
% INFO    : Updated Thermal Rating: on line 6100-5982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10163
% INFO    : Updated Thermal Rating: on line 6214-5982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15043
% INFO    : Updated Thermal Rating: on line 6017-5984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 6017-5983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 6133-5984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1230
% INFO    : Updated Thermal Rating: on line 6140-5983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on line 5992-5987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 6196-5987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5512
% INFO    : Updated Thermal Rating: on line 6133-5989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 6190-5989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 5996-5990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6412
% INFO    : Updated Thermal Rating: on line 6028-5991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4239
% INFO    : Updated Thermal Rating: on line 6112-5991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3048
% INFO    : Updated Thermal Rating: on line 6101-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2790
% INFO    : Updated Thermal Rating: on line 6117-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1623
% INFO    : Updated Thermal Rating: on line 6196-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 5855-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10739
% INFO    : Updated Thermal Rating: on line 5869-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9685
% INFO    : Updated Thermal Rating: on line 5868-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9522
% INFO    : Updated Thermal Rating: on line 6249-5995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 5862-5997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 6084-5997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 6084-5997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 6000-5999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 6006-6001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3733
% INFO    : Updated Thermal Rating: on line 6115-6001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3493
% INFO    : Updated Thermal Rating: on line 805-6003 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1033
% INFO    : Updated Thermal Rating: on line 6072-6002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 6133-6002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 6165-6002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13437
% INFO    : Updated Thermal Rating: on line 6165-6002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10336
% INFO    : Updated Thermal Rating: on line 6165-6002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10336
% INFO    : Updated Thermal Rating: on line 6132-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4661
% INFO    : Updated Thermal Rating: on line 6164-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4902
% INFO    : Updated Thermal Rating: on line 6221-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1460
% INFO    : Updated Thermal Rating: on line 6171-6005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 6190-6005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3569
% INFO    : Updated Thermal Rating: on line 6164-6008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5656
% INFO    : Updated Thermal Rating: on line 6238-6008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4356
% INFO    : Updated Thermal Rating: on line 6143-6011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4032
% INFO    : Updated Thermal Rating: on line 6178-6011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 6051-6013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3568
% INFO    : Updated Thermal Rating: on line 6171-6013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1333
% INFO    : Updated Thermal Rating: on line 6136-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2974
% INFO    : Updated Thermal Rating: on line 6136-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 6186-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21158
% INFO    : Updated Thermal Rating: on line 6186-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21158
% INFO    : Updated Thermal Rating: on line 1762-6015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5474-6015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 6002-6017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 6002-6017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 6216-6018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2833
% INFO    : Updated Thermal Rating: on line 6094-6024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 6250-6024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6060
% INFO    : Updated Thermal Rating: on line 5858-6025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9771
% INFO    : Updated Thermal Rating: on line 5857-6025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9748
% INFO    : Updated Thermal Rating: on line 6070-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 6071-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 6172-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 6091-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3080
% INFO    : Updated Thermal Rating: on line 6104-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3518
% INFO    : Updated Thermal Rating: on line 6104-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3518
% INFO    : Updated Thermal Rating: on line 6113-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1781
% INFO    : Updated Thermal Rating: on line 5856-6032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12649
% INFO    : Updated Thermal Rating: on line 6076-6034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 6077-6033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 6249-6034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1551
% INFO    : Updated Thermal Rating: on line 6248-6033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 6094-6035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2357
% INFO    : Updated Thermal Rating: on line 6113-6036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 6112-6036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 6073-6037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 6085-6037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2624
% INFO    : Updated Thermal Rating: on line 6243-6037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on line 5858-6040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9186
% INFO    : Updated Thermal Rating: on line 5857-6040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9482
% INFO    : Updated Thermal Rating: on line 6220-6041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8417
% INFO    : Updated Thermal Rating: on line 6104-6043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8447
% INFO    : Updated Thermal Rating: on line 6104-6043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8447
% INFO    : Updated Thermal Rating: on line 5863-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4327
% INFO    : Updated Thermal Rating: on line 6234-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1315
% INFO    : Updated Thermal Rating: on line 6069-6045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8719
% INFO    : Updated Thermal Rating: on line 6130-6045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9496
% INFO    : Updated Thermal Rating: on line 6121-6046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 6153-6046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 6213-6046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50827
% INFO    : Updated Thermal Rating: on line 6159-6048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12717
% INFO    : Updated Thermal Rating: on line 6210-6048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7215
% INFO    : Updated Thermal Rating: on line 6056-6050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4573
% INFO    : Updated Thermal Rating: on line 6146-6050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 6169-6050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on line 6194-6050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2456
% INFO    : Updated Thermal Rating: on line 6229-6051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5222
% INFO    : Updated Thermal Rating: on line 6229-6051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5222
% INFO    : Updated Thermal Rating: on line 6091-6055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5223
% INFO    : Updated Thermal Rating: on line 6091-6055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5223
% INFO    : Updated Thermal Rating: on line 6251-6055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2681
% INFO    : Updated Thermal Rating: on line 6152-6056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5467
% INFO    : Updated Thermal Rating: on line 6099-6057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2347
% INFO    : Updated Thermal Rating: on line 6061-6060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 6061-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 6210-6060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1674
% INFO    : Updated Thermal Rating: on line 6210-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1674
% INFO    : Updated Thermal Rating: on line 6127-6061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 6127-6061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 6070-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 6146-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 6161-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 6240-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 6073-6067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 6083-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3035
% INFO    : Updated Thermal Rating: on line 6130-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 6158-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 6176-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3773
% INFO    : Updated Thermal Rating: on line 6212-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 6071-6070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 6182-6070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 6200-6071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29308
% INFO    : Updated Thermal Rating: on line 6133-6072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 6242-6073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 6253-6073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 6121-6075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 6149-6075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 6098-6076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2790
% INFO    : Updated Thermal Rating: on line 6099-6077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2813
% INFO    : Updated Thermal Rating: on line 6133-6078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1926
% INFO    : Updated Thermal Rating: on line 6190-6078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 6254-6079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3003
% INFO    : Updated Thermal Rating: on line 6254-6079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3003
% INFO    : Updated Thermal Rating: on line 6084-6080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 6240-6080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2050
% INFO    : Updated Thermal Rating: on line 6111-6083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4385
% INFO    : Updated Thermal Rating: on line 6158-6083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 6176-6083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 6212-6083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 6161-6084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14302
% INFO    : Updated Thermal Rating: on line 6143-6085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 6143-6085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 899
% INFO    : Updated Thermal Rating: on line 6253-6085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8735
% INFO    : Updated Thermal Rating: on line 6232-6087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 6151-6089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344932
% INFO    : Updated Thermal Rating: on line 6151-6089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344932
% INFO    : Updated Thermal Rating: on line 5859-6090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222473
% INFO    : Updated Thermal Rating: on line 6142-6091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2451
% INFO    : Updated Thermal Rating: on line 6099-6093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5936
% INFO    : Updated Thermal Rating: on line 6097-6092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5070
% INFO    : Updated Thermal Rating: on line 5870-6095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2799
% INFO    : Updated Thermal Rating: on line 6100-6094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22600
% INFO    : Updated Thermal Rating: on line 6100-6094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22600
% INFO    : Updated Thermal Rating: on line 5860-6096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252116
% INFO    : Updated Thermal Rating: on line 6107-6097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 6140-6098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1454
% INFO    : Updated Thermal Rating: on line 6214-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6883
% INFO    : Updated Thermal Rating: on line 6217-6101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2353
% INFO    : Updated Thermal Rating: on line 6132-6105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on line 6221-6105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 6156-6106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6857
% INFO    : Updated Thermal Rating: on line 6156-6106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6857
% INFO    : Updated Thermal Rating: on line 6133-6107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 935
% INFO    : Updated Thermal Rating: on line 6124-6109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7176
% INFO    : Updated Thermal Rating: on line 6150-6114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1703
% INFO    : Updated Thermal Rating: on line 6186-6114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on line 6212-6114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 6157-6115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2832
% INFO    : Updated Thermal Rating: on line 6247-6115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2522
% INFO    : Updated Thermal Rating: on line 6124-6118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4297
% INFO    : Updated Thermal Rating: on line 6218-6123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6641
% INFO    : Updated Thermal Rating: on line 5862-6126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345173
% INFO    : Updated Thermal Rating: on line 6220-6126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9695
% INFO    : Updated Thermal Rating: on line 6129-6127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3213
% INFO    : Updated Thermal Rating: on line 6159-6129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2708
% INFO    : Updated Thermal Rating: on line 6158-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22626
% INFO    : Updated Thermal Rating: on line 5863-6131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17394
% INFO    : Updated Thermal Rating: on line 6192-6131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1355
% INFO    : Updated Thermal Rating: on line 6234-6131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 6155-6133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2638
% INFO    : Updated Thermal Rating: on line 6144-6137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4262
% INFO    : Updated Thermal Rating: on line 6220-6137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2064
% INFO    : Updated Thermal Rating: on line 5864-6138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240858
% INFO    : Updated Thermal Rating: on line 6182-6139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4379
% INFO    : Updated Thermal Rating: on line 6182-6139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4379
% INFO    : Updated Thermal Rating: on line 6185-6141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 6195-6143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 6220-6144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4013
% INFO    : Updated Thermal Rating: on line 6169-6146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 6161-6151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2696
% INFO    : Updated Thermal Rating: on line 6161-6151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2698
% INFO    : Updated Thermal Rating: on line 6194-6152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5431
% INFO    : Updated Thermal Rating: on line 6157-6156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6857
% INFO    : Updated Thermal Rating: on line 6176-6158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3007
% INFO    : Updated Thermal Rating: on line 6212-6158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3983
% INFO    : Updated Thermal Rating: on line 6222-6158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 6182-6161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 6240-6161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 6239-6162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19968
% INFO    : Updated Thermal Rating: on line 2241-6163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1752
% INFO    : Updated Thermal Rating: on line 6221-6165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 5866-6170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69049
% INFO    : Updated Thermal Rating: on line 36-6205 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 873
% INFO    : Updated Thermal Rating: on line 35-6204 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 950
% INFO    : Updated Thermal Rating: on line 6225-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4262
% INFO    : Updated Thermal Rating: on line 6205-6174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245589
% INFO    : Updated Thermal Rating: on line 6216-6174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8451
% INFO    : Updated Thermal Rating: on line 6212-6176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43571
% INFO    : Updated Thermal Rating: on line 6178-6177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 6213-6177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 5863-6181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on line 5865-6188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3404
% INFO    : Updated Thermal Rating: on line 6231-6190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3347
% INFO    : Updated Thermal Rating: on line 6234-6192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 5858-6219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3368
% INFO    : Updated Thermal Rating: on line 5857-6219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3374
% INFO    : Updated Thermal Rating: on line 5862-6220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9679
% INFO    : Updated Thermal Rating: on line 6229-6225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 5868-6227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6972
% INFO    : Updated Thermal Rating: on line 323-6233 : Rate A, Rate B, Rate C , 1624.0, 1624.0, 1624.0 -> 1498
% INFO    : Updated Thermal Rating: on line 5870-6237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12963
% INFO    : Updated Thermal Rating: on line 6253-6241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on transformer 26-27 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 26-27 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 26-27 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 31-33 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 31-34 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 32-33 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 35-5899 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1111
% INFO    : Updated Thermal Rating: on line 35-5923 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1111
% INFO    : Updated Thermal Rating: on transformer 50-51 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 50-51 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 50-51 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 103-104 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 103-104 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 109-110 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 109-110 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 112-113 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 112-113 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 112-113 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 128-130 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 129-130 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 137-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 139-140 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 142-143 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 142-143 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 144-145 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 285
% INFO    : Updated Thermal Rating: on transformer 144-146 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 201
% INFO    : Updated Thermal Rating: on transformer 144-146 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 201
% INFO    : Updated Thermal Rating: on line 146-5871 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1094
% INFO    : Updated Thermal Rating: on line 146-5924 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1070
% INFO    : Updated Thermal Rating: on transformer 156-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on transformer 153-154 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 324
% INFO    : Updated Thermal Rating: on transformer 157-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 165-168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 166-168 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 166-168 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 166-168 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 167-168 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 171-172 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 171-172 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 273
% INFO    : Updated Thermal Rating: on line 180-5900 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 303
% INFO    : Updated Thermal Rating: on line 180-5925 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 203-204 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 346
% INFO    : Updated Thermal Rating: on transformer 203-204 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 346
% INFO    : Updated Thermal Rating: on transformer 214-215 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 214-215 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 214-215 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 221-222 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 233-234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 246-247 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 256-257 : Rate A, Rate B, Rate C , 459.0, 459.0, 459.0 -> 292
% INFO    : Updated Thermal Rating: on transformer 259-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 259-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 272-273 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 272-273 : Rate A, Rate B, Rate C , 447.0, 447.0, 447.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 277-278 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 277-278 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 313-314 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 313-314 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 321-323 : Rate A, Rate B, Rate C , 1020.0, 1020.0, 1020.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 321-323 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 321-323 : Rate A, Rate B, Rate C , 1016.0, 1016.0, 1016.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 326-327 : Rate A, Rate B, Rate C , 433.0, 433.0, 433.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 326-327 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 330-331 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 330-331 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 342-343 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 360-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 360-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 360-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 360-362 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 378-379 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 378-379 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 422-423 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 422-423 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 424-425 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 424-425 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 424-425 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 445-446 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 443-446 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 444-446 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 448-449 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 448-449 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 452-453 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 452-453 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 457-458 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on line 459-5872 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1169
% INFO    : Updated Thermal Rating: on line 459-5901 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 464-465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 478-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 480-481 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 480-481 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 480-481 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 504-505 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 504-505 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 512-513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 521-523 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 522-523 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 526-527 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 526-527 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 526-527 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 535-536 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 535-536 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 535-536 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 544-545 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 550-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 563-564 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 602-603 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 602-603 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 607-608 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 607-608 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 610-611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 627-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 658-659 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 658-659 : Rate A, Rate B, Rate C , 718.0, 718.0, 718.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 673-674 : Rate A, Rate B, Rate C , 337.0, 337.0, 337.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 682-683 : Rate A, Rate B, Rate C , 530.0, 530.0, 530.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 700-701 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 700-701 : Rate A, Rate B, Rate C , 300.0, 300.0, 300.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 702-705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 703-705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 704-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 707-709 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 707-709 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 714-717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 713-717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 712-717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 716-717 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 715-717 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 715-717 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 730-732 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 731-732 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 730-732 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 747-748 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 747-748 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 252
% INFO    : Updated Thermal Rating: on line 760-5873 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1169
% INFO    : Updated Thermal Rating: on line 760-5903 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 767-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 773-774 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 773-774 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 773-774 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 775-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 776-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 777-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 781-782 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 792-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 791-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 793-795 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 794-795 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 804-805 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 808-810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 807-810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 806-809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 854-855 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 854-855 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 854-855 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 857-858 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 857-858 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 858-859 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 566
% INFO    : Updated Thermal Rating: on transformer 884-886 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 885-886 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 884-886 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 894-895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 928-929 : Rate A, Rate B, Rate C , 1629.0, 1629.0, 1629.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 928-929 : Rate A, Rate B, Rate C , 1629.0, 1629.0, 1629.0 -> 320
% INFO    : Updated Thermal Rating: on line 940-5927 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 894
% INFO    : Updated Thermal Rating: on line 939-5941 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 974
% INFO    : Updated Thermal Rating: on line 940-5951 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 987
% INFO    : Updated Thermal Rating: on transformer 942-943 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 942-943 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 942-943 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 953-954 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 953-954 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 958-959 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 958-959 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 318
% INFO    : Updated Thermal Rating: on transformer 965-966 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 335
% INFO    : Updated Thermal Rating: on transformer 965-966 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 330
% INFO    : Updated Thermal Rating: on transformer 965-966 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 966-968 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1177
% INFO    : Updated Thermal Rating: on transformer 970-971 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 137
% INFO    : Updated Thermal Rating: on transformer 970-971 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 137
% INFO    : Updated Thermal Rating: on transformer 970-971 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 137
% INFO    : Updated Thermal Rating: on transformer 973-974 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 973-974 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 979-980 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 979-980 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 981-982 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 220
% INFO    : Updated Thermal Rating: on transformer 993-995 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 993-995 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 1001-1002 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1000-5876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 1001-1003 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 1001-1003 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 1016-1017 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1016-1017 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1031-1033 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1038-1039 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1038-1039 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1039-1040 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1168
% INFO    : Updated Thermal Rating: on transformer 1039-1040 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1165
% INFO    : Updated Thermal Rating: on line 1042-5928 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 959
% INFO    : Updated Thermal Rating: on transformer 1046-1047 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1046-1047 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1045-1047 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 1063-1064 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1063-1064 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1063-1064 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1063-1064 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1068-1069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 1068-1069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 1068-1069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 1076-1077 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1162
% INFO    : Updated Thermal Rating: on transformer 1076-1077 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1159
% INFO    : Updated Thermal Rating: on line 1077-5929 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 985
% INFO    : Updated Thermal Rating: on transformer 1078-1079 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1078-1079 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1092-1093 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1113-1114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 1116-1117 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1116-1117 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1135-1136 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1135-1136 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1141-1143 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1142-1143 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 1146-1147 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1146-1147 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 1150-1151 : Rate A, Rate B, Rate C , 1038.0, 1038.0, 1038.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 1157-1158 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1157-1158 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 1156-1158 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 1164-1167 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 311
% INFO    : Updated Thermal Rating: on transformer 1165-1167 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 1166-1167 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 1174-1175 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 1174-1175 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 1174-1175 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 334
% INFO    : Updated Thermal Rating: on transformer 1174-1175 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 1195-1196 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1194-1196 : Rate A, Rate B, Rate C , 466.0, 466.0, 466.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 1195-1197 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1199-1200 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 1199-1200 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1153
% INFO    : Updated Thermal Rating: on transformer 1202-1203 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 1202-1203 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1208-1209 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1208-1209 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1211-1212 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 1211-1212 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1211-1212 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1229-1230 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 1237-1236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6597
% INFO    : Updated Thermal Rating: on transformer 1239-1241 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1238-1241 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 1239-1242 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1244-1245 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 1247-1248 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 1247-1248 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 1247-1248 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1249-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 1249-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 1251-1252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1258-1259 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1258-1259 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 1263-1265 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 1264-1265 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1263-1265 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1308-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 1309-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 1325-1326 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1325-1326 : Rate A, Rate B, Rate C , 316.0, 316.0, 316.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 1332-1333 : Rate A, Rate B, Rate C , 310.0, 310.0, 310.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1332-1333 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1335-1336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 1343-1344 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1345-1346 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1345-1346 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 1349-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1357-1358 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 338
% INFO    : Updated Thermal Rating: on transformer 1357-1358 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 1357-1358 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 330
% INFO    : Updated Thermal Rating: on transformer 1359-1360 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 1359-1360 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 1359-1360 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 1380-1381 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 1386-1387 : Rate A, Rate B, Rate C , 729.0, 729.0, 729.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1386-1387 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 1386-1387 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1407-1408 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1409-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 1410-1411 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1410-1411 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1434-1435 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 1434-1435 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 1441-1442 : Rate A, Rate B, Rate C , 740.0, 740.0, 740.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1441-1442 : Rate A, Rate B, Rate C , 740.0, 740.0, 740.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1445-1446 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 1444-1446 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1456-1457 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 210
% INFO    : Updated Thermal Rating: on transformer 1459-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1462-1463 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1462-1463 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 248
% INFO    : Updated Thermal Rating: on line 1464-5877 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 1465-1466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on transformer 1465-1467 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 1465-1467 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 1473-1474 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 1479-1480 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1479-1480 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1485-1487 : Rate A, Rate B, Rate C , 545.0, 545.0, 545.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1503-1504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1518-1519 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 343
% INFO    : Updated Thermal Rating: on transformer 1518-1519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 1518-1519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 1519-1520 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1153
% INFO    : Updated Thermal Rating: on transformer 1519-1520 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 1523-1525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 1522-1525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 1526-1527 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1526-1527 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1533-1535 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1534-1535 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1533-1535 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1533-1536 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 316
% INFO    : Updated Thermal Rating: on line 1536-5942 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1016
% INFO    : Updated Thermal Rating: on line 1536-5953 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1039
% INFO    : Updated Thermal Rating: on transformer 1543-1544 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 305
% INFO    : Updated Thermal Rating: on transformer 1543-1544 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 305
% INFO    : Updated Thermal Rating: on transformer 1564-1565 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 1564-1565 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1564-1565 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 1588-1589 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 1588-1589 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1598-1600 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1599-1600 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 272
% INFO    : Updated Thermal Rating: on line 1601-5878 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 999
% INFO    : Updated Thermal Rating: on transformer 1602-1603 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1602-1603 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1602-1604 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 1614-1615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 1614-1615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 1617-1618 : Rate A, Rate B, Rate C , 428.0, 428.0, 428.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1616-1618 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1616-1618 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 1620-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 1638-1639 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1638-1639 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1638-1639 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1669-1670 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 1669-1670 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 1673-1674 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1673-1674 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1682-1683 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1682-1683 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 1689-1690 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1689-1690 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1708-1711 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 1709-1713 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 1709-1710 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1708-1712 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 287
% INFO    : Updated Thermal Rating: on transformer 1717-1718 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 1717-1718 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 1722-1723 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1722-1723 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 1728-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1735-1737 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1735-1737 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1749-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 1748-1751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 1747-1750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 1753-1755 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1754-1755 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 1776-1779 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 1777-1779 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 1778-1779 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1778-1779 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1778-1779 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 1781-1782 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 1781-1782 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 1781-1782 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 293
% INFO    : Updated Thermal Rating: on transformer 1786-1787 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1786-1787 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1792-1793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 1792-1794 : Rate A, Rate B, Rate C , 310.0, 310.0, 310.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 1792-1794 : Rate A, Rate B, Rate C , 442.0, 442.0, 442.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 1792-1794 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1793-1794 : Rate A, Rate B, Rate C , 301.0, 301.0, 301.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 1795-1796 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1795-1796 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1804-1805 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1811-1812 : Rate A, Rate B, Rate C , 557.0, 557.0, 557.0 -> 212
% INFO    : Updated Thermal Rating: on transformer 1811-1812 : Rate A, Rate B, Rate C , 579.0, 579.0, 579.0 -> 208
% INFO    : Updated Thermal Rating: on transformer 1823-1824 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1823-1824 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1827-1828 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1832-1833 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1832-1833 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1838-1839 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1838-1839 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 1843-1844 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1843-1844 : Rate A, Rate B, Rate C , 448.0, 448.0, 448.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1883-1884 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1897-1901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1896-1900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1895-1899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1894-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1904-1905 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1904-1905 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1906-1907 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1913-1914 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1913-1914 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1928-1929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1928-1929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 1930-1931 : Rate A, Rate B, Rate C , 717.0, 717.0, 717.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 1934-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 1936-5907 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1158
% INFO    : Updated Thermal Rating: on transformer 1937-1938 : Rate A, Rate B, Rate C , 1011.0, 1011.0, 1011.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 1943-1945 : Rate A, Rate B, Rate C , 315.0, 315.0, 315.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 1943-1946 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 323
% INFO    : Updated Thermal Rating: on transformer 1944-1946 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 319
% INFO    : Updated Thermal Rating: on transformer 1972-1978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1971-1976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1970-1975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1969-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1968-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1981-1984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on transformer 1990-1991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on transformer 1990-1992 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 1991-1992 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 1991-1992 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 1997-1998 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1997-1998 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1997-1998 : Rate A, Rate B, Rate C , 758.0, 758.0, 758.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 2012-2013 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 2012-2013 : Rate A, Rate B, Rate C , 337.0, 337.0, 337.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 2040-2041 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2040-2041 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 2049-2050 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 2048-2050 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2056-2057 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 2056-2057 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 2056-2057 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 2073-2075 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 2073-2074 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 2077-2078 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 2077-2078 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2086-2087 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 2086-2087 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 238
% INFO    : Updated Thermal Rating: on line 2089-5879 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on transformer 2093-2095 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 2093-2095 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 2096-2097 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2096-2097 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2104-2105 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2104-2105 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2104-2105 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 2112-2113 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2112-2113 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2112-2113 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 2125-2126 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 2125-2126 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2129-2132 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2128-2131 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 2128-2130 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2133-2135 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2134-2135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 2134-2135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 2137-2138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 2137-2138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 2137-2139 : Rate A, Rate B, Rate C , 560.0, 560.0, 560.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 2137-2139 : Rate A, Rate B, Rate C , 604.0, 604.0, 604.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 2143-2144 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 2143-2144 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2148-2149 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 2148-2149 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 2162-2163 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 2166-2167 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 282
% INFO    : Updated Thermal Rating: on transformer 2173-2176 : Rate A, Rate B, Rate C , 701.0, 701.0, 701.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 2173-2175 : Rate A, Rate B, Rate C , 701.0, 701.0, 701.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 2185-2186 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 267
% INFO    : Updated Thermal Rating: on line 2186-5930 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 278
% INFO    : Updated Thermal Rating: on line 2186-5943 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 348
% INFO    : Updated Thermal Rating: on transformer 2197-2198 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 2197-2198 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 2223-2224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2228-2229 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 2233-2234 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 2233-2234 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 2236-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2241-2242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 2241-2242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 2247-5880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on transformer 2248-5880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29046
% INFO    : Updated Thermal Rating: on line 2249-5880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 2254-2255 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2254-2255 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2263-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 2263-2265 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 210
% INFO    : Updated Thermal Rating: on transformer 2263-2265 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2264-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on transformer 2268-2270 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2272-2273 : Rate A, Rate B, Rate C , 316.0, 316.0, 316.0 -> 282
% INFO    : Updated Thermal Rating: on transformer 2272-2273 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 282
% INFO    : Updated Thermal Rating: on transformer 2272-2273 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2289-2290 : Rate A, Rate B, Rate C , 1018.0, 1018.0, 1018.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 2292-2293 : Rate A, Rate B, Rate C , 428.0, 428.0, 428.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 2292-2293 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2298-2299 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2298-2299 : Rate A, Rate B, Rate C , 474.0, 474.0, 474.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 2308-2309 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 2308-2309 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2314-2315 : Rate A, Rate B, Rate C , 437.0, 437.0, 437.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2314-2315 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2314-2315 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2327-2328 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2334-2336 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2335-2336 : Rate A, Rate B, Rate C , 447.0, 447.0, 447.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2335-2336 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 2344-2346 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2344-2346 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2345-2346 : Rate A, Rate B, Rate C , 337.0, 337.0, 337.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 2368-2374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2367-2372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2366-2371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2365-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2364-2369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2375-2376 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2375-2376 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2423-2425 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 234
% INFO    : Updated Thermal Rating: on transformer 2423-2424 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2427-2428 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 2431-2432 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2431-2432 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2430-2432 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 2430-2432 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2446-2447 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 2446-2448 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 2446-2448 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2447-2448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 2457-2458 : Rate A, Rate B, Rate C , 1243.0, 1243.0, 1243.0 -> 301
% INFO    : Updated Thermal Rating: on transformer 2457-2458 : Rate A, Rate B, Rate C , 1243.0, 1243.0, 1243.0 -> 315
% INFO    : Updated Thermal Rating: on line 2467-5908 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on line 2467-5931 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1089
% INFO    : Updated Thermal Rating: on transformer 2468-2469 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2468-2469 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2468-2470 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 2468-2470 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 2482-2484 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 336
% INFO    : Updated Thermal Rating: on transformer 2483-2484 : Rate A, Rate B, Rate C , 530.0, 530.0, 530.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 2482-2484 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 2489-2490 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2489-2490 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2502-2503 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2502-2503 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2509-2510 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2514-2515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 2514-2515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 2516-2517 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2516-2517 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2523-2524 : Rate A, Rate B, Rate C , 437.0, 437.0, 437.0 -> 295
% INFO    : Updated Thermal Rating: on transformer 2539-2540 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2548-2549 : Rate A, Rate B, Rate C , 278.0, 278.0, 278.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2548-2550 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 2548-2550 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2549-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on transformer 2559-2560 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 2559-2560 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 2566-2567 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2566-2567 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2566-2567 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2570-2571 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 2570-2571 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 2577-2578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 2577-2580 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2578-2580 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 2578-2580 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 2579-2580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 2583-2584 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 348
% INFO    : Updated Thermal Rating: on transformer 2583-2584 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 2594-2595 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2594-2595 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2594-2595 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2594-2595 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2605-2607 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 2605-2606 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 2625-2626 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 2633-2635 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 2634-2635 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2633-2635 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 2654-2655 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2660-2661 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 2660-2661 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 2663-2665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7637
% INFO    : Updated Thermal Rating: on transformer 2662-5932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on transformer 2664-2666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on transformer 2665-5932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12244
% INFO    : Updated Thermal Rating: on line 2666-5932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on transformer 2667-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 2669-2670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 2675-2676 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2675-2676 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2675-2676 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2684-2685 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2703-2704 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 2703-2704 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2705-2707 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2705-2707 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 2706-2707 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2724-2725 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 2724-2725 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2753-2754 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2753-2754 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 180
% INFO    : Updated Thermal Rating: on transformer 2769-2770 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 2768-5881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on transformer 2769-2771 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 307
% INFO    : Updated Thermal Rating: on transformer 2769-2771 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 314
% INFO    : Updated Thermal Rating: on transformer 2774-2775 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 2776-2777 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 2780-2781 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 292
% INFO    : Updated Thermal Rating: on transformer 2780-2781 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 287
% INFO    : Updated Thermal Rating: on transformer 2779-2782 : Rate A, Rate B, Rate C , 1628.0, 1628.0, 1628.0 -> 314
% INFO    : Updated Thermal Rating: on transformer 2779-2782 : Rate A, Rate B, Rate C , 1628.0, 1628.0, 1628.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 2781-2782 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 885
% INFO    : Updated Thermal Rating: on line 2785-5882 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 883
% INFO    : Updated Thermal Rating: on line 2786-5909 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 982
% INFO    : Updated Thermal Rating: on transformer 2790-2791 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2790-2791 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2796-2798 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 2803-2806 : Rate A, Rate B, Rate C , 604.0, 604.0, 604.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2804-2806 : Rate A, Rate B, Rate C , 342.0, 342.0, 342.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2805-2806 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2809-2810 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2809-2810 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2814-2815 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2814-2815 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 2847-2848 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 2863-2864 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 306
% INFO    : Updated Thermal Rating: on transformer 2863-2864 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 309
% INFO    : Updated Thermal Rating: on line 2893-5884 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 894
% INFO    : Updated Thermal Rating: on line 2893-5934 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1068
% INFO    : Updated Thermal Rating: on line 2893-5944 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 891
% INFO    : Updated Thermal Rating: on transformer 2899-5885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on transformer 2900-5885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 2901-5885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 2913-2914 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on line 2917-5886 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1166
% INFO    : Updated Thermal Rating: on line 2917-5912 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1178
% INFO    : Updated Thermal Rating: on transformer 2930-2932 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2930-2931 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2936-2937 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2935-2937 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 240
% INFO    : Updated Thermal Rating: on transformer 2935-2937 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2944-2945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 2944-2945 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2946-2947 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 318
% INFO    : Updated Thermal Rating: on transformer 2950-2952 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2950-2951 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2958-2959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on transformer 2966-2968 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on line 2968-5913 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 891
% INFO    : Updated Thermal Rating: on line 2969-5935 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 989
% INFO    : Updated Thermal Rating: on line 2969-5945 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 981
% INFO    : Updated Thermal Rating: on transformer 2971-2972 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2971-2972 : Rate A, Rate B, Rate C , 469.0, 469.0, 469.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 2984-2985 : Rate A, Rate B, Rate C , 796.0, 796.0, 796.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2984-2985 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2994-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 2995-2998 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2996-2998 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 2999-3000 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2999-3000 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 2999-3000 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3001-3002 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 3001-3002 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3001-3002 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3008-3009 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 3008-3009 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 3015-3016 : Rate A, Rate B, Rate C , 363.0, 363.0, 363.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 3015-3016 : Rate A, Rate B, Rate C , 363.0, 363.0, 363.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3030-3031 : Rate A, Rate B, Rate C , 307.0, 307.0, 307.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 3030-3031 : Rate A, Rate B, Rate C , 307.0, 307.0, 307.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 3063-3064 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3063-3064 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3073-3074 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3073-3074 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 3081-3082 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3081-3082 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3085-3086 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 3085-3086 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3085-3086 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3087-3088 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3100-3101 : Rate A, Rate B, Rate C , 378.0, 378.0, 378.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3100-3101 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 3118-3121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3117-3120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3116-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3127-3128 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3127-3128 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3134-3135 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 3134-3135 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 3145-3146 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 3145-3146 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 3152-3153 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 3152-3154 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 3152-3154 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 3164-3165 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3164-3165 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3175-3176 : Rate A, Rate B, Rate C , 471.0, 471.0, 471.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 3175-3176 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 243
% INFO    : Updated Thermal Rating: on line 3180-5888 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1178
% INFO    : Updated Thermal Rating: on line 3180-5915 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1097
% INFO    : Updated Thermal Rating: on transformer 3197-3199 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3197-3199 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 3197-3199 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3201-3202 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3201-3202 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3215-3217 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 3258-3259 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 3258-3259 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 309
% INFO    : Updated Thermal Rating: on transformer 3269-3270 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3269-3270 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 3269-3270 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 3278-3279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 3278-3279 : Rate A, Rate B, Rate C , 437.0, 437.0, 437.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 3282-3284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 3281-3283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 3280-3286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3290-3291 : Rate A, Rate B, Rate C , 420.0, 420.0, 420.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3297-3298 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3311-3312 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3311-3312 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3311-3312 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 3321-3323 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3321-3323 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3322-3323 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3335-3336 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 3335-3336 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 3334-3336 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3344-3345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 3344-3345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 3345-3346 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3345-3346 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3349-3350 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 3349-3350 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 3363-3364 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3363-3364 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 3366-3367 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 298
% INFO    : Updated Thermal Rating: on transformer 3366-3367 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 298
% INFO    : Updated Thermal Rating: on transformer 3366-3367 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 3371-3372 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 3371-3372 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 3380-3381 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 3380-3381 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3380-3381 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 3396-3397 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3396-3397 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3399-3400 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3399-3400 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3399-3400 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 3432-3433 : Rate A, Rate B, Rate C , 710.0, 710.0, 710.0 -> 204
% INFO    : Updated Thermal Rating: on transformer 3432-3433 : Rate A, Rate B, Rate C , 710.0, 710.0, 710.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 3441-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 3441-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 3482-3485 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3482-3485 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3483-3485 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3502-3504 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3505-3506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 3508-3509 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3514-3516 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 3514-3515 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 3517-3518 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 3517-3518 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3517-3518 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 3519-3520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3521-3523 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3522-3523 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3522-3523 : Rate A, Rate B, Rate C , 758.0, 758.0, 758.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 3538-3539 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3538-3539 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3542-3543 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3545-3546 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3545-3546 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3545-3546 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 3555-3556 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3555-3556 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3559-3560 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3559-3560 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3559-3560 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 3561-3562 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 3561-3563 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 3564-3565 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 3572-3573 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 3572-3573 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 3578-3579 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3586-3588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 3587-3589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 3594-3595 : Rate A, Rate B, Rate C , 313.0, 313.0, 313.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 3596-3597 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 3600-3601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3602-3603 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 3608-3609 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3614-3615 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1171
% INFO    : Updated Thermal Rating: on line 3616-5889 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 974
% INFO    : Updated Thermal Rating: on line 3616-5916 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1046
% INFO    : Updated Thermal Rating: on line 3615-5936 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 985
% INFO    : Updated Thermal Rating: on line 3615-5946 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1003
% INFO    : Updated Thermal Rating: on transformer 3619-3620 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3619-3620 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3619-3620 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3623-3624 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 3630-3631 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3630-3631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 3630-3631 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3647-3648 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 3647-3648 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 3654-3655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3653-3655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3662-3663 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 3664-3665 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3664-3666 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3664-3665 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 3664-3666 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 3670-3671 : Rate A, Rate B, Rate C , 316.0, 316.0, 316.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 3670-3671 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 3674-3675 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 3674-3675 : Rate A, Rate B, Rate C , 274.0, 274.0, 274.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3674-3675 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 3678-3679 : Rate A, Rate B, Rate C , 722.0, 722.0, 722.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3678-3679 : Rate A, Rate B, Rate C , 722.0, 722.0, 722.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3678-3679 : Rate A, Rate B, Rate C , 722.0, 722.0, 722.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3704-3705 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1153
% INFO    : Updated Thermal Rating: on line 3705-5890 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 3709-3710 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3711-3712 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3711-3712 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 3727-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 3727-3729 : Rate A, Rate B, Rate C , 290.0, 290.0, 290.0 -> 117
% INFO    : Updated Thermal Rating: on transformer 3728-3730 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3734-3735 : Rate A, Rate B, Rate C , 530.0, 530.0, 530.0 -> 340
% INFO    : Updated Thermal Rating: on transformer 3736-3738 : Rate A, Rate B, Rate C , 439.0, 439.0, 439.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3736-3738 : Rate A, Rate B, Rate C , 439.0, 439.0, 439.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3736-3738 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3736-3738 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3742-3743 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3745-3746 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 3745-3746 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 3758-3759 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 3758-3759 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 3763-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3763-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3763-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 3773-3774 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 314
% INFO    : Updated Thermal Rating: on transformer 3773-3774 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 3777-3781 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3778-3780 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3777-3781 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3776-3779 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3790-3792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 3789-3792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 3788-3791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 3809-3810 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 3809-3810 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 3810-3811 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1134
% INFO    : Updated Thermal Rating: on transformer 3818-3821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3817-3820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3816-3819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3830-3832 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3831-3832 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 3840-3841 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3850-3851 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 3850-3851 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3854-3856 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 3855-3856 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3873-3874 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3873-3874 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3878-3879 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 3878-3879 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 3878-3879 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3880-3881 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 258
% INFO    : Updated Thermal Rating: on line 3881-5937 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 3888-3889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3897-3898 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 3900-3901 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 3900-3901 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 3905-3907 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1177
% INFO    : Updated Thermal Rating: on transformer 3916-3917 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3916-3917 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3916-3917 : Rate A, Rate B, Rate C , 378.0, 378.0, 378.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 3923-3925 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3924-3925 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 3927-3928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 3930-3931 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3930-3931 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 3936-3937 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 3969-3970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 3968-3971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 3978-3980 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3979-3980 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 4004-4005 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 4004-4005 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4008-4009 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4008-4009 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4010-4011 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 4017-4018 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 215
% INFO    : Updated Thermal Rating: on transformer 4017-4018 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 211
% INFO    : Updated Thermal Rating: on transformer 4026-4027 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4026-4027 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 4036-4037 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 4045-4046 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 197
% INFO    : Updated Thermal Rating: on line 4049-5892 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1039
% INFO    : Updated Thermal Rating: on transformer 4063-4064 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 195
% INFO    : Updated Thermal Rating: on transformer 4077-5893 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4076-5918 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4088-4089 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4088-4089 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4092-4093 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4094-4095 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 4101-4102 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4101-4102 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on line 4106-5894 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1158
% INFO    : Updated Thermal Rating: on transformer 4110-4111 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4110-4111 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 4118-4119 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 4118-4119 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 4120-4121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 4121-4122 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 4140-4142 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4141-4142 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4141-4142 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 4141-4142 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 4143-4144 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 4143-4144 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 4148-4149 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4147-4149 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4147-4149 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4164-4165 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 4164-4165 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4170-4171 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 309
% INFO    : Updated Thermal Rating: on transformer 4172-4173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10522
% INFO    : Updated Thermal Rating: on transformer 4181-4182 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4181-4182 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4207-4209 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4207-4209 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4210-4211 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 4210-4211 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 4216-4218 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 4217-4218 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 4217-4218 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 4216-4218 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 4224-4221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4226-4227 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 4225-4227 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 4242-4243 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 304
% INFO    : Updated Thermal Rating: on transformer 4248-4270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on transformer 4250-4251 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 4250-4251 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4253-4254 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4255-4256 : Rate A, Rate B, Rate C , 726.0, 726.0, 726.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4255-4256 : Rate A, Rate B, Rate C , 726.0, 726.0, 726.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4274-5895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 4275-5895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4276-5895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3573
% INFO    : Updated Thermal Rating: on transformer 4290-4291 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 136
% INFO    : Updated Thermal Rating: on transformer 4289-4291 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 139
% INFO    : Updated Thermal Rating: on transformer 4289-4291 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 143
% INFO    : Updated Thermal Rating: on transformer 4289-4291 : Rate A, Rate B, Rate C , 304.0, 304.0, 304.0 -> 131
% INFO    : Updated Thermal Rating: on transformer 4293-4294 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4303-4304 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 4310-4311 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 4310-4312 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4323-4324 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4329-4332 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 4330-4332 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4330-4331 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 4329-4331 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4341-4343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4340-4343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4339-4343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4342-4343 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 4342-4343 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4346-4347 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4346-4347 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 4346-4347 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 4355-4353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4388-4389 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 4388-4389 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4390-4392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4397-4398 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 4397-4398 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 1498-4406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 4420-4422 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 4421-4422 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4442-4444 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4442-4444 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4443-4444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 4455-4457 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 4460-4461 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 285
% INFO    : Updated Thermal Rating: on transformer 4460-4461 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4460-4461 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4465-4466 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 4465-4466 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 4464-4466 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 4475-4476 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 4475-4476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 4478-4483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 4482-4487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4481-4486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4480-4485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4479-4484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4501-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4502-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 4504-4505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 4511-4512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 4516-4517 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4516-4517 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 211
% INFO    : Updated Thermal Rating: on transformer 4526-4528 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4527-4528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 4538-4539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 4543-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 4543-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 4543-4545 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 258
% INFO    : Updated Thermal Rating: on line 4551-5896 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on line 4551-5919 : Rate A, Rate B, Rate C , 1174.0, 1174.0, 1174.0 -> 1166
% INFO    : Updated Thermal Rating: on transformer 4558-4559 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 4558-4560 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4559-4560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 4572-4573 : Rate A, Rate B, Rate C , 1217.0, 1217.0, 1217.0 -> 293
% INFO    : Updated Thermal Rating: on transformer 4576-4577 : Rate A, Rate B, Rate C , 1266.0, 1266.0, 1266.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 4576-4577 : Rate A, Rate B, Rate C , 1266.0, 1266.0, 1266.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 4595-4597 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 312
% INFO    : Updated Thermal Rating: on transformer 4595-4596 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4598-4599 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4598-4599 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4601-4602 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 4601-4603 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 4610-4611 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 4610-4611 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 199
% INFO    : Updated Thermal Rating: on transformer 4610-4611 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 223
% INFO    : Updated Thermal Rating: on transformer 4618-4619 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 4618-4619 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 4639-4641 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4639-4640 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4649-4650 : Rate A, Rate B, Rate C , 711.0, 711.0, 711.0 -> 204
% INFO    : Updated Thermal Rating: on transformer 4649-4650 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 4649-4650 : Rate A, Rate B, Rate C , 711.0, 711.0, 711.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 4652-4654 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4652-4653 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 248
% INFO    : Updated Thermal Rating: on line 4664-5939 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 976
% INFO    : Updated Thermal Rating: on line 4664-5948 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 983
% INFO    : Updated Thermal Rating: on transformer 4674-4675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7637
% INFO    : Updated Thermal Rating: on transformer 4676-4677 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4676-4677 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4676-4677 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4677-4678 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 4677-4678 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 991
% INFO    : Updated Thermal Rating: on transformer 4682-4684 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 4682-4684 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 4682-4684 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 4682-4684 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4689-4690 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4689-4690 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 4711-4714 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4710-4714 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4707-4714 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4706-4714 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4721-4722 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4721-4722 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4743-4744 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 4743-4744 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4743-4744 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4745-4746 : Rate A, Rate B, Rate C , 374.0, 374.0, 374.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4745-4746 : Rate A, Rate B, Rate C , 374.0, 374.0, 374.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4767-4768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 4773-4774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4779-4780 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 4779-4780 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4783-4784 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 4803-4804 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4803-4804 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4809-4811 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 306
% INFO    : Updated Thermal Rating: on transformer 4809-4811 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 307
% INFO    : Updated Thermal Rating: on transformer 4820-4822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 4819-4821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 4825-4831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on transformer 4826-4831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on transformer 4829-4831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on transformer 4830-4831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on transformer 4827-4831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on transformer 4828-4831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 4832-4834 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4832-4833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 4832-4833 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 4832-4833 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4834-4835 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 4833-4835 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 4833-4835 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 4852-4853 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 4852-4853 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 4857-4858 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4862-4863 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 4862-4863 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 178
% INFO    : Updated Thermal Rating: on line 4864-5920 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1175
% INFO    : Updated Thermal Rating: on transformer 4867-4868 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4867-4868 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4867-4868 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4885-4886 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4885-4886 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4905-4907 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4905-4906 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4920-4922 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4919-4922 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 4920-4922 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4921-4922 : Rate A, Rate B, Rate C , 358.0, 358.0, 358.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 4926-4927 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 4926-4927 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 4931-4932 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 4931-4932 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4931-4932 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 4945-4946 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4959-4961 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 4959-4961 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 255
% INFO    : Updated Thermal Rating: on line 4962-5898 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1046
% INFO    : Updated Thermal Rating: on line 4962-5921 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1041
% INFO    : Updated Thermal Rating: on line 4962-5940 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 983
% INFO    : Updated Thermal Rating: on line 4962-5949 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 983
% INFO    : Updated Thermal Rating: on line 4962-5955 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 886
% INFO    : Updated Thermal Rating: on transformer 4963-4965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4964-4965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 4964-4965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4964-4965 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4970-4972 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4970-4971 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 311
% INFO    : Updated Thermal Rating: on transformer 4976-4978 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4977-4978 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 4978-4980 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on line 4980-5922 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 885
% INFO    : Updated Thermal Rating: on line 4980-5950 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 4984-4985 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4984-4985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 4989-4992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 4988-4991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 4987-4990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 4993-4995 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4997-4998 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 5001-5002 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 5003-5004 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 5008-5009 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 5008-5009 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 5037-5038 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 5055-5056 : Rate A, Rate B, Rate C , 511.0, 511.0, 511.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 5081-5082 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 5088-5089 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 5965-5966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on transformer 5964-5966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on transformer 5971-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on transformer 5973-5974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1364
% INFO    : Updated Thermal Rating: on transformer 5983-5985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on transformer 5984-5985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on transformer 6198-6003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11039
% INFO    : Updated Thermal Rating: on transformer 6002-6198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6986
% INFO    : Updated Thermal Rating: on transformer 6021-6023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1892
% INFO    : Updated Thermal Rating: on transformer 6022-6024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1968
% INFO    : Updated Thermal Rating: on transformer 6034-6035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1892
% INFO    : Updated Thermal Rating: on transformer 6039-6041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on transformer 6057-6058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on transformer 6061-6064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 6062-6063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 6067-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 6068-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 6073-6074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on transformer 6073-6074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on transformer 6081-6082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 6085-6086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 6085-6086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1316
% INFO    : Updated Thermal Rating: on transformer 6093-6095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on transformer 6098-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on transformer 6105-6106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on transformer 6121-6122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on transformer 6135-6136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1837
% INFO    : Updated Thermal Rating: on transformer 6149-6150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on transformer 6149-6150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 6153-6154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1509
% INFO    : Updated Thermal Rating: on transformer 6173-6174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1689
% INFO    : Updated Thermal Rating: on transformer 6179-6180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on transformer 6183-6184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on transformer 6183-6184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1355
% INFO    : Updated Thermal Rating: on transformer 6183-6184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on transformer 6185-6186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 6210-6211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on transformer 6206-6220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55237
% INFO    : Updated Thermal Rating: on transformer 6206-6219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on transformer 6232-6233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on transformer 6232-6233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 6232-6233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1850
% INFO    : Updated Thermal Rating: on transformer 6244-6245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6242-6245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6243-6245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6241-6245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6246-6247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on transformer 6246-6247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on transformer 115-6255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 116-6256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 200-6257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 200-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 200-6259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 230-6260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 230-6261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on transformer 247-6262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on transformer 271-6263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 271-6264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 270-6265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 270-6266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 366-6267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 366-6268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 367-6269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 367-6270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 368-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 368-6272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 501-6280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on transformer 501-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 527-6283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 527-6284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 527-6285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 527-6286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 527-6287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 2797-6288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 616-6289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on transformer 616-6290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 616-6291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 623-6292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 624-6293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 624-6294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on transformer 699-6301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 699-6302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 699-6303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 698-6304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 698-6305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 698-6306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 720-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 1008-6311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 1007-6312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1007-6313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1047-6314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on transformer 73-6325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 72-6326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 2107-6327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 1176-6328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on transformer 1179-6332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1588
% INFO    : Updated Thermal Rating: on transformer 1446-6333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1446-6334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1446-6335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1446-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1446-6337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1446-6338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1340-6343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1340-6344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1366-6345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on transformer 1365-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on transformer 1608-6352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 1872-6355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 1961-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1962-6357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1962-6358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1962-6359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on transformer 1961-6360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on transformer 2021-6363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 2021-6364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 2054-6366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 2135-6373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on transformer 2200-6376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on transformer 2201-6377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on transformer 2222-6379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 2222-6380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 2242-6381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on transformer 2242-6382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on transformer 2400-6383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 2400-6384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 2460-6385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 2661-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2661-6387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2661-6388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2661-6389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2617-6390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on transformer 2653-6391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on transformer 2653-6392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on transformer 2704-6393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 2704-6394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on transformer 2704-6395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2704-6396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 2710-6397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 2710-6398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 2710-6399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 2727-6400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2749-6401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 2749-6402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 2749-6403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 2749-6404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 2821-6405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on transformer 2820-6406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on transformer 2860-6407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 2860-6408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 4405-6409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 3038-6411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 3038-6412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 3055-6413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 3054-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 3058-6415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on transformer 3058-6416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on transformer 3057-6417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on transformer 3057-6418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on transformer 3088-6419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on transformer 3088-6420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on transformer 3149-6424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on transformer 3150-6425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1000
% INFO    : Updated Thermal Rating: on transformer 3253-6427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 3253-6428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 3263-6429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 3346-6434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on transformer 3479-6437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on transformer 3478-6438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on transformer 3476-6440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 3493-6441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 3493-6442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 3493-6443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 3504-6444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on transformer 3595-6447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 3595-6448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 3607-6449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 3688-6450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 3688-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 3703-6453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on transformer 3726-6454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 3725-6455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 3724-6456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 3729-6457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3729-6458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3729-6459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3729-6460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3808-6461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 3807-6462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on transformer 3806-6463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 3805-6464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 645-6465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 644-6466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 643-6467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 642-6468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 641-6469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 3991-6470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on transformer 3996-6471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3996-6472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 4020-6473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 4020-6474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 4020-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 4020-6476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 4046-6477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on transformer 4046-6478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on transformer 4052-6479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 4137-6480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4137-6481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4137-6482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4137-6483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4144-6484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 4254-6491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on transformer 4254-6492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on transformer 4264-6493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 4263-6494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 4269-6495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4269-6496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on transformer 4294-6499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 4294-6500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 4294-6501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 4507-6502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 4528-6503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 4528-6504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 4764-6509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 4764-6510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 4763-6511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 4795-6512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 4795-6513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 4795-6514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 4952-6517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 5009-6518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on transformer 5009-6519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=0.992673125, theta=-12.8471377 -> V=0.9444445, theta=0.0
% INFO    : Bus 2	: V=1.02546105, theta=-9.79090947 -> V=0.999999, theta=0.0
% INFO    : Bus 3	: V=1.00864353, theta=-17.1895145 -> V=1.0158755, theta=0.0
% INFO    : Bus 4	: V=1.02422997, theta=-30.343276 -> V=1.0111115, theta=0.0
% INFO    : Bus 5	: V=1.00903343, theta=-61.8409771 -> V=1.0079355, theta=0.0
% INFO    : Bus 6	: V=1.03039688, theta=-21.8739211 -> V=1.0000025, theta=0.0
% INFO    : Bus 7	: V=1.04823977, theta=-23.3329536 -> V=1.0000025, theta=0.0
% INFO    : Bus 8	: V=1.04175444, theta=-22.659297 -> V=0.9888895, theta=0.0
% INFO    : Bus 9	: V=1.04155579, theta=-20.2679216 -> V=0.999999, theta=0.0
% INFO    : Bus 10	: V=1.0132689, theta=-29.1463296 -> V=1.000001, theta=0.0
% INFO    : Bus 11	: V=1.01326868, theta=-29.1463272 -> V=1.000001, theta=0.0
% INFO    : Bus 12	: V=1.01492907, theta=-3.69736777 -> V=1.0158755, theta=0.0
% INFO    : Bus 13	: V=1.06112977, theta=-5.52856096 -> V=1.07767, theta=0.0
% INFO    : Bus 14	: V=1.05559114, theta=-38.6865005 -> V=1.027779, theta=0.0
% INFO    : Bus 15	: V=1.02066892, theta=-25.2263375 -> V=1.0000025, theta=0.0
% INFO    : Bus 16	: V=1.03089962, theta=-28.9019546 -> V=1.0000025, theta=0.0
% INFO    : Bus 17	: V=1.04190862, theta=-35.5001147 -> V=1.022224, theta=0.0
% INFO    : Bus 18	: V=0.938816943, theta=-6.53938592 -> V=0.9444445, theta=0.0
% INFO    : Bus 19	: V=1.01915832, theta=-24.0844174 -> V=0.999999, theta=0.0
% INFO    : Bus 20	: V=0.939550393, theta=-6.5786432 -> V=0.9444445, theta=0.0
% INFO    : Bus 21	: V=1.02352369, theta=-23.3128349 -> V=1.022224, theta=0.0
% INFO    : Bus 22	: V=1.00657527, theta=-18.245777 -> V=1.0158755, theta=0.0
% INFO    : Bus 23	: V=1.01974649, theta=-11.4972658 -> V=0.999999, theta=0.0
% INFO    : Bus 24	: V=1.02620358, theta=-28.8977254 -> V=1.033333, theta=0.0
% INFO    : Bus 25	: V=1.06210876, theta=-24.9347957 -> V=1.022222, theta=0.0
% INFO    : Bus 26	: V=1.01923142, theta=-30.5619937 -> V=1.022224, theta=0.0
% INFO    : Bus 27	: V=1.05630842, theta=-25.6901089 -> V=1.04444, theta=0.0
% INFO    : Bus 28	: V=1.01919759, theta=-24.3820624 -> V=1.0158755, theta=0.0
% INFO    : Bus 29	: V=0.992476874, theta=-26.274171 -> V=1.015872, theta=0.0
% INFO    : Bus 30	: V=1.01607663, theta=-29.4588142 -> V=1.0111115, theta=0.0
% INFO    : Bus 31	: V=1.04325949, theta=-10.3722447 -> V=0.999999, theta=0.0
% INFO    : Bus 32	: V=1.0482513, theta=-5.17611119 -> V=1.003335, theta=0.0
% INFO    : Bus 33	: V=1.05862347, theta=-7.53647866 -> V=1.0111115, theta=0.0
% INFO    : Bus 34	: V=1.05568981, theta=-6.87832327 -> V=1.0111115, theta=0.0
% INFO    : Bus 35	: V=1.07212104, theta=-6.27267486 -> V=1.072365, theta=0.0
% INFO    : Bus 36	: V=1.07555328, theta=-5.29121134 -> V=1.072365, theta=0.0
% INFO    : Bus 37	: V=1.01345584, theta=-27.1537318 -> V=1.0000025, theta=0.0
% INFO    : Bus 38	: V=1.02829838, theta=-25.8684243 -> V=1.015874, theta=0.0
% INFO    : Bus 39	: V=1.01570693, theta=-46.2156561 -> V=1.027779, theta=0.0
% INFO    : Bus 40	: V=1.04839394, theta=-36.8261167 -> V=1.027779, theta=0.0
% INFO    : Bus 41	: V=1.05970737, theta=-31.1653571 -> V=1.046665, theta=0.0
% INFO    : Bus 42	: V=1.12316346, theta=0.171268459 -> V=1.0416855, theta=0.0
% INFO    : Bus 43	: V=1.03415253, theta=-33.026203 -> V=1.027779, theta=0.0
% INFO    : Bus 44	: V=1.02400777, theta=-57.5229333 -> V=1.0079355, theta=0.0
% INFO    : Bus 45	: V=1.01408884, theta=-40.0298803 -> V=1.022224, theta=0.0
% INFO    : Bus 46	: V=1.02956066, theta=-17.1027795 -> V=0.999999, theta=0.0
% INFO    : Bus 47	: V=1.022, theta=-13.006679 -> V=0.999999, theta=0.0
% INFO    : Bus 48	: V=1.01540389, theta=-30.4810602 -> V=1.000001, theta=0.0
% INFO    : Bus 49	: V=1.0241398, theta=-18.4598697 -> V=0.999999, theta=0.0
% INFO    : Bus 50	: V=1.06676716, theta=-15.8911637 -> V=1.002889, theta=0.0
% INFO    : Bus 51	: V=1.05441957, theta=-10.919134 -> V=1.0111115, theta=0.0
% INFO    : Bus 52	: V=1.02819015, theta=-42.0616957 -> V=1.022224, theta=0.0
% INFO    : Bus 53	: V=0.990894456, theta=-33.1970632 -> V=1.0000005, theta=0.0
% INFO    : Bus 54	: V=1.03197366, theta=-22.2968493 -> V=1.022224, theta=0.0
% INFO    : Bus 55	: V=1.06700842, theta=-34.6141552 -> V=1.046665, theta=0.0
% INFO    : Bus 56	: V=1.05516756, theta=-29.8601461 -> V=1.046665, theta=0.0
% INFO    : Bus 57	: V=1.058, theta=-20.1693954 -> V=1.0000025, theta=0.0
% INFO    : Bus 58	: V=1.06686281, theta=-34.6314288 -> V=1.046665, theta=0.0
% INFO    : Bus 59	: V=1.02827769, theta=-15.3855852 -> V=1.0158755, theta=0.0
% INFO    : Bus 60	: V=1.0337691, theta=-9.9719196 -> V=1.0158755, theta=0.0
% INFO    : Bus 61	: V=1.03489853, theta=-11.5603392 -> V=1.0158755, theta=0.0
% INFO    : Bus 62	: V=1.02055977, theta=-9.93967295 -> V=1.0158755, theta=0.0
% INFO    : Bus 63	: V=1.0112534, theta=-4.26584306 -> V=1.0158755, theta=0.0
% INFO    : Bus 64	: V=1.05467311, theta=-22.3706653 -> V=0.9888895, theta=0.0
% INFO    : Bus 65	: V=1.04688113, theta=-12.1924535 -> V=1.0158755, theta=0.0
% INFO    : Bus 66	: V=1.02707223, theta=-27.7656942 -> V=0.999999, theta=0.0
% INFO    : Bus 67	: V=1.03945348, theta=-23.5570146 -> V=1.0000025, theta=0.0
% INFO    : Bus 68	: V=1.01382383, theta=-17.068817 -> V=0.999999, theta=0.0
% INFO    : Bus 69	: V=1.04182792, theta=-62.4588387 -> V=1.0079355, theta=0.0
% INFO    : Bus 70	: V=1.02517777, theta=-2.58318588 -> V=1.0158755, theta=0.0
% INFO    : Bus 71	: V=1.00979621, theta=-33.3578345 -> V=1.0000005, theta=0.0
% INFO    : Bus 72	: V=1.07727637, theta=-26.6245331 -> V=1.046665, theta=0.0
% INFO    : Bus 73	: V=1.07728775, theta=-26.6238384 -> V=1.046665, theta=0.0
% INFO    : Bus 74	: V=1.05521642, theta=-22.2096659 -> V=0.9888895, theta=0.0
% INFO    : Bus 75	: V=1.03831803, theta=-25.8993445 -> V=1.022224, theta=0.0
% INFO    : Bus 76	: V=1.07673551, theta=-0.737800075 -> V=1.0377785, theta=0.0
% INFO    : Bus 77	: V=1.01539346, theta=-18.6809907 -> V=0.999999, theta=0.0
% INFO    : Bus 78	: V=1.03810449, theta=-26.0425496 -> V=1.0000025, theta=0.0
% INFO    : Bus 79	: V=1.00480897, theta=-32.1704872 -> V=1.0000005, theta=0.0
% INFO    : Bus 80	: V=1.03513924, theta=-31.7118517 -> V=1.046665, theta=0.0
% INFO    : Bus 81	: V=1.03515795, theta=-31.7118034 -> V=1.046665, theta=0.0
% INFO    : Bus 82	: V=1.02513848, theta=-19.7466558 -> V=0.999999, theta=0.0
% INFO    : Bus 83	: V=1.04529914, theta=-32.2878169 -> V=1.046665, theta=0.0
% INFO    : Bus 84	: V=1.01622729, theta=-14.3105965 -> V=0.999999, theta=0.0
% INFO    : Bus 85	: V=1.04080844, theta=-18.1005924 -> V=0.999999, theta=0.0
% INFO    : Bus 86	: V=1.01614449, theta=-49.9270109 -> V=1.022224, theta=0.0
% INFO    : Bus 87	: V=1.02330517, theta=-4.28707361 -> V=1.0158755, theta=0.0
% INFO    : Bus 88	: V=1.03614098, theta=-22.0451103 -> V=0.999999, theta=0.0
% INFO    : Bus 89	: V=1.02844336, theta=-35.7613286 -> V=1.027779, theta=0.0
% INFO    : Bus 90	: V=0.942964456, theta=-7.25414887 -> V=0.9444445, theta=0.0
% INFO    : Bus 91	: V=0.938816943, theta=-6.53938592 -> V=0.9444445, theta=0.0
% INFO    : Bus 92	: V=1.00914587, theta=-21.2607832 -> V=1.015872, theta=0.0
% INFO    : Bus 93	: V=0.954341202, theta=-8.94487733 -> V=0.9444445, theta=0.0
% INFO    : Bus 94	: V=1.0348292, theta=-29.3342649 -> V=1.022224, theta=0.0
% INFO    : Bus 95	: V=1.02330918, theta=-41.8968451 -> V=1.022224, theta=0.0
% INFO    : Bus 96	: V=1.05013888, theta=-10.4724751 -> V=0.999999, theta=0.0
% INFO    : Bus 97	: V=1.0637675, theta=-23.1503147 -> V=1.0000025, theta=0.0
% INFO    : Bus 98	: V=1.01837903, theta=-23.6016005 -> V=1.0158755, theta=0.0
% INFO    : Bus 99	: V=1.04200009, theta=-11.2421339 -> V=1.0158755, theta=0.0
% INFO    : Bus 100	: V=1.0198988, theta=-16.7237189 -> V=0.999999, theta=0.0
% INFO    : Bus 101	: V=1.00720077, theta=-15.4022054 -> V=0.999999, theta=0.0
% INFO    : Bus 102	: V=1.033, theta=-17.5428369 -> V=1.0158755, theta=0.0
% INFO    : Bus 103	: V=1.03402232, theta=-10.2412822 -> V=1.0158755, theta=0.0
% INFO    : Bus 104	: V=1.06896149, theta=-7.24533817 -> V=1.0377785, theta=0.0
% INFO    : Bus 105	: V=1.03585863, theta=-20.6678397 -> V=0.9888895, theta=0.0
% INFO    : Bus 106	: V=1.04519922, theta=-25.684212 -> V=1.022222, theta=0.0
% INFO    : Bus 107	: V=1.040509, theta=-31.5107115 -> V=1.046665, theta=0.0
% INFO    : Bus 108	: V=1.04638166, theta=-31.1343278 -> V=1.027779, theta=0.0
% INFO    : Bus 109	: V=1.03905102, theta=-13.9671499 -> V=0.999999, theta=0.0
% INFO    : Bus 110	: V=1.02643332, theta=-9.99598604 -> V=1.0111115, theta=0.0
% INFO    : Bus 111	: V=0.999939733, theta=-23.8557541 -> V=1.015872, theta=0.0
% INFO    : Bus 112	: V=1.0084672, theta=-32.7244461 -> V=1.0000005, theta=0.0
% INFO    : Bus 113	: V=1.04193595, theta=-29.0769585 -> V=1.046665, theta=0.0
% INFO    : Bus 114	: V=1.05164361, theta=-14.0192231 -> V=0.999999, theta=0.0
% INFO    : Bus 115	: V=1.06113897, theta=-5.52864435 -> V=1.078945, theta=0.0
% INFO    : Bus 116	: V=1.06113897, theta=-5.52864435 -> V=1.078945, theta=0.0
% INFO    : Bus 117	: V=1.0148958, theta=-22.0594793 -> V=1.0158755, theta=0.0
% INFO    : Bus 118	: V=1.0407153, theta=-25.5846169 -> V=1.022224, theta=0.0
% INFO    : Bus 119	: V=1.00751513, theta=-12.2929818 -> V=0.999999, theta=0.0
% INFO    : Bus 120	: V=1.02701829, theta=-10.6746379 -> V=0.999999, theta=0.0
% INFO    : Bus 121	: V=1.01905698, theta=-28.4357141 -> V=1.0000025, theta=0.0
% INFO    : Bus 122	: V=1.026, theta=-11.4893332 -> V=1.0158755, theta=0.0
% INFO    : Bus 123	: V=1.02345495, theta=-11.6208216 -> V=1.0158755, theta=0.0
% INFO    : Bus 124	: V=1.03058281, theta=-32.0456097 -> V=1.022224, theta=0.0
% INFO    : Bus 125	: V=1.02451482, theta=-17.6128119 -> V=1.0158755, theta=0.0
% INFO    : Bus 126	: V=1.04200581, theta=-18.1711791 -> V=0.999999, theta=0.0
% INFO    : Bus 127	: V=1.00893682, theta=-34.7845994 -> V=1.0000005, theta=0.0
% INFO    : Bus 128	: V=1.02420693, theta=-13.4505926 -> V=1.015872, theta=0.0
% INFO    : Bus 129	: V=1.02228026, theta=-11.684565 -> V=1.015872, theta=0.0
% INFO    : Bus 130	: V=1.04938638, theta=-10.7559484 -> V=1.046665, theta=0.0
% INFO    : Bus 131	: V=1.04797649, theta=-19.2970195 -> V=1.046665, theta=0.0
% INFO    : Bus 132	: V=1.061, theta=-17.4067202 -> V=1.000001, theta=0.0
% INFO    : Bus 133	: V=0.977015678, theta=-35.7038784 -> V=1.0000005, theta=0.0
% INFO    : Bus 134	: V=1.01919465, theta=-32.3675851 -> V=1.046665, theta=0.0
% INFO    : Bus 135	: V=1.06787852, theta=-34.4372217 -> V=1.046665, theta=0.0
% INFO    : Bus 136	: V=1.02860167, theta=-45.1625315 -> V=1.027779, theta=0.0
% INFO    : Bus 137	: V=1.021, theta=-13.7741519 -> V=1.015872, theta=0.0
% INFO    : Bus 138	: V=1.05230738, theta=-11.8528375 -> V=1.0233335, theta=0.0
% INFO    : Bus 139	: V=1.04648958, theta=-14.9227418 -> V=1.0000025, theta=0.0
% INFO    : Bus 140	: V=1.07646104, theta=-11.6950122 -> V=1.044445, theta=0.0
% INFO    : Bus 141	: V=1.08763346, theta=-8.32866303 -> V=1.078945, theta=0.0
% INFO    : Bus 142	: V=1.03228893, theta=-14.8981507 -> V=1.0158755, theta=0.0
% INFO    : Bus 143	: V=1.06313802, theta=-9.96969754 -> V=1.0377785, theta=0.0
% INFO    : Bus 144	: V=1.03309181, theta=-26.8698953 -> V=1.033333, theta=0.0
% INFO    : Bus 145	: V=1.05635444, theta=-22.0953535 -> V=1.0288895, theta=0.0
% INFO    : Bus 146	: V=1.07128281, theta=-18.8795632 -> V=1.05263, theta=0.0
% INFO    : Bus 147	: V=1.04390759, theta=-16.0736886 -> V=0.999999, theta=0.0
% INFO    : Bus 148	: V=1.03749817, theta=-13.2119304 -> V=0.999999, theta=0.0
% INFO    : Bus 149	: V=1.03408373, theta=-41.2236007 -> V=1.022224, theta=0.0
% INFO    : Bus 150	: V=1.04112536, theta=-10.8602978 -> V=0.999999, theta=0.0
% INFO    : Bus 151	: V=0.98098642, theta=-26.9365676 -> V=1.015872, theta=0.0
% INFO    : Bus 152	: V=0.980839029, theta=-25.6821086 -> V=1.015872, theta=0.0
% INFO    : Bus 153	: V=1.04181234, theta=-13.2314985 -> V=0.999999, theta=0.0
% INFO    : Bus 154	: V=1.06674466, theta=-9.80672971 -> V=1.0111115, theta=0.0
% INFO    : Bus 155	: V=1.03406286, theta=-20.2221707 -> V=1.0000025, theta=0.0
% INFO    : Bus 156	: V=0.980935792, theta=-26.9415225 -> V=1.015872, theta=0.0
% INFO    : Bus 157	: V=0.935542823, theta=-10.5371068 -> V=0.9444445, theta=0.0
% INFO    : Bus 158	: V=0.959, theta=-8.8219929 -> V=0.9444445, theta=0.0
% INFO    : Bus 159	: V=1.03725797, theta=-13.4653506 -> V=0.999999, theta=0.0
% INFO    : Bus 160	: V=1.04467103, theta=-19.1138119 -> V=0.9888895, theta=0.0
% INFO    : Bus 161	: V=1.04448642, theta=-19.1176995 -> V=0.9888895, theta=0.0
% INFO    : Bus 162	: V=1.01339884, theta=-30.3158034 -> V=1.022224, theta=0.0
% INFO    : Bus 163	: V=1.02801672, theta=-10.7250105 -> V=1.0158755, theta=0.0
% INFO    : Bus 164	: V=1.02801672, theta=-10.7250105 -> V=1.0158755, theta=0.0
% INFO    : Bus 165	: V=1.05983201, theta=-36.314939 -> V=0.975, theta=0.0
% INFO    : Bus 166	: V=1.03524133, theta=-40.7823374 -> V=1.022224, theta=0.0
% INFO    : Bus 167	: V=1.02999342, theta=-41.2456122 -> V=1.022224, theta=0.0
% INFO    : Bus 168	: V=1.05995948, theta=-36.3084919 -> V=1.04444, theta=0.0
% INFO    : Bus 169	: V=1.01990731, theta=-34.6512734 -> V=1.022224, theta=0.0
% INFO    : Bus 170	: V=1.02344208, theta=-35.0733645 -> V=1.027779, theta=0.0
% INFO    : Bus 171	: V=1.04082815, theta=-39.1279989 -> V=1.027779, theta=0.0
% INFO    : Bus 172	: V=1.04692773, theta=-34.5246347 -> V=1.046665, theta=0.0
% INFO    : Bus 173	: V=1.0590281, theta=-23.829887 -> V=1.0111115, theta=0.0
% INFO    : Bus 174	: V=1.05612022, theta=-26.5540592 -> V=1.033333, theta=0.0
% INFO    : Bus 175	: V=1.03904928, theta=-18.731462 -> V=1.0000025, theta=0.0
% INFO    : Bus 176	: V=1.0990839, theta=-16.9543598 -> V=1.0, theta=0.0
% INFO    : Bus 177	: V=1.06242189, theta=-31.0018642 -> V=1.046665, theta=0.0
% INFO    : Bus 178	: V=1.06242211, theta=-31.0018654 -> V=1.046665, theta=0.0
% INFO    : Bus 179	: V=1.00913769, theta=-34.7703996 -> V=1.0000005, theta=0.0
% INFO    : Bus 180	: V=1.06242061, theta=-31.0018573 -> V=1.046665, theta=0.0
% INFO    : Bus 181	: V=1.05536442, theta=-25.4715017 -> V=1.0000025, theta=0.0
% INFO    : Bus 182	: V=1.03881229, theta=-11.07428 -> V=0.999999, theta=0.0
% INFO    : Bus 183	: V=1.02470235, theta=-22.7861282 -> V=1.0158755, theta=0.0
% INFO    : Bus 184	: V=1.06245644, theta=-33.1058103 -> V=1.027779, theta=0.0
% INFO    : Bus 185	: V=1.02299848, theta=-15.8326102 -> V=1.0158755, theta=0.0
% INFO    : Bus 186	: V=1.02336193, theta=-28.6617357 -> V=1.022224, theta=0.0
% INFO    : Bus 187	: V=1.05073012, theta=-20.5024991 -> V=1.0000025, theta=0.0
% INFO    : Bus 188	: V=1.09874151, theta=-19.0660354 -> V=1.0096925, theta=0.0
% INFO    : Bus 189	: V=1.0371871, theta=-24.0139136 -> V=1.0000025, theta=0.0
% INFO    : Bus 190	: V=0.952733602, theta=-8.26372461 -> V=0.9444445, theta=0.0
% INFO    : Bus 191	: V=1.02020663, theta=-34.5833907 -> V=1.022224, theta=0.0
% INFO    : Bus 192	: V=1.05772429, theta=-20.6421751 -> V=1.0000025, theta=0.0
% INFO    : Bus 193	: V=1.04211754, theta=-29.6167516 -> V=1.046665, theta=0.0
% INFO    : Bus 194	: V=1.056, theta=-24.8084248 -> V=1.0000025, theta=0.0
% INFO    : Bus 195	: V=1.0450331, theta=-32.4605615 -> V=1.0080005, theta=0.0
% INFO    : Bus 196	: V=1.04503452, theta=-32.460604 -> V=1.0080005, theta=0.0
% INFO    : Bus 197	: V=1.0141897, theta=-32.2451924 -> V=1.0000025, theta=0.0
% INFO    : Bus 198	: V=1.02001475, theta=-23.0392125 -> V=1.0000025, theta=0.0
% INFO    : Bus 199	: V=1.01797065, theta=-48.3616102 -> V=1.022224, theta=0.0
% INFO    : Bus 200	: V=1.08350695, theta=-23.092176 -> V=1.044445, theta=0.0
% INFO    : Bus 201	: V=1.03251802, theta=-21.0261708 -> V=0.9888895, theta=0.0
% INFO    : Bus 202	: V=0.98924488, theta=-31.9140237 -> V=1.015872, theta=0.0
% INFO    : Bus 203	: V=1.0538609, theta=-21.262209 -> V=1.022222, theta=0.0
% INFO    : Bus 204	: V=1.06275277, theta=-17.6321089 -> V=1.0288895, theta=0.0
% INFO    : Bus 205	: V=1.0806262, theta=-13.9262236 -> V=1.05263, theta=0.0
% INFO    : Bus 206	: V=1.00099391, theta=-29.1082641 -> V=1.015872, theta=0.0
% INFO    : Bus 207	: V=0.998775541, theta=-14.4398208 -> V=1.015872, theta=0.0
% INFO    : Bus 208	: V=1.02994044, theta=-31.4348495 -> V=1.027779, theta=0.0
% INFO    : Bus 209	: V=1.01773286, theta=-21.6895086 -> V=1.015872, theta=0.0
% INFO    : Bus 210	: V=1.001334, theta=-18.0189521 -> V=1.015872, theta=0.0
% INFO    : Bus 211	: V=1.00125822, theta=-17.8810358 -> V=1.015872, theta=0.0
% INFO    : Bus 212	: V=1.04607441, theta=-17.8137055 -> V=1.046665, theta=0.0
% INFO    : Bus 213	: V=1.04596506, theta=-17.8012714 -> V=1.046665, theta=0.0
% INFO    : Bus 214	: V=1.04653378, theta=-40.8987094 -> V=1.027779, theta=0.0
% INFO    : Bus 215	: V=1.04875608, theta=-36.7613791 -> V=1.046665, theta=0.0
% INFO    : Bus 216	: V=0.997442753, theta=-21.0728377 -> V=1.0079355, theta=0.0
% INFO    : Bus 217	: V=1.00529548, theta=-36.5328724 -> V=1.022224, theta=0.0
% INFO    : Bus 218	: V=1.03181198, theta=-22.2883585 -> V=1.022224, theta=0.0
% INFO    : Bus 219	: V=1.04725993, theta=-32.6044895 -> V=1.022224, theta=0.0
% INFO    : Bus 220	: V=1.02306231, theta=-4.31170672 -> V=1.0158755, theta=0.0
% INFO    : Bus 221	: V=1.03523913, theta=-20.2744684 -> V=0.999999, theta=0.0
% INFO    : Bus 222	: V=1.08673421, theta=-16.9442728 -> V=1.0115415, theta=0.0
% INFO    : Bus 223	: V=1.02240022, theta=-26.5436877 -> V=1.0000025, theta=0.0
% INFO    : Bus 224	: V=1.09903379, theta=-16.9533877 -> V=1.0, theta=0.0
% INFO    : Bus 225	: V=1.05365557, theta=-17.4986186 -> V=1.046665, theta=0.0
% INFO    : Bus 226	: V=1.05277673, theta=-17.4905818 -> V=1.046665, theta=0.0
% INFO    : Bus 227	: V=1.00523468, theta=-65.4085842 -> V=1.0079355, theta=0.0
% INFO    : Bus 228	: V=1.0011292, theta=-65.9537359 -> V=1.0079355, theta=0.0
% INFO    : Bus 229	: V=1.06036427, theta=-21.1310968 -> V=1.0000025, theta=0.0
% INFO    : Bus 230	: V=1.05409261, theta=-17.7133514 -> V=1.033334, theta=0.0
% INFO    : Bus 231	: V=1.02159822, theta=-33.7929454 -> V=1.022224, theta=0.0
% INFO    : Bus 232	: V=1.02185177, theta=-17.6540322 -> V=1.0111115, theta=0.0
% INFO    : Bus 233	: V=1.05491928, theta=-20.2117896 -> V=0.975, theta=0.0
% INFO    : Bus 234	: V=1.05491928, theta=-20.2117896 -> V=1.0111115, theta=0.0
% INFO    : Bus 235	: V=1.06350414, theta=-16.5316962 -> V=0.9888895, theta=0.0
% INFO    : Bus 236	: V=1.03161392, theta=-28.896997 -> V=1.000001, theta=0.0
% INFO    : Bus 237	: V=1.04264709, theta=-12.5647275 -> V=0.999999, theta=0.0
% INFO    : Bus 238	: V=1.03097544, theta=-33.3196315 -> V=1.022224, theta=0.0
% INFO    : Bus 239	: V=1.0254186, theta=-66.5625027 -> V=1.0079355, theta=0.0
% INFO    : Bus 240	: V=1.03816745, theta=-26.0387966 -> V=1.0000025, theta=0.0
% INFO    : Bus 241	: V=1.00826142, theta=-27.6942275 -> V=1.000001, theta=0.0
% INFO    : Bus 242	: V=0.991669358, theta=-28.3393625 -> V=1.015872, theta=0.0
% INFO    : Bus 243	: V=1.01698326, theta=-28.6224163 -> V=1.0000025, theta=0.0
% INFO    : Bus 244	: V=1.05013828, theta=-18.1166005 -> V=1.000001, theta=0.0
% INFO    : Bus 245	: V=1.0229306, theta=-30.1899411 -> V=1.0000025, theta=0.0
% INFO    : Bus 246	: V=1.02438367, theta=-5.95845046 -> V=0.999999, theta=0.0
% INFO    : Bus 247	: V=1.05496602, theta=-4.10290117 -> V=1.0111115, theta=0.0
% INFO    : Bus 248	: V=1.05387909, theta=-30.1240036 -> V=1.046665, theta=0.0
% INFO    : Bus 249	: V=1.03362507, theta=-28.3190117 -> V=1.0000025, theta=0.0
% INFO    : Bus 250	: V=1.0019054, theta=-26.4862118 -> V=1.0158755, theta=0.0
% INFO    : Bus 251	: V=1.0267786, theta=-40.1051006 -> V=1.022224, theta=0.0
% INFO    : Bus 252	: V=1.02300373, theta=-29.2051309 -> V=1.022224, theta=0.0
% INFO    : Bus 253	: V=1.02223066, theta=-24.1210237 -> V=1.0158755, theta=0.0
% INFO    : Bus 254	: V=1.02424846, theta=-23.8650622 -> V=1.0158755, theta=0.0
% INFO    : Bus 255	: V=1.02114981, theta=-22.7265748 -> V=0.999999, theta=0.0
% INFO    : Bus 256	: V=1.047, theta=-22.480992 -> V=1.0000025, theta=0.0
% INFO    : Bus 257	: V=1.08045932, theta=-23.1943667 -> V=1.044445, theta=0.0
% INFO    : Bus 258	: V=1.078, theta=-13.9319145 -> V=1.000001, theta=0.0
% INFO    : Bus 259	: V=1.03119988, theta=-21.9926111 -> V=1.0158755, theta=0.0
% INFO    : Bus 260	: V=1.06065358, theta=-19.7152158 -> V=1.0377785, theta=0.0
% INFO    : Bus 261	: V=1.04201919, theta=-28.9359591 -> V=1.0000025, theta=0.0
% INFO    : Bus 262	: V=1.05231276, theta=-17.882437 -> V=0.9888895, theta=0.0
% INFO    : Bus 263	: V=1.03792888, theta=-19.8807008 -> V=0.9888895, theta=0.0
% INFO    : Bus 264	: V=1.05275574, theta=-13.9074561 -> V=1.05921, theta=0.0
% INFO    : Bus 265	: V=0.984196219, theta=-34.2311004 -> V=1.0000005, theta=0.0
% INFO    : Bus 266	: V=1.04926203, theta=-30.2671936 -> V=1.046665, theta=0.0
% INFO    : Bus 267	: V=1.03429811, theta=-31.8956653 -> V=1.046665, theta=0.0
% INFO    : Bus 268	: V=0.997039702, theta=-20.3034079 -> V=1.0000025, theta=0.0
% INFO    : Bus 269	: V=1.00603616, theta=-31.7016721 -> V=1.0000025, theta=0.0
% INFO    : Bus 270	: V=1.04272832, theta=-12.4479327 -> V=1.033334, theta=0.0
% INFO    : Bus 271	: V=1.04288704, theta=-12.4485478 -> V=1.033334, theta=0.0
% INFO    : Bus 272	: V=1.02142207, theta=-17.9607493 -> V=1.015872, theta=0.0
% INFO    : Bus 273	: V=1.03965058, theta=-13.3145543 -> V=1.046665, theta=0.0
% INFO    : Bus 274	: V=1.05673733, theta=-26.4631545 -> V=1.022222, theta=0.0
% INFO    : Bus 275	: V=1.06980247, theta=-31.5017955 -> V=1.04444, theta=0.0
% INFO    : Bus 276	: V=1.08670873, theta=-25.4811688 -> V=1.07237, theta=0.0
% INFO    : Bus 277	: V=1.03945776, theta=-34.5071877 -> V=1.022224, theta=0.0
% INFO    : Bus 278	: V=1.06948193, theta=-31.5610822 -> V=1.04444, theta=0.0
% INFO    : Bus 279	: V=1.01875746, theta=-23.866064 -> V=0.999999, theta=0.0
% INFO    : Bus 280	: V=1.03135054, theta=-41.13262 -> V=1.027779, theta=0.0
% INFO    : Bus 281	: V=1.00611835, theta=-19.8438332 -> V=1.0158755, theta=0.0
% INFO    : Bus 282	: V=1.02438417, theta=-5.95846201 -> V=0.999999, theta=0.0
% INFO    : Bus 283	: V=1.0221035, theta=-42.1640855 -> V=1.022224, theta=0.0
% INFO    : Bus 284	: V=1.01582133, theta=-3.21974946 -> V=1.0158755, theta=0.0
% INFO    : Bus 285	: V=1.05612354, theta=-29.681294 -> V=1.046665, theta=0.0
% INFO    : Bus 286	: V=1.05593847, theta=-29.6968177 -> V=1.046665, theta=0.0
% INFO    : Bus 287	: V=1.03197788, theta=-30.3932038 -> V=1.022224, theta=0.0
% INFO    : Bus 288	: V=1.03719437, theta=-35.8294852 -> V=1.022224, theta=0.0
% INFO    : Bus 289	: V=1.06976394, theta=-4.09862461 -> V=0.9888895, theta=0.0
% INFO    : Bus 290	: V=1.05961349, theta=-19.0664292 -> V=1.033333, theta=0.0
% INFO    : Bus 291	: V=1.02249417, theta=-26.2118039 -> V=1.0000025, theta=0.0
% INFO    : Bus 292	: V=1.02874605, theta=-14.4266215 -> V=0.999999, theta=0.0
% INFO    : Bus 293	: V=1.02880214, theta=-14.4233739 -> V=0.999999, theta=0.0
% INFO    : Bus 294	: V=1.02778612, theta=-15.982115 -> V=1.0158755, theta=0.0
% INFO    : Bus 295	: V=1.04223267, theta=-21.8796124 -> V=0.9888895, theta=0.0
% INFO    : Bus 296	: V=1.00683224, theta=-21.9613166 -> V=1.0158755, theta=0.0
% INFO    : Bus 297	: V=0.9983637, theta=-22.1202927 -> V=0.999999, theta=0.0
% INFO    : Bus 298	: V=0.996721512, theta=-9.3744994 -> V=0.999999, theta=0.0
% INFO    : Bus 299	: V=1.05742607, theta=-19.1233537 -> V=1.033333, theta=0.0
% INFO    : Bus 300	: V=1.06193559, theta=-16.3639152 -> V=0.9888895, theta=0.0
% INFO    : Bus 301	: V=0.997349587, theta=-15.101472 -> V=1.015872, theta=0.0
% INFO    : Bus 302	: V=1.02887239, theta=-13.6115873 -> V=0.999999, theta=0.0
% INFO    : Bus 303	: V=0.985646874, theta=-35.0294199 -> V=1.0000025, theta=0.0
% INFO    : Bus 304	: V=0.994904716, theta=-26.0408415 -> V=1.015872, theta=0.0
% INFO    : Bus 305	: V=1.04954414, theta=-18.1446537 -> V=0.999999, theta=0.0
% INFO    : Bus 306	: V=1.00617026, theta=-20.1404288 -> V=1.0158755, theta=0.0
% INFO    : Bus 307	: V=1.00032043, theta=-49.2069197 -> V=1.022224, theta=0.0
% INFO    : Bus 308	: V=1.0429675, theta=-26.8508089 -> V=1.0000025, theta=0.0
% INFO    : Bus 309	: V=1.02998574, theta=-31.482602 -> V=1.015872, theta=0.0
% INFO    : Bus 310	: V=1.03013699, theta=-31.5125213 -> V=1.015872, theta=0.0
% INFO    : Bus 311	: V=0.993342121, theta=-36.1370655 -> V=1.022224, theta=0.0
% INFO    : Bus 312	: V=1.01013445, theta=-14.845692 -> V=1.000001, theta=0.0
% INFO    : Bus 313	: V=1.0357065, theta=-25.1160121 -> V=1.0000025, theta=0.0
% INFO    : Bus 314	: V=1.06771956, theta=-21.2359963 -> V=1.044445, theta=0.0
% INFO    : Bus 315	: V=1.06148934, theta=-33.2723882 -> V=1.027779, theta=0.0
% INFO    : Bus 316	: V=1.02357892, theta=-28.4746323 -> V=1.0000025, theta=0.0
% INFO    : Bus 317	: V=1.05741266, theta=-21.3578813 -> V=1.0000025, theta=0.0
% INFO    : Bus 318	: V=1.0034781, theta=-33.2624718 -> V=1.0000005, theta=0.0
% INFO    : Bus 319	: V=1.03837137, theta=-27.3667593 -> V=1.0000025, theta=0.0
% INFO    : Bus 320	: V=1.04390395, theta=-24.2969688 -> V=1.022222, theta=0.0
% INFO    : Bus 321	: V=1.04624247, theta=-25.0188354 -> V=1.0000025, theta=0.0
% INFO    : Bus 322	: V=1.03532593, theta=-14.8171267 -> V=1.044445, theta=0.0
% INFO    : Bus 323	: V=1.07367958, theta=-14.7701267 -> V=1.07879, theta=0.0
% INFO    : Bus 324	: V=1.02359078, theta=-10.0972287 -> V=0.999999, theta=0.0
% INFO    : Bus 325	: V=1.02932058, theta=-15.4648216 -> V=0.999999, theta=0.0
% INFO    : Bus 326	: V=1.03782877, theta=-22.030117 -> V=1.0000025, theta=0.0
% INFO    : Bus 327	: V=1.04466601, theta=-18.6697329 -> V=1.044445, theta=0.0
% INFO    : Bus 328	: V=1.01931425, theta=-24.1347758 -> V=1.0000025, theta=0.0
% INFO    : Bus 329	: V=1.05207993, theta=-24.9440201 -> V=1.022222, theta=0.0
% INFO    : Bus 330	: V=1.05178827, theta=-26.0751487 -> V=1.0000025, theta=0.0
% INFO    : Bus 331	: V=1.0676449, theta=-21.633252 -> V=1.044445, theta=0.0
% INFO    : Bus 332	: V=1.03569192, theta=-35.2466426 -> V=1.015872, theta=0.0
% INFO    : Bus 333	: V=1.04743343, theta=-27.5673573 -> V=1.0233335, theta=0.0
% INFO    : Bus 334	: V=1.03844267, theta=-62.2648321 -> V=1.0079355, theta=0.0
% INFO    : Bus 335	: V=1.0290222, theta=-20.606774 -> V=0.999999, theta=0.0
% INFO    : Bus 336	: V=1.023, theta=-23.1366301 -> V=1.0000025, theta=0.0
% INFO    : Bus 337	: V=1.04687756, theta=-27.7585081 -> V=1.0000025, theta=0.0
% INFO    : Bus 338	: V=1.06489248, theta=-23.2690968 -> V=1.0000025, theta=0.0
% INFO    : Bus 339	: V=1.02958526, theta=-26.4448977 -> V=1.0000025, theta=0.0
% INFO    : Bus 340	: V=1.04282869, theta=-31.878817 -> V=1.022224, theta=0.0
% INFO    : Bus 341	: V=1.06978734, theta=-25.1332997 -> V=1.0000025, theta=0.0
% INFO    : Bus 342	: V=1.01623618, theta=-17.6994392 -> V=1.0158755, theta=0.0
% INFO    : Bus 343	: V=1.02366689, theta=-14.7195373 -> V=1.0377785, theta=0.0
% INFO    : Bus 344	: V=1.00516117, theta=-16.3071742 -> V=1.015872, theta=0.0
% INFO    : Bus 345	: V=1.02445107, theta=-31.7690629 -> V=1.027779, theta=0.0
% INFO    : Bus 346	: V=1.06283817, theta=-8.53301908 -> V=1.046665, theta=0.0
% INFO    : Bus 347	: V=1.03475244, theta=-31.8667454 -> V=1.015872, theta=0.0
% INFO    : Bus 348	: V=1.04470359, theta=-28.2715195 -> V=1.022222, theta=0.0
% INFO    : Bus 349	: V=1.09052675, theta=-17.4811733 -> V=1.073685, theta=0.0
% INFO    : Bus 350	: V=1.09028231, theta=-17.4755834 -> V=1.073685, theta=0.0
% INFO    : Bus 351	: V=1.07337894, theta=-19.732709 -> V=1.044445, theta=0.0
% INFO    : Bus 352	: V=1.05499183, theta=-32.6260701 -> V=1.046665, theta=0.0
% INFO    : Bus 353	: V=0.999856824, theta=-35.392568 -> V=1.0000005, theta=0.0
% INFO    : Bus 354	: V=1.03014013, theta=-19.3912013 -> V=1.0000025, theta=0.0
% INFO    : Bus 355	: V=1.03765517, theta=-13.7940577 -> V=1.0000025, theta=0.0
% INFO    : Bus 356	: V=1.01766205, theta=-25.5920789 -> V=1.0000025, theta=0.0
% INFO    : Bus 357	: V=0.994050001, theta=-18.3361942 -> V=1.0158755, theta=0.0
% INFO    : Bus 358	: V=1.01809739, theta=-25.5630865 -> V=1.0000025, theta=0.0
% INFO    : Bus 359	: V=1.01010544, theta=-27.1256562 -> V=1.015872, theta=0.0
% INFO    : Bus 360	: V=1.04521436, theta=-25.1488551 -> V=1.0000025, theta=0.0
% INFO    : Bus 361	: V=1.0747394, theta=-21.1239661 -> V=1.0, theta=0.0
% INFO    : Bus 362	: V=1.07361906, theta=-19.9015692 -> V=1.044445, theta=0.0
% INFO    : Bus 363	: V=1.05981748, theta=-23.8424745 -> V=1.0111115, theta=0.0
% INFO    : Bus 364	: V=1.035, theta=-31.7697627 -> V=1.046665, theta=0.0
% INFO    : Bus 365	: V=1.04032727, theta=-10.5400452 -> V=0.999999, theta=0.0
% INFO    : Bus 366	: V=1.05471202, theta=-6.84158263 -> V=1.0111115, theta=0.0
% INFO    : Bus 367	: V=1.07570137, theta=-5.24351668 -> V=1.072365, theta=0.0
% INFO    : Bus 368	: V=1.0714801, theta=-6.20662022 -> V=1.072365, theta=0.0
% INFO    : Bus 369	: V=1.06735269, theta=-34.5876905 -> V=1.046665, theta=0.0
% INFO    : Bus 370	: V=1.01762064, theta=-32.594073 -> V=1.046665, theta=0.0
% INFO    : Bus 371	: V=1.01112712, theta=-4.31364094 -> V=1.0158755, theta=0.0
% INFO    : Bus 372	: V=1.04405704, theta=-6.1323898 -> V=1.0377785, theta=0.0
% INFO    : Bus 373	: V=1.06718223, theta=-34.6023651 -> V=1.046665, theta=0.0
% INFO    : Bus 374	: V=0.989951875, theta=-64.188326 -> V=1.0079355, theta=0.0
% INFO    : Bus 375	: V=1.012995, theta=-42.9276039 -> V=1.022224, theta=0.0
% INFO    : Bus 376	: V=1.02323947, theta=-49.4887777 -> V=1.0079355, theta=0.0
% INFO    : Bus 377	: V=0.999114277, theta=-16.2615601 -> V=1.0158755, theta=0.0
% INFO    : Bus 378	: V=1.0374685, theta=-19.5696458 -> V=0.999999, theta=0.0
% INFO    : Bus 379	: V=1.0476369, theta=-14.7587915 -> V=1.0111115, theta=0.0
% INFO    : Bus 380	: V=1.07099961, theta=-11.900282 -> V=1.072365, theta=0.0
% INFO    : Bus 381	: V=1.01595944, theta=-39.690392 -> V=1.027779, theta=0.0
% INFO    : Bus 382	: V=1.01403381, theta=-9.96607612 -> V=1.0158755, theta=0.0
% INFO    : Bus 383	: V=1.02159916, theta=-19.8638231 -> V=1.0000025, theta=0.0
% INFO    : Bus 384	: V=1.00036749, theta=-31.6253794 -> V=1.0000025, theta=0.0
% INFO    : Bus 385	: V=1.02049765, theta=-8.72170342 -> V=1.0000025, theta=0.0
% INFO    : Bus 386	: V=1.07513613, theta=-19.6881555 -> V=1.044445, theta=0.0
% INFO    : Bus 387	: V=1.05914312, theta=-17.0602279 -> V=1.000001, theta=0.0
% INFO    : Bus 388	: V=1.04421346, theta=-26.4405775 -> V=1.022222, theta=0.0
% INFO    : Bus 389	: V=1.03633893, theta=-17.1599226 -> V=0.999999, theta=0.0
% INFO    : Bus 390	: V=1.02162937, theta=-17.9110711 -> V=1.015872, theta=0.0
% INFO    : Bus 391	: V=1.03055102, theta=-24.4328262 -> V=1.0000025, theta=0.0
% INFO    : Bus 392	: V=0.998611608, theta=-29.9051234 -> V=1.015872, theta=0.0
% INFO    : Bus 393	: V=1.0262156, theta=-19.8286851 -> V=1.0158755, theta=0.0
% INFO    : Bus 394	: V=1.03274712, theta=-25.1240449 -> V=1.0000025, theta=0.0
% INFO    : Bus 395	: V=1.03284961, theta=-25.1178183 -> V=1.0000025, theta=0.0
% INFO    : Bus 396	: V=1.04268437, theta=-8.98161405 -> V=1.0158755, theta=0.0
% INFO    : Bus 397	: V=1.03212539, theta=-28.3146997 -> V=1.0000025, theta=0.0
% INFO    : Bus 398	: V=1.02275202, theta=-42.0482757 -> V=1.022224, theta=0.0
% INFO    : Bus 399	: V=1.07475522, theta=-20.1635124 -> V=1.0000025, theta=0.0
% INFO    : Bus 400	: V=1.03835387, theta=-26.4639054 -> V=1.0000025, theta=0.0
% INFO    : Bus 401	: V=1.03411307, theta=-20.0719947 -> V=0.999999, theta=0.0
% INFO    : Bus 402	: V=1.01504217, theta=-30.567527 -> V=1.000001, theta=0.0
% INFO    : Bus 403	: V=1.03276274, theta=-13.002357 -> V=0.999999, theta=0.0
% INFO    : Bus 404	: V=1.04141919, theta=-15.9334843 -> V=0.999999, theta=0.0
% INFO    : Bus 405	: V=1.01627903, theta=-17.973936 -> V=0.999999, theta=0.0
% INFO    : Bus 406	: V=1.01746924, theta=-31.3715206 -> V=1.022224, theta=0.0
% INFO    : Bus 407	: V=1.02819101, theta=-37.1819112 -> V=1.022224, theta=0.0
% INFO    : Bus 408	: V=1.05328366, theta=-33.3457637 -> V=1.0000025, theta=0.0
% INFO    : Bus 409	: V=1.02988277, theta=-28.0643599 -> V=1.015872, theta=0.0
% INFO    : Bus 410	: V=1.02246983, theta=-45.2162666 -> V=1.022224, theta=0.0
% INFO    : Bus 411	: V=1.02447567, theta=-35.5912862 -> V=1.022224, theta=0.0
% INFO    : Bus 412	: V=1.0131162, theta=-11.8578858 -> V=1.0158755, theta=0.0
% INFO    : Bus 413	: V=1.03043666, theta=-62.6294267 -> V=1.0079355, theta=0.0
% INFO    : Bus 414	: V=1.00302473, theta=-19.5871377 -> V=0.999999, theta=0.0
% INFO    : Bus 415	: V=1.01885738, theta=-24.6192293 -> V=1.0158755, theta=0.0
% INFO    : Bus 416	: V=1.04459244, theta=-33.790793 -> V=1.046665, theta=0.0
% INFO    : Bus 417	: V=1.03154697, theta=-31.7439115 -> V=1.0000025, theta=0.0
% INFO    : Bus 418	: V=1.00923689, theta=-31.9189114 -> V=1.0000005, theta=0.0
% INFO    : Bus 419	: V=1.04549306, theta=-32.6548335 -> V=1.0000025, theta=0.0
% INFO    : Bus 420	: V=1.0491312, theta=-32.2179712 -> V=1.0000025, theta=0.0
% INFO    : Bus 421	: V=1.01511918, theta=-37.5248257 -> V=1.015872, theta=0.0
% INFO    : Bus 422	: V=1.06178004, theta=-20.7081048 -> V=1.0000025, theta=0.0
% INFO    : Bus 423	: V=1.08389686, theta=-17.8250129 -> V=1.044445, theta=0.0
% INFO    : Bus 424	: V=1.03179575, theta=-6.62389331 -> V=1.0158755, theta=0.0
% INFO    : Bus 425	: V=1.06490897, theta=-3.07833969 -> V=1.0377785, theta=0.0
% INFO    : Bus 426	: V=1.00798869, theta=-33.2280267 -> V=1.0000005, theta=0.0
% INFO    : Bus 427	: V=1.02896084, theta=-10.8246043 -> V=0.999999, theta=0.0
% INFO    : Bus 428	: V=1.02960738, theta=-54.6127718 -> V=1.0079355, theta=0.0
% INFO    : Bus 429	: V=1.02652892, theta=-21.4473868 -> V=1.015872, theta=0.0
% INFO    : Bus 430	: V=1.05972417, theta=-31.1597091 -> V=1.046665, theta=0.0
% INFO    : Bus 431	: V=1.04880029, theta=-23.5118127 -> V=1.0000025, theta=0.0
% INFO    : Bus 432	: V=1.02493533, theta=-40.9603618 -> V=1.0000025, theta=0.0
% INFO    : Bus 433	: V=0.99179827, theta=-33.9368242 -> V=1.0000005, theta=0.0
% INFO    : Bus 434	: V=1.01464219, theta=-15.4782036 -> V=0.999999, theta=0.0
% INFO    : Bus 435	: V=1.02952882, theta=-31.0035246 -> V=1.000001, theta=0.0
% INFO    : Bus 436	: V=1.00340153, theta=-17.518046 -> V=1.015872, theta=0.0
% INFO    : Bus 437	: V=1.03686829, theta=-19.6214818 -> V=1.000001, theta=0.0
% INFO    : Bus 438	: V=0.990831041, theta=-34.6362593 -> V=1.0000005, theta=0.0
% INFO    : Bus 439	: V=1.02700524, theta=-15.4095065 -> V=1.0158755, theta=0.0
% INFO    : Bus 440	: V=1.01992597, theta=-30.7429289 -> V=1.0000025, theta=0.0
% INFO    : Bus 441	: V=1.02446087, theta=-14.6452168 -> V=0.999999, theta=0.0
% INFO    : Bus 442	: V=1.02758383, theta=-2.23288321 -> V=1.0158755, theta=0.0
% INFO    : Bus 443	: V=1.05682249, theta=-25.9989635 -> V=1.033333, theta=0.0
% INFO    : Bus 444	: V=1.06114405, theta=-26.8252602 -> V=1.033333, theta=0.0
% INFO    : Bus 445	: V=1.07162654, theta=-27.0577274 -> V=1.033333, theta=0.0
% INFO    : Bus 446	: V=1.02344927, theta=-21.8165407 -> V=1.006667, theta=0.0
% INFO    : Bus 447	: V=0.997, theta=-11.3819268 -> V=1.015872, theta=0.0
% INFO    : Bus 448	: V=1.02157893, theta=-2.87784341 -> V=1.0158755, theta=0.0
% INFO    : Bus 449	: V=1.08515919, theta=0.893383295 -> V=1.0410235, theta=0.0
% INFO    : Bus 450	: V=1.09042917, theta=2.07753863 -> V=1.072365, theta=0.0
% INFO    : Bus 451	: V=0.999777094, theta=-25.3905955 -> V=1.0000025, theta=0.0
% INFO    : Bus 452	: V=1.06341658, theta=-56.5583574 -> V=1.0090905, theta=0.0
% INFO    : Bus 453	: V=1.05912572, theta=-51.3018135 -> V=1.04444, theta=0.0
% INFO    : Bus 454	: V=1.03909419, theta=-26.1162884 -> V=1.0000025, theta=0.0
% INFO    : Bus 455	: V=1.04325376, theta=-25.7709423 -> V=1.022222, theta=0.0
% INFO    : Bus 456	: V=1.04259044, theta=-25.8284424 -> V=1.022222, theta=0.0
% INFO    : Bus 457	: V=0.970510614, theta=-32.1146555 -> V=1.015872, theta=0.0
% INFO    : Bus 458	: V=1.04265763, theta=-30.2127422 -> V=1.046665, theta=0.0
% INFO    : Bus 459	: V=1.03537023, theta=-27.3066155 -> V=1.06579, theta=0.0
% INFO    : Bus 460	: V=1.04860986, theta=-22.1317079 -> V=1.0000025, theta=0.0
% INFO    : Bus 461	: V=1.01831314, theta=-8.40244389 -> V=1.0158755, theta=0.0
% INFO    : Bus 462	: V=1.04340168, theta=-61.7765309 -> V=1.0079355, theta=0.0
% INFO    : Bus 463	: V=1.01842373, theta=-25.8510454 -> V=1.022224, theta=0.0
% INFO    : Bus 464	: V=1.176, theta=-25.0291508 -> V=0.98822, theta=0.0
% INFO    : Bus 465	: V=1.04563655, theta=-26.452367 -> V=1.033333, theta=0.0
% INFO    : Bus 466	: V=1.03349312, theta=-45.9913561 -> V=1.0079355, theta=0.0
% INFO    : Bus 467	: V=0.983597364, theta=-34.9471795 -> V=1.0000005, theta=0.0
% INFO    : Bus 468	: V=1.01016609, theta=-39.7943082 -> V=1.0000005, theta=0.0
% INFO    : Bus 469	: V=1.0479505, theta=-14.7594695 -> V=1.0111115, theta=0.0
% INFO    : Bus 470	: V=1.04933842, theta=-19.1515427 -> V=0.999999, theta=0.0
% INFO    : Bus 471	: V=1.05021087, theta=-12.9912817 -> V=0.999999, theta=0.0
% INFO    : Bus 472	: V=1.08089785, theta=-14.7677706 -> V=1.052629, theta=0.0
% INFO    : Bus 473	: V=1.08087092, theta=-14.7681732 -> V=1.052629, theta=0.0
% INFO    : Bus 474	: V=1.00050398, theta=-37.6618956 -> V=1.027779, theta=0.0
% INFO    : Bus 475	: V=1.0267406, theta=-10.5312192 -> V=1.0158755, theta=0.0
% INFO    : Bus 476	: V=1.01540221, theta=-30.2554944 -> V=1.0000025, theta=0.0
% INFO    : Bus 477	: V=1.01778306, theta=-10.7768933 -> V=1.0158755, theta=0.0
% INFO    : Bus 478	: V=1.00723297, theta=-6.28719041 -> V=0.9505945, theta=0.0
% INFO    : Bus 479	: V=1.02639303, theta=-5.8862871 -> V=0.999999, theta=0.0
% INFO    : Bus 480	: V=1.03782356, theta=-13.1731392 -> V=0.999999, theta=0.0
% INFO    : Bus 481	: V=1.03456564, theta=-9.45497399 -> V=1.0111115, theta=0.0
% INFO    : Bus 482	: V=0.993369803, theta=-13.1768449 -> V=1.0158755, theta=0.0
% INFO    : Bus 483	: V=1.03851718, theta=-26.533814 -> V=1.0000025, theta=0.0
% INFO    : Bus 484	: V=1.0273914, theta=-31.1521232 -> V=1.022224, theta=0.0
% INFO    : Bus 485	: V=0.994733969, theta=-55.0037669 -> V=1.0079355, theta=0.0
% INFO    : Bus 486	: V=1.03805246, theta=-26.0236958 -> V=1.0000025, theta=0.0
% INFO    : Bus 487	: V=1.01693211, theta=-45.9622315 -> V=1.022224, theta=0.0
% INFO    : Bus 488	: V=1.04355819, theta=-26.6601633 -> V=1.0000025, theta=0.0
% INFO    : Bus 489	: V=1.00113509, theta=-24.3279773 -> V=1.0158755, theta=0.0
% INFO    : Bus 490	: V=1.06011318, theta=-24.4816441 -> V=1.0111115, theta=0.0
% INFO    : Bus 491	: V=1.05763244, theta=-10.388374 -> V=1.033334, theta=0.0
% INFO    : Bus 492	: V=1.01998951, theta=-21.3529256 -> V=0.999999, theta=0.0
% INFO    : Bus 493	: V=1.09599994, theta=-11.9125553 -> V=1.048485, theta=0.0
% INFO    : Bus 494	: V=1.09291439, theta=-11.851626 -> V=1.078945, theta=0.0
% INFO    : Bus 495	: V=1.09286468, theta=-11.8424915 -> V=1.078945, theta=0.0
% INFO    : Bus 496	: V=1.09291679, theta=-11.8400504 -> V=1.078945, theta=0.0
% INFO    : Bus 497	: V=1.09287331, theta=-11.8362118 -> V=1.078945, theta=0.0
% INFO    : Bus 498	: V=1.03314213, theta=-27.016047 -> V=1.0000025, theta=0.0
% INFO    : Bus 499	: V=1.08585971, theta=1.00144233 -> V=1.0413635, theta=0.0
% INFO    : Bus 500	: V=1.08603114, theta=1.03759289 -> V=1.0414435, theta=0.0
% INFO    : Bus 501	: V=1.0907211, theta=2.1801036 -> V=1.072365, theta=0.0
% INFO    : Bus 502	: V=1.0284194, theta=-38.9543706 -> V=1.022224, theta=0.0
% INFO    : Bus 503	: V=1.0451062, theta=-31.6550481 -> V=1.027779, theta=0.0
% INFO    : Bus 504	: V=1.03280977, theta=-28.741468 -> V=1.016666, theta=0.0
% INFO    : Bus 505	: V=1.04484098, theta=-24.3962502 -> V=1.0288895, theta=0.0
% INFO    : Bus 506	: V=1.02583528, theta=-49.471308 -> V=1.0079355, theta=0.0
% INFO    : Bus 507	: V=1.01133397, theta=-30.1815169 -> V=1.022224, theta=0.0
% INFO    : Bus 508	: V=1.02336586, theta=-18.4374053 -> V=0.999999, theta=0.0
% INFO    : Bus 509	: V=1.0417933, theta=-38.9996624 -> V=1.027779, theta=0.0
% INFO    : Bus 510	: V=1.00710203, theta=-37.5674996 -> V=1.015872, theta=0.0
% INFO    : Bus 511	: V=1.04051635, theta=-31.4574455 -> V=1.046665, theta=0.0
% INFO    : Bus 512	: V=0.936401481, theta=-7.66537631 -> V=0.9444445, theta=0.0
% INFO    : Bus 513	: V=1.00288579, theta=-7.66537631 -> V=0.999999, theta=0.0
% INFO    : Bus 514	: V=1.06285351, theta=-15.5760549 -> V=1.072365, theta=0.0
% INFO    : Bus 515	: V=1.01955515, theta=-38.1215441 -> V=1.022224, theta=0.0
% INFO    : Bus 516	: V=0.995950004, theta=-16.4610825 -> V=0.999999, theta=0.0
% INFO    : Bus 517	: V=1.01249008, theta=-30.292594 -> V=1.0000025, theta=0.0
% INFO    : Bus 518	: V=1.03365816, theta=-8.94926251 -> V=0.9688995, theta=0.0
% INFO    : Bus 519	: V=0.998331496, theta=-26.3502317 -> V=1.015874, theta=0.0
% INFO    : Bus 520	: V=1.02275624, theta=-33.2300504 -> V=1.022224, theta=0.0
% INFO    : Bus 521	: V=1.03512892, theta=-15.3798835 -> V=0.999999, theta=0.0
% INFO    : Bus 522	: V=1.03486016, theta=-14.9741029 -> V=0.999999, theta=0.0
% INFO    : Bus 523	: V=1.04985119, theta=-10.1091389 -> V=1.0111115, theta=0.0
% INFO    : Bus 524	: V=1.06641892, theta=-4.72465121 -> V=1.072365, theta=0.0
% INFO    : Bus 525	: V=1.04639225, theta=-40.9046243 -> V=1.027779, theta=0.0
% INFO    : Bus 526	: V=1.01947546, theta=-12.1555941 -> V=1.015872, theta=0.0
% INFO    : Bus 527	: V=1.06100086, theta=-7.47122004 -> V=1.046665, theta=0.0
% INFO    : Bus 528	: V=1.01239585, theta=-16.4952243 -> V=1.0158755, theta=0.0
% INFO    : Bus 529	: V=1.01229963, theta=-16.5064545 -> V=1.0158755, theta=0.0
% INFO    : Bus 530	: V=1.039, theta=-15.7908812 -> V=0.999999, theta=0.0
% INFO    : Bus 531	: V=0.998820193, theta=-33.7948723 -> V=1.0000005, theta=0.0
% INFO    : Bus 532	: V=0.998789358, theta=-33.7993153 -> V=1.0000005, theta=0.0
% INFO    : Bus 533	: V=0.991584667, theta=-32.8347492 -> V=1.0000005, theta=0.0
% INFO    : Bus 534	: V=0.992359825, theta=-32.8699299 -> V=1.0000005, theta=0.0
% INFO    : Bus 535	: V=1.04566862, theta=-27.6496267 -> V=1.022224, theta=0.0
% INFO    : Bus 536	: V=1.05525887, theta=-22.7289538 -> V=1.04444, theta=0.0
% INFO    : Bus 537	: V=1.02628448, theta=-35.3533294 -> V=1.022224, theta=0.0
% INFO    : Bus 538	: V=1.03699093, theta=-14.8968012 -> V=0.999999, theta=0.0
% INFO    : Bus 539	: V=1.01307782, theta=-44.4863889 -> V=1.022224, theta=0.0
% INFO    : Bus 540	: V=1.06397675, theta=-22.3739596 -> V=1.000001, theta=0.0
% INFO    : Bus 541	: V=1.02940355, theta=-13.4992737 -> V=0.999999, theta=0.0
% INFO    : Bus 542	: V=1.04969764, theta=-10.8765001 -> V=1.0111115, theta=0.0
% INFO    : Bus 543	: V=1.0496531, theta=-10.881783 -> V=1.0111115, theta=0.0
% INFO    : Bus 544	: V=1.02676187, theta=-36.9267514 -> V=1.027779, theta=0.0
% INFO    : Bus 545	: V=1.04483388, theta=-33.759889 -> V=1.046665, theta=0.0
% INFO    : Bus 546	: V=1.025, theta=-28.9594809 -> V=1.0000025, theta=0.0
% INFO    : Bus 547	: V=1.03456322, theta=-27.0556779 -> V=1.0000025, theta=0.0
% INFO    : Bus 548	: V=1.03863687, theta=-18.356704 -> V=1.0000025, theta=0.0
% INFO    : Bus 549	: V=1.0096437, theta=-33.0350723 -> V=1.0000025, theta=0.0
% INFO    : Bus 550	: V=1.04500823, theta=-21.836849 -> V=1.0000025, theta=0.0
% INFO    : Bus 551	: V=1.03217435, theta=-22.1853173 -> V=1.000001, theta=0.0
% INFO    : Bus 552	: V=1.02037811, theta=-17.5217188 -> V=0.999999, theta=0.0
% INFO    : Bus 553	: V=0.992368319, theta=-40.2019195 -> V=1.0000005, theta=0.0
% INFO    : Bus 554	: V=1.03162448, theta=-3.60202957 -> V=1.0158755, theta=0.0
% INFO    : Bus 555	: V=1.09002989, theta=-14.4536052 -> V=1.04533, theta=0.0
% INFO    : Bus 556	: V=1.09003189, theta=-14.4536271 -> V=1.04533, theta=0.0
% INFO    : Bus 557	: V=1.06842964, theta=-21.1440632 -> V=1.044445, theta=0.0
% INFO    : Bus 558	: V=1.06293096, theta=-29.4588987 -> V=1.046665, theta=0.0
% INFO    : Bus 559	: V=1.01897156, theta=-22.565062 -> V=0.999999, theta=0.0
% INFO    : Bus 560	: V=1.00568052, theta=-23.1503899 -> V=1.0158755, theta=0.0
% INFO    : Bus 561	: V=1.05684726, theta=-22.1719517 -> V=1.0000025, theta=0.0
% INFO    : Bus 562	: V=1.01014437, theta=-43.6281569 -> V=1.027779, theta=0.0
% INFO    : Bus 563	: V=1.00224841, theta=-14.0728644 -> V=1.015872, theta=0.0
% INFO    : Bus 564	: V=1.04907648, theta=-9.37818171 -> V=1.046665, theta=0.0
% INFO    : Bus 565	: V=1.02418868, theta=-22.7582678 -> V=1.0000025, theta=0.0
% INFO    : Bus 566	: V=1.02124137, theta=-51.7152879 -> V=1.022224, theta=0.0
% INFO    : Bus 567	: V=1.03415681, theta=-19.9377159 -> V=1.0000025, theta=0.0
% INFO    : Bus 568	: V=0.997866039, theta=-24.430801 -> V=1.015872, theta=0.0
% INFO    : Bus 569	: V=1.04060017, theta=-27.1224021 -> V=1.0000025, theta=0.0
% INFO    : Bus 570	: V=0.996174616, theta=-6.74764454 -> V=1.0158755, theta=0.0
% INFO    : Bus 571	: V=1.0163706, theta=-31.2449605 -> V=1.0000025, theta=0.0
% INFO    : Bus 572	: V=1.00505882, theta=-16.6299902 -> V=0.999999, theta=0.0
% INFO    : Bus 573	: V=1.0141897, theta=-32.2451924 -> V=1.0000025, theta=0.0
% INFO    : Bus 574	: V=1.0287516, theta=-26.7170675 -> V=1.022224, theta=0.0
% INFO    : Bus 575	: V=1.02035168, theta=-22.411127 -> V=0.999999, theta=0.0
% INFO    : Bus 576	: V=1.05489379, theta=-20.8522188 -> V=1.0111115, theta=0.0
% INFO    : Bus 577	: V=1.06421961, theta=-21.6107321 -> V=1.044445, theta=0.0
% INFO    : Bus 578	: V=1.01264828, theta=-30.2019275 -> V=1.0000025, theta=0.0
% INFO    : Bus 579	: V=1.05252506, theta=-20.315959 -> V=1.046665, theta=0.0
% INFO    : Bus 580	: V=1.05239063, theta=-20.3268178 -> V=1.046665, theta=0.0
% INFO    : Bus 581	: V=1.05367889, theta=-15.0402897 -> V=1.046665, theta=0.0
% INFO    : Bus 582	: V=1.05069795, theta=-11.7088294 -> V=1.06579, theta=0.0
% INFO    : Bus 583	: V=1.009, theta=-33.2079065 -> V=1.0000005, theta=0.0
% INFO    : Bus 584	: V=1.03419592, theta=-14.8149174 -> V=0.999999, theta=0.0
% INFO    : Bus 585	: V=0.985454044, theta=-7.91835717 -> V=1.0158755, theta=0.0
% INFO    : Bus 586	: V=1.02223991, theta=-11.7269547 -> V=0.999999, theta=0.0
% INFO    : Bus 587	: V=1.00719308, theta=-8.29339369 -> V=1.0158755, theta=0.0
% INFO    : Bus 588	: V=1.04036067, theta=-11.7135699 -> V=0.999999, theta=0.0
% INFO    : Bus 589	: V=1.01744454, theta=-24.680098 -> V=1.000001, theta=0.0
% INFO    : Bus 590	: V=1.06261263, theta=-16.2050783 -> V=0.9888895, theta=0.0
% INFO    : Bus 591	: V=1.01840795, theta=-51.3359379 -> V=1.0079355, theta=0.0
% INFO    : Bus 592	: V=1.03449857, theta=-39.3350518 -> V=1.0000025, theta=0.0
% INFO    : Bus 593	: V=1.02908602, theta=-21.9931091 -> V=1.0000025, theta=0.0
% INFO    : Bus 594	: V=1.09599725, theta=-11.9124968 -> V=1.048485, theta=0.0
% INFO    : Bus 595	: V=1.09268972, theta=-11.913418 -> V=1.078945, theta=0.0
% INFO    : Bus 596	: V=1.03103123, theta=-47.5481139 -> V=1.022224, theta=0.0
% INFO    : Bus 597	: V=1.02382419, theta=-24.1475094 -> V=1.0158755, theta=0.0
% INFO    : Bus 598	: V=1.05625605, theta=-20.4289837 -> V=1.0377785, theta=0.0
% INFO    : Bus 599	: V=1.0120699, theta=-35.8954904 -> V=1.022224, theta=0.0
% INFO    : Bus 600	: V=1.02302333, theta=-31.0809522 -> V=1.015872, theta=0.0
% INFO    : Bus 601	: V=1.01068667, theta=-27.3479146 -> V=1.000001, theta=0.0
% INFO    : Bus 602	: V=1.03411242, theta=-22.8457452 -> V=1.0000025, theta=0.0
% INFO    : Bus 603	: V=1.06462066, theta=-21.3592504 -> V=1.044445, theta=0.0
% INFO    : Bus 604	: V=1.04957253, theta=-54.9653932 -> V=1.04444, theta=0.0
% INFO    : Bus 605	: V=1.04957253, theta=-54.9653932 -> V=1.04444, theta=0.0
% INFO    : Bus 606	: V=1.04957989, theta=-54.9655901 -> V=1.04444, theta=0.0
% INFO    : Bus 607	: V=1.03362736, theta=-58.8714257 -> V=1.0079355, theta=0.0
% INFO    : Bus 608	: V=1.04957149, theta=-54.9653655 -> V=1.04444, theta=0.0
% INFO    : Bus 609	: V=0.994584077, theta=-34.4120856 -> V=1.0000005, theta=0.0
% INFO    : Bus 610	: V=1.021, theta=-8.21415349 -> V=0.975, theta=0.0
% INFO    : Bus 611	: V=1.02477974, theta=-9.90969851 -> V=1.0111115, theta=0.0
% INFO    : Bus 612	: V=0.997697968, theta=-34.1722781 -> V=1.022224, theta=0.0
% INFO    : Bus 613	: V=0.990000627, theta=-34.9199237 -> V=1.0000005, theta=0.0
% INFO    : Bus 614	: V=0.990227608, theta=-34.0670273 -> V=1.0000025, theta=0.0
% INFO    : Bus 615	: V=1.03675022, theta=-17.8794353 -> V=1.0377785, theta=0.0
% INFO    : Bus 616	: V=1.08747268, theta=-14.4174542 -> V=1.044445, theta=0.0
% INFO    : Bus 617	: V=1.10139077, theta=-11.8143634 -> V=1.078945, theta=0.0
% INFO    : Bus 618	: V=1.00802596, theta=-38.8467023 -> V=1.0000005, theta=0.0
% INFO    : Bus 619	: V=1.0064995, theta=-38.9037998 -> V=1.0000005, theta=0.0
% INFO    : Bus 620	: V=1.00791824, theta=-33.2167587 -> V=1.0000005, theta=0.0
% INFO    : Bus 621	: V=1.007935, theta=-33.2185628 -> V=1.0000005, theta=0.0
% INFO    : Bus 622	: V=1.03803813, theta=-22.2063152 -> V=1.0158755, theta=0.0
% INFO    : Bus 623	: V=1.01124511, theta=-11.3264596 -> V=0.999999, theta=0.0
% INFO    : Bus 624	: V=1.047, theta=-6.86792709 -> V=1.0111115, theta=0.0
% INFO    : Bus 625	: V=1.01736402, theta=-61.3913278 -> V=1.0079355, theta=0.0
% INFO    : Bus 626	: V=1.01637265, theta=-14.3725164 -> V=1.015872, theta=0.0
% INFO    : Bus 627	: V=0.98774618, theta=-12.8778937 -> V=1.015872, theta=0.0
% INFO    : Bus 628	: V=1.05219488, theta=-11.8307921 -> V=1.0233335, theta=0.0
% INFO    : Bus 629	: V=1.05004056, theta=-24.2968433 -> V=1.022224, theta=0.0
% INFO    : Bus 630	: V=1.00174673, theta=-32.353762 -> V=1.0000005, theta=0.0
% INFO    : Bus 631	: V=1.0356316, theta=-31.5443518 -> V=1.046665, theta=0.0
% INFO    : Bus 632	: V=1.03600815, theta=-31.4393897 -> V=1.046665, theta=0.0
% INFO    : Bus 633	: V=1.0283882, theta=-14.4603433 -> V=0.999999, theta=0.0
% INFO    : Bus 634	: V=1.01073539, theta=-64.1712381 -> V=1.0079355, theta=0.0
% INFO    : Bus 635	: V=0.985617443, theta=-19.2367223 -> V=1.0158755, theta=0.0
% INFO    : Bus 636	: V=0.999, theta=-21.6462709 -> V=1.015872, theta=0.0
% INFO    : Bus 637	: V=1.01624121, theta=-22.6580687 -> V=0.999999, theta=0.0
% INFO    : Bus 638	: V=1.04131753, theta=-29.8170463 -> V=1.022224, theta=0.0
% INFO    : Bus 639	: V=1.03347205, theta=-45.9934793 -> V=1.0079355, theta=0.0
% INFO    : Bus 640	: V=1.06287261, theta=-16.3043721 -> V=0.9888895, theta=0.0
% INFO    : Bus 641	: V=1.0901284, theta=-13.2018327 -> V=1.045315, theta=0.0
% INFO    : Bus 642	: V=1.0901284, theta=-13.2018327 -> V=1.04531, theta=0.0
% INFO    : Bus 643	: V=1.09016095, theta=-13.1913675 -> V=1.04535, theta=0.0
% INFO    : Bus 644	: V=1.0901284, theta=-13.2018327 -> V=1.04532, theta=0.0
% INFO    : Bus 645	: V=1.09015222, theta=-13.1929235 -> V=1.045345, theta=0.0
% INFO    : Bus 646	: V=1.104, theta=-9.9811074 -> V=1.078945, theta=0.0
% INFO    : Bus 647	: V=1.02626537, theta=-5.91664838 -> V=0.999999, theta=0.0
% INFO    : Bus 648	: V=1.01140885, theta=-11.1199791 -> V=0.999999, theta=0.0
% INFO    : Bus 649	: V=1.0273235, theta=-13.7178688 -> V=0.999999, theta=0.0
% INFO    : Bus 650	: V=1.02501297, theta=-13.8518 -> V=0.999999, theta=0.0
% INFO    : Bus 651	: V=1.03062929, theta=-35.2984648 -> V=1.022224, theta=0.0
% INFO    : Bus 652	: V=0.987340789, theta=-16.9994226 -> V=1.0158755, theta=0.0
% INFO    : Bus 653	: V=1.02010754, theta=-18.8598823 -> V=1.015872, theta=0.0
% INFO    : Bus 654	: V=1.02550533, theta=-17.5057587 -> V=0.999999, theta=0.0
% INFO    : Bus 655	: V=1.03540553, theta=-28.5214685 -> V=1.0000025, theta=0.0
% INFO    : Bus 656	: V=1.01499465, theta=-46.4553523 -> V=1.022224, theta=0.0
% INFO    : Bus 657	: V=1.06456053, theta=-18.2568052 -> V=1.0000025, theta=0.0
% INFO    : Bus 658	: V=1.04594158, theta=-26.3331454 -> V=1.0000025, theta=0.0
% INFO    : Bus 659	: V=1.06440361, theta=-21.5811187 -> V=1.044445, theta=0.0
% INFO    : Bus 660	: V=1.03949504, theta=-10.4238218 -> V=1.0158755, theta=0.0
% INFO    : Bus 661	: V=1.02449719, theta=-27.0940897 -> V=1.0000025, theta=0.0
% INFO    : Bus 662	: V=1.03296365, theta=-29.3683502 -> V=1.015872, theta=0.0
% INFO    : Bus 663	: V=1.06803731, theta=-4.44630907 -> V=1.0377785, theta=0.0
% INFO    : Bus 664	: V=0.991872374, theta=-36.6174157 -> V=1.0000005, theta=0.0
% INFO    : Bus 665	: V=1.02259646, theta=-1.400621 -> V=1.0158755, theta=0.0
% INFO    : Bus 666	: V=0.994998557, theta=-52.0704649 -> V=1.022224, theta=0.0
% INFO    : Bus 667	: V=1.05931579, theta=-23.6861544 -> V=1.000001, theta=0.0
% INFO    : Bus 668	: V=1.04456821, theta=-27.9161027 -> V=1.022224, theta=0.0
% INFO    : Bus 669	: V=1.07950404, theta=-2.83970356 -> V=1.072365, theta=0.0
% INFO    : Bus 670	: V=1.07842798, theta=-2.90656131 -> V=1.072365, theta=0.0
% INFO    : Bus 671	: V=1.07952489, theta=-2.84010246 -> V=1.072365, theta=0.0
% INFO    : Bus 672	: V=1.0783858, theta=-2.91606077 -> V=1.072365, theta=0.0
% INFO    : Bus 673	: V=1.03531422, theta=-21.0402493 -> V=1.000001, theta=0.0
% INFO    : Bus 674	: V=1.06187176, theta=-17.2663702 -> V=1.006667, theta=0.0
% INFO    : Bus 675	: V=1.02463581, theta=-24.2631656 -> V=1.022224, theta=0.0
% INFO    : Bus 676	: V=1.02335546, theta=-29.4724417 -> V=1.027779, theta=0.0
% INFO    : Bus 677	: V=1.01420955, theta=-15.4614449 -> V=0.999999, theta=0.0
% INFO    : Bus 678	: V=1.02500149, theta=-24.459746 -> V=1.000001, theta=0.0
% INFO    : Bus 679	: V=1.05095921, theta=-29.3873295 -> V=1.022224, theta=0.0
% INFO    : Bus 680	: V=1.00497132, theta=-21.7059654 -> V=0.999999, theta=0.0
% INFO    : Bus 681	: V=1.06674767, theta=-9.92599499 -> V=1.0377785, theta=0.0
% INFO    : Bus 682	: V=1.05069362, theta=-46.2071792 -> V=1.024754, theta=0.0
% INFO    : Bus 683	: V=1.04896094, theta=-41.9621288 -> V=1.04444, theta=0.0
% INFO    : Bus 684	: V=0.987904676, theta=-49.5290254 -> V=1.0218635, theta=0.0
% INFO    : Bus 685	: V=1.0489226, theta=-26.012056 -> V=1.022224, theta=0.0
% INFO    : Bus 686	: V=1.00792462, theta=-39.805318 -> V=1.0000005, theta=0.0
% INFO    : Bus 687	: V=1.04613337, theta=-21.2933632 -> V=1.0000025, theta=0.0
% INFO    : Bus 688	: V=0.978314632, theta=-38.5144632 -> V=1.0000005, theta=0.0
% INFO    : Bus 689	: V=0.966, theta=-9.39748967 -> V=0.9444445, theta=0.0
% INFO    : Bus 690	: V=1.0766313, theta=-9.73491168 -> V=1.07237, theta=0.0
% INFO    : Bus 691	: V=0.98638607, theta=-21.2195949 -> V=0.999999, theta=0.0
% INFO    : Bus 692	: V=1.07664775, theta=-9.75273265 -> V=1.07237, theta=0.0
% INFO    : Bus 693	: V=1.01173152, theta=-36.4043661 -> V=1.027779, theta=0.0
% INFO    : Bus 694	: V=1.01015348, theta=-30.2882426 -> V=1.027779, theta=0.0
% INFO    : Bus 695	: V=1.04462794, theta=-19.3123647 -> V=0.999999, theta=0.0
% INFO    : Bus 696	: V=1.03233804, theta=-32.1903061 -> V=1.046665, theta=0.0
% INFO    : Bus 697	: V=1.01352395, theta=-27.305257 -> V=1.000001, theta=0.0
% INFO    : Bus 698	: V=1.04526732, theta=-13.1648705 -> V=1.033334, theta=0.0
% INFO    : Bus 699	: V=1.04532609, theta=-13.1640581 -> V=1.033334, theta=0.0
% INFO    : Bus 700	: V=1.03196052, theta=-29.6717452 -> V=1.022222, theta=0.0
% INFO    : Bus 701	: V=1.03979307, theta=-25.2745209 -> V=1.0288895, theta=0.0
% INFO    : Bus 702	: V=1.014, theta=-4.2446214 -> V=0.975, theta=0.0
% INFO    : Bus 703	: V=1.014, theta=-4.33184413 -> V=0.975, theta=0.0
% INFO    : Bus 704	: V=1.015, theta=-4.65057797 -> V=0.975, theta=0.0
% INFO    : Bus 705	: V=1.02419497, theta=-6.74104812 -> V=1.0111115, theta=0.0
% INFO    : Bus 706	: V=1.02454266, theta=-7.12145937 -> V=1.0111115, theta=0.0
% INFO    : Bus 707	: V=1.02378556, theta=-40.8298511 -> V=1.022224, theta=0.0
% INFO    : Bus 708	: V=1.02218806, theta=-42.2500348 -> V=1.022224, theta=0.0
% INFO    : Bus 709	: V=1.04739344, theta=-38.0544468 -> V=1.04444, theta=0.0
% INFO    : Bus 710	: V=0.963, theta=-9.45014494 -> V=0.9444445, theta=0.0
% INFO    : Bus 711	: V=1.00269719, theta=-31.3495734 -> V=1.022224, theta=0.0
% INFO    : Bus 712	: V=1.05212783, theta=-32.2931493 -> V=0.975, theta=0.0
% INFO    : Bus 713	: V=1.05210818, theta=-32.2952312 -> V=0.975, theta=0.0
% INFO    : Bus 714	: V=1.05212106, theta=-32.2970436 -> V=0.975, theta=0.0
% INFO    : Bus 715	: V=1.04060775, theta=-35.5198234 -> V=1.022224, theta=0.0
% INFO    : Bus 716	: V=1.04884763, theta=-37.9338343 -> V=1.022224, theta=0.0
% INFO    : Bus 717	: V=1.0521446, theta=-32.2844169 -> V=1.04444, theta=0.0
% INFO    : Bus 718	: V=1.032329, theta=-29.9753285 -> V=1.022224, theta=0.0
% INFO    : Bus 719	: V=1.01055618, theta=-21.8173806 -> V=1.015872, theta=0.0
% INFO    : Bus 720	: V=1.05357083, theta=-15.9952381 -> V=1.033334, theta=0.0
% INFO    : Bus 721	: V=0.975202116, theta=-28.8594211 -> V=1.0158755, theta=0.0
% INFO    : Bus 722	: V=1.03002815, theta=-24.4257096 -> V=1.022224, theta=0.0
% INFO    : Bus 723	: V=0.974425283, theta=-29.2034731 -> V=1.0158755, theta=0.0
% INFO    : Bus 724	: V=1.03109549, theta=-46.7818281 -> V=1.022224, theta=0.0
% INFO    : Bus 725	: V=1.00809922, theta=-6.16839605 -> V=1.0158755, theta=0.0
% INFO    : Bus 726	: V=1.07112468, theta=-23.0061085 -> V=1.04444, theta=0.0
% INFO    : Bus 727	: V=1.02877875, theta=-22.6905547 -> V=1.000001, theta=0.0
% INFO    : Bus 728	: V=1.00180068, theta=-16.4485632 -> V=0.999999, theta=0.0
% INFO    : Bus 729	: V=0.998576228, theta=-33.9998037 -> V=1.015872, theta=0.0
% INFO    : Bus 730	: V=1.02835693, theta=-25.8493042 -> V=1.015874, theta=0.0
% INFO    : Bus 731	: V=1.04861991, theta=-26.7997384 -> V=1.015874, theta=0.0
% INFO    : Bus 732	: V=1.03803617, theta=-22.6160468 -> V=1.0200005, theta=0.0
% INFO    : Bus 733	: V=0.984191901, theta=-34.230963 -> V=1.0000005, theta=0.0
% INFO    : Bus 734	: V=0.983855828, theta=-33.8170763 -> V=1.0000005, theta=0.0
% INFO    : Bus 735	: V=0.981776421, theta=-33.8569427 -> V=1.0000005, theta=0.0
% INFO    : Bus 736	: V=1.00297764, theta=-27.0823133 -> V=1.0000005, theta=0.0
% INFO    : Bus 737	: V=1.01836313, theta=-54.5402245 -> V=1.022224, theta=0.0
% INFO    : Bus 738	: V=0.995, theta=-14.6655106 -> V=0.999999, theta=0.0
% INFO    : Bus 739	: V=0.994452778, theta=-10.4609975 -> V=1.0158755, theta=0.0
% INFO    : Bus 740	: V=1.05967335, theta=-29.0299726 -> V=1.027779, theta=0.0
% INFO    : Bus 741	: V=1.02788043, theta=-30.1635473 -> V=1.000001, theta=0.0
% INFO    : Bus 742	: V=1.03412117, theta=-22.8460102 -> V=1.0000025, theta=0.0
% INFO    : Bus 743	: V=1.0594974, theta=-30.0629904 -> V=1.027779, theta=0.0
% INFO    : Bus 744	: V=1.04928528, theta=-30.1406557 -> V=1.046665, theta=0.0
% INFO    : Bus 745	: V=1.03823271, theta=-34.675743 -> V=1.022224, theta=0.0
% INFO    : Bus 746	: V=1.03927345, theta=-34.6965475 -> V=1.022224, theta=0.0
% INFO    : Bus 747	: V=1.03444322, theta=-13.0386311 -> V=1.0158755, theta=0.0
% INFO    : Bus 748	: V=1.06674213, theta=-10.1127395 -> V=1.0377785, theta=0.0
% INFO    : Bus 749	: V=1.00521092, theta=-13.6713916 -> V=0.999999, theta=0.0
% INFO    : Bus 750	: V=1.002, theta=-13.7066579 -> V=0.999999, theta=0.0
% INFO    : Bus 751	: V=1.014, theta=-44.211093 -> V=1.022224, theta=0.0
% INFO    : Bus 752	: V=1.01133938, theta=-55.8231952 -> V=1.0079355, theta=0.0
% INFO    : Bus 753	: V=1.01689306, theta=-45.9648627 -> V=1.022224, theta=0.0
% INFO    : Bus 754	: V=1.03740219, theta=-22.6216294 -> V=1.0000025, theta=0.0
% INFO    : Bus 755	: V=1.01429145, theta=-23.3187019 -> V=0.999999, theta=0.0
% INFO    : Bus 756	: V=1.02438481, theta=-5.95848539 -> V=0.999999, theta=0.0
% INFO    : Bus 757	: V=1.01321635, theta=-15.078808 -> V=1.0158755, theta=0.0
% INFO    : Bus 758	: V=1.04386923, theta=-18.108942 -> V=0.999999, theta=0.0
% INFO    : Bus 759	: V=1.03927016, theta=-29.3434034 -> V=1.046665, theta=0.0
% INFO    : Bus 760	: V=1.03679358, theta=-27.9341365 -> V=1.06579, theta=0.0
% INFO    : Bus 761	: V=1.00351575, theta=-14.5893428 -> V=1.015872, theta=0.0
% INFO    : Bus 762	: V=1.04869266, theta=-30.4643505 -> V=1.046665, theta=0.0
% INFO    : Bus 763	: V=1.04850584, theta=-22.028866 -> V=0.9888895, theta=0.0
% INFO    : Bus 764	: V=1.04850574, theta=-22.0288655 -> V=0.9888895, theta=0.0
% INFO    : Bus 765	: V=1.037, theta=-13.106509 -> V=0.999999, theta=0.0
% INFO    : Bus 766	: V=1.036, theta=-14.2068615 -> V=0.999999, theta=0.0
% INFO    : Bus 767	: V=0.567599432, theta=-21.9963195 -> V=0.825, theta=0.0
% INFO    : Bus 768	: V=1.03132204, theta=-21.9963195 -> V=1.0158755, theta=0.0
% INFO    : Bus 769	: V=1.01639601, theta=-5.30594 -> V=1.0158755, theta=0.0
% INFO    : Bus 770	: V=1.02496778, theta=-20.8341121 -> V=1.0158755, theta=0.0
% INFO    : Bus 771	: V=1.01074169, theta=-13.8795142 -> V=1.0158755, theta=0.0
% INFO    : Bus 772	: V=1.04609159, theta=-32.367819 -> V=1.022224, theta=0.0
% INFO    : Bus 773	: V=1.01578545, theta=-50.1875796 -> V=1.022224, theta=0.0
% INFO    : Bus 774	: V=1.05101908, theta=-43.8945971 -> V=1.04444, theta=0.0
% INFO    : Bus 775	: V=1.0361688, theta=-12.312774 -> V=0.975, theta=0.0
% INFO    : Bus 776	: V=1.0361688, theta=-12.312774 -> V=0.975, theta=0.0
% INFO    : Bus 777	: V=1.0361688, theta=-12.312774 -> V=0.975, theta=0.0
% INFO    : Bus 778	: V=1.03513367, theta=-12.312774 -> V=0.999999, theta=0.0
% INFO    : Bus 779	: V=1.00606552, theta=-30.8755419 -> V=1.0000025, theta=0.0
% INFO    : Bus 780	: V=1.06283971, theta=-29.736713 -> V=1.027779, theta=0.0
% INFO    : Bus 781	: V=1.02564427, theta=-5.39979512 -> V=1.0158755, theta=0.0
% INFO    : Bus 782	: V=1.07613783, theta=-0.538301718 -> V=1.0377785, theta=0.0
% INFO    : Bus 783	: V=1.03588793, theta=-48.7596546 -> V=1.0079355, theta=0.0
% INFO    : Bus 784	: V=1.03594143, theta=-48.7518507 -> V=1.0079355, theta=0.0
% INFO    : Bus 785	: V=1.03619454, theta=-48.7367946 -> V=1.0079355, theta=0.0
% INFO    : Bus 786	: V=1.01810567, theta=-23.2151375 -> V=1.0158755, theta=0.0
% INFO    : Bus 787	: V=1.02052274, theta=-26.6116595 -> V=1.0000025, theta=0.0
% INFO    : Bus 788	: V=1.04789551, theta=-19.3124972 -> V=1.046665, theta=0.0
% INFO    : Bus 789	: V=1.04637736, theta=-19.9258985 -> V=1.046665, theta=0.0
% INFO    : Bus 790	: V=1.02843725, theta=-10.2027861 -> V=0.999999, theta=0.0
% INFO    : Bus 791	: V=1.0141143, theta=-13.6072327 -> V=0.975, theta=0.0
% INFO    : Bus 792	: V=1.01944718, theta=-12.5782613 -> V=0.975, theta=0.0
% INFO    : Bus 793	: V=1.01842875, theta=-12.5782613 -> V=0.999999, theta=0.0
% INFO    : Bus 794	: V=1.01310119, theta=-13.6072327 -> V=0.999999, theta=0.0
% INFO    : Bus 795	: V=1.02539955, theta=-8.12321068 -> V=1.0111115, theta=0.0
% INFO    : Bus 796	: V=1.08516043, theta=-0.675325688 -> V=1.072365, theta=0.0
% INFO    : Bus 797	: V=1.00376695, theta=-17.969444 -> V=1.0158755, theta=0.0
% INFO    : Bus 798	: V=1.00879922, theta=-30.6051865 -> V=1.022224, theta=0.0
% INFO    : Bus 799	: V=1.02301362, theta=-19.950582 -> V=1.0158755, theta=0.0
% INFO    : Bus 800	: V=1.01669264, theta=-20.8008231 -> V=1.0158755, theta=0.0
% INFO    : Bus 801	: V=1.03209793, theta=-13.8408241 -> V=0.999999, theta=0.0
% INFO    : Bus 802	: V=1.01618335, theta=-61.3226984 -> V=1.0079355, theta=0.0
% INFO    : Bus 803	: V=1.02302986, theta=-19.7843271 -> V=0.999999, theta=0.0
% INFO    : Bus 804	: V=1.0193282, theta=-14.9760179 -> V=0.999999, theta=0.0
% INFO    : Bus 805	: V=1.06255782, theta=-7.34662814 -> V=1.072365, theta=0.0
% INFO    : Bus 806	: V=1.014, theta=-5.32278752 -> V=0.975, theta=0.0
% INFO    : Bus 807	: V=1.018, theta=-5.47607994 -> V=0.975, theta=0.0
% INFO    : Bus 808	: V=1.016, theta=-5.51241133 -> V=0.975, theta=0.0
% INFO    : Bus 809	: V=1.0246396, theta=-7.44343633 -> V=1.0111115, theta=0.0
% INFO    : Bus 810	: V=1.02511381, theta=-7.70016068 -> V=1.0111115, theta=0.0
% INFO    : Bus 811	: V=1.05641409, theta=-30.1786535 -> V=1.0000025, theta=0.0
% INFO    : Bus 812	: V=1.01695959, theta=-24.7747609 -> V=1.0000025, theta=0.0
% INFO    : Bus 813	: V=1.05572634, theta=-16.7220991 -> V=1.046665, theta=0.0
% INFO    : Bus 814	: V=1.05629389, theta=-16.6625567 -> V=1.046665, theta=0.0
% INFO    : Bus 815	: V=1.0294226, theta=-32.8054945 -> V=1.015872, theta=0.0
% INFO    : Bus 816	: V=1.00782218, theta=-30.1794265 -> V=1.0000025, theta=0.0
% INFO    : Bus 817	: V=1.04914002, theta=-18.0870949 -> V=1.046665, theta=0.0
% INFO    : Bus 818	: V=1.02846424, theta=-17.289219 -> V=0.999999, theta=0.0
% INFO    : Bus 819	: V=1.00075821, theta=-20.4221746 -> V=1.015872, theta=0.0
% INFO    : Bus 820	: V=1.022, theta=-13.296145 -> V=1.015872, theta=0.0
% INFO    : Bus 821	: V=1.022, theta=-10.9978629 -> V=1.015872, theta=0.0
% INFO    : Bus 822	: V=1.06021656, theta=-32.6462445 -> V=1.046665, theta=0.0
% INFO    : Bus 823	: V=1.01658431, theta=-61.3614233 -> V=1.0079355, theta=0.0
% INFO    : Bus 824	: V=1.02303475, theta=-31.5919173 -> V=1.0000025, theta=0.0
% INFO    : Bus 825	: V=1.02278503, theta=-31.6250088 -> V=1.0000025, theta=0.0
% INFO    : Bus 826	: V=1.04648565, theta=-19.854699 -> V=1.046665, theta=0.0
% INFO    : Bus 827	: V=1.04709569, theta=-19.8184721 -> V=1.046665, theta=0.0
% INFO    : Bus 828	: V=1.06531635, theta=-29.1748388 -> V=1.027779, theta=0.0
% INFO    : Bus 829	: V=1.06227604, theta=-17.3655702 -> V=1.0266685, theta=0.0
% INFO    : Bus 830	: V=0.999600098, theta=-16.7847744 -> V=1.015872, theta=0.0
% INFO    : Bus 831	: V=1.03150619, theta=-21.9701044 -> V=1.0000025, theta=0.0
% INFO    : Bus 832	: V=1.0595336, theta=-53.3120715 -> V=1.04444, theta=0.0
% INFO    : Bus 833	: V=1.05806236, theta=-48.4212457 -> V=1.07237, theta=0.0
% INFO    : Bus 834	: V=1.0507924, theta=-21.8003421 -> V=1.022222, theta=0.0
% INFO    : Bus 835	: V=1.047, theta=-24.961459 -> V=1.0000025, theta=0.0
% INFO    : Bus 836	: V=0.982930823, theta=-6.12938069 -> V=0.9444445, theta=0.0
% INFO    : Bus 837	: V=1.01006624, theta=-17.1053332 -> V=1.015872, theta=0.0
% INFO    : Bus 838	: V=1.06672581, theta=-17.9699484 -> V=1.0000025, theta=0.0
% INFO    : Bus 839	: V=1.03510344, theta=-34.8147647 -> V=1.027779, theta=0.0
% INFO    : Bus 840	: V=1.03895343, theta=-25.4927194 -> V=1.015874, theta=0.0
% INFO    : Bus 841	: V=1.018, theta=-23.5218534 -> V=1.0000025, theta=0.0
% INFO    : Bus 842	: V=1.0506217, theta=-20.4998362 -> V=1.0000025, theta=0.0
% INFO    : Bus 843	: V=1.05052231, theta=-20.4971493 -> V=1.0000025, theta=0.0
% INFO    : Bus 844	: V=1.03914624, theta=-31.7764205 -> V=1.0000025, theta=0.0
% INFO    : Bus 845	: V=1.0144461, theta=-24.5434801 -> V=1.0000025, theta=0.0
% INFO    : Bus 846	: V=1.05945998, theta=-29.9030868 -> V=1.027779, theta=0.0
% INFO    : Bus 847	: V=1.02816777, theta=-18.3515836 -> V=1.015872, theta=0.0
% INFO    : Bus 848	: V=1.03864793, theta=-29.4369186 -> V=1.027779, theta=0.0
% INFO    : Bus 849	: V=1.01416618, theta=-31.8684302 -> V=1.0000025, theta=0.0
% INFO    : Bus 850	: V=1.00429606, theta=-30.6630086 -> V=1.0000025, theta=0.0
% INFO    : Bus 851	: V=1.01335188, theta=-35.8891951 -> V=1.015872, theta=0.0
% INFO    : Bus 852	: V=1.01388819, theta=-35.9644653 -> V=1.015872, theta=0.0
% INFO    : Bus 853	: V=1.01499625, theta=-35.861401 -> V=1.015872, theta=0.0
% INFO    : Bus 854	: V=1.07480974, theta=-20.1630537 -> V=1.0000025, theta=0.0
% INFO    : Bus 855	: V=1.0863911, theta=-16.661769 -> V=1.044445, theta=0.0
% INFO    : Bus 856	: V=1.08505136, theta=-14.1378395 -> V=1.078945, theta=0.0
% INFO    : Bus 857	: V=1.04003687, theta=-20.120648 -> V=1.015874, theta=0.0
% INFO    : Bus 858	: V=1.05530031, theta=-16.4642906 -> V=1.0000005, theta=0.0
% INFO    : Bus 859	: V=1.05993971, theta=-6.96309068 -> V=1.05263, theta=0.0
% INFO    : Bus 860	: V=0.997019081, theta=-31.8228997 -> V=1.0000005, theta=0.0
% INFO    : Bus 861	: V=1.02340324, theta=-49.6630592 -> V=1.0079355, theta=0.0
% INFO    : Bus 862	: V=1.02502073, theta=-31.084903 -> V=1.0000025, theta=0.0
% INFO    : Bus 863	: V=1.04367574, theta=-23.7175411 -> V=1.0000025, theta=0.0
% INFO    : Bus 864	: V=1.06732327, theta=-34.5914343 -> V=1.046665, theta=0.0
% INFO    : Bus 865	: V=1.01769646, theta=-32.5881214 -> V=1.046665, theta=0.0
% INFO    : Bus 866	: V=1.02287363, theta=-64.0817274 -> V=1.0079355, theta=0.0
% INFO    : Bus 867	: V=1.0587905, theta=-19.8953451 -> V=1.0377785, theta=0.0
% INFO    : Bus 868	: V=1.0587905, theta=-19.8953451 -> V=1.0377785, theta=0.0
% INFO    : Bus 869	: V=1.028, theta=-22.2995359 -> V=1.0000025, theta=0.0
% INFO    : Bus 870	: V=1.027, theta=-22.4510527 -> V=1.0000025, theta=0.0
% INFO    : Bus 871	: V=1.03442234, theta=-1.82303962 -> V=1.0158755, theta=0.0
% INFO    : Bus 872	: V=1.01308361, theta=-33.7569565 -> V=1.015872, theta=0.0
% INFO    : Bus 873	: V=1.02229243, theta=-31.9123839 -> V=1.022224, theta=0.0
% INFO    : Bus 874	: V=0.998157664, theta=-35.0892678 -> V=1.015872, theta=0.0
% INFO    : Bus 875	: V=1.01115841, theta=-23.2746127 -> V=1.015872, theta=0.0
% INFO    : Bus 876	: V=1.00937561, theta=-23.3727567 -> V=1.015872, theta=0.0
% INFO    : Bus 877	: V=1.0647768, theta=-33.4536529 -> V=1.027779, theta=0.0
% INFO    : Bus 878	: V=1.03602366, theta=-17.2190998 -> V=1.015872, theta=0.0
% INFO    : Bus 879	: V=1.02267119, theta=-50.0197451 -> V=1.0079355, theta=0.0
% INFO    : Bus 880	: V=1.01637128, theta=-31.1005356 -> V=1.015872, theta=0.0
% INFO    : Bus 881	: V=1.01549416, theta=-31.119711 -> V=1.015872, theta=0.0
% INFO    : Bus 882	: V=1.05776916, theta=-30.4472754 -> V=1.046665, theta=0.0
% INFO    : Bus 883	: V=1.05736286, theta=-30.4655325 -> V=1.046665, theta=0.0
% INFO    : Bus 884	: V=0.992011193, theta=-33.9309658 -> V=1.0000005, theta=0.0
% INFO    : Bus 885	: V=1.0012643, theta=-34.2339655 -> V=1.0000005, theta=0.0
% INFO    : Bus 886	: V=1.02997623, theta=-30.0330514 -> V=1.046665, theta=0.0
% INFO    : Bus 887	: V=1.03482285, theta=-28.7762693 -> V=1.046665, theta=0.0
% INFO    : Bus 888	: V=1.03849031, theta=-26.2608483 -> V=1.0111115, theta=0.0
% INFO    : Bus 889	: V=1.03365289, theta=-63.2899459 -> V=1.0079355, theta=0.0
% INFO    : Bus 890	: V=1.04752559, theta=-28.4378614 -> V=1.0000025, theta=0.0
% INFO    : Bus 891	: V=1.01680674, theta=-26.9757872 -> V=1.000001, theta=0.0
% INFO    : Bus 892	: V=1.05357657, theta=-31.8303404 -> V=1.046665, theta=0.0
% INFO    : Bus 893	: V=1.0542643, theta=-31.7767895 -> V=1.046665, theta=0.0
% INFO    : Bus 894	: V=0.995157677, theta=-16.676414 -> V=0.975, theta=0.0
% INFO    : Bus 895	: V=1.06456964, theta=-21.6180831 -> V=1.0233335, theta=0.0
% INFO    : Bus 896	: V=1.01135565, theta=-24.0522731 -> V=1.0000025, theta=0.0
% INFO    : Bus 897	: V=1.03686288, theta=-23.933542 -> V=0.999999, theta=0.0
% INFO    : Bus 898	: V=1.02261476, theta=-26.5256095 -> V=1.015874, theta=0.0
% INFO    : Bus 899	: V=0.996438563, theta=-35.4086531 -> V=1.0000005, theta=0.0
% INFO    : Bus 900	: V=1.10073835, theta=7.31655984 -> V=1.07445, theta=0.0
% INFO    : Bus 901	: V=1.09385516, theta=4.23331421 -> V=1.072365, theta=0.0
% INFO    : Bus 902	: V=1.10409131, theta=8.66110228 -> V=1.076955, theta=0.0
% INFO    : Bus 903	: V=1.10419367, theta=8.67829651 -> V=1.07699, theta=0.0
% INFO    : Bus 904	: V=1.02565447, theta=-5.39998999 -> V=1.0158755, theta=0.0
% INFO    : Bus 905	: V=1.02382973, theta=-5.4856372 -> V=1.0158755, theta=0.0
% INFO    : Bus 906	: V=1.03959177, theta=-32.2545697 -> V=1.027779, theta=0.0
% INFO    : Bus 907	: V=1.04143211, theta=-33.8409254 -> V=1.0000025, theta=0.0
% INFO    : Bus 908	: V=1.03711217, theta=-29.325607 -> V=1.022222, theta=0.0
% INFO    : Bus 909	: V=1.02284572, theta=-26.3786439 -> V=1.015874, theta=0.0
% INFO    : Bus 910	: V=1.03440621, theta=-31.8033301 -> V=1.046665, theta=0.0
% INFO    : Bus 911	: V=1.02155013, theta=-17.9646735 -> V=1.015872, theta=0.0
% INFO    : Bus 912	: V=1.04593152, theta=-39.3025484 -> V=1.027779, theta=0.0
% INFO    : Bus 913	: V=1.02327717, theta=-18.6859351 -> V=1.015872, theta=0.0
% INFO    : Bus 914	: V=0.98663315, theta=-39.3710183 -> V=1.015872, theta=0.0
% INFO    : Bus 915	: V=1.01918016, theta=-18.7539317 -> V=1.015872, theta=0.0
% INFO    : Bus 916	: V=1.00911436, theta=-34.7708806 -> V=1.0000005, theta=0.0
% INFO    : Bus 917	: V=1.0090412, theta=-34.7820017 -> V=1.0000005, theta=0.0
% INFO    : Bus 918	: V=0.997298576, theta=-32.1219223 -> V=1.0000025, theta=0.0
% INFO    : Bus 919	: V=1.08137919, theta=-18.1149391 -> V=1.044445, theta=0.0
% INFO    : Bus 920	: V=1.08130727, theta=-18.4727573 -> V=1.044445, theta=0.0
% INFO    : Bus 921	: V=1.09015374, theta=-17.429834 -> V=1.078945, theta=0.0
% INFO    : Bus 922	: V=1.01440005, theta=-28.4624133 -> V=1.0000025, theta=0.0
% INFO    : Bus 923	: V=1.05917058, theta=-30.1942472 -> V=1.027779, theta=0.0
% INFO    : Bus 924	: V=1.0111592, theta=-24.6136478 -> V=1.0000025, theta=0.0
% INFO    : Bus 925	: V=1.02283906, theta=-30.3197631 -> V=1.0000025, theta=0.0
% INFO    : Bus 926	: V=1.02558776, theta=-8.15983019 -> V=1.0111115, theta=0.0
% INFO    : Bus 927	: V=1.03226956, theta=-13.8021537 -> V=0.999999, theta=0.0
% INFO    : Bus 928	: V=1.0085677, theta=-26.4525027 -> V=1.0000005, theta=0.0
% INFO    : Bus 929	: V=1.05093913, theta=-22.2118753 -> V=1.073685, theta=0.0
% INFO    : Bus 930	: V=1.03162064, theta=-24.0786092 -> V=0.999999, theta=0.0
% INFO    : Bus 931	: V=1.03281341, theta=-26.7852851 -> V=0.999999, theta=0.0
% INFO    : Bus 932	: V=1.06750448, theta=-9.72722765 -> V=1.0158755, theta=0.0
% INFO    : Bus 933	: V=1.02739269, theta=-25.8508569 -> V=1.0000025, theta=0.0
% INFO    : Bus 934	: V=1.04088053, theta=-15.5922938 -> V=1.0000025, theta=0.0
% INFO    : Bus 935	: V=1.01663781, theta=-32.7508859 -> V=1.0000025, theta=0.0
% INFO    : Bus 936	: V=1.04067435, theta=-32.16776 -> V=1.046665, theta=0.0
% INFO    : Bus 937	: V=1.06460521, theta=-32.0446452 -> V=1.046665, theta=0.0
% INFO    : Bus 938	: V=1.0659843, theta=-32.2113583 -> V=1.046665, theta=0.0
% INFO    : Bus 939	: V=1.05759822, theta=-26.5117154 -> V=1.073685, theta=0.0
% INFO    : Bus 940	: V=1.05761976, theta=-26.4844017 -> V=1.073685, theta=0.0
% INFO    : Bus 941	: V=1.02562914, theta=-46.3168206 -> V=1.022224, theta=0.0
% INFO    : Bus 942	: V=1.03943378, theta=-19.2544294 -> V=1.000001, theta=0.0
% INFO    : Bus 943	: V=1.02436316, theta=-15.6695716 -> V=1.0088895, theta=0.0
% INFO    : Bus 944	: V=1.06256726, theta=-7.35328089 -> V=1.072365, theta=0.0
% INFO    : Bus 945	: V=0.990006404, theta=-23.0086602 -> V=1.0000025, theta=0.0
% INFO    : Bus 946	: V=1.01890768, theta=-44.7792775 -> V=1.022224, theta=0.0
% INFO    : Bus 947	: V=1.02098436, theta=-29.6400348 -> V=1.0158755, theta=0.0
% INFO    : Bus 948	: V=1.0162861, theta=-30.64228 -> V=1.0158755, theta=0.0
% INFO    : Bus 949	: V=1.02341221, theta=-26.3313952 -> V=1.000001, theta=0.0
% INFO    : Bus 950	: V=1.00887257, theta=-25.3223276 -> V=1.015872, theta=0.0
% INFO    : Bus 951	: V=1.01865764, theta=-48.1485968 -> V=1.022224, theta=0.0
% INFO    : Bus 952	: V=1.02801543, theta=-22.6113142 -> V=1.022224, theta=0.0
% INFO    : Bus 953	: V=1.03619425, theta=-48.7367888 -> V=1.0079355, theta=0.0
% INFO    : Bus 954	: V=1.06475455, theta=-43.5057777 -> V=1.04444, theta=0.0
% INFO    : Bus 955	: V=1.03755506, theta=-8.35592796 -> V=1.0111115, theta=0.0
% INFO    : Bus 956	: V=1.01919883, theta=-34.9097112 -> V=1.022224, theta=0.0
% INFO    : Bus 957	: V=0.99956243, theta=-31.7910042 -> V=1.022224, theta=0.0
% INFO    : Bus 958	: V=1.04302368, theta=-10.4289708 -> V=0.999999, theta=0.0
% INFO    : Bus 959	: V=1.07503521, theta=-3.18884918 -> V=1.072365, theta=0.0
% INFO    : Bus 960	: V=1.02855137, theta=-24.8067788 -> V=1.022224, theta=0.0
% INFO    : Bus 961	: V=1.02854517, theta=-24.778241 -> V=1.022224, theta=0.0
% INFO    : Bus 962	: V=0.974689853, theta=-28.7595424 -> V=1.0158755, theta=0.0
% INFO    : Bus 963	: V=1.03044111, theta=-27.6634755 -> V=1.022224, theta=0.0
% INFO    : Bus 964	: V=0.991287365, theta=-33.3138696 -> V=1.0158755, theta=0.0
% INFO    : Bus 965	: V=1.03902576, theta=-29.1303785 -> V=1.022224, theta=0.0
% INFO    : Bus 966	: V=1.06745936, theta=-23.6452336 -> V=1.04444, theta=0.0
% INFO    : Bus 967	: V=1.07846519, theta=-20.4826983 -> V=1.07237, theta=0.0
% INFO    : Bus 968	: V=1.07848567, theta=-20.4794869 -> V=1.07237, theta=0.0
% INFO    : Bus 969	: V=0.998757069, theta=-25.2774299 -> V=1.0158755, theta=0.0
% INFO    : Bus 970	: V=1.061, theta=-6.40994918 -> V=0.975, theta=0.0
% INFO    : Bus 971	: V=1.08203353, theta=-6.00630264 -> V=1.0377785, theta=0.0
% INFO    : Bus 972	: V=1.02096037, theta=-53.650363 -> V=1.022224, theta=0.0
% INFO    : Bus 973	: V=1.00258154, theta=-24.8017554 -> V=1.0158755, theta=0.0
% INFO    : Bus 974	: V=1.03535802, theta=-16.6948739 -> V=1.0377785, theta=0.0
% INFO    : Bus 975	: V=1.00620825, theta=-15.2454966 -> V=1.0158755, theta=0.0
% INFO    : Bus 976	: V=1.03782323, theta=-13.1740106 -> V=0.999999, theta=0.0
% INFO    : Bus 977	: V=1.04402134, theta=-14.323103 -> V=0.999999, theta=0.0
% INFO    : Bus 978	: V=1.015, theta=-6.77628219 -> V=0.999999, theta=0.0
% INFO    : Bus 979	: V=1.0337986, theta=-36.2239208 -> V=1.022224, theta=0.0
% INFO    : Bus 980	: V=1.07525144, theta=-28.5039801 -> V=1.07237, theta=0.0
% INFO    : Bus 981	: V=1.00896247, theta=-14.468246 -> V=1.0158755, theta=0.0
% INFO    : Bus 982	: V=1.04689273, theta=-9.62655866 -> V=1.0377785, theta=0.0
% INFO    : Bus 983	: V=1.05190545, theta=-15.0652282 -> V=1.004059, theta=0.0
% INFO    : Bus 984	: V=1.039482, theta=-47.4501265 -> V=1.022224, theta=0.0
% INFO    : Bus 985	: V=1.02895822, theta=-15.3827754 -> V=0.999999, theta=0.0
% INFO    : Bus 986	: V=1.02495023, theta=-36.6144974 -> V=1.022224, theta=0.0
% INFO    : Bus 987	: V=1.02382444, theta=-32.0475135 -> V=1.022224, theta=0.0
% INFO    : Bus 988	: V=1.04048872, theta=-31.6585665 -> V=1.027779, theta=0.0
% INFO    : Bus 989	: V=1.06453245, theta=-27.6573839 -> V=1.046665, theta=0.0
% INFO    : Bus 990	: V=1.00532485, theta=-22.2345292 -> V=0.984126, theta=0.0
% INFO    : Bus 991	: V=1.03983706, theta=-29.9334849 -> V=1.022224, theta=0.0
% INFO    : Bus 992	: V=1.00847186, theta=-33.5731255 -> V=1.022224, theta=0.0
% INFO    : Bus 993	: V=1.00995398, theta=-31.867876 -> V=1.0000005, theta=0.0
% INFO    : Bus 994	: V=1.0622302, theta=-31.0347237 -> V=1.046665, theta=0.0
% INFO    : Bus 995	: V=1.0621387, theta=-31.0943542 -> V=1.046665, theta=0.0
% INFO    : Bus 996	: V=1.0198153, theta=-17.854784 -> V=1.0158755, theta=0.0
% INFO    : Bus 997	: V=1.04027019, theta=-17.9517985 -> V=0.999999, theta=0.0
% INFO    : Bus 998	: V=1.00532946, theta=-31.5016025 -> V=1.0158755, theta=0.0
% INFO    : Bus 999	: V=1.00071485, theta=-24.7385333 -> V=1.0158755, theta=0.0
% INFO    : Bus 1000	: V=0.969666285, theta=-8.95048473 -> V=0.975, theta=0.0
% INFO    : Bus 1001	: V=1.01441742, theta=-10.8885431 -> V=0.999999, theta=0.0
% INFO    : Bus 1002	: V=1.05055552, theta=-8.25431226 -> V=1.0111115, theta=0.0
% INFO    : Bus 1003	: V=1.0731928, theta=-4.52835159 -> V=1.072365, theta=0.0
% INFO    : Bus 1004	: V=1.02731397, theta=-34.9629932 -> V=1.027779, theta=0.0
% INFO    : Bus 1005	: V=1.02838397, theta=-13.7421934 -> V=0.999999, theta=0.0
% INFO    : Bus 1006	: V=1.03264745, theta=-12.8344344 -> V=0.999999, theta=0.0
% INFO    : Bus 1007	: V=1.0915439, theta=-13.3913866 -> V=1.045775, theta=0.0
% INFO    : Bus 1008	: V=1.07839269, theta=-15.183991 -> V=1.044445, theta=0.0
% INFO    : Bus 1009	: V=1.00996798, theta=-36.8142818 -> V=1.022224, theta=0.0
% INFO    : Bus 1010	: V=1.02246073, theta=-40.4743664 -> V=1.022224, theta=0.0
% INFO    : Bus 1011	: V=1.05188119, theta=-27.9767484 -> V=1.0233335, theta=0.0
% INFO    : Bus 1012	: V=1.05831309, theta=-30.8657578 -> V=1.046665, theta=0.0
% INFO    : Bus 1013	: V=1.04428926, theta=-30.4250358 -> V=1.046665, theta=0.0
% INFO    : Bus 1014	: V=1.051, theta=-23.9628284 -> V=1.000001, theta=0.0
% INFO    : Bus 1015	: V=1.03542779, theta=-50.0841144 -> V=1.022224, theta=0.0
% INFO    : Bus 1016	: V=1.05837018, theta=-12.267638 -> V=1.000844, theta=0.0
% INFO    : Bus 1017	: V=1.05681738, theta=-9.18016207 -> V=1.0111115, theta=0.0
% INFO    : Bus 1018	: V=1.061, theta=-12.2687721 -> V=1.001649, theta=0.0
% INFO    : Bus 1019	: V=1.04748401, theta=-35.0340675 -> V=1.022224, theta=0.0
% INFO    : Bus 1020	: V=1.00479292, theta=-20.6233174 -> V=0.999999, theta=0.0
% INFO    : Bus 1021	: V=1.01292809, theta=-20.3686033 -> V=1.0158755, theta=0.0
% INFO    : Bus 1022	: V=0.993878457, theta=-25.5241674 -> V=1.0158755, theta=0.0
% INFO    : Bus 1023	: V=1.04965313, theta=-27.7231334 -> V=1.04444, theta=0.0
% INFO    : Bus 1024	: V=1.04965974, theta=-27.7219281 -> V=1.04444, theta=0.0
% INFO    : Bus 1025	: V=1.01657374, theta=-32.2029283 -> V=1.022224, theta=0.0
% INFO    : Bus 1026	: V=0.992543933, theta=-12.8247379 -> V=0.9444445, theta=0.0
% INFO    : Bus 1027	: V=0.992534008, theta=-12.8230146 -> V=0.9444445, theta=0.0
% INFO    : Bus 1028	: V=0.992534008, theta=-12.8230146 -> V=0.9444445, theta=0.0
% INFO    : Bus 1029	: V=1.0095334, theta=-26.8145394 -> V=1.022224, theta=0.0
% INFO    : Bus 1030	: V=1.02040095, theta=-47.6758324 -> V=1.022224, theta=0.0
% INFO    : Bus 1031	: V=1.06787018, theta=-29.1856894 -> V=1.0185205, theta=0.0
% INFO    : Bus 1032	: V=1.0679195, theta=-29.1863008 -> V=1.0185455, theta=0.0
% INFO    : Bus 1033	: V=1.0416961, theta=-29.1834702 -> V=1.046665, theta=0.0
% INFO    : Bus 1034	: V=1.03720076, theta=-13.6069064 -> V=1.000001, theta=0.0
% INFO    : Bus 1035	: V=1.06372202, theta=-32.9421741 -> V=1.027779, theta=0.0
% INFO    : Bus 1036	: V=1.06271198, theta=-33.0873185 -> V=1.027779, theta=0.0
% INFO    : Bus 1037	: V=1.04587719, theta=-42.1657002 -> V=1.022224, theta=0.0
% INFO    : Bus 1038	: V=1.01476253, theta=-29.7374221 -> V=1.0000005, theta=0.0
% INFO    : Bus 1039	: V=1.03577024, theta=-23.9599024 -> V=1.046665, theta=0.0
% INFO    : Bus 1040	: V=1.05066779, theta=-21.3716963 -> V=1.073685, theta=0.0
% INFO    : Bus 1041	: V=1.0684135, theta=-17.2514277 -> V=1.073685, theta=0.0
% INFO    : Bus 1042	: V=1.05105265, theta=-21.1837531 -> V=1.073685, theta=0.0
% INFO    : Bus 1043	: V=1.00994963, theta=-11.7449108 -> V=0.999999, theta=0.0
% INFO    : Bus 1044	: V=1.05085944, theta=-21.277711 -> V=1.073685, theta=0.0
% INFO    : Bus 1045	: V=1.02840479, theta=-49.3073121 -> V=1.0079355, theta=0.0
% INFO    : Bus 1046	: V=1.03070322, theta=-49.4427735 -> V=1.0079355, theta=0.0
% INFO    : Bus 1047	: V=1.06327096, theta=-43.7407965 -> V=1.04444, theta=0.0
% INFO    : Bus 1048	: V=1.01747433, theta=-45.3100936 -> V=1.027779, theta=0.0
% INFO    : Bus 1049	: V=1.04815437, theta=-15.4047054 -> V=0.999999, theta=0.0
% INFO    : Bus 1050	: V=1.06436892, theta=-17.8344757 -> V=1.05263, theta=0.0
% INFO    : Bus 1051	: V=1.06040856, theta=-31.257628 -> V=1.046665, theta=0.0
% INFO    : Bus 1052	: V=1.05985378, theta=-31.0779397 -> V=1.046665, theta=0.0
% INFO    : Bus 1053	: V=1.01064856, theta=-11.4301465 -> V=0.999999, theta=0.0
% INFO    : Bus 1054	: V=1.07088204, theta=-4.32039546 -> V=1.072365, theta=0.0
% INFO    : Bus 1055	: V=0.979740134, theta=-18.0598624 -> V=1.015872, theta=0.0
% INFO    : Bus 1056	: V=1.01010977, theta=-21.7733807 -> V=1.000001, theta=0.0
% INFO    : Bus 1057	: V=1.08688976, theta=-25.4363893 -> V=1.07237, theta=0.0
% INFO    : Bus 1058	: V=1.03367371, theta=-35.21903 -> V=1.022224, theta=0.0
% INFO    : Bus 1059	: V=1.03633019, theta=-34.9251257 -> V=1.022224, theta=0.0
% INFO    : Bus 1060	: V=1.08691275, theta=-25.4362811 -> V=1.07237, theta=0.0
% INFO    : Bus 1061	: V=1.08691266, theta=-25.4361795 -> V=1.07237, theta=0.0
% INFO    : Bus 1062	: V=1.062, theta=-23.4540933 -> V=1.022222, theta=0.0
% INFO    : Bus 1063	: V=1.02561001, theta=-44.7961722 -> V=1.022224, theta=0.0
% INFO    : Bus 1064	: V=1.04754225, theta=-40.1800306 -> V=1.04444, theta=0.0
% INFO    : Bus 1065	: V=1.01489702, theta=-1.6297513 -> V=1.0158755, theta=0.0
% INFO    : Bus 1066	: V=1.09981774, theta=3.73241092 -> V=1.057685, theta=0.0
% INFO    : Bus 1067	: V=1.08786931, theta=3.53553115 -> V=1.05263, theta=0.0
% INFO    : Bus 1068	: V=1.05824604, theta=-6.89736511 -> V=1.0000025, theta=0.0
% INFO    : Bus 1069	: V=1.0697747, theta=-4.10653721 -> V=0.9888895, theta=0.0
% INFO    : Bus 1070	: V=1.0210487, theta=-30.1050025 -> V=0.9682545, theta=0.0
% INFO    : Bus 1071	: V=1.034, theta=-20.2204757 -> V=1.0000025, theta=0.0
% INFO    : Bus 1072	: V=1.01420459, theta=-31.47796 -> V=1.0000025, theta=0.0
% INFO    : Bus 1073	: V=1.01717075, theta=-31.5093953 -> V=1.0000025, theta=0.0
% INFO    : Bus 1074	: V=0.992255205, theta=-32.1969028 -> V=1.015872, theta=0.0
% INFO    : Bus 1075	: V=1.00540484, theta=-10.7557896 -> V=1.0158755, theta=0.0
% INFO    : Bus 1076	: V=1.04524846, theta=-28.414574 -> V=1.046665, theta=0.0
% INFO    : Bus 1077	: V=1.05297216, theta=-23.2550744 -> V=1.073685, theta=0.0
% INFO    : Bus 1078	: V=1.05433664, theta=-24.8704042 -> V=1.0000025, theta=0.0
% INFO    : Bus 1079	: V=1.08172597, theta=-21.4344902 -> V=1.044445, theta=0.0
% INFO    : Bus 1080	: V=1.07481903, theta=-11.3039056 -> V=1.07237, theta=0.0
% INFO    : Bus 1081	: V=1.07471056, theta=-11.3295375 -> V=1.07237, theta=0.0
% INFO    : Bus 1082	: V=1.01318204, theta=-38.8751239 -> V=1.022224, theta=0.0
% INFO    : Bus 1083	: V=1.01103483, theta=-11.8573194 -> V=0.999999, theta=0.0
% INFO    : Bus 1084	: V=1.01894912, theta=-17.8962147 -> V=0.999999, theta=0.0
% INFO    : Bus 1085	: V=1.03857218, theta=-15.8127223 -> V=0.999999, theta=0.0
% INFO    : Bus 1086	: V=1.05228264, theta=-12.0135179 -> V=1.0111115, theta=0.0
% INFO    : Bus 1087	: V=1.02878124, theta=-10.4906365 -> V=1.0158755, theta=0.0
% INFO    : Bus 1088	: V=1.01629121, theta=-22.4046885 -> V=1.0158755, theta=0.0
% INFO    : Bus 1089	: V=1.0156173, theta=-8.08498658 -> V=0.999999, theta=0.0
% INFO    : Bus 1090	: V=0.992147233, theta=-26.0420154 -> V=1.0158755, theta=0.0
% INFO    : Bus 1091	: V=1.0074814, theta=-64.0682967 -> V=1.0079355, theta=0.0
% INFO    : Bus 1092	: V=1.0426237, theta=-30.8456967 -> V=1.027779, theta=0.0
% INFO    : Bus 1093	: V=1.06386421, theta=-27.8719302 -> V=1.046665, theta=0.0
% INFO    : Bus 1094	: V=1.00835919, theta=-39.9750651 -> V=1.0000005, theta=0.0
% INFO    : Bus 1095	: V=0.973079458, theta=-36.2849437 -> V=1.0000005, theta=0.0
% INFO    : Bus 1096	: V=1.03519929, theta=-20.7168694 -> V=0.9888895, theta=0.0
% INFO    : Bus 1097	: V=1.0348297, theta=-20.7345026 -> V=0.9888895, theta=0.0
% INFO    : Bus 1098	: V=1.00493435, theta=-15.7119417 -> V=0.999999, theta=0.0
% INFO    : Bus 1099	: V=0.995935519, theta=-21.3732711 -> V=1.0158755, theta=0.0
% INFO    : Bus 1100	: V=1.05307343, theta=-15.4564591 -> V=1.003859, theta=0.0
% INFO    : Bus 1101	: V=1.05970206, theta=-12.1197153 -> V=0.999999, theta=0.0
% INFO    : Bus 1102	: V=1.03039621, theta=-49.4962146 -> V=1.0079355, theta=0.0
% INFO    : Bus 1103	: V=1.02556787, theta=-50.2397163 -> V=1.0079355, theta=0.0
% INFO    : Bus 1104	: V=1.02779151, theta=-49.3530603 -> V=1.0079355, theta=0.0
% INFO    : Bus 1105	: V=1.03026503, theta=-49.4862718 -> V=1.0079355, theta=0.0
% INFO    : Bus 1106	: V=1.00774462, theta=-31.5603285 -> V=1.0000005, theta=0.0
% INFO    : Bus 1107	: V=1.03102831, theta=-27.5319314 -> V=1.0000025, theta=0.0
% INFO    : Bus 1108	: V=1.02332741, theta=-60.7223498 -> V=1.0079355, theta=0.0
% INFO    : Bus 1109	: V=1.07051939, theta=-4.96167701 -> V=1.072365, theta=0.0
% INFO    : Bus 1110	: V=1.01253399, theta=-13.6647367 -> V=1.015872, theta=0.0
% INFO    : Bus 1111	: V=1.03739486, theta=-30.8662334 -> V=1.022224, theta=0.0
% INFO    : Bus 1112	: V=1.03298441, theta=-38.1828885 -> V=1.0032705, theta=0.0
% INFO    : Bus 1113	: V=1.078, theta=-11.4598397 -> V=0.975, theta=0.0
% INFO    : Bus 1114	: V=1.07643511, theta=-14.1174742 -> V=1.000001, theta=0.0
% INFO    : Bus 1115	: V=1.046, theta=-15.0853979 -> V=1.001754, theta=0.0
% INFO    : Bus 1116	: V=1.04703924, theta=-26.7815277 -> V=1.0000025, theta=0.0
% INFO    : Bus 1117	: V=1.05171193, theta=-20.2105962 -> V=1.044445, theta=0.0
% INFO    : Bus 1118	: V=1.0226666, theta=-24.155611 -> V=1.0158755, theta=0.0
% INFO    : Bus 1119	: V=1.0337565, theta=-10.266678 -> V=1.0158755, theta=0.0
% INFO    : Bus 1120	: V=1.03529249, theta=-27.6443896 -> V=1.0000025, theta=0.0
% INFO    : Bus 1121	: V=1.0273001, theta=-28.3859806 -> V=1.0000025, theta=0.0
% INFO    : Bus 1122	: V=1.02246359, theta=-16.9566883 -> V=1.015872, theta=0.0
% INFO    : Bus 1123	: V=1.01574028, theta=-34.3576081 -> V=1.022224, theta=0.0
% INFO    : Bus 1124	: V=1.0621465, theta=-31.0907054 -> V=1.046665, theta=0.0
% INFO    : Bus 1125	: V=1.03519209, theta=-26.2348908 -> V=1.022224, theta=0.0
% INFO    : Bus 1126	: V=1.03014541, theta=-10.7422384 -> V=1.0158755, theta=0.0
% INFO    : Bus 1127	: V=1.03294649, theta=-10.4135079 -> V=1.0158755, theta=0.0
% INFO    : Bus 1128	: V=1.05622478, theta=-10.6623442 -> V=1.003335, theta=0.0
% INFO    : Bus 1129	: V=1.01056382, theta=-14.3448188 -> V=0.999999, theta=0.0
% INFO    : Bus 1130	: V=1.02946301, theta=-27.3692916 -> V=1.0000025, theta=0.0
% INFO    : Bus 1131	: V=1.01982652, theta=-32.8178129 -> V=1.022224, theta=0.0
% INFO    : Bus 1132	: V=1.01934921, theta=-12.1522831 -> V=1.015872, theta=0.0
% INFO    : Bus 1133	: V=0.987016323, theta=-46.7316419 -> V=1.022224, theta=0.0
% INFO    : Bus 1134	: V=1.00417513, theta=-3.73836765 -> V=1.0158755, theta=0.0
% INFO    : Bus 1135	: V=1.02888802, theta=-43.1744362 -> V=1.022224, theta=0.0
% INFO    : Bus 1136	: V=1.05057724, theta=-39.1643975 -> V=1.04444, theta=0.0
% INFO    : Bus 1137	: V=1.0123788, theta=-38.9973337 -> V=1.022224, theta=0.0
% INFO    : Bus 1138	: V=1.02897813, theta=-20.6010468 -> V=0.999999, theta=0.0
% INFO    : Bus 1139	: V=1.04496219, theta=-17.2585679 -> V=1.0377785, theta=0.0
% INFO    : Bus 1140	: V=1.00778369, theta=-17.1303901 -> V=1.0000025, theta=0.0
% INFO    : Bus 1141	: V=1.00887144, theta=-31.3252812 -> V=1.0000005, theta=0.0
% INFO    : Bus 1142	: V=1.00642097, theta=-31.3927911 -> V=1.0000005, theta=0.0
% INFO    : Bus 1143	: V=1.02738258, theta=-28.0643946 -> V=1.046665, theta=0.0
% INFO    : Bus 1144	: V=1.02397834, theta=-18.5008761 -> V=1.0111115, theta=0.0
% INFO    : Bus 1145	: V=1.01746931, theta=-17.8127907 -> V=1.015872, theta=0.0
% INFO    : Bus 1146	: V=1.03805122, theta=-61.2016166 -> V=1.0079355, theta=0.0
% INFO    : Bus 1147	: V=1.04985049, theta=-56.3897428 -> V=1.04444, theta=0.0
% INFO    : Bus 1148	: V=1.04759977, theta=-19.6174601 -> V=1.046665, theta=0.0
% INFO    : Bus 1149	: V=1.00159652, theta=-33.4297731 -> V=1.0000025, theta=0.0
% INFO    : Bus 1150	: V=1.03163162, theta=-16.5913131 -> V=0.975, theta=0.0
% INFO    : Bus 1151	: V=1.04056927, theta=-7.06676932 -> V=1.0111115, theta=0.0
% INFO    : Bus 1152	: V=1.02384041, theta=-25.0734275 -> V=1.022224, theta=0.0
% INFO    : Bus 1153	: V=1.0165159, theta=-17.3179687 -> V=1.0158755, theta=0.0
% INFO    : Bus 1154	: V=1.00676354, theta=-45.2148763 -> V=1.022224, theta=0.0
% INFO    : Bus 1155	: V=1.01084922, theta=-12.5605093 -> V=1.0158755, theta=0.0
% INFO    : Bus 1156	: V=1.02894692, theta=-10.8206298 -> V=0.999999, theta=0.0
% INFO    : Bus 1157	: V=1.02607537, theta=-10.723361 -> V=0.999999, theta=0.0
% INFO    : Bus 1158	: V=1.05239998, theta=-7.63969736 -> V=1.0111115, theta=0.0
% INFO    : Bus 1159	: V=1.01281434, theta=-33.7513802 -> V=1.015872, theta=0.0
% INFO    : Bus 1160	: V=1.00243982, theta=-27.9641487 -> V=1.022224, theta=0.0
% INFO    : Bus 1161	: V=1.05390813, theta=-31.7923397 -> V=1.046665, theta=0.0
% INFO    : Bus 1162	: V=1.04096265, theta=-29.2404065 -> V=1.046665, theta=0.0
% INFO    : Bus 1163	: V=1.04109791, theta=-29.2132922 -> V=1.046665, theta=0.0
% INFO    : Bus 1164	: V=1.04431472, theta=-35.2869827 -> V=1.027779, theta=0.0
% INFO    : Bus 1165	: V=1.04063568, theta=-34.1597273 -> V=1.027779, theta=0.0
% INFO    : Bus 1166	: V=1.04487895, theta=-35.2432549 -> V=1.027779, theta=0.0
% INFO    : Bus 1167	: V=1.0645351, theta=-30.5049847 -> V=1.046665, theta=0.0
% INFO    : Bus 1168	: V=1.00904951, theta=-33.7184624 -> V=1.0000005, theta=0.0
% INFO    : Bus 1169	: V=1.00677429, theta=-32.7484592 -> V=1.0000005, theta=0.0
% INFO    : Bus 1170	: V=0.952733602, theta=-8.26372461 -> V=0.9444445, theta=0.0
% INFO    : Bus 1171	: V=1.00923586, theta=-8.15703843 -> V=0.999999, theta=0.0
% INFO    : Bus 1172	: V=1.01532937, theta=-23.7104801 -> V=1.0158755, theta=0.0
% INFO    : Bus 1173	: V=1.03477408, theta=-20.7570283 -> V=0.9888895, theta=0.0
% INFO    : Bus 1174	: V=1.0304617, theta=-41.2006966 -> V=1.022224, theta=0.0
% INFO    : Bus 1175	: V=1.05515872, theta=-36.485597 -> V=1.04444, theta=0.0
% INFO    : Bus 1176	: V=1.0769428, theta=-41.6152303 -> V=1.04444, theta=0.0
% INFO    : Bus 1177	: V=1.07842383, theta=-41.410518 -> V=1.04444, theta=0.0
% INFO    : Bus 1178	: V=1.07814362, theta=-41.4525018 -> V=1.04444, theta=0.0
% INFO    : Bus 1179	: V=1.06958279, theta=-38.9477482 -> V=1.07237, theta=0.0
% INFO    : Bus 1180	: V=1.04053193, theta=-26.2212005 -> V=1.0000025, theta=0.0
% INFO    : Bus 1181	: V=1.0486834, theta=-5.79524958 -> V=1.0111115, theta=0.0
% INFO    : Bus 1182	: V=1.02254857, theta=-41.6971973 -> V=1.027779, theta=0.0
% INFO    : Bus 1183	: V=1.051758, theta=-28.9930993 -> V=1.027779, theta=0.0
% INFO    : Bus 1184	: V=1.03238539, theta=-28.3913068 -> V=1.022224, theta=0.0
% INFO    : Bus 1185	: V=1.0289127, theta=-28.5268884 -> V=1.022224, theta=0.0
% INFO    : Bus 1186	: V=0.978035991, theta=-28.1329502 -> V=1.0158755, theta=0.0
% INFO    : Bus 1187	: V=1.06179533, theta=-31.0810938 -> V=1.046665, theta=0.0
% INFO    : Bus 1188	: V=1.05956532, theta=-31.1635193 -> V=1.046665, theta=0.0
% INFO    : Bus 1189	: V=1.0388272, theta=-23.4969513 -> V=1.022224, theta=0.0
% INFO    : Bus 1190	: V=1.06787522, theta=-34.3736635 -> V=1.046665, theta=0.0
% INFO    : Bus 1191	: V=0.997990649, theta=-15.0021558 -> V=1.0158755, theta=0.0
% INFO    : Bus 1192	: V=1.05175244, theta=-28.9929335 -> V=1.027779, theta=0.0
% INFO    : Bus 1193	: V=1.03335722, theta=-16.2599831 -> V=0.999999, theta=0.0
% INFO    : Bus 1194	: V=1.03868972, theta=-14.5110568 -> V=0.999999, theta=0.0
% INFO    : Bus 1195	: V=1.02419008, theta=-13.6696363 -> V=0.999999, theta=0.0
% INFO    : Bus 1196	: V=1.06719546, theta=-9.6306022 -> V=1.0111115, theta=0.0
% INFO    : Bus 1197	: V=1.06585316, theta=-9.006477 -> V=1.0111115, theta=0.0
% INFO    : Bus 1198	: V=1.07217485, theta=-8.06231062 -> V=1.072365, theta=0.0
% INFO    : Bus 1199	: V=1.07695358, theta=-41.6154007 -> V=1.04444, theta=0.0
% INFO    : Bus 1200	: V=1.0695916, theta=-38.9479136 -> V=1.07237, theta=0.0
% INFO    : Bus 1201	: V=0.997959083, theta=-18.9876496 -> V=1.0158755, theta=0.0
% INFO    : Bus 1202	: V=1.01478661, theta=-34.2974449 -> V=1.0000005, theta=0.0
% INFO    : Bus 1203	: V=1.05342723, theta=-29.6713149 -> V=1.046665, theta=0.0
% INFO    : Bus 1204	: V=1.03456709, theta=-23.3620349 -> V=1.000001, theta=0.0
% INFO    : Bus 1205	: V=1.02233132, theta=-24.8400032 -> V=1.000001, theta=0.0
% INFO    : Bus 1206	: V=1.04048738, theta=-31.6585411 -> V=1.027779, theta=0.0
% INFO    : Bus 1207	: V=1.05310664, theta=-29.7137499 -> V=1.046665, theta=0.0
% INFO    : Bus 1208	: V=1.00665965, theta=-22.7931134 -> V=1.0158755, theta=0.0
% INFO    : Bus 1209	: V=1.04527905, theta=-18.5747625 -> V=1.0377785, theta=0.0
% INFO    : Bus 1210	: V=1.05748788, theta=-19.1241676 -> V=1.033333, theta=0.0
% INFO    : Bus 1211	: V=1.0359472, theta=-28.9225207 -> V=1.015872, theta=0.0
% INFO    : Bus 1212	: V=1.03764392, theta=-24.7994 -> V=1.046665, theta=0.0
% INFO    : Bus 1213	: V=1.01858705, theta=-34.7025605 -> V=1.022224, theta=0.0
% INFO    : Bus 1214	: V=1.01647852, theta=-38.7963492 -> V=1.022224, theta=0.0
% INFO    : Bus 1215	: V=1.091, theta=-12.7306474 -> V=1.04542, theta=0.0
% INFO    : Bus 1216	: V=1.075, theta=-17.631961 -> V=1.044445, theta=0.0
% INFO    : Bus 1217	: V=1.01384548, theta=-22.7056745 -> V=1.0000025, theta=0.0
% INFO    : Bus 1218	: V=1.01279384, theta=-13.3654279 -> V=1.015872, theta=0.0
% INFO    : Bus 1219	: V=1.08981112, theta=1.36009101 -> V=1.07973, theta=0.0
% INFO    : Bus 1220	: V=1.0095507, theta=-24.2658599 -> V=0.999999, theta=0.0
% INFO    : Bus 1221	: V=1.05529359, theta=-23.7261467 -> V=1.023584, theta=0.0
% INFO    : Bus 1222	: V=1.01467735, theta=-36.3802289 -> V=1.0000005, theta=0.0
% INFO    : Bus 1223	: V=1.02438712, theta=-19.342878 -> V=0.999999, theta=0.0
% INFO    : Bus 1224	: V=1.03732842, theta=-29.1091979 -> V=1.022224, theta=0.0
% INFO    : Bus 1225	: V=1.02623344, theta=-42.2193121 -> V=1.027779, theta=0.0
% INFO    : Bus 1226	: V=1.04275905, theta=-40.1059632 -> V=1.027779, theta=0.0
% INFO    : Bus 1227	: V=1.02626488, theta=-8.76671159 -> V=1.0111115, theta=0.0
% INFO    : Bus 1228	: V=1.03252822, theta=-22.921293 -> V=1.0158755, theta=0.0
% INFO    : Bus 1229	: V=1.01957112, theta=-45.0740218 -> V=1.022224, theta=0.0
% INFO    : Bus 1230	: V=1.05137615, theta=-39.9213392 -> V=1.04444, theta=0.0
% INFO    : Bus 1231	: V=1.01703343, theta=-18.6054597 -> V=1.015872, theta=0.0
% INFO    : Bus 1232	: V=0.99833498, theta=-32.0859644 -> V=1.0158755, theta=0.0
% INFO    : Bus 1233	: V=1.00601927, theta=-31.6735115 -> V=1.0158755, theta=0.0
% INFO    : Bus 1234	: V=1.00912653, theta=-6.937805 -> V=1.0158755, theta=0.0
% INFO    : Bus 1235	: V=1.0191608, theta=-24.9455824 -> V=1.000001, theta=0.0
% INFO    : Bus 1236	: V=1.05644853, theta=-33.7234874 -> V=0.975, theta=0.0
% INFO    : Bus 1237	: V=1.05644853, theta=-33.7234874 -> V=1.022224, theta=0.0
% INFO    : Bus 1238	: V=1.01513408, theta=-6.87910459 -> V=0.999999, theta=0.0
% INFO    : Bus 1239	: V=1.00700767, theta=-5.24481245 -> V=0.999999, theta=0.0
% INFO    : Bus 1240	: V=1.04470565, theta=-6.68063343 -> V=1.0111115, theta=0.0
% INFO    : Bus 1241	: V=1.04841982, theta=-5.72379269 -> V=1.0111115, theta=0.0
% INFO    : Bus 1242	: V=1.04643592, theta=-5.32005442 -> V=1.0111115, theta=0.0
% INFO    : Bus 1243	: V=1.06318991, theta=-0.29589758 -> V=1.072365, theta=0.0
% INFO    : Bus 1244	: V=1.0275991, theta=-15.976418 -> V=1.0158755, theta=0.0
% INFO    : Bus 1245	: V=1.05663079, theta=-10.684567 -> V=1.0377785, theta=0.0
% INFO    : Bus 1246	: V=1.02895404, theta=-23.877439 -> V=0.999999, theta=0.0
% INFO    : Bus 1247	: V=1.03915597, theta=-22.1079465 -> V=1.0158755, theta=0.0
% INFO    : Bus 1248	: V=1.0373384, theta=-18.4041783 -> V=1.0377785, theta=0.0
% INFO    : Bus 1249	: V=1.00649327, theta=-22.7868978 -> V=1.0158755, theta=0.0
% INFO    : Bus 1250	: V=0.984189676, theta=-21.5323503 -> V=1.0, theta=0.0
% INFO    : Bus 1251	: V=0.575259885, theta=-23.7109415 -> V=0.825, theta=0.0
% INFO    : Bus 1252	: V=1.01839282, theta=-23.6018871 -> V=1.0158755, theta=0.0
% INFO    : Bus 1253	: V=1.05700054, theta=-12.5382588 -> V=1.000159, theta=0.0
% INFO    : Bus 1254	: V=1.01148084, theta=-48.8502755 -> V=1.022224, theta=0.0
% INFO    : Bus 1255	: V=1.00447849, theta=-12.2542458 -> V=0.999999, theta=0.0
% INFO    : Bus 1256	: V=0.991660246, theta=-13.6841783 -> V=0.999999, theta=0.0
% INFO    : Bus 1257	: V=1.03730483, theta=-19.5647078 -> V=0.999999, theta=0.0
% INFO    : Bus 1258	: V=1.04955002, theta=-23.2805597 -> V=1.016666, theta=0.0
% INFO    : Bus 1259	: V=1.04278705, theta=-19.5971566 -> V=1.0111115, theta=0.0
% INFO    : Bus 1260	: V=1.0115427, theta=-19.2562153 -> V=1.0158755, theta=0.0
% INFO    : Bus 1261	: V=1.04079434, theta=-59.1795259 -> V=1.0079355, theta=0.0
% INFO    : Bus 1262	: V=1.00711773, theta=-13.9061685 -> V=1.015872, theta=0.0
% INFO    : Bus 1263	: V=1.02731997, theta=-17.0830161 -> V=1.0158755, theta=0.0
% INFO    : Bus 1264	: V=1.02522915, theta=-17.4556535 -> V=1.0158755, theta=0.0
% INFO    : Bus 1265	: V=1.03500877, theta=-13.5725554 -> V=1.0377785, theta=0.0
% INFO    : Bus 1266	: V=1.06560499, theta=-12.7930435 -> V=1.072365, theta=0.0
% INFO    : Bus 1267	: V=1.02400901, theta=-22.7951835 -> V=0.999999, theta=0.0
% INFO    : Bus 1268	: V=0.98991583, theta=-16.9355728 -> V=1.015872, theta=0.0
% INFO    : Bus 1269	: V=1.0606474, theta=-31.2429198 -> V=1.046665, theta=0.0
% INFO    : Bus 1270	: V=1.06016038, theta=-31.1476972 -> V=1.046665, theta=0.0
% INFO    : Bus 1271	: V=1.02161814, theta=-38.8354126 -> V=1.027779, theta=0.0
% INFO    : Bus 1272	: V=0.995695755, theta=-25.4826231 -> V=1.0158755, theta=0.0
% INFO    : Bus 1273	: V=1.0340632, theta=-1.53704168 -> V=1.0158755, theta=0.0
% INFO    : Bus 1274	: V=1.01050083, theta=-37.7853168 -> V=1.0000005, theta=0.0
% INFO    : Bus 1275	: V=1.07663394, theta=-4.42293098 -> V=1.072365, theta=0.0
% INFO    : Bus 1276	: V=1.07722468, theta=-4.38053641 -> V=1.072365, theta=0.0
% INFO    : Bus 1277	: V=1.00987059, theta=-21.802152 -> V=1.0000025, theta=0.0
% INFO    : Bus 1278	: V=1.032954, theta=-32.1321284 -> V=1.046665, theta=0.0
% INFO    : Bus 1279	: V=1.04826821, theta=-30.5205124 -> V=1.046665, theta=0.0
% INFO    : Bus 1280	: V=1.02495572, theta=-23.9500069 -> V=1.0158755, theta=0.0
% INFO    : Bus 1281	: V=1.03315033, theta=-31.9030533 -> V=1.027779, theta=0.0
% INFO    : Bus 1282	: V=1.02664952, theta=-29.2116137 -> V=1.033333, theta=0.0
% INFO    : Bus 1283	: V=1.06143169, theta=-7.53573594 -> V=1.046665, theta=0.0
% INFO    : Bus 1284	: V=1.04360271, theta=-35.69942 -> V=1.027779, theta=0.0
% INFO    : Bus 1285	: V=1.04863882, theta=-25.6429159 -> V=1.0111115, theta=0.0
% INFO    : Bus 1286	: V=1.04182368, theta=-20.2033103 -> V=0.9888895, theta=0.0
% INFO    : Bus 1287	: V=1.04209805, theta=-7.37201457 -> V=1.0111115, theta=0.0
% INFO    : Bus 1288	: V=1.02136284, theta=-10.6117214 -> V=1.0158755, theta=0.0
% INFO    : Bus 1289	: V=1.03059708, theta=-47.5017506 -> V=1.022224, theta=0.0
% INFO    : Bus 1290	: V=1.0080372, theta=-33.229533 -> V=1.0000005, theta=0.0
% INFO    : Bus 1291	: V=1.065, theta=-21.5800077 -> V=1.0000025, theta=0.0
% INFO    : Bus 1292	: V=1.04384466, theta=-20.2040199 -> V=1.0000025, theta=0.0
% INFO    : Bus 1293	: V=1.07932575, theta=-16.5555124 -> V=1.044445, theta=0.0
% INFO    : Bus 1294	: V=1.0177652, theta=-25.1654289 -> V=1.0000025, theta=0.0
% INFO    : Bus 1295	: V=1.00479258, theta=-65.409175 -> V=1.0079355, theta=0.0
% INFO    : Bus 1296	: V=1.04175652, theta=-8.32541376 -> V=1.046665, theta=0.0
% INFO    : Bus 1297	: V=1.0906706, theta=1.58394255 -> V=1.078945, theta=0.0
% INFO    : Bus 1298	: V=1.09073942, theta=1.59916468 -> V=1.078945, theta=0.0
% INFO    : Bus 1299	: V=1.09079756, theta=1.60194682 -> V=1.078945, theta=0.0
% INFO    : Bus 1300	: V=1.0905715, theta=1.58429503 -> V=1.078945, theta=0.0
% INFO    : Bus 1301	: V=1.02904206, theta=-41.7313673 -> V=1.022224, theta=0.0
% INFO    : Bus 1302	: V=1.00291471, theta=-51.8112089 -> V=1.022224, theta=0.0
% INFO    : Bus 1303	: V=0.974897671, theta=-24.6232206 -> V=0.999999, theta=0.0
% INFO    : Bus 1304	: V=1.01051539, theta=-21.499558 -> V=1.0158755, theta=0.0
% INFO    : Bus 1305	: V=1.01046561, theta=-21.5136997 -> V=1.0158755, theta=0.0
% INFO    : Bus 1306	: V=1.0677923, theta=-9.50893456 -> V=1.0111115, theta=0.0
% INFO    : Bus 1307	: V=1.00750534, theta=-15.1695401 -> V=0.999999, theta=0.0
% INFO    : Bus 1308	: V=1.0452412, theta=-26.4682029 -> V=0.975, theta=0.0
% INFO    : Bus 1309	: V=1.0690306, theta=-28.8689654 -> V=0.975, theta=0.0
% INFO    : Bus 1310	: V=1.0452412, theta=-26.4682029 -> V=1.0000025, theta=0.0
% INFO    : Bus 1311	: V=1.02127816, theta=-30.716527 -> V=1.0000025, theta=0.0
% INFO    : Bus 1312	: V=1.06402811, theta=-21.7713173 -> V=1.0233335, theta=0.0
% INFO    : Bus 1313	: V=1.0094811, theta=-23.098596 -> V=1.0000025, theta=0.0
% INFO    : Bus 1314	: V=1.02326922, theta=-28.5072259 -> V=1.0000025, theta=0.0
% INFO    : Bus 1315	: V=1.068, theta=-18.8297417 -> V=1.0000025, theta=0.0
% INFO    : Bus 1316	: V=1.00383257, theta=-27.3322835 -> V=1.0000025, theta=0.0
% INFO    : Bus 1317	: V=1.00375144, theta=-27.3692636 -> V=1.0000025, theta=0.0
% INFO    : Bus 1318	: V=1.046099, theta=-21.29237 -> V=1.0000025, theta=0.0
% INFO    : Bus 1319	: V=1.046099, theta=-21.29237 -> V=1.0000025, theta=0.0
% INFO    : Bus 1320	: V=1.02595433, theta=-46.8828 -> V=1.022224, theta=0.0
% INFO    : Bus 1321	: V=1.01365143, theta=-36.6630502 -> V=1.022224, theta=0.0
% INFO    : Bus 1322	: V=0.953730461, theta=-8.91070945 -> V=0.9444445, theta=0.0
% INFO    : Bus 1323	: V=0.953857893, theta=-8.90621647 -> V=0.9444445, theta=0.0
% INFO    : Bus 1324	: V=1.01034943, theta=-14.1464093 -> V=1.015872, theta=0.0
% INFO    : Bus 1325	: V=1.03036128, theta=-17.4290674 -> V=1.015872, theta=0.0
% INFO    : Bus 1326	: V=1.03951513, theta=-14.1238664 -> V=1.046665, theta=0.0
% INFO    : Bus 1327	: V=1.05102985, theta=-31.0407228 -> V=1.0000025, theta=0.0
% INFO    : Bus 1328	: V=0.982139692, theta=-6.07692173 -> V=0.9444445, theta=0.0
% INFO    : Bus 1329	: V=1.02621961, theta=-31.3417138 -> V=1.022224, theta=0.0
% INFO    : Bus 1330	: V=1.053, theta=-23.7415021 -> V=1.000001, theta=0.0
% INFO    : Bus 1331	: V=1.02892002, theta=-53.1514439 -> V=1.0079355, theta=0.0
% INFO    : Bus 1332	: V=1.03565926, theta=-24.0235593 -> V=1.0000025, theta=0.0
% INFO    : Bus 1333	: V=1.07605312, theta=-19.2928954 -> V=1.044445, theta=0.0
% INFO    : Bus 1334	: V=1.08945893, theta=-13.5865812 -> V=1.078945, theta=0.0
% INFO    : Bus 1335	: V=0.981116154, theta=-11.1513628 -> V=0.9444445, theta=0.0
% INFO    : Bus 1336	: V=1.03747261, theta=-10.7202783 -> V=0.999999, theta=0.0
% INFO    : Bus 1337	: V=1.00096591, theta=-20.6482303 -> V=1.0158755, theta=0.0
% INFO    : Bus 1338	: V=1.04155627, theta=-11.5635776 -> V=0.999999, theta=0.0
% INFO    : Bus 1339	: V=1.02957962, theta=-15.0786592 -> V=0.9888895, theta=0.0
% INFO    : Bus 1340	: V=1.05754626, theta=-10.1383731 -> V=1.046665, theta=0.0
% INFO    : Bus 1341	: V=1.01307273, theta=-13.6063532 -> V=0.999999, theta=0.0
% INFO    : Bus 1342	: V=1.04153333, theta=-15.6486437 -> V=1.0377785, theta=0.0
% INFO    : Bus 1343	: V=1.01715653, theta=-5.23235293 -> V=1.0158755, theta=0.0
% INFO    : Bus 1344	: V=1.08129046, theta=0.434697272 -> V=1.0390785, theta=0.0
% INFO    : Bus 1345	: V=1.02932863, theta=-13.4969952 -> V=0.999999, theta=0.0
% INFO    : Bus 1346	: V=1.04982638, theta=-10.8536915 -> V=1.0111115, theta=0.0
% INFO    : Bus 1347	: V=1.04049591, theta=-3.05383478 -> V=1.0158755, theta=0.0
% INFO    : Bus 1348	: V=1.00552386, theta=-27.3136099 -> V=1.0000005, theta=0.0
% INFO    : Bus 1349	: V=1.005, theta=-21.7806033 -> V=0.975, theta=0.0
% INFO    : Bus 1350	: V=1.06406119, theta=-21.7718905 -> V=1.0233335, theta=0.0
% INFO    : Bus 1351	: V=1.02861595, theta=-19.2510937 -> V=0.999999, theta=0.0
% INFO    : Bus 1352	: V=1.02624916, theta=-37.4672456 -> V=1.022224, theta=0.0
% INFO    : Bus 1353	: V=1.02618332, theta=-37.4712865 -> V=1.022224, theta=0.0
% INFO    : Bus 1354	: V=1.01903886, theta=-23.9025192 -> V=1.022224, theta=0.0
% INFO    : Bus 1355	: V=0.999562333, theta=-17.8482085 -> V=1.0158755, theta=0.0
% INFO    : Bus 1356	: V=1.03961272, theta=-28.333738 -> V=1.022224, theta=0.0
% INFO    : Bus 1357	: V=1.04562485, theta=-32.3616023 -> V=1.022224, theta=0.0
% INFO    : Bus 1358	: V=1.04967266, theta=-27.7199086 -> V=1.04444, theta=0.0
% INFO    : Bus 1359	: V=1.03698572, theta=-13.5621036 -> V=1.0000025, theta=0.0
% INFO    : Bus 1360	: V=1.03583389, theta=-12.2545257 -> V=0.9977785, theta=0.0
% INFO    : Bus 1361	: V=1.052, theta=-10.1148355 -> V=0.999999, theta=0.0
% INFO    : Bus 1362	: V=1.05, theta=-10.0756414 -> V=0.999999, theta=0.0
% INFO    : Bus 1363	: V=1.05501626, theta=-6.6779297 -> V=1.000001, theta=0.0
% INFO    : Bus 1364	: V=1.0280262, theta=-28.3762734 -> V=1.022224, theta=0.0
% INFO    : Bus 1365	: V=1.05426116, theta=-17.4354575 -> V=1.033334, theta=0.0
% INFO    : Bus 1366	: V=1.05427959, theta=-17.4354333 -> V=1.033334, theta=0.0
% INFO    : Bus 1367	: V=1.03140091, theta=-36.6190453 -> V=1.022224, theta=0.0
% INFO    : Bus 1368	: V=1.042, theta=-34.8388323 -> V=1.015872, theta=0.0
% INFO    : Bus 1369	: V=0.975142395, theta=-35.9574856 -> V=1.0000005, theta=0.0
% INFO    : Bus 1370	: V=0.978567575, theta=-36.4161707 -> V=1.0000005, theta=0.0
% INFO    : Bus 1371	: V=0.976171336, theta=-36.647436 -> V=1.0000005, theta=0.0
% INFO    : Bus 1372	: V=1.06612155, theta=-34.7010683 -> V=1.046665, theta=0.0
% INFO    : Bus 1373	: V=1.00706185, theta=-13.902597 -> V=1.015872, theta=0.0
% INFO    : Bus 1374	: V=0.99994713, theta=-31.7416668 -> V=1.022224, theta=0.0
% INFO    : Bus 1375	: V=1.03916083, theta=-29.1333375 -> V=1.022224, theta=0.0
% INFO    : Bus 1376	: V=1.04290145, theta=-29.5864313 -> V=1.027779, theta=0.0
% INFO    : Bus 1377	: V=1.03436015, theta=-31.8962482 -> V=1.046665, theta=0.0
% INFO    : Bus 1378	: V=1.00718442, theta=-30.6503109 -> V=1.0079355, theta=0.0
% INFO    : Bus 1379	: V=1.0185263, theta=-25.1512571 -> V=0.999999, theta=0.0
% INFO    : Bus 1380	: V=1.04059208, theta=-25.1456821 -> V=1.016666, theta=0.0
% INFO    : Bus 1381	: V=1.03283048, theta=-20.9982614 -> V=1.004445, theta=0.0
% INFO    : Bus 1382	: V=1.00915492, theta=-31.1131804 -> V=1.0158755, theta=0.0
% INFO    : Bus 1383	: V=1.00764259, theta=-13.9206483 -> V=1.015872, theta=0.0
% INFO    : Bus 1384	: V=1.01966117, theta=-32.8141517 -> V=1.022224, theta=0.0
% INFO    : Bus 1385	: V=1.01709911, theta=-18.6066436 -> V=1.015872, theta=0.0
% INFO    : Bus 1386	: V=1.02402005, theta=-30.4333459 -> V=1.0000005, theta=0.0
% INFO    : Bus 1387	: V=1.02770983, theta=-24.9718002 -> V=1.046665, theta=0.0
% INFO    : Bus 1388	: V=1.04242931, theta=-29.6216618 -> V=1.046665, theta=0.0
% INFO    : Bus 1389	: V=1.03900874, theta=-33.0429047 -> V=1.022224, theta=0.0
% INFO    : Bus 1390	: V=1.03383189, theta=-33.6652337 -> V=1.022224, theta=0.0
% INFO    : Bus 1391	: V=1.03041767, theta=-18.3826632 -> V=0.999999, theta=0.0
% INFO    : Bus 1392	: V=0.990653021, theta=-17.4648316 -> V=0.999999, theta=0.0
% INFO    : Bus 1393	: V=1.0099835, theta=-13.6395423 -> V=1.015872, theta=0.0
% INFO    : Bus 1394	: V=0.992706444, theta=-40.1272225 -> V=1.0000005, theta=0.0
% INFO    : Bus 1395	: V=1.03546474, theta=-11.4113901 -> V=0.999999, theta=0.0
% INFO    : Bus 1396	: V=1.03713696, theta=-30.7548913 -> V=1.022224, theta=0.0
% INFO    : Bus 1397	: V=1.00168695, theta=-33.6178022 -> V=1.0000005, theta=0.0
% INFO    : Bus 1398	: V=1.04803416, theta=-29.3121674 -> V=1.046665, theta=0.0
% INFO    : Bus 1399	: V=1.04615151, theta=-24.3872372 -> V=1.000001, theta=0.0
% INFO    : Bus 1400	: V=1.02558088, theta=-10.9851921 -> V=1.0158755, theta=0.0
% INFO    : Bus 1401	: V=1.0080765, theta=-15.8053864 -> V=1.015872, theta=0.0
% INFO    : Bus 1402	: V=0.993381218, theta=-21.2347934 -> V=0.999999, theta=0.0
% INFO    : Bus 1403	: V=1.00887811, theta=-25.2799435 -> V=1.0158755, theta=0.0
% INFO    : Bus 1404	: V=1.03633073, theta=-17.159675 -> V=0.999999, theta=0.0
% INFO    : Bus 1405	: V=1.03633533, theta=-17.1598288 -> V=0.999999, theta=0.0
% INFO    : Bus 1406	: V=1.01381758, theta=-17.0071939 -> V=1.0158755, theta=0.0
% INFO    : Bus 1407	: V=1.03163327, theta=-15.7332962 -> V=0.999999, theta=0.0
% INFO    : Bus 1408	: V=1.04913168, theta=-10.4655342 -> V=1.0111115, theta=0.0
% INFO    : Bus 1409	: V=1.05666347, theta=-37.003323 -> V=0.975, theta=0.0
% INFO    : Bus 1410	: V=1.03994396, theta=-40.7057751 -> V=1.022224, theta=0.0
% INFO    : Bus 1411	: V=1.05671206, theta=-36.9841818 -> V=1.04444, theta=0.0
% INFO    : Bus 1412	: V=0.990622692, theta=-26.48781 -> V=1.0158755, theta=0.0
% INFO    : Bus 1413	: V=1.02356333, theta=-18.9944322 -> V=1.015872, theta=0.0
% INFO    : Bus 1414	: V=1.02231797, theta=-18.2989787 -> V=1.015872, theta=0.0
% INFO    : Bus 1415	: V=1.00977951, theta=-25.7761454 -> V=1.015872, theta=0.0
% INFO    : Bus 1416	: V=1.03542608, theta=-15.890912 -> V=0.999999, theta=0.0
% INFO    : Bus 1417	: V=1.01293021, theta=-55.1982213 -> V=1.0079355, theta=0.0
% INFO    : Bus 1418	: V=0.993604167, theta=-48.6772441 -> V=1.022224, theta=0.0
% INFO    : Bus 1419	: V=1.04849352, theta=-20.6681 -> V=1.0000025, theta=0.0
% INFO    : Bus 1420	: V=0.984073483, theta=-47.2411841 -> V=1.022224, theta=0.0
% INFO    : Bus 1421	: V=1.02542107, theta=-34.2847618 -> V=1.022224, theta=0.0
% INFO    : Bus 1422	: V=1.05011484, theta=-30.0774449 -> V=1.027779, theta=0.0
% INFO    : Bus 1423	: V=0.992125547, theta=-17.9809066 -> V=1.0158755, theta=0.0
% INFO    : Bus 1424	: V=1.0010828, theta=-17.326107 -> V=1.0158755, theta=0.0
% INFO    : Bus 1425	: V=1.031, theta=-21.1343531 -> V=1.000001, theta=0.0
% INFO    : Bus 1426	: V=1.0596927, theta=-31.2354388 -> V=1.046665, theta=0.0
% INFO    : Bus 1427	: V=0.969033291, theta=-28.764623 -> V=1.0158755, theta=0.0
% INFO    : Bus 1428	: V=1.03356478, theta=-35.9687848 -> V=1.027779, theta=0.0
% INFO    : Bus 1429	: V=1.01689507, theta=-39.028504 -> V=1.022224, theta=0.0
% INFO    : Bus 1430	: V=1.01986731, theta=-20.0743706 -> V=1.0158755, theta=0.0
% INFO    : Bus 1431	: V=1.02177752, theta=-30.956372 -> V=1.022224, theta=0.0
% INFO    : Bus 1432	: V=1.07591065, theta=1.38342889 -> V=1.0377785, theta=0.0
% INFO    : Bus 1433	: V=1.03865123, theta=-30.5667737 -> V=1.046665, theta=0.0
% INFO    : Bus 1434	: V=1.02343398, theta=-0.880796806 -> V=1.0158755, theta=0.0
% INFO    : Bus 1435	: V=1.07586143, theta=1.36359046 -> V=1.0377785, theta=0.0
% INFO    : Bus 1436	: V=1.03597604, theta=-23.7308927 -> V=0.999999, theta=0.0
% INFO    : Bus 1437	: V=1.04893481, theta=-44.9815221 -> V=1.027779, theta=0.0
% INFO    : Bus 1438	: V=1.01100418, theta=-25.6341344 -> V=1.015872, theta=0.0
% INFO    : Bus 1439	: V=1.00403713, theta=-15.1689719 -> V=1.015872, theta=0.0
% INFO    : Bus 1440	: V=1.03472484, theta=-35.7570274 -> V=1.027779, theta=0.0
% INFO    : Bus 1441	: V=1.03079011, theta=-23.9257906 -> V=1.0158755, theta=0.0
% INFO    : Bus 1442	: V=1.04640368, theta=-18.28228 -> V=1.0377785, theta=0.0
% INFO    : Bus 1443	: V=1.01484632, theta=-36.1211837 -> V=1.022224, theta=0.0
% INFO    : Bus 1444	: V=1.013801, theta=-13.4577956 -> V=1.015872, theta=0.0
% INFO    : Bus 1445	: V=1.01174964, theta=-14.0385986 -> V=1.015872, theta=0.0
% INFO    : Bus 1446	: V=1.05301652, theta=-7.92385046 -> V=1.046665, theta=0.0
% INFO    : Bus 1447	: V=1.00793404, theta=-34.850254 -> V=1.0000005, theta=0.0
% INFO    : Bus 1448	: V=1.03909156, theta=-29.1318304 -> V=1.022224, theta=0.0
% INFO    : Bus 1449	: V=1.00811351, theta=-34.8418947 -> V=1.0000005, theta=0.0
% INFO    : Bus 1450	: V=1.01148721, theta=-15.30319 -> V=0.999999, theta=0.0
% INFO    : Bus 1451	: V=1.04808899, theta=-8.85640919 -> V=1.0111115, theta=0.0
% INFO    : Bus 1452	: V=1.00085311, theta=-25.2393474 -> V=1.0158755, theta=0.0
% INFO    : Bus 1453	: V=1.02281689, theta=-2.38167969 -> V=1.0158755, theta=0.0
% INFO    : Bus 1454	: V=1.02281689, theta=-2.38167969 -> V=1.0158755, theta=0.0
% INFO    : Bus 1455	: V=1.02366192, theta=-23.9221685 -> V=1.0158755, theta=0.0
% INFO    : Bus 1456	: V=1.01026028, theta=-18.3846289 -> V=1.0158755, theta=0.0
% INFO    : Bus 1457	: V=1.04962962, theta=-15.8852089 -> V=1.0377785, theta=0.0
% INFO    : Bus 1458	: V=1.00876325, theta=-21.7851548 -> V=1.0000025, theta=0.0
% INFO    : Bus 1459	: V=0.577448345, theta=-22.0656715 -> V=0.825, theta=0.0
% INFO    : Bus 1460	: V=1.03125011, theta=-21.9936019 -> V=1.0158755, theta=0.0
% INFO    : Bus 1461	: V=0.988828249, theta=-7.61610851 -> V=1.0158755, theta=0.0
% INFO    : Bus 1462	: V=1.02359808, theta=-28.4938775 -> V=1.022224, theta=0.0
% INFO    : Bus 1463	: V=1.06539023, theta=-24.3745377 -> V=1.04444, theta=0.0
% INFO    : Bus 1464	: V=1.07016666, theta=-20.1449502 -> V=1.07237, theta=0.0
% INFO    : Bus 1465	: V=1.03107004, theta=-20.2233637 -> V=1.000001, theta=0.0
% INFO    : Bus 1466	: V=1.02514767, theta=-19.3800959 -> V=1.016666, theta=0.0
% INFO    : Bus 1467	: V=1.01074503, theta=-17.5618096 -> V=0.9977785, theta=0.0
% INFO    : Bus 1468	: V=1.02357586, theta=-14.3491964 -> V=1.0158755, theta=0.0
% INFO    : Bus 1469	: V=1.01355091, theta=-40.4687824 -> V=1.027779, theta=0.0
% INFO    : Bus 1470	: V=1.02004209, theta=-17.1930607 -> V=1.0158755, theta=0.0
% INFO    : Bus 1471	: V=0.973098104, theta=-36.275813 -> V=1.0000005, theta=0.0
% INFO    : Bus 1472	: V=1.00836215, theta=-39.9750819 -> V=1.0000005, theta=0.0
% INFO    : Bus 1473	: V=1.03836484, theta=-28.6442374 -> V=1.0000025, theta=0.0
% INFO    : Bus 1474	: V=1.05042093, theta=-24.1498976 -> V=1.044445, theta=0.0
% INFO    : Bus 1475	: V=1.06589819, theta=-27.4155644 -> V=1.046665, theta=0.0
% INFO    : Bus 1476	: V=0.998184197, theta=-12.8360706 -> V=0.999999, theta=0.0
% INFO    : Bus 1477	: V=1.01552291, theta=-13.8639821 -> V=1.0158755, theta=0.0
% INFO    : Bus 1478	: V=1.02744719, theta=-30.9261232 -> V=1.027779, theta=0.0
% INFO    : Bus 1479	: V=1.03273474, theta=-17.5913705 -> V=1.015872, theta=0.0
% INFO    : Bus 1480	: V=1.05630016, theta=-16.6632086 -> V=1.046665, theta=0.0
% INFO    : Bus 1481	: V=1.04106772, theta=-26.0379038 -> V=1.0000025, theta=0.0
% INFO    : Bus 1482	: V=1.06790952, theta=-29.1861861 -> V=1.0185405, theta=0.0
% INFO    : Bus 1483	: V=1.0578161, theta=-24.1962333 -> V=1.0000025, theta=0.0
% INFO    : Bus 1484	: V=1.1232084, theta=0.170262727 -> V=1.0416105, theta=0.0
% INFO    : Bus 1485	: V=1.01826918, theta=-21.0089799 -> V=1.0000015, theta=0.0
% INFO    : Bus 1486	: V=1.06247981, theta=-17.3645473 -> V=1.0266685, theta=0.0
% INFO    : Bus 1487	: V=1.03554369, theta=-20.6575276 -> V=0.9888895, theta=0.0
% INFO    : Bus 1488	: V=1.05026496, theta=-8.9438549 -> V=1.0111115, theta=0.0
% INFO    : Bus 1489	: V=1.04143533, theta=-27.2537774 -> V=1.0000025, theta=0.0
% INFO    : Bus 1490	: V=1.06486607, theta=-20.2538433 -> V=1.016666, theta=0.0
% INFO    : Bus 1491	: V=1.02129035, theta=-15.7780527 -> V=1.0158755, theta=0.0
% INFO    : Bus 1492	: V=1.04632289, theta=-23.8394773 -> V=1.0000025, theta=0.0
% INFO    : Bus 1493	: V=1.00668365, theta=-35.0057494 -> V=1.0000005, theta=0.0
% INFO    : Bus 1494	: V=1.07019361, theta=-15.0527199 -> V=0.9888895, theta=0.0
% INFO    : Bus 1495	: V=1.05434222, theta=-24.8961321 -> V=1.022224, theta=0.0
% INFO    : Bus 1496	: V=1.0375789, theta=-21.0684347 -> V=0.9888895, theta=0.0
% INFO    : Bus 1497	: V=1.06746106, theta=-12.4733199 -> V=1.072365, theta=0.0
% INFO    : Bus 1498	: V=1.0390879, theta=-29.5636872 -> V=1.000001, theta=0.0
% INFO    : Bus 1499	: V=1.0613203, theta=-9.92492778 -> V=0.975, theta=0.0
% INFO    : Bus 1500	: V=1.02824438, theta=-46.3788178 -> V=1.022224, theta=0.0
% INFO    : Bus 1501	: V=1.01280653, theta=-34.5427853 -> V=1.022224, theta=0.0
% INFO    : Bus 1502	: V=1.03256946, theta=-27.1619865 -> V=1.0111115, theta=0.0
% INFO    : Bus 1503	: V=1.03340204, theta=-10.8690042 -> V=1.0158755, theta=0.0
% INFO    : Bus 1504	: V=1.0554247, theta=-5.34067697 -> V=1.0377785, theta=0.0
% INFO    : Bus 1505	: V=1.02418141, theta=2.7508507 -> V=1.013331, theta=0.0
% INFO    : Bus 1506	: V=1.06010037, theta=-29.0172049 -> V=1.027779, theta=0.0
% INFO    : Bus 1507	: V=1.0623111, theta=-29.4933972 -> V=1.027779, theta=0.0
% INFO    : Bus 1508	: V=1.02347915, theta=-24.7439712 -> V=1.027779, theta=0.0
% INFO    : Bus 1509	: V=0.971089607, theta=-21.6989789 -> V=1.015872, theta=0.0
% INFO    : Bus 1510	: V=1.03333076, theta=-25.4180244 -> V=1.0000025, theta=0.0
% INFO    : Bus 1511	: V=1.01646008, theta=-3.64736101 -> V=1.0158755, theta=0.0
% INFO    : Bus 1512	: V=0.967768475, theta=-19.3410743 -> V=1.015872, theta=0.0
% INFO    : Bus 1513	: V=1.02539683, theta=-17.6391416 -> V=1.015872, theta=0.0
% INFO    : Bus 1514	: V=1.018287, theta=-23.7025335 -> V=1.0158755, theta=0.0
% INFO    : Bus 1515	: V=1.01463132, theta=-55.272955 -> V=1.0079355, theta=0.0
% INFO    : Bus 1516	: V=1.03104688, theta=-52.0266928 -> V=1.0079355, theta=0.0
% INFO    : Bus 1517	: V=1.05324583, theta=-54.4964326 -> V=1.04444, theta=0.0
% INFO    : Bus 1518	: V=1.0192998, theta=-34.9125487 -> V=1.022224, theta=0.0
% INFO    : Bus 1519	: V=1.06504612, theta=-31.8995833 -> V=1.04444, theta=0.0
% INFO    : Bus 1520	: V=1.07743679, theta=-26.9722939 -> V=1.07237, theta=0.0
% INFO    : Bus 1521	: V=1.03362367, theta=-36.3303304 -> V=1.027779, theta=0.0
% INFO    : Bus 1522	: V=1.122, theta=-8.00812219 -> V=0.975, theta=0.0
% INFO    : Bus 1523	: V=0.969, theta=-6.21846895 -> V=0.975, theta=0.0
% INFO    : Bus 1524	: V=1.06270782, theta=-16.2053754 -> V=1.0222245, theta=0.0
% INFO    : Bus 1525	: V=1.07616796, theta=-12.9233966 -> V=1.0222245, theta=0.0
% INFO    : Bus 1526	: V=1.00169803, theta=-53.6913862 -> V=1.0079355, theta=0.0
% INFO    : Bus 1527	: V=1.04207191, theta=-50.0440364 -> V=1.04444, theta=0.0
% INFO    : Bus 1528	: V=1.01988869, theta=-10.9518369 -> V=1.0158755, theta=0.0
% INFO    : Bus 1529	: V=1.00542528, theta=-55.7355205 -> V=1.0079355, theta=0.0
% INFO    : Bus 1530	: V=1.01729438, theta=-7.33960349 -> V=1.0158755, theta=0.0
% INFO    : Bus 1531	: V=1.01523266, theta=-12.1122501 -> V=0.999999, theta=0.0
% INFO    : Bus 1532	: V=1.04767798, theta=-44.5754671 -> V=1.027779, theta=0.0
% INFO    : Bus 1533	: V=1.02270773, theta=-44.3724895 -> V=1.022224, theta=0.0
% INFO    : Bus 1534	: V=1.01772876, theta=-47.5461744 -> V=1.022224, theta=0.0
% INFO    : Bus 1535	: V=1.0621514, theta=-42.1017056 -> V=1.04444, theta=0.0
% INFO    : Bus 1536	: V=1.06770847, theta=-37.146222 -> V=1.07237, theta=0.0
% INFO    : Bus 1537	: V=1.01092565, theta=-23.4619627 -> V=0.999999, theta=0.0
% INFO    : Bus 1538	: V=1.04247886, theta=-8.83881723 -> V=1.000001, theta=0.0
% INFO    : Bus 1539	: V=1.03229521, theta=-46.4443851 -> V=1.0079355, theta=0.0
% INFO    : Bus 1540	: V=1.00639319, theta=-24.1156381 -> V=0.999999, theta=0.0
% INFO    : Bus 1541	: V=1.07318378, theta=-16.7044684 -> V=1.044445, theta=0.0
% INFO    : Bus 1542	: V=1.09345222, theta=-10.5030145 -> V=1.078945, theta=0.0
% INFO    : Bus 1543	: V=1.03658476, theta=-21.8472484 -> V=1.000001, theta=0.0
% INFO    : Bus 1544	: V=1.06079376, theta=-17.6340305 -> V=1.044445, theta=0.0
% INFO    : Bus 1545	: V=1.03506224, theta=-26.2531458 -> V=1.022224, theta=0.0
% INFO    : Bus 1546	: V=1.02420601, theta=-29.4590764 -> V=0.999999, theta=0.0
% INFO    : Bus 1547	: V=1.01028756, theta=-21.8381588 -> V=1.0000025, theta=0.0
% INFO    : Bus 1548	: V=1.04602507, theta=-11.0109943 -> V=1.0158755, theta=0.0
% INFO    : Bus 1549	: V=1.01234545, theta=-45.3024798 -> V=1.022224, theta=0.0
% INFO    : Bus 1550	: V=1.00499286, theta=-64.8414499 -> V=1.0079355, theta=0.0
% INFO    : Bus 1551	: V=1.0081722, theta=-23.9299992 -> V=1.0158755, theta=0.0
% INFO    : Bus 1552	: V=1.00939294, theta=-32.5337711 -> V=1.0000025, theta=0.0
% INFO    : Bus 1553	: V=1.02248713, theta=-30.1323632 -> V=1.022222, theta=0.0
% INFO    : Bus 1554	: V=1.05986731, theta=-44.277182 -> V=1.04444, theta=0.0
% INFO    : Bus 1555	: V=1.02510377, theta=-37.9195802 -> V=1.027779, theta=0.0
% INFO    : Bus 1556	: V=1.02576307, theta=-18.6814009 -> V=0.999999, theta=0.0
% INFO    : Bus 1557	: V=1.0297745, theta=-20.2892552 -> V=1.0158755, theta=0.0
% INFO    : Bus 1558	: V=1.04965142, theta=-26.898972 -> V=1.022222, theta=0.0
% INFO    : Bus 1559	: V=1.03242609, theta=-21.0465718 -> V=0.9888895, theta=0.0
% INFO    : Bus 1560	: V=1.033, theta=-26.8879082 -> V=1.033333, theta=0.0
% INFO    : Bus 1561	: V=1.01851507, theta=-34.1699246 -> V=1.015872, theta=0.0
% INFO    : Bus 1562	: V=1.04927263, theta=-30.1407427 -> V=1.046665, theta=0.0
% INFO    : Bus 1563	: V=1.0376487, theta=-39.6994583 -> V=1.027779, theta=0.0
% INFO    : Bus 1564	: V=1.04747453, theta=-36.4889004 -> V=1.027779, theta=0.0
% INFO    : Bus 1565	: V=1.06108966, theta=-32.4543496 -> V=1.046665, theta=0.0
% INFO    : Bus 1566	: V=1.01365423, theta=-45.8791823 -> V=1.022224, theta=0.0
% INFO    : Bus 1567	: V=1.01802804, theta=-8.42076937 -> V=1.0158755, theta=0.0
% INFO    : Bus 1568	: V=1.03435073, theta=-13.4875838 -> V=0.999999, theta=0.0
% INFO    : Bus 1569	: V=1.0341535, theta=-13.7508769 -> V=0.999999, theta=0.0
% INFO    : Bus 1570	: V=0.964384427, theta=-10.1000457 -> V=1.0158755, theta=0.0
% INFO    : Bus 1571	: V=1.05749556, theta=-19.1243419 -> V=1.005558, theta=0.0
% INFO    : Bus 1572	: V=1.05705376, theta=-17.0136799 -> V=0.9888895, theta=0.0
% INFO    : Bus 1573	: V=1.04100518, theta=-18.4481561 -> V=0.999999, theta=0.0
% INFO    : Bus 1574	: V=1.02442174, theta=-24.1600357 -> V=1.022224, theta=0.0
% INFO    : Bus 1575	: V=1.04714681, theta=-18.034323 -> V=1.046665, theta=0.0
% INFO    : Bus 1576	: V=1.02457396, theta=-22.3731972 -> V=0.999999, theta=0.0
% INFO    : Bus 1577	: V=0.987838337, theta=-35.5751486 -> V=1.0000005, theta=0.0
% INFO    : Bus 1578	: V=1.07993799, theta=-13.9255055 -> V=1.07237, theta=0.0
% INFO    : Bus 1579	: V=1.07993799, theta=-13.9255055 -> V=1.07237, theta=0.0
% INFO    : Bus 1580	: V=1.07993691, theta=-13.9241596 -> V=1.07237, theta=0.0
% INFO    : Bus 1581	: V=1.07987953, theta=-13.9210538 -> V=1.07237, theta=0.0
% INFO    : Bus 1582	: V=1.01020086, theta=-35.8824581 -> V=1.022224, theta=0.0
% INFO    : Bus 1583	: V=1.03849979, theta=-29.8349838 -> V=1.046665, theta=0.0
% INFO    : Bus 1584	: V=1.01831827, theta=-11.4402833 -> V=0.999999, theta=0.0
% INFO    : Bus 1585	: V=1.05022385, theta=-8.5157019 -> V=1.0111115, theta=0.0
% INFO    : Bus 1586	: V=1.07335892, theta=-3.01774947 -> V=1.072365, theta=0.0
% INFO    : Bus 1587	: V=1.01670183, theta=-14.6306695 -> V=0.999999, theta=0.0
% INFO    : Bus 1588	: V=1.04914658, theta=-25.0564769 -> V=1.016666, theta=0.0
% INFO    : Bus 1589	: V=1.05124806, theta=-19.8876593 -> V=1.0288895, theta=0.0
% INFO    : Bus 1590	: V=1.0215642, theta=-41.7005326 -> V=1.022224, theta=0.0
% INFO    : Bus 1591	: V=1.02521686, theta=-41.6521894 -> V=1.022224, theta=0.0
% INFO    : Bus 1592	: V=1.03695054, theta=-32.2857401 -> V=1.027779, theta=0.0
% INFO    : Bus 1593	: V=1.02171852, theta=2.90138148 -> V=1.013331, theta=0.0
% INFO    : Bus 1594	: V=1.049, theta=-18.0264957 -> V=1.0000025, theta=0.0
% INFO    : Bus 1595	: V=0.987506263, theta=-40.0777575 -> V=1.0000005, theta=0.0
% INFO    : Bus 1596	: V=1.05115474, theta=-18.9349673 -> V=1.000001, theta=0.0
% INFO    : Bus 1597	: V=0.991444392, theta=-27.0839317 -> V=1.015872, theta=0.0
% INFO    : Bus 1598	: V=1.02832101, theta=-22.3799559 -> V=1.022224, theta=0.0
% INFO    : Bus 1599	: V=1.045, theta=-21.35665 -> V=1.022224, theta=0.0
% INFO    : Bus 1600	: V=1.0804712, theta=-18.1969776 -> V=1.04498, theta=0.0
% INFO    : Bus 1601	: V=1.08482699, theta=-14.1758821 -> V=1.07237, theta=0.0
% INFO    : Bus 1602	: V=1.0353013, theta=-37.9824271 -> V=1.0043955, theta=0.0
% INFO    : Bus 1603	: V=1.04282819, theta=-33.7405775 -> V=1.046665, theta=0.0
% INFO    : Bus 1604	: V=1.03960392, theta=-34.0840233 -> V=1.046665, theta=0.0
% INFO    : Bus 1605	: V=1.034, theta=-36.3407575 -> V=1.0000005, theta=0.0
% INFO    : Bus 1606	: V=1.064105, theta=-31.7731265 -> V=1.046665, theta=0.0
% INFO    : Bus 1607	: V=1.00918153, theta=-15.2198968 -> V=1.015872, theta=0.0
% INFO    : Bus 1608	: V=1.0861373, theta=-14.6527188 -> V=1.044445, theta=0.0
% INFO    : Bus 1609	: V=1.03152645, theta=-3.60046224 -> V=1.0158755, theta=0.0
% INFO    : Bus 1610	: V=0.996808524, theta=-25.5148518 -> V=1.0000025, theta=0.0
% INFO    : Bus 1611	: V=1.02941124, theta=-10.2268105 -> V=1.0158755, theta=0.0
% INFO    : Bus 1612	: V=0.997453187, theta=-26.9215462 -> V=1.015872, theta=0.0
% INFO    : Bus 1613	: V=1.01323091, theta=-34.889174 -> V=1.015872, theta=0.0
% INFO    : Bus 1614	: V=0.981871923, theta=-24.8515334 -> V=1.015872, theta=0.0
% INFO    : Bus 1615	: V=1.05714896, theta=-24.432818 -> V=1.0233335, theta=0.0
% INFO    : Bus 1616	: V=1.0349479, theta=-23.0595306 -> V=0.999999, theta=0.0
% INFO    : Bus 1617	: V=1.03056019, theta=-23.2515408 -> V=0.999999, theta=0.0
% INFO    : Bus 1618	: V=1.02284512, theta=-18.972234 -> V=1.0111115, theta=0.0
% INFO    : Bus 1619	: V=1.02709131, theta=-22.2249847 -> V=1.027779, theta=0.0
% INFO    : Bus 1620	: V=1.03321673, theta=-35.1016473 -> V=1.0079355, theta=0.0
% INFO    : Bus 1621	: V=1.03292054, theta=-35.1010549 -> V=1.022224, theta=0.0
% INFO    : Bus 1622	: V=1.01644283, theta=-22.9505369 -> V=1.0000025, theta=0.0
% INFO    : Bus 1623	: V=0.94313849, theta=-7.4322218 -> V=0.9444445, theta=0.0
% INFO    : Bus 1624	: V=0.949779064, theta=-41.1982675 -> V=0.9975445, theta=0.0
% INFO    : Bus 1625	: V=0.992360065, theta=-36.5795697 -> V=1.0000005, theta=0.0
% INFO    : Bus 1626	: V=1.00604082, theta=-46.7817274 -> V=1.022224, theta=0.0
% INFO    : Bus 1627	: V=1.00190907, theta=-26.1576152 -> V=1.0158755, theta=0.0
% INFO    : Bus 1628	: V=1.05188557, theta=-17.9476875 -> V=0.9888895, theta=0.0
% INFO    : Bus 1629	: V=1.05157185, theta=-17.9804196 -> V=0.9888895, theta=0.0
% INFO    : Bus 1630	: V=1.04460787, theta=-10.5422549 -> V=1.0377785, theta=0.0
% INFO    : Bus 1631	: V=1.02687261, theta=-30.9747577 -> V=1.027779, theta=0.0
% INFO    : Bus 1632	: V=1.05954553, theta=-31.3473589 -> V=1.046665, theta=0.0
% INFO    : Bus 1633	: V=1.03410755, theta=-47.4675169 -> V=1.022224, theta=0.0
% INFO    : Bus 1634	: V=1.00364482, theta=-55.0034701 -> V=1.0079355, theta=0.0
% INFO    : Bus 1635	: V=1.01891778, theta=-24.6515384 -> V=1.0000025, theta=0.0
% INFO    : Bus 1636	: V=1.01745511, theta=-5.1278404 -> V=1.0158755, theta=0.0
% INFO    : Bus 1637	: V=1.01070042, theta=-11.5880279 -> V=1.0158755, theta=0.0
% INFO    : Bus 1638	: V=1.03069609, theta=-31.4448876 -> V=1.015872, theta=0.0
% INFO    : Bus 1639	: V=1.03422534, theta=-24.6337713 -> V=1.046665, theta=0.0
% INFO    : Bus 1640	: V=0.984657673, theta=-37.7656817 -> V=1.015872, theta=0.0
% INFO    : Bus 1641	: V=1.04952257, theta=-27.8035415 -> V=1.0000025, theta=0.0
% INFO    : Bus 1642	: V=1.05136923, theta=-14.7040084 -> V=1.000204, theta=0.0
% INFO    : Bus 1643	: V=1.04641553, theta=-21.293219 -> V=1.0000025, theta=0.0
% INFO    : Bus 1644	: V=1.04093681, theta=-26.2297387 -> V=1.0000025, theta=0.0
% INFO    : Bus 1645	: V=1.061, theta=-25.4652215 -> V=1.04444, theta=0.0
% INFO    : Bus 1646	: V=1.01516552, theta=-24.7314393 -> V=1.0000025, theta=0.0
% INFO    : Bus 1647	: V=1.04323689, theta=-25.6508869 -> V=1.033333, theta=0.0
% INFO    : Bus 1648	: V=1.0646888, theta=-23.2535138 -> V=1.0000025, theta=0.0
% INFO    : Bus 1649	: V=1.04405929, theta=-49.0236799 -> V=1.022224, theta=0.0
% INFO    : Bus 1650	: V=1.05078355, theta=-49.4858421 -> V=1.022224, theta=0.0
% INFO    : Bus 1651	: V=1.07076525, theta=-27.2491009 -> V=1.033333, theta=0.0
% INFO    : Bus 1652	: V=1.027585, theta=-15.4815497 -> V=1.0158755, theta=0.0
% INFO    : Bus 1653	: V=1.00388122, theta=-8.02190553 -> V=1.0158755, theta=0.0
% INFO    : Bus 1654	: V=1.00507265, theta=-33.0304942 -> V=1.0000005, theta=0.0
% INFO    : Bus 1655	: V=1.00506681, theta=-32.9868245 -> V=1.0000005, theta=0.0
% INFO    : Bus 1656	: V=1.00389727, theta=-33.069927 -> V=1.0000005, theta=0.0
% INFO    : Bus 1657	: V=1.04637947, theta=-24.1870305 -> V=1.022222, theta=0.0
% INFO    : Bus 1658	: V=1.01140768, theta=-24.9269822 -> V=1.015872, theta=0.0
% INFO    : Bus 1659	: V=1.05800268, theta=-16.0765818 -> V=1.0000025, theta=0.0
% INFO    : Bus 1660	: V=1.01038994, theta=-32.3513688 -> V=1.0000005, theta=0.0
% INFO    : Bus 1661	: V=1.05202731, theta=-17.9499167 -> V=0.9888895, theta=0.0
% INFO    : Bus 1662	: V=1.02387629, theta=-13.6595664 -> V=0.999999, theta=0.0
% INFO    : Bus 1663	: V=1.03109926, theta=-25.1502912 -> V=1.0000025, theta=0.0
% INFO    : Bus 1664	: V=0.980663247, theta=-8.36808471 -> V=1.0158755, theta=0.0
% INFO    : Bus 1665	: V=1.00745439, theta=-32.9052463 -> V=1.0000005, theta=0.0
% INFO    : Bus 1666	: V=1.02772992, theta=-21.32163 -> V=1.015872, theta=0.0
% INFO    : Bus 1667	: V=1.01940154, theta=-26.2059153 -> V=1.0000025, theta=0.0
% INFO    : Bus 1668	: V=1.03515467, theta=-20.7949859 -> V=0.9888895, theta=0.0
% INFO    : Bus 1669	: V=1.02900275, theta=-10.4787447 -> V=1.0158755, theta=0.0
% INFO    : Bus 1670	: V=1.06367974, theta=-7.63068619 -> V=1.0377785, theta=0.0
% INFO    : Bus 1671	: V=0.982056064, theta=-36.2236548 -> V=1.0000005, theta=0.0
% INFO    : Bus 1672	: V=1.03434766, theta=-33.9693561 -> V=1.027779, theta=0.0
% INFO    : Bus 1673	: V=1.03403137, theta=-14.5525336 -> V=1.0158755, theta=0.0
% INFO    : Bus 1674	: V=1.06480328, theta=-10.0008075 -> V=1.0377785, theta=0.0
% INFO    : Bus 1675	: V=1.02116485, theta=-16.8381845 -> V=1.0111115, theta=0.0
% INFO    : Bus 1676	: V=1.04768979, theta=-17.5872701 -> V=0.999999, theta=0.0
% INFO    : Bus 1677	: V=1.05716049, theta=-17.5443459 -> V=0.999999, theta=0.0
% INFO    : Bus 1678	: V=1.03199405, theta=-36.5613499 -> V=1.027779, theta=0.0
% INFO    : Bus 1679	: V=1.01303678, theta=-48.2756 -> V=1.022224, theta=0.0
% INFO    : Bus 1680	: V=1.01337969, theta=-48.5953343 -> V=1.022224, theta=0.0
% INFO    : Bus 1681	: V=1.01655571, theta=-42.1214512 -> V=1.0000025, theta=0.0
% INFO    : Bus 1682	: V=1.02542023, theta=-9.78966345 -> V=0.999999, theta=0.0
% INFO    : Bus 1683	: V=1.04541233, theta=-5.99555828 -> V=1.0111115, theta=0.0
% INFO    : Bus 1684	: V=1.01, theta=-14.721237 -> V=1.015872, theta=0.0
% INFO    : Bus 1685	: V=1.02506834, theta=-28.9613432 -> V=1.0000025, theta=0.0
% INFO    : Bus 1686	: V=1.01882016, theta=-21.6932723 -> V=1.015872, theta=0.0
% INFO    : Bus 1687	: V=1.01839538, theta=-23.5256437 -> V=0.999999, theta=0.0
% INFO    : Bus 1688	: V=1.04641553, theta=-21.293219 -> V=1.0000025, theta=0.0
% INFO    : Bus 1689	: V=1.02222013, theta=-25.934082 -> V=1.015872, theta=0.0
% INFO    : Bus 1690	: V=1.04672854, theta=-19.7789516 -> V=1.046665, theta=0.0
% INFO    : Bus 1691	: V=1.01232254, theta=-5.67796293 -> V=1.0158755, theta=0.0
% INFO    : Bus 1692	: V=1.05157829, theta=-34.330664 -> V=1.022224, theta=0.0
% INFO    : Bus 1693	: V=1.002, theta=-24.8552523 -> V=1.0000025, theta=0.0
% INFO    : Bus 1694	: V=1.03002613, theta=-36.8034126 -> V=1.022224, theta=0.0
% INFO    : Bus 1695	: V=1.1031987, theta=6.83298343 -> V=1.07631, theta=0.0
% INFO    : Bus 1696	: V=1.1031905, theta=6.8319795 -> V=1.07631, theta=0.0
% INFO    : Bus 1697	: V=1.03575062, theta=-1.26256946 -> V=1.0158755, theta=0.0
% INFO    : Bus 1698	: V=1.08436638, theta=2.02200963 -> V=1.0400885, theta=0.0
% INFO    : Bus 1699	: V=1.08421652, theta=2.01268861 -> V=1.0400135, theta=0.0
% INFO    : Bus 1700	: V=1.064711, theta=-23.2647895 -> V=1.0000025, theta=0.0
% INFO    : Bus 1701	: V=1.02139505, theta=-17.9601446 -> V=1.015872, theta=0.0
% INFO    : Bus 1702	: V=1.01895408, theta=-2.39571695 -> V=1.0158755, theta=0.0
% INFO    : Bus 1703	: V=1.04301186, theta=-18.3980759 -> V=1.0000025, theta=0.0
% INFO    : Bus 1704	: V=1.0384142, theta=-26.2084467 -> V=1.0000025, theta=0.0
% INFO    : Bus 1705	: V=1.03337285, theta=-27.037781 -> V=1.0000025, theta=0.0
% INFO    : Bus 1706	: V=1.041, theta=-21.4349353 -> V=0.999999, theta=0.0
% INFO    : Bus 1707	: V=1.06158524, theta=-31.1010753 -> V=1.046665, theta=0.0
% INFO    : Bus 1708	: V=0.978555231, theta=-36.2636185 -> V=1.0000005, theta=0.0
% INFO    : Bus 1709	: V=0.977156322, theta=-35.6883877 -> V=1.0000005, theta=0.0
% INFO    : Bus 1710	: V=1.0193867, theta=-32.3477846 -> V=1.046665, theta=0.0
% INFO    : Bus 1711	: V=1.01939605, theta=-32.3496302 -> V=1.046665, theta=0.0
% INFO    : Bus 1712	: V=1.01943452, theta=-32.350146 -> V=1.046665, theta=0.0
% INFO    : Bus 1713	: V=1.01940356, theta=-32.348449 -> V=1.046665, theta=0.0
% INFO    : Bus 1714	: V=0.978782999, theta=-36.3079228 -> V=1.0000005, theta=0.0
% INFO    : Bus 1715	: V=0.976917994, theta=-35.7820039 -> V=1.0000005, theta=0.0
% INFO    : Bus 1716	: V=1.0194236, theta=-32.3427222 -> V=1.046665, theta=0.0
% INFO    : Bus 1717	: V=1.07018883, theta=-22.0233886 -> V=1.015874, theta=0.0
% INFO    : Bus 1718	: V=1.05030108, theta=-18.0768355 -> V=1.015556, theta=0.0
% INFO    : Bus 1719	: V=1.02295354, theta=-31.68181 -> V=1.046665, theta=0.0
% INFO    : Bus 1720	: V=1.02264204, theta=-31.6942444 -> V=1.046665, theta=0.0
% INFO    : Bus 1721	: V=1.02807468, theta=-16.0714488 -> V=0.999999, theta=0.0
% INFO    : Bus 1722	: V=1.02599329, theta=-33.1923507 -> V=1.022224, theta=0.0
% INFO    : Bus 1723	: V=1.05650386, theta=-30.1604161 -> V=1.04444, theta=0.0
% INFO    : Bus 1724	: V=1.04100437, theta=-31.5737879 -> V=1.0000025, theta=0.0
% INFO    : Bus 1725	: V=1.02563592, theta=-24.5252567 -> V=1.0000025, theta=0.0
% INFO    : Bus 1726	: V=1.04793371, theta=-17.7657345 -> V=1.046665, theta=0.0
% INFO    : Bus 1727	: V=1.02219758, theta=-15.05724 -> V=0.999999, theta=0.0
% INFO    : Bus 1728	: V=1.0527378, theta=-12.7956654 -> V=0.975, theta=0.0
% INFO    : Bus 1729	: V=1.05168611, theta=-12.7956654 -> V=0.999999, theta=0.0
% INFO    : Bus 1730	: V=1.01150287, theta=-37.0846988 -> V=1.022224, theta=0.0
% INFO    : Bus 1731	: V=1.03250144, theta=-32.6558646 -> V=1.027779, theta=0.0
% INFO    : Bus 1732	: V=1.06485602, theta=-20.2770689 -> V=1.0111115, theta=0.0
% INFO    : Bus 1733	: V=1.03351638, theta=-10.9826189 -> V=0.999999, theta=0.0
% INFO    : Bus 1734	: V=1.02718493, theta=-26.952811 -> V=1.0000025, theta=0.0
% INFO    : Bus 1735	: V=1.06178654, theta=-21.6881196 -> V=1.0000025, theta=0.0
% INFO    : Bus 1736	: V=1.06488628, theta=-25.7241139 -> V=1.0000025, theta=0.0
% INFO    : Bus 1737	: V=1.06305284, theta=-17.7574371 -> V=1.044445, theta=0.0
% INFO    : Bus 1738	: V=1.04365072, theta=-41.4367213 -> V=1.027779, theta=0.0
% INFO    : Bus 1739	: V=1.02135365, theta=-26.4802135 -> V=1.022224, theta=0.0
% INFO    : Bus 1740	: V=1.05, theta=-26.0992272 -> V=1.0000025, theta=0.0
% INFO    : Bus 1741	: V=1.01963444, theta=-19.1538347 -> V=1.015872, theta=0.0
% INFO    : Bus 1742	: V=1.08371479, theta=-5.73756141 -> V=1.0377785, theta=0.0
% INFO    : Bus 1743	: V=1.08371091, theta=-5.73746101 -> V=1.0377785, theta=0.0
% INFO    : Bus 1744	: V=1.10463186, theta=-0.802806305 -> V=1.072365, theta=0.0
% INFO    : Bus 1745	: V=1.10486785, theta=-0.802339721 -> V=1.072365, theta=0.0
% INFO    : Bus 1746	: V=1.08374876, theta=-5.73843832 -> V=1.0377785, theta=0.0
% INFO    : Bus 1747	: V=1.127, theta=0.934554416 -> V=0.975, theta=0.0
% INFO    : Bus 1748	: V=1.127, theta=-0.657049584 -> V=0.975, theta=0.0
% INFO    : Bus 1749	: V=1.124, theta=0.632224781 -> V=0.975, theta=0.0
% INFO    : Bus 1750	: V=1.08386285, theta=-5.71438787 -> V=1.0377785, theta=0.0
% INFO    : Bus 1751	: V=1.08387618, theta=-5.72006155 -> V=1.0377785, theta=0.0
% INFO    : Bus 1752	: V=1.08385534, theta=-5.71553626 -> V=1.0377785, theta=0.0
% INFO    : Bus 1753	: V=1.03292177, theta=-18.4458977 -> V=1.015872, theta=0.0
% INFO    : Bus 1754	: V=1.01965386, theta=-18.697165 -> V=1.015872, theta=0.0
% INFO    : Bus 1755	: V=1.05416749, theta=-17.4305109 -> V=1.046665, theta=0.0
% INFO    : Bus 1756	: V=0.998388545, theta=-22.1100736 -> V=0.999999, theta=0.0
% INFO    : Bus 1757	: V=1.02906027, theta=-13.5119458 -> V=0.999999, theta=0.0
% INFO    : Bus 1758	: V=1.03386943, theta=-12.5405983 -> V=0.999999, theta=0.0
% INFO    : Bus 1759	: V=1.0582296, theta=-12.2773394 -> V=1.000774, theta=0.0
% INFO    : Bus 1760	: V=1.01770165, theta=-22.8371422 -> V=1.0000025, theta=0.0
% INFO    : Bus 1761	: V=1.02507256, theta=-25.828983 -> V=1.0000025, theta=0.0
% INFO    : Bus 1762	: V=0.985001209, theta=-17.9988712 -> V=1.0158755, theta=0.0
% INFO    : Bus 1763	: V=1.03893858, theta=-11.2626654 -> V=1.0111115, theta=0.0
% INFO    : Bus 1764	: V=1.01624183, theta=-20.1174155 -> V=1.015872, theta=0.0
% INFO    : Bus 1765	: V=1.00249933, theta=-23.366502 -> V=1.0000025, theta=0.0
% INFO    : Bus 1766	: V=1.01695959, theta=-24.7747609 -> V=1.0000025, theta=0.0
% INFO    : Bus 1767	: V=0.997421173, theta=-20.8672206 -> V=1.0158755, theta=0.0
% INFO    : Bus 1768	: V=1.09119102, theta=-25.3942437 -> V=1.073685, theta=0.0
% INFO    : Bus 1769	: V=1.09666359, theta=-22.957183 -> V=1.073685, theta=0.0
% INFO    : Bus 1770	: V=1.09668499, theta=-22.7059737 -> V=1.073685, theta=0.0
% INFO    : Bus 1771	: V=1.09110975, theta=-25.3939891 -> V=1.073685, theta=0.0
% INFO    : Bus 1772	: V=1.02901432, theta=-28.1153532 -> V=1.0000025, theta=0.0
% INFO    : Bus 1773	: V=1.04505076, theta=-19.0277318 -> V=0.9888895, theta=0.0
% INFO    : Bus 1774	: V=1.03920499, theta=-23.3210614 -> V=0.999999, theta=0.0
% INFO    : Bus 1775	: V=1.04830161, theta=-30.5158995 -> V=1.046665, theta=0.0
% INFO    : Bus 1776	: V=1.0236907, theta=-29.8861533 -> V=1.0079355, theta=0.0
% INFO    : Bus 1777	: V=1.05727741, theta=-31.5931451 -> V=1.022224, theta=0.0
% INFO    : Bus 1778	: V=1.0605353, theta=-33.1538898 -> V=1.022224, theta=0.0
% INFO    : Bus 1779	: V=1.0580054, theta=-28.5941388 -> V=1.04444, theta=0.0
% INFO    : Bus 1780	: V=1.01496077, theta=-42.3966092 -> V=1.022224, theta=0.0
% INFO    : Bus 1781	: V=1.0626634, theta=-43.283309 -> V=1.027779, theta=0.0
% INFO    : Bus 1782	: V=1.05630172, theta=-39.6094323 -> V=1.046665, theta=0.0
% INFO    : Bus 1783	: V=0.989692616, theta=-30.099021 -> V=1.0000025, theta=0.0
% INFO    : Bus 1784	: V=0.994958124, theta=-21.0372562 -> V=1.0158755, theta=0.0
% INFO    : Bus 1785	: V=1.05121725, theta=-7.14690107 -> V=0.985306, theta=0.0
% INFO    : Bus 1786	: V=1.03063664, theta=-16.976799 -> V=0.999999, theta=0.0
% INFO    : Bus 1787	: V=1.04943773, theta=-12.8688258 -> V=1.0111115, theta=0.0
% INFO    : Bus 1788	: V=1.03357998, theta=-36.36666 -> V=1.0000005, theta=0.0
% INFO    : Bus 1789	: V=1.00694471, theta=-23.972429 -> V=1.0158755, theta=0.0
% INFO    : Bus 1790	: V=1.00791347, theta=-23.9435033 -> V=1.0158755, theta=0.0
% INFO    : Bus 1791	: V=1.0412006, theta=-9.11555571 -> V=1.0000025, theta=0.0
% INFO    : Bus 1792	: V=1.03302715, theta=-24.9548497 -> V=1.0000025, theta=0.0
% INFO    : Bus 1793	: V=1.04669095, theta=-24.8083625 -> V=1.000001, theta=0.0
% INFO    : Bus 1794	: V=1.06872003, theta=-21.0951165 -> V=1.044445, theta=0.0
% INFO    : Bus 1795	: V=1.02868764, theta=-22.8553868 -> V=1.0000025, theta=0.0
% INFO    : Bus 1796	: V=1.0487088, theta=-19.550484 -> V=1.044445, theta=0.0
% INFO    : Bus 1797	: V=1.00128753, theta=-17.881339 -> V=1.015872, theta=0.0
% INFO    : Bus 1798	: V=1.06670729, theta=-34.6499743 -> V=1.046665, theta=0.0
% INFO    : Bus 1799	: V=1.06654292, theta=-34.6725669 -> V=1.046665, theta=0.0
% INFO    : Bus 1800	: V=1.04817562, theta=-26.402766 -> V=1.0000025, theta=0.0
% INFO    : Bus 1801	: V=1.04868325, theta=-26.3487949 -> V=1.0000025, theta=0.0
% INFO    : Bus 1802	: V=1.03435202, theta=-31.8415267 -> V=1.046665, theta=0.0
% INFO    : Bus 1803	: V=1.01271964, theta=-24.1481491 -> V=1.0000025, theta=0.0
% INFO    : Bus 1804	: V=1.02202457, theta=-20.5647705 -> V=0.999999, theta=0.0
% INFO    : Bus 1805	: V=1.04512054, theta=-15.5838939 -> V=1.0111115, theta=0.0
% INFO    : Bus 1806	: V=1.02746623, theta=-2.33933435 -> V=1.0158755, theta=0.0
% INFO    : Bus 1807	: V=1.02621097, theta=-2.42566522 -> V=1.0158755, theta=0.0
% INFO    : Bus 1808	: V=1.04310563, theta=-28.5101035 -> V=1.0000025, theta=0.0
% INFO    : Bus 1809	: V=1.01401321, theta=-15.9016867 -> V=1.0079355, theta=0.0
% INFO    : Bus 1810	: V=1.05724521, theta=-19.1285903 -> V=1.033333, theta=0.0
% INFO    : Bus 1811	: V=1.01841754, theta=-36.0125713 -> V=1.0000005, theta=0.0
% INFO    : Bus 1812	: V=1.05225504, theta=-30.5411601 -> V=1.046665, theta=0.0
% INFO    : Bus 1813	: V=1.03407062, theta=-20.2223912 -> V=1.0000025, theta=0.0
% INFO    : Bus 1814	: V=1.03795302, theta=-40.9179972 -> V=1.022224, theta=0.0
% INFO    : Bus 1815	: V=1.01629979, theta=-16.3920365 -> V=1.0158755, theta=0.0
% INFO    : Bus 1816	: V=1.00802772, theta=-46.4231332 -> V=1.022224, theta=0.0
% INFO    : Bus 1817	: V=1.03177932, theta=-28.8286798 -> V=1.005558, theta=0.0
% INFO    : Bus 1818	: V=1.03039174, theta=-35.0045333 -> V=1.027779, theta=0.0
% INFO    : Bus 1819	: V=1.03758162, theta=-39.7062951 -> V=1.027779, theta=0.0
% INFO    : Bus 1820	: V=1.0268422, theta=-22.3210653 -> V=1.000001, theta=0.0
% INFO    : Bus 1821	: V=1.01970433, theta=-38.7390858 -> V=1.022224, theta=0.0
% INFO    : Bus 1822	: V=1.02695142, theta=-22.3085764 -> V=1.0000025, theta=0.0
% INFO    : Bus 1823	: V=1.0509455, theta=-20.3954806 -> V=1.0000025, theta=0.0
% INFO    : Bus 1824	: V=1.05672974, theta=-16.5800206 -> V=1.044445, theta=0.0
% INFO    : Bus 1825	: V=1.06196329, theta=-16.366919 -> V=0.9888895, theta=0.0
% INFO    : Bus 1826	: V=1.05499514, theta=-20.8386244 -> V=1.0111115, theta=0.0
% INFO    : Bus 1827	: V=1.03200135, theta=-12.2741547 -> V=1.0158755, theta=0.0
% INFO    : Bus 1828	: V=1.05410715, theta=-9.79308873 -> V=1.0377785, theta=0.0
% INFO    : Bus 1829	: V=1.0870628, theta=-7.12503465 -> V=1.072365, theta=0.0
% INFO    : Bus 1830	: V=0.995197901, theta=-47.6623147 -> V=1.022224, theta=0.0
% INFO    : Bus 1831	: V=1.01600875, theta=-23.5548424 -> V=1.0000025, theta=0.0
% INFO    : Bus 1832	: V=1.01929764, theta=-37.1367335 -> V=1.015872, theta=0.0
% INFO    : Bus 1833	: V=1.01920383, theta=-29.9495695 -> V=1.046665, theta=0.0
% INFO    : Bus 1834	: V=1.04769551, theta=-36.4816976 -> V=1.027779, theta=0.0
% INFO    : Bus 1835	: V=1.02524698, theta=-5.97113377 -> V=0.999999, theta=0.0
% INFO    : Bus 1836	: V=1.00206824, theta=-48.3696597 -> V=1.022224, theta=0.0
% INFO    : Bus 1837	: V=1.02719883, theta=-30.2964658 -> V=1.0111115, theta=0.0
% INFO    : Bus 1838	: V=1.02473261, theta=-9.8569541 -> V=0.999999, theta=0.0
% INFO    : Bus 1839	: V=1.04254002, theta=-7.34512462 -> V=1.0111115, theta=0.0
% INFO    : Bus 1840	: V=1.06707604, theta=-33.990403 -> V=1.046665, theta=0.0
% INFO    : Bus 1841	: V=1.06750326, theta=-33.9501845 -> V=1.046665, theta=0.0
% INFO    : Bus 1842	: V=0.992009455, theta=-23.0637705 -> V=1.0158755, theta=0.0
% INFO    : Bus 1843	: V=1.0267042, theta=-14.9332753 -> V=1.0158755, theta=0.0
% INFO    : Bus 1844	: V=1.03706546, theta=-11.9375782 -> V=1.0377785, theta=0.0
% INFO    : Bus 1845	: V=1.03827698, theta=-21.9847899 -> V=1.0000025, theta=0.0
% INFO    : Bus 1846	: V=1.01708042, theta=-5.24223661 -> V=1.0158755, theta=0.0
% INFO    : Bus 1847	: V=1.01675325, theta=-5.26905616 -> V=1.0158755, theta=0.0
% INFO    : Bus 1848	: V=1.0618323, theta=-25.6647373 -> V=1.022222, theta=0.0
% INFO    : Bus 1849	: V=1.03764882, theta=-39.6994618 -> V=1.027779, theta=0.0
% INFO    : Bus 1850	: V=1.03764877, theta=-39.6994604 -> V=1.027779, theta=0.0
% INFO    : Bus 1851	: V=1.00646721, theta=-23.723398 -> V=0.999999, theta=0.0
% INFO    : Bus 1852	: V=0.992628767, theta=-26.1272758 -> V=1.0158755, theta=0.0
% INFO    : Bus 1853	: V=1.04521925, theta=-30.2007242 -> V=1.015872, theta=0.0
% INFO    : Bus 1854	: V=1.0275649, theta=-29.1183137 -> V=1.0000025, theta=0.0
% INFO    : Bus 1855	: V=1.02845231, theta=-23.9278713 -> V=0.999999, theta=0.0
% INFO    : Bus 1856	: V=1.02791726, theta=-23.9486936 -> V=0.999999, theta=0.0
% INFO    : Bus 1857	: V=1.01367044, theta=-5.60512151 -> V=1.0158755, theta=0.0
% INFO    : Bus 1858	: V=1.03459627, theta=-36.9400438 -> V=1.0000025, theta=0.0
% INFO    : Bus 1859	: V=1.000734, theta=-35.1823116 -> V=1.015872, theta=0.0
% INFO    : Bus 1860	: V=0.983673218, theta=-18.0476849 -> V=1.015872, theta=0.0
% INFO    : Bus 1861	: V=1.03700801, theta=-29.6899959 -> V=1.0000025, theta=0.0
% INFO    : Bus 1862	: V=1.01847997, theta=-11.3963517 -> V=0.999999, theta=0.0
% INFO    : Bus 1863	: V=1.02155916, theta=-11.0672912 -> V=1.0158755, theta=0.0
% INFO    : Bus 1864	: V=1.06496579, theta=-23.2712517 -> V=1.0000025, theta=0.0
% INFO    : Bus 1865	: V=0.998687484, theta=-16.904447 -> V=1.015872, theta=0.0
% INFO    : Bus 1866	: V=1.01871525, theta=-30.6481051 -> V=1.022224, theta=0.0
% INFO    : Bus 1867	: V=1.01872795, theta=-30.9721621 -> V=1.022224, theta=0.0
% INFO    : Bus 1868	: V=0.984095129, theta=-46.4405231 -> V=1.0192145, theta=0.0
% INFO    : Bus 1869	: V=1.02177153, theta=-17.1481774 -> V=1.0111115, theta=0.0
% INFO    : Bus 1870	: V=1.02093733, theta=-36.6373487 -> V=1.022224, theta=0.0
% INFO    : Bus 1871	: V=1.009, theta=-31.8931677 -> V=1.0000005, theta=0.0
% INFO    : Bus 1872	: V=1.03813153, theta=-8.93130933 -> V=0.999999, theta=0.0
% INFO    : Bus 1873	: V=1.01480011, theta=-19.1769916 -> V=1.015872, theta=0.0
% INFO    : Bus 1874	: V=0.973507528, theta=-31.1741728 -> V=1.0000005, theta=0.0
% INFO    : Bus 1875	: V=1.01639651, theta=-23.7584131 -> V=1.0000025, theta=0.0
% INFO    : Bus 1876	: V=1.02674886, theta=-36.6809848 -> V=1.027779, theta=0.0
% INFO    : Bus 1877	: V=1.06840498, theta=-21.0623673 -> V=1.000001, theta=0.0
% INFO    : Bus 1878	: V=1.03432842, theta=-12.3680993 -> V=0.999999, theta=0.0
% INFO    : Bus 1879	: V=1.07074579, theta=-27.2637391 -> V=1.033333, theta=0.0
% INFO    : Bus 1880	: V=1.04799477, theta=-9.16184257 -> V=1.0158755, theta=0.0
% INFO    : Bus 1881	: V=1.03576029, theta=-27.3687261 -> V=1.022224, theta=0.0
% INFO    : Bus 1882	: V=1.03481665, theta=-17.3737508 -> V=0.999999, theta=0.0
% INFO    : Bus 1883	: V=1.0389181, theta=-29.4201294 -> V=1.027779, theta=0.0
% INFO    : Bus 1884	: V=1.07721127, theta=-26.6515529 -> V=1.046665, theta=0.0
% INFO    : Bus 1885	: V=1.03628239, theta=-43.2643685 -> V=1.027779, theta=0.0
% INFO    : Bus 1886	: V=1.00257723, theta=-52.15525 -> V=1.022224, theta=0.0
% INFO    : Bus 1887	: V=1.00257723, theta=-52.15525 -> V=1.022224, theta=0.0
% INFO    : Bus 1888	: V=1.03101726, theta=-36.0382359 -> V=1.027779, theta=0.0
% INFO    : Bus 1889	: V=1.03113473, theta=-23.148802 -> V=1.0000025, theta=0.0
% INFO    : Bus 1890	: V=1.03273375, theta=-17.5913405 -> V=1.015872, theta=0.0
% INFO    : Bus 1891	: V=1.05683298, theta=-29.2451728 -> V=1.046665, theta=0.0
% INFO    : Bus 1892	: V=1.04932884, theta=-29.5077593 -> V=1.046665, theta=0.0
% INFO    : Bus 1893	: V=1.05397686, theta=-30.0999898 -> V=1.046665, theta=0.0
% INFO    : Bus 1894	: V=1.042, theta=-4.3617797 -> V=0.975, theta=0.0
% INFO    : Bus 1895	: V=1.04, theta=-4.67126643 -> V=0.975, theta=0.0
% INFO    : Bus 1896	: V=1.046, theta=-4.19389829 -> V=0.975, theta=0.0
% INFO    : Bus 1897	: V=1.046, theta=-4.25676889 -> V=0.975, theta=0.0
% INFO    : Bus 1898	: V=1.04273906, theta=-6.38680077 -> V=1.0377785, theta=0.0
% INFO    : Bus 1899	: V=1.04273007, theta=-6.3883483 -> V=1.0377785, theta=0.0
% INFO    : Bus 1900	: V=1.04275831, theta=-6.38592865 -> V=1.0377785, theta=0.0
% INFO    : Bus 1901	: V=1.04275852, theta=-6.38624085 -> V=1.0377785, theta=0.0
% INFO    : Bus 1902	: V=1.02443236, theta=-10.5505861 -> V=1.0158755, theta=0.0
% INFO    : Bus 1903	: V=1.04274538, theta=-6.39687292 -> V=1.0377785, theta=0.0
% INFO    : Bus 1904	: V=1.01739119, theta=-14.4993979 -> V=0.999999, theta=0.0
% INFO    : Bus 1905	: V=1.03010785, theta=-8.90422954 -> V=1.0111115, theta=0.0
% INFO    : Bus 1906	: V=1.01111962, theta=-18.778102 -> V=1.0000025, theta=0.0
% INFO    : Bus 1907	: V=1.05876758, theta=-15.5648603 -> V=1.044445, theta=0.0
% INFO    : Bus 1908	: V=1.02560786, theta=-37.5324309 -> V=1.027779, theta=0.0
% INFO    : Bus 1909	: V=1.02346224, theta=-22.7726574 -> V=0.999999, theta=0.0
% INFO    : Bus 1910	: V=1.0078434, theta=-34.1175711 -> V=1.0000005, theta=0.0
% INFO    : Bus 1911	: V=1.04531211, theta=-29.5582827 -> V=1.027779, theta=0.0
% INFO    : Bus 1912	: V=1.02578669, theta=-12.9637628 -> V=1.015872, theta=0.0
% INFO    : Bus 1913	: V=1.02963275, theta=-19.488854 -> V=1.0158755, theta=0.0
% INFO    : Bus 1914	: V=1.06462625, theta=-16.6868659 -> V=1.0377785, theta=0.0
% INFO    : Bus 1915	: V=1.01100258, theta=-25.6341084 -> V=1.0158755, theta=0.0
% INFO    : Bus 1916	: V=1.00980106, theta=-25.7764948 -> V=1.0158755, theta=0.0
% INFO    : Bus 1917	: V=1.02710059, theta=-29.5156134 -> V=1.015872, theta=0.0
% INFO    : Bus 1918	: V=1.03634752, theta=-25.1168035 -> V=1.046665, theta=0.0
% INFO    : Bus 1919	: V=1.01299699, theta=-35.934138 -> V=1.022224, theta=0.0
% INFO    : Bus 1920	: V=1.00970891, theta=-25.7749773 -> V=1.015872, theta=0.0
% INFO    : Bus 1921	: V=1.0205102, theta=-22.7939905 -> V=1.0000025, theta=0.0
% INFO    : Bus 1922	: V=0.997763482, theta=-15.043424 -> V=1.015872, theta=0.0
% INFO    : Bus 1923	: V=1.02676153, theta=-25.5493073 -> V=1.0000025, theta=0.0
% INFO    : Bus 1924	: V=1.07357474, theta=-21.7884784 -> V=1.0000025, theta=0.0
% INFO    : Bus 1925	: V=1.05280062, theta=-21.389534 -> V=1.022222, theta=0.0
% INFO    : Bus 1926	: V=1.00790596, theta=-37.5570232 -> V=1.0000005, theta=0.0
% INFO    : Bus 1927	: V=1.05406349, theta=-31.7755862 -> V=1.046665, theta=0.0
% INFO    : Bus 1928	: V=1.06669958, theta=-16.1277252 -> V=1.000001, theta=0.0
% INFO    : Bus 1929	: V=1.08478313, theta=-14.8187033 -> V=1.044445, theta=0.0
% INFO    : Bus 1930	: V=1.03051379, theta=-24.2255988 -> V=1.022224, theta=0.0
% INFO    : Bus 1931	: V=1.06772291, theta=-17.6034204 -> V=1.07237, theta=0.0
% INFO    : Bus 1932	: V=1.02633764, theta=-27.542876 -> V=1.0000025, theta=0.0
% INFO    : Bus 1933	: V=1.03334307, theta=-22.309797 -> V=1.000001, theta=0.0
% INFO    : Bus 1934	: V=1.01095276, theta=-18.223797 -> V=0.975, theta=0.0
% INFO    : Bus 1935	: V=1.06536485, theta=-17.765253 -> V=1.044445, theta=0.0
% INFO    : Bus 1936	: V=1.07695976, theta=-14.7181669 -> V=1.078945, theta=0.0
% INFO    : Bus 1937	: V=1.01452835, theta=-15.6820715 -> V=1.0079355, theta=0.0
% INFO    : Bus 1938	: V=1.07657771, theta=-9.81883407 -> V=1.07237, theta=0.0
% INFO    : Bus 1939	: V=1.0156173, theta=-8.08498658 -> V=0.999999, theta=0.0
% INFO    : Bus 1940	: V=1.0156173, theta=-8.08498658 -> V=0.999999, theta=0.0
% INFO    : Bus 1941	: V=1.01818717, theta=-7.91725635 -> V=0.999999, theta=0.0
% INFO    : Bus 1942	: V=1.0177259, theta=-24.2262632 -> V=1.015872, theta=0.0
% INFO    : Bus 1943	: V=1.04651843, theta=-25.4334255 -> V=1.016666, theta=0.0
% INFO    : Bus 1944	: V=1.06169976, theta=-25.6654839 -> V=1.016666, theta=0.0
% INFO    : Bus 1945	: V=1.03538408, theta=-20.7870983 -> V=1.015556, theta=0.0
% INFO    : Bus 1946	: V=1.05701032, theta=-17.2845037 -> V=1.05263, theta=0.0
% INFO    : Bus 1947	: V=1.03325082, theta=-35.1025373 -> V=1.0001405, theta=0.0
% INFO    : Bus 1948	: V=0.973463264, theta=-31.173219 -> V=1.0000005, theta=0.0
% INFO    : Bus 1949	: V=1.05684789, theta=-15.0980234 -> V=1.0000025, theta=0.0
% INFO    : Bus 1950	: V=1.01970336, theta=-9.68384641 -> V=1.0158755, theta=0.0
% INFO    : Bus 1951	: V=1.04172338, theta=-33.0175292 -> V=1.022224, theta=0.0
% INFO    : Bus 1952	: V=1.03082433, theta=-14.9190324 -> V=0.999999, theta=0.0
% INFO    : Bus 1953	: V=1.02403954, theta=-17.6076048 -> V=0.999999, theta=0.0
% INFO    : Bus 1954	: V=1.02798548, theta=-46.3891723 -> V=1.022224, theta=0.0
% INFO    : Bus 1955	: V=1.02597971, theta=-20.7309539 -> V=1.0158755, theta=0.0
% INFO    : Bus 1956	: V=1.04369906, theta=-25.8990342 -> V=1.022224, theta=0.0
% INFO    : Bus 1957	: V=1.03907106, theta=-13.2570379 -> V=0.999999, theta=0.0
% INFO    : Bus 1958	: V=1.02318551, theta=-24.1773856 -> V=1.0158755, theta=0.0
% INFO    : Bus 1959	: V=1.02996218, theta=-19.7288441 -> V=1.0158755, theta=0.0
% INFO    : Bus 1960	: V=1.01645057, theta=-24.4919042 -> V=1.0000025, theta=0.0
% INFO    : Bus 1961	: V=1.06842866, theta=-9.17208304 -> V=1.0111115, theta=0.0
% INFO    : Bus 1962	: V=1.06760741, theta=-9.68623115 -> V=1.0111115, theta=0.0
% INFO    : Bus 1963	: V=1.0741593, theta=-7.60885901 -> V=1.072365, theta=0.0
% INFO    : Bus 1964	: V=1.0225891, theta=-11.9971596 -> V=1.0158755, theta=0.0
% INFO    : Bus 1965	: V=1.01418514, theta=-14.6579224 -> V=0.999999, theta=0.0
% INFO    : Bus 1966	: V=1.02245592, theta=-13.6469168 -> V=0.999999, theta=0.0
% INFO    : Bus 1967	: V=1.00086543, theta=-28.7227108 -> V=1.0158755, theta=0.0
% INFO    : Bus 1968	: V=1.06, theta=-3.04396766 -> V=0.975, theta=0.0
% INFO    : Bus 1969	: V=1.064, theta=-3.10799825 -> V=0.975, theta=0.0
% INFO    : Bus 1970	: V=1.06, theta=-3.04514984 -> V=0.975, theta=0.0
% INFO    : Bus 1971	: V=1.064, theta=-3.08149921 -> V=0.975, theta=0.0
% INFO    : Bus 1972	: V=1.066, theta=-3.14395736 -> V=0.975, theta=0.0
% INFO    : Bus 1973	: V=1.0622338, theta=-4.11137525 -> V=1.0377785, theta=0.0
% INFO    : Bus 1974	: V=1.06227497, theta=-4.11195666 -> V=1.0377785, theta=0.0
% INFO    : Bus 1975	: V=1.06223381, theta=-4.11138727 -> V=1.0377785, theta=0.0
% INFO    : Bus 1976	: V=1.06227481, theta=-4.11168603 -> V=1.0377785, theta=0.0
% INFO    : Bus 1977	: V=1.06226168, theta=-4.12233167 -> V=1.0377785, theta=0.0
% INFO    : Bus 1978	: V=1.06229558, theta=-4.11228955 -> V=1.0377785, theta=0.0
% INFO    : Bus 1979	: V=1.00369469, theta=-12.5693406 -> V=1.0158755, theta=0.0
% INFO    : Bus 1980	: V=1.06226105, theta=-4.12233161 -> V=1.0377785, theta=0.0
% INFO    : Bus 1981	: V=1.019, theta=-3.69640666 -> V=0.975, theta=0.0
% INFO    : Bus 1982	: V=1.007, theta=-11.8251225 -> V=0.999999, theta=0.0
% INFO    : Bus 1983	: V=1.01, theta=-12.8636711 -> V=0.999999, theta=0.0
% INFO    : Bus 1984	: V=1.02586683, theta=-7.81777238 -> V=1.0111115, theta=0.0
% INFO    : Bus 1985	: V=1.04963935, theta=-27.409695 -> V=1.0000025, theta=0.0
% INFO    : Bus 1986	: V=1.00952287, theta=-51.8553057 -> V=1.0079355, theta=0.0
% INFO    : Bus 1987	: V=1.046, theta=-21.28965 -> V=1.0000025, theta=0.0
% INFO    : Bus 1988	: V=1.00004411, theta=-23.7990396 -> V=1.0158755, theta=0.0
% INFO    : Bus 1989	: V=1.01396258, theta=-16.3269266 -> V=0.999999, theta=0.0
% INFO    : Bus 1990	: V=1.00235599, theta=-20.2453538 -> V=1.0079355, theta=0.0
% INFO    : Bus 1991	: V=1.05538614, theta=-23.4546291 -> V=1.023634, theta=0.0
% INFO    : Bus 1992	: V=1.05786537, theta=-18.9281424 -> V=1.04444, theta=0.0
% INFO    : Bus 1993	: V=1.05300968, theta=-12.9051453 -> V=0.999999, theta=0.0
% INFO    : Bus 1994	: V=1.05502978, theta=-21.7503685 -> V=1.0000025, theta=0.0
% INFO    : Bus 1995	: V=1.04159745, theta=-10.866525 -> V=0.999999, theta=0.0
% INFO    : Bus 1996	: V=1.01537098, theta=-30.2182309 -> V=1.0000025, theta=0.0
% INFO    : Bus 1997	: V=1.0343662, theta=-26.7976965 -> V=1.0000025, theta=0.0
% INFO    : Bus 1998	: V=1.05983294, theta=-21.3851976 -> V=1.044445, theta=0.0
% INFO    : Bus 1999	: V=1.015291, theta=-16.5440598 -> V=1.0158755, theta=0.0
% INFO    : Bus 2000	: V=1.01069011, theta=-12.6580726 -> V=1.0158755, theta=0.0
% INFO    : Bus 2001	: V=0.96600458, theta=-9.39761699 -> V=0.9444445, theta=0.0
% INFO    : Bus 2002	: V=1.01803295, theta=-21.5079354 -> V=1.0158755, theta=0.0
% INFO    : Bus 2003	: V=1.01709422, theta=-21.5563413 -> V=1.0158755, theta=0.0
% INFO    : Bus 2004	: V=1.0557134, theta=-7.1611641 -> V=1.0000025, theta=0.0
% INFO    : Bus 2005	: V=1.04763747, theta=-8.94528902 -> V=1.0111115, theta=0.0
% INFO    : Bus 2006	: V=1.029477, theta=-28.0861486 -> V=1.0000025, theta=0.0
% INFO    : Bus 2007	: V=1.01628296, theta=-11.4136628 -> V=1.0158755, theta=0.0
% INFO    : Bus 2008	: V=1.033, theta=-17.5632297 -> V=1.0158755, theta=0.0
% INFO    : Bus 2009	: V=1.05989022, theta=-31.221446 -> V=1.046665, theta=0.0
% INFO    : Bus 2010	: V=1.05966225, theta=-31.3378673 -> V=1.046665, theta=0.0
% INFO    : Bus 2011	: V=1.01567817, theta=-36.6547097 -> V=1.022224, theta=0.0
% INFO    : Bus 2012	: V=1.04384436, theta=-20.2040178 -> V=1.0000025, theta=0.0
% INFO    : Bus 2013	: V=1.07932544, theta=-16.5555084 -> V=1.044445, theta=0.0
% INFO    : Bus 2014	: V=1.00238706, theta=-12.06337 -> V=1.0158755, theta=0.0
% INFO    : Bus 2015	: V=1.02713943, theta=-31.3958957 -> V=1.022224, theta=0.0
% INFO    : Bus 2016	: V=1.06224754, theta=-6.57311463 -> V=1.0377785, theta=0.0
% INFO    : Bus 2017	: V=1.09387146, theta=-10.3136977 -> V=1.078945, theta=0.0
% INFO    : Bus 2018	: V=1.09382623, theta=-10.3284774 -> V=1.078945, theta=0.0
% INFO    : Bus 2019	: V=1.025, theta=-25.291802 -> V=1.0000025, theta=0.0
% INFO    : Bus 2020	: V=1.03, theta=-25.040375 -> V=1.0000025, theta=0.0
% INFO    : Bus 2021	: V=1.0912443, theta=-12.6810395 -> V=1.045275, theta=0.0
% INFO    : Bus 2022	: V=1.02232349, theta=-10.1917391 -> V=0.999999, theta=0.0
% INFO    : Bus 2023	: V=1.01464133, theta=-15.0913121 -> V=1.0158755, theta=0.0
% INFO    : Bus 2024	: V=1.03796927, theta=-30.6614105 -> V=1.046665, theta=0.0
% INFO    : Bus 2025	: V=1.01923105, theta=-30.4914939 -> V=1.027779, theta=0.0
% INFO    : Bus 2026	: V=1.00027606, theta=-22.7057927 -> V=1.015872, theta=0.0
% INFO    : Bus 2027	: V=1.01821337, theta=-33.9600139 -> V=1.015872, theta=0.0
% INFO    : Bus 2028	: V=1.02295315, theta=-12.2167846 -> V=0.999999, theta=0.0
% INFO    : Bus 2029	: V=1.041, theta=-21.9967644 -> V=1.000001, theta=0.0
% INFO    : Bus 2030	: V=1.03767557, theta=-21.7014582 -> V=1.000001, theta=0.0
% INFO    : Bus 2031	: V=1.03957322, theta=-47.1443751 -> V=1.022224, theta=0.0
% INFO    : Bus 2032	: V=1.05417276, theta=-26.9569118 -> V=1.022222, theta=0.0
% INFO    : Bus 2033	: V=0.99151061, theta=-53.6566224 -> V=1.022224, theta=0.0
% INFO    : Bus 2034	: V=1.05270327, theta=-17.7242762 -> V=1.000001, theta=0.0
% INFO    : Bus 2035	: V=1.03246302, theta=-48.5446481 -> V=1.022224, theta=0.0
% INFO    : Bus 2036	: V=1.02300945, theta=-21.8607064 -> V=1.0000025, theta=0.0
% INFO    : Bus 2037	: V=1.00095742, theta=-56.5570633 -> V=1.0079355, theta=0.0
% INFO    : Bus 2038	: V=1.05141179, theta=-24.8221036 -> V=1.0000025, theta=0.0
% INFO    : Bus 2039	: V=1.03583325, theta=-65.5521825 -> V=1.0079355, theta=0.0
% INFO    : Bus 2040	: V=1.01842849, theta=-22.8407113 -> V=1.0000025, theta=0.0
% INFO    : Bus 2041	: V=1.07063196, theta=-20.4464227 -> V=1.044445, theta=0.0
% INFO    : Bus 2042	: V=0.983181227, theta=-37.7398284 -> V=1.0000005, theta=0.0
% INFO    : Bus 2043	: V=1.03896937, theta=-23.607137 -> V=1.0000025, theta=0.0
% INFO    : Bus 2044	: V=1.02875514, theta=-30.3724227 -> V=1.046665, theta=0.0
% INFO    : Bus 2045	: V=1.01982181, theta=-21.9952085 -> V=0.999999, theta=0.0
% INFO    : Bus 2046	: V=1.09665512, theta=-17.8547101 -> V=1.0, theta=0.0
% INFO    : Bus 2047	: V=1.05718964, theta=-16.3223296 -> V=1.033334, theta=0.0
% INFO    : Bus 2048	: V=1.02043783, theta=-9.61879646 -> V=1.0158755, theta=0.0
% INFO    : Bus 2049	: V=1.02689343, theta=-10.3710766 -> V=1.0158755, theta=0.0
% INFO    : Bus 2050	: V=1.05689628, theta=-5.31302516 -> V=1.0377785, theta=0.0
% INFO    : Bus 2051	: V=1.023, theta=-18.3178304 -> V=0.999999, theta=0.0
% INFO    : Bus 2052	: V=1.00447708, theta=-32.2304492 -> V=1.0000005, theta=0.0
% INFO    : Bus 2053	: V=0.993745799, theta=-34.1594392 -> V=1.0000005, theta=0.0
% INFO    : Bus 2054	: V=1.0762877, theta=-13.0436283 -> V=1.044445, theta=0.0
% INFO    : Bus 2055	: V=0.972875529, theta=-28.2609253 -> V=1.0158755, theta=0.0
% INFO    : Bus 2056	: V=1.0632318, theta=-25.4775742 -> V=1.04444, theta=0.0
% INFO    : Bus 2057	: V=1.06997232, theta=-19.048919 -> V=1.07237, theta=0.0
% INFO    : Bus 2058	: V=1.00682815, theta=-34.6129764 -> V=1.015872, theta=0.0
% INFO    : Bus 2059	: V=1.00694104, theta=-34.6022945 -> V=1.015872, theta=0.0
% INFO    : Bus 2060	: V=1.00699351, theta=-34.6069878 -> V=1.015872, theta=0.0
% INFO    : Bus 2061	: V=1.02650581, theta=-23.8896927 -> V=1.0000025, theta=0.0
% INFO    : Bus 2062	: V=1.0891647, theta=-11.0620743 -> V=1.05263, theta=0.0
% INFO    : Bus 2063	: V=1.08580872, theta=-11.2549246 -> V=1.05263, theta=0.0
% INFO    : Bus 2064	: V=1.08613049, theta=-11.2502119 -> V=1.05263, theta=0.0
% INFO    : Bus 2065	: V=1.08873593, theta=-11.0497733 -> V=1.05263, theta=0.0
% INFO    : Bus 2066	: V=1.08582718, theta=-11.2399252 -> V=1.05263, theta=0.0
% INFO    : Bus 2067	: V=1.08903069, theta=-11.1325942 -> V=1.05263, theta=0.0
% INFO    : Bus 2068	: V=1.05184978, theta=-22.0509183 -> V=1.000509, theta=0.0
% INFO    : Bus 2069	: V=1.05044764, theta=-20.9536843 -> V=1.022222, theta=0.0
% INFO    : Bus 2070	: V=1.00166853, theta=-25.9772705 -> V=1.0158755, theta=0.0
% INFO    : Bus 2071	: V=0.961617463, theta=-29.6134424 -> V=1.0000005, theta=0.0
% INFO    : Bus 2072	: V=1.04707572, theta=-8.56663078 -> V=1.0111115, theta=0.0
% INFO    : Bus 2073	: V=1.05003869, theta=-16.060991 -> V=1.001084, theta=0.0
% INFO    : Bus 2074	: V=1.0697054, theta=-8.14106534 -> V=1.072365, theta=0.0
% INFO    : Bus 2075	: V=1.06966335, theta=-8.26284489 -> V=1.072365, theta=0.0
% INFO    : Bus 2076	: V=1.06485114, theta=-20.2554653 -> V=1.022222, theta=0.0
% INFO    : Bus 2077	: V=1.05639052, theta=-24.5813437 -> V=1.0000025, theta=0.0
% INFO    : Bus 2078	: V=1.06187562, theta=-21.3092593 -> V=1.044445, theta=0.0
% INFO    : Bus 2079	: V=1.00699513, theta=-30.7754609 -> V=1.022224, theta=0.0
% INFO    : Bus 2080	: V=1.01182627, theta=-30.1166569 -> V=1.022224, theta=0.0
% INFO    : Bus 2081	: V=1.04024699, theta=-29.4340307 -> V=1.046665, theta=0.0
% INFO    : Bus 2082	: V=1.04007261, theta=-29.5449795 -> V=1.046665, theta=0.0
% INFO    : Bus 2083	: V=1.02646757, theta=-31.7032372 -> V=1.022224, theta=0.0
% INFO    : Bus 2084	: V=1.03912547, theta=-25.8113453 -> V=1.022224, theta=0.0
% INFO    : Bus 2085	: V=1.05072813, theta=-20.50245 -> V=1.0000025, theta=0.0
% INFO    : Bus 2086	: V=1.02789381, theta=-12.7799141 -> V=1.015872, theta=0.0
% INFO    : Bus 2087	: V=1.055315, theta=-9.70151968 -> V=1.046665, theta=0.0
% INFO    : Bus 2088	: V=1.04178191, theta=-15.5843528 -> V=1.0377785, theta=0.0
% INFO    : Bus 2089	: V=1.05487064, theta=-11.8462899 -> V=1.072365, theta=0.0
% INFO    : Bus 2090	: V=1.00462054, theta=-34.8144837 -> V=1.015872, theta=0.0
% INFO    : Bus 2091	: V=1.02505111, theta=-37.1280125 -> V=1.027779, theta=0.0
% INFO    : Bus 2092	: V=1.01077225, theta=-46.3309114 -> V=1.022224, theta=0.0
% INFO    : Bus 2093	: V=1.06827584, theta=-24.3787274 -> V=1.033333, theta=0.0
% INFO    : Bus 2094	: V=1.03764839, theta=-21.0472716 -> V=1.0000005, theta=0.0
% INFO    : Bus 2095	: V=1.03624064, theta=-19.9862354 -> V=1.0000005, theta=0.0
% INFO    : Bus 2096	: V=1.03297971, theta=-8.93494341 -> V=1.0158755, theta=0.0
% INFO    : Bus 2097	: V=1.07185861, theta=-5.99859765 -> V=1.0377785, theta=0.0
% INFO    : Bus 2098	: V=1.00217722, theta=-62.2474662 -> V=1.0079355, theta=0.0
% INFO    : Bus 2099	: V=1.053, theta=-21.3723752 -> V=1.022222, theta=0.0
% INFO    : Bus 2100	: V=1.01208499, theta=-51.3049028 -> V=1.0079355, theta=0.0
% INFO    : Bus 2101	: V=1.06588961, theta=-21.9455498 -> V=1.000001, theta=0.0
% INFO    : Bus 2102	: V=1.01545786, theta=-54.2691201 -> V=1.022224, theta=0.0
% INFO    : Bus 2103	: V=1.011, theta=-66.9556115 -> V=1.0079355, theta=0.0
% INFO    : Bus 2104	: V=1.0364423, theta=-45.5170352 -> V=1.0079355, theta=0.0
% INFO    : Bus 2105	: V=1.08278408, theta=-41.6090017 -> V=1.04461, theta=0.0
% INFO    : Bus 2106	: V=0.996261793, theta=-53.4459465 -> V=1.022224, theta=0.0
% INFO    : Bus 2107	: V=1.06246292, theta=-30.9910005 -> V=1.046665, theta=0.0
% INFO    : Bus 2108	: V=1.03283583, theta=-21.6997305 -> V=1.0158755, theta=0.0
% INFO    : Bus 2109	: V=1.03404983, theta=-21.6573138 -> V=1.0158755, theta=0.0
% INFO    : Bus 2110	: V=1.03372172, theta=-21.6407071 -> V=1.0158755, theta=0.0
% INFO    : Bus 2111	: V=1.03377145, theta=-21.640014 -> V=1.0158755, theta=0.0
% INFO    : Bus 2112	: V=1.03375885, theta=-21.6330834 -> V=1.0158755, theta=0.0
% INFO    : Bus 2113	: V=1.03168649, theta=-18.2965459 -> V=1.0377785, theta=0.0
% INFO    : Bus 2114	: V=1.01116, theta=-60.644643 -> V=1.0079355, theta=0.0
% INFO    : Bus 2115	: V=1.0473029, theta=-25.5819247 -> V=1.0000025, theta=0.0
% INFO    : Bus 2116	: V=0.996614111, theta=-61.8362414 -> V=1.0079355, theta=0.0
% INFO    : Bus 2117	: V=1.00270715, theta=-18.5568618 -> V=1.0158755, theta=0.0
% INFO    : Bus 2118	: V=1.02615214, theta=-21.2542342 -> V=1.0000025, theta=0.0
% INFO    : Bus 2119	: V=1.00903349, theta=-15.0393161 -> V=0.999999, theta=0.0
% INFO    : Bus 2120	: V=1.04462162, theta=-11.5937882 -> V=0.975, theta=0.0
% INFO    : Bus 2121	: V=0.981317837, theta=-25.1613448 -> V=1.015872, theta=0.0
% INFO    : Bus 2122	: V=1.01379733, theta=-29.4933981 -> V=1.0000005, theta=0.0
% INFO    : Bus 2123	: V=1.00531427, theta=-60.8013944 -> V=1.0079355, theta=0.0
% INFO    : Bus 2124	: V=1.01232184, theta=-12.049247 -> V=1.0158755, theta=0.0
% INFO    : Bus 2125	: V=1.05340732, theta=-27.2540971 -> V=1.0000025, theta=0.0
% INFO    : Bus 2126	: V=1.05085609, theta=-22.324247 -> V=1.044445, theta=0.0
% INFO    : Bus 2127	: V=1.00839473, theta=-23.7658932 -> V=1.0158755, theta=0.0
% INFO    : Bus 2128	: V=1.03579392, theta=-12.4531375 -> V=0.999999, theta=0.0
% INFO    : Bus 2129	: V=1.03318016, theta=-13.6960025 -> V=0.999999, theta=0.0
% INFO    : Bus 2130	: V=1.04755227, theta=-8.95890764 -> V=1.0111115, theta=0.0
% INFO    : Bus 2131	: V=1.04760379, theta=-8.95691662 -> V=1.0111115, theta=0.0
% INFO    : Bus 2132	: V=1.04756101, theta=-8.95913578 -> V=1.0111115, theta=0.0
% INFO    : Bus 2133	: V=1.06343653, theta=-23.1575372 -> V=1.022222, theta=0.0
% INFO    : Bus 2134	: V=1.06233133, theta=-17.3622222 -> V=1.0266685, theta=0.0
% INFO    : Bus 2135	: V=1.0562413, theta=-17.3098324 -> V=1.022223, theta=0.0
% INFO    : Bus 2136	: V=0.994669608, theta=-21.3649382 -> V=1.0158755, theta=0.0
% INFO    : Bus 2137	: V=0.953877778, theta=-8.90658392 -> V=0.9444445, theta=0.0
% INFO    : Bus 2138	: V=1.03006473, theta=-11.1973583 -> V=0.999999, theta=0.0
% INFO    : Bus 2139	: V=1.05287284, theta=-7.45013884 -> V=1.0111115, theta=0.0
% INFO    : Bus 2140	: V=1.05834579, theta=-16.8583222 -> V=0.9888895, theta=0.0
% INFO    : Bus 2141	: V=1.07023199, theta=-15.0352347 -> V=0.9888895, theta=0.0
% INFO    : Bus 2142	: V=1.01907311, theta=-7.25316034 -> V=1.0158755, theta=0.0
% INFO    : Bus 2143	: V=1.03887198, theta=-28.7178492 -> V=1.027779, theta=0.0
% INFO    : Bus 2144	: V=1.06611687, theta=-27.3843987 -> V=1.046665, theta=0.0
% INFO    : Bus 2145	: V=1.06584951, theta=-24.3512126 -> V=1.04444, theta=0.0
% INFO    : Bus 2146	: V=1.0611458, theta=-24.8173451 -> V=1.04444, theta=0.0
% INFO    : Bus 2147	: V=1.0021128, theta=-22.239203 -> V=1.015872, theta=0.0
% INFO    : Bus 2148	: V=1.04064017, theta=-11.3575011 -> V=0.999999, theta=0.0
% INFO    : Bus 2149	: V=1.04813356, theta=-7.83864302 -> V=1.0111115, theta=0.0
% INFO    : Bus 2150	: V=1.07293638, theta=-4.86909889 -> V=1.072365, theta=0.0
% INFO    : Bus 2151	: V=1.02360816, theta=-51.3638222 -> V=1.022224, theta=0.0
% INFO    : Bus 2152	: V=1.03533058, theta=-41.1017914 -> V=1.022224, theta=0.0
% INFO    : Bus 2153	: V=1.04542515, theta=-11.077674 -> V=1.0158755, theta=0.0
% INFO    : Bus 2154	: V=0.992656383, theta=-19.6835517 -> V=1.0158755, theta=0.0
% INFO    : Bus 2155	: V=1.00286357, theta=-25.2298736 -> V=1.0000025, theta=0.0
% INFO    : Bus 2156	: V=1.04799297, theta=-9.1618016 -> V=1.0158755, theta=0.0
% INFO    : Bus 2157	: V=1.02236462, theta=-16.2278371 -> V=1.0158755, theta=0.0
% INFO    : Bus 2158	: V=1.03318357, theta=-27.0106897 -> V=1.0000025, theta=0.0
% INFO    : Bus 2159	: V=1.01937937, theta=-47.7529441 -> V=1.022224, theta=0.0
% INFO    : Bus 2160	: V=1.00948346, theta=-30.4556326 -> V=1.0000005, theta=0.0
% INFO    : Bus 2161	: V=1.061, theta=-28.9933595 -> V=1.027779, theta=0.0
% INFO    : Bus 2162	: V=1.05994683, theta=-28.9962695 -> V=1.027779, theta=0.0
% INFO    : Bus 2163	: V=1.07213724, theta=-25.3609283 -> V=1.046665, theta=0.0
% INFO    : Bus 2164	: V=1.08412036, theta=-41.3386087 -> V=1.045215, theta=0.0
% INFO    : Bus 2165	: V=1.01, theta=-33.3019998 -> V=1.0000005, theta=0.0
% INFO    : Bus 2166	: V=1.05742767, theta=-19.123376 -> V=1.033333, theta=0.0
% INFO    : Bus 2167	: V=1.06212513, theta=-16.3441486 -> V=1.0288895, theta=0.0
% INFO    : Bus 2168	: V=1.03765176, theta=-13.2135987 -> V=0.999999, theta=0.0
% INFO    : Bus 2169	: V=1.0375057, theta=-13.2341176 -> V=0.999999, theta=0.0
% INFO    : Bus 2170	: V=1.03749886, theta=-13.2762327 -> V=0.999999, theta=0.0
% INFO    : Bus 2171	: V=1.02891413, theta=-15.5086528 -> V=0.999999, theta=0.0
% INFO    : Bus 2172	: V=1.02804569, theta=-25.0717907 -> V=1.0000025, theta=0.0
% INFO    : Bus 2173	: V=1.06750016, theta=-9.72714276 -> V=1.0158755, theta=0.0
% INFO    : Bus 2174	: V=1.02607875, theta=-10.6548936 -> V=1.0158755, theta=0.0
% INFO    : Bus 2175	: V=1.0418371, theta=-6.2775209 -> V=1.0377785, theta=0.0
% INFO    : Bus 2176	: V=1.04148207, theta=-6.27291633 -> V=1.0377785, theta=0.0
% INFO    : Bus 2177	: V=1.05512555, theta=-34.2201658 -> V=1.027779, theta=0.0
% INFO    : Bus 2178	: V=1.02803793, theta=-10.725669 -> V=1.0158755, theta=0.0
% INFO    : Bus 2179	: V=1.02803793, theta=-10.725669 -> V=1.0158755, theta=0.0
% INFO    : Bus 2180	: V=1.047557, theta=-30.5886958 -> V=1.046665, theta=0.0
% INFO    : Bus 2181	: V=1.01778126, theta=-3.45832051 -> V=1.0158755, theta=0.0
% INFO    : Bus 2182	: V=1.03623163, theta=-28.3977163 -> V=1.0000025, theta=0.0
% INFO    : Bus 2183	: V=1.04091615, theta=-20.2479659 -> V=0.9888895, theta=0.0
% INFO    : Bus 2184	: V=1.04100379, theta=-20.2462849 -> V=0.9888895, theta=0.0
% INFO    : Bus 2185	: V=0.984181467, theta=-34.8681832 -> V=1.0000005, theta=0.0
% INFO    : Bus 2186	: V=1.05445446, theta=-31.7376075 -> V=1.046665, theta=0.0
% INFO    : Bus 2187	: V=1.04291819, theta=-30.8353257 -> V=1.027779, theta=0.0
% INFO    : Bus 2188	: V=0.984182831, theta=-34.8681912 -> V=1.0000005, theta=0.0
% INFO    : Bus 2189	: V=1.02165186, theta=-38.0431105 -> V=1.0000005, theta=0.0
% INFO    : Bus 2190	: V=1.00004313, theta=-33.4617499 -> V=0.9682545, theta=0.0
% INFO    : Bus 2191	: V=1.02601117, theta=-28.9148459 -> V=1.0000025, theta=0.0
% INFO    : Bus 2192	: V=1.05443, theta=-23.8710352 -> V=1.022222, theta=0.0
% INFO    : Bus 2193	: V=0.967, theta=-9.36707443 -> V=0.9444445, theta=0.0
% INFO    : Bus 2194	: V=1.02333367, theta=-17.9936159 -> V=0.999999, theta=0.0
% INFO    : Bus 2195	: V=1.063, theta=-17.0772169 -> V=1.000001, theta=0.0
% INFO    : Bus 2196	: V=0.995098387, theta=-17.367854 -> V=1.0000015, theta=0.0
% INFO    : Bus 2197	: V=1.07836489, theta=-26.2189026 -> V=1.046665, theta=0.0
% INFO    : Bus 2198	: V=1.07857616, theta=-24.3708537 -> V=1.073685, theta=0.0
% INFO    : Bus 2199	: V=1.07854251, theta=-26.1974926 -> V=1.046665, theta=0.0
% INFO    : Bus 2200	: V=1.0783514, theta=-26.2182586 -> V=1.046665, theta=0.0
% INFO    : Bus 2201	: V=1.07857728, theta=-24.3704518 -> V=1.073685, theta=0.0
% INFO    : Bus 2202	: V=1.04328761, theta=-9.19268638 -> V=0.984126, theta=0.0
% INFO    : Bus 2203	: V=1.06064612, theta=-25.6738268 -> V=1.022222, theta=0.0
% INFO    : Bus 2204	: V=1.02542121, theta=-47.503964 -> V=1.0079355, theta=0.0
% INFO    : Bus 2205	: V=1.02149396, theta=-16.5113964 -> V=1.015872, theta=0.0
% INFO    : Bus 2206	: V=1.04317425, theta=-19.8629711 -> V=0.9888895, theta=0.0
% INFO    : Bus 2207	: V=1.01716548, theta=-7.94651539 -> V=1.0158755, theta=0.0
% INFO    : Bus 2208	: V=1.0466136, theta=-25.5475803 -> V=1.022222, theta=0.0
% INFO    : Bus 2209	: V=1.01886424, theta=-24.6573052 -> V=1.0000025, theta=0.0
% INFO    : Bus 2210	: V=1.04161308, theta=-26.6085387 -> V=1.022222, theta=0.0
% INFO    : Bus 2211	: V=1.00273059, theta=-20.3020489 -> V=1.0079355, theta=0.0
% INFO    : Bus 2212	: V=1.01964663, theta=-51.5358367 -> V=1.0079355, theta=0.0
% INFO    : Bus 2213	: V=1.02024363, theta=-29.6870739 -> V=1.0000025, theta=0.0
% INFO    : Bus 2214	: V=1.01982938, theta=-48.5623513 -> V=1.022224, theta=0.0
% INFO    : Bus 2215	: V=0.994794749, theta=-39.567607 -> V=1.0000005, theta=0.0
% INFO    : Bus 2216	: V=1.06542881, theta=-33.4058941 -> V=1.046665, theta=0.0
% INFO    : Bus 2217	: V=1.06387957, theta=-33.5131435 -> V=1.046665, theta=0.0
% INFO    : Bus 2218	: V=1.03159803, theta=-14.9630759 -> V=1.0158755, theta=0.0
% INFO    : Bus 2219	: V=1.02740039, theta=-15.4239885 -> V=1.0158755, theta=0.0
% INFO    : Bus 2220	: V=0.995482741, theta=-11.4242901 -> V=1.0158755, theta=0.0
% INFO    : Bus 2221	: V=1.01450768, theta=-50.4012442 -> V=1.022224, theta=0.0
% INFO    : Bus 2222	: V=1.04601245, theta=-6.47178905 -> V=1.0111115, theta=0.0
% INFO    : Bus 2223	: V=1.02801437, theta=-10.7249514 -> V=1.0158755, theta=0.0
% INFO    : Bus 2224	: V=1.05619128, theta=-5.53529042 -> V=1.0377785, theta=0.0
% INFO    : Bus 2225	: V=1.05357815, theta=-22.3602159 -> V=1.073685, theta=0.0
% INFO    : Bus 2226	: V=1.03914394, theta=-29.558038 -> V=1.022222, theta=0.0
% INFO    : Bus 2227	: V=1.01563692, theta=-10.4357988 -> V=1.0158755, theta=0.0
% INFO    : Bus 2228	: V=1.04478825, theta=-10.7895481 -> V=1.0158755, theta=0.0
% INFO    : Bus 2229	: V=1.07415916, theta=-7.79685526 -> V=1.0377785, theta=0.0
% INFO    : Bus 2230	: V=1.03400752, theta=-21.2397575 -> V=1.0000025, theta=0.0
% INFO    : Bus 2231	: V=1.01725581, theta=-27.4589114 -> V=1.0000025, theta=0.0
% INFO    : Bus 2232	: V=1.01863509, theta=-10.7943836 -> V=1.0158755, theta=0.0
% INFO    : Bus 2233	: V=1.04789824, theta=-20.9795138 -> V=1.033333, theta=0.0
% INFO    : Bus 2234	: V=1.05449502, theta=-18.1567438 -> V=1.0288895, theta=0.0
% INFO    : Bus 2235	: V=1.02027966, theta=-10.8837014 -> V=1.0158755, theta=0.0
% INFO    : Bus 2236	: V=1.05488643, theta=-22.5015374 -> V=1.015874, theta=0.0
% INFO    : Bus 2237	: V=1.05306032, theta=-20.5804607 -> V=1.033333, theta=0.0
% INFO    : Bus 2238	: V=1.02805754, theta=-16.069127 -> V=0.999999, theta=0.0
% INFO    : Bus 2239	: V=1.05456833, theta=-17.5517219 -> V=0.9888895, theta=0.0
% INFO    : Bus 2240	: V=1.03874337, theta=-28.025559 -> V=1.0000025, theta=0.0
% INFO    : Bus 2241	: V=0.871141962, theta=-23.3630402 -> V=0.83, theta=0.0
% INFO    : Bus 2242	: V=1.08891526, theta=-23.362661 -> V=1.044445, theta=0.0
% INFO    : Bus 2243	: V=1.04624767, theta=-25.0708352 -> V=1.0000025, theta=0.0
% INFO    : Bus 2244	: V=1.04290824, theta=-28.3956209 -> V=1.022224, theta=0.0
% INFO    : Bus 2245	: V=1.00416058, theta=-15.2733738 -> V=1.0158755, theta=0.0
% INFO    : Bus 2246	: V=1.08533145, theta=-1.97345188 -> V=1.072365, theta=0.0
% INFO    : Bus 2247	: V=1.082, theta=-21.2544469 -> V=0.975, theta=0.0
% INFO    : Bus 2248	: V=1.04599281, theta=-21.3356325 -> V=1.0000025, theta=0.0
% INFO    : Bus 2249	: V=1.0761416, theta=-19.3419134 -> V=1.044445, theta=0.0
% INFO    : Bus 2250	: V=1.05565121, theta=-26.0916041 -> V=1.0000025, theta=0.0
% INFO    : Bus 2251	: V=1.05001877, theta=-35.3082031 -> V=1.027779, theta=0.0
% INFO    : Bus 2252	: V=1.01759589, theta=-10.2404745 -> V=1.0158755, theta=0.0
% INFO    : Bus 2253	: V=1.0678863, theta=-22.2203827 -> V=1.015874, theta=0.0
% INFO    : Bus 2254	: V=1.01998135, theta=-30.6930066 -> V=1.015872, theta=0.0
% INFO    : Bus 2255	: V=1.03424329, theta=-25.4848614 -> V=1.046665, theta=0.0
% INFO    : Bus 2256	: V=1.04043879, theta=-31.8817402 -> V=1.046665, theta=0.0
% INFO    : Bus 2257	: V=1.01244138, theta=-18.4193477 -> V=1.0158755, theta=0.0
% INFO    : Bus 2258	: V=1.07256506, theta=-25.2086583 -> V=1.046665, theta=0.0
% INFO    : Bus 2259	: V=1.07317155, theta=-25.5850334 -> V=1.046665, theta=0.0
% INFO    : Bus 2260	: V=1.02287148, theta=-2.34525508 -> V=1.0158755, theta=0.0
% INFO    : Bus 2261	: V=1.0132297, theta=-5.84051993 -> V=1.0158755, theta=0.0
% INFO    : Bus 2262	: V=1.05222099, theta=-24.8606787 -> V=1.033333, theta=0.0
% INFO    : Bus 2263	: V=1.01344979, theta=-22.8831728 -> V=1.0158755, theta=0.0
% INFO    : Bus 2264	: V=0.999402574, theta=-20.6587523 -> V=1.0, theta=0.0
% INFO    : Bus 2265	: V=1.03776235, theta=-17.7735474 -> V=1.0377785, theta=0.0
% INFO    : Bus 2266	: V=1.05192505, theta=-37.5398084 -> V=1.027779, theta=0.0
% INFO    : Bus 2267	: V=1.03831334, theta=-8.66859125 -> V=0.984126, theta=0.0
% INFO    : Bus 2268	: V=1.11527752, theta=-0.39229017 -> V=1.0387305, theta=0.0
% INFO    : Bus 2269	: V=1.01905475, theta=-2.24315524 -> V=1.0158755, theta=0.0
% INFO    : Bus 2270	: V=1.07624221, theta=-0.39229017 -> V=1.0377785, theta=0.0
% INFO    : Bus 2271	: V=0.995899955, theta=-29.0964291 -> V=1.0000025, theta=0.0
% INFO    : Bus 2272	: V=1.0531135, theta=-24.7989539 -> V=1.016666, theta=0.0
% INFO    : Bus 2273	: V=1.04147558, theta=-20.176972 -> V=1.006667, theta=0.0
% INFO    : Bus 2274	: V=1.02045786, theta=-11.3110124 -> V=1.0158755, theta=0.0
% INFO    : Bus 2275	: V=1.05443, theta=-23.8710352 -> V=1.022222, theta=0.0
% INFO    : Bus 2276	: V=1.02684982, theta=-7.39447582 -> V=1.0158755, theta=0.0
% INFO    : Bus 2277	: V=1.01292924, theta=-20.3686249 -> V=1.0158755, theta=0.0
% INFO    : Bus 2278	: V=1.0310776, theta=-49.4981661 -> V=1.0079355, theta=0.0
% INFO    : Bus 2279	: V=1.02634679, theta=-31.7466079 -> V=1.022224, theta=0.0
% INFO    : Bus 2280	: V=1.01801731, theta=-12.0044819 -> V=1.0158755, theta=0.0
% INFO    : Bus 2281	: V=1.01869823, theta=-4.59754878 -> V=1.0158755, theta=0.0
% INFO    : Bus 2282	: V=1.02374792, theta=2.59422745 -> V=1.013331, theta=0.0
% INFO    : Bus 2283	: V=1.02023195, theta=2.38051475 -> V=1.013331, theta=0.0
% INFO    : Bus 2284	: V=1.0198219, theta=-2.26354802 -> V=1.0158755, theta=0.0
% INFO    : Bus 2285	: V=1.03558063, theta=-20.0397391 -> V=0.9888895, theta=0.0
% INFO    : Bus 2286	: V=1.04087156, theta=-38.1954181 -> V=1.027779, theta=0.0
% INFO    : Bus 2287	: V=1.00543005, theta=-29.5045921 -> V=1.015872, theta=0.0
% INFO    : Bus 2288	: V=1.04594158, theta=-26.3331454 -> V=1.0000025, theta=0.0
% INFO    : Bus 2289	: V=1.03262542, theta=-26.686818 -> V=1.0000025, theta=0.0
% INFO    : Bus 2290	: V=1.07939839, theta=-15.7879659 -> V=1.078945, theta=0.0
% INFO    : Bus 2291	: V=1.03151691, theta=-46.3591555 -> V=1.022224, theta=0.0
% INFO    : Bus 2292	: V=1.03330209, theta=-20.7006141 -> V=0.999999, theta=0.0
% INFO    : Bus 2293	: V=1.03107277, theta=-17.7226932 -> V=1.0111115, theta=0.0
% INFO    : Bus 2294	: V=1.00789911, theta=-37.5569048 -> V=1.0000005, theta=0.0
% INFO    : Bus 2295	: V=0.984183749, theta=-34.868233 -> V=1.0000005, theta=0.0
% INFO    : Bus 2296	: V=0.98612382, theta=-34.6668458 -> V=1.0000005, theta=0.0
% INFO    : Bus 2297	: V=1.00997816, theta=-31.8682601 -> V=1.0000005, theta=0.0
% INFO    : Bus 2298	: V=1.05462181, theta=-15.2672406 -> V=1.004629, theta=0.0
% INFO    : Bus 2299	: V=1.05286511, theta=-11.7084782 -> V=1.0111115, theta=0.0
% INFO    : Bus 2300	: V=1.00946088, theta=-27.2677667 -> V=1.0000025, theta=0.0
% INFO    : Bus 2301	: V=1.03842483, theta=-11.8432322 -> V=0.999999, theta=0.0
% INFO    : Bus 2302	: V=1.00957851, theta=-29.6046403 -> V=1.0000025, theta=0.0
% INFO    : Bus 2303	: V=1.01143804, theta=-17.3453143 -> V=1.0158755, theta=0.0
% INFO    : Bus 2304	: V=1.02882554, theta=-38.4057827 -> V=1.022224, theta=0.0
% INFO    : Bus 2305	: V=1.03033066, theta=-30.5401329 -> V=1.0000025, theta=0.0
% INFO    : Bus 2306	: V=1.00834775, theta=-33.5856685 -> V=1.022224, theta=0.0
% INFO    : Bus 2307	: V=1.00229677, theta=-65.6946127 -> V=1.0079355, theta=0.0
% INFO    : Bus 2308	: V=1.02813071, theta=-10.0669275 -> V=1.0158755, theta=0.0
% INFO    : Bus 2309	: V=1.07812401, theta=-7.03973052 -> V=1.0377785, theta=0.0
% INFO    : Bus 2310	: V=1.00905791, theta=-29.2277349 -> V=1.015872, theta=0.0
% INFO    : Bus 2311	: V=1.04036751, theta=-26.6894347 -> V=1.0000025, theta=0.0
% INFO    : Bus 2312	: V=1.02296736, theta=-10.2257763 -> V=0.999999, theta=0.0
% INFO    : Bus 2313	: V=1.03913188, theta=-11.2494456 -> V=1.0111115, theta=0.0
% INFO    : Bus 2314	: V=1.02676545, theta=-26.0136079 -> V=1.0000025, theta=0.0
% INFO    : Bus 2315	: V=1.06526015, theta=-22.09638 -> V=1.044445, theta=0.0
% INFO    : Bus 2316	: V=1.02651451, theta=-12.525992 -> V=0.999999, theta=0.0
% INFO    : Bus 2317	: V=1.00583447, theta=-50.1080573 -> V=1.022224, theta=0.0
% INFO    : Bus 2318	: V=1.02179588, theta=-32.2900802 -> V=1.015872, theta=0.0
% INFO    : Bus 2319	: V=1.02526117, theta=-18.3185642 -> V=1.015872, theta=0.0
% INFO    : Bus 2320	: V=1.02051314, theta=-32.0488184 -> V=1.022224, theta=0.0
% INFO    : Bus 2321	: V=1.02843055, theta=-27.3214329 -> V=1.0000025, theta=0.0
% INFO    : Bus 2322	: V=1.04264052, theta=-31.6877911 -> V=1.022224, theta=0.0
% INFO    : Bus 2323	: V=1.03719415, theta=-35.8296163 -> V=1.022224, theta=0.0
% INFO    : Bus 2324	: V=1.01908355, theta=-25.739638 -> V=1.022224, theta=0.0
% INFO    : Bus 2325	: V=1.05421613, theta=-31.7528798 -> V=1.046665, theta=0.0
% INFO    : Bus 2326	: V=1.05422433, theta=-31.7640674 -> V=1.046665, theta=0.0
% INFO    : Bus 2327	: V=1.02523625, theta=-10.3020139 -> V=1.0158755, theta=0.0
% INFO    : Bus 2328	: V=1.06198057, theta=-6.65227323 -> V=1.0377785, theta=0.0
% INFO    : Bus 2329	: V=1.01267393, theta=-15.9553385 -> V=1.0158755, theta=0.0
% INFO    : Bus 2330	: V=1.02815111, theta=-25.1905285 -> V=1.0000025, theta=0.0
% INFO    : Bus 2331	: V=1.00635401, theta=-35.2807956 -> V=1.0000005, theta=0.0
% INFO    : Bus 2332	: V=1.01950994, theta=-18.7693402 -> V=1.015872, theta=0.0
% INFO    : Bus 2333	: V=1.03199992, theta=-18.4717886 -> V=1.015872, theta=0.0
% INFO    : Bus 2334	: V=1.02769809, theta=-19.4118867 -> V=1.015872, theta=0.0
% INFO    : Bus 2335	: V=1.02645417, theta=-18.6958996 -> V=1.015872, theta=0.0
% INFO    : Bus 2336	: V=1.04452812, theta=-13.3422607 -> V=1.046665, theta=0.0
% INFO    : Bus 2337	: V=1.05954238, theta=-5.80641642 -> V=1.076885, theta=0.0
% INFO    : Bus 2338	: V=1.04391595, theta=-30.2634588 -> V=1.022224, theta=0.0
% INFO    : Bus 2339	: V=1.04821071, theta=-58.0672396 -> V=1.0079355, theta=0.0
% INFO    : Bus 2340	: V=1.01953708, theta=-4.72726914 -> V=1.0158755, theta=0.0
% INFO    : Bus 2341	: V=0.987, theta=-20.8529588 -> V=1.015872, theta=0.0
% INFO    : Bus 2342	: V=1.05515966, theta=-19.6872083 -> V=1.0000025, theta=0.0
% INFO    : Bus 2343	: V=1.00837703, theta=-33.5865004 -> V=1.022224, theta=0.0
% INFO    : Bus 2344	: V=1.02160354, theta=-17.8263879 -> V=0.999999, theta=0.0
% INFO    : Bus 2345	: V=1.02767135, theta=-16.5216095 -> V=0.999999, theta=0.0
% INFO    : Bus 2346	: V=1.03719765, theta=-12.4426243 -> V=1.0111115, theta=0.0
% INFO    : Bus 2347	: V=0.999282031, theta=-33.0355809 -> V=1.0158755, theta=0.0
% INFO    : Bus 2348	: V=1.01177672, theta=-36.402412 -> V=1.027779, theta=0.0
% INFO    : Bus 2349	: V=1.01019312, theta=-30.2868901 -> V=1.027779, theta=0.0
% INFO    : Bus 2350	: V=1.0587879, theta=-25.4637195 -> V=1.04444, theta=0.0
% INFO    : Bus 2351	: V=1.07290441, theta=-24.2541199 -> V=1.07237, theta=0.0
% INFO    : Bus 2352	: V=1.07308586, theta=-24.2318273 -> V=1.07237, theta=0.0
% INFO    : Bus 2353	: V=1.0199321, theta=-3.31832786 -> V=1.0158755, theta=0.0
% INFO    : Bus 2354	: V=1.04201961, theta=-24.8448202 -> V=1.000001, theta=0.0
% INFO    : Bus 2355	: V=1.05639328, theta=-17.403743 -> V=1.000001, theta=0.0
% INFO    : Bus 2356	: V=1.01000983, theta=-18.558229 -> V=1.0158755, theta=0.0
% INFO    : Bus 2357	: V=1.04838188, theta=-23.1719644 -> V=1.022224, theta=0.0
% INFO    : Bus 2358	: V=1.02803917, theta=-28.1366474 -> V=1.0000025, theta=0.0
% INFO    : Bus 2359	: V=1.03067603, theta=-29.7892578 -> V=1.022224, theta=0.0
% INFO    : Bus 2360	: V=0.996278029, theta=-37.9132709 -> V=1.022224, theta=0.0
% INFO    : Bus 2361	: V=1.02134457, theta=-50.6109091 -> V=1.0079355, theta=0.0
% INFO    : Bus 2362	: V=1.02625055, theta=-37.4672845 -> V=1.022224, theta=0.0
% INFO    : Bus 2363	: V=1.02075785, theta=-10.1941743 -> V=1.0158755, theta=0.0
% INFO    : Bus 2364	: V=1.101, theta=-4.39337108 -> V=0.975, theta=0.0
% INFO    : Bus 2365	: V=1.103, theta=-4.48832836 -> V=0.975, theta=0.0
% INFO    : Bus 2366	: V=1.081, theta=-5.14917101 -> V=0.975, theta=0.0
% INFO    : Bus 2367	: V=1.102, theta=-4.7102527 -> V=0.975, theta=0.0
% INFO    : Bus 2368	: V=1.111, theta=-5.57952694 -> V=0.975, theta=0.0
% INFO    : Bus 2369	: V=1.08374751, theta=-6.42701392 -> V=1.0377785, theta=0.0
% INFO    : Bus 2370	: V=1.08376642, theta=-6.42695979 -> V=1.0377785, theta=0.0
% INFO    : Bus 2371	: V=1.08362527, theta=-6.43215681 -> V=1.0377785, theta=0.0
% INFO    : Bus 2372	: V=1.08375585, theta=-6.4290356 -> V=1.0377785, theta=0.0
% INFO    : Bus 2373	: V=1.08364678, theta=-6.44030158 -> V=1.0377785, theta=0.0
% INFO    : Bus 2374	: V=1.08381732, theta=-6.43453097 -> V=1.0377785, theta=0.0
% INFO    : Bus 2375	: V=1.03275805, theta=-8.94360259 -> V=1.0158755, theta=0.0
% INFO    : Bus 2376	: V=1.08364678, theta=-6.44030158 -> V=1.0377785, theta=0.0
% INFO    : Bus 2377	: V=1.01764974, theta=-62.6593432 -> V=1.0079355, theta=0.0
% INFO    : Bus 2378	: V=1.01798246, theta=-3.25916385 -> V=1.0158755, theta=0.0
% INFO    : Bus 2379	: V=1.02858537, theta=-61.993661 -> V=1.0079355, theta=0.0
% INFO    : Bus 2380	: V=0.999834468, theta=-66.3264085 -> V=1.0079355, theta=0.0
% INFO    : Bus 2381	: V=1.01328922, theta=-68.5920175 -> V=1.0079355, theta=0.0
% INFO    : Bus 2382	: V=1.01710326, theta=-62.681054 -> V=1.0079355, theta=0.0
% INFO    : Bus 2383	: V=1.03820935, theta=-62.0144227 -> V=1.0079355, theta=0.0
% INFO    : Bus 2384	: V=1.00493104, theta=-60.877406 -> V=1.0079355, theta=0.0
% INFO    : Bus 2385	: V=1.01838593, theta=-62.9429636 -> V=1.0079355, theta=0.0
% INFO    : Bus 2386	: V=1.00207273, theta=-60.3648531 -> V=1.0079355, theta=0.0
% INFO    : Bus 2387	: V=1.00361583, theta=-22.4259576 -> V=1.0158755, theta=0.0
% INFO    : Bus 2388	: V=0.97123039, theta=-55.6787397 -> V=1.0079355, theta=0.0
% INFO    : Bus 2389	: V=1.01993112, theta=-9.79473773 -> V=1.0158755, theta=0.0
% INFO    : Bus 2390	: V=1.03970445, theta=-27.4361127 -> V=1.0000025, theta=0.0
% INFO    : Bus 2391	: V=1.04879866, theta=-24.8935204 -> V=1.0000025, theta=0.0
% INFO    : Bus 2392	: V=1.04881683, theta=-24.8903856 -> V=1.0000025, theta=0.0
% INFO    : Bus 2393	: V=1.01212521, theta=-24.1877547 -> V=1.0000025, theta=0.0
% INFO    : Bus 2394	: V=1.02172249, theta=-23.6678246 -> V=1.0000025, theta=0.0
% INFO    : Bus 2395	: V=1.03771797, theta=-29.0011518 -> V=1.0000025, theta=0.0
% INFO    : Bus 2396	: V=1.03020244, theta=-23.2210597 -> V=1.0000025, theta=0.0
% INFO    : Bus 2397	: V=1.02770797, theta=-22.069821 -> V=1.0000025, theta=0.0
% INFO    : Bus 2398	: V=1.03144986, theta=-24.1033087 -> V=0.999999, theta=0.0
% INFO    : Bus 2399	: V=1.03243376, theta=-27.7877425 -> V=1.0000025, theta=0.0
% INFO    : Bus 2400	: V=1.06343672, theta=-9.12834448 -> V=1.046665, theta=0.0
% INFO    : Bus 2401	: V=1.05111874, theta=-30.9434885 -> V=1.0000025, theta=0.0
% INFO    : Bus 2402	: V=1.06166683, theta=-7.0675588 -> V=1.046665, theta=0.0
% INFO    : Bus 2403	: V=1.0616682, theta=-7.06712762 -> V=1.046665, theta=0.0
% INFO    : Bus 2404	: V=1.00182196, theta=-31.6028556 -> V=1.0000025, theta=0.0
% INFO    : Bus 2405	: V=1.03436738, theta=-41.9965131 -> V=1.027779, theta=0.0
% INFO    : Bus 2406	: V=1.01106298, theta=-31.4233065 -> V=1.0000025, theta=0.0
% INFO    : Bus 2407	: V=1.05405053, theta=-31.1013304 -> V=1.0000025, theta=0.0
% INFO    : Bus 2408	: V=1.05998813, theta=-15.78971 -> V=1.000001, theta=0.0
% INFO    : Bus 2409	: V=0.977768214, theta=-36.394044 -> V=1.0000005, theta=0.0
% INFO    : Bus 2410	: V=1.00287972, theta=-32.3294156 -> V=1.0000005, theta=0.0
% INFO    : Bus 2411	: V=0.978725725, theta=-17.7732414 -> V=0.999999, theta=0.0
% INFO    : Bus 2412	: V=1.06, theta=-15.7882156 -> V=1.000001, theta=0.0
% INFO    : Bus 2413	: V=0.994192189, theta=-24.1068246 -> V=1.015872, theta=0.0
% INFO    : Bus 2414	: V=0.999052565, theta=-54.6919308 -> V=1.0079355, theta=0.0
% INFO    : Bus 2415	: V=1.02433738, theta=-28.2484283 -> V=1.016666, theta=0.0
% INFO    : Bus 2416	: V=1.06759138, theta=-34.5054663 -> V=1.046665, theta=0.0
% INFO    : Bus 2417	: V=1.06758287, theta=-34.5053578 -> V=1.046665, theta=0.0
% INFO    : Bus 2418	: V=1.0333386, theta=-27.0453847 -> V=1.0000025, theta=0.0
% INFO    : Bus 2419	: V=1.07920222, theta=-13.0774521 -> V=1.044445, theta=0.0
% INFO    : Bus 2420	: V=1.02813725, theta=-9.53823979 -> V=0.999999, theta=0.0
% INFO    : Bus 2421	: V=1.02046611, theta=-3.33009115 -> V=1.0158755, theta=0.0
% INFO    : Bus 2422	: V=1.05229306, theta=-25.1068367 -> V=1.022224, theta=0.0
% INFO    : Bus 2423	: V=1.03730994, theta=-60.5859778 -> V=1.0079355, theta=0.0
% INFO    : Bus 2424	: V=1.05249355, theta=-54.571925 -> V=1.04444, theta=0.0
% INFO    : Bus 2425	: V=1.05275762, theta=-54.7072111 -> V=1.04444, theta=0.0
% INFO    : Bus 2426	: V=1.01973038, theta=-62.911448 -> V=1.0079355, theta=0.0
% INFO    : Bus 2427	: V=1.01966268, theta=-4.72489634 -> V=1.0158755, theta=0.0
% INFO    : Bus 2428	: V=1.07516686, theta=-0.686325605 -> V=1.0377785, theta=0.0
% INFO    : Bus 2429	: V=1.01545879, theta=-7.55814515 -> V=1.0158755, theta=0.0
% INFO    : Bus 2430	: V=1.01906319, theta=-7.24567203 -> V=1.0158755, theta=0.0
% INFO    : Bus 2431	: V=1.02304014, theta=-6.79762737 -> V=1.0158755, theta=0.0
% INFO    : Bus 2432	: V=1.06169209, theta=-2.30083599 -> V=1.0377785, theta=0.0
% INFO    : Bus 2433	: V=1.00686471, theta=-63.5548438 -> V=1.0079355, theta=0.0
% INFO    : Bus 2434	: V=1.0332274, theta=-64.8670698 -> V=1.0079355, theta=0.0
% INFO    : Bus 2435	: V=1.05643344, theta=-29.3362885 -> V=1.046665, theta=0.0
% INFO    : Bus 2436	: V=1.05588856, theta=-29.4362923 -> V=1.046665, theta=0.0
% INFO    : Bus 2437	: V=1.0352802, theta=-16.7821764 -> V=0.999999, theta=0.0
% INFO    : Bus 2438	: V=1.02961974, theta=-9.01532765 -> V=1.0158755, theta=0.0
% INFO    : Bus 2439	: V=1.02968827, theta=-9.01845999 -> V=1.0158755, theta=0.0
% INFO    : Bus 2440	: V=1.02542061, theta=-21.3668653 -> V=0.999999, theta=0.0
% INFO    : Bus 2441	: V=1.01520689, theta=-30.4521837 -> V=1.0000025, theta=0.0
% INFO    : Bus 2442	: V=1.01657179, theta=-61.3629218 -> V=1.0079355, theta=0.0
% INFO    : Bus 2443	: V=1.00149309, theta=-63.5314764 -> V=1.0079355, theta=0.0
% INFO    : Bus 2444	: V=1.00808628, theta=-60.8361814 -> V=1.0079355, theta=0.0
% INFO    : Bus 2445	: V=1.01261869, theta=-60.9996898 -> V=1.0079355, theta=0.0
% INFO    : Bus 2446	: V=1.02952339, theta=-19.4518142 -> V=1.0000025, theta=0.0
% INFO    : Bus 2447	: V=1.09173153, theta=-18.8892668 -> V=1.0, theta=0.0
% INFO    : Bus 2448	: V=1.0796865, theta=-18.1872541 -> V=1.044445, theta=0.0
% INFO    : Bus 2449	: V=1.01727532, theta=-58.8453479 -> V=1.0079355, theta=0.0
% INFO    : Bus 2450	: V=1.07029183, theta=-14.9429115 -> V=1.000001, theta=0.0
% INFO    : Bus 2451	: V=1.01378147, theta=-7.04119287 -> V=0.999999, theta=0.0
% INFO    : Bus 2452	: V=1.02476918, theta=-28.581286 -> V=1.0000025, theta=0.0
% INFO    : Bus 2453	: V=1.03543024, theta=-29.9132884 -> V=1.0000025, theta=0.0
% INFO    : Bus 2454	: V=1.0537744, theta=-31.8063282 -> V=1.046665, theta=0.0
% INFO    : Bus 2455	: V=1.08355219, theta=-23.0926901 -> V=1.044445, theta=0.0
% INFO    : Bus 2456	: V=1.01256337, theta=-12.3309324 -> V=1.0158755, theta=0.0
% INFO    : Bus 2457	: V=1.0314266, theta=-36.6171662 -> V=1.022224, theta=0.0
% INFO    : Bus 2458	: V=1.07795015, theta=-27.8120392 -> V=1.07237, theta=0.0
% INFO    : Bus 2459	: V=1.06674034, theta=-17.9703468 -> V=1.0000025, theta=0.0
% INFO    : Bus 2460	: V=1.09120959, theta=-12.6802864 -> V=1.045365, theta=0.0
% INFO    : Bus 2461	: V=0.999004229, theta=-21.6463597 -> V=1.015872, theta=0.0
% INFO    : Bus 2462	: V=1.01542268, theta=-30.7248564 -> V=1.0158755, theta=0.0
% INFO    : Bus 2463	: V=1.01391254, theta=-29.4619728 -> V=1.0000005, theta=0.0
% INFO    : Bus 2464	: V=0.999168676, theta=-51.8316291 -> V=1.022224, theta=0.0
% INFO    : Bus 2465	: V=1.04296485, theta=-23.7416929 -> V=0.9888895, theta=0.0
% INFO    : Bus 2466	: V=1.04180835, theta=-22.5108109 -> V=0.9888895, theta=0.0
% INFO    : Bus 2467	: V=1.05377904, theta=-21.1554702 -> V=1.05263, theta=0.0
% INFO    : Bus 2468	: V=1.03810262, theta=-40.2618959 -> V=1.027779, theta=0.0
% INFO    : Bus 2469	: V=1.05391437, theta=-40.5132264 -> V=1.046665, theta=0.0
% INFO    : Bus 2470	: V=1.07219871, theta=-33.4271773 -> V=1.073685, theta=0.0
% INFO    : Bus 2471	: V=1.02011858, theta=-27.2393479 -> V=1.0000025, theta=0.0
% INFO    : Bus 2472	: V=0.968786945, theta=-30.0316782 -> V=1.0147495, theta=0.0
% INFO    : Bus 2473	: V=1.01248856, theta=-23.2572467 -> V=1.015872, theta=0.0
% INFO    : Bus 2474	: V=1.01272993, theta=-23.257658 -> V=1.015872, theta=0.0
% INFO    : Bus 2475	: V=1.02660945, theta=-20.8505068 -> V=0.999999, theta=0.0
% INFO    : Bus 2476	: V=1.04366643, theta=-8.99162531 -> V=1.0158755, theta=0.0
% INFO    : Bus 2477	: V=1.01756744, theta=-9.51781237 -> V=0.999999, theta=0.0
% INFO    : Bus 2478	: V=1.01377052, theta=-27.5165421 -> V=1.0000025, theta=0.0
% INFO    : Bus 2479	: V=1.06456053, theta=-18.2568052 -> V=1.0000025, theta=0.0
% INFO    : Bus 2480	: V=0.992071246, theta=-21.6563329 -> V=1.015872, theta=0.0
% INFO    : Bus 2481	: V=1.0527271, theta=-20.6058905 -> V=1.0000025, theta=0.0
% INFO    : Bus 2482	: V=1.04826163, theta=-46.2370642 -> V=1.022594, theta=0.0
% INFO    : Bus 2483	: V=1.02992443, theta=-47.3778534 -> V=1.022224, theta=0.0
% INFO    : Bus 2484	: V=1.05139783, theta=-42.6611208 -> V=1.04444, theta=0.0
% INFO    : Bus 2485	: V=0.995896273, theta=-36.8766447 -> V=1.015872, theta=0.0
% INFO    : Bus 2486	: V=1.06553631, theta=-22.0529079 -> V=1.000001, theta=0.0
% INFO    : Bus 2487	: V=1.02225257, theta=-11.8468673 -> V=1.0158755, theta=0.0
% INFO    : Bus 2488	: V=1.04668385, theta=-27.9174735 -> V=1.0000025, theta=0.0
% INFO    : Bus 2489	: V=1.01313541, theta=-23.2068556 -> V=1.015872, theta=0.0
% INFO    : Bus 2490	: V=1.05381342, theta=-17.7302342 -> V=1.046665, theta=0.0
% INFO    : Bus 2491	: V=1.01107273, theta=-26.533135 -> V=1.0000025, theta=0.0
% INFO    : Bus 2492	: V=1.02503489, theta=-10.3685234 -> V=1.0158755, theta=0.0
% INFO    : Bus 2493	: V=1.02941584, theta=-24.1466211 -> V=1.0158755, theta=0.0
% INFO    : Bus 2494	: V=1.00466289, theta=-8.09559571 -> V=1.0158755, theta=0.0
% INFO    : Bus 2495	: V=1.02152606, theta=-16.4749919 -> V=1.015872, theta=0.0
% INFO    : Bus 2496	: V=1.02894846, theta=-34.7774726 -> V=1.027779, theta=0.0
% INFO    : Bus 2497	: V=0.953801889, theta=-8.90509974 -> V=0.9444445, theta=0.0
% INFO    : Bus 2498	: V=0.985191222, theta=-30.5375307 -> V=1.0000025, theta=0.0
% INFO    : Bus 2499	: V=1.01960143, theta=-28.8668024 -> V=1.0000025, theta=0.0
% INFO    : Bus 2500	: V=1.00824483, theta=-20.664349 -> V=1.015872, theta=0.0
% INFO    : Bus 2501	: V=1.02600763, theta=-29.0745871 -> V=1.0000025, theta=0.0
% INFO    : Bus 2502	: V=1.03798631, theta=-27.0711407 -> V=1.0000025, theta=0.0
% INFO    : Bus 2503	: V=1.06234979, theta=-22.2442363 -> V=1.044445, theta=0.0
% INFO    : Bus 2504	: V=1.04184729, theta=-26.3851333 -> V=1.0000025, theta=0.0
% INFO    : Bus 2505	: V=1.01831337, theta=-31.6464431 -> V=1.022224, theta=0.0
% INFO    : Bus 2506	: V=1.03067738, theta=-17.7560864 -> V=0.999999, theta=0.0
% INFO    : Bus 2507	: V=1.00869035, theta=-28.8762479 -> V=1.0000025, theta=0.0
% INFO    : Bus 2508	: V=1.01647868, theta=-2.34548321 -> V=1.0158755, theta=0.0
% INFO    : Bus 2509	: V=1.04503075, theta=-26.0765876 -> V=1.0000025, theta=0.0
% INFO    : Bus 2510	: V=1.06728721, theta=-19.579956 -> V=1.044445, theta=0.0
% INFO    : Bus 2511	: V=1.02113771, theta=-62.532734 -> V=1.0079355, theta=0.0
% INFO    : Bus 2512	: V=1.05428989, theta=-25.4348279 -> V=1.0000025, theta=0.0
% INFO    : Bus 2513	: V=1.03884309, theta=-26.5978725 -> V=1.0000025, theta=0.0
% INFO    : Bus 2514	: V=1.03411435, theta=-37.3470527 -> V=1.0000025, theta=0.0
% INFO    : Bus 2515	: V=1.05117401, theta=-37.3470527 -> V=1.000001, theta=0.0
% INFO    : Bus 2516	: V=1.04779352, theta=-24.6910422 -> V=1.0000025, theta=0.0
% INFO    : Bus 2517	: V=1.06805763, theta=-19.904896 -> V=1.044445, theta=0.0
% INFO    : Bus 2518	: V=1.07941239, theta=-15.0852997 -> V=1.078945, theta=0.0
% INFO    : Bus 2519	: V=1.03223459, theta=-21.058684 -> V=0.9888895, theta=0.0
% INFO    : Bus 2520	: V=1.03227293, theta=-21.060634 -> V=0.9888895, theta=0.0
% INFO    : Bus 2521	: V=1.01633207, theta=-26.5581676 -> V=1.0000025, theta=0.0
% INFO    : Bus 2522	: V=1.00575684, theta=-30.9423485 -> V=1.022224, theta=0.0
% INFO    : Bus 2523	: V=1.135, theta=-20.2296963 -> V=1.049058, theta=0.0
% INFO    : Bus 2524	: V=1.04282926, theta=-19.6465779 -> V=0.9888895, theta=0.0
% INFO    : Bus 2525	: V=0.996481915, theta=-33.7696674 -> V=1.0000005, theta=0.0
% INFO    : Bus 2526	: V=1.06738644, theta=-34.5738287 -> V=1.046665, theta=0.0
% INFO    : Bus 2527	: V=1.01772701, theta=-24.4197911 -> V=1.022224, theta=0.0
% INFO    : Bus 2528	: V=1.06602198, theta=-15.6067369 -> V=1.0000025, theta=0.0
% INFO    : Bus 2529	: V=0.993834863, theta=-24.7833759 -> V=1.0000025, theta=0.0
% INFO    : Bus 2530	: V=1.01012695, theta=-17.1596631 -> V=1.0000025, theta=0.0
% INFO    : Bus 2531	: V=1.028834, theta=-31.6380985 -> V=1.015872, theta=0.0
% INFO    : Bus 2532	: V=1.025, theta=-14.255217 -> V=1.0158755, theta=0.0
% INFO    : Bus 2533	: V=1.02356552, theta=-14.3488802 -> V=1.0158755, theta=0.0
% INFO    : Bus 2534	: V=1.04364809, theta=-29.5246587 -> V=1.046665, theta=0.0
% INFO    : Bus 2535	: V=1.04079249, theta=-31.8330501 -> V=1.046665, theta=0.0
% INFO    : Bus 2536	: V=1.00114317, theta=-33.1792062 -> V=1.0000005, theta=0.0
% INFO    : Bus 2537	: V=1.00141467, theta=-33.3644174 -> V=1.0000005, theta=0.0
% INFO    : Bus 2538	: V=1.03691279, theta=-23.9175788 -> V=0.999999, theta=0.0
% INFO    : Bus 2539	: V=1.03046505, theta=-23.5260897 -> V=0.999999, theta=0.0
% INFO    : Bus 2540	: V=1.03362363, theta=-17.1153943 -> V=1.0111115, theta=0.0
% INFO    : Bus 2541	: V=1.00892339, theta=-20.1390438 -> V=1.015872, theta=0.0
% INFO    : Bus 2542	: V=1.00339443, theta=-37.8839726 -> V=1.0000005, theta=0.0
% INFO    : Bus 2543	: V=1.00636947, theta=-37.8105496 -> V=1.0000005, theta=0.0
% INFO    : Bus 2544	: V=1.00693507, theta=-37.8604076 -> V=1.0000005, theta=0.0
% INFO    : Bus 2545	: V=1.03631721, theta=-25.6789822 -> V=1.0000025, theta=0.0
% INFO    : Bus 2546	: V=1.01608264, theta=-15.0643695 -> V=0.999999, theta=0.0
% INFO    : Bus 2547	: V=1.03440345, theta=-27.5929877 -> V=0.999999, theta=0.0
% INFO    : Bus 2548	: V=1.03531438, theta=-32.7350103 -> V=1.015872, theta=0.0
% INFO    : Bus 2549	: V=1.02804676, theta=-28.9194449 -> V=1.0233335, theta=0.0
% INFO    : Bus 2550	: V=1.03877161, theta=-29.7509308 -> V=1.046665, theta=0.0
% INFO    : Bus 2551	: V=1.03653583, theta=-19.5998843 -> V=1.0000025, theta=0.0
% INFO    : Bus 2552	: V=1.05140663, theta=-26.569231 -> V=1.0000025, theta=0.0
% INFO    : Bus 2553	: V=1.05840253, theta=-19.2286186 -> V=1.002284, theta=0.0
% INFO    : Bus 2554	: V=1.03844193, theta=-36.4056139 -> V=1.027779, theta=0.0
% INFO    : Bus 2555	: V=1.03455723, theta=-22.453592 -> V=1.0000025, theta=0.0
% INFO    : Bus 2556	: V=1.00167242, theta=-61.9823939 -> V=1.0079355, theta=0.0
% INFO    : Bus 2557	: V=1.03056642, theta=-41.2633818 -> V=1.027779, theta=0.0
% INFO    : Bus 2558	: V=1.013, theta=-8.18555582 -> V=0.999999, theta=0.0
% INFO    : Bus 2559	: V=0.991732262, theta=-22.6520548 -> V=1.0000025, theta=0.0
% INFO    : Bus 2560	: V=1.06153173, theta=-18.8707043 -> V=1.044445, theta=0.0
% INFO    : Bus 2561	: V=1.00214673, theta=-28.1512179 -> V=1.0000005, theta=0.0
% INFO    : Bus 2562	: V=1.02429822, theta=-39.6718696 -> V=1.022224, theta=0.0
% INFO    : Bus 2563	: V=1.01198766, theta=-64.3820091 -> V=1.0079355, theta=0.0
% INFO    : Bus 2564	: V=1.04488173, theta=-62.0169413 -> V=1.0079355, theta=0.0
% INFO    : Bus 2565	: V=1.04062165, theta=-22.1628735 -> V=1.0000025, theta=0.0
% INFO    : Bus 2566	: V=1.03355666, theta=-10.2403625 -> V=1.0158755, theta=0.0
% INFO    : Bus 2567	: V=1.07832788, theta=-5.70832094 -> V=1.0377785, theta=0.0
% INFO    : Bus 2568	: V=1.09473417, theta=-1.99945741 -> V=1.072365, theta=0.0
% INFO    : Bus 2569	: V=1.02410543, theta=-36.9080059 -> V=1.027779, theta=0.0
% INFO    : Bus 2570	: V=1.02430694, theta=-34.9002202 -> V=1.027779, theta=0.0
% INFO    : Bus 2571	: V=1.04425918, theta=-29.0287382 -> V=1.046665, theta=0.0
% INFO    : Bus 2572	: V=1.00580262, theta=-31.171573 -> V=1.0000005, theta=0.0
% INFO    : Bus 2573	: V=1.04697602, theta=-44.7662243 -> V=1.027779, theta=0.0
% INFO    : Bus 2574	: V=1.04998017, theta=-24.2956335 -> V=1.022224, theta=0.0
% INFO    : Bus 2575	: V=1.05394518, theta=-31.8650727 -> V=1.046665, theta=0.0
% INFO    : Bus 2576	: V=1.03465966, theta=-3.4083427 -> V=1.0158755, theta=0.0
% INFO    : Bus 2577	: V=0.955030493, theta=-7.82783494 -> V=0.9444445, theta=0.0
% INFO    : Bus 2578	: V=1.00264412, theta=-7.66150361 -> V=0.999999, theta=0.0
% INFO    : Bus 2579	: V=1.05536547, theta=-9.87849461 -> V=1.003335, theta=0.0
% INFO    : Bus 2580	: V=1.04605486, theta=-6.48083476 -> V=1.0111115, theta=0.0
% INFO    : Bus 2581	: V=1.03292672, theta=-52.8791855 -> V=1.022224, theta=0.0
% INFO    : Bus 2582	: V=1.00575549, theta=-43.5819161 -> V=1.022224, theta=0.0
% INFO    : Bus 2583	: V=1.06138726, theta=-23.3641413 -> V=1.016666, theta=0.0
% INFO    : Bus 2584	: V=1.05188463, theta=-18.6618667 -> V=1.0288895, theta=0.0
% INFO    : Bus 2585	: V=1.03756892, theta=-30.2929914 -> V=1.0000025, theta=0.0
% INFO    : Bus 2586	: V=1.01037775, theta=-27.4035316 -> V=1.022224, theta=0.0
% INFO    : Bus 2587	: V=1.0268097, theta=-37.2419547 -> V=1.022224, theta=0.0
% INFO    : Bus 2588	: V=1.03433444, theta=-13.8380929 -> V=0.999999, theta=0.0
% INFO    : Bus 2589	: V=0.991827542, theta=-34.0226074 -> V=1.0000005, theta=0.0
% INFO    : Bus 2590	: V=1.07760303, theta=-1.22118878 -> V=1.05263, theta=0.0
% INFO    : Bus 2591	: V=1.00297196, theta=-60.2634992 -> V=1.0079355, theta=0.0
% INFO    : Bus 2592	: V=1.00795217, theta=-14.5545204 -> V=0.975, theta=0.0
% INFO    : Bus 2593	: V=1.0336778, theta=-26.626501 -> V=1.022224, theta=0.0
% INFO    : Bus 2594	: V=1.02129371, theta=-59.609852 -> V=1.0079355, theta=0.0
% INFO    : Bus 2595	: V=1.05211563, theta=-55.9575521 -> V=1.04444, theta=0.0
% INFO    : Bus 2596	: V=1.04801198, theta=-24.3671487 -> V=1.022224, theta=0.0
% INFO    : Bus 2597	: V=1.02290812, theta=-23.1352172 -> V=1.022224, theta=0.0
% INFO    : Bus 2598	: V=1.04344877, theta=-17.7507238 -> V=1.0000025, theta=0.0
% INFO    : Bus 2599	: V=1.04295377, theta=-19.2624072 -> V=0.999999, theta=0.0
% INFO    : Bus 2600	: V=1.04345052, theta=-17.7502115 -> V=1.0000025, theta=0.0
% INFO    : Bus 2601	: V=1.00363281, theta=-69.6612965 -> V=1.0079355, theta=0.0
% INFO    : Bus 2602	: V=1.01413719, theta=-33.6674201 -> V=1.022224, theta=0.0
% INFO    : Bus 2603	: V=1.01864599, theta=-44.0366205 -> V=1.022224, theta=0.0
% INFO    : Bus 2604	: V=0.990136224, theta=-24.2778447 -> V=1.0158755, theta=0.0
% INFO    : Bus 2605	: V=1.03588019, theta=-45.7139422 -> V=1.022224, theta=0.0
% INFO    : Bus 2606	: V=1.06755204, theta=-38.3793695 -> V=1.07237, theta=0.0
% INFO    : Bus 2607	: V=1.06820079, theta=-38.3820631 -> V=1.07237, theta=0.0
% INFO    : Bus 2608	: V=1.02533184, theta=-34.4464883 -> V=1.022224, theta=0.0
% INFO    : Bus 2609	: V=1.03132753, theta=-33.7574199 -> V=1.022224, theta=0.0
% INFO    : Bus 2610	: V=1.02742485, theta=-23.3706661 -> V=1.0000025, theta=0.0
% INFO    : Bus 2611	: V=0.997705213, theta=-35.889216 -> V=1.015872, theta=0.0
% INFO    : Bus 2612	: V=1.01946141, theta=-30.5070454 -> V=1.0000025, theta=0.0
% INFO    : Bus 2613	: V=1.03692815, theta=-37.1554775 -> V=1.027779, theta=0.0
% INFO    : Bus 2614	: V=1.00634485, theta=-40.9413867 -> V=1.0000005, theta=0.0
% INFO    : Bus 2615	: V=1.01221725, theta=-25.2956269 -> V=1.000001, theta=0.0
% INFO    : Bus 2616	: V=1.01323751, theta=-45.4366981 -> V=1.022224, theta=0.0
% INFO    : Bus 2617	: V=1.03552864, theta=-17.9864463 -> V=1.0377785, theta=0.0
% INFO    : Bus 2618	: V=1.00615908, theta=-24.1238805 -> V=1.0158755, theta=0.0
% INFO    : Bus 2619	: V=1.0047641, theta=-27.323212 -> V=1.0000025, theta=0.0
% INFO    : Bus 2620	: V=1.0133306, theta=-40.7717377 -> V=1.022224, theta=0.0
% INFO    : Bus 2621	: V=1.0123603, theta=-7.83615573 -> V=1.0158755, theta=0.0
% INFO    : Bus 2622	: V=1.04068459, theta=-20.3921302 -> V=1.0000025, theta=0.0
% INFO    : Bus 2623	: V=1.04566243, theta=-32.4508244 -> V=1.022224, theta=0.0
% INFO    : Bus 2624	: V=1.04659217, theta=-24.9710498 -> V=1.0111115, theta=0.0
% INFO    : Bus 2625	: V=1.05058794, theta=-7.48730504 -> V=1.000001, theta=0.0
% INFO    : Bus 2626	: V=1.07022555, theta=-4.04485346 -> V=1.0288895, theta=0.0
% INFO    : Bus 2627	: V=0.994, theta=-25.5163621 -> V=1.0158755, theta=0.0
% INFO    : Bus 2628	: V=0.985133388, theta=-24.1740007 -> V=1.0000025, theta=0.0
% INFO    : Bus 2629	: V=1.00474632, theta=-17.9277654 -> V=1.0158755, theta=0.0
% INFO    : Bus 2630	: V=0.994482999, theta=-36.3535812 -> V=1.022224, theta=0.0
% INFO    : Bus 2631	: V=1.0223162, theta=-26.206356 -> V=1.0000025, theta=0.0
% INFO    : Bus 2632	: V=1.04487719, theta=-25.967624 -> V=1.0000025, theta=0.0
% INFO    : Bus 2633	: V=1.04951183, theta=-10.6408721 -> V=1.0158755, theta=0.0
% INFO    : Bus 2634	: V=1.04661234, theta=-10.6432102 -> V=1.0158755, theta=0.0
% INFO    : Bus 2635	: V=1.07747419, theta=-7.18149266 -> V=1.0377785, theta=0.0
% INFO    : Bus 2636	: V=1.02293738, theta=-10.2387146 -> V=1.0158755, theta=0.0
% INFO    : Bus 2637	: V=1.01191214, theta=-17.6153913 -> V=1.0158755, theta=0.0
% INFO    : Bus 2638	: V=0.997298576, theta=-32.1219223 -> V=1.0000025, theta=0.0
% INFO    : Bus 2639	: V=1.03659924, theta=-36.0593711 -> V=1.022224, theta=0.0
% INFO    : Bus 2640	: V=1.03108486, theta=-31.1807546 -> V=1.0000025, theta=0.0
% INFO    : Bus 2641	: V=1.06912373, theta=-28.9184696 -> V=0.975, theta=0.0
% INFO    : Bus 2642	: V=1.03299714, theta=-25.3943484 -> V=1.0000025, theta=0.0
% INFO    : Bus 2643	: V=1.02908602, theta=-21.9931091 -> V=1.0000025, theta=0.0
% INFO    : Bus 2644	: V=1.029, theta=-21.9842465 -> V=1.0000025, theta=0.0
% INFO    : Bus 2645	: V=1.058, theta=-16.0765081 -> V=1.0000025, theta=0.0
% INFO    : Bus 2646	: V=1.08984234, theta=-25.966879 -> V=1.0042125, theta=0.0
% INFO    : Bus 2647	: V=1.09687761, theta=-17.1727182 -> V=0.975, theta=0.0
% INFO    : Bus 2648	: V=1.09684179, theta=-17.1746064 -> V=1.0, theta=0.0
% INFO    : Bus 2649	: V=0.9967277, theta=-14.1005366 -> V=1.0158755, theta=0.0
% INFO    : Bus 2650	: V=1.02917078, theta=-28.88808 -> V=1.022224, theta=0.0
% INFO    : Bus 2651	: V=1.03796976, theta=-28.8822769 -> V=1.0000025, theta=0.0
% INFO    : Bus 2652	: V=1.067, theta=-18.0172434 -> V=1.0000025, theta=0.0
% INFO    : Bus 2653	: V=1.07381313, theta=-15.6991998 -> V=1.044445, theta=0.0
% INFO    : Bus 2654	: V=1.04111675, theta=-25.6496264 -> V=1.015874, theta=0.0
% INFO    : Bus 2655	: V=1.02704705, theta=-22.4052682 -> V=0.9888895, theta=0.0
% INFO    : Bus 2656	: V=1.03852505, theta=-21.0003599 -> V=0.9888895, theta=0.0
% INFO    : Bus 2657	: V=1.01573672, theta=-24.9636824 -> V=1.0000025, theta=0.0
% INFO    : Bus 2658	: V=0.993008894, theta=-15.175731 -> V=1.015872, theta=0.0
% INFO    : Bus 2659	: V=1.018, theta=-7.9132343 -> V=0.999999, theta=0.0
% INFO    : Bus 2660	: V=1.018, theta=-12.8325005 -> V=1.015872, theta=0.0
% INFO    : Bus 2661	: V=1.04172415, theta=-8.32469352 -> V=1.046665, theta=0.0
% INFO    : Bus 2662	: V=1.10047386, theta=-19.1744103 -> V=0.975, theta=0.0
% INFO    : Bus 2663	: V=1.048, theta=-19.1904055 -> V=0.975, theta=0.0
% INFO    : Bus 2664	: V=1.098, theta=-17.3383929 -> V=0.975, theta=0.0
% INFO    : Bus 2665	: V=1.048, theta=-19.1904055 -> V=1.0000025, theta=0.0
% INFO    : Bus 2666	: V=1.09853284, theta=-17.3718839 -> V=1.0, theta=0.0
% INFO    : Bus 2667	: V=1.01992029, theta=-49.9801157 -> V=1.0079355, theta=0.0
% INFO    : Bus 2668	: V=1.0326493, theta=-48.8190851 -> V=1.022224, theta=0.0
% INFO    : Bus 2669	: V=0.55906877, theta=-3.21975792 -> V=0.825, theta=0.0
% INFO    : Bus 2670	: V=1.01582192, theta=-3.21975792 -> V=1.0158755, theta=0.0
% INFO    : Bus 2671	: V=1.02906343, theta=-19.2097713 -> V=1.0158755, theta=0.0
% INFO    : Bus 2672	: V=1.02906343, theta=-19.2097713 -> V=1.0158755, theta=0.0
% INFO    : Bus 2673	: V=1.01437532, theta=-23.6541802 -> V=1.0000025, theta=0.0
% INFO    : Bus 2674	: V=0.994552692, theta=-53.7170704 -> V=1.0079355, theta=0.0
% INFO    : Bus 2675	: V=1.01689586, theta=-18.7538195 -> V=1.0158755, theta=0.0
% INFO    : Bus 2676	: V=1.03429166, theta=-14.7548346 -> V=1.0377785, theta=0.0
% INFO    : Bus 2677	: V=1.00594585, theta=-19.8105923 -> V=1.0158755, theta=0.0
% INFO    : Bus 2678	: V=1.03377159, theta=-12.7382431 -> V=0.999999, theta=0.0
% INFO    : Bus 2679	: V=1.04669303, theta=-8.98123864 -> V=1.0111115, theta=0.0
% INFO    : Bus 2680	: V=1.00310831, theta=-21.5813219 -> V=1.0000025, theta=0.0
% INFO    : Bus 2681	: V=1.05294589, theta=-24.9070735 -> V=1.022224, theta=0.0
% INFO    : Bus 2682	: V=1.04785139, theta=-30.5700871 -> V=1.046665, theta=0.0
% INFO    : Bus 2683	: V=1.02682836, theta=-36.6732941 -> V=1.027779, theta=0.0
% INFO    : Bus 2684	: V=1.0247862, theta=-23.5134824 -> V=1.0158755, theta=0.0
% INFO    : Bus 2685	: V=1.04326439, theta=-18.6316002 -> V=1.0377785, theta=0.0
% INFO    : Bus 2686	: V=1.01025814, theta=-27.5716863 -> V=1.000001, theta=0.0
% INFO    : Bus 2687	: V=1.00826009, theta=-16.0350036 -> V=1.0158755, theta=0.0
% INFO    : Bus 2688	: V=1.05287684, theta=-27.1331314 -> V=1.033333, theta=0.0
% INFO    : Bus 2689	: V=1.0052093, theta=-34.7448146 -> V=1.0000005, theta=0.0
% INFO    : Bus 2690	: V=1.01827116, theta=-25.1674073 -> V=1.0158755, theta=0.0
% INFO    : Bus 2691	: V=1.03493365, theta=-34.7075917 -> V=1.022224, theta=0.0
% INFO    : Bus 2692	: V=1.041544, theta=-33.3024364 -> V=1.022224, theta=0.0
% INFO    : Bus 2693	: V=1.05438231, theta=-30.0562949 -> V=1.046665, theta=0.0
% INFO    : Bus 2694	: V=0.983804297, theta=-28.000894 -> V=1.015872, theta=0.0
% INFO    : Bus 2695	: V=1.0, theta=-35.3716603 -> V=1.0000005, theta=0.0
% INFO    : Bus 2696	: V=1.01809226, theta=-18.244307 -> V=1.0158755, theta=0.0
% INFO    : Bus 2697	: V=1.04074404, theta=-33.0751716 -> V=1.022224, theta=0.0
% INFO    : Bus 2698	: V=1.06349549, theta=-29.3699134 -> V=1.027779, theta=0.0
% INFO    : Bus 2699	: V=1.04313405, theta=-58.4406384 -> V=1.0079355, theta=0.0
% INFO    : Bus 2700	: V=1.02483697, theta=-19.7511643 -> V=1.015872, theta=0.0
% INFO    : Bus 2701	: V=1.0428701, theta=-29.3852843 -> V=1.046665, theta=0.0
% INFO    : Bus 2702	: V=1.00361549, theta=-32.0684695 -> V=1.0000005, theta=0.0
% INFO    : Bus 2703	: V=1.02896665, theta=-10.1864653 -> V=0.999999, theta=0.0
% INFO    : Bus 2704	: V=1.05116936, theta=-7.06488143 -> V=1.0111115, theta=0.0
% INFO    : Bus 2705	: V=1.05398146, theta=-21.6784644 -> V=1.001564, theta=0.0
% INFO    : Bus 2706	: V=1.04770295, theta=-23.0685991 -> V=0.999999, theta=0.0
% INFO    : Bus 2707	: V=1.03466618, theta=-16.6809519 -> V=1.0111115, theta=0.0
% INFO    : Bus 2708	: V=1.00861062, theta=-25.3487224 -> V=1.015872, theta=0.0
% INFO    : Bus 2709	: V=1.00588953, theta=-23.2132051 -> V=1.015872, theta=0.0
% INFO    : Bus 2710	: V=1.04829469, theta=-15.4953563 -> V=1.033334, theta=0.0
% INFO    : Bus 2711	: V=1.0145235, theta=-39.122426 -> V=1.027779, theta=0.0
% INFO    : Bus 2712	: V=1.04507305, theta=-26.465825 -> V=1.0111115, theta=0.0
% INFO    : Bus 2713	: V=1.07108162, theta=-9.76532646 -> V=1.0377785, theta=0.0
% INFO    : Bus 2714	: V=1.08606886, theta=-5.83991374 -> V=1.072365, theta=0.0
% INFO    : Bus 2715	: V=1.02432556, theta=-43.5822071 -> V=1.022224, theta=0.0
% INFO    : Bus 2716	: V=1.02383625, theta=-32.0478425 -> V=1.022224, theta=0.0
% INFO    : Bus 2717	: V=1.01551595, theta=-26.0315357 -> V=1.0000025, theta=0.0
% INFO    : Bus 2718	: V=1.0149601, theta=-30.2189867 -> V=1.0000025, theta=0.0
% INFO    : Bus 2719	: V=1.04961084, theta=-22.0702011 -> V=1.016666, theta=0.0
% INFO    : Bus 2720	: V=1.0647088, theta=-17.5972496 -> V=0.9888895, theta=0.0
% INFO    : Bus 2721	: V=1.08120714, theta=-14.7448043 -> V=1.05263, theta=0.0
% INFO    : Bus 2722	: V=1.00867948, theta=-59.7658196 -> V=1.0079355, theta=0.0
% INFO    : Bus 2723	: V=1.00397608, theta=-31.7522337 -> V=1.0000025, theta=0.0
% INFO    : Bus 2724	: V=1.03435005, theta=-33.0173878 -> V=1.027779, theta=0.0
% INFO    : Bus 2725	: V=1.05707465, theta=-29.5067381 -> V=1.046665, theta=0.0
% INFO    : Bus 2726	: V=1.01374194, theta=-6.63560691 -> V=1.0158755, theta=0.0
% INFO    : Bus 2727	: V=1.05515354, theta=-15.9200417 -> V=1.033334, theta=0.0
% INFO    : Bus 2728	: V=1.06801702, theta=-21.7249267 -> V=1.000001, theta=0.0
% INFO    : Bus 2729	: V=1.03437845, theta=-36.3177676 -> V=1.022224, theta=0.0
% INFO    : Bus 2730	: V=1.05212462, theta=-14.4705739 -> V=1.003299, theta=0.0
% INFO    : Bus 2731	: V=1.02975653, theta=-38.7128838 -> V=1.022224, theta=0.0
% INFO    : Bus 2732	: V=0.978190677, theta=-36.2913975 -> V=1.0000005, theta=0.0
% INFO    : Bus 2733	: V=1.0298638, theta=-36.704597 -> V=1.027779, theta=0.0
% INFO    : Bus 2734	: V=1.053, theta=-18.5607898 -> V=1.000001, theta=0.0
% INFO    : Bus 2735	: V=1.01896669, theta=-25.2909435 -> V=1.0158755, theta=0.0
% INFO    : Bus 2736	: V=1.03430454, theta=-34.4794687 -> V=1.027779, theta=0.0
% INFO    : Bus 2737	: V=1.03156187, theta=-34.4432503 -> V=1.027779, theta=0.0
% INFO    : Bus 2738	: V=1.04866742, theta=-30.2683358 -> V=1.0000025, theta=0.0
% INFO    : Bus 2739	: V=1.01478875, theta=-6.88694313 -> V=0.999999, theta=0.0
% INFO    : Bus 2740	: V=1.03816215, theta=-29.3564881 -> V=1.022224, theta=0.0
% INFO    : Bus 2741	: V=1.03678322, theta=-29.4372515 -> V=1.022224, theta=0.0
% INFO    : Bus 2742	: V=0.992937737, theta=-25.76392 -> V=1.0158755, theta=0.0
% INFO    : Bus 2743	: V=1.00070112, theta=-12.1069718 -> V=1.0158755, theta=0.0
% INFO    : Bus 2744	: V=1.06871848, theta=-4.49163357 -> V=1.0377785, theta=0.0
% INFO    : Bus 2745	: V=1.05429952, theta=-16.8063272 -> V=0.999999, theta=0.0
% INFO    : Bus 2746	: V=1.01284372, theta=-13.6430734 -> V=1.015872, theta=0.0
% INFO    : Bus 2747	: V=1.02958304, theta=-20.3461733 -> V=1.000001, theta=0.0
% INFO    : Bus 2748	: V=1.06496361, theta=-15.4852362 -> V=1.000001, theta=0.0
% INFO    : Bus 2749	: V=1.09002548, theta=-14.4250534 -> V=1.04532, theta=0.0
% INFO    : Bus 2750	: V=1.0178675, theta=-35.2241574 -> V=1.022224, theta=0.0
% INFO    : Bus 2751	: V=1.01497453, theta=-36.349013 -> V=1.0000005, theta=0.0
% INFO    : Bus 2752	: V=1.0395923, theta=-27.4670729 -> V=1.0000025, theta=0.0
% INFO    : Bus 2753	: V=1.03847956, theta=-17.7590686 -> V=0.999999, theta=0.0
% INFO    : Bus 2754	: V=1.06804762, theta=-14.0882666 -> V=1.0111115, theta=0.0
% INFO    : Bus 2755	: V=1.03454907, theta=-38.2040586 -> V=1.0040855, theta=0.0
% INFO    : Bus 2756	: V=0.999163588, theta=-14.9090915 -> V=0.999999, theta=0.0
% INFO    : Bus 2757	: V=1.00636911, theta=-37.8105423 -> V=1.0000005, theta=0.0
% INFO    : Bus 2758	: V=1.02782832, theta=-2.28403583 -> V=1.0158755, theta=0.0
% INFO    : Bus 2759	: V=1.03886609, theta=-28.7185606 -> V=1.027779, theta=0.0
% INFO    : Bus 2760	: V=0.995882547, theta=-31.1105968 -> V=1.0000005, theta=0.0
% INFO    : Bus 2761	: V=1.04182742, theta=-8.9520339 -> V=1.0000025, theta=0.0
% INFO    : Bus 2762	: V=1.06177333, theta=-4.51045703 -> V=1.0377785, theta=0.0
% INFO    : Bus 2763	: V=1.07653474, theta=-1.65398085 -> V=1.072365, theta=0.0
% INFO    : Bus 2764	: V=1.03409169, theta=-14.3486073 -> V=0.999999, theta=0.0
% INFO    : Bus 2765	: V=1.12305059, theta=0.172660556 -> V=1.0416705, theta=0.0
% INFO    : Bus 2766	: V=1.03042074, theta=-23.7451218 -> V=1.0000025, theta=0.0
% INFO    : Bus 2767	: V=1.0459354, theta=-28.1057249 -> V=1.0000025, theta=0.0
% INFO    : Bus 2768	: V=0.936303853, theta=-19.2721913 -> V=0.975, theta=0.0
% INFO    : Bus 2769	: V=1.03181807, theta=-22.2860696 -> V=1.022224, theta=0.0
% INFO    : Bus 2770	: V=1.06289187, theta=-18.9628882 -> V=1.04444, theta=0.0
% INFO    : Bus 2771	: V=1.08360776, theta=-14.3470564 -> V=1.07237, theta=0.0
% INFO    : Bus 2772	: V=1.02235898, theta=-37.8738236 -> V=1.027779, theta=0.0
% INFO    : Bus 2773	: V=1.00624963, theta=-15.2463711 -> V=1.0158755, theta=0.0
% INFO    : Bus 2774	: V=1.0382207, theta=-12.8300556 -> V=0.999999, theta=0.0
% INFO    : Bus 2775	: V=1.0246533, theta=-9.92934774 -> V=1.0111115, theta=0.0
% INFO    : Bus 2776	: V=1.0184155, theta=-13.7923412 -> V=1.0158755, theta=0.0
% INFO    : Bus 2777	: V=1.04531581, theta=-10.9370973 -> V=1.0377785, theta=0.0
% INFO    : Bus 2778	: V=1.03474406, theta=-36.9640889 -> V=1.0000025, theta=0.0
% INFO    : Bus 2779	: V=1.03199905, theta=-21.7408699 -> V=1.0000025, theta=0.0
% INFO    : Bus 2780	: V=1.04847229, theta=-23.293587 -> V=1.0000025, theta=0.0
% INFO    : Bus 2781	: V=1.07566703, theta=-18.8571668 -> V=1.044445, theta=0.0
% INFO    : Bus 2782	: V=1.08840221, theta=-18.2787524 -> V=1.078945, theta=0.0
% INFO    : Bus 2783	: V=1.04085402, theta=-36.1542645 -> V=1.027779, theta=0.0
% INFO    : Bus 2784	: V=1.05332268, theta=-54.4300492 -> V=1.04444, theta=0.0
% INFO    : Bus 2785	: V=1.05684211, theta=-48.9275377 -> V=1.07213, theta=0.0
% INFO    : Bus 2786	: V=1.05556089, theta=-51.0235505 -> V=1.071505, theta=0.0
% INFO    : Bus 2787	: V=1.01343469, theta=-52.2764644 -> V=1.0079355, theta=0.0
% INFO    : Bus 2788	: V=1.05094966, theta=-24.7534535 -> V=1.0000025, theta=0.0
% INFO    : Bus 2789	: V=1.04247055, theta=-11.9745635 -> V=1.0158755, theta=0.0
% INFO    : Bus 2790	: V=1.03900973, theta=-26.0960797 -> V=1.0000025, theta=0.0
% INFO    : Bus 2791	: V=1.06717601, theta=-21.0434152 -> V=1.044445, theta=0.0
% INFO    : Bus 2792	: V=1.0366787, theta=-20.7940522 -> V=0.999999, theta=0.0
% INFO    : Bus 2793	: V=1.03466034, theta=-34.4570166 -> V=1.027779, theta=0.0
% INFO    : Bus 2794	: V=1.0448731, theta=-29.9468356 -> V=1.046665, theta=0.0
% INFO    : Bus 2795	: V=1.05782781, theta=-30.8864869 -> V=1.046665, theta=0.0
% INFO    : Bus 2796	: V=1.05992836, theta=-19.0442002 -> V=1.016666, theta=0.0
% INFO    : Bus 2797	: V=1.05805343, theta=-17.0298184 -> V=1.022223, theta=0.0
% INFO    : Bus 2798	: V=1.05345601, theta=-11.3579288 -> V=1.05263, theta=0.0
% INFO    : Bus 2799	: V=1.02908506, theta=-18.0859805 -> V=0.999999, theta=0.0
% INFO    : Bus 2800	: V=1.02288693, theta=-33.1321028 -> V=1.022224, theta=0.0
% INFO    : Bus 2801	: V=0.998892273, theta=-28.1596586 -> V=1.0000025, theta=0.0
% INFO    : Bus 2802	: V=1.01709207, theta=-31.2923026 -> V=1.0000005, theta=0.0
% INFO    : Bus 2803	: V=0.995216526, theta=-17.3500271 -> V=1.0000015, theta=0.0
% INFO    : Bus 2804	: V=0.994187146, theta=-17.1831425 -> V=1.0000015, theta=0.0
% INFO    : Bus 2805	: V=1.0653087, theta=-20.218975 -> V=1.022222, theta=0.0
% INFO    : Bus 2806	: V=1.05900379, theta=-16.9768852 -> V=0.9888895, theta=0.0
% INFO    : Bus 2807	: V=1.02690247, theta=-29.8777592 -> V=1.0000025, theta=0.0
% INFO    : Bus 2808	: V=1.00332999, theta=-61.885536 -> V=1.0079355, theta=0.0
% INFO    : Bus 2809	: V=1.03789311, theta=-46.872013 -> V=1.022224, theta=0.0
% INFO    : Bus 2810	: V=1.05389447, theta=-42.5502223 -> V=1.04444, theta=0.0
% INFO    : Bus 2811	: V=1.00852086, theta=-24.6059563 -> V=1.0000025, theta=0.0
% INFO    : Bus 2812	: V=1.01999603, theta=-46.9458546 -> V=1.022224, theta=0.0
% INFO    : Bus 2813	: V=1.01014059, theta=-13.7636003 -> V=0.984126, theta=0.0
% INFO    : Bus 2814	: V=1.04283539, theta=-24.697748 -> V=1.000001, theta=0.0
% INFO    : Bus 2815	: V=1.05489967, theta=-19.8498117 -> V=1.044445, theta=0.0
% INFO    : Bus 2816	: V=1.05545754, theta=-15.770923 -> V=1.000001, theta=0.0
% INFO    : Bus 2817	: V=1.03717252, theta=-21.1209384 -> V=1.0000025, theta=0.0
% INFO    : Bus 2818	: V=1.05539639, theta=-31.4907992 -> V=1.0000025, theta=0.0
% INFO    : Bus 2819	: V=1.03152359, theta=-3.60043527 -> V=1.0158755, theta=0.0
% INFO    : Bus 2820	: V=1.08185672, theta=0.701083374 -> V=1.0389585, theta=0.0
% INFO    : Bus 2821	: V=1.08177311, theta=0.699731741 -> V=1.0389135, theta=0.0
% INFO    : Bus 2822	: V=1.0409801, theta=-47.1839093 -> V=1.022224, theta=0.0
% INFO    : Bus 2823	: V=1.01500726, theta=-37.8068151 -> V=1.0000025, theta=0.0
% INFO    : Bus 2824	: V=1.01440487, theta=-23.9079051 -> V=1.0000025, theta=0.0
% INFO    : Bus 2825	: V=1.04688496, theta=-19.8021326 -> V=1.046665, theta=0.0
% INFO    : Bus 2826	: V=1.03330209, theta=-20.7006141 -> V=0.999999, theta=0.0
% INFO    : Bus 2827	: V=1.03106018, theta=-17.7237022 -> V=1.0111115, theta=0.0
% INFO    : Bus 2828	: V=1.01127688, theta=-43.0245579 -> V=1.022224, theta=0.0
% INFO    : Bus 2829	: V=1.02042478, theta=-24.2085147 -> V=1.022224, theta=0.0
% INFO    : Bus 2830	: V=1.02708156, theta=-21.5462835 -> V=0.9888895, theta=0.0
% INFO    : Bus 2831	: V=1.07493171, theta=-3.23795493 -> V=0.9894695, theta=0.0
% INFO    : Bus 2832	: V=1.07945137, theta=-1.11963008 -> V=1.05263, theta=0.0
% INFO    : Bus 2833	: V=1.01, theta=-34.8036961 -> V=1.0000005, theta=0.0
% INFO    : Bus 2834	: V=0.984441578, theta=-27.9630929 -> V=1.015872, theta=0.0
% INFO    : Bus 2835	: V=1.03938063, theta=-26.5681781 -> V=1.0000025, theta=0.0
% INFO    : Bus 2836	: V=1.05432015, theta=-25.42082 -> V=1.0000025, theta=0.0
% INFO    : Bus 2837	: V=1.03533419, theta=-27.6913855 -> V=1.0000025, theta=0.0
% INFO    : Bus 2838	: V=1.05551845, theta=-14.2235538 -> V=1.033334, theta=0.0
% INFO    : Bus 2839	: V=1.03253907, theta=-14.6853229 -> V=0.999999, theta=0.0
% INFO    : Bus 2840	: V=1.03483141, theta=-23.4774228 -> V=1.022224, theta=0.0
% INFO    : Bus 2841	: V=1.02925742, theta=-10.8887983 -> V=1.0158755, theta=0.0
% INFO    : Bus 2842	: V=1.03813934, theta=-61.648981 -> V=1.0079355, theta=0.0
% INFO    : Bus 2843	: V=0.985609823, theta=-36.1895389 -> V=1.022224, theta=0.0
% INFO    : Bus 2844	: V=1.01925558, theta=-30.9069613 -> V=1.0000005, theta=0.0
% INFO    : Bus 2845	: V=1.01859254, theta=-23.2926991 -> V=0.999999, theta=0.0
% INFO    : Bus 2846	: V=1.0208442, theta=-31.9083794 -> V=1.000001, theta=0.0
% INFO    : Bus 2847	: V=0.997581953, theta=-31.8543218 -> V=1.015872, theta=0.0
% INFO    : Bus 2848	: V=1.01588467, theta=-26.4765989 -> V=1.046665, theta=0.0
% INFO    : Bus 2849	: V=1.09063448, theta=-25.3916439 -> V=1.073685, theta=0.0
% INFO    : Bus 2850	: V=1.01645387, theta=-13.1902569 -> V=0.999999, theta=0.0
% INFO    : Bus 2851	: V=1.05417008, theta=-31.8098355 -> V=1.046665, theta=0.0
% INFO    : Bus 2852	: V=1.06637021, theta=-34.7201862 -> V=1.046665, theta=0.0
% INFO    : Bus 2853	: V=1.00067938, theta=-36.8724212 -> V=1.0000005, theta=0.0
% INFO    : Bus 2854	: V=1.02447508, theta=-9.8530708 -> V=0.999999, theta=0.0
% INFO    : Bus 2855	: V=1.04642269, theta=-7.57593981 -> V=1.0111115, theta=0.0
% INFO    : Bus 2856	: V=1.05062493, theta=-25.30845 -> V=1.0000025, theta=0.0
% INFO    : Bus 2857	: V=1.04531572, theta=-60.0172893 -> V=1.0079355, theta=0.0
% INFO    : Bus 2858	: V=1.03931581, theta=-27.760328 -> V=1.0000025, theta=0.0
% INFO    : Bus 2859	: V=1.03949997, theta=-27.6801235 -> V=1.0000025, theta=0.0
% INFO    : Bus 2860	: V=1.08790422, theta=-23.3192711 -> V=1.044445, theta=0.0
% INFO    : Bus 2861	: V=1.04043524, theta=-27.3931856 -> V=1.0000025, theta=0.0
% INFO    : Bus 2862	: V=1.01963067, theta=-18.6999154 -> V=1.015872, theta=0.0
% INFO    : Bus 2863	: V=1.05085402, theta=-49.2960373 -> V=1.022224, theta=0.0
% INFO    : Bus 2864	: V=1.04636956, theta=-45.7603765 -> V=1.04444, theta=0.0
% INFO    : Bus 2865	: V=1.04673094, theta=-11.9071511 -> V=1.001069, theta=0.0
% INFO    : Bus 2866	: V=1.04533818, theta=-11.913365 -> V=1.000379, theta=0.0
% INFO    : Bus 2867	: V=1.03787845, theta=-11.9990936 -> V=0.999999, theta=0.0
% INFO    : Bus 2868	: V=1.01068241, theta=-34.8319152 -> V=1.022224, theta=0.0
% INFO    : Bus 2869	: V=1.02508524, theta=-31.1568572 -> V=1.000001, theta=0.0
% INFO    : Bus 2870	: V=0.990516475, theta=-26.4382023 -> V=1.0158755, theta=0.0
% INFO    : Bus 2871	: V=0.995397207, theta=-39.2626308 -> V=1.0000005, theta=0.0
% INFO    : Bus 2872	: V=0.984300582, theta=-49.5772184 -> V=1.0211205, theta=0.0
% INFO    : Bus 2873	: V=1.01801103, theta=-22.4388002 -> V=1.0158755, theta=0.0
% INFO    : Bus 2874	: V=1.05100273, theta=-39.8084505 -> V=1.027779, theta=0.0
% INFO    : Bus 2875	: V=1.038878, theta=-8.68893331 -> V=1.0000025, theta=0.0
% INFO    : Bus 2876	: V=0.999790573, theta=-51.4670796 -> V=1.022224, theta=0.0
% INFO    : Bus 2877	: V=1.03166374, theta=-17.9470075 -> V=1.015872, theta=0.0
% INFO    : Bus 2878	: V=1.00094245, theta=-7.11564603 -> V=1.0158755, theta=0.0
% INFO    : Bus 2879	: V=1.04565414, theta=-27.6532056 -> V=1.022224, theta=0.0
% INFO    : Bus 2880	: V=1.04360525, theta=-11.2097063 -> V=1.0111115, theta=0.0
% INFO    : Bus 2881	: V=1.03624878, theta=-28.3994665 -> V=1.0000025, theta=0.0
% INFO    : Bus 2882	: V=0.977332096, theta=-28.4861134 -> V=1.0158755, theta=0.0
% INFO    : Bus 2883	: V=1.01045145, theta=-17.5300263 -> V=0.999999, theta=0.0
% INFO    : Bus 2884	: V=1.03482174, theta=-3.33061272 -> V=1.0158755, theta=0.0
% INFO    : Bus 2885	: V=1.02257697, theta=-10.3554397 -> V=0.999999, theta=0.0
% INFO    : Bus 2886	: V=1.03627046, theta=-31.0255303 -> V=1.0000025, theta=0.0
% INFO    : Bus 2887	: V=0.989099003, theta=-22.7938529 -> V=1.015872, theta=0.0
% INFO    : Bus 2888	: V=1.01121428, theta=-13.5446116 -> V=1.015872, theta=0.0
% INFO    : Bus 2889	: V=1.05697929, theta=-12.5410582 -> V=1.000144, theta=0.0
% INFO    : Bus 2890	: V=1.03152595, theta=-15.559585 -> V=0.999999, theta=0.0
% INFO    : Bus 2891	: V=1.05090537, theta=-9.54315141 -> V=1.0111115, theta=0.0
% INFO    : Bus 2892	: V=1.04794836, theta=-31.9125273 -> V=1.046665, theta=0.0
% INFO    : Bus 2893	: V=1.06061499, theta=-26.6026856 -> V=1.073685, theta=0.0
% INFO    : Bus 2894	: V=1.03945822, theta=-29.0375083 -> V=1.022224, theta=0.0
% INFO    : Bus 2895	: V=1.0275427, theta=-24.0647045 -> V=0.999999, theta=0.0
% INFO    : Bus 2896	: V=1.02614043, theta=-30.1979602 -> V=1.0000025, theta=0.0
% INFO    : Bus 2897	: V=1.00699605, theta=-8.77389146 -> V=1.0158755, theta=0.0
% INFO    : Bus 2898	: V=1.04748578, theta=-29.2822477 -> V=1.0000025, theta=0.0
% INFO    : Bus 2899	: V=1.072, theta=-18.922896 -> V=0.975, theta=0.0
% INFO    : Bus 2900	: V=1.09871017, theta=-19.0655561 -> V=1.0096775, theta=0.0
% INFO    : Bus 2901	: V=1.07609692, theta=-19.3307681 -> V=1.044445, theta=0.0
% INFO    : Bus 2902	: V=0.990821046, theta=-26.5310635 -> V=1.0158755, theta=0.0
% INFO    : Bus 2903	: V=1.04360228, theta=-27.8802725 -> V=1.022224, theta=0.0
% INFO    : Bus 2904	: V=1.09912798, theta=-16.955016 -> V=1.0, theta=0.0
% INFO    : Bus 2905	: V=1.02272828, theta=-14.2607653 -> V=0.999999, theta=0.0
% INFO    : Bus 2906	: V=1.01427709, theta=-27.3689774 -> V=1.0000025, theta=0.0
% INFO    : Bus 2907	: V=1.01935173, theta=-3.15746662 -> V=1.0158755, theta=0.0
% INFO    : Bus 2908	: V=1.03312445, theta=-27.6504504 -> V=1.0000025, theta=0.0
% INFO    : Bus 2909	: V=1.03542586, theta=-27.4039223 -> V=1.0000025, theta=0.0
% INFO    : Bus 2910	: V=0.992103579, theta=-36.3594723 -> V=1.022224, theta=0.0
% INFO    : Bus 2911	: V=1.01162904, theta=-60.518043 -> V=1.0079355, theta=0.0
% INFO    : Bus 2912	: V=1.03792312, theta=-35.7752893 -> V=1.022224, theta=0.0
% INFO    : Bus 2913	: V=1.03614754, theta=-13.3179437 -> V=0.999999, theta=0.0
% INFO    : Bus 2914	: V=1.04975814, theta=-8.62213845 -> V=1.0111115, theta=0.0
% INFO    : Bus 2915	: V=1.04758159, theta=-8.43307747 -> V=1.0111115, theta=0.0
% INFO    : Bus 2916	: V=1.05367726, theta=-8.53129597 -> V=1.0111115, theta=0.0
% INFO    : Bus 2917	: V=1.06946463, theta=-4.07242841 -> V=1.072365, theta=0.0
% INFO    : Bus 2918	: V=1.02563404, theta=-22.4135326 -> V=1.015872, theta=0.0
% INFO    : Bus 2919	: V=1.03469255, theta=-28.8396812 -> V=1.0000025, theta=0.0
% INFO    : Bus 2920	: V=1.02566099, theta=-22.4118834 -> V=1.015872, theta=0.0
% INFO    : Bus 2921	: V=1.01750939, theta=-27.5875605 -> V=1.0000025, theta=0.0
% INFO    : Bus 2922	: V=1.01586159, theta=-31.4110105 -> V=1.022224, theta=0.0
% INFO    : Bus 2923	: V=1.01520267, theta=-11.6903677 -> V=1.0158755, theta=0.0
% INFO    : Bus 2924	: V=1.03234698, theta=-27.9855717 -> V=1.0000025, theta=0.0
% INFO    : Bus 2925	: V=1.0343419, theta=-21.5286688 -> V=1.0000025, theta=0.0
% INFO    : Bus 2926	: V=1.03086756, theta=-15.9192273 -> V=0.999999, theta=0.0
% INFO    : Bus 2927	: V=1.06439982, theta=-20.236597 -> V=1.0000025, theta=0.0
% INFO    : Bus 2928	: V=1.00090786, theta=-8.78711327 -> V=0.999999, theta=0.0
% INFO    : Bus 2929	: V=1.02782262, theta=-27.192254 -> V=1.000001, theta=0.0
% INFO    : Bus 2930	: V=1.04660605, theta=-8.01148937 -> V=1.0000025, theta=0.0
% INFO    : Bus 2931	: V=1.06938812, theta=-4.19147572 -> V=0.9888895, theta=0.0
% INFO    : Bus 2932	: V=1.0698057, theta=-4.16093997 -> V=0.9888895, theta=0.0
% INFO    : Bus 2933	: V=1.02535405, theta=-30.7545741 -> V=1.046665, theta=0.0
% INFO    : Bus 2934	: V=0.979162433, theta=-24.112219 -> V=0.999999, theta=0.0
% INFO    : Bus 2935	: V=1.03216958, theta=-11.4329798 -> V=0.999999, theta=0.0
% INFO    : Bus 2936	: V=1.02917868, theta=-11.8215535 -> V=0.999999, theta=0.0
% INFO    : Bus 2937	: V=1.03985734, theta=-7.43128024 -> V=1.0111115, theta=0.0
% INFO    : Bus 2938	: V=1.04179691, theta=-11.7776493 -> V=0.999999, theta=0.0
% INFO    : Bus 2939	: V=1.05286867, theta=-29.7642942 -> V=1.046665, theta=0.0
% INFO    : Bus 2940	: V=1.01129, theta=-26.7153267 -> V=1.0000025, theta=0.0
% INFO    : Bus 2941	: V=1.01035596, theta=-35.7959597 -> V=1.022224, theta=0.0
% INFO    : Bus 2942	: V=1.03259807, theta=-17.5985464 -> V=1.015872, theta=0.0
% INFO    : Bus 2943	: V=1.03259807, theta=-17.5985464 -> V=1.015872, theta=0.0
% INFO    : Bus 2944	: V=1.06498932, theta=-15.4857965 -> V=1.000001, theta=0.0
% INFO    : Bus 2945	: V=1.08994221, theta=-14.4525824 -> V=1.04529, theta=0.0
% INFO    : Bus 2946	: V=1.0274873, theta=-40.0524601 -> V=1.022224, theta=0.0
% INFO    : Bus 2947	: V=1.07109531, theta=-34.1157274 -> V=1.07237, theta=0.0
% INFO    : Bus 2948	: V=0.984486256, theta=-34.3674861 -> V=1.0158755, theta=0.0
% INFO    : Bus 2949	: V=0.974649735, theta=-28.7570984 -> V=1.0158755, theta=0.0
% INFO    : Bus 2950	: V=1.02058644, theta=-10.1031443 -> V=1.0158755, theta=0.0
% INFO    : Bus 2951	: V=1.05811429, theta=-4.95561123 -> V=1.0377785, theta=0.0
% INFO    : Bus 2952	: V=1.05711506, theta=-4.94200339 -> V=1.0377785, theta=0.0
% INFO    : Bus 2953	: V=1.01826275, theta=-23.4038451 -> V=0.999999, theta=0.0
% INFO    : Bus 2954	: V=1.03756609, theta=-44.9538399 -> V=1.022224, theta=0.0
% INFO    : Bus 2955	: V=0.984936456, theta=-7.13288405 -> V=1.0158755, theta=0.0
% INFO    : Bus 2956	: V=1.03652837, theta=-41.5871081 -> V=1.022224, theta=0.0
% INFO    : Bus 2957	: V=1.00970515, theta=-13.5863703 -> V=1.015872, theta=0.0
% INFO    : Bus 2958	: V=1.05050391, theta=-20.4966009 -> V=1.0000025, theta=0.0
% INFO    : Bus 2959	: V=1.09279266, theta=-18.2428746 -> V=1.0, theta=0.0
% INFO    : Bus 2960	: V=1.0267948, theta=-36.5457124 -> V=1.022224, theta=0.0
% INFO    : Bus 2961	: V=1.02399185, theta=-22.2083488 -> V=1.0000025, theta=0.0
% INFO    : Bus 2962	: V=1.0520184, theta=-34.4481991 -> V=1.022224, theta=0.0
% INFO    : Bus 2963	: V=1.05896273, theta=-27.8216291 -> V=1.046665, theta=0.0
% INFO    : Bus 2964	: V=1.05750766, theta=-29.1850548 -> V=1.046665, theta=0.0
% INFO    : Bus 2965	: V=1.06093147, theta=-30.3754111 -> V=1.046665, theta=0.0
% INFO    : Bus 2966	: V=1.05752507, theta=-29.1821578 -> V=1.046665, theta=0.0
% INFO    : Bus 2967	: V=1.05896239, theta=-27.8202881 -> V=1.046665, theta=0.0
% INFO    : Bus 2968	: V=1.05248636, theta=-22.5933225 -> V=1.073685, theta=0.0
% INFO    : Bus 2969	: V=1.05056616, theta=-23.3195792 -> V=1.073685, theta=0.0
% INFO    : Bus 2970	: V=1.07108288, theta=-20.8325032 -> V=1.0000025, theta=0.0
% INFO    : Bus 2971	: V=1.04662777, theta=-23.2540963 -> V=1.0000025, theta=0.0
% INFO    : Bus 2972	: V=1.06381386, theta=-18.5059688 -> V=1.044445, theta=0.0
% INFO    : Bus 2973	: V=1.0275653, theta=-15.5127336 -> V=0.999999, theta=0.0
% INFO    : Bus 2974	: V=1.00706641, theta=-19.1675214 -> V=0.999999, theta=0.0
% INFO    : Bus 2975	: V=1.0185101, theta=-17.7067184 -> V=1.0158755, theta=0.0
% INFO    : Bus 2976	: V=1.00409512, theta=-37.3050376 -> V=1.027779, theta=0.0
% INFO    : Bus 2977	: V=0.992356581, theta=-52.0584069 -> V=1.022224, theta=0.0
% INFO    : Bus 2978	: V=1.03924501, theta=-36.864869 -> V=1.022224, theta=0.0
% INFO    : Bus 2979	: V=1.01220323, theta=-62.8589082 -> V=1.0079355, theta=0.0
% INFO    : Bus 2980	: V=1.03709465, theta=-19.6308888 -> V=1.0000025, theta=0.0
% INFO    : Bus 2981	: V=1.0242773, theta=-22.7789627 -> V=1.0000025, theta=0.0
% INFO    : Bus 2982	: V=1.03719173, theta=-43.461705 -> V=1.027779, theta=0.0
% INFO    : Bus 2983	: V=1.0422502, theta=-29.6274393 -> V=1.027779, theta=0.0
% INFO    : Bus 2984	: V=0.995665706, theta=-33.8522609 -> V=1.0000005, theta=0.0
% INFO    : Bus 2985	: V=1.02633628, theta=-29.439295 -> V=1.046665, theta=0.0
% INFO    : Bus 2986	: V=1.02697389, theta=-36.9673458 -> V=1.027779, theta=0.0
% INFO    : Bus 2987	: V=1.02005377, theta=-23.4169629 -> V=0.999999, theta=0.0
% INFO    : Bus 2988	: V=1.02195616, theta=-16.4880737 -> V=1.015872, theta=0.0
% INFO    : Bus 2989	: V=1.04259875, theta=-12.476488 -> V=1.046665, theta=0.0
% INFO    : Bus 2990	: V=1.06041683, theta=-16.9323425 -> V=0.999999, theta=0.0
% INFO    : Bus 2991	: V=1.02154668, theta=-12.0852317 -> V=0.999999, theta=0.0
% INFO    : Bus 2992	: V=1.04870806, theta=-21.5231466 -> V=1.022222, theta=0.0
% INFO    : Bus 2993	: V=1.05, theta=-10.8443011 -> V=0.999999, theta=0.0
% INFO    : Bus 2994	: V=1.04462162, theta=-11.5937882 -> V=0.975, theta=0.0
% INFO    : Bus 2995	: V=1.04357804, theta=-11.5937882 -> V=0.999999, theta=0.0
% INFO    : Bus 2996	: V=1.03872224, theta=-11.8632247 -> V=0.999999, theta=0.0
% INFO    : Bus 2997	: V=1.04988016, theta=-8.62281816 -> V=1.0111115, theta=0.0
% INFO    : Bus 2998	: V=1.04469632, theta=-9.28707553 -> V=1.0111115, theta=0.0
% INFO    : Bus 2999	: V=1.0160678, theta=-35.7037139 -> V=1.015872, theta=0.0
% INFO    : Bus 3000	: V=1.0406194, theta=-31.403001 -> V=1.046665, theta=0.0
% INFO    : Bus 3001	: V=1.06699717, theta=-20.3582286 -> V=1.0000025, theta=0.0
% INFO    : Bus 3002	: V=1.07498149, theta=-12.4914003 -> V=1.044445, theta=0.0
% INFO    : Bus 3003	: V=1.01943539, theta=-32.0595575 -> V=1.0000025, theta=0.0
% INFO    : Bus 3004	: V=1.04377506, theta=-13.5715965 -> V=1.046665, theta=0.0
% INFO    : Bus 3005	: V=1.03084854, theta=-27.5550198 -> V=1.000001, theta=0.0
% INFO    : Bus 3006	: V=1.05438317, theta=-31.7366628 -> V=1.046665, theta=0.0
% INFO    : Bus 3007	: V=1.01955992, theta=-28.8659472 -> V=1.0000025, theta=0.0
% INFO    : Bus 3008	: V=1.03844177, theta=-2.97221233 -> V=1.0158755, theta=0.0
% INFO    : Bus 3009	: V=1.07556682, theta=0.13325591 -> V=1.0377785, theta=0.0
% INFO    : Bus 3010	: V=1.08607475, theta=2.24560424 -> V=1.072365, theta=0.0
% INFO    : Bus 3011	: V=1.00749499, theta=-4.59528784 -> V=1.0158755, theta=0.0
% INFO    : Bus 3012	: V=1.0509941, theta=-31.1133699 -> V=1.0000025, theta=0.0
% INFO    : Bus 3013	: V=1.01418514, theta=-14.6579224 -> V=0.999999, theta=0.0
% INFO    : Bus 3014	: V=1.03197148, theta=-12.3060985 -> V=1.0158755, theta=0.0
% INFO    : Bus 3015	: V=1.05574953, theta=-24.7365378 -> V=1.022224, theta=0.0
% INFO    : Bus 3016	: V=1.06045593, theta=-20.2945736 -> V=1.04444, theta=0.0
% INFO    : Bus 3017	: V=1.01358203, theta=-19.7488733 -> V=1.015872, theta=0.0
% INFO    : Bus 3018	: V=1.06302833, theta=-20.7250246 -> V=1.0000025, theta=0.0
% INFO    : Bus 3019	: V=1.04991624, theta=-34.6362135 -> V=1.022224, theta=0.0
% INFO    : Bus 3020	: V=1.01193319, theta=-18.2617087 -> V=1.0158755, theta=0.0
% INFO    : Bus 3021	: V=1.02517844, theta=-10.8623466 -> V=0.999999, theta=0.0
% INFO    : Bus 3022	: V=1.044, theta=-14.8967959 -> V=1.001294, theta=0.0
% INFO    : Bus 3023	: V=1.0252782, theta=-8.28609625 -> V=1.0000025, theta=0.0
% INFO    : Bus 3024	: V=1.01128919, theta=-46.0257007 -> V=1.022224, theta=0.0
% INFO    : Bus 3025	: V=1.0290623, theta=-10.482107 -> V=1.0158755, theta=0.0
% INFO    : Bus 3026	: V=1.029003, theta=-10.4787521 -> V=1.0158755, theta=0.0
% INFO    : Bus 3027	: V=1.02741612, theta=-26.4960499 -> V=1.0000025, theta=0.0
% INFO    : Bus 3028	: V=1.03072952, theta=-31.445903 -> V=1.015872, theta=0.0
% INFO    : Bus 3029	: V=1.0438924, theta=-24.9475593 -> V=1.022222, theta=0.0
% INFO    : Bus 3030	: V=1.03952227, theta=-23.5492242 -> V=1.0000025, theta=0.0
% INFO    : Bus 3031	: V=1.07552912, theta=-19.6375451 -> V=1.044445, theta=0.0
% INFO    : Bus 3032	: V=1.08651176, theta=-14.2020048 -> V=1.078945, theta=0.0
% INFO    : Bus 3033	: V=1.00838935, theta=-22.94217 -> V=1.015872, theta=0.0
% INFO    : Bus 3034	: V=1.01181449, theta=-29.6583513 -> V=1.0000025, theta=0.0
% INFO    : Bus 3035	: V=1.03678777, theta=-29.686345 -> V=1.0000025, theta=0.0
% INFO    : Bus 3036	: V=1.01738264, theta=-12.6899921 -> V=1.015872, theta=0.0
% INFO    : Bus 3037	: V=0.972843632, theta=-29.1662962 -> V=1.0158755, theta=0.0
% INFO    : Bus 3038	: V=1.07424352, theta=-17.7730732 -> V=1.044445, theta=0.0
% INFO    : Bus 3039	: V=1.00836171, theta=-37.4319668 -> V=1.0000005, theta=0.0
% INFO    : Bus 3040	: V=1.03406801, theta=-14.7772252 -> V=0.999999, theta=0.0
% INFO    : Bus 3041	: V=1.02528986, theta=-25.0372625 -> V=1.0000025, theta=0.0
% INFO    : Bus 3042	: V=1.02011731, theta=-25.6967198 -> V=1.0000025, theta=0.0
% INFO    : Bus 3043	: V=1.00761705, theta=-23.8600256 -> V=1.0158755, theta=0.0
% INFO    : Bus 3044	: V=1.03336402, theta=-19.7628088 -> V=1.0158755, theta=0.0
% INFO    : Bus 3045	: V=1.05299857, theta=-34.6069928 -> V=1.022224, theta=0.0
% INFO    : Bus 3046	: V=1.05390524, theta=-22.3643691 -> V=1.0000025, theta=0.0
% INFO    : Bus 3047	: V=1.03300555, theta=-21.3237242 -> V=0.9888895, theta=0.0
% INFO    : Bus 3048	: V=1.0106254, theta=-14.8335001 -> V=1.015872, theta=0.0
% INFO    : Bus 3049	: V=0.998877972, theta=-14.7484717 -> V=1.015872, theta=0.0
% INFO    : Bus 3050	: V=1.05130166, theta=-29.5736751 -> V=1.022224, theta=0.0
% INFO    : Bus 3051	: V=1.0440214, theta=-14.323105 -> V=0.999999, theta=0.0
% INFO    : Bus 3052	: V=0.992854123, theta=-31.4908654 -> V=1.0000005, theta=0.0
% INFO    : Bus 3053	: V=1.00687342, theta=-30.8755586 -> V=1.0000005, theta=0.0
% INFO    : Bus 3054	: V=1.03579518, theta=-23.9601449 -> V=1.046665, theta=0.0
% INFO    : Bus 3055	: V=1.03579539, theta=-23.9601473 -> V=1.046665, theta=0.0
% INFO    : Bus 3056	: V=1.10487196, theta=-9.36014706 -> V=1.07928, theta=0.0
% INFO    : Bus 3057	: V=1.10495298, theta=-9.33698742 -> V=1.07932, theta=0.0
% INFO    : Bus 3058	: V=1.10495373, theta=-9.33632037 -> V=1.07932, theta=0.0
% INFO    : Bus 3059	: V=1.03621122, theta=-22.0412525 -> V=0.999999, theta=0.0
% INFO    : Bus 3060	: V=1.00545126, theta=-51.5755314 -> V=1.022224, theta=0.0
% INFO    : Bus 3061	: V=1.02137871, theta=-38.814753 -> V=1.0000005, theta=0.0
% INFO    : Bus 3062	: V=1.01934603, theta=-39.9538733 -> V=1.0000005, theta=0.0
% INFO    : Bus 3063	: V=1.05262507, theta=-29.1254526 -> V=1.022224, theta=0.0
% INFO    : Bus 3064	: V=1.06155286, theta=-24.3065405 -> V=1.04444, theta=0.0
% INFO    : Bus 3065	: V=1.02834535, theta=-22.346108 -> V=1.000001, theta=0.0
% INFO    : Bus 3066	: V=1.05063544, theta=-30.3479903 -> V=1.027779, theta=0.0
% INFO    : Bus 3067	: V=1.03160719, theta=-34.7875953 -> V=1.027779, theta=0.0
% INFO    : Bus 3068	: V=1.04665052, theta=-29.8404975 -> V=1.046665, theta=0.0
% INFO    : Bus 3069	: V=1.04563934, theta=-29.8030696 -> V=1.046665, theta=0.0
% INFO    : Bus 3070	: V=0.991310772, theta=-16.8631559 -> V=1.015872, theta=0.0
% INFO    : Bus 3071	: V=1.01060571, theta=-32.9693598 -> V=1.0000025, theta=0.0
% INFO    : Bus 3072	: V=1.03331846, theta=-49.4188267 -> V=1.0079355, theta=0.0
% INFO    : Bus 3073	: V=1.03214406, theta=-21.2605544 -> V=0.999999, theta=0.0
% INFO    : Bus 3074	: V=1.05176455, theta=-17.8891854 -> V=1.0111115, theta=0.0
% INFO    : Bus 3075	: V=1.02925006, theta=-15.6237429 -> V=0.999999, theta=0.0
% INFO    : Bus 3076	: V=0.973171849, theta=-19.6632886 -> V=1.015872, theta=0.0
% INFO    : Bus 3077	: V=1.03848073, theta=-12.1002169 -> V=0.999999, theta=0.0
% INFO    : Bus 3078	: V=0.989193655, theta=-24.4852986 -> V=0.984126, theta=0.0
% INFO    : Bus 3079	: V=1.01955102, theta=-25.6684036 -> V=1.022224, theta=0.0
% INFO    : Bus 3080	: V=1.03364408, theta=-45.9685145 -> V=1.0079355, theta=0.0
% INFO    : Bus 3081	: V=1.01650921, theta=-3.70124538 -> V=1.0158755, theta=0.0
% INFO    : Bus 3082	: V=1.07426747, theta=-0.996431027 -> V=1.0377785, theta=0.0
% INFO    : Bus 3083	: V=1.02429863, theta=-26.1226413 -> V=1.0000025, theta=0.0
% INFO    : Bus 3084	: V=1.00953245, theta=-30.301652 -> V=1.0000025, theta=0.0
% INFO    : Bus 3085	: V=1.03156336, theta=-21.1472943 -> V=1.0000025, theta=0.0
% INFO    : Bus 3086	: V=1.05094865, theta=-17.2835775 -> V=1.044445, theta=0.0
% INFO    : Bus 3087	: V=1.02414098, theta=-12.7116453 -> V=0.999999, theta=0.0
% INFO    : Bus 3088	: V=1.0492495, theta=-9.94878933 -> V=1.0111115, theta=0.0
% INFO    : Bus 3089	: V=0.995648478, theta=-33.3958817 -> V=1.0000025, theta=0.0
% INFO    : Bus 3090	: V=1.02677573, theta=-41.5548217 -> V=1.022224, theta=0.0
% INFO    : Bus 3091	: V=0.995246715, theta=-20.246773 -> V=0.999999, theta=0.0
% INFO    : Bus 3092	: V=1.01756367, theta=-39.9736059 -> V=1.022224, theta=0.0
% INFO    : Bus 3093	: V=0.936401481, theta=-7.66537631 -> V=0.9444445, theta=0.0
% INFO    : Bus 3094	: V=0.984199334, theta=-6.20805671 -> V=0.9444445, theta=0.0
% INFO    : Bus 3095	: V=1.01090731, theta=-20.2183358 -> V=0.999999, theta=0.0
% INFO    : Bus 3096	: V=1.01012611, theta=-39.7573125 -> V=1.0000005, theta=0.0
% INFO    : Bus 3097	: V=0.982696887, theta=-34.9795084 -> V=1.0000005, theta=0.0
% INFO    : Bus 3098	: V=0.992583612, theta=-12.8243841 -> V=0.9444445, theta=0.0
% INFO    : Bus 3099	: V=0.978744371, theta=-24.1754785 -> V=0.999999, theta=0.0
% INFO    : Bus 3100	: V=1.03106721, theta=-19.8626872 -> V=0.999999, theta=0.0
% INFO    : Bus 3101	: V=1.05071051, theta=-17.2135738 -> V=1.0111115, theta=0.0
% INFO    : Bus 3102	: V=1.06608537, theta=-34.767706 -> V=1.046665, theta=0.0
% INFO    : Bus 3103	: V=1.10446187, theta=-0.853348546 -> V=1.072365, theta=0.0
% INFO    : Bus 3104	: V=1.02613267, theta=-10.3116868 -> V=1.0158755, theta=0.0
% INFO    : Bus 3105	: V=1.01645305, theta=-11.5780903 -> V=1.0158755, theta=0.0
% INFO    : Bus 3106	: V=1.00888021, theta=-9.13196969 -> V=0.999999, theta=0.0
% INFO    : Bus 3107	: V=1.01192325, theta=-8.81341098 -> V=0.999999, theta=0.0
% INFO    : Bus 3108	: V=1.00203312, theta=-39.7757474 -> V=1.0000005, theta=0.0
% INFO    : Bus 3109	: V=1.04364311, theta=-32.7030037 -> V=1.046665, theta=0.0
% INFO    : Bus 3110	: V=1.05108747, theta=-9.4383261 -> V=1.0377785, theta=0.0
% INFO    : Bus 3111	: V=1.04021228, theta=-31.5577602 -> V=1.0000025, theta=0.0
% INFO    : Bus 3112	: V=1.02497428, theta=-20.6509848 -> V=1.0000025, theta=0.0
% INFO    : Bus 3113	: V=1.00958554, theta=-66.9609217 -> V=1.0079355, theta=0.0
% INFO    : Bus 3114	: V=1.03616586, theta=-24.9919846 -> V=1.022224, theta=0.0
% INFO    : Bus 3115	: V=1.03855838, theta=-26.2394488 -> V=1.022224, theta=0.0
% INFO    : Bus 3116	: V=1.073, theta=1.52900995 -> V=0.975, theta=0.0
% INFO    : Bus 3117	: V=1.108, theta=0.597476777 -> V=0.975, theta=0.0
% INFO    : Bus 3118	: V=1.105, theta=0.788577662 -> V=0.975, theta=0.0
% INFO    : Bus 3119	: V=1.06870134, theta=-4.47162123 -> V=1.0377785, theta=0.0
% INFO    : Bus 3120	: V=1.0688241, theta=-4.47395475 -> V=1.0377785, theta=0.0
% INFO    : Bus 3121	: V=1.06881273, theta=-4.47336763 -> V=1.0377785, theta=0.0
% INFO    : Bus 3122	: V=1.02629044, theta=-52.9621887 -> V=1.022224, theta=0.0
% INFO    : Bus 3123	: V=1.03723733, theta=-18.0536584 -> V=0.999999, theta=0.0
% INFO    : Bus 3124	: V=1.01602682, theta=-61.3372242 -> V=1.0079355, theta=0.0
% INFO    : Bus 3125	: V=1.0223163, theta=-25.0748466 -> V=0.999999, theta=0.0
% INFO    : Bus 3126	: V=1.04375109, theta=-18.4140681 -> V=1.0000025, theta=0.0
% INFO    : Bus 3127	: V=1.03972667, theta=-27.4749503 -> V=1.0000025, theta=0.0
% INFO    : Bus 3128	: V=0.962669544, theta=-25.8297862 -> V=1.0, theta=0.0
% INFO    : Bus 3129	: V=1.02800655, theta=-10.2725093 -> V=0.984126, theta=0.0
% INFO    : Bus 3130	: V=1.07012776, theta=-22.0256584 -> V=1.0047975, theta=0.0
% INFO    : Bus 3131	: V=0.986235017, theta=-25.7655679 -> V=1.015872, theta=0.0
% INFO    : Bus 3132	: V=1.00671567, theta=-36.6314401 -> V=1.022224, theta=0.0
% INFO    : Bus 3133	: V=1.04626219, theta=-26.6814749 -> V=1.022222, theta=0.0
% INFO    : Bus 3134	: V=1.05366864, theta=-14.1188964 -> V=1.001354, theta=0.0
% INFO    : Bus 3135	: V=1.07094179, theta=-7.43058255 -> V=1.072365, theta=0.0
% INFO    : Bus 3136	: V=1.065, theta=-21.4831249 -> V=1.000001, theta=0.0
% INFO    : Bus 3137	: V=1.04243487, theta=-19.968521 -> V=0.9888895, theta=0.0
% INFO    : Bus 3138	: V=1.04312693, theta=-19.9492225 -> V=0.9888895, theta=0.0
% INFO    : Bus 3139	: V=1.0374659, theta=-10.1321639 -> V=1.0158755, theta=0.0
% INFO    : Bus 3140	: V=1.07000533, theta=-0.138461437 -> V=1.0377785, theta=0.0
% INFO    : Bus 3141	: V=1.03651835, theta=-22.5198974 -> V=1.0000025, theta=0.0
% INFO    : Bus 3142	: V=1.03407132, theta=-20.2224123 -> V=1.0000025, theta=0.0
% INFO    : Bus 3143	: V=1.02381701, theta=-18.9670224 -> V=1.015872, theta=0.0
% INFO    : Bus 3144	: V=1.0476568, theta=-29.4789267 -> V=1.046665, theta=0.0
% INFO    : Bus 3145	: V=1.01585045, theta=-32.8772135 -> V=1.0000005, theta=0.0
% INFO    : Bus 3146	: V=1.04766083, theta=-29.4786568 -> V=1.046665, theta=0.0
% INFO    : Bus 3147	: V=1.01355917, theta=-26.7694553 -> V=1.0000025, theta=0.0
% INFO    : Bus 3148	: V=1.02491516, theta=-22.4551845 -> V=1.015872, theta=0.0
% INFO    : Bus 3149	: V=1.05517914, theta=-17.4927081 -> V=1.033334, theta=0.0
% INFO    : Bus 3150	: V=1.00867133, theta=-17.5100037 -> V=1.05375, theta=0.0
% INFO    : Bus 3151	: V=0.99202509, theta=-18.5233047 -> V=1.0158755, theta=0.0
% INFO    : Bus 3152	: V=1.01008113, theta=-14.8575774 -> V=1.0277795, theta=0.0
% INFO    : Bus 3153	: V=1.06404217, theta=-14.1597395 -> V=1.072365, theta=0.0
% INFO    : Bus 3154	: V=1.06439485, theta=-14.6411652 -> V=1.072365, theta=0.0
% INFO    : Bus 3155	: V=1.01833776, theta=-27.5691021 -> V=1.0000025, theta=0.0
% INFO    : Bus 3156	: V=1.03657129, theta=-13.3934634 -> V=0.999999, theta=0.0
% INFO    : Bus 3157	: V=1.049, theta=-24.8958794 -> V=1.0111115, theta=0.0
% INFO    : Bus 3158	: V=1.02456573, theta=-24.2552046 -> V=0.999999, theta=0.0
% INFO    : Bus 3159	: V=1.067, theta=-22.0247722 -> V=1.000001, theta=0.0
% INFO    : Bus 3160	: V=1.02557836, theta=-31.3724968 -> V=1.022224, theta=0.0
% INFO    : Bus 3161	: V=0.997152113, theta=-33.9306849 -> V=1.0000005, theta=0.0
% INFO    : Bus 3162	: V=1.04325963, theta=-10.3723131 -> V=0.999999, theta=0.0
% INFO    : Bus 3163	: V=1.06761997, theta=-34.5047209 -> V=1.046665, theta=0.0
% INFO    : Bus 3164	: V=1.0351113, theta=-21.9508191 -> V=1.0000025, theta=0.0
% INFO    : Bus 3165	: V=1.08906308, theta=-17.7218838 -> V=1.04474, theta=0.0
% INFO    : Bus 3166	: V=0.987238729, theta=-23.6673098 -> V=1.0000025, theta=0.0
% INFO    : Bus 3167	: V=1.05399644, theta=-30.1122134 -> V=1.046665, theta=0.0
% INFO    : Bus 3168	: V=1.05986757, theta=-31.1519502 -> V=1.046665, theta=0.0
% INFO    : Bus 3169	: V=1.0314054, theta=-36.6877715 -> V=1.022224, theta=0.0
% INFO    : Bus 3170	: V=1.03591925, theta=-16.9027333 -> V=0.999999, theta=0.0
% INFO    : Bus 3171	: V=1.01540221, theta=-30.2554944 -> V=1.0000025, theta=0.0
% INFO    : Bus 3172	: V=1.03056891, theta=-22.1247602 -> V=1.000001, theta=0.0
% INFO    : Bus 3173	: V=1.00197786, theta=-26.1157821 -> V=1.0158755, theta=0.0
% INFO    : Bus 3174	: V=1.05036626, theta=-21.909334 -> V=1.0000025, theta=0.0
% INFO    : Bus 3175	: V=1.02141665, theta=-28.7488604 -> V=1.0000005, theta=0.0
% INFO    : Bus 3176	: V=1.03114241, theta=-24.2172009 -> V=1.046665, theta=0.0
% INFO    : Bus 3177	: V=1.00902611, theta=-60.5134243 -> V=1.0079355, theta=0.0
% INFO    : Bus 3178	: V=1.01593143, theta=-24.1488358 -> V=1.0, theta=0.0
% INFO    : Bus 3179	: V=1.04017016, theta=-24.2405577 -> V=1.046665, theta=0.0
% INFO    : Bus 3180	: V=1.03461682, theta=-21.0661758 -> V=1.06504, theta=0.0
% INFO    : Bus 3181	: V=1.02719119, theta=-29.852118 -> V=1.0000025, theta=0.0
% INFO    : Bus 3182	: V=0.988799791, theta=-27.0025207 -> V=1.022224, theta=0.0
% INFO    : Bus 3183	: V=1.05167442, theta=-26.2945934 -> V=0.987941, theta=0.0
% INFO    : Bus 3184	: V=1.03460001, theta=-34.6028121 -> V=1.027779, theta=0.0
% INFO    : Bus 3185	: V=1.02216081, theta=-31.3083671 -> V=1.000001, theta=0.0
% INFO    : Bus 3186	: V=0.99957368, theta=-16.8677801 -> V=1.0158755, theta=0.0
% INFO    : Bus 3187	: V=1.01830904, theta=-19.8308666 -> V=0.999999, theta=0.0
% INFO    : Bus 3188	: V=1.06097669, theta=-18.6985822 -> V=1.003564, theta=0.0
% INFO    : Bus 3189	: V=1.01384362, theta=-15.9358416 -> V=1.0079355, theta=0.0
% INFO    : Bus 3190	: V=1.01638042, theta=-20.1970536 -> V=1.0158755, theta=0.0
% INFO    : Bus 3191	: V=1.03483027, theta=-31.7884126 -> V=1.046665, theta=0.0
% INFO    : Bus 3192	: V=1.03481058, theta=-31.7908257 -> V=1.046665, theta=0.0
% INFO    : Bus 3193	: V=1.03719727, theta=-30.751624 -> V=1.022224, theta=0.0
% INFO    : Bus 3194	: V=1.04001551, theta=-15.2296102 -> V=1.046665, theta=0.0
% INFO    : Bus 3195	: V=1.01202409, theta=-21.8192883 -> V=1.015872, theta=0.0
% INFO    : Bus 3196	: V=1.01820642, theta=-32.8143639 -> V=1.022224, theta=0.0
% INFO    : Bus 3197	: V=1.0284338, theta=-33.8295409 -> V=1.022224, theta=0.0
% INFO    : Bus 3198	: V=1.05240749, theta=-29.2008185 -> V=1.04444, theta=0.0
% INFO    : Bus 3199	: V=1.05284828, theta=-31.0533981 -> V=1.04444, theta=0.0
% INFO    : Bus 3200	: V=1.05062728, theta=-21.7902845 -> V=1.0000025, theta=0.0
% INFO    : Bus 3201	: V=1.00925599, theta=-21.7544506 -> V=0.984126, theta=0.0
% INFO    : Bus 3202	: V=1.00940898, theta=-18.4257733 -> V=0.995556, theta=0.0
% INFO    : Bus 3203	: V=1.00825986, theta=-31.2977166 -> V=1.0000025, theta=0.0
% INFO    : Bus 3204	: V=1.04915338, theta=-30.3924871 -> V=1.046665, theta=0.0
% INFO    : Bus 3205	: V=1.05480509, theta=-29.9687681 -> V=1.046665, theta=0.0
% INFO    : Bus 3206	: V=1.03142235, theta=-40.6081959 -> V=1.027779, theta=0.0
% INFO    : Bus 3207	: V=1.03248089, theta=-41.5685164 -> V=1.0000025, theta=0.0
% INFO    : Bus 3208	: V=1.05438491, theta=-19.9333195 -> V=1.022222, theta=0.0
% INFO    : Bus 3209	: V=1.03443954, theta=-1.89432119 -> V=1.0158755, theta=0.0
% INFO    : Bus 3210	: V=1.099, theta=-16.9544515 -> V=1.0, theta=0.0
% INFO    : Bus 3211	: V=1.0349965, theta=-20.3761378 -> V=1.0000025, theta=0.0
% INFO    : Bus 3212	: V=1.04271874, theta=-32.7395483 -> V=1.046665, theta=0.0
% INFO    : Bus 3213	: V=1.03732779, theta=-8.77899046 -> V=0.9707295, theta=0.0
% INFO    : Bus 3214	: V=1.03594139, theta=-19.3339648 -> V=1.0158755, theta=0.0
% INFO    : Bus 3215	: V=1.04501024, theta=-32.4598768 -> V=1.0079905, theta=0.0
% INFO    : Bus 3216	: V=0.978298575, theta=-36.3223963 -> V=1.0000005, theta=0.0
% INFO    : Bus 3217	: V=1.01849513, theta=-32.4577421 -> V=1.046665, theta=0.0
% INFO    : Bus 3218	: V=1.00482821, theta=-49.87008 -> V=1.022224, theta=0.0
% INFO    : Bus 3219	: V=1.02866368, theta=-28.4257671 -> V=1.0000025, theta=0.0
% INFO    : Bus 3220	: V=1.01717638, theta=-31.2814004 -> V=1.0000005, theta=0.0
% INFO    : Bus 3221	: V=1.03443881, theta=-34.466428 -> V=1.027779, theta=0.0
% INFO    : Bus 3222	: V=1.0119048, theta=-23.2441198 -> V=1.0158755, theta=0.0
% INFO    : Bus 3223	: V=1.01666966, theta=-22.4213408 -> V=1.0158755, theta=0.0
% INFO    : Bus 3224	: V=0.960238928, theta=-22.8924961 -> V=1.012875, theta=0.0
% INFO    : Bus 3225	: V=0.95371988, theta=-8.94662212 -> V=0.9444445, theta=0.0
% INFO    : Bus 3226	: V=1.02683919, theta=-47.7069433 -> V=1.022224, theta=0.0
% INFO    : Bus 3227	: V=0.980503573, theta=-27.3933536 -> V=1.0158755, theta=0.0
% INFO    : Bus 3228	: V=1.02590956, theta=-30.9556386 -> V=1.027779, theta=0.0
% INFO    : Bus 3229	: V=1.01276594, theta=-7.81084886 -> V=1.0158755, theta=0.0
% INFO    : Bus 3230	: V=1.08620628, theta=-2.00094348 -> V=1.072365, theta=0.0
% INFO    : Bus 3231	: V=1.05584503, theta=-29.7619562 -> V=1.046665, theta=0.0
% INFO    : Bus 3232	: V=1.05587466, theta=-29.7594526 -> V=1.046665, theta=0.0
% INFO    : Bus 3233	: V=1.05588064, theta=-29.7580919 -> V=1.046665, theta=0.0
% INFO    : Bus 3234	: V=1.02302329, theta=-34.4520988 -> V=1.022224, theta=0.0
% INFO    : Bus 3235	: V=0.974932135, theta=-48.4472814 -> V=1.0182535, theta=0.0
% INFO    : Bus 3236	: V=1.06305538, theta=-15.4769672 -> V=1.072365, theta=0.0
% INFO    : Bus 3237	: V=1.06285251, theta=-15.5761202 -> V=1.072365, theta=0.0
% INFO    : Bus 3238	: V=1.00342689, theta=-19.2055478 -> V=1.0158755, theta=0.0
% INFO    : Bus 3239	: V=1.067, theta=-15.321798 -> V=1.000001, theta=0.0
% INFO    : Bus 3240	: V=1.01812865, theta=-10.7286772 -> V=1.0158755, theta=0.0
% INFO    : Bus 3241	: V=1.00092967, theta=-8.78767418 -> V=0.999999, theta=0.0
% INFO    : Bus 3242	: V=1.01595239, theta=-62.7338666 -> V=1.0079355, theta=0.0
% INFO    : Bus 3243	: V=1.02069673, theta=2.6012632 -> V=1.013331, theta=0.0
% INFO    : Bus 3244	: V=1.03139276, theta=-37.6065889 -> V=1.027779, theta=0.0
% INFO    : Bus 3245	: V=1.00245757, theta=-20.6886438 -> V=1.0000025, theta=0.0
% INFO    : Bus 3246	: V=1.049, theta=-28.6336467 -> V=1.0000025, theta=0.0
% INFO    : Bus 3247	: V=1.01545473, theta=-20.3083141 -> V=1.015872, theta=0.0
% INFO    : Bus 3248	: V=1.02731544, theta=-34.8931145 -> V=1.027779, theta=0.0
% INFO    : Bus 3249	: V=1.02767555, theta=-28.0021895 -> V=0.999999, theta=0.0
% INFO    : Bus 3250	: V=1.01619427, theta=-54.3338841 -> V=1.022224, theta=0.0
% INFO    : Bus 3251	: V=1.041234, theta=-25.7713375 -> V=1.0000025, theta=0.0
% INFO    : Bus 3252	: V=1.01489067, theta=-38.7693783 -> V=1.022224, theta=0.0
% INFO    : Bus 3253	: V=1.05605629, theta=-14.3543605 -> V=1.046665, theta=0.0
% INFO    : Bus 3254	: V=1.03753322, theta=-9.71712524 -> V=1.0158755, theta=0.0
% INFO    : Bus 3255	: V=1.03753322, theta=-9.71712524 -> V=1.0158755, theta=0.0
% INFO    : Bus 3256	: V=1.03753338, theta=-9.71720771 -> V=1.0158755, theta=0.0
% INFO    : Bus 3257	: V=1.00706204, theta=-13.9026014 -> V=1.015872, theta=0.0
% INFO    : Bus 3258	: V=1.03227687, theta=-30.6271688 -> V=1.022224, theta=0.0
% INFO    : Bus 3259	: V=1.05471213, theta=-25.7611401 -> V=1.04444, theta=0.0
% INFO    : Bus 3260	: V=1.03304086, theta=-37.3489455 -> V=1.027779, theta=0.0
% INFO    : Bus 3261	: V=1.02674432, theta=-23.2770277 -> V=1.022224, theta=0.0
% INFO    : Bus 3262	: V=1.03548447, theta=-26.6018885 -> V=1.0111115, theta=0.0
% INFO    : Bus 3263	: V=1.05404191, theta=-4.43080434 -> V=1.0111115, theta=0.0
% INFO    : Bus 3264	: V=1.042, theta=-27.1460236 -> V=1.0000025, theta=0.0
% INFO    : Bus 3265	: V=1.03543914, theta=-28.1728061 -> V=1.022224, theta=0.0
% INFO    : Bus 3266	: V=1.056, theta=-22.9299513 -> V=1.0, theta=0.0
% INFO    : Bus 3267	: V=1.05944939, theta=-31.1385331 -> V=1.046665, theta=0.0
% INFO    : Bus 3268	: V=0.934265835, theta=-36.9173651 -> V=0.9901955, theta=0.0
% INFO    : Bus 3269	: V=1.03521574, theta=-19.8959271 -> V=1.0000025, theta=0.0
% INFO    : Bus 3270	: V=1.02132738, theta=-17.2047651 -> V=1.002223, theta=0.0
% INFO    : Bus 3271	: V=1.03444187, theta=-31.831916 -> V=1.046665, theta=0.0
% INFO    : Bus 3272	: V=1.01429847, theta=-21.2141327 -> V=1.0158755, theta=0.0
% INFO    : Bus 3273	: V=1.05902623, theta=-28.9219725 -> V=1.046665, theta=0.0
% INFO    : Bus 3274	: V=1.04067442, theta=-27.0008833 -> V=1.0000025, theta=0.0
% INFO    : Bus 3275	: V=1.00405062, theta=-33.2324474 -> V=1.0000005, theta=0.0
% INFO    : Bus 3276	: V=1.03887643, theta=-8.68889318 -> V=1.0000025, theta=0.0
% INFO    : Bus 3277	: V=1.04839242, theta=-25.2197186 -> V=1.033333, theta=0.0
% INFO    : Bus 3278	: V=1.03660215, theta=-7.91207815 -> V=1.0158755, theta=0.0
% INFO    : Bus 3279	: V=1.08121513, theta=-6.52262402 -> V=1.0377785, theta=0.0
% INFO    : Bus 3280	: V=1.129, theta=-1.4311999 -> V=0.975, theta=0.0
% INFO    : Bus 3281	: V=1.071, theta=-3.33273043 -> V=0.975, theta=0.0
% INFO    : Bus 3282	: V=1.05, theta=-3.28629294 -> V=0.975, theta=0.0
% INFO    : Bus 3283	: V=1.03800115, theta=-7.64580151 -> V=1.0158755, theta=0.0
% INFO    : Bus 3284	: V=1.03684154, theta=-7.65168001 -> V=1.0158755, theta=0.0
% INFO    : Bus 3285	: V=1.08121513, theta=-6.52262402 -> V=1.0377785, theta=0.0
% INFO    : Bus 3286	: V=1.08134848, theta=-6.50476779 -> V=1.0377785, theta=0.0
% INFO    : Bus 3287	: V=1.03856887, theta=-11.8988751 -> V=0.999999, theta=0.0
% INFO    : Bus 3288	: V=1.04480008, theta=-9.31029116 -> V=1.0111115, theta=0.0
% INFO    : Bus 3289	: V=1.04927173, theta=-25.0692987 -> V=1.033333, theta=0.0
% INFO    : Bus 3290	: V=1.08359657, theta=-0.556607145 -> V=1.0228105, theta=0.0
% INFO    : Bus 3291	: V=1.07709522, theta=-0.556607145 -> V=1.0377785, theta=0.0
% INFO    : Bus 3292	: V=1.03613217, theta=-17.167084 -> V=0.999999, theta=0.0
% INFO    : Bus 3293	: V=1.04137937, theta=-15.855453 -> V=0.999999, theta=0.0
% INFO    : Bus 3294	: V=1.0058135, theta=-13.8895018 -> V=0.999999, theta=0.0
% INFO    : Bus 3295	: V=1.01108879, theta=-9.1725463 -> V=0.999999, theta=0.0
% INFO    : Bus 3296	: V=0.983107135, theta=-34.9125632 -> V=1.0000005, theta=0.0
% INFO    : Bus 3297	: V=1.05717349, theta=-22.3502683 -> V=1.0000025, theta=0.0
% INFO    : Bus 3298	: V=1.07600703, theta=-16.315282 -> V=1.044445, theta=0.0
% INFO    : Bus 3299	: V=1.0177544, theta=-22.4433462 -> V=1.0158755, theta=0.0
% INFO    : Bus 3300	: V=1.01447298, theta=-22.8965313 -> V=1.0158755, theta=0.0
% INFO    : Bus 3301	: V=1.057, theta=-29.7213365 -> V=1.019842, theta=0.0
% INFO    : Bus 3302	: V=1.03627489, theta=-27.6521436 -> V=1.0000025, theta=0.0
% INFO    : Bus 3303	: V=0.971292771, theta=-55.6764574 -> V=1.0079355, theta=0.0
% INFO    : Bus 3304	: V=0.999505819, theta=-62.5160043 -> V=1.0079355, theta=0.0
% INFO    : Bus 3305	: V=1.02999487, theta=-17.0986603 -> V=0.999999, theta=0.0
% INFO    : Bus 3306	: V=1.00532885, theta=-36.4218139 -> V=1.0000005, theta=0.0
% INFO    : Bus 3307	: V=1.02373459, theta=-26.3216622 -> V=1.000001, theta=0.0
% INFO    : Bus 3308	: V=1.014, theta=-29.8113559 -> V=1.0000025, theta=0.0
% INFO    : Bus 3309	: V=1.04432475, theta=-35.1160131 -> V=1.022224, theta=0.0
% INFO    : Bus 3310	: V=1.06381847, theta=-22.7444912 -> V=1.044445, theta=0.0
% INFO    : Bus 3311	: V=1.03823235, theta=-19.0830852 -> V=1.0158755, theta=0.0
% INFO    : Bus 3312	: V=1.04786824, theta=-12.4372141 -> V=1.0377785, theta=0.0
% INFO    : Bus 3313	: V=1.03060675, theta=-14.5042886 -> V=0.999999, theta=0.0
% INFO    : Bus 3314	: V=1.0404539, theta=-36.0778344 -> V=1.022224, theta=0.0
% INFO    : Bus 3315	: V=1.03173312, theta=-52.2185008 -> V=1.022224, theta=0.0
% INFO    : Bus 3316	: V=1.01933373, theta=-12.1736873 -> V=1.015872, theta=0.0
% INFO    : Bus 3317	: V=1.10688164, theta=-13.4923502 -> V=1.080405, theta=0.0
% INFO    : Bus 3318	: V=1.1047832, theta=-13.4715065 -> V=1.07925, theta=0.0
% INFO    : Bus 3319	: V=1.11068193, theta=-13.5597281 -> V=1.08215, theta=0.0
% INFO    : Bus 3320	: V=1.10715456, theta=-13.488397 -> V=1.08041, theta=0.0
% INFO    : Bus 3321	: V=1.01162306, theta=-25.4994444 -> V=1.015872, theta=0.0
% INFO    : Bus 3322	: V=0.999675041, theta=-21.8807418 -> V=1.015872, theta=0.0
% INFO    : Bus 3323	: V=1.05057831, theta=-18.4549514 -> V=1.046665, theta=0.0
% INFO    : Bus 3324	: V=1.0334445, theta=-27.5721433 -> V=1.0000025, theta=0.0
% INFO    : Bus 3325	: V=1.03240446, theta=-27.7916438 -> V=1.0000025, theta=0.0
% INFO    : Bus 3326	: V=1.04033433, theta=-28.8432188 -> V=1.022224, theta=0.0
% INFO    : Bus 3327	: V=1.02404794, theta=-23.606711 -> V=1.022224, theta=0.0
% INFO    : Bus 3328	: V=1.0620925, theta=-36.0415735 -> V=1.04444, theta=0.0
% INFO    : Bus 3329	: V=1.06162775, theta=-36.09283 -> V=1.04444, theta=0.0
% INFO    : Bus 3330	: V=1.03082849, theta=-21.8358167 -> V=1.0000025, theta=0.0
% INFO    : Bus 3331	: V=1.02377625, theta=-29.0936544 -> V=1.0000025, theta=0.0
% INFO    : Bus 3332	: V=1.04711562, theta=-11.8064552 -> V=1.001264, theta=0.0
% INFO    : Bus 3333	: V=1.04743311, theta=-11.7817774 -> V=1.001419, theta=0.0
% INFO    : Bus 3334	: V=1.02531001, theta=-10.6340446 -> V=0.999999, theta=0.0
% INFO    : Bus 3335	: V=1.02108503, theta=-10.9932399 -> V=0.999999, theta=0.0
% INFO    : Bus 3336	: V=1.040517, theta=-7.12296525 -> V=1.0111115, theta=0.0
% INFO    : Bus 3337	: V=1.01135416, theta=-21.0209641 -> V=1.0158755, theta=0.0
% INFO    : Bus 3338	: V=1.01152829, theta=-31.5546173 -> V=1.0158755, theta=0.0
% INFO    : Bus 3339	: V=0.991590499, theta=-34.6024577 -> V=1.022224, theta=0.0
% INFO    : Bus 3340	: V=1.00713438, theta=-33.2488956 -> V=1.0000005, theta=0.0
% INFO    : Bus 3341	: V=1.00803755, theta=-33.2060788 -> V=1.0000005, theta=0.0
% INFO    : Bus 3342	: V=1.01741369, theta=-32.6059459 -> V=1.046665, theta=0.0
% INFO    : Bus 3343	: V=1.00032849, theta=-19.7905618 -> V=1.015872, theta=0.0
% INFO    : Bus 3344	: V=0.992534008, theta=-12.8230146 -> V=0.9444445, theta=0.0
% INFO    : Bus 3345	: V=1.05242848, theta=-12.5419247 -> V=0.999999, theta=0.0
% INFO    : Bus 3346	: V=1.0543625, theta=-8.75877196 -> V=1.0111115, theta=0.0
% INFO    : Bus 3347	: V=1.00833474, theta=-23.1695735 -> V=1.0000025, theta=0.0
% INFO    : Bus 3348	: V=0.999265176, theta=-50.9493903 -> V=1.022224, theta=0.0
% INFO    : Bus 3349	: V=0.990606965, theta=-33.1930028 -> V=1.0000005, theta=0.0
% INFO    : Bus 3350	: V=1.03049608, theta=-29.400459 -> V=1.046665, theta=0.0
% INFO    : Bus 3351	: V=1.03124073, theta=-24.3157522 -> V=1.046665, theta=0.0
% INFO    : Bus 3352	: V=1.05269339, theta=-27.3413297 -> V=1.0000025, theta=0.0
% INFO    : Bus 3353	: V=1.01539449, theta=-18.815797 -> V=0.999999, theta=0.0
% INFO    : Bus 3354	: V=1.04760881, theta=-25.5208445 -> V=1.0000025, theta=0.0
% INFO    : Bus 3355	: V=1.02508991, theta=-27.5852863 -> V=1.0000025, theta=0.0
% INFO    : Bus 3356	: V=1.02902059, theta=-27.1549423 -> V=1.0000025, theta=0.0
% INFO    : Bus 3357	: V=1.03826943, theta=-26.5655599 -> V=1.0000025, theta=0.0
% INFO    : Bus 3358	: V=1.03592527, theta=-26.3308643 -> V=1.022224, theta=0.0
% INFO    : Bus 3359	: V=0.9715644, theta=-37.2646727 -> V=1.0000005, theta=0.0
% INFO    : Bus 3360	: V=1.00119544, theta=-41.2938375 -> V=1.0000005, theta=0.0
% INFO    : Bus 3361	: V=1.00658161, theta=-37.716145 -> V=1.0000005, theta=0.0
% INFO    : Bus 3362	: V=1.01184566, theta=-33.911109 -> V=1.015872, theta=0.0
% INFO    : Bus 3363	: V=1.04578791, theta=-25.4274895 -> V=1.0000025, theta=0.0
% INFO    : Bus 3364	: V=1.06294238, theta=-21.2285198 -> V=1.044445, theta=0.0
% INFO    : Bus 3365	: V=1.02835938, theta=-37.3890516 -> V=1.022224, theta=0.0
% INFO    : Bus 3366	: V=1.12262307, theta=0.179474681 -> V=1.0415705, theta=0.0
% INFO    : Bus 3367	: V=1.08064045, theta=0.182323731 -> V=1.0382735, theta=0.0
% INFO    : Bus 3368	: V=1.05099879, theta=-22.5017403 -> V=1.073685, theta=0.0
% INFO    : Bus 3369	: V=1.03723335, theta=-60.5978079 -> V=1.0079355, theta=0.0
% INFO    : Bus 3370	: V=1.00641957, theta=-63.9051441 -> V=1.0079355, theta=0.0
% INFO    : Bus 3371	: V=1.03447579, theta=-19.8796385 -> V=1.027779, theta=0.0
% INFO    : Bus 3372	: V=1.09831292, theta=-14.9972414 -> V=1.07669, theta=0.0
% INFO    : Bus 3373	: V=1.09926914, theta=-14.7885895 -> V=1.07714, theta=0.0
% INFO    : Bus 3374	: V=1.09928291, theta=-14.801791 -> V=1.077155, theta=0.0
% INFO    : Bus 3375	: V=1.01183999, theta=-27.4336846 -> V=1.015872, theta=0.0
% INFO    : Bus 3376	: V=1.04201919, theta=-28.9359591 -> V=1.0000025, theta=0.0
% INFO    : Bus 3377	: V=1.02878371, theta=-40.1502961 -> V=1.027779, theta=0.0
% INFO    : Bus 3378	: V=1.02462437, theta=-12.1539599 -> V=0.999999, theta=0.0
% INFO    : Bus 3379	: V=1.06106565, theta=-33.4957779 -> V=1.027779, theta=0.0
% INFO    : Bus 3380	: V=1.03492673, theta=-24.6050477 -> V=1.000001, theta=0.0
% INFO    : Bus 3381	: V=1.05240996, theta=-20.4002098 -> V=0.9888895, theta=0.0
% INFO    : Bus 3382	: V=1.04242003, theta=-28.6041712 -> V=1.0111115, theta=0.0
% INFO    : Bus 3383	: V=1.05263437, theta=-26.8523151 -> V=1.0000025, theta=0.0
% INFO    : Bus 3384	: V=1.04577046, theta=-27.2136044 -> V=1.0000025, theta=0.0
% INFO    : Bus 3385	: V=1.05570235, theta=-24.0384625 -> V=1.0000025, theta=0.0
% INFO    : Bus 3386	: V=0.941671744, theta=-6.63356587 -> V=0.9444445, theta=0.0
% INFO    : Bus 3387	: V=1.01449761, theta=-59.0788172 -> V=1.0079355, theta=0.0
% INFO    : Bus 3388	: V=1.0024396, theta=-19.8795079 -> V=1.0158755, theta=0.0
% INFO    : Bus 3389	: V=1.04457324, theta=-9.32129572 -> V=1.0111115, theta=0.0
% INFO    : Bus 3390	: V=1.06745025, theta=-34.5682502 -> V=1.046665, theta=0.0
% INFO    : Bus 3391	: V=1.00191394, theta=-23.2857607 -> V=1.0158755, theta=0.0
% INFO    : Bus 3392	: V=1.01983243, theta=-32.8179788 -> V=1.022224, theta=0.0
% INFO    : Bus 3393	: V=0.939045387, theta=-38.6055472 -> V=0.9924445, theta=0.0
% INFO    : Bus 3394	: V=0.986870721, theta=-40.5954815 -> V=1.0000005, theta=0.0
% INFO    : Bus 3395	: V=1.03680399, theta=-30.9884812 -> V=1.046665, theta=0.0
% INFO    : Bus 3396	: V=1.05440175, theta=-26.035498 -> V=1.000001, theta=0.0
% INFO    : Bus 3397	: V=1.03781213, theta=-22.8622434 -> V=1.024445, theta=0.0
% INFO    : Bus 3398	: V=0.982632484, theta=-24.8668386 -> V=1.015872, theta=0.0
% INFO    : Bus 3399	: V=1.04685458, theta=-26.2470939 -> V=1.0000025, theta=0.0
% INFO    : Bus 3400	: V=1.06567528, theta=-21.0305192 -> V=1.044445, theta=0.0
% INFO    : Bus 3401	: V=1.02343137, theta=-10.3799095 -> V=1.0158755, theta=0.0
% INFO    : Bus 3402	: V=1.02876994, theta=-9.61254912 -> V=1.0158755, theta=0.0
% INFO    : Bus 3403	: V=0.988414486, theta=-34.0648648 -> V=1.0000005, theta=0.0
% INFO    : Bus 3404	: V=1.03500034, theta=-14.5273259 -> V=1.0158755, theta=0.0
% INFO    : Bus 3405	: V=1.035, theta=-14.5273216 -> V=1.0158755, theta=0.0
% INFO    : Bus 3406	: V=1.00167741, theta=-34.7990831 -> V=1.015872, theta=0.0
% INFO    : Bus 3407	: V=1.05004757, theta=-17.5504861 -> V=1.044445, theta=0.0
% INFO    : Bus 3408	: V=1.053, theta=-18.5533232 -> V=1.000214, theta=0.0
% INFO    : Bus 3409	: V=1.01798711, theta=-24.6088586 -> V=1.0000025, theta=0.0
% INFO    : Bus 3410	: V=1.00633196, theta=-12.6936308 -> V=1.0158755, theta=0.0
% INFO    : Bus 3411	: V=1.01532596, theta=-9.94007717 -> V=1.0158755, theta=0.0
% INFO    : Bus 3412	: V=1.03324298, theta=-33.7327916 -> V=1.022224, theta=0.0
% INFO    : Bus 3413	: V=1.04927069, theta=-10.778525 -> V=1.033334, theta=0.0
% INFO    : Bus 3414	: V=1.03179514, theta=-20.801075 -> V=0.999999, theta=0.0
% INFO    : Bus 3415	: V=1.01819693, theta=-20.4894149 -> V=1.015872, theta=0.0
% INFO    : Bus 3416	: V=1.08092063, theta=-22.7957519 -> V=1.07237, theta=0.0
% INFO    : Bus 3417	: V=1.00726642, theta=-37.5980823 -> V=1.015872, theta=0.0
% INFO    : Bus 3418	: V=1.031, theta=-27.0214892 -> V=1.0000025, theta=0.0
% INFO    : Bus 3419	: V=1.04093885, theta=-29.3815749 -> V=1.022224, theta=0.0
% INFO    : Bus 3420	: V=1.02447422, theta=-29.3126549 -> V=1.0000025, theta=0.0
% INFO    : Bus 3421	: V=1.03917241, theta=-28.6541547 -> V=1.022224, theta=0.0
% INFO    : Bus 3422	: V=1.00756739, theta=-13.9566244 -> V=1.015872, theta=0.0
% INFO    : Bus 3423	: V=1.03098562, theta=-25.4311085 -> V=1.022224, theta=0.0
% INFO    : Bus 3424	: V=1.003, theta=-14.3236395 -> V=0.999999, theta=0.0
% INFO    : Bus 3425	: V=1.01752165, theta=-11.8427506 -> V=0.999999, theta=0.0
% INFO    : Bus 3426	: V=1.0316701, theta=-37.9994219 -> V=1.0026455, theta=0.0
% INFO    : Bus 3427	: V=1.0560088, theta=-29.7493929 -> V=1.046665, theta=0.0
% INFO    : Bus 3428	: V=1.03918856, theta=-28.9371457 -> V=1.022224, theta=0.0
% INFO    : Bus 3429	: V=1.01892066, theta=-54.8463987 -> V=1.0079355, theta=0.0
% INFO    : Bus 3430	: V=0.99654308, theta=-11.5997679 -> V=1.015872, theta=0.0
% INFO    : Bus 3431	: V=0.997260148, theta=-15.1114767 -> V=1.015872, theta=0.0
% INFO    : Bus 3432	: V=1.04017105, theta=-21.3127871 -> V=1.000001, theta=0.0
% INFO    : Bus 3433	: V=1.0905423, theta=-14.9972121 -> V=1.078945, theta=0.0
% INFO    : Bus 3434	: V=0.997347092, theta=-53.599921 -> V=1.022224, theta=0.0
% INFO    : Bus 3435	: V=0.98060319, theta=-56.4834157 -> V=1.0079355, theta=0.0
% INFO    : Bus 3436	: V=1.01763073, theta=-54.3521846 -> V=1.022224, theta=0.0
% INFO    : Bus 3437	: V=1.03893355, theta=-31.2104132 -> V=1.022224, theta=0.0
% INFO    : Bus 3438	: V=1.04226158, theta=-29.6217232 -> V=1.046665, theta=0.0
% INFO    : Bus 3439	: V=1.05028907, theta=-61.5594263 -> V=1.0079355, theta=0.0
% INFO    : Bus 3440	: V=1.06142959, theta=-57.0153692 -> V=1.0080855, theta=0.0
% INFO    : Bus 3441	: V=1.0265651, theta=-15.223709 -> V=1.0158755, theta=0.0
% INFO    : Bus 3442	: V=0.996303309, theta=-11.2226817 -> V=0.95, theta=0.0
% INFO    : Bus 3443	: V=1.00732006, theta=-60.754584 -> V=1.0079355, theta=0.0
% INFO    : Bus 3444	: V=1.02631849, theta=-54.9829771 -> V=1.0079355, theta=0.0
% INFO    : Bus 3445	: V=1.03111234, theta=-61.7692153 -> V=1.0079355, theta=0.0
% INFO    : Bus 3446	: V=1.06071292, theta=-23.3230378 -> V=0.992091, theta=0.0
% INFO    : Bus 3447	: V=1.01270304, theta=-56.91107 -> V=1.0079355, theta=0.0
% INFO    : Bus 3448	: V=1.01826729, theta=-57.3090547 -> V=1.0079355, theta=0.0
% INFO    : Bus 3449	: V=1.02958574, theta=-41.5555482 -> V=1.022224, theta=0.0
% INFO    : Bus 3450	: V=1.02388751, theta=-65.0520507 -> V=1.0079355, theta=0.0
% INFO    : Bus 3451	: V=1.00832932, theta=-60.1531874 -> V=1.0079355, theta=0.0
% INFO    : Bus 3452	: V=1.01644922, theta=-24.4918717 -> V=1.0000025, theta=0.0
% INFO    : Bus 3453	: V=1.02060256, theta=-29.3105445 -> V=1.0000025, theta=0.0
% INFO    : Bus 3454	: V=1.03901229, theta=-39.8018909 -> V=1.027779, theta=0.0
% INFO    : Bus 3455	: V=1.01529454, theta=-29.8213302 -> V=1.022224, theta=0.0
% INFO    : Bus 3456	: V=1.02758191, theta=-19.6075795 -> V=1.0158755, theta=0.0
% INFO    : Bus 3457	: V=1.00337991, theta=-41.6757197 -> V=1.0000005, theta=0.0
% INFO    : Bus 3458	: V=1.05503064, theta=-12.8057271 -> V=0.999999, theta=0.0
% INFO    : Bus 3459	: V=1.04438296, theta=-28.1074445 -> V=1.022224, theta=0.0
% INFO    : Bus 3460	: V=1.02759704, theta=-30.0440324 -> V=1.022224, theta=0.0
% INFO    : Bus 3461	: V=0.992483282, theta=-20.2678585 -> V=1.0158755, theta=0.0
% INFO    : Bus 3462	: V=1.02089542, theta=-17.9556562 -> V=0.999999, theta=0.0
% INFO    : Bus 3463	: V=1.00663677, theta=-14.9365252 -> V=0.999999, theta=0.0
% INFO    : Bus 3464	: V=1.02702012, theta=-30.937303 -> V=1.027779, theta=0.0
% INFO    : Bus 3465	: V=1.02372877, theta=-10.866836 -> V=0.999999, theta=0.0
% INFO    : Bus 3466	: V=1.01574686, theta=-30.4931168 -> V=1.000001, theta=0.0
% INFO    : Bus 3467	: V=1.00834082, theta=-34.8371861 -> V=1.0000005, theta=0.0
% INFO    : Bus 3468	: V=1.029, theta=-10.7403145 -> V=0.999999, theta=0.0
% INFO    : Bus 3469	: V=1.04346864, theta=-29.4389858 -> V=1.022224, theta=0.0
% INFO    : Bus 3470	: V=1.05494286, theta=-17.5099047 -> V=1.046665, theta=0.0
% INFO    : Bus 3471	: V=1.00867052, theta=-17.5099991 -> V=1.05375, theta=0.0
% INFO    : Bus 3472	: V=1.00867908, theta=-37.418225 -> V=1.0000005, theta=0.0
% INFO    : Bus 3473	: V=1.0086505, theta=-37.4204265 -> V=1.0000005, theta=0.0
% INFO    : Bus 3474	: V=1.00868165, theta=-37.4181314 -> V=1.0000005, theta=0.0
% INFO    : Bus 3475	: V=1.00859683, theta=-37.4267067 -> V=1.0000005, theta=0.0
% INFO    : Bus 3476	: V=1.06062912, theta=-26.6027578 -> V=1.073685, theta=0.0
% INFO    : Bus 3477	: V=1.06342087, theta=-26.3309696 -> V=1.073685, theta=0.0
% INFO    : Bus 3478	: V=1.06062836, theta=-26.6027578 -> V=1.073685, theta=0.0
% INFO    : Bus 3479	: V=1.06062836, theta=-26.6027578 -> V=1.073685, theta=0.0
% INFO    : Bus 3480	: V=0.984324427, theta=-34.9703182 -> V=1.0000005, theta=0.0
% INFO    : Bus 3481	: V=0.984323461, theta=-34.9702898 -> V=1.0000005, theta=0.0
% INFO    : Bus 3482	: V=1.00869323, theta=-37.4178047 -> V=1.0000005, theta=0.0
% INFO    : Bus 3483	: V=1.03375811, theta=-35.4603271 -> V=1.027779, theta=0.0
% INFO    : Bus 3484	: V=1.04484532, theta=-36.1003802 -> V=1.027779, theta=0.0
% INFO    : Bus 3485	: V=1.04576887, theta=-32.2429037 -> V=1.046665, theta=0.0
% INFO    : Bus 3486	: V=0.960228831, theta=-57.0828747 -> V=1.0035795, theta=0.0
% INFO    : Bus 3487	: V=1.0267196, theta=-37.5656041 -> V=1.022224, theta=0.0
% INFO    : Bus 3488	: V=1.02269993, theta=-55.120796 -> V=1.0079355, theta=0.0
% INFO    : Bus 3489	: V=1.03803826, theta=-28.3248671 -> V=1.0000025, theta=0.0
% INFO    : Bus 3490	: V=1.02060538, theta=-13.6718809 -> V=0.999999, theta=0.0
% INFO    : Bus 3491	: V=1.1, theta=-17.0362477 -> V=1.0, theta=0.0
% INFO    : Bus 3492	: V=1.01699446, theta=-48.0338132 -> V=1.022224, theta=0.0
% INFO    : Bus 3493	: V=1.07666494, theta=-17.6878827 -> V=1.044445, theta=0.0
% INFO    : Bus 3494	: V=1.02365755, theta=-14.7149699 -> V=0.999999, theta=0.0
% INFO    : Bus 3495	: V=0.997246941, theta=-66.1819923 -> V=1.0079355, theta=0.0
% INFO    : Bus 3496	: V=1.00584762, theta=-31.6975038 -> V=1.0158755, theta=0.0
% INFO    : Bus 3497	: V=1.02575739, theta=-11.4829849 -> V=1.0158755, theta=0.0
% INFO    : Bus 3498	: V=1.04228766, theta=-44.9436865 -> V=1.022224, theta=0.0
% INFO    : Bus 3499	: V=1.00786636, theta=-14.5709874 -> V=1.015872, theta=0.0
% INFO    : Bus 3500	: V=1.05212965, theta=-23.2505483 -> V=1.0000025, theta=0.0
% INFO    : Bus 3501	: V=1.02721103, theta=-27.1507904 -> V=1.0000025, theta=0.0
% INFO    : Bus 3502	: V=1.05684789, theta=-15.0980234 -> V=1.0000025, theta=0.0
% INFO    : Bus 3503	: V=1.06123937, theta=-9.89876356 -> V=1.044445, theta=0.0
% INFO    : Bus 3504	: V=1.073, theta=-13.7676079 -> V=1.044445, theta=0.0
% INFO    : Bus 3505	: V=1.02457197, theta=-11.4405628 -> V=0.975, theta=0.0
% INFO    : Bus 3506	: V=1.02354842, theta=-11.4405628 -> V=0.999999, theta=0.0
% INFO    : Bus 3507	: V=1.03687693, theta=-20.5520501 -> V=0.999999, theta=0.0
% INFO    : Bus 3508	: V=1.03723733, theta=-18.0536584 -> V=0.999999, theta=0.0
% INFO    : Bus 3509	: V=1.0524434, theta=-13.3375161 -> V=1.0111115, theta=0.0
% INFO    : Bus 3510	: V=1.05737587, theta=-60.4193137 -> V=1.0079355, theta=0.0
% INFO    : Bus 3511	: V=1.02028186, theta=-49.7370697 -> V=1.022224, theta=0.0
% INFO    : Bus 3512	: V=1.01151419, theta=-25.4494763 -> V=0.999999, theta=0.0
% INFO    : Bus 3513	: V=1.01673553, theta=-16.2346497 -> V=1.0158755, theta=0.0
% INFO    : Bus 3514	: V=1.04902337, theta=-26.8469819 -> V=1.022224, theta=0.0
% INFO    : Bus 3515	: V=1.07964202, theta=-15.5355773 -> V=1.07237, theta=0.0
% INFO    : Bus 3516	: V=1.07970603, theta=-15.5247607 -> V=1.07237, theta=0.0
% INFO    : Bus 3517	: V=1.02409151, theta=-23.8175782 -> V=1.0158755, theta=0.0
% INFO    : Bus 3518	: V=1.05657949, theta=-20.3463642 -> V=1.0377785, theta=0.0
% INFO    : Bus 3519	: V=1.03674682, theta=-25.262193 -> V=1.0000025, theta=0.0
% INFO    : Bus 3520	: V=1.04501675, theta=-22.1631428 -> V=1.0111115, theta=0.0
% INFO    : Bus 3521	: V=1.06220554, theta=-12.9434545 -> V=0.999999, theta=0.0
% INFO    : Bus 3522	: V=1.06110159, theta=-11.9678174 -> V=0.999999, theta=0.0
% INFO    : Bus 3523	: V=1.06149529, theta=-8.67405511 -> V=1.0111115, theta=0.0
% INFO    : Bus 3524	: V=1.0383947, theta=-31.9625129 -> V=1.022224, theta=0.0
% INFO    : Bus 3525	: V=1.02523114, theta=-10.8601432 -> V=1.0158755, theta=0.0
% INFO    : Bus 3526	: V=1.0256977, theta=-31.3673867 -> V=1.022224, theta=0.0
% INFO    : Bus 3527	: V=1.01840359, theta=-21.2609898 -> V=1.0000025, theta=0.0
% INFO    : Bus 3528	: V=1.03605987, theta=-31.3280312 -> V=1.046665, theta=0.0
% INFO    : Bus 3529	: V=1.05163711, theta=-11.264128 -> V=1.06579, theta=0.0
% INFO    : Bus 3530	: V=0.988672118, theta=-16.3363541 -> V=1.015872, theta=0.0
% INFO    : Bus 3531	: V=1.03754927, theta=-9.71768715 -> V=1.0158755, theta=0.0
% INFO    : Bus 3532	: V=0.984465049, theta=-34.0261868 -> V=1.0000005, theta=0.0
% INFO    : Bus 3533	: V=1.05076018, theta=-18.4363814 -> V=1.033334, theta=0.0
% INFO    : Bus 3534	: V=1.0507316, theta=-18.4463825 -> V=1.033334, theta=0.0
% INFO    : Bus 3535	: V=1.05532261, theta=-17.183259 -> V=1.0000025, theta=0.0
% INFO    : Bus 3536	: V=1.0552564, theta=-17.190894 -> V=1.0000025, theta=0.0
% INFO    : Bus 3537	: V=1.06090025, theta=-7.48117788 -> V=1.046665, theta=0.0
% INFO    : Bus 3538	: V=1.05400802, theta=-23.954007 -> V=1.0111115, theta=0.0
% INFO    : Bus 3539	: V=1.03851895, theta=-20.9990747 -> V=1.0088895, theta=0.0
% INFO    : Bus 3540	: V=1.04876689, theta=-5.77961852 -> V=1.0111115, theta=0.0
% INFO    : Bus 3541	: V=1.02842081, theta=-27.5586023 -> V=1.0000025, theta=0.0
% INFO    : Bus 3542	: V=1.02120726, theta=-16.2681433 -> V=1.0158755, theta=0.0
% INFO    : Bus 3543	: V=1.0519003, theta=-11.5519291 -> V=1.0377785, theta=0.0
% INFO    : Bus 3544	: V=1.042, theta=-11.2278841 -> V=0.999999, theta=0.0
% INFO    : Bus 3545	: V=1.0537125, theta=-48.3474298 -> V=1.0079355, theta=0.0
% INFO    : Bus 3546	: V=1.06478216, theta=-43.9335221 -> V=1.04444, theta=0.0
% INFO    : Bus 3547	: V=1.02245512, theta=-16.9568298 -> V=1.015872, theta=0.0
% INFO    : Bus 3548	: V=1.03684538, theta=-19.7349075 -> V=1.0000025, theta=0.0
% INFO    : Bus 3549	: V=1.12324661, theta=0.169439875 -> V=1.0414805, theta=0.0
% INFO    : Bus 3550	: V=1.03153897, theta=-3.60070123 -> V=1.0158755, theta=0.0
% INFO    : Bus 3551	: V=0.996509203, theta=-66.7301877 -> V=1.0079355, theta=0.0
% INFO    : Bus 3552	: V=1.00597927, theta=-46.7804286 -> V=1.022224, theta=0.0
% INFO    : Bus 3553	: V=1.06047376, theta=-16.9293865 -> V=0.999999, theta=0.0
% INFO    : Bus 3554	: V=1.01511718, theta=-37.5247694 -> V=1.015872, theta=0.0
% INFO    : Bus 3555	: V=1.01157647, theta=-38.1423101 -> V=1.0000005, theta=0.0
% INFO    : Bus 3556	: V=1.03963161, theta=-32.5617465 -> V=1.046665, theta=0.0
% INFO    : Bus 3557	: V=0.999201271, theta=-19.6641665 -> V=1.0000025, theta=0.0
% INFO    : Bus 3558	: V=1.03069949, theta=-27.8996712 -> V=1.0000025, theta=0.0
% INFO    : Bus 3559	: V=1.02234023, theta=-16.8494401 -> V=1.0158755, theta=0.0
% INFO    : Bus 3560	: V=1.05332346, theta=-14.2513427 -> V=1.0377785, theta=0.0
% INFO    : Bus 3561	: V=1.01177594, theta=-39.5294915 -> V=1.0000005, theta=0.0
% INFO    : Bus 3562	: V=1.06672043, theta=-34.639812 -> V=1.046665, theta=0.0
% INFO    : Bus 3563	: V=1.06674158, theta=-34.6400046 -> V=1.046665, theta=0.0
% INFO    : Bus 3564	: V=1.01194049, theta=-39.424215 -> V=1.0000005, theta=0.0
% INFO    : Bus 3565	: V=1.06678525, theta=-34.6321562 -> V=1.046665, theta=0.0
% INFO    : Bus 3566	: V=1.01313692, theta=-3.80725036 -> V=1.0158755, theta=0.0
% INFO    : Bus 3567	: V=1.03312506, theta=-47.5490329 -> V=1.022224, theta=0.0
% INFO    : Bus 3568	: V=1.03693836, theta=-27.7121597 -> V=1.0000025, theta=0.0
% INFO    : Bus 3569	: V=1.02960468, theta=-22.3978129 -> V=1.000001, theta=0.0
% INFO    : Bus 3570	: V=1.05694162, theta=-33.6555454 -> V=1.022224, theta=0.0
% INFO    : Bus 3571	: V=1.02670019, theta=-20.688229 -> V=0.999999, theta=0.0
% INFO    : Bus 3572	: V=1.0290633, theta=-19.2097706 -> V=1.0158755, theta=0.0
% INFO    : Bus 3573	: V=1.04543596, theta=-15.8486287 -> V=1.0377785, theta=0.0
% INFO    : Bus 3574	: V=1.03378638, theta=-31.8484313 -> V=1.046665, theta=0.0
% INFO    : Bus 3575	: V=1.04176146, theta=-13.2304765 -> V=0.999999, theta=0.0
% INFO    : Bus 3576	: V=0.986910969, theta=-67.233025 -> V=1.0079355, theta=0.0
% INFO    : Bus 3577	: V=1.04186847, theta=-27.5003721 -> V=1.0000025, theta=0.0
% INFO    : Bus 3578	: V=1.02661329, theta=-5.87285788 -> V=0.999999, theta=0.0
% INFO    : Bus 3579	: V=1.05402181, theta=-4.43315235 -> V=1.0111115, theta=0.0
% INFO    : Bus 3580	: V=1.06749745, theta=-12.4557262 -> V=1.072365, theta=0.0
% INFO    : Bus 3581	: V=1.0673108, theta=-2.58294789 -> V=1.072365, theta=0.0
% INFO    : Bus 3582	: V=1.01512571, theta=-32.7345134 -> V=1.015872, theta=0.0
% INFO    : Bus 3583	: V=1.03394784, theta=-33.0314811 -> V=1.027779, theta=0.0
% INFO    : Bus 3584	: V=1.03046855, theta=-35.3229816 -> V=1.027779, theta=0.0
% INFO    : Bus 3585	: V=1.0187711, theta=-22.4635726 -> V=1.0158755, theta=0.0
% INFO    : Bus 3586	: V=1.032, theta=-9.86345028 -> V=0.975, theta=0.0
% INFO    : Bus 3587	: V=1.023, theta=-8.24372693 -> V=0.975, theta=0.0
% INFO    : Bus 3588	: V=1.03825558, theta=-11.9631535 -> V=0.999999, theta=0.0
% INFO    : Bus 3589	: V=1.03612424, theta=-12.0440531 -> V=0.999999, theta=0.0
% INFO    : Bus 3590	: V=0.999986984, theta=-23.5637557 -> V=1.0158755, theta=0.0
% INFO    : Bus 3591	: V=1.02844818, theta=-24.2483665 -> V=1.0158755, theta=0.0
% INFO    : Bus 3592	: V=0.998133929, theta=-20.6923532 -> V=1.0, theta=0.0
% INFO    : Bus 3593	: V=1.04505478, theta=-29.2910099 -> V=1.046665, theta=0.0
% INFO    : Bus 3594	: V=0.995834885, theta=-11.5921954 -> V=1.015872, theta=0.0
% INFO    : Bus 3595	: V=1.06316849, theta=-9.29704681 -> V=1.046665, theta=0.0
% INFO    : Bus 3596	: V=1.00989406, theta=-22.3030916 -> V=1.015872, theta=0.0
% INFO    : Bus 3597	: V=1.05291382, theta=-17.9098159 -> V=1.046665, theta=0.0
% INFO    : Bus 3598	: V=1.0489369, theta=-25.0743228 -> V=1.016666, theta=0.0
% INFO    : Bus 3599	: V=1.03613472, theta=-28.0579943 -> V=1.0000025, theta=0.0
% INFO    : Bus 3600	: V=1.069, theta=-20.8736574 -> V=1.000001, theta=0.0
% INFO    : Bus 3601	: V=1.06436029, theta=-18.4041284 -> V=1.044445, theta=0.0
% INFO    : Bus 3602	: V=1.01926853, theta=-61.1900807 -> V=1.0079355, theta=0.0
% INFO    : Bus 3603	: V=1.04705463, theta=-55.6900839 -> V=1.04444, theta=0.0
% INFO    : Bus 3604	: V=1.008, theta=-5.14050998 -> V=0.999999, theta=0.0
% INFO    : Bus 3605	: V=1.08257908, theta=-0.765630576 -> V=1.072365, theta=0.0
% INFO    : Bus 3606	: V=1.03073433, theta=-21.6439458 -> V=1.000001, theta=0.0
% INFO    : Bus 3607	: V=1.04841092, theta=-6.24293471 -> V=1.0111115, theta=0.0
% INFO    : Bus 3608	: V=1.02310034, theta=-13.5482948 -> V=0.999999, theta=0.0
% INFO    : Bus 3609	: V=1.03848371, theta=-8.97061883 -> V=1.0111115, theta=0.0
% INFO    : Bus 3610	: V=1.05870242, theta=-23.6470828 -> V=1.0000025, theta=0.0
% INFO    : Bus 3611	: V=1.02220651, theta=-13.6528953 -> V=1.015872, theta=0.0
% INFO    : Bus 3612	: V=1.02727446, theta=-30.752037 -> V=1.046665, theta=0.0
% INFO    : Bus 3613	: V=1.04390134, theta=-30.1697375 -> V=1.046665, theta=0.0
% INFO    : Bus 3614	: V=1.0384496, theta=-30.631344 -> V=1.046665, theta=0.0
% INFO    : Bus 3615	: V=1.05114713, theta=-24.4452039 -> V=1.073685, theta=0.0
% INFO    : Bus 3616	: V=1.05064718, theta=-24.9382744 -> V=1.073685, theta=0.0
% INFO    : Bus 3617	: V=1.01418203, theta=-44.1555411 -> V=1.022224, theta=0.0
% INFO    : Bus 3618	: V=1.01032049, theta=-43.6108582 -> V=1.022224, theta=0.0
% INFO    : Bus 3619	: V=1.00736994, theta=-34.5415768 -> V=1.015872, theta=0.0
% INFO    : Bus 3620	: V=1.0408957, theta=-31.2623278 -> V=1.046665, theta=0.0
% INFO    : Bus 3621	: V=1.03553434, theta=-26.3432682 -> V=1.0000025, theta=0.0
% INFO    : Bus 3622	: V=1.02424045, theta=-27.5639659 -> V=0.999999, theta=0.0
% INFO    : Bus 3623	: V=1.05075674, theta=-50.2776798 -> V=1.04444, theta=0.0
% INFO    : Bus 3624	: V=1.05169792, theta=-43.4275575 -> V=1.07033, theta=0.0
% INFO    : Bus 3625	: V=1.02295208, theta=-12.2167607 -> V=0.999999, theta=0.0
% INFO    : Bus 3626	: V=1.02745383, theta=-30.9276661 -> V=1.027779, theta=0.0
% INFO    : Bus 3627	: V=1.02747205, theta=-30.9258067 -> V=1.027779, theta=0.0
% INFO    : Bus 3628	: V=1.00712437, theta=-33.7209416 -> V=1.015872, theta=0.0
% INFO    : Bus 3629	: V=1.00711612, theta=-33.7408252 -> V=1.015872, theta=0.0
% INFO    : Bus 3630	: V=1.02747976, theta=-30.9238684 -> V=1.027779, theta=0.0
% INFO    : Bus 3631	: V=1.06869371, theta=-27.3834614 -> V=1.046665, theta=0.0
% INFO    : Bus 3632	: V=0.988721075, theta=-33.0157248 -> V=1.0000005, theta=0.0
% INFO    : Bus 3633	: V=1.04870253, theta=-30.4646454 -> V=1.046665, theta=0.0
% INFO    : Bus 3634	: V=1.00600764, theta=-25.8496096 -> V=1.015872, theta=0.0
% INFO    : Bus 3635	: V=1.02469955, theta=-9.86060628 -> V=0.999999, theta=0.0
% INFO    : Bus 3636	: V=1.05214228, theta=-17.2347563 -> V=1.001569, theta=0.0
% INFO    : Bus 3637	: V=1.01182012, theta=-43.9712575 -> V=1.022224, theta=0.0
% INFO    : Bus 3638	: V=1.04166122, theta=-20.2613027 -> V=0.9888895, theta=0.0
% INFO    : Bus 3639	: V=1.0396816, theta=-27.2711451 -> V=1.0000025, theta=0.0
% INFO    : Bus 3640	: V=1.01517558, theta=-30.9063212 -> V=1.0000005, theta=0.0
% INFO    : Bus 3641	: V=1.00975799, theta=-31.6089036 -> V=1.0000005, theta=0.0
% INFO    : Bus 3642	: V=1.02263899, theta=-22.6632851 -> V=0.999999, theta=0.0
% INFO    : Bus 3643	: V=1.03901341, theta=-29.1545575 -> V=1.022224, theta=0.0
% INFO    : Bus 3644	: V=1.0126959, theta=-24.0094122 -> V=1.0158755, theta=0.0
% INFO    : Bus 3645	: V=1.0136398, theta=-3.26074235 -> V=1.0158755, theta=0.0
% INFO    : Bus 3646	: V=0.987570066, theta=-23.1126517 -> V=1.0000025, theta=0.0
% INFO    : Bus 3647	: V=1.02930391, theta=-18.0799174 -> V=1.015872, theta=0.0
% INFO    : Bus 3648	: V=1.04626594, theta=-14.0383845 -> V=1.046665, theta=0.0
% INFO    : Bus 3649	: V=0.99941463, theta=-52.405176 -> V=1.022224, theta=0.0
% INFO    : Bus 3650	: V=1.03751863, theta=-9.71676272 -> V=1.0158755, theta=0.0
% INFO    : Bus 3651	: V=1.057, theta=-16.567728 -> V=1.0000025, theta=0.0
% INFO    : Bus 3652	: V=1.03610794, theta=-7.97097995 -> V=1.0158755, theta=0.0
% INFO    : Bus 3653	: V=1.0214683, theta=-11.0664152 -> V=1.0158755, theta=0.0
% INFO    : Bus 3654	: V=1.04798717, theta=-9.16162834 -> V=1.0158755, theta=0.0
% INFO    : Bus 3655	: V=1.05216596, theta=-5.37358799 -> V=1.0377785, theta=0.0
% INFO    : Bus 3656	: V=1.02199854, theta=-20.513098 -> V=1.015872, theta=0.0
% INFO    : Bus 3657	: V=1.02033272, theta=-22.6776173 -> V=1.0000025, theta=0.0
% INFO    : Bus 3658	: V=1.01108749, theta=-15.3439474 -> V=0.999999, theta=0.0
% INFO    : Bus 3659	: V=1.01071085, theta=-15.3237215 -> V=0.999999, theta=0.0
% INFO    : Bus 3660	: V=1.02723126, theta=-13.9427665 -> V=1.0158755, theta=0.0
% INFO    : Bus 3661	: V=1.00354697, theta=-55.2406271 -> V=1.0079355, theta=0.0
% INFO    : Bus 3662	: V=1.03225366, theta=-1.89795706 -> V=1.0158755, theta=0.0
% INFO    : Bus 3663	: V=1.07684792, theta=1.02386828 -> V=1.0377785, theta=0.0
% INFO    : Bus 3664	: V=1.0167485, theta=-58.7418677 -> V=1.0079355, theta=0.0
% INFO    : Bus 3665	: V=1.05495692, theta=-52.0434406 -> V=1.04444, theta=0.0
% INFO    : Bus 3666	: V=1.05907791, theta=-53.7249015 -> V=1.04444, theta=0.0
% INFO    : Bus 3667	: V=1.00029558, theta=-14.0338861 -> V=0.999999, theta=0.0
% INFO    : Bus 3668	: V=1.03122495, theta=-16.6654929 -> V=0.999999, theta=0.0
% INFO    : Bus 3669	: V=1.03743448, theta=-17.7049292 -> V=0.999999, theta=0.0
% INFO    : Bus 3670	: V=1.05926998, theta=-19.881712 -> V=1.016666, theta=0.0
% INFO    : Bus 3671	: V=1.06380924, theta=-16.4898656 -> V=1.006667, theta=0.0
% INFO    : Bus 3672	: V=1.00845412, theta=-25.8680375 -> V=1.0158755, theta=0.0
% INFO    : Bus 3673	: V=1.03214493, theta=-15.7091917 -> V=0.999999, theta=0.0
% INFO    : Bus 3674	: V=1.05180762, theta=-29.9300228 -> V=1.027779, theta=0.0
% INFO    : Bus 3675	: V=1.07712039, theta=-26.5059906 -> V=1.046665, theta=0.0
% INFO    : Bus 3676	: V=1.03045417, theta=-2.06492688 -> V=1.0158755, theta=0.0
% INFO    : Bus 3677	: V=1.03135813, theta=-1.94728537 -> V=1.0158755, theta=0.0
% INFO    : Bus 3678	: V=1.05674695, theta=-30.1563365 -> V=1.0000025, theta=0.0
% INFO    : Bus 3679	: V=1.06389316, theta=-22.7201477 -> V=1.044445, theta=0.0
% INFO    : Bus 3680	: V=1.03995054, theta=-12.0117877 -> V=0.999999, theta=0.0
% INFO    : Bus 3681	: V=1.04652421, theta=-12.072576 -> V=1.000979, theta=0.0
% INFO    : Bus 3682	: V=1.04233792, theta=-8.79405181 -> V=1.0000025, theta=0.0
% INFO    : Bus 3683	: V=1.04769071, theta=-17.3901501 -> V=1.044445, theta=0.0
% INFO    : Bus 3684	: V=1.02810902, theta=-35.0533806 -> V=1.015872, theta=0.0
% INFO    : Bus 3685	: V=1.03175265, theta=-19.7641329 -> V=1.0158755, theta=0.0
% INFO    : Bus 3686	: V=1.01791782, theta=-13.1515433 -> V=0.999999, theta=0.0
% INFO    : Bus 3687	: V=1.04183238, theta=-14.8215753 -> V=1.0377785, theta=0.0
% INFO    : Bus 3688	: V=1.01699113, theta=-8.10481582 -> V=0.999999, theta=0.0
% INFO    : Bus 3689	: V=1.05113921, theta=-18.2290757 -> V=0.9888895, theta=0.0
% INFO    : Bus 3690	: V=1.06278105, theta=-23.0997394 -> V=1.0010775, theta=0.0
% INFO    : Bus 3691	: V=1.04793698, theta=-12.4441225 -> V=1.0377785, theta=0.0
% INFO    : Bus 3692	: V=1.04, theta=-12.3628366 -> V=0.999999, theta=0.0
% INFO    : Bus 3693	: V=1.01991998, theta=-28.9562749 -> V=1.022222, theta=0.0
% INFO    : Bus 3694	: V=1.04900677, theta=-21.1844578 -> V=1.0111115, theta=0.0
% INFO    : Bus 3695	: V=1.04107295, theta=-60.6832019 -> V=1.0079355, theta=0.0
% INFO    : Bus 3696	: V=1.03622505, theta=-22.0418263 -> V=0.999999, theta=0.0
% INFO    : Bus 3697	: V=1.01014894, theta=-10.7733078 -> V=1.0158755, theta=0.0
% INFO    : Bus 3698	: V=1.00576292, theta=-69.9267302 -> V=1.0079355, theta=0.0
% INFO    : Bus 3699	: V=1.00349601, theta=-61.874142 -> V=1.0079355, theta=0.0
% INFO    : Bus 3700	: V=1.01664, theta=-62.9925754 -> V=1.0079355, theta=0.0
% INFO    : Bus 3701	: V=1.02745728, theta=-16.7892447 -> V=0.999999, theta=0.0
% INFO    : Bus 3702	: V=1.01015955, theta=-22.8568728 -> V=1.0158755, theta=0.0
% INFO    : Bus 3703	: V=1.0525505, theta=-17.9480703 -> V=1.033334, theta=0.0
% INFO    : Bus 3704	: V=1.06158975, theta=-36.0312959 -> V=1.04444, theta=0.0
% INFO    : Bus 3705	: V=1.07071815, theta=-32.1543004 -> V=1.07237, theta=0.0
% INFO    : Bus 3706	: V=1.00897948, theta=-31.1220808 -> V=1.0158755, theta=0.0
% INFO    : Bus 3707	: V=1.05842738, theta=-17.0461372 -> V=0.9888895, theta=0.0
% INFO    : Bus 3708	: V=0.98397988, theta=-34.876116 -> V=1.0000005, theta=0.0
% INFO    : Bus 3709	: V=1.01879859, theta=-22.181391 -> V=1.0000025, theta=0.0
% INFO    : Bus 3710	: V=1.05473127, theta=-16.7465282 -> V=1.044445, theta=0.0
% INFO    : Bus 3711	: V=0.977587651, theta=-22.5114123 -> V=1.015872, theta=0.0
% INFO    : Bus 3712	: V=1.04737064, theta=-19.7470188 -> V=1.046665, theta=0.0
% INFO    : Bus 3713	: V=1.03660055, theta=-59.7775595 -> V=1.0079355, theta=0.0
% INFO    : Bus 3714	: V=1.05157838, theta=-34.3306002 -> V=1.022224, theta=0.0
% INFO    : Bus 3715	: V=1.048, theta=-30.6371013 -> V=1.027779, theta=0.0
% INFO    : Bus 3716	: V=1.02663414, theta=-11.2171577 -> V=0.999999, theta=0.0
% INFO    : Bus 3717	: V=1.036, theta=-12.2239692 -> V=0.999999, theta=0.0
% INFO    : Bus 3718	: V=1.01853209, theta=-11.1409746 -> V=1.0158755, theta=0.0
% INFO    : Bus 3719	: V=1.03463946, theta=-38.2049242 -> V=1.0041355, theta=0.0
% INFO    : Bus 3720	: V=0.994233681, theta=-41.9764727 -> V=1.027779, theta=0.0
% INFO    : Bus 3721	: V=1.05114264, theta=-30.9442003 -> V=1.0000025, theta=0.0
% INFO    : Bus 3722	: V=1.03381299, theta=-51.7167608 -> V=1.0079355, theta=0.0
% INFO    : Bus 3723	: V=1.02628675, theta=-53.9845497 -> V=1.0079355, theta=0.0
% INFO    : Bus 3724	: V=1.03260091, theta=-47.0610906 -> V=1.04444, theta=0.0
% INFO    : Bus 3725	: V=1.03260032, theta=-47.0610745 -> V=1.04444, theta=0.0
% INFO    : Bus 3726	: V=1.03259991, theta=-47.0610631 -> V=1.04444, theta=0.0
% INFO    : Bus 3727	: V=0.938816943, theta=-6.53938592 -> V=0.9444445, theta=0.0
% INFO    : Bus 3728	: V=1.00584999, theta=-6.94353156 -> V=0.999999, theta=0.0
% INFO    : Bus 3729	: V=1.05362754, theta=-4.5159757 -> V=1.003335, theta=0.0
% INFO    : Bus 3730	: V=1.05588393, theta=-7.16117961 -> V=1.0111115, theta=0.0
% INFO    : Bus 3731	: V=1.01513499, theta=-5.52453221 -> V=1.0158755, theta=0.0
% INFO    : Bus 3732	: V=0.96437228, theta=-35.7699192 -> V=1.0000005, theta=0.0
% INFO    : Bus 3733	: V=0.99391134, theta=-35.2955719 -> V=1.0000005, theta=0.0
% INFO    : Bus 3734	: V=1.02329316, theta=-36.2918416 -> V=1.027779, theta=0.0
% INFO    : Bus 3735	: V=1.06130314, theta=-32.5542948 -> V=1.046665, theta=0.0
% INFO    : Bus 3736	: V=1.03387233, theta=-51.7153656 -> V=1.0079355, theta=0.0
% INFO    : Bus 3737	: V=1.02726329, theta=-51.4157402 -> V=1.04444, theta=0.0
% INFO    : Bus 3738	: V=1.03259846, theta=-47.0610229 -> V=1.04444, theta=0.0
% INFO    : Bus 3739	: V=1.02506263, theta=-10.6031034 -> V=1.0158755, theta=0.0
% INFO    : Bus 3740	: V=1.00938337, theta=-31.9005466 -> V=1.0000005, theta=0.0
% INFO    : Bus 3741	: V=1.00935165, theta=-31.9052471 -> V=1.0000005, theta=0.0
% INFO    : Bus 3742	: V=0.992061047, theta=-21.6560124 -> V=1.015872, theta=0.0
% INFO    : Bus 3743	: V=1.05173137, theta=-16.5999335 -> V=1.046665, theta=0.0
% INFO    : Bus 3744	: V=1.05021303, theta=-12.9913459 -> V=0.999999, theta=0.0
% INFO    : Bus 3745	: V=1.04897793, theta=-28.9048322 -> V=1.027779, theta=0.0
% INFO    : Bus 3746	: V=1.07719012, theta=-26.6473396 -> V=1.046665, theta=0.0
% INFO    : Bus 3747	: V=1.04313915, theta=-21.9339936 -> V=1.022224, theta=0.0
% INFO    : Bus 3748	: V=1.029, theta=-20.6004529 -> V=0.999999, theta=0.0
% INFO    : Bus 3749	: V=1.00800937, theta=-24.0897602 -> V=1.0000025, theta=0.0
% INFO    : Bus 3750	: V=1.01310682, theta=-24.4513384 -> V=1.0000025, theta=0.0
% INFO    : Bus 3751	: V=1.04910957, theta=-18.0849174 -> V=1.046665, theta=0.0
% INFO    : Bus 3752	: V=1.04151935, theta=-15.4980839 -> V=1.06579, theta=0.0
% INFO    : Bus 3753	: V=1.03624504, theta=-41.2588033 -> V=1.022224, theta=0.0
% INFO    : Bus 3754	: V=1.01183153, theta=-14.0405641 -> V=1.015872, theta=0.0
% INFO    : Bus 3755	: V=1.01501163, theta=-46.4557171 -> V=1.022224, theta=0.0
% INFO    : Bus 3756	: V=1.05417081, theta=-42.0514705 -> V=1.04444, theta=0.0
% INFO    : Bus 3757	: V=1.04815841, theta=-50.1154764 -> V=1.022224, theta=0.0
% INFO    : Bus 3758	: V=1.02454292, theta=-15.9163831 -> V=0.984126, theta=0.0
% INFO    : Bus 3759	: V=1.03096188, theta=-13.9052419 -> V=0.9888895, theta=0.0
% INFO    : Bus 3760	: V=1.00763807, theta=-67.3911442 -> V=1.0079355, theta=0.0
% INFO    : Bus 3761	: V=1.011, theta=-15.8048089 -> V=1.0158755, theta=0.0
% INFO    : Bus 3762	: V=1.00952725, theta=-34.8204083 -> V=1.0000005, theta=0.0
% INFO    : Bus 3763	: V=1.01777624, theta=-10.7768009 -> V=1.0158755, theta=0.0
% INFO    : Bus 3764	: V=1.05275723, theta=-5.56284071 -> V=1.0377785, theta=0.0
% INFO    : Bus 3765	: V=1.01777269, theta=-5.56717646 -> V=1.0158755, theta=0.0
% INFO    : Bus 3766	: V=0.998443451, theta=-46.5980159 -> V=1.027779, theta=0.0
% INFO    : Bus 3767	: V=1.05637947, theta=-16.6691086 -> V=1.046665, theta=0.0
% INFO    : Bus 3768	: V=1.03583556, theta=-29.2945567 -> V=1.022224, theta=0.0
% INFO    : Bus 3769	: V=1.03489098, theta=-29.048837 -> V=1.022224, theta=0.0
% INFO    : Bus 3770	: V=1.08162449, theta=-0.0140613877 -> V=1.0396135, theta=0.0
% INFO    : Bus 3771	: V=1.02162364, theta=-4.37761796 -> V=1.0158755, theta=0.0
% INFO    : Bus 3772	: V=1.02156238, theta=-13.3069798 -> V=1.0158755, theta=0.0
% INFO    : Bus 3773	: V=1.00551599, theta=-28.9809584 -> V=1.0000005, theta=0.0
% INFO    : Bus 3774	: V=1.06627254, theta=-22.2711678 -> V=1.073685, theta=0.0
% INFO    : Bus 3775	: V=1.02072024, theta=-17.8697549 -> V=1.0158755, theta=0.0
% INFO    : Bus 3776	: V=1.00686582, theta=-18.5055654 -> V=1.015872, theta=0.0
% INFO    : Bus 3777	: V=0.98890168, theta=-19.7492485 -> V=1.015872, theta=0.0
% INFO    : Bus 3778	: V=1.01852135, theta=-19.971209 -> V=1.015872, theta=0.0
% INFO    : Bus 3779	: V=1.05380679, theta=-17.7308076 -> V=1.046665, theta=0.0
% INFO    : Bus 3780	: V=1.05381012, theta=-17.7367979 -> V=1.046665, theta=0.0
% INFO    : Bus 3781	: V=1.05366361, theta=-17.7373229 -> V=1.046665, theta=0.0
% INFO    : Bus 3782	: V=1.01373917, theta=-29.7895978 -> V=1.0000005, theta=0.0
% INFO    : Bus 3783	: V=1.03577738, theta=-23.9572908 -> V=1.046665, theta=0.0
% INFO    : Bus 3784	: V=1.06844702, theta=-17.25168 -> V=1.073685, theta=0.0
% INFO    : Bus 3785	: V=1.02791192, theta=-41.269415 -> V=1.022224, theta=0.0
% INFO    : Bus 3786	: V=1.02275601, theta=2.40784131 -> V=1.046665, theta=0.0
% INFO    : Bus 3787	: V=1.02123772, theta=2.66323393 -> V=1.046665, theta=0.0
% INFO    : Bus 3788	: V=1.05063047, theta=-43.9495561 -> V=0.975, theta=0.0
% INFO    : Bus 3789	: V=1.05048314, theta=-44.0291335 -> V=0.975, theta=0.0
% INFO    : Bus 3790	: V=1.05048314, theta=-44.0291335 -> V=0.975, theta=0.0
% INFO    : Bus 3791	: V=1.05068207, theta=-43.9397089 -> V=1.04444, theta=0.0
% INFO    : Bus 3792	: V=1.05048314, theta=-44.0291335 -> V=1.04444, theta=0.0
% INFO    : Bus 3793	: V=1.03467236, theta=-28.8390702 -> V=1.0000025, theta=0.0
% INFO    : Bus 3794	: V=1.01235637, theta=-26.1408605 -> V=1.000001, theta=0.0
% INFO    : Bus 3795	: V=1.00054878, theta=-20.5163258 -> V=1.015872, theta=0.0
% INFO    : Bus 3796	: V=1.06097821, theta=-21.5991966 -> V=1.0000025, theta=0.0
% INFO    : Bus 3797	: V=1.07471817, theta=-20.2530904 -> V=1.0000025, theta=0.0
% INFO    : Bus 3798	: V=1.01710041, theta=-31.3173015 -> V=1.0000005, theta=0.0
% INFO    : Bus 3799	: V=1.02727931, theta=-18.287002 -> V=1.0000025, theta=0.0
% INFO    : Bus 3800	: V=1.01015668, theta=-15.3063847 -> V=0.999999, theta=0.0
% INFO    : Bus 3801	: V=1.02484474, theta=-28.576517 -> V=1.0000025, theta=0.0
% INFO    : Bus 3802	: V=1.01288764, theta=-14.450864 -> V=0.999999, theta=0.0
% INFO    : Bus 3803	: V=1.03516422, theta=-31.7087704 -> V=1.046665, theta=0.0
% INFO    : Bus 3804	: V=1.03488378, theta=-31.7225827 -> V=1.046665, theta=0.0
% INFO    : Bus 3805	: V=1.07997154, theta=-1.08246954 -> V=1.05263, theta=0.0
% INFO    : Bus 3806	: V=1.0794926, theta=-1.08002921 -> V=1.05263, theta=0.0
% INFO    : Bus 3807	: V=1.07991843, theta=-1.08369734 -> V=1.05263, theta=0.0
% INFO    : Bus 3808	: V=1.0799344, theta=-1.08284611 -> V=1.05263, theta=0.0
% INFO    : Bus 3809	: V=1.01171399, theta=-12.4590079 -> V=1.0158755, theta=0.0
% INFO    : Bus 3810	: V=1.05146553, theta=-9.22459011 -> V=1.0377785, theta=0.0
% INFO    : Bus 3811	: V=1.059629, theta=-6.81005789 -> V=1.072365, theta=0.0
% INFO    : Bus 3812	: V=1.03356599, theta=-10.0974024 -> V=0.984126, theta=0.0
% INFO    : Bus 3813	: V=1.06919452, theta=-5.08781442 -> V=1.0377785, theta=0.0
% INFO    : Bus 3814	: V=0.994073556, theta=-13.1630875 -> V=1.0158755, theta=0.0
% INFO    : Bus 3815	: V=1.06535416, theta=-3.98771692 -> V=1.0377785, theta=0.0
% INFO    : Bus 3816	: V=1.05, theta=2.8636934 -> V=0.975, theta=0.0
% INFO    : Bus 3817	: V=1.063, theta=2.10456652 -> V=0.975, theta=0.0
% INFO    : Bus 3818	: V=1.068, theta=1.97334734 -> V=0.975, theta=0.0
% INFO    : Bus 3819	: V=1.0652653, theta=-3.96548995 -> V=1.0377785, theta=0.0
% INFO    : Bus 3820	: V=1.06531469, theta=-3.9676301 -> V=1.0377785, theta=0.0
% INFO    : Bus 3821	: V=1.06533223, theta=-3.96794039 -> V=1.0377785, theta=0.0
% INFO    : Bus 3822	: V=1.01940559, theta=-48.8607862 -> V=1.022224, theta=0.0
% INFO    : Bus 3823	: V=1.03587724, theta=-22.5159016 -> V=1.0158755, theta=0.0
% INFO    : Bus 3824	: V=1.0098933, theta=-12.5485612 -> V=1.0158755, theta=0.0
% INFO    : Bus 3825	: V=1.00886308, theta=-31.5156755 -> V=1.0000005, theta=0.0
% INFO    : Bus 3826	: V=1.02953068, theta=-27.0278611 -> V=1.0000025, theta=0.0
% INFO    : Bus 3827	: V=1.04609201, theta=-33.8172128 -> V=1.046665, theta=0.0
% INFO    : Bus 3828	: V=1.05774632, theta=-29.3900437 -> V=1.046665, theta=0.0
% INFO    : Bus 3829	: V=1.05757746, theta=-29.4026152 -> V=1.046665, theta=0.0
% INFO    : Bus 3830	: V=1.01823286, theta=-2.01969428 -> V=1.0158755, theta=0.0
% INFO    : Bus 3831	: V=1.01581499, theta=-1.89835921 -> V=1.0158755, theta=0.0
% INFO    : Bus 3832	: V=1.07718002, theta=-0.653960373 -> V=1.0377785, theta=0.0
% INFO    : Bus 3833	: V=1.0541341, theta=-17.4346327 -> V=1.046665, theta=0.0
% INFO    : Bus 3834	: V=1.05260432, theta=-21.4247831 -> V=1.033333, theta=0.0
% INFO    : Bus 3835	: V=1.04179697, theta=-22.8382152 -> V=1.033333, theta=0.0
% INFO    : Bus 3836	: V=1.03332923, theta=-25.6198802 -> V=1.0000025, theta=0.0
% INFO    : Bus 3837	: V=1.05316121, theta=-19.9753437 -> V=1.0000025, theta=0.0
% INFO    : Bus 3838	: V=1.02902753, theta=-15.1385258 -> V=0.999999, theta=0.0
% INFO    : Bus 3839	: V=1.03274328, theta=-23.6307836 -> V=0.999999, theta=0.0
% INFO    : Bus 3840	: V=1.03399046, theta=-17.6177156 -> V=0.999999, theta=0.0
% INFO    : Bus 3841	: V=1.04542676, theta=-16.0885852 -> V=1.0111115, theta=0.0
% INFO    : Bus 3842	: V=1.015, theta=-8.11230485 -> V=0.999999, theta=0.0
% INFO    : Bus 3843	: V=1.01235989, theta=-28.7661267 -> V=1.022224, theta=0.0
% INFO    : Bus 3844	: V=1.04180797, theta=-29.9284356 -> V=1.0000025, theta=0.0
% INFO    : Bus 3845	: V=1.03041255, theta=-35.3306328 -> V=1.027779, theta=0.0
% INFO    : Bus 3846	: V=1.03495852, theta=-29.4462453 -> V=1.046665, theta=0.0
% INFO    : Bus 3847	: V=1.02269359, theta=-23.8502769 -> V=1.022224, theta=0.0
% INFO    : Bus 3848	: V=1.04359961, theta=-27.8801095 -> V=1.022224, theta=0.0
% INFO    : Bus 3849	: V=1.02504137, theta=-12.7702774 -> V=0.999999, theta=0.0
% INFO    : Bus 3850	: V=1.03502684, theta=-27.2907369 -> V=1.0000025, theta=0.0
% INFO    : Bus 3851	: V=1.07005615, theta=-23.8052178 -> V=1.044445, theta=0.0
% INFO    : Bus 3852	: V=1.01755942, theta=-9.51883711 -> V=0.999999, theta=0.0
% INFO    : Bus 3853	: V=1.034, theta=-22.8349618 -> V=1.0000025, theta=0.0
% INFO    : Bus 3854	: V=1.03864398, theta=-15.1361052 -> V=0.999999, theta=0.0
% INFO    : Bus 3855	: V=1.04383015, theta=-15.6355665 -> V=0.999999, theta=0.0
% INFO    : Bus 3856	: V=1.03993457, theta=-11.2766803 -> V=1.0111115, theta=0.0
% INFO    : Bus 3857	: V=1.02836239, theta=-10.1105617 -> V=1.0158755, theta=0.0
% INFO    : Bus 3858	: V=1.03233785, theta=-17.9227166 -> V=0.999999, theta=0.0
% INFO    : Bus 3859	: V=1.0320814, theta=-10.0196015 -> V=1.0158755, theta=0.0
% INFO    : Bus 3860	: V=1.05827904, theta=-30.8598982 -> V=1.046665, theta=0.0
% INFO    : Bus 3861	: V=1.04448327, theta=-30.399521 -> V=1.046665, theta=0.0
% INFO    : Bus 3862	: V=1.05301664, theta=-17.5600449 -> V=1.046665, theta=0.0
% INFO    : Bus 3863	: V=1.03933223, theta=-28.658773 -> V=1.022224, theta=0.0
% INFO    : Bus 3864	: V=1.03056997, theta=-15.904875 -> V=0.999999, theta=0.0
% INFO    : Bus 3865	: V=1.03324566, theta=-11.5427127 -> V=0.999999, theta=0.0
% INFO    : Bus 3866	: V=1.04945536, theta=-33.16858 -> V=1.022224, theta=0.0
% INFO    : Bus 3867	: V=1.0211374, theta=-34.1041288 -> V=1.022224, theta=0.0
% INFO    : Bus 3868	: V=1.011, theta=-33.5903877 -> V=1.022224, theta=0.0
% INFO    : Bus 3869	: V=1.05039786, theta=-23.5471758 -> V=1.0000025, theta=0.0
% INFO    : Bus 3870	: V=1.03312704, theta=-29.4146567 -> V=1.015872, theta=0.0
% INFO    : Bus 3871	: V=1.03660128, theta=-9.50754147 -> V=1.0158755, theta=0.0
% INFO    : Bus 3872	: V=1.0771752, theta=-26.6484898 -> V=1.046665, theta=0.0
% INFO    : Bus 3873	: V=1.02859138, theta=-21.2299497 -> V=1.015872, theta=0.0
% INFO    : Bus 3874	: V=1.04640218, theta=-17.7663597 -> V=1.046665, theta=0.0
% INFO    : Bus 3875	: V=1.02716634, theta=-10.4293178 -> V=1.0158755, theta=0.0
% INFO    : Bus 3876	: V=1.02336884, theta=-29.5954566 -> V=1.0000025, theta=0.0
% INFO    : Bus 3877	: V=1.01671576, theta=-30.4161805 -> V=1.0000025, theta=0.0
% INFO    : Bus 3878	: V=1.00221521, theta=-17.1421173 -> V=1.0158755, theta=0.0
% INFO    : Bus 3879	: V=1.04412283, theta=-15.3009937 -> V=1.0377785, theta=0.0
% INFO    : Bus 3880	: V=0.994564188, theta=-32.6261127 -> V=1.0000005, theta=0.0
% INFO    : Bus 3881	: V=1.04925241, theta=-30.3895233 -> V=1.046665, theta=0.0
% INFO    : Bus 3882	: V=1.05481979, theta=-29.9691518 -> V=1.046665, theta=0.0
% INFO    : Bus 3883	: V=1.02035, theta=-17.9650661 -> V=1.0158755, theta=0.0
% INFO    : Bus 3884	: V=1.01979577, theta=-2.26297346 -> V=1.0158755, theta=0.0
% INFO    : Bus 3885	: V=1.0160957, theta=-1.90643107 -> V=1.0158755, theta=0.0
% INFO    : Bus 3886	: V=1.00029701, theta=-23.572352 -> V=1.0158755, theta=0.0
% INFO    : Bus 3887	: V=0.947134847, theta=-30.97112 -> V=1.0127355, theta=0.0
% INFO    : Bus 3888	: V=1.0123413, theta=-16.8890598 -> V=1.0158755, theta=0.0
% INFO    : Bus 3889	: V=1.00882371, theta=-16.4013361 -> V=1.0277795, theta=0.0
% INFO    : Bus 3890	: V=1.0116336, theta=-28.053289 -> V=1.022224, theta=0.0
% INFO    : Bus 3891	: V=1.01778503, theta=-16.4525301 -> V=1.0158755, theta=0.0
% INFO    : Bus 3892	: V=1.01298449, theta=-25.2884228 -> V=1.0158755, theta=0.0
% INFO    : Bus 3893	: V=1.0078435, theta=-56.3944592 -> V=1.0079355, theta=0.0
% INFO    : Bus 3894	: V=1.03983111, theta=-20.7516827 -> V=1.015872, theta=0.0
% INFO    : Bus 3895	: V=1.03112327, theta=-9.11622147 -> V=1.0158755, theta=0.0
% INFO    : Bus 3896	: V=1.02037365, theta=-42.5695211 -> V=1.022224, theta=0.0
% INFO    : Bus 3897	: V=1.01659824, theta=-18.092025 -> V=1.0158755, theta=0.0
% INFO    : Bus 3898	: V=1.03835465, theta=-14.7731781 -> V=1.0377785, theta=0.0
% INFO    : Bus 3899	: V=1.02118309, theta=-26.5365456 -> V=1.022224, theta=0.0
% INFO    : Bus 3900	: V=1.02061552, theta=-58.1852853 -> V=1.0079355, theta=0.0
% INFO    : Bus 3901	: V=1.04551855, theta=-52.914782 -> V=1.04444, theta=0.0
% INFO    : Bus 3902	: V=0.989333259, theta=-36.8783222 -> V=1.0000005, theta=0.0
% INFO    : Bus 3903	: V=1.03239231, theta=-13.8486246 -> V=0.999999, theta=0.0
% INFO    : Bus 3904	: V=1.02110904, theta=-65.2917351 -> V=1.0079355, theta=0.0
% INFO    : Bus 3905	: V=1.07550001, theta=-26.4782996 -> V=1.046665, theta=0.0
% INFO    : Bus 3906	: V=1.06794465, theta=-27.7351338 -> V=1.046665, theta=0.0
% INFO    : Bus 3907	: V=1.07829915, theta=-23.5852567 -> V=1.073685, theta=0.0
% INFO    : Bus 3908	: V=1.04203545, theta=-12.5007352 -> V=1.046665, theta=0.0
% INFO    : Bus 3909	: V=1.05685708, theta=-31.9290059 -> V=1.022224, theta=0.0
% INFO    : Bus 3910	: V=1.06312804, theta=-20.315985 -> V=1.0233335, theta=0.0
% INFO    : Bus 3911	: V=1.04941259, theta=-19.2641403 -> V=1.046665, theta=0.0
% INFO    : Bus 3912	: V=1.01740742, theta=-21.266852 -> V=1.015872, theta=0.0
% INFO    : Bus 3913	: V=0.992308114, theta=-23.1324671 -> V=1.015872, theta=0.0
% INFO    : Bus 3914	: V=1.03801866, theta=-23.8112048 -> V=1.022224, theta=0.0
% INFO    : Bus 3915	: V=1.00360429, theta=-7.1485604 -> V=1.0158755, theta=0.0
% INFO    : Bus 3916	: V=1.02754981, theta=-28.6602865 -> V=1.0158755, theta=0.0
% INFO    : Bus 3917	: V=1.03435515, theta=-23.7906889 -> V=1.0377785, theta=0.0
% INFO    : Bus 3918	: V=1.0505124, theta=-25.1447488 -> V=1.0000025, theta=0.0
% INFO    : Bus 3919	: V=1.04996579, theta=-27.5314943 -> V=1.0000025, theta=0.0
% INFO    : Bus 3920	: V=1.04162343, theta=-20.2275937 -> V=0.9888895, theta=0.0
% INFO    : Bus 3921	: V=1.04163458, theta=-20.2228009 -> V=0.9888895, theta=0.0
% INFO    : Bus 3922	: V=1.02927955, theta=-30.9555236 -> V=1.022224, theta=0.0
% INFO    : Bus 3923	: V=1.04845888, theta=-28.1687528 -> V=1.015874, theta=0.0
% INFO    : Bus 3924	: V=1.0428576, theta=-27.7537324 -> V=1.015874, theta=0.0
% INFO    : Bus 3925	: V=1.03675293, theta=-23.0149563 -> V=1.026667, theta=0.0
% INFO    : Bus 3926	: V=1.06173541, theta=-16.3742404 -> V=0.9888895, theta=0.0
% INFO    : Bus 3927	: V=1.02982568, theta=-28.0626289 -> V=1.015872, theta=0.0
% INFO    : Bus 3928	: V=1.05029016, theta=-28.0884136 -> V=1.0233335, theta=0.0
% INFO    : Bus 3929	: V=1.06078465, theta=-23.278132 -> V=1.0000025, theta=0.0
% INFO    : Bus 3930	: V=1.01803062, theta=-21.6703226 -> V=1.015872, theta=0.0
% INFO    : Bus 3931	: V=1.04558626, theta=-15.7524639 -> V=1.046665, theta=0.0
% INFO    : Bus 3932	: V=1.00884371, theta=-18.9409942 -> V=1.0079355, theta=0.0
% INFO    : Bus 3933	: V=0.974614525, theta=-36.9991364 -> V=1.0000005, theta=0.0
% INFO    : Bus 3934	: V=1.06752215, theta=-34.5392417 -> V=1.046665, theta=0.0
% INFO    : Bus 3935	: V=1.06735265, theta=-34.553632 -> V=1.046665, theta=0.0
% INFO    : Bus 3936	: V=1.06557334, theta=-15.5993022 -> V=1.0000025, theta=0.0
% INFO    : Bus 3937	: V=1.0901284, theta=-13.2018327 -> V=1.045335, theta=0.0
% INFO    : Bus 3938	: V=1.10369925, theta=-10.0759989 -> V=1.078945, theta=0.0
% INFO    : Bus 3939	: V=1.02669276, theta=-30.6973254 -> V=1.000001, theta=0.0
% INFO    : Bus 3940	: V=1.03552929, theta=-23.3639546 -> V=1.0000025, theta=0.0
% INFO    : Bus 3941	: V=1.02538714, theta=-9.78896684 -> V=0.999999, theta=0.0
% INFO    : Bus 3942	: V=1.03756372, theta=-16.3837651 -> V=1.0111115, theta=0.0
% INFO    : Bus 3943	: V=1.06174668, theta=-13.2888482 -> V=1.072365, theta=0.0
% INFO    : Bus 3944	: V=1.01239344, theta=-63.5767526 -> V=1.0079355, theta=0.0
% INFO    : Bus 3945	: V=1.04371063, theta=-12.2752505 -> V=0.999999, theta=0.0
% INFO    : Bus 3946	: V=1.05444533, theta=-18.1642797 -> V=0.9888895, theta=0.0
% INFO    : Bus 3947	: V=1.05907601, theta=-31.3776011 -> V=1.046665, theta=0.0
% INFO    : Bus 3948	: V=1.05947496, theta=-31.1366709 -> V=1.046665, theta=0.0
% INFO    : Bus 3949	: V=1.0299282, theta=-22.9986314 -> V=0.9888895, theta=0.0
% INFO    : Bus 3950	: V=0.987858218, theta=-36.2445636 -> V=1.0000005, theta=0.0
% INFO    : Bus 3951	: V=1.00831552, theta=-9.41569471 -> V=1.0158755, theta=0.0
% INFO    : Bus 3952	: V=1.05996009, theta=-31.1633525 -> V=1.046665, theta=0.0
% INFO    : Bus 3953	: V=1.05969798, theta=-31.1660241 -> V=1.046665, theta=0.0
% INFO    : Bus 3954	: V=1.02676562, theta=-15.2353301 -> V=0.999999, theta=0.0
% INFO    : Bus 3955	: V=1.02576309, theta=-15.8763236 -> V=0.999999, theta=0.0
% INFO    : Bus 3956	: V=1.06708577, theta=-21.9719136 -> V=1.0000025, theta=0.0
% INFO    : Bus 3957	: V=1.0377387, theta=-32.0082367 -> V=1.027779, theta=0.0
% INFO    : Bus 3958	: V=1.03060055, theta=-32.4767756 -> V=1.027779, theta=0.0
% INFO    : Bus 3959	: V=1.0312538, theta=-22.3159637 -> V=1.0158755, theta=0.0
% INFO    : Bus 3960	: V=1.03145186, theta=-22.320111 -> V=1.0158755, theta=0.0
% INFO    : Bus 3961	: V=0.984446306, theta=-37.3465067 -> V=1.0000005, theta=0.0
% INFO    : Bus 3962	: V=1.05542139, theta=-31.4475375 -> V=1.046665, theta=0.0
% INFO    : Bus 3963	: V=1.05573233, theta=-31.5326265 -> V=1.046665, theta=0.0
% INFO    : Bus 3964	: V=1.04788033, theta=-50.4789266 -> V=1.022224, theta=0.0
% INFO    : Bus 3965	: V=1.05205417, theta=-24.5856496 -> V=1.0000025, theta=0.0
% INFO    : Bus 3966	: V=1.04714275, theta=-5.84472787 -> V=1.0111115, theta=0.0
% INFO    : Bus 3967	: V=1.02676821, theta=-40.4890206 -> V=1.022224, theta=0.0
% INFO    : Bus 3968	: V=1.029, theta=-6.06793096 -> V=0.975, theta=0.0
% INFO    : Bus 3969	: V=1.015, theta=-9.62819759 -> V=0.975, theta=0.0
% INFO    : Bus 3970	: V=1.01812269, theta=-12.5855429 -> V=0.999999, theta=0.0
% INFO    : Bus 3971	: V=1.03029646, theta=-8.76568682 -> V=1.0111115, theta=0.0
% INFO    : Bus 3972	: V=1.00313234, theta=-14.6358821 -> V=1.015872, theta=0.0
% INFO    : Bus 3973	: V=1.03721259, theta=-25.6050887 -> V=1.0000025, theta=0.0
% INFO    : Bus 3974	: V=1.01322156, theta=-2.33026898 -> V=1.0158755, theta=0.0
% INFO    : Bus 3975	: V=1.01574451, theta=-2.10943248 -> V=1.0158755, theta=0.0
% INFO    : Bus 3976	: V=1.07592689, theta=0.21244409 -> V=1.0377785, theta=0.0
% INFO    : Bus 3977	: V=1.02062522, theta=-23.5668346 -> V=1.000001, theta=0.0
% INFO    : Bus 3978	: V=1.04979741, theta=-30.5529979 -> V=1.027779, theta=0.0
% INFO    : Bus 3979	: V=1.04418238, theta=-31.1937852 -> V=1.027779, theta=0.0
% INFO    : Bus 3980	: V=1.07427039, theta=-26.9099304 -> V=1.046665, theta=0.0
% INFO    : Bus 3981	: V=1.0433343, theta=-28.9693185 -> V=1.022224, theta=0.0
% INFO    : Bus 3982	: V=1.02333483, theta=-18.4364561 -> V=0.999999, theta=0.0
% INFO    : Bus 3983	: V=1.01937278, theta=-2.9467521 -> V=1.0158755, theta=0.0
% INFO    : Bus 3984	: V=1.01139885, theta=-15.2982922 -> V=0.999999, theta=0.0
% INFO    : Bus 3985	: V=1.00783263, theta=-27.4827129 -> V=1.0000025, theta=0.0
% INFO    : Bus 3986	: V=1.03034483, theta=-27.6399267 -> V=1.022224, theta=0.0
% INFO    : Bus 3987	: V=1.001, theta=-14.681434 -> V=1.015872, theta=0.0
% INFO    : Bus 3988	: V=1.01134794, theta=-34.7997942 -> V=1.015872, theta=0.0
% INFO    : Bus 3989	: V=1.01097751, theta=-21.8985348 -> V=0.999999, theta=0.0
% INFO    : Bus 3990	: V=1.01236283, theta=-23.0931423 -> V=1.0158755, theta=0.0
% INFO    : Bus 3991	: V=1.05652572, theta=-13.1745531 -> V=1.033334, theta=0.0
% INFO    : Bus 3992	: V=1.02852436, theta=-17.4067672 -> V=1.015872, theta=0.0
% INFO    : Bus 3993	: V=1.0255882, theta=-17.3734683 -> V=1.015872, theta=0.0
% INFO    : Bus 3994	: V=1.04827133, theta=-14.2435526 -> V=0.999999, theta=0.0
% INFO    : Bus 3995	: V=1.01170861, theta=-12.4690665 -> V=1.0158755, theta=0.0
% INFO    : Bus 3996	: V=1.04614061, theta=-15.64507 -> V=1.033334, theta=0.0
% INFO    : Bus 3997	: V=1.05165465, theta=-23.2520322 -> V=1.0000025, theta=0.0
% INFO    : Bus 3998	: V=1.05237292, theta=-23.1876391 -> V=1.0000025, theta=0.0
% INFO    : Bus 3999	: V=1.02051172, theta=-22.0483548 -> V=0.999999, theta=0.0
% INFO    : Bus 4000	: V=1.03721225, theta=-27.0606933 -> V=1.022222, theta=0.0
% INFO    : Bus 4001	: V=0.994468707, theta=-32.2290233 -> V=1.0000005, theta=0.0
% INFO    : Bus 4002	: V=1.01082693, theta=-30.967782 -> V=1.0000005, theta=0.0
% INFO    : Bus 4003	: V=1.00186156, theta=-19.401841 -> V=1.0079355, theta=0.0
% INFO    : Bus 4004	: V=1.04301831, theta=-29.5736128 -> V=1.027779, theta=0.0
% INFO    : Bus 4005	: V=1.07304179, theta=-27.1476431 -> V=1.046665, theta=0.0
% INFO    : Bus 4006	: V=0.995910075, theta=-31.110987 -> V=1.0000005, theta=0.0
% INFO    : Bus 4007	: V=1.04495262, theta=-21.3629992 -> V=1.0000025, theta=0.0
% INFO    : Bus 4008	: V=1.04630579, theta=-35.8115293 -> V=1.0000025, theta=0.0
% INFO    : Bus 4009	: V=1.03649098, theta=-29.4007155 -> V=1.044445, theta=0.0
% INFO    : Bus 4010	: V=1.04663656, theta=-18.8647651 -> V=0.999999, theta=0.0
% INFO    : Bus 4011	: V=1.04440891, theta=-13.5221113 -> V=1.0111115, theta=0.0
% INFO    : Bus 4012	: V=1.02490123, theta=-39.3977464 -> V=1.027779, theta=0.0
% INFO    : Bus 4013	: V=1.02312005, theta=-30.2901846 -> V=1.022224, theta=0.0
% INFO    : Bus 4014	: V=1.0257628, theta=-15.8763147 -> V=0.999999, theta=0.0
% INFO    : Bus 4015	: V=1.02942993, theta=-30.6178139 -> V=1.0000025, theta=0.0
% INFO    : Bus 4016	: V=1.01328963, theta=-25.4659672 -> V=0.999999, theta=0.0
% INFO    : Bus 4017	: V=1.02120648, theta=-3.23871106 -> V=1.0158755, theta=0.0
% INFO    : Bus 4018	: V=1.07051145, theta=-0.0984855271 -> V=1.0377785, theta=0.0
% INFO    : Bus 4019	: V=1.01486563, theta=-3.70036033 -> V=1.0158755, theta=0.0
% INFO    : Bus 4020	: V=1.08990502, theta=-13.0247826 -> V=1.0452, theta=0.0
% INFO    : Bus 4021	: V=1.02660393, theta=-7.37480413 -> V=1.0158755, theta=0.0
% INFO    : Bus 4022	: V=1.05758044, theta=-19.2712899 -> V=1.0377785, theta=0.0
% INFO    : Bus 4023	: V=1.04023956, theta=-24.6327081 -> V=1.0000025, theta=0.0
% INFO    : Bus 4024	: V=1.04603313, theta=-61.648409 -> V=1.0079355, theta=0.0
% INFO    : Bus 4025	: V=1.01848189, theta=-11.3964107 -> V=0.999999, theta=0.0
% INFO    : Bus 4026	: V=1.04533229, theta=-24.0657568 -> V=1.0000025, theta=0.0
% INFO    : Bus 4027	: V=1.07413705, theta=-19.5182866 -> V=1.044445, theta=0.0
% INFO    : Bus 4028	: V=1.08464244, theta=-14.9549014 -> V=1.078945, theta=0.0
% INFO    : Bus 4029	: V=0.963091315, theta=-9.45269166 -> V=0.9444445, theta=0.0
% INFO    : Bus 4030	: V=0.999816743, theta=-25.3866434 -> V=1.0000025, theta=0.0
% INFO    : Bus 4031	: V=1.0252393, theta=-31.0844005 -> V=1.0111115, theta=0.0
% INFO    : Bus 4032	: V=1.00799537, theta=-14.4403832 -> V=1.0158755, theta=0.0
% INFO    : Bus 4033	: V=1.02485556, theta=-34.9703619 -> V=1.027779, theta=0.0
% INFO    : Bus 4034	: V=1.01492432, theta=-25.1518923 -> V=1.0158755, theta=0.0
% INFO    : Bus 4035	: V=1.03088221, theta=-30.931879 -> V=1.022224, theta=0.0
% INFO    : Bus 4036	: V=1.0281254, theta=-2.2413133 -> V=1.0158755, theta=0.0
% INFO    : Bus 4037	: V=1.07016614, theta=-0.531331413 -> V=1.0377785, theta=0.0
% INFO    : Bus 4038	: V=1.03856959, theta=-11.8988968 -> V=0.999999, theta=0.0
% INFO    : Bus 4039	: V=1.01786062, theta=-12.8509215 -> V=1.015872, theta=0.0
% INFO    : Bus 4040	: V=1.03988001, theta=-34.4272942 -> V=1.046665, theta=0.0
% INFO    : Bus 4041	: V=1.01168832, theta=-23.9420613 -> V=1.0158755, theta=0.0
% INFO    : Bus 4042	: V=1.04835331, theta=-19.0547333 -> V=1.046665, theta=0.0
% INFO    : Bus 4043	: V=1.05012911, theta=-17.532514 -> V=1.044445, theta=0.0
% INFO    : Bus 4044	: V=1.01728072, theta=-35.1993221 -> V=1.022224, theta=0.0
% INFO    : Bus 4045	: V=0.982139692, theta=-6.07692173 -> V=0.9444445, theta=0.0
% INFO    : Bus 4046	: V=1.05167068, theta=-5.09724598 -> V=1.0111115, theta=0.0
% INFO    : Bus 4047	: V=1.04918117, theta=-29.3928674 -> V=1.046665, theta=0.0
% INFO    : Bus 4048	: V=1.03820537, theta=-30.6902468 -> V=1.046665, theta=0.0
% INFO    : Bus 4049	: V=1.0486751, theta=-25.0530929 -> V=1.073685, theta=0.0
% INFO    : Bus 4050	: V=1.02428832, theta=-31.2258668 -> V=1.022224, theta=0.0
% INFO    : Bus 4051	: V=1.02020841, theta=-14.6967343 -> V=0.975, theta=0.0
% INFO    : Bus 4052	: V=1.04868633, theta=-5.79706738 -> V=1.0111115, theta=0.0
% INFO    : Bus 4053	: V=1.02338308, theta=-29.0012508 -> V=0.984126, theta=0.0
% INFO    : Bus 4054	: V=1.00415935, theta=-70.2245264 -> V=1.0079355, theta=0.0
% INFO    : Bus 4055	: V=1.025, theta=-15.9432194 -> V=1.015872, theta=0.0
% INFO    : Bus 4056	: V=1.00492509, theta=-21.902546 -> V=1.015872, theta=0.0
% INFO    : Bus 4057	: V=1.00361582, theta=-32.0684799 -> V=1.0000005, theta=0.0
% INFO    : Bus 4058	: V=1.00361598, theta=-32.068485 -> V=1.0000005, theta=0.0
% INFO    : Bus 4059	: V=1.043889, theta=-30.444729 -> V=1.0000025, theta=0.0
% INFO    : Bus 4060	: V=1.03495436, theta=-50.5655219 -> V=1.0079355, theta=0.0
% INFO    : Bus 4061	: V=1.01375694, theta=-11.2521112 -> V=1.0158755, theta=0.0
% INFO    : Bus 4062	: V=1.03659092, theta=-31.1777362 -> V=1.046665, theta=0.0
% INFO    : Bus 4063	: V=1.06686436, theta=-18.3393917 -> V=1.005599, theta=0.0
% INFO    : Bus 4064	: V=1.07961169, theta=-14.162192 -> V=1.0111115, theta=0.0
% INFO    : Bus 4065	: V=1.02256141, theta=-64.5877757 -> V=1.0079355, theta=0.0
% INFO    : Bus 4066	: V=1.04356515, theta=-25.7365896 -> V=1.016666, theta=0.0
% INFO    : Bus 4067	: V=1.07245068, theta=-4.05984997 -> V=1.0377785, theta=0.0
% INFO    : Bus 4068	: V=1.08340217, theta=-1.75111558 -> V=1.072365, theta=0.0
% INFO    : Bus 4069	: V=1.02416686, theta=-10.3134658 -> V=1.0158755, theta=0.0
% INFO    : Bus 4070	: V=1.02151281, theta=-28.0621714 -> V=1.0000025, theta=0.0
% INFO    : Bus 4071	: V=1.03963697, theta=-42.4650063 -> V=1.027779, theta=0.0
% INFO    : Bus 4072	: V=1.00152107, theta=-46.8620698 -> V=1.022224, theta=0.0
% INFO    : Bus 4073	: V=0.978359488, theta=-36.2759678 -> V=1.0000005, theta=0.0
% INFO    : Bus 4074	: V=1.01496606, theta=-22.2872783 -> V=1.0158755, theta=0.0
% INFO    : Bus 4075	: V=1.0212464, theta=-40.9709545 -> V=1.022224, theta=0.0
% INFO    : Bus 4076	: V=1.00490026, theta=-32.1648844 -> V=1.0000005, theta=0.0
% INFO    : Bus 4077	: V=1.00460123, theta=-32.1616749 -> V=1.0000005, theta=0.0
% INFO    : Bus 4078	: V=1.03517654, theta=-31.7094108 -> V=1.046665, theta=0.0
% INFO    : Bus 4079	: V=1.01974208, theta=-28.8701652 -> V=1.0000025, theta=0.0
% INFO    : Bus 4080	: V=0.999606548, theta=-13.4540858 -> V=1.0158755, theta=0.0
% INFO    : Bus 4081	: V=1.0333705, theta=-16.2571022 -> V=0.999999, theta=0.0
% INFO    : Bus 4082	: V=1.06100293, theta=-30.3626172 -> V=1.046665, theta=0.0
% INFO    : Bus 4083	: V=1.04477118, theta=-6.66898806 -> V=1.0111115, theta=0.0
% INFO    : Bus 4084	: V=1.06267694, theta=-23.7090593 -> V=1.0000025, theta=0.0
% INFO    : Bus 4085	: V=1.02062522, theta=-23.5668346 -> V=1.000001, theta=0.0
% INFO    : Bus 4086	: V=1.02813581, theta=-57.0217455 -> V=1.0079355, theta=0.0
% INFO    : Bus 4087	: V=1.02932738, theta=-14.6671081 -> V=1.0158755, theta=0.0
% INFO    : Bus 4088	: V=1.04903169, theta=-8.43392391 -> V=1.0158755, theta=0.0
% INFO    : Bus 4089	: V=1.03750327, theta=-7.66338363 -> V=1.0377785, theta=0.0
% INFO    : Bus 4090	: V=1.02550488, theta=-37.5637194 -> V=1.022224, theta=0.0
% INFO    : Bus 4091	: V=1.01529493, theta=-28.0485005 -> V=1.0000025, theta=0.0
% INFO    : Bus 4092	: V=1.02715928, theta=-21.8808251 -> V=0.999999, theta=0.0
% INFO    : Bus 4093	: V=1.03554402, theta=-16.1244595 -> V=1.0111115, theta=0.0
% INFO    : Bus 4094	: V=0.962071105, theta=-29.6260381 -> V=1.0000005, theta=0.0
% INFO    : Bus 4095	: V=1.04212307, theta=-29.6167509 -> V=1.046665, theta=0.0
% INFO    : Bus 4096	: V=0.985409643, theta=-35.4412943 -> V=1.0000005, theta=0.0
% INFO    : Bus 4097	: V=0.981905482, theta=-27.1609429 -> V=1.0158755, theta=0.0
% INFO    : Bus 4098	: V=1.04066208, theta=-40.6741885 -> V=1.027779, theta=0.0
% INFO    : Bus 4099	: V=0.995566572, theta=-20.9741644 -> V=1.0158755, theta=0.0
% INFO    : Bus 4100	: V=1.00565678, theta=-32.0407133 -> V=1.0158755, theta=0.0
% INFO    : Bus 4101	: V=1.01802579, theta=-24.1356989 -> V=1.015872, theta=0.0
% INFO    : Bus 4102	: V=1.04877606, theta=-18.8256636 -> V=1.046665, theta=0.0
% INFO    : Bus 4103	: V=1.03826189, theta=-21.0326876 -> V=0.9888895, theta=0.0
% INFO    : Bus 4104	: V=1.03848127, theta=-21.0109994 -> V=0.9888895, theta=0.0
% INFO    : Bus 4105	: V=1.05867966, theta=-19.8937993 -> V=1.0377785, theta=0.0
% INFO    : Bus 4106	: V=1.0640333, theta=-17.3613962 -> V=1.072365, theta=0.0
% INFO    : Bus 4107	: V=0.99666579, theta=-31.6826474 -> V=1.0000005, theta=0.0
% INFO    : Bus 4108	: V=1.02728021, theta=-25.9375751 -> V=1.022224, theta=0.0
% INFO    : Bus 4109	: V=1.02561765, theta=-36.2521441 -> V=1.027779, theta=0.0
% INFO    : Bus 4110	: V=1.05013244, theta=-10.4522839 -> V=0.999999, theta=0.0
% INFO    : Bus 4111	: V=1.06899633, theta=-9.43444052 -> V=1.0111115, theta=0.0
% INFO    : Bus 4112	: V=1.00478794, theta=-14.067447 -> V=0.999999, theta=0.0
% INFO    : Bus 4113	: V=1.01552052, theta=-44.9755377 -> V=1.022224, theta=0.0
% INFO    : Bus 4114	: V=1.02605308, theta=-17.382744 -> V=0.999999, theta=0.0
% INFO    : Bus 4115	: V=1.01484685, theta=-50.2502632 -> V=1.022224, theta=0.0
% INFO    : Bus 4116	: V=1.03514535, theta=-22.4578084 -> V=1.0000025, theta=0.0
% INFO    : Bus 4117	: V=1.03515524, theta=-22.4568053 -> V=1.0000025, theta=0.0
% INFO    : Bus 4118	: V=1.03389188, theta=-26.0719744 -> V=1.000001, theta=0.0
% INFO    : Bus 4119	: V=1.03999526, theta=-22.2384921 -> V=1.0111115, theta=0.0
% INFO    : Bus 4120	: V=1.04125423, theta=-15.5295793 -> V=1.000001, theta=0.0
% INFO    : Bus 4121	: V=1.05275546, theta=-11.9512321 -> V=1.016666, theta=0.0
% INFO    : Bus 4122	: V=1.05613029, theta=-6.74437541 -> V=1.05263, theta=0.0
% INFO    : Bus 4123	: V=1.03346945, theta=-51.8871663 -> V=1.0079355, theta=0.0
% INFO    : Bus 4124	: V=1.01195612, theta=-25.2306057 -> V=1.0000025, theta=0.0
% INFO    : Bus 4125	: V=0.998560499, theta=-56.3692078 -> V=1.0079355, theta=0.0
% INFO    : Bus 4126	: V=1.05308692, theta=-31.8641118 -> V=1.046665, theta=0.0
% INFO    : Bus 4127	: V=1.02344743, theta=-32.1200492 -> V=1.015872, theta=0.0
% INFO    : Bus 4128	: V=1.04072382, theta=-31.8198413 -> V=1.0000025, theta=0.0
% INFO    : Bus 4129	: V=1.033, theta=-13.3273863 -> V=0.999999, theta=0.0
% INFO    : Bus 4130	: V=1.01383699, theta=-17.0565281 -> V=1.0111115, theta=0.0
% INFO    : Bus 4131	: V=0.983221915, theta=-34.5396646 -> V=1.015872, theta=0.0
% INFO    : Bus 4132	: V=1.03119545, theta=-12.9886192 -> V=0.999999, theta=0.0
% INFO    : Bus 4133	: V=1.08345193, theta=-6.40846783 -> V=1.0377785, theta=0.0
% INFO    : Bus 4134	: V=1.0991471, theta=-2.62955593 -> V=1.072365, theta=0.0
% INFO    : Bus 4135	: V=1.09988292, theta=-2.64119144 -> V=1.072365, theta=0.0
% INFO    : Bus 4136	: V=1.0031232, theta=-34.3442051 -> V=1.015872, theta=0.0
% INFO    : Bus 4137	: V=1.03722669, theta=-2.85002567 -> V=1.0111115, theta=0.0
% INFO    : Bus 4138	: V=1.02098247, theta=-27.0053033 -> V=1.015874, theta=0.0
% INFO    : Bus 4139	: V=1.05369085, theta=-18.9556603 -> V=1.0000025, theta=0.0
% INFO    : Bus 4140	: V=1.03037297, theta=-45.7209072 -> V=1.022224, theta=0.0
% INFO    : Bus 4141	: V=1.05820401, theta=-49.2418396 -> V=1.022224, theta=0.0
% INFO    : Bus 4142	: V=1.04968538, theta=-44.290039 -> V=1.04444, theta=0.0
% INFO    : Bus 4143	: V=1.02794007, theta=-13.9834742 -> V=1.015872, theta=0.0
% INFO    : Bus 4144	: V=1.05771198, theta=-11.6326854 -> V=1.046665, theta=0.0
% INFO    : Bus 4145	: V=1.00243543, theta=-27.9640713 -> V=1.022224, theta=0.0
% INFO    : Bus 4146	: V=1.02673492, theta=-27.8572724 -> V=1.0000025, theta=0.0
% INFO    : Bus 4147	: V=1.05192236, theta=-14.4671642 -> V=1.003199, theta=0.0
% INFO    : Bus 4148	: V=1.04526624, theta=-14.9407874 -> V=0.999999, theta=0.0
% INFO    : Bus 4149	: V=1.03880942, theta=-10.7583356 -> V=1.0111115, theta=0.0
% INFO    : Bus 4150	: V=1.03558797, theta=-14.8258883 -> V=1.044445, theta=0.0
% INFO    : Bus 4151	: V=1.03560611, theta=-14.8217112 -> V=1.044445, theta=0.0
% INFO    : Bus 4152	: V=1.02304229, theta=-26.3647176 -> V=1.015874, theta=0.0
% INFO    : Bus 4153	: V=1.02997443, theta=-30.3497779 -> V=1.015872, theta=0.0
% INFO    : Bus 4154	: V=1.02295505, theta=-26.5554937 -> V=1.0000025, theta=0.0
% INFO    : Bus 4155	: V=1.05119728, theta=-7.14650263 -> V=1.0000025, theta=0.0
% INFO    : Bus 4156	: V=1.00714413, theta=-23.6231985 -> V=1.015872, theta=0.0
% INFO    : Bus 4157	: V=1.05779172, theta=-29.3669591 -> V=1.046665, theta=0.0
% INFO    : Bus 4158	: V=1.0517635, theta=-28.9932626 -> V=1.027779, theta=0.0
% INFO    : Bus 4159	: V=1.05174157, theta=-29.9377585 -> V=1.027779, theta=0.0
% INFO    : Bus 4160	: V=1.01109611, theta=-18.4245667 -> V=1.015872, theta=0.0
% INFO    : Bus 4161	: V=1.01930018, theta=-37.188684 -> V=1.022224, theta=0.0
% INFO    : Bus 4162	: V=1.02944007, theta=-49.6587339 -> V=1.022224, theta=0.0
% INFO    : Bus 4163	: V=1.01814251, theta=-23.2355561 -> V=1.0158755, theta=0.0
% INFO    : Bus 4164	: V=1.0545448, theta=-27.3050252 -> V=1.033333, theta=0.0
% INFO    : Bus 4165	: V=1.04093585, theta=-21.9596202 -> V=1.0288895, theta=0.0
% INFO    : Bus 4166	: V=1.01307347, theta=-31.528562 -> V=1.015872, theta=0.0
% INFO    : Bus 4167	: V=1.06067475, theta=-21.9945041 -> V=1.0000025, theta=0.0
% INFO    : Bus 4168	: V=1.05190772, theta=-26.419917 -> V=1.0000025, theta=0.0
% INFO    : Bus 4169	: V=1.053, theta=-21.7631283 -> V=1.0000025, theta=0.0
% INFO    : Bus 4170	: V=1.01912819, theta=-52.8938421 -> V=1.022224, theta=0.0
% INFO    : Bus 4171	: V=1.05216642, theta=-47.7177124 -> V=1.04444, theta=0.0
% INFO    : Bus 4172	: V=1.05525505, theta=-17.1908709 -> V=1.0000025, theta=0.0
% INFO    : Bus 4173	: V=1.09475989, theta=-17.1906882 -> V=1.0, theta=0.0
% INFO    : Bus 4174	: V=1.02178627, theta=-31.8860934 -> V=1.022224, theta=0.0
% INFO    : Bus 4175	: V=1.03542116, theta=-47.1880386 -> V=1.022224, theta=0.0
% INFO    : Bus 4176	: V=1.05534555, theta=-25.5540432 -> V=1.0000025, theta=0.0
% INFO    : Bus 4177	: V=1.0222821, theta=-24.8795704 -> V=1.000001, theta=0.0
% INFO    : Bus 4178	: V=1.04834195, theta=-34.6605483 -> V=1.022224, theta=0.0
% INFO    : Bus 4179	: V=1.03441662, theta=-40.8307532 -> V=1.022224, theta=0.0
% INFO    : Bus 4180	: V=1.05220719, theta=-5.37338463 -> V=1.0377785, theta=0.0
% INFO    : Bus 4181	: V=1.01779402, theta=-62.6372165 -> V=1.0079355, theta=0.0
% INFO    : Bus 4182	: V=1.0488986, theta=-56.0687501 -> V=1.04444, theta=0.0
% INFO    : Bus 4183	: V=0.999714977, theta=-60.4348239 -> V=1.0079355, theta=0.0
% INFO    : Bus 4184	: V=1.0236033, theta=-2.46307234 -> V=1.0158735, theta=0.0
% INFO    : Bus 4185	: V=1.03220411, theta=-12.8496353 -> V=0.999999, theta=0.0
% INFO    : Bus 4186	: V=1.03230582, theta=-12.8515172 -> V=0.999999, theta=0.0
% INFO    : Bus 4187	: V=1.08280708, theta=-0.703167274 -> V=1.072365, theta=0.0
% INFO    : Bus 4188	: V=1.08279625, theta=-0.701841936 -> V=1.072365, theta=0.0
% INFO    : Bus 4189	: V=1.00899413, theta=-31.5413657 -> V=1.0000025, theta=0.0
% INFO    : Bus 4190	: V=1.03149439, theta=-27.3722923 -> V=1.0000025, theta=0.0
% INFO    : Bus 4191	: V=1.04790059, theta=-24.9099445 -> V=1.0000025, theta=0.0
% INFO    : Bus 4192	: V=0.994669847, theta=-21.3649432 -> V=1.0158755, theta=0.0
% INFO    : Bus 4193	: V=0.994881517, theta=-21.318702 -> V=1.0158755, theta=0.0
% INFO    : Bus 4194	: V=1.01288225, theta=-26.9640094 -> V=1.022224, theta=0.0
% INFO    : Bus 4195	: V=1.04721764, theta=-8.93953974 -> V=1.0111115, theta=0.0
% INFO    : Bus 4196	: V=1.0495305, theta=-10.9056187 -> V=1.0111115, theta=0.0
% INFO    : Bus 4197	: V=1.01155694, theta=-30.2583805 -> V=1.0000025, theta=0.0
% INFO    : Bus 4198	: V=1.0276089, theta=-32.2793948 -> V=1.022224, theta=0.0
% INFO    : Bus 4199	: V=1.02831794, theta=-41.4744986 -> V=1.022224, theta=0.0
% INFO    : Bus 4200	: V=1.04783548, theta=-25.5825686 -> V=1.022224, theta=0.0
% INFO    : Bus 4201	: V=1.04716456, theta=-25.6278943 -> V=1.022224, theta=0.0
% INFO    : Bus 4202	: V=1.03794718, theta=-17.8121266 -> V=0.999999, theta=0.0
% INFO    : Bus 4203	: V=1.03794718, theta=-17.8121266 -> V=0.999999, theta=0.0
% INFO    : Bus 4204	: V=1.03842009, theta=-17.7760985 -> V=0.999999, theta=0.0
% INFO    : Bus 4205	: V=1.02900422, theta=-24.1824693 -> V=1.0158755, theta=0.0
% INFO    : Bus 4206	: V=0.986386233, theta=-21.2196001 -> V=0.999999, theta=0.0
% INFO    : Bus 4207	: V=1.00585197, theta=-36.2958101 -> V=1.0000005, theta=0.0
% INFO    : Bus 4208	: V=1.05061985, theta=-29.8564461 -> V=1.046665, theta=0.0
% INFO    : Bus 4209	: V=1.03880658, theta=-34.7375817 -> V=1.046665, theta=0.0
% INFO    : Bus 4210	: V=1.041546, theta=-16.1875227 -> V=1.015872, theta=0.0
% INFO    : Bus 4211	: V=1.0548867, theta=-14.090083 -> V=1.046665, theta=0.0
% INFO    : Bus 4212	: V=1.0560381, theta=-60.7445015 -> V=1.0079355, theta=0.0
% INFO    : Bus 4213	: V=1.03063872, theta=-36.8771984 -> V=1.022224, theta=0.0
% INFO    : Bus 4214	: V=1.03049982, theta=-36.7338229 -> V=1.022224, theta=0.0
% INFO    : Bus 4215	: V=1.02411999, theta=-14.6461 -> V=0.999999, theta=0.0
% INFO    : Bus 4216	: V=1.03575062, theta=-1.26256932 -> V=1.0158755, theta=0.0
% INFO    : Bus 4217	: V=1.03452034, theta=-1.8258827 -> V=1.0158755, theta=0.0
% INFO    : Bus 4218	: V=1.08408645, theta=2.00098184 -> V=1.0399485, theta=0.0
% INFO    : Bus 4219	: V=1.10295185, theta=6.81830588 -> V=1.07619, theta=0.0
% INFO    : Bus 4220	: V=0.939294987, theta=-8.64022039 -> V=0.9444445, theta=0.0
% INFO    : Bus 4221	: V=1.05476746, theta=-36.5521406 -> V=0.975, theta=0.0
% INFO    : Bus 4222	: V=1.02968277, theta=-41.279034 -> V=1.022224, theta=0.0
% INFO    : Bus 4223	: V=1.03041896, theta=-41.2013502 -> V=1.022224, theta=0.0
% INFO    : Bus 4224	: V=1.0548404, theta=-36.5382679 -> V=1.04444, theta=0.0
% INFO    : Bus 4225	: V=1.03638952, theta=-35.5427808 -> V=1.027779, theta=0.0
% INFO    : Bus 4226	: V=1.03550625, theta=-35.5023314 -> V=1.027779, theta=0.0
% INFO    : Bus 4227	: V=1.04568357, theta=-31.8747294 -> V=1.046665, theta=0.0
% INFO    : Bus 4228	: V=1.01593418, theta=-22.3581276 -> V=1.0158755, theta=0.0
% INFO    : Bus 4229	: V=1.00885936, theta=-23.6370755 -> V=1.0158755, theta=0.0
% INFO    : Bus 4230	: V=1.02628054, theta=-17.0052495 -> V=0.999999, theta=0.0
% INFO    : Bus 4231	: V=1.025, theta=-14.2929178 -> V=0.999999, theta=0.0
% INFO    : Bus 4232	: V=1.00977534, theta=-12.6855571 -> V=1.0158755, theta=0.0
% INFO    : Bus 4233	: V=1.01139736, theta=-15.3005482 -> V=0.999999, theta=0.0
% INFO    : Bus 4234	: V=1.00608996, theta=-20.2109907 -> V=0.999999, theta=0.0
% INFO    : Bus 4235	: V=1.02079373, theta=-52.0919516 -> V=1.022224, theta=0.0
% INFO    : Bus 4236	: V=1.03043051, theta=-20.5454074 -> V=1.0000025, theta=0.0
% INFO    : Bus 4237	: V=1.02089918, theta=-17.2612943 -> V=0.9888895, theta=0.0
% INFO    : Bus 4238	: V=1.02080153, theta=-17.2978444 -> V=0.9888895, theta=0.0
% INFO    : Bus 4239	: V=1.01890203, theta=-43.6078689 -> V=1.022224, theta=0.0
% INFO    : Bus 4240	: V=1.02824455, theta=-41.144697 -> V=1.022224, theta=0.0
% INFO    : Bus 4241	: V=1.02643884, theta=-54.9385189 -> V=1.0079355, theta=0.0
% INFO    : Bus 4242	: V=1.0400479, theta=-40.7289842 -> V=1.022224, theta=0.0
% INFO    : Bus 4243	: V=1.06719382, theta=-37.2088347 -> V=1.04444, theta=0.0
% INFO    : Bus 4244	: V=1.067, theta=-16.1005084 -> V=1.000001, theta=0.0
% INFO    : Bus 4245	: V=0.971, theta=-32.2257017 -> V=1.015872, theta=0.0
% INFO    : Bus 4246	: V=1.03099991, theta=-29.5774932 -> V=1.0000025, theta=0.0
% INFO    : Bus 4247	: V=0.996646624, theta=-23.4255231 -> V=1.015872, theta=0.0
% INFO    : Bus 4248	: V=0.999597882, theta=-16.7847283 -> V=1.015872, theta=0.0
% INFO    : Bus 4249	: V=1.05606673, theta=-19.2444156 -> V=1.0000025, theta=0.0
% INFO    : Bus 4250	: V=1.02896227, theta=-20.7211204 -> V=1.015872, theta=0.0
% INFO    : Bus 4251	: V=1.04020671, theta=-15.2127757 -> V=1.046665, theta=0.0
% INFO    : Bus 4252	: V=1.01982734, theta=-7.27330209 -> V=1.0158755, theta=0.0
% INFO    : Bus 4253	: V=1.0398392, theta=-20.7518168 -> V=1.015872, theta=0.0
% INFO    : Bus 4254	: V=1.0492379, theta=-17.5035809 -> V=1.046665, theta=0.0
% INFO    : Bus 4255	: V=1.02155036, theta=-23.0144015 -> V=1.0000025, theta=0.0
% INFO    : Bus 4256	: V=1.03842889, theta=-17.3282996 -> V=1.044445, theta=0.0
% INFO    : Bus 4257	: V=1.0270533, theta=-16.919972 -> V=0.999999, theta=0.0
% INFO    : Bus 4258	: V=1.00493411, theta=-15.7119367 -> V=0.999999, theta=0.0
% INFO    : Bus 4259	: V=1.02225167, theta=-11.6836925 -> V=1.015872, theta=0.0
% INFO    : Bus 4260	: V=1.00724496, theta=-65.059647 -> V=1.0079355, theta=0.0
% INFO    : Bus 4261	: V=1.02621418, theta=-37.4491962 -> V=1.022224, theta=0.0
% INFO    : Bus 4262	: V=1.04876737, theta=-5.77962419 -> V=1.0111115, theta=0.0
% INFO    : Bus 4263	: V=1.01575782, theta=-6.03493438 -> V=0.999999, theta=0.0
% INFO    : Bus 4264	: V=1.02235468, theta=-6.12898899 -> V=0.999999, theta=0.0
% INFO    : Bus 4265	: V=1.02533517, theta=-37.5108851 -> V=1.027779, theta=0.0
% INFO    : Bus 4266	: V=1.02972845, theta=-16.6782217 -> V=0.999999, theta=0.0
% INFO    : Bus 4267	: V=1.03238907, theta=-47.4208335 -> V=1.022224, theta=0.0
% INFO    : Bus 4268	: V=0.986143984, theta=-25.7685975 -> V=1.015872, theta=0.0
% INFO    : Bus 4269	: V=1.05121504, theta=-18.6046453 -> V=1.033334, theta=0.0
% INFO    : Bus 4270	: V=0.99954823, theta=-23.2667191 -> V=1.015872, theta=0.0
% INFO    : Bus 4271	: V=1.01795553, theta=-25.4808558 -> V=1.0000025, theta=0.0
% INFO    : Bus 4272	: V=0.94348235, theta=-40.423064 -> V=0.996874, theta=0.0
% INFO    : Bus 4273	: V=1.00129678, theta=-33.1031397 -> V=1.015872, theta=0.0
% INFO    : Bus 4274	: V=1.05767811, theta=-27.8381118 -> V=0.975, theta=0.0
% INFO    : Bus 4275	: V=1.056, theta=-29.7857006 -> V=1.019107, theta=0.0
% INFO    : Bus 4276	: V=1.04804715, theta=-28.7119792 -> V=1.0233335, theta=0.0
% INFO    : Bus 4277	: V=1.05777579, theta=-24.2007068 -> V=1.0000025, theta=0.0
% INFO    : Bus 4278	: V=0.99857736, theta=-33.999821 -> V=1.015872, theta=0.0
% INFO    : Bus 4279	: V=0.998042628, theta=-34.0870668 -> V=1.015872, theta=0.0
% INFO    : Bus 4280	: V=1.00499989, theta=-5.45693648 -> V=0.999999, theta=0.0
% INFO    : Bus 4281	: V=1.02381206, theta=-11.3386899 -> V=1.0158755, theta=0.0
% INFO    : Bus 4282	: V=1.00351112, theta=-15.1051633 -> V=1.0158755, theta=0.0
% INFO    : Bus 4283	: V=1.02406918, theta=-23.6017131 -> V=1.022224, theta=0.0
% INFO    : Bus 4284	: V=1.07157217, theta=-23.0149002 -> V=1.04444, theta=0.0
% INFO    : Bus 4285	: V=1.08215682, theta=-19.7205328 -> V=1.07237, theta=0.0
% INFO    : Bus 4286	: V=1.08214396, theta=-19.7246837 -> V=1.07237, theta=0.0
% INFO    : Bus 4287	: V=1.01693961, theta=-11.5995855 -> V=0.999999, theta=0.0
% INFO    : Bus 4288	: V=1.04186242, theta=-30.8636297 -> V=1.027779, theta=0.0
% INFO    : Bus 4289	: V=1.01953271, theta=-19.8471947 -> V=1.0158755, theta=0.0
% INFO    : Bus 4290	: V=1.10476235, theta=-16.0305574 -> V=1.0357405, theta=0.0
% INFO    : Bus 4291	: V=1.06720011, theta=-16.0305574 -> V=1.0377785, theta=0.0
% INFO    : Bus 4292	: V=1.07359394, theta=-12.0205122 -> V=1.072365, theta=0.0
% INFO    : Bus 4293	: V=1.00693029, theta=-21.7003251 -> V=1.015872, theta=0.0
% INFO    : Bus 4294	: V=1.04988308, theta=-15.9317679 -> V=1.046665, theta=0.0
% INFO    : Bus 4295	: V=1.01742352, theta=-25.8965583 -> V=1.0000025, theta=0.0
% INFO    : Bus 4296	: V=1.0175067, theta=-39.3243713 -> V=1.027779, theta=0.0
% INFO    : Bus 4297	: V=1.0056268, theta=-37.0867233 -> V=1.027779, theta=0.0
% INFO    : Bus 4298	: V=1.00516319, theta=-37.0966007 -> V=1.027779, theta=0.0
% INFO    : Bus 4299	: V=1.017, theta=-11.5282452 -> V=0.999999, theta=0.0
% INFO    : Bus 4300	: V=1.04558505, theta=-14.33433 -> V=0.999999, theta=0.0
% INFO    : Bus 4301	: V=1.04759052, theta=-26.9482116 -> V=1.0000025, theta=0.0
% INFO    : Bus 4302	: V=1.0321864, theta=-19.982231 -> V=1.0158755, theta=0.0
% INFO    : Bus 4303	: V=1.06649541, theta=-21.7328947 -> V=1.000001, theta=0.0
% INFO    : Bus 4304	: V=1.08401061, theta=-17.9180678 -> V=1.044445, theta=0.0
% INFO    : Bus 4305	: V=1.01889506, theta=-61.5179142 -> V=1.0079355, theta=0.0
% INFO    : Bus 4306	: V=0.999174478, theta=-25.1874869 -> V=1.0158755, theta=0.0
% INFO    : Bus 4307	: V=0.99885454, theta=-25.2270983 -> V=1.0158755, theta=0.0
% INFO    : Bus 4308	: V=1.05648936, theta=-18.9333518 -> V=1.001094, theta=0.0
% INFO    : Bus 4309	: V=1.05234842, theta=-19.1703464 -> V=0.999999, theta=0.0
% INFO    : Bus 4310	: V=1.02712944, theta=-31.3911272 -> V=1.022224, theta=0.0
% INFO    : Bus 4311	: V=1.06268755, theta=-25.7572376 -> V=1.04444, theta=0.0
% INFO    : Bus 4312	: V=1.0614669, theta=-26.0281611 -> V=1.04444, theta=0.0
% INFO    : Bus 4313	: V=1.04796377, theta=-30.6374946 -> V=1.027779, theta=0.0
% INFO    : Bus 4314	: V=1.01304054, theta=-36.5821852 -> V=1.0000025, theta=0.0
% INFO    : Bus 4315	: V=1.045, theta=-11.482791 -> V=1.000119, theta=0.0
% INFO    : Bus 4316	: V=1.02584929, theta=-16.7789376 -> V=0.999999, theta=0.0
% INFO    : Bus 4317	: V=1.01634914, theta=-41.5920616 -> V=1.022224, theta=0.0
% INFO    : Bus 4318	: V=1.00572037, theta=-15.9487189 -> V=0.999999, theta=0.0
% INFO    : Bus 4319	: V=1.062, theta=-14.559431 -> V=1.000001, theta=0.0
% INFO    : Bus 4320	: V=1.04943477, theta=-27.3148682 -> V=1.0000025, theta=0.0
% INFO    : Bus 4321	: V=1.01746537, theta=-53.6439287 -> V=1.022224, theta=0.0
% INFO    : Bus 4322	: V=1.03582113, theta=-59.4883593 -> V=1.0079355, theta=0.0
% INFO    : Bus 4323	: V=1.00059926, theta=-8.81638197 -> V=0.999999, theta=0.0
% INFO    : Bus 4324	: V=1.04835544, theta=-6.29789929 -> V=1.0111115, theta=0.0
% INFO    : Bus 4325	: V=1.02552787, theta=-31.1898818 -> V=1.0000025, theta=0.0
% INFO    : Bus 4326	: V=1.02953078, theta=-60.2810853 -> V=1.0079355, theta=0.0
% INFO    : Bus 4327	: V=1.008, theta=-13.4046696 -> V=0.999999, theta=0.0
% INFO    : Bus 4328	: V=1.00516954, theta=-25.0448545 -> V=1.0158755, theta=0.0
% INFO    : Bus 4329	: V=1.01793474, theta=-5.01818162 -> V=1.0158755, theta=0.0
% INFO    : Bus 4330	: V=1.01997226, theta=-2.1989034 -> V=1.0158755, theta=0.0
% INFO    : Bus 4331	: V=1.0772862, theta=-0.509681142 -> V=1.0377785, theta=0.0
% INFO    : Bus 4332	: V=1.07635117, theta=-0.31017135 -> V=1.0377785, theta=0.0
% INFO    : Bus 4333	: V=1.03029441, theta=-28.1575844 -> V=1.0000025, theta=0.0
% INFO    : Bus 4334	: V=1.02478448, theta=-37.4597214 -> V=1.0000025, theta=0.0
% INFO    : Bus 4335	: V=1.02584948, theta=-22.1167132 -> V=0.999999, theta=0.0
% INFO    : Bus 4336	: V=1.02131119, theta=-42.43107 -> V=1.022224, theta=0.0
% INFO    : Bus 4337	: V=1.02920854, theta=-26.7477004 -> V=1.0000025, theta=0.0
% INFO    : Bus 4338	: V=0.955099363, theta=-7.85191585 -> V=0.9444445, theta=0.0
% INFO    : Bus 4339	: V=1.05938921, theta=-44.3456125 -> V=0.975, theta=0.0
% INFO    : Bus 4340	: V=1.05938995, theta=-44.3451858 -> V=0.975, theta=0.0
% INFO    : Bus 4341	: V=1.0594084, theta=-44.3482939 -> V=0.975, theta=0.0
% INFO    : Bus 4342	: V=1.02961423, theta=-49.1596899 -> V=1.0079355, theta=0.0
% INFO    : Bus 4343	: V=1.05943263, theta=-44.3348974 -> V=1.04444, theta=0.0
% INFO    : Bus 4344	: V=1.02342257, theta=-23.7586519 -> V=1.022224, theta=0.0
% INFO    : Bus 4345	: V=1.027, theta=-29.7207522 -> V=1.0000025, theta=0.0
% INFO    : Bus 4346	: V=1.03152143, theta=-3.60036985 -> V=1.0158755, theta=0.0
% INFO    : Bus 4347	: V=1.08150178, theta=0.600790997 -> V=1.0387835, theta=0.0
% INFO    : Bus 4348	: V=1.03459628, theta=-22.4968125 -> V=1.000001, theta=0.0
% INFO    : Bus 4349	: V=1.01640084, theta=-18.9387764 -> V=0.999999, theta=0.0
% INFO    : Bus 4350	: V=1.03986072, theta=-11.4633552 -> V=0.999999, theta=0.0
% INFO    : Bus 4351	: V=1.04021759, theta=-11.4673988 -> V=0.999999, theta=0.0
% INFO    : Bus 4352	: V=1.04375109, theta=-18.4140681 -> V=1.0000025, theta=0.0
% INFO    : Bus 4353	: V=1.0557498, theta=-43.1527755 -> V=0.975, theta=0.0
% INFO    : Bus 4354	: V=1.01603756, theta=-44.8644644 -> V=1.022224, theta=0.0
% INFO    : Bus 4355	: V=1.05586904, theta=-43.1261174 -> V=1.04444, theta=0.0
% INFO    : Bus 4356	: V=1.00294118, theta=-64.6053034 -> V=1.0079355, theta=0.0
% INFO    : Bus 4357	: V=1.02601901, theta=-29.5550867 -> V=1.0000025, theta=0.0
% INFO    : Bus 4358	: V=1.00644602, theta=-22.8676691 -> V=1.0000025, theta=0.0
% INFO    : Bus 4359	: V=1.03480036, theta=-23.2426394 -> V=1.0000025, theta=0.0
% INFO    : Bus 4360	: V=0.988425669, theta=-40.2580379 -> V=1.015872, theta=0.0
% INFO    : Bus 4361	: V=0.985153793, theta=-37.776781 -> V=1.015872, theta=0.0
% INFO    : Bus 4362	: V=1.01501534, theta=-30.4742234 -> V=1.0000025, theta=0.0
% INFO    : Bus 4363	: V=1.00636833, theta=-35.9646162 -> V=1.022224, theta=0.0
% INFO    : Bus 4364	: V=1.02626643, theta=-53.9455048 -> V=1.0079355, theta=0.0
% INFO    : Bus 4365	: V=1.01059164, theta=-30.5232358 -> V=1.0000005, theta=0.0
% INFO    : Bus 4366	: V=1.00822504, theta=-30.7787752 -> V=1.0000005, theta=0.0
% INFO    : Bus 4367	: V=0.994179301, theta=-34.3951244 -> V=1.0000005, theta=0.0
% INFO    : Bus 4368	: V=1.05025363, theta=-33.9739336 -> V=1.0000025, theta=0.0
% INFO    : Bus 4369	: V=0.990941581, theta=-15.4657597 -> V=0.999999, theta=0.0
% INFO    : Bus 4370	: V=1.04456483, theta=-23.8956592 -> V=1.022224, theta=0.0
% INFO    : Bus 4371	: V=1.043, theta=-24.6963315 -> V=1.000001, theta=0.0
% INFO    : Bus 4372	: V=1.04413496, theta=-26.4130182 -> V=1.0000025, theta=0.0
% INFO    : Bus 4373	: V=0.994854901, theta=-16.3920376 -> V=1.0000025, theta=0.0
% INFO    : Bus 4374	: V=1.02562781, theta=-11.0810309 -> V=1.0158755, theta=0.0
% INFO    : Bus 4375	: V=1.01814079, theta=-22.6299264 -> V=0.999999, theta=0.0
% INFO    : Bus 4376	: V=0.978198468, theta=-7.19130363 -> V=1.0158755, theta=0.0
% INFO    : Bus 4377	: V=1.00278076, theta=-13.4714361 -> V=1.0158755, theta=0.0
% INFO    : Bus 4378	: V=0.982139692, theta=-6.07692173 -> V=0.9444445, theta=0.0
% INFO    : Bus 4379	: V=1.03315436, theta=-46.9819495 -> V=1.022224, theta=0.0
% INFO    : Bus 4380	: V=1.01151645, theta=-21.0246228 -> V=1.0158755, theta=0.0
% INFO    : Bus 4381	: V=1.01674624, theta=-53.7563608 -> V=1.022224, theta=0.0
% INFO    : Bus 4382	: V=1.03019867, theta=-15.9446422 -> V=0.999999, theta=0.0
% INFO    : Bus 4383	: V=1.01258439, theta=-36.3154605 -> V=1.022224, theta=0.0
% INFO    : Bus 4384	: V=1.02112572, theta=-13.7101848 -> V=1.015872, theta=0.0
% INFO    : Bus 4385	: V=1.05756185, theta=-29.4068334 -> V=1.046665, theta=0.0
% INFO    : Bus 4386	: V=1.06185656, theta=-31.1252954 -> V=1.046665, theta=0.0
% INFO    : Bus 4387	: V=1.00352031, theta=-14.5894836 -> V=1.015872, theta=0.0
% INFO    : Bus 4388	: V=1.02828175, theta=-10.9421296 -> V=1.0158755, theta=0.0
% INFO    : Bus 4389	: V=1.06048272, theta=-7.70611753 -> V=1.0377785, theta=0.0
% INFO    : Bus 4390	: V=1.08123344, theta=-41.8772174 -> V=0.975, theta=0.0
% INFO    : Bus 4391	: V=1.03227948, theta=-46.1711403 -> V=1.0079355, theta=0.0
% INFO    : Bus 4392	: V=1.08132664, theta=-41.8521387 -> V=1.04444, theta=0.0
% INFO    : Bus 4393	: V=1.01363555, theta=-65.6760638 -> V=1.0079355, theta=0.0
% INFO    : Bus 4394	: V=1.04558, theta=-24.5346488 -> V=1.000001, theta=0.0
% INFO    : Bus 4395	: V=1.06158296, theta=-23.3789204 -> V=1.022222, theta=0.0
% INFO    : Bus 4396	: V=1.06018396, theta=-23.524538 -> V=1.022222, theta=0.0
% INFO    : Bus 4397	: V=1.04190539, theta=-26.120535 -> V=1.0000025, theta=0.0
% INFO    : Bus 4398	: V=1.06586476, theta=-22.3638753 -> V=1.044445, theta=0.0
% INFO    : Bus 4399	: V=1.0348998, theta=-31.7829134 -> V=1.046665, theta=0.0
% INFO    : Bus 4400	: V=1.03366993, theta=-20.5399367 -> V=0.999999, theta=0.0
% INFO    : Bus 4401	: V=1.00003614, theta=-52.9015967 -> V=1.0079355, theta=0.0
% INFO    : Bus 4402	: V=1.03495138, theta=-27.1347697 -> V=1.0000025, theta=0.0
% INFO    : Bus 4403	: V=1.01571729, theta=-61.1937721 -> V=1.0079355, theta=0.0
% INFO    : Bus 4404	: V=1.02979234, theta=-10.1587983 -> V=1.0158755, theta=0.0
% INFO    : Bus 4405	: V=1.08995777, theta=-14.4168289 -> V=1.04529, theta=0.0
% INFO    : Bus 4406	: V=1.03363494, theta=-29.2522984 -> V=1.000001, theta=0.0
% INFO    : Bus 4407	: V=1.01740583, theta=-15.2140999 -> V=0.999999, theta=0.0
% INFO    : Bus 4408	: V=1.01078433, theta=-21.9716762 -> V=0.999999, theta=0.0
% INFO    : Bus 4409	: V=1.02785174, theta=-17.9669454 -> V=1.015872, theta=0.0
% INFO    : Bus 4410	: V=1.02101861, theta=-23.9539663 -> V=1.022224, theta=0.0
% INFO    : Bus 4411	: V=1.03898992, theta=-11.0623927 -> V=0.999999, theta=0.0
% INFO    : Bus 4412	: V=0.978848781, theta=-40.434503 -> V=1.015872, theta=0.0
% INFO    : Bus 4413	: V=1.01525754, theta=-61.0400313 -> V=1.0079355, theta=0.0
% INFO    : Bus 4414	: V=0.965104643, theta=-56.4557228 -> V=1.006081, theta=0.0
% INFO    : Bus 4415	: V=1.03306317, theta=-34.4493016 -> V=1.015872, theta=0.0
% INFO    : Bus 4416	: V=1.04996035, theta=-38.3868567 -> V=1.027779, theta=0.0
% INFO    : Bus 4417	: V=1.01390724, theta=-25.9172263 -> V=0.999999, theta=0.0
% INFO    : Bus 4418	: V=1.04109851, theta=-20.2668262 -> V=0.9888895, theta=0.0
% INFO    : Bus 4419	: V=1.04129935, theta=-20.2633489 -> V=0.9888895, theta=0.0
% INFO    : Bus 4420	: V=1.04072283, theta=-31.6184408 -> V=1.027779, theta=0.0
% INFO    : Bus 4421	: V=1.04060778, theta=-31.6155238 -> V=1.027779, theta=0.0
% INFO    : Bus 4422	: V=1.06454978, theta=-27.6475784 -> V=1.046665, theta=0.0
% INFO    : Bus 4423	: V=1.00181233, theta=-13.96536 -> V=0.999999, theta=0.0
% INFO    : Bus 4424	: V=0.983752391, theta=-16.8977039 -> V=1.015872, theta=0.0
% INFO    : Bus 4425	: V=1.02764765, theta=-20.2813819 -> V=0.999999, theta=0.0
% INFO    : Bus 4426	: V=0.999603701, theta=-27.9256614 -> V=0.999999, theta=0.0
% INFO    : Bus 4427	: V=1.01315239, theta=-38.8744892 -> V=1.022224, theta=0.0
% INFO    : Bus 4428	: V=1.02891963, theta=-53.1514374 -> V=1.0079355, theta=0.0
% INFO    : Bus 4429	: V=0.984449321, theta=-34.2093791 -> V=1.0000005, theta=0.0
% INFO    : Bus 4430	: V=0.97700789, theta=-34.7733823 -> V=1.0000005, theta=0.0
% INFO    : Bus 4431	: V=1.01645296, theta=-24.4919774 -> V=1.0000025, theta=0.0
% INFO    : Bus 4432	: V=1.0686392, theta=-21.064151 -> V=1.000001, theta=0.0
% INFO    : Bus 4433	: V=1.02984308, theta=-23.7579742 -> V=1.0000025, theta=0.0
% INFO    : Bus 4434	: V=1.04370051, theta=-18.1732389 -> V=0.999999, theta=0.0
% INFO    : Bus 4435	: V=1.01540868, theta=-18.0338391 -> V=0.999999, theta=0.0
% INFO    : Bus 4436	: V=1.01673803, theta=-58.7438415 -> V=1.0079355, theta=0.0
% INFO    : Bus 4437	: V=1.04545422, theta=-26.2832182 -> V=1.0000025, theta=0.0
% INFO    : Bus 4438	: V=1.01597629, theta=-30.2019918 -> V=1.0158755, theta=0.0
% INFO    : Bus 4439	: V=0.993041546, theta=-32.9965888 -> V=1.0158755, theta=0.0
% INFO    : Bus 4440	: V=1.03529301, theta=-27.6444004 -> V=1.0000025, theta=0.0
% INFO    : Bus 4441	: V=0.985742055, theta=-39.8127235 -> V=1.015872, theta=0.0
% INFO    : Bus 4442	: V=1.00495683, theta=-19.6549391 -> V=1.015872, theta=0.0
% INFO    : Bus 4443	: V=1.07344338, theta=-18.9893983 -> V=1.0278985, theta=0.0
% INFO    : Bus 4444	: V=1.05301061, theta=-16.0297958 -> V=1.046665, theta=0.0
% INFO    : Bus 4445	: V=1.06300075, theta=-23.3399346 -> V=1.0000025, theta=0.0
% INFO    : Bus 4446	: V=1.01880611, theta=-24.6222999 -> V=1.0158755, theta=0.0
% INFO    : Bus 4447	: V=1.0228583, theta=-31.2523887 -> V=1.022224, theta=0.0
% INFO    : Bus 4448	: V=0.985335813, theta=-24.8600135 -> V=1.0158755, theta=0.0
% INFO    : Bus 4449	: V=1.00127061, theta=-15.5389088 -> V=0.999999, theta=0.0
% INFO    : Bus 4450	: V=1.01949064, theta=-18.2016323 -> V=1.015872, theta=0.0
% INFO    : Bus 4451	: V=1.052, theta=-27.9789254 -> V=1.0233335, theta=0.0
% INFO    : Bus 4452	: V=1.0374486, theta=-24.3511821 -> V=1.0000025, theta=0.0
% INFO    : Bus 4453	: V=1.00981702, theta=-27.0095061 -> V=1.000001, theta=0.0
% INFO    : Bus 4454	: V=1.0245618, theta=-22.3728258 -> V=0.999999, theta=0.0
% INFO    : Bus 4455	: V=1.05412306, theta=-19.6930664 -> V=1.0000025, theta=0.0
% INFO    : Bus 4456	: V=1.02861381, theta=-27.1226386 -> V=1.0000025, theta=0.0
% INFO    : Bus 4457	: V=1.07528654, theta=-17.7908914 -> V=1.044445, theta=0.0
% INFO    : Bus 4458	: V=1.02158848, theta=-18.5928967 -> V=1.015872, theta=0.0
% INFO    : Bus 4459	: V=1.02528756, theta=-37.2936058 -> V=1.027779, theta=0.0
% INFO    : Bus 4460	: V=1.02037251, theta=-23.5782225 -> V=1.0000025, theta=0.0
% INFO    : Bus 4461	: V=1.05738501, theta=-19.3368239 -> V=1.044445, theta=0.0
% INFO    : Bus 4462	: V=1.01020444, theta=-22.8582637 -> V=1.0158755, theta=0.0
% INFO    : Bus 4463	: V=1.04457892, theta=-27.4928541 -> V=1.0000025, theta=0.0
% INFO    : Bus 4464	: V=1.02711872, theta=-14.3119127 -> V=0.999999, theta=0.0
% INFO    : Bus 4465	: V=1.03843518, theta=-12.7196068 -> V=0.999999, theta=0.0
% INFO    : Bus 4466	: V=1.04534153, theta=-10.2340497 -> V=1.0111115, theta=0.0
% INFO    : Bus 4467	: V=1.07925383, theta=-2.92149584 -> V=1.072365, theta=0.0
% INFO    : Bus 4468	: V=1.07813742, theta=-2.99234243 -> V=1.072365, theta=0.0
% INFO    : Bus 4469	: V=1.04142152, theta=-29.6331902 -> V=1.027779, theta=0.0
% INFO    : Bus 4470	: V=1.00706528, theta=-22.6417458 -> V=0.999999, theta=0.0
% INFO    : Bus 4471	: V=1.00188286, theta=-27.6749694 -> V=1.000001, theta=0.0
% INFO    : Bus 4472	: V=1.0274184, theta=-30.9281448 -> V=1.027779, theta=0.0
% INFO    : Bus 4473	: V=1.03441898, theta=-1.86420089 -> V=1.0158755, theta=0.0
% INFO    : Bus 4474	: V=1.03451647, theta=-1.8614686 -> V=1.0158755, theta=0.0
% INFO    : Bus 4475	: V=1.05329546, theta=-6.57149179 -> V=1.0000025, theta=0.0
% INFO    : Bus 4476	: V=1.07235387, theta=-3.11149244 -> V=1.0288895, theta=0.0
% INFO    : Bus 4477	: V=1.01565491, theta=-23.8059491 -> V=1.0000025, theta=0.0
% INFO    : Bus 4478	: V=1.028, theta=-6.86227318 -> V=0.975, theta=0.0
% INFO    : Bus 4479	: V=1.056, theta=-4.02197433 -> V=0.975, theta=0.0
% INFO    : Bus 4480	: V=1.056, theta=-3.96221078 -> V=0.975, theta=0.0
% INFO    : Bus 4481	: V=1.055, theta=-3.93030836 -> V=0.975, theta=0.0
% INFO    : Bus 4482	: V=1.06, theta=-3.99992749 -> V=0.975, theta=0.0
% INFO    : Bus 4483	: V=1.01924864, theta=-10.8682554 -> V=1.0158755, theta=0.0
% INFO    : Bus 4484	: V=1.0546228, theta=-5.13406471 -> V=1.0377785, theta=0.0
% INFO    : Bus 4485	: V=1.05462242, theta=-5.13345461 -> V=1.0377785, theta=0.0
% INFO    : Bus 4486	: V=1.05461201, theta=-5.1331485 -> V=1.0377785, theta=0.0
% INFO    : Bus 4487	: V=1.05466344, theta=-5.13376404 -> V=1.0377785, theta=0.0
% INFO    : Bus 4488	: V=1.01913811, theta=-11.0107836 -> V=1.0158755, theta=0.0
% INFO    : Bus 4489	: V=1.02118864, theta=-11.1324518 -> V=1.0158755, theta=0.0
% INFO    : Bus 4490	: V=1.05461374, theta=-5.14554897 -> V=1.0377785, theta=0.0
% INFO    : Bus 4491	: V=1.01424489, theta=-16.3813302 -> V=0.984126, theta=0.0
% INFO    : Bus 4492	: V=1.07661613, theta=0.565596422 -> V=1.0377785, theta=0.0
% INFO    : Bus 4493	: V=0.981438148, theta=-35.0644095 -> V=1.0000005, theta=0.0
% INFO    : Bus 4494	: V=0.998165237, theta=-35.092311 -> V=1.015872, theta=0.0
% INFO    : Bus 4495	: V=1.02557718, theta=-22.4208558 -> V=1.0158755, theta=0.0
% INFO    : Bus 4496	: V=1.03093973, theta=-41.4588652 -> V=1.022224, theta=0.0
% INFO    : Bus 4497	: V=0.975544417, theta=-22.8396558 -> V=1.015872, theta=0.0
% INFO    : Bus 4498	: V=0.976938551, theta=-22.6539373 -> V=1.015872, theta=0.0
% INFO    : Bus 4499	: V=1.03516012, theta=-1.28263706 -> V=1.0158755, theta=0.0
% INFO    : Bus 4500	: V=1.03441881, theta=-1.86419656 -> V=1.0158755, theta=0.0
% INFO    : Bus 4501	: V=1.09103471, theta=-11.6314856 -> V=1.037777, theta=0.0
% INFO    : Bus 4502	: V=1.09103471, theta=-11.6314856 -> V=1.037777, theta=0.0
% INFO    : Bus 4503	: V=1.05284893, theta=-11.6314856 -> V=1.0233335, theta=0.0
% INFO    : Bus 4504	: V=1.02297088, theta=-25.0814996 -> V=0.975, theta=0.0
% INFO    : Bus 4505	: V=1.02297088, theta=-25.0814996 -> V=0.999999, theta=0.0
% INFO    : Bus 4506	: V=1.07719208, theta=-14.1317998 -> V=1.000001, theta=0.0
% INFO    : Bus 4507	: V=1.0672741, theta=-2.57328503 -> V=1.072365, theta=0.0
% INFO    : Bus 4508	: V=1.00681308, theta=-22.844389 -> V=1.015872, theta=0.0
% INFO    : Bus 4509	: V=1.01926758, theta=-34.6745983 -> V=1.022224, theta=0.0
% INFO    : Bus 4510	: V=0.993339837, theta=-45.4243912 -> V=1.022224, theta=0.0
% INFO    : Bus 4511	: V=1.037, theta=-13.0293153 -> V=0.975, theta=0.0
% INFO    : Bus 4512	: V=1.03697863, theta=-13.9781724 -> V=0.999999, theta=0.0
% INFO    : Bus 4513	: V=1.00996725, theta=-26.7759694 -> V=1.022224, theta=0.0
% INFO    : Bus 4514	: V=0.999477559, theta=-21.0332328 -> V=0.999999, theta=0.0
% INFO    : Bus 4515	: V=1.074, theta=-17.2843819 -> V=1.044445, theta=0.0
% INFO    : Bus 4516	: V=1.0360064, theta=-26.388914 -> V=1.0000025, theta=0.0
% INFO    : Bus 4517	: V=1.02679558, theta=-22.9619481 -> V=1.013334, theta=0.0
% INFO    : Bus 4518	: V=1.02995193, theta=-27.9470785 -> V=1.0000025, theta=0.0
% INFO    : Bus 4519	: V=1.02256157, theta=-32.180244 -> V=1.015872, theta=0.0
% INFO    : Bus 4520	: V=1.01714493, theta=-22.3918926 -> V=1.015872, theta=0.0
% INFO    : Bus 4521	: V=1.01450865, theta=-46.6984976 -> V=1.022224, theta=0.0
% INFO    : Bus 4522	: V=1.03176132, theta=-28.4657486 -> V=1.022224, theta=0.0
% INFO    : Bus 4523	: V=1.02124149, theta=-8.46477042 -> V=1.0000025, theta=0.0
% INFO    : Bus 4524	: V=1.056, theta=-14.7033333 -> V=1.006274, theta=0.0
% INFO    : Bus 4525	: V=1.0313138, theta=-36.6982841 -> V=1.022224, theta=0.0
% INFO    : Bus 4526	: V=1.02169377, theta=-13.0429697 -> V=1.015872, theta=0.0
% INFO    : Bus 4527	: V=1.06230872, theta=-10.7308078 -> V=1.0236785, theta=0.0
% INFO    : Bus 4528	: V=1.05641203, theta=-9.42592945 -> V=1.046665, theta=0.0
% INFO    : Bus 4529	: V=1.0113311, theta=-17.8658746 -> V=0.9682545, theta=0.0
% INFO    : Bus 4530	: V=1.04182634, theta=-8.95200329 -> V=1.0000025, theta=0.0
% INFO    : Bus 4531	: V=1.01926982, theta=-2.42921075 -> V=1.0158755, theta=0.0
% INFO    : Bus 4532	: V=1.02946301, theta=-27.3692916 -> V=1.0000025, theta=0.0
% INFO    : Bus 4533	: V=1.01522925, theta=-7.73230201 -> V=1.0158755, theta=0.0
% INFO    : Bus 4534	: V=1.06159791, theta=-18.1954777 -> V=1.04444, theta=0.0
% INFO    : Bus 4535	: V=1.07941015, theta=-14.0917954 -> V=1.07237, theta=0.0
% INFO    : Bus 4536	: V=0.998089822, theta=-24.415927 -> V=1.015872, theta=0.0
% INFO    : Bus 4537	: V=1.02350536, theta=-15.0198729 -> V=0.999999, theta=0.0
% INFO    : Bus 4538	: V=0.563259564, theta=-0.880848364 -> V=0.825, theta=0.0
% INFO    : Bus 4539	: V=1.02343655, theta=-0.880848364 -> V=1.0158755, theta=0.0
% INFO    : Bus 4540	: V=1.01987384, theta=-54.5944727 -> V=1.0079355, theta=0.0
% INFO    : Bus 4541	: V=1.00618072, theta=-37.9111482 -> V=1.0000005, theta=0.0
% INFO    : Bus 4542	: V=1.00789133, theta=-14.0952728 -> V=0.999999, theta=0.0
% INFO    : Bus 4543	: V=1.0672494, theta=-17.9134058 -> V=1.0000025, theta=0.0
% INFO    : Bus 4544	: V=1.05534087, theta=-15.7779682 -> V=1.000001, theta=0.0
% INFO    : Bus 4545	: V=1.07369511, theta=-15.7596422 -> V=1.044445, theta=0.0
% INFO    : Bus 4546	: V=1.03514066, theta=-27.7256837 -> V=1.0000025, theta=0.0
% INFO    : Bus 4547	: V=1.06683602, theta=-18.3387068 -> V=1.005584, theta=0.0
% INFO    : Bus 4548	: V=1.01378808, theta=-50.4491345 -> V=1.022224, theta=0.0
% INFO    : Bus 4549	: V=1.02105573, theta=-18.6446399 -> V=1.015872, theta=0.0
% INFO    : Bus 4550	: V=1.05888671, theta=-15.9852326 -> V=1.044445, theta=0.0
% INFO    : Bus 4551	: V=1.0635232, theta=-12.1656849 -> V=1.076345, theta=0.0
% INFO    : Bus 4552	: V=1.05993873, theta=-12.5011691 -> V=0.999999, theta=0.0
% INFO    : Bus 4553	: V=1.02659432, theta=-49.378513 -> V=1.0079355, theta=0.0
% INFO    : Bus 4554	: V=1.0232533, theta=-50.4959997 -> V=1.0079355, theta=0.0
% INFO    : Bus 4555	: V=1.0297831, theta=-49.2687807 -> V=1.0079355, theta=0.0
% INFO    : Bus 4556	: V=1.03767461, theta=-21.7014402 -> V=1.000001, theta=0.0
% INFO    : Bus 4557	: V=0.99521576, theta=-15.285926 -> V=0.999999, theta=0.0
% INFO    : Bus 4558	: V=1.05205192, theta=-24.5856222 -> V=1.0000025, theta=0.0
% INFO    : Bus 4559	: V=1.06178893, theta=-23.501781 -> V=1.0, theta=0.0
% INFO    : Bus 4560	: V=1.07982479, theta=-23.2767521 -> V=1.044445, theta=0.0
% INFO    : Bus 4561	: V=1.04147782, theta=-25.6065964 -> V=1.0000025, theta=0.0
% INFO    : Bus 4562	: V=1.03810042, theta=-26.0426379 -> V=1.0000025, theta=0.0
% INFO    : Bus 4563	: V=1.07420116, theta=-12.6622905 -> V=1.044445, theta=0.0
% INFO    : Bus 4564	: V=1.01899688, theta=-23.3021222 -> V=0.999999, theta=0.0
% INFO    : Bus 4565	: V=1.05925459, theta=-21.1616609 -> V=1.0000025, theta=0.0
% INFO    : Bus 4566	: V=1.00986566, theta=-34.9504232 -> V=1.0000005, theta=0.0
% INFO    : Bus 4567	: V=1.034, theta=-25.0955503 -> V=1.0000025, theta=0.0
% INFO    : Bus 4568	: V=1.05697929, theta=-12.5410582 -> V=1.000144, theta=0.0
% INFO    : Bus 4569	: V=1.02696653, theta=-20.7718479 -> V=0.999999, theta=0.0
% INFO    : Bus 4570	: V=1.01431831, theta=-22.8888135 -> V=0.999999, theta=0.0
% INFO    : Bus 4571	: V=1.04138347, theta=-26.1966921 -> V=1.0000025, theta=0.0
% INFO    : Bus 4572	: V=1.06207194, theta=-33.2683264 -> V=1.027779, theta=0.0
% INFO    : Bus 4573	: V=1.08528883, theta=-27.0586892 -> V=1.073685, theta=0.0
% INFO    : Bus 4574	: V=1.036, theta=-18.5460977 -> V=1.0377785, theta=0.0
% INFO    : Bus 4575	: V=1.05003965, theta=-10.9270556 -> V=1.046665, theta=0.0
% INFO    : Bus 4576	: V=1.05360413, theta=-9.91650784 -> V=1.046665, theta=0.0
% INFO    : Bus 4577	: V=1.06291249, theta=-5.04731409 -> V=1.07854, theta=0.0
% INFO    : Bus 4578	: V=1.05214179, theta=-29.3828722 -> V=1.04444, theta=0.0
% INFO    : Bus 4579	: V=1.02746288, theta=-51.611779 -> V=1.04444, theta=0.0
% INFO    : Bus 4580	: V=1.00608376, theta=-36.302228 -> V=1.0000005, theta=0.0
% INFO    : Bus 4581	: V=1.12314799, theta=0.172082815 -> V=1.0416355, theta=0.0
% INFO    : Bus 4582	: V=1.04181988, theta=-27.0917535 -> V=1.0000025, theta=0.0
% INFO    : Bus 4583	: V=1.03687994, theta=-20.552101 -> V=0.999999, theta=0.0
% INFO    : Bus 4584	: V=1.0030515, theta=-14.4967656 -> V=1.015872, theta=0.0
% INFO    : Bus 4585	: V=1.00304771, theta=-14.4966833 -> V=1.015872, theta=0.0
% INFO    : Bus 4586	: V=1.03231497, theta=-32.1897765 -> V=1.046665, theta=0.0
% INFO    : Bus 4587	: V=0.981297423, theta=-6.12259267 -> V=0.9444445, theta=0.0
% INFO    : Bus 4588	: V=1.023, theta=-30.1127507 -> V=1.0000025, theta=0.0
% INFO    : Bus 4589	: V=1.02661764, theta=-14.7170314 -> V=0.999999, theta=0.0
% INFO    : Bus 4590	: V=1.04777353, theta=-8.27899195 -> V=1.0000025, theta=0.0
% INFO    : Bus 4591	: V=1.02774049, theta=-25.8847884 -> V=1.000001, theta=0.0
% INFO    : Bus 4592	: V=1.06709502, theta=-34.6050418 -> V=1.046665, theta=0.0
% INFO    : Bus 4593	: V=1.03359445, theta=-29.2550828 -> V=1.033333, theta=0.0
% INFO    : Bus 4594	: V=0.982723385, theta=-35.4917259 -> V=1.0000025, theta=0.0
% INFO    : Bus 4595	: V=1.06501157, theta=-35.870494 -> V=1.027779, theta=0.0
% INFO    : Bus 4596	: V=1.08384712, theta=-27.2096928 -> V=1.073685, theta=0.0
% INFO    : Bus 4597	: V=1.08342438, theta=-27.2059136 -> V=1.073685, theta=0.0
% INFO    : Bus 4598	: V=1.04185135, theta=-16.8447471 -> V=1.015872, theta=0.0
% INFO    : Bus 4599	: V=1.04116076, theta=-12.4913351 -> V=1.046665, theta=0.0
% INFO    : Bus 4600	: V=1.04426994, theta=-15.276091 -> V=0.999999, theta=0.0
% INFO    : Bus 4601	: V=1.03849916, theta=-28.2241958 -> V=1.046665, theta=0.0
% INFO    : Bus 4602	: V=1.05954999, theta=-23.4366989 -> V=1.073685, theta=0.0
% INFO    : Bus 4603	: V=1.05899419, theta=-23.7084691 -> V=1.073685, theta=0.0
% INFO    : Bus 4604	: V=1.00790364, theta=-35.1842407 -> V=1.022224, theta=0.0
% INFO    : Bus 4605	: V=1.0214726, theta=-28.0684561 -> V=1.0000025, theta=0.0
% INFO    : Bus 4606	: V=1.04325756, theta=-28.6996203 -> V=1.022224, theta=0.0
% INFO    : Bus 4607	: V=1.04663868, theta=-12.0807531 -> V=1.0158755, theta=0.0
% INFO    : Bus 4608	: V=0.969698923, theta=-48.9566973 -> V=1.015654, theta=0.0
% INFO    : Bus 4609	: V=1.01907045, theta=-34.6693834 -> V=1.022224, theta=0.0
% INFO    : Bus 4610	: V=1.05949936, theta=-60.2888206 -> V=1.0079355, theta=0.0
% INFO    : Bus 4611	: V=1.05504694, theta=-52.0288962 -> V=1.04444, theta=0.0
% INFO    : Bus 4612	: V=1.03713717, theta=-10.1807155 -> V=1.0158755, theta=0.0
% INFO    : Bus 4613	: V=0.984511452, theta=-34.0317624 -> V=1.0000005, theta=0.0
% INFO    : Bus 4614	: V=1.04842265, theta=-46.2402049 -> V=1.022674, theta=0.0
% INFO    : Bus 4615	: V=1.01747671, theta=-20.0782571 -> V=1.015872, theta=0.0
% INFO    : Bus 4616	: V=1.04787643, theta=-50.4802109 -> V=1.022224, theta=0.0
% INFO    : Bus 4617	: V=1.02992728, theta=-27.059242 -> V=0.999999, theta=0.0
% INFO    : Bus 4618	: V=1.06915344, theta=-22.1847182 -> V=1.000001, theta=0.0
% INFO    : Bus 4619	: V=1.05087596, theta=-18.2506224 -> V=0.9888895, theta=0.0
% INFO    : Bus 4620	: V=0.997947299, theta=-15.5047472 -> V=1.0158755, theta=0.0
% INFO    : Bus 4621	: V=1.04166798, theta=-40.1455877 -> V=1.027779, theta=0.0
% INFO    : Bus 4622	: V=1.0155748, theta=-29.629726 -> V=1.022224, theta=0.0
% INFO    : Bus 4623	: V=1.00775432, theta=-30.8182676 -> V=1.022224, theta=0.0
% INFO    : Bus 4624	: V=1.01230301, theta=-2.79009401 -> V=1.0158755, theta=0.0
% INFO    : Bus 4625	: V=1.05366811, theta=-38.6180995 -> V=1.046665, theta=0.0
% INFO    : Bus 4626	: V=1.05689949, theta=-12.5419315 -> V=1.000104, theta=0.0
% INFO    : Bus 4627	: V=1.02304683, theta=-42.9407379 -> V=1.0000025, theta=0.0
% INFO    : Bus 4628	: V=1.02791789, theta=-16.7261154 -> V=0.999999, theta=0.0
% INFO    : Bus 4629	: V=1.05907918, theta=-16.4871914 -> V=0.999999, theta=0.0
% INFO    : Bus 4630	: V=1.00311832, theta=-45.3823731 -> V=1.022224, theta=0.0
% INFO    : Bus 4631	: V=1.02155796, theta=-17.9648756 -> V=1.015872, theta=0.0
% INFO    : Bus 4632	: V=1.00124926, theta=-34.325172 -> V=1.022224, theta=0.0
% INFO    : Bus 4633	: V=1.00767299, theta=-31.5949453 -> V=1.0000005, theta=0.0
% INFO    : Bus 4634	: V=1.03156095, theta=-35.1367916 -> V=1.022224, theta=0.0
% INFO    : Bus 4635	: V=1.04833484, theta=-28.5323847 -> V=1.0000025, theta=0.0
% INFO    : Bus 4636	: V=1.03329457, theta=-26.3786148 -> V=1.0000025, theta=0.0
% INFO    : Bus 4637	: V=1.07618667, theta=-7.32458387 -> V=1.0377785, theta=0.0
% INFO    : Bus 4638	: V=1.02862646, theta=-13.7274023 -> V=0.999999, theta=0.0
% INFO    : Bus 4639	: V=1.03932, theta=-32.4760819 -> V=1.027779, theta=0.0
% INFO    : Bus 4640	: V=1.07143894, theta=-25.045905 -> V=1.073685, theta=0.0
% INFO    : Bus 4641	: V=1.07191228, theta=-25.0558173 -> V=1.073685, theta=0.0
% INFO    : Bus 4642	: V=1.0242498, theta=-23.8650896 -> V=1.0158755, theta=0.0
% INFO    : Bus 4643	: V=1.01999217, theta=-32.1574535 -> V=1.046665, theta=0.0
% INFO    : Bus 4644	: V=0.992356522, theta=-52.8941578 -> V=1.022224, theta=0.0
% INFO    : Bus 4645	: V=1.02125071, theta=-28.9019322 -> V=1.022224, theta=0.0
% INFO    : Bus 4646	: V=1.01925506, theta=-29.461243 -> V=1.022224, theta=0.0
% INFO    : Bus 4647	: V=0.99272102, theta=-12.8565614 -> V=0.9444445, theta=0.0
% INFO    : Bus 4648	: V=1.05981555, theta=-31.3256288 -> V=1.046665, theta=0.0
% INFO    : Bus 4649	: V=1.06671013, theta=-32.7138375 -> V=1.027779, theta=0.0
% INFO    : Bus 4650	: V=1.09013278, theta=-25.6347858 -> V=1.073685, theta=0.0
% INFO    : Bus 4651	: V=1.06135214, theta=-34.3208288 -> V=1.027779, theta=0.0
% INFO    : Bus 4652	: V=1.01877059, theta=-22.4635668 -> V=1.0158755, theta=0.0
% INFO    : Bus 4653	: V=1.05848848, theta=-20.1423599 -> V=1.0377785, theta=0.0
% INFO    : Bus 4654	: V=1.0579318, theta=-20.2314654 -> V=1.0377785, theta=0.0
% INFO    : Bus 4655	: V=1.0418273, theta=-8.9520274 -> V=1.0000025, theta=0.0
% INFO    : Bus 4656	: V=1.05178348, theta=-26.0764539 -> V=1.0000025, theta=0.0
% INFO    : Bus 4657	: V=1.06681747, theta=-17.9726101 -> V=1.0000025, theta=0.0
% INFO    : Bus 4658	: V=1.0251373, theta=-37.7381096 -> V=1.027779, theta=0.0
% INFO    : Bus 4659	: V=1.00456674, theta=-35.5187755 -> V=1.0000005, theta=0.0
% INFO    : Bus 4660	: V=1.02140066, theta=-26.8658273 -> V=1.0000025, theta=0.0
% INFO    : Bus 4661	: V=1.01624217, theta=-29.8023397 -> V=1.022224, theta=0.0
% INFO    : Bus 4662	: V=1.02904605, theta=-28.1426695 -> V=1.022224, theta=0.0
% INFO    : Bus 4663	: V=1.06559087, theta=-31.3846222 -> V=1.046665, theta=0.0
% INFO    : Bus 4664	: V=1.07799041, theta=-26.861462 -> V=1.073685, theta=0.0
% INFO    : Bus 4665	: V=0.958547932, theta=-8.85291098 -> V=0.9444445, theta=0.0
% INFO    : Bus 4666	: V=1.06510236, theta=-32.8334076 -> V=1.027779, theta=0.0
% INFO    : Bus 4667	: V=1.00629589, theta=-14.6283537 -> V=0.999999, theta=0.0
% INFO    : Bus 4668	: V=1.02524805, theta=-38.4537034 -> V=1.022224, theta=0.0
% INFO    : Bus 4669	: V=1.01613528, theta=-29.9966133 -> V=1.022224, theta=0.0
% INFO    : Bus 4670	: V=1.00391743, theta=-32.4355437 -> V=1.0000005, theta=0.0
% INFO    : Bus 4671	: V=1.05145941, theta=-34.4315579 -> V=1.022224, theta=0.0
% INFO    : Bus 4672	: V=1.06770389, theta=-21.6936441 -> V=1.044445, theta=0.0
% INFO    : Bus 4673	: V=1.04919275, theta=-24.6552733 -> V=1.0111115, theta=0.0
% INFO    : Bus 4674	: V=1.045, theta=-17.5927079 -> V=0.975, theta=0.0
% INFO    : Bus 4675	: V=1.0448725, theta=-17.603966 -> V=1.0000025, theta=0.0
% INFO    : Bus 4676	: V=1.02253092, theta=-33.7489739 -> V=1.015872, theta=0.0
% INFO    : Bus 4677	: V=1.02630138, theta=-28.9350576 -> V=1.046665, theta=0.0
% INFO    : Bus 4678	: V=1.03278941, theta=-26.1340874 -> V=1.064785, theta=0.0
% INFO    : Bus 4679	: V=1.00996616, theta=-17.101841 -> V=1.015872, theta=0.0
% INFO    : Bus 4680	: V=1.00188286, theta=-27.6749694 -> V=1.000001, theta=0.0
% INFO    : Bus 4681	: V=1.01182354, theta=-18.374252 -> V=0.999999, theta=0.0
% INFO    : Bus 4682	: V=1.02970579, theta=-54.5586673 -> V=1.0079355, theta=0.0
% INFO    : Bus 4683	: V=1.02846962, theta=-59.4877859 -> V=1.0079355, theta=0.0
% INFO    : Bus 4684	: V=1.0485475, theta=-50.7929153 -> V=1.04444, theta=0.0
% INFO    : Bus 4685	: V=1.02457345, theta=-41.9056628 -> V=1.022224, theta=0.0
% INFO    : Bus 4686	: V=1.02516529, theta=-31.1516151 -> V=1.000001, theta=0.0
% INFO    : Bus 4687	: V=0.979711712, theta=-47.8468107 -> V=1.019814, theta=0.0
% INFO    : Bus 4688	: V=1.02146444, theta=-16.4735453 -> V=1.015872, theta=0.0
% INFO    : Bus 4689	: V=1.05211688, theta=-17.2372333 -> V=1.001624, theta=0.0
% INFO    : Bus 4690	: V=1.03361043, theta=-13.0489345 -> V=1.0111115, theta=0.0
% INFO    : Bus 4691	: V=1.0165976, theta=-32.9519936 -> V=1.022224, theta=0.0
% INFO    : Bus 4692	: V=1.01948275, theta=-12.1557182 -> V=1.015872, theta=0.0
% INFO    : Bus 4693	: V=1.01948261, theta=-12.1557465 -> V=1.015872, theta=0.0
% INFO    : Bus 4694	: V=1.0260545, theta=3.32591625 -> V=1.033334, theta=0.0
% INFO    : Bus 4695	: V=1.02236031, theta=3.11539964 -> V=1.033334, theta=0.0
% INFO    : Bus 4696	: V=1.02485647, theta=3.12913512 -> V=1.033334, theta=0.0
% INFO    : Bus 4697	: V=1.02350013, theta=3.54846388 -> V=1.033334, theta=0.0
% INFO    : Bus 4698	: V=1.01776633, theta=-24.9051683 -> V=1.0158755, theta=0.0
% INFO    : Bus 4699	: V=1.03603686, theta=-45.5371722 -> V=1.0079355, theta=0.0
% INFO    : Bus 4700	: V=1.04116954, theta=-27.8653604 -> V=1.022222, theta=0.0
% INFO    : Bus 4701	: V=1.02110848, theta=-13.7096435 -> V=1.015872, theta=0.0
% INFO    : Bus 4702	: V=0.9884492, theta=-24.1517534 -> V=1.015872, theta=0.0
% INFO    : Bus 4703	: V=1.05384695, theta=-17.4846386 -> V=0.9888895, theta=0.0
% INFO    : Bus 4704	: V=1.05386245, theta=-17.481917 -> V=0.9888895, theta=0.0
% INFO    : Bus 4705	: V=1.06168118, theta=-7.06642682 -> V=1.046665, theta=0.0
% INFO    : Bus 4706	: V=1.02302114, theta=2.34612468 -> V=1.046665, theta=0.0
% INFO    : Bus 4707	: V=1.01974905, theta=2.1286087 -> V=1.046665, theta=0.0
% INFO    : Bus 4708	: V=1.0235119, theta=2.50588992 -> V=1.046665, theta=0.0
% INFO    : Bus 4709	: V=1.02017157, theta=2.35154097 -> V=1.046665, theta=0.0
% INFO    : Bus 4710	: V=1.02209064, theta=2.15495984 -> V=1.046665, theta=0.0
% INFO    : Bus 4711	: V=1.02064886, theta=2.39177999 -> V=1.046665, theta=0.0
% INFO    : Bus 4712	: V=1.02262993, theta=2.36485634 -> V=1.046665, theta=0.0
% INFO    : Bus 4713	: V=1.02108849, theta=2.63230079 -> V=1.046665, theta=0.0
% INFO    : Bus 4714	: V=1.07353026, theta=-1.18783267 -> V=1.078945, theta=0.0
% INFO    : Bus 4715	: V=1.03107113, theta=-30.4661486 -> V=1.0000025, theta=0.0
% INFO    : Bus 4716	: V=1.02317854, theta=-17.8203932 -> V=1.0158755, theta=0.0
% INFO    : Bus 4717	: V=1.02402821, theta=-10.8325671 -> V=1.0158755, theta=0.0
% INFO    : Bus 4718	: V=1.056, theta=-19.6098326 -> V=1.0000025, theta=0.0
% INFO    : Bus 4719	: V=1.09912226, theta=-16.9549312 -> V=1.0, theta=0.0
% INFO    : Bus 4720	: V=1.01493281, theta=-5.35522931 -> V=1.0158755, theta=0.0
% INFO    : Bus 4721	: V=1.061, theta=-30.7662212 -> V=1.0000025, theta=0.0
% INFO    : Bus 4722	: V=1.04400606, theta=-25.7334431 -> V=1.044445, theta=0.0
% INFO    : Bus 4723	: V=1.02835036, theta=-22.4222239 -> V=1.000001, theta=0.0
% INFO    : Bus 4724	: V=1.06470567, theta=-17.600585 -> V=0.9888895, theta=0.0
% INFO    : Bus 4725	: V=1.06471828, theta=-17.5982292 -> V=0.9888895, theta=0.0
% INFO    : Bus 4726	: V=1.06453927, theta=-17.610997 -> V=0.9888895, theta=0.0
% INFO    : Bus 4727	: V=1.01078016, theta=-26.6080671 -> V=1.000001, theta=0.0
% INFO    : Bus 4728	: V=1.03446315, theta=-31.8342468 -> V=1.046665, theta=0.0
% INFO    : Bus 4729	: V=0.997734844, theta=-14.3150599 -> V=1.0158755, theta=0.0
% INFO    : Bus 4730	: V=0.997624351, theta=-31.6628417 -> V=1.0000005, theta=0.0
% INFO    : Bus 4731	: V=1.02226781, theta=-34.1233092 -> V=1.022224, theta=0.0
% INFO    : Bus 4732	: V=1.05603054, theta=-6.64189482 -> V=1.0377785, theta=0.0
% INFO    : Bus 4733	: V=1.02491195, theta=-5.96728755 -> V=0.999999, theta=0.0
% INFO    : Bus 4734	: V=1.04167862, theta=-40.1456448 -> V=1.027779, theta=0.0
% INFO    : Bus 4735	: V=1.01913805, theta=-18.0073776 -> V=1.0158755, theta=0.0
% INFO    : Bus 4736	: V=1.03057266, theta=-33.4904201 -> V=1.015872, theta=0.0
% INFO    : Bus 4737	: V=1.03771245, theta=-29.8630892 -> V=1.046665, theta=0.0
% INFO    : Bus 4738	: V=1.0760345, theta=-21.4411776 -> V=1.044705, theta=0.0
% INFO    : Bus 4739	: V=1.01818672, theta=-21.0219825 -> V=1.0000015, theta=0.0
% INFO    : Bus 4740	: V=0.991321108, theta=-17.3129783 -> V=0.999999, theta=0.0
% INFO    : Bus 4741	: V=1.04031741, theta=-10.5398885 -> V=0.999999, theta=0.0
% INFO    : Bus 4742	: V=1.0202953, theta=-7.23818573 -> V=1.0158755, theta=0.0
% INFO    : Bus 4743	: V=1.01264657, theta=-33.2593287 -> V=1.015872, theta=0.0
% INFO    : Bus 4744	: V=1.03514449, theta=-29.3970992 -> V=1.046665, theta=0.0
% INFO    : Bus 4745	: V=0.958547932, theta=-8.85291098 -> V=0.9444445, theta=0.0
% INFO    : Bus 4746	: V=1.05740376, theta=-7.65791787 -> V=1.0111115, theta=0.0
% INFO    : Bus 4747	: V=1.01230738, theta=-30.8853072 -> V=1.0000025, theta=0.0
% INFO    : Bus 4748	: V=1.03482044, theta=-17.3738374 -> V=0.999999, theta=0.0
% INFO    : Bus 4749	: V=1.03143966, theta=-27.554219 -> V=1.0000025, theta=0.0
% INFO    : Bus 4750	: V=1.03744881, theta=-24.3511864 -> V=1.0000025, theta=0.0
% INFO    : Bus 4751	: V=1.0464533, theta=-14.9219664 -> V=1.0000025, theta=0.0
% INFO    : Bus 4752	: V=1.02459172, theta=-11.6356079 -> V=1.0158755, theta=0.0
% INFO    : Bus 4753	: V=1.02340493, theta=2.64260198 -> V=1.013331, theta=0.0
% INFO    : Bus 4754	: V=1.05739529, theta=-19.1673919 -> V=1.033333, theta=0.0
% INFO    : Bus 4755	: V=1.05742579, theta=-19.1233605 -> V=1.033333, theta=0.0
% INFO    : Bus 4756	: V=1.0481637, theta=-18.489734 -> V=1.000001, theta=0.0
% INFO    : Bus 4757	: V=1.04996579, theta=-27.5314943 -> V=1.0000025, theta=0.0
% INFO    : Bus 4758	: V=1.005, theta=-19.6432589 -> V=1.015872, theta=0.0
% INFO    : Bus 4759	: V=1.005, theta=-19.6432589 -> V=1.015872, theta=0.0
% INFO    : Bus 4760	: V=1.00662956, theta=-67.7635 -> V=1.0079355, theta=0.0
% INFO    : Bus 4761	: V=0.979794042, theta=-22.385533 -> V=1.015872, theta=0.0
% INFO    : Bus 4762	: V=0.99129866, theta=-34.0202218 -> V=1.0000005, theta=0.0
% INFO    : Bus 4763	: V=1.049736, theta=-29.0708561 -> V=1.046665, theta=0.0
% INFO    : Bus 4764	: V=1.0586728, theta=-28.7756074 -> V=1.046665, theta=0.0
% INFO    : Bus 4765	: V=1.04798558, theta=-8.87758189 -> V=1.0111115, theta=0.0
% INFO    : Bus 4766	: V=0.965693357, theta=-25.1651744 -> V=1.0124555, theta=0.0
% INFO    : Bus 4767	: V=1.0128922, theta=-28.930006 -> V=1.015872, theta=0.0
% INFO    : Bus 4768	: V=1.049, theta=-27.4999138 -> V=1.0233335, theta=0.0
% INFO    : Bus 4769	: V=1.00267826, theta=-14.9632656 -> V=1.015872, theta=0.0
% INFO    : Bus 4770	: V=1.00847948, theta=-36.4611079 -> V=1.015872, theta=0.0
% INFO    : Bus 4771	: V=1.04317249, theta=-35.9910781 -> V=1.027779, theta=0.0
% INFO    : Bus 4772	: V=1.00449673, theta=-20.4290095 -> V=1.0158755, theta=0.0
% INFO    : Bus 4773	: V=1.02395568, theta=-23.5513494 -> V=1.022224, theta=0.0
% INFO    : Bus 4774	: V=1.06213093, theta=-19.3460134 -> V=1.04444, theta=0.0
% INFO    : Bus 4775	: V=1.07474146, theta=-11.4860934 -> V=1.07237, theta=0.0
% INFO    : Bus 4776	: V=1.02757503, theta=-19.6074882 -> V=1.0158755, theta=0.0
% INFO    : Bus 4777	: V=1.02669182, theta=-14.4811567 -> V=1.0158755, theta=0.0
% INFO    : Bus 4778	: V=1.01540955, theta=-23.8433231 -> V=1.0000025, theta=0.0
% INFO    : Bus 4779	: V=1.020624, theta=-13.6723684 -> V=0.999999, theta=0.0
% INFO    : Bus 4780	: V=1.02472597, theta=-8.76724092 -> V=1.0111115, theta=0.0
% INFO    : Bus 4781	: V=1.02028419, theta=-23.8866053 -> V=1.022224, theta=0.0
% INFO    : Bus 4782	: V=1.05166648, theta=-18.1024515 -> V=0.9888895, theta=0.0
% INFO    : Bus 4783	: V=1.00661025, theta=-34.0902108 -> V=1.0000005, theta=0.0
% INFO    : Bus 4784	: V=1.02966384, theta=-29.7455598 -> V=1.046665, theta=0.0
% INFO    : Bus 4785	: V=1.01304136, theta=-29.5335594 -> V=1.0000025, theta=0.0
% INFO    : Bus 4786	: V=1.01938529, theta=-18.713553 -> V=1.015872, theta=0.0
% INFO    : Bus 4787	: V=1.01380688, theta=-36.0256085 -> V=1.022224, theta=0.0
% INFO    : Bus 4788	: V=1.016959, theta=-38.5198254 -> V=1.022224, theta=0.0
% INFO    : Bus 4789	: V=1.0152354, theta=-50.4330458 -> V=1.022224, theta=0.0
% INFO    : Bus 4790	: V=1.02592009, theta=-22.2381027 -> V=0.999999, theta=0.0
% INFO    : Bus 4791	: V=1.04990099, theta=-34.6357972 -> V=1.022224, theta=0.0
% INFO    : Bus 4792	: V=1.03964245, theta=-34.5055177 -> V=1.027779, theta=0.0
% INFO    : Bus 4793	: V=1.04358985, theta=-35.6988653 -> V=1.027779, theta=0.0
% INFO    : Bus 4794	: V=1.05292646, theta=-11.3472516 -> V=0.999999, theta=0.0
% INFO    : Bus 4795	: V=1.0781856, theta=-5.75951703 -> V=1.0111115, theta=0.0
% INFO    : Bus 4796	: V=1.00959759, theta=-31.8926429 -> V=1.0000005, theta=0.0
% INFO    : Bus 4797	: V=1.00932327, theta=-31.8999079 -> V=1.0000005, theta=0.0
% INFO    : Bus 4798	: V=0.971660307, theta=-19.8956685 -> V=1.015872, theta=0.0
% INFO    : Bus 4799	: V=0.972705457, theta=-19.7482116 -> V=1.015872, theta=0.0
% INFO    : Bus 4800	: V=1.00279214, theta=-14.2567928 -> V=1.015872, theta=0.0
% INFO    : Bus 4801	: V=1.02970912, theta=-33.2080401 -> V=1.027779, theta=0.0
% INFO    : Bus 4802	: V=1.02766587, theta=-32.8885343 -> V=1.015872, theta=0.0
% INFO    : Bus 4803	: V=1.02274873, theta=-2.36890646 -> V=1.0158755, theta=0.0
% INFO    : Bus 4804	: V=1.08164791, theta=-0.0139559038 -> V=1.0396285, theta=0.0
% INFO    : Bus 4805	: V=1.007, theta=-14.1397834 -> V=0.999999, theta=0.0
% INFO    : Bus 4806	: V=1.05507548, theta=-61.0440193 -> V=1.0079355, theta=0.0
% INFO    : Bus 4807	: V=0.982691418, theta=-34.9897987 -> V=1.0000005, theta=0.0
% INFO    : Bus 4808	: V=1.00199909, theta=-9.58854226 -> V=1.0158755, theta=0.0
% INFO    : Bus 4809	: V=1.02146772, theta=-23.6298505 -> V=1.022224, theta=0.0
% INFO    : Bus 4810	: V=1.0295607, theta=-40.6941097 -> V=1.022224, theta=0.0
% INFO    : Bus 4811	: V=1.0583627, theta=-21.1432657 -> V=1.04444, theta=0.0
% INFO    : Bus 4812	: V=0.993622164, theta=-25.672666 -> V=1.0158755, theta=0.0
% INFO    : Bus 4813	: V=1.02700693, theta=-37.4342745 -> V=1.027779, theta=0.0
% INFO    : Bus 4814	: V=1.0078629, theta=-15.4969461 -> V=1.015872, theta=0.0
% INFO    : Bus 4815	: V=1.03629838, theta=-45.1234843 -> V=1.027779, theta=0.0
% INFO    : Bus 4816	: V=1.05167764, theta=-24.1274328 -> V=1.0111115, theta=0.0
% INFO    : Bus 4817	: V=1.03051536, theta=-33.8703489 -> V=1.027779, theta=0.0
% INFO    : Bus 4818	: V=1.026, theta=-14.0312182 -> V=1.0158755, theta=0.0
% INFO    : Bus 4819	: V=1.013, theta=-13.5844384 -> V=0.975, theta=0.0
% INFO    : Bus 4820	: V=1.012, theta=-13.6701313 -> V=0.975, theta=0.0
% INFO    : Bus 4821	: V=1.0129333, theta=-14.4453049 -> V=0.999999, theta=0.0
% INFO    : Bus 4822	: V=1.01292247, theta=-14.4456945 -> V=0.999999, theta=0.0
% INFO    : Bus 4823	: V=1.04062617, theta=-36.0658788 -> V=1.022224, theta=0.0
% INFO    : Bus 4824	: V=1.01172853, theta=-14.6483437 -> V=0.999999, theta=0.0
% INFO    : Bus 4825	: V=1.09, theta=13.4276553 -> V=0.975, theta=0.0
% INFO    : Bus 4826	: V=1.087, theta=13.3308075 -> V=0.975, theta=0.0
% INFO    : Bus 4827	: V=1.081, theta=7.85181014 -> V=0.975, theta=0.0
% INFO    : Bus 4828	: V=1.087, theta=13.2047744 -> V=0.975, theta=0.0
% INFO    : Bus 4829	: V=1.091, theta=13.1702308 -> V=0.975, theta=0.0
% INFO    : Bus 4830	: V=1.079, theta=13.3603407 -> V=0.975, theta=0.0
% INFO    : Bus 4831	: V=1.0648033, theta=1.90626201 -> V=1.072365, theta=0.0
% INFO    : Bus 4832	: V=1.06593491, theta=-29.1086727 -> V=1.027779, theta=0.0
% INFO    : Bus 4833	: V=1.07343447, theta=-25.0715947 -> V=1.046665, theta=0.0
% INFO    : Bus 4834	: V=1.07388982, theta=-25.4693019 -> V=1.046665, theta=0.0
% INFO    : Bus 4835	: V=1.08482553, theta=-18.8365618 -> V=1.073685, theta=0.0
% INFO    : Bus 4836	: V=0.998287556, theta=-24.4370645 -> V=1.015872, theta=0.0
% INFO    : Bus 4837	: V=1.03343512, theta=-29.9524623 -> V=0.984126, theta=0.0
% INFO    : Bus 4838	: V=1.02667076, theta=-33.2443091 -> V=1.022224, theta=0.0
% INFO    : Bus 4839	: V=1.00133604, theta=-18.0189926 -> V=1.015872, theta=0.0
% INFO    : Bus 4840	: V=1.02730368, theta=-17.6592405 -> V=0.999999, theta=0.0
% INFO    : Bus 4841	: V=1.022166, theta=-28.4838264 -> V=1.033333, theta=0.0
% INFO    : Bus 4842	: V=1.01859928, theta=-18.2268941 -> V=1.015872, theta=0.0
% INFO    : Bus 4843	: V=1.00733282, theta=-22.0852217 -> V=1.0158755, theta=0.0
% INFO    : Bus 4844	: V=1.00525624, theta=-23.9254999 -> V=1.0158755, theta=0.0
% INFO    : Bus 4845	: V=1.02441065, theta=-33.8434322 -> V=1.015872, theta=0.0
% INFO    : Bus 4846	: V=0.999677573, theta=-23.8982283 -> V=1.0000025, theta=0.0
% INFO    : Bus 4847	: V=0.998087413, theta=-24.9550626 -> V=1.0000025, theta=0.0
% INFO    : Bus 4848	: V=1.05214458, theta=-17.2348126 -> V=1.001574, theta=0.0
% INFO    : Bus 4849	: V=1.0319188, theta=-21.1537529 -> V=0.9888895, theta=0.0
% INFO    : Bus 4850	: V=1.01060527, theta=-33.7117182 -> V=1.022224, theta=0.0
% INFO    : Bus 4851	: V=1.02100052, theta=-25.3765669 -> V=1.022224, theta=0.0
% INFO    : Bus 4852	: V=1.04743741, theta=-11.7819058 -> V=1.001424, theta=0.0
% INFO    : Bus 4853	: V=1.05036274, theta=-8.91160102 -> V=1.0111115, theta=0.0
% INFO    : Bus 4854	: V=1.02669951, theta=-27.8564934 -> V=1.0000025, theta=0.0
% INFO    : Bus 4855	: V=1.02634407, theta=-15.4685239 -> V=1.015872, theta=0.0
% INFO    : Bus 4856	: V=0.943018333, theta=-8.76525236 -> V=0.9444445, theta=0.0
% INFO    : Bus 4857	: V=0.943018027, theta=-8.76524219 -> V=0.9444445, theta=0.0
% INFO    : Bus 4858	: V=1.05602395, theta=-6.92073115 -> V=1.0111115, theta=0.0
% INFO    : Bus 4859	: V=1.03528593, theta=-13.4999928 -> V=0.999999, theta=0.0
% INFO    : Bus 4860	: V=1.03263461, theta=-26.6257132 -> V=1.022224, theta=0.0
% INFO    : Bus 4861	: V=0.964020735, theta=-9.72629512 -> V=1.0158755, theta=0.0
% INFO    : Bus 4862	: V=1.05190571, theta=-24.1401053 -> V=1.0000025, theta=0.0
% INFO    : Bus 4863	: V=1.07099915, theta=-20.9431997 -> V=1.044445, theta=0.0
% INFO    : Bus 4864	: V=1.08203823, theta=-15.9588386 -> V=1.078945, theta=0.0
% INFO    : Bus 4865	: V=1.0815361, theta=-19.8997431 -> V=1.07237, theta=0.0
% INFO    : Bus 4866	: V=1.04037939, theta=-33.8625855 -> V=1.046665, theta=0.0
% INFO    : Bus 4867	: V=1.02510531, theta=-25.0260838 -> V=1.0000025, theta=0.0
% INFO    : Bus 4868	: V=1.06450005, theta=-20.2711585 -> V=1.044445, theta=0.0
% INFO    : Bus 4869	: V=1.01434472, theta=-9.27920921 -> V=0.999999, theta=0.0
% INFO    : Bus 4870	: V=1.0357064, theta=-25.3837383 -> V=0.999999, theta=0.0
% INFO    : Bus 4871	: V=1.00679618, theta=-15.9766303 -> V=0.999999, theta=0.0
% INFO    : Bus 4872	: V=1.0395253, theta=-10.5854002 -> V=0.999999, theta=0.0
% INFO    : Bus 4873	: V=1.00804866, theta=-49.1087661 -> V=1.022224, theta=0.0
% INFO    : Bus 4874	: V=1.03811012, theta=-11.2999045 -> V=0.999999, theta=0.0
% INFO    : Bus 4875	: V=1.07133804, theta=-27.0759714 -> V=1.016666, theta=0.0
% INFO    : Bus 4876	: V=1.04017025, theta=-24.2405597 -> V=1.033334, theta=0.0
% INFO    : Bus 4877	: V=1.02068089, theta=-20.6992594 -> V=1.0158755, theta=0.0
% INFO    : Bus 4878	: V=1.01911533, theta=-20.8353053 -> V=1.0158755, theta=0.0
% INFO    : Bus 4879	: V=1.0324478, theta=-38.1758314 -> V=1.0029905, theta=0.0
% INFO    : Bus 4880	: V=1.0040127, theta=-36.5963362 -> V=1.0000005, theta=0.0
% INFO    : Bus 4881	: V=0.984347903, theta=-34.9710012 -> V=1.0000005, theta=0.0
% INFO    : Bus 4882	: V=1.03926634, theta=-34.639425 -> V=1.046665, theta=0.0
% INFO    : Bus 4883	: V=1.029, theta=-19.6154376 -> V=0.999999, theta=0.0
% INFO    : Bus 4884	: V=1.04143142, theta=-20.2310229 -> V=0.9888895, theta=0.0
% INFO    : Bus 4885	: V=1.03356233, theta=-48.418872 -> V=1.022224, theta=0.0
% INFO    : Bus 4886	: V=1.05953168, theta=-44.0714942 -> V=1.04444, theta=0.0
% INFO    : Bus 4887	: V=1.02315446, theta=-18.2509882 -> V=1.0111115, theta=0.0
% INFO    : Bus 4888	: V=1.00672907, theta=-16.5393583 -> V=1.0158755, theta=0.0
% INFO    : Bus 4889	: V=1.02919239, theta=-15.0713491 -> V=0.9888895, theta=0.0
% INFO    : Bus 4890	: V=1.04637119, theta=-10.7494336 -> V=1.039472, theta=0.0
% INFO    : Bus 4891	: V=1.01935352, theta=-17.3028051 -> V=1.0158755, theta=0.0
% INFO    : Bus 4892	: V=1.00076264, theta=-24.1977991 -> V=1.015872, theta=0.0
% INFO    : Bus 4893	: V=0.995246768, theta=-40.5038268 -> V=1.0000005, theta=0.0
% INFO    : Bus 4894	: V=1.02220096, theta=-17.1159563 -> V=1.015872, theta=0.0
% INFO    : Bus 4895	: V=1.05500687, theta=-23.6002634 -> V=1.000001, theta=0.0
% INFO    : Bus 4896	: V=1.02327962, theta=-18.9753975 -> V=0.9888895, theta=0.0
% INFO    : Bus 4897	: V=1.03859042, theta=-40.1592444 -> V=1.027779, theta=0.0
% INFO    : Bus 4898	: V=1.01704252, theta=-24.161823 -> V=1.0000025, theta=0.0
% INFO    : Bus 4899	: V=1.03208306, theta=-3.6135166 -> V=1.0158755, theta=0.0
% INFO    : Bus 4900	: V=1.04392514, theta=-42.1151095 -> V=1.022224, theta=0.0
% INFO    : Bus 4901	: V=1.01671586, theta=-21.2857899 -> V=0.999999, theta=0.0
% INFO    : Bus 4902	: V=1.02201314, theta=-10.8334373 -> V=0.999999, theta=0.0
% INFO    : Bus 4903	: V=1.0232864, theta=-10.559568 -> V=0.999999, theta=0.0
% INFO    : Bus 4904	: V=1.02248506, theta=-33.7475703 -> V=1.015872, theta=0.0
% INFO    : Bus 4905	: V=1.02312848, theta=-19.9531126 -> V=1.0158755, theta=0.0
% INFO    : Bus 4906	: V=1.05571906, theta=-15.8652908 -> V=1.0377785, theta=0.0
% INFO    : Bus 4907	: V=1.05873314, theta=-17.0908181 -> V=1.0377785, theta=0.0
% INFO    : Bus 4908	: V=1.0700338, theta=-12.5812378 -> V=1.072365, theta=0.0
% INFO    : Bus 4909	: V=1.02859456, theta=-24.803802 -> V=1.022224, theta=0.0
% INFO    : Bus 4910	: V=1.02682683, theta=-35.9555214 -> V=1.027779, theta=0.0
% INFO    : Bus 4911	: V=1.04299895, theta=-23.8085228 -> V=1.0000025, theta=0.0
% INFO    : Bus 4912	: V=1.08146993, theta=0.583672772 -> V=1.0388335, theta=0.0
% INFO    : Bus 4913	: V=1.09434298, theta=4.35893563 -> V=1.072365, theta=0.0
% INFO    : Bus 4914	: V=1.09594338, theta=5.73055237 -> V=1.07287, theta=0.0
% INFO    : Bus 4915	: V=1.03392106, theta=-41.3289571 -> V=1.027779, theta=0.0
% INFO    : Bus 4916	: V=0.992391979, theta=-16.1474499 -> V=0.999999, theta=0.0
% INFO    : Bus 4917	: V=1.06209206, theta=-31.1215135 -> V=1.046665, theta=0.0
% INFO    : Bus 4918	: V=1.05415759, theta=-30.0903033 -> V=1.046665, theta=0.0
% INFO    : Bus 4919	: V=1.02819872, theta=-9.7354531 -> V=1.0158755, theta=0.0
% INFO    : Bus 4920	: V=1.02961961, theta=-9.01532693 -> V=1.0158755, theta=0.0
% INFO    : Bus 4921	: V=1.0016725, theta=-8.54522216 -> V=1.0, theta=0.0
% INFO    : Bus 4922	: V=1.06909522, theta=-5.66909455 -> V=1.0377785, theta=0.0
% INFO    : Bus 4923	: V=1.0815905, theta=-2.83154495 -> V=1.072365, theta=0.0
% INFO    : Bus 4924	: V=1.01343229, theta=-30.044123 -> V=1.022224, theta=0.0
% INFO    : Bus 4925	: V=1.002, theta=-20.2089449 -> V=1.015872, theta=0.0
% INFO    : Bus 4926	: V=1.03435145, theta=-31.9284203 -> V=1.015872, theta=0.0
% INFO    : Bus 4927	: V=1.03455578, theta=-27.2306091 -> V=1.046665, theta=0.0
% INFO    : Bus 4928	: V=1.026, theta=-22.9056246 -> V=1.0000025, theta=0.0
% INFO    : Bus 4929	: V=1.04206103, theta=-25.8019245 -> V=1.0000025, theta=0.0
% INFO    : Bus 4930	: V=1.02573878, theta=-40.5677047 -> V=1.022224, theta=0.0
% INFO    : Bus 4931	: V=1.02928579, theta=-17.3780153 -> V=1.015872, theta=0.0
% INFO    : Bus 4932	: V=1.04707296, theta=-12.7966413 -> V=1.046665, theta=0.0
% INFO    : Bus 4933	: V=1.05110131, theta=-8.08916476 -> V=1.0000025, theta=0.0
% INFO    : Bus 4934	: V=1.05121765, theta=-8.05360048 -> V=1.0000025, theta=0.0
% INFO    : Bus 4935	: V=1.0385614, theta=-43.3708816 -> V=1.027779, theta=0.0
% INFO    : Bus 4936	: V=1.02876936, theta=-17.2669253 -> V=0.999999, theta=0.0
% INFO    : Bus 4937	: V=1.00891486, theta=-34.7694378 -> V=1.0000005, theta=0.0
% INFO    : Bus 4938	: V=0.989681859, theta=-49.244727 -> V=1.022224, theta=0.0
% INFO    : Bus 4939	: V=1.01716649, theta=-24.1210602 -> V=1.015872, theta=0.0
% INFO    : Bus 4940	: V=1.00911565, theta=-34.770975 -> V=1.0000005, theta=0.0
% INFO    : Bus 4941	: V=1.009118, theta=-34.7707006 -> V=1.0000005, theta=0.0
% INFO    : Bus 4942	: V=1.00906546, theta=-34.7737943 -> V=1.0000005, theta=0.0
% INFO    : Bus 4943	: V=1.06273207, theta=-30.9814889 -> V=1.046665, theta=0.0
% INFO    : Bus 4944	: V=1.06278105, theta=-30.9793692 -> V=1.046665, theta=0.0
% INFO    : Bus 4945	: V=1.02195113, theta=-11.8715502 -> V=1.0158755, theta=0.0
% INFO    : Bus 4946	: V=1.06281196, theta=-6.79242201 -> V=1.0377785, theta=0.0
% INFO    : Bus 4947	: V=1.06208319, theta=-31.0747376 -> V=1.046665, theta=0.0
% INFO    : Bus 4948	: V=1.01179654, theta=-14.0398105 -> V=1.015872, theta=0.0
% INFO    : Bus 4949	: V=1.0121041, theta=-8.6471366 -> V=0.999999, theta=0.0
% INFO    : Bus 4950	: V=1.02325824, theta=-30.8686737 -> V=1.0000005, theta=0.0
% INFO    : Bus 4951	: V=0.958, theta=-9.0834815 -> V=0.9444445, theta=0.0
% INFO    : Bus 4952	: V=1.06843302, theta=-11.8243144 -> V=1.072365, theta=0.0
% INFO    : Bus 4953	: V=0.99465729, theta=-21.0547176 -> V=1.0158755, theta=0.0
% INFO    : Bus 4954	: V=1.06706121, theta=-17.4260496 -> V=1.072365, theta=0.0
% INFO    : Bus 4955	: V=1.02631151, theta=-41.3498051 -> V=1.027779, theta=0.0
% INFO    : Bus 4956	: V=1.02411554, theta=-21.6751769 -> V=0.999999, theta=0.0
% INFO    : Bus 4957	: V=1.02669827, theta=-16.8104729 -> V=0.999999, theta=0.0
% INFO    : Bus 4958	: V=1.00129034, theta=-17.6280358 -> V=1.0158755, theta=0.0
% INFO    : Bus 4959	: V=1.03444082, theta=-34.4552491 -> V=1.027779, theta=0.0
% INFO    : Bus 4960	: V=1.05775573, theta=-30.4451412 -> V=1.046665, theta=0.0
% INFO    : Bus 4961	: V=1.04563812, theta=-29.7351438 -> V=1.046665, theta=0.0
% INFO    : Bus 4962	: V=1.0522277, theta=-24.6805479 -> V=1.073685, theta=0.0
% INFO    : Bus 4963	: V=1.0380684, theta=-22.7688328 -> V=0.975, theta=0.0
% INFO    : Bus 4964	: V=1.04071989, theta=-25.5764366 -> V=1.022224, theta=0.0
% INFO    : Bus 4965	: V=1.03813352, theta=-22.7554946 -> V=1.04444, theta=0.0
% INFO    : Bus 4966	: V=1.04782731, theta=-25.582345 -> V=1.022224, theta=0.0
% INFO    : Bus 4967	: V=1.03834237, theta=-27.868801 -> V=1.0000025, theta=0.0
% INFO    : Bus 4968	: V=1.01832087, theta=-32.999157 -> V=1.0000005, theta=0.0
% INFO    : Bus 4969	: V=1.0495929, theta=-29.8272513 -> V=1.046665, theta=0.0
% INFO    : Bus 4970	: V=1.01647342, theta=-29.5033048 -> V=1.022224, theta=0.0
% INFO    : Bus 4971	: V=1.07680607, theta=-22.605675 -> V=1.07237, theta=0.0
% INFO    : Bus 4972	: V=1.08067069, theta=-21.4762248 -> V=1.07237, theta=0.0
% INFO    : Bus 4973	: V=1.032, theta=-17.3150781 -> V=0.999999, theta=0.0
% INFO    : Bus 4974	: V=1.00030421, theta=-32.5702124 -> V=1.0000005, theta=0.0
% INFO    : Bus 4975	: V=1.04188379, theta=-8.95312169 -> V=1.000001, theta=0.0
% INFO    : Bus 4976	: V=1.0235138, theta=-32.5303711 -> V=1.0000005, theta=0.0
% INFO    : Bus 4977	: V=1.01705162, theta=-32.4792099 -> V=1.0000005, theta=0.0
% INFO    : Bus 4978	: V=1.04972633, theta=-29.0708133 -> V=1.046665, theta=0.0
% INFO    : Bus 4979	: V=1.05864432, theta=-28.7753603 -> V=1.046665, theta=0.0
% INFO    : Bus 4980	: V=1.05052103, theta=-24.1177859 -> V=1.073685, theta=0.0
% INFO    : Bus 4981	: V=1.04595821, theta=-15.8197146 -> V=0.999999, theta=0.0
% INFO    : Bus 4982	: V=1.02949258, theta=-22.5678492 -> V=1.000001, theta=0.0
% INFO    : Bus 4983	: V=1.02705377, theta=-22.8443989 -> V=1.000001, theta=0.0
% INFO    : Bus 4984	: V=1.02478227, theta=-21.3695081 -> V=1.0158755, theta=0.0
% INFO    : Bus 4985	: V=1.0624521, theta=-18.8793537 -> V=1.0377785, theta=0.0
% INFO    : Bus 4986	: V=1.024, theta=-11.6883713 -> V=0.999999, theta=0.0
% INFO    : Bus 4987	: V=1.108, theta=-0.568115093 -> V=0.975, theta=0.0
% INFO    : Bus 4988	: V=1.12, theta=-0.902628465 -> V=0.975, theta=0.0
% INFO    : Bus 4989	: V=1.12, theta=-0.818150144 -> V=0.975, theta=0.0
% INFO    : Bus 4990	: V=1.06921359, theta=-5.02683576 -> V=1.0377785, theta=0.0
% INFO    : Bus 4991	: V=1.0821293, theta=-5.537842 -> V=1.0377785, theta=0.0
% INFO    : Bus 4992	: V=1.08212868, theta=-5.53755358 -> V=1.0377785, theta=0.0
% INFO    : Bus 4993	: V=1.02339261, theta=-9.48503306 -> V=1.0158755, theta=0.0
% INFO    : Bus 4994	: V=1.08202499, theta=-5.55398902 -> V=1.0377785, theta=0.0
% INFO    : Bus 4995	: V=1.06910473, theta=-5.04240476 -> V=1.0377785, theta=0.0
% INFO    : Bus 4996	: V=1.00640076, theta=-11.2418563 -> V=1.0158755, theta=0.0
% INFO    : Bus 4997	: V=1.01563051, theta=-2.13419996 -> V=1.0158755, theta=0.0
% INFO    : Bus 4998	: V=1.073162, theta=0.770325688 -> V=1.0377785, theta=0.0
% INFO    : Bus 4999	: V=0.996633784, theta=-28.6761506 -> V=0.999999, theta=0.0
% INFO    : Bus 5000	: V=1.02070372, theta=-13.0499404 -> V=0.999999, theta=0.0
% INFO    : Bus 5001	: V=1.04356131, theta=-22.6517773 -> V=0.999999, theta=0.0
% INFO    : Bus 5002	: V=1.02534846, theta=-18.3400971 -> V=1.0111115, theta=0.0
% INFO    : Bus 5003	: V=1.02877634, theta=-17.5157992 -> V=0.999999, theta=0.0
% INFO    : Bus 5004	: V=1.03495435, theta=-11.3215992 -> V=1.0111115, theta=0.0
% INFO    : Bus 5005	: V=0.974952107, theta=-24.6184269 -> V=0.999999, theta=0.0
% INFO    : Bus 5006	: V=1.02306508, theta=-12.1970153 -> V=0.999999, theta=0.0
% INFO    : Bus 5007	: V=0.992757338, theta=-25.1961408 -> V=1.0158755, theta=0.0
% INFO    : Bus 5008	: V=1.05444535, theta=-15.3003075 -> V=1.004609, theta=0.0
% INFO    : Bus 5009	: V=1.05863683, theta=-12.6819029 -> V=1.0111115, theta=0.0
% INFO    : Bus 5010	: V=1.05408926, theta=-14.0271953 -> V=0.999999, theta=0.0
% INFO    : Bus 5011	: V=1.02182529, theta=-15.9910609 -> V=1.0158755, theta=0.0
% INFO    : Bus 5012	: V=1.00109699, theta=-15.6334856 -> V=1.015872, theta=0.0
% INFO    : Bus 5013	: V=1.03413783, theta=-24.0933249 -> V=1.046665, theta=0.0
% INFO    : Bus 5014	: V=1.03570789, theta=-23.9527114 -> V=1.046665, theta=0.0
% INFO    : Bus 5015	: V=1.03087943, theta=-16.3768199 -> V=1.0000025, theta=0.0
% INFO    : Bus 5016	: V=1.03349797, theta=-28.8670208 -> V=1.022224, theta=0.0
% INFO    : Bus 5017	: V=1.02711578, theta=-32.131115 -> V=1.022224, theta=0.0
% INFO    : Bus 5018	: V=1.06039019, theta=-16.9351602 -> V=0.999999, theta=0.0
% INFO    : Bus 5019	: V=1.02676153, theta=-25.5493073 -> V=1.0000025, theta=0.0
% INFO    : Bus 5020	: V=1.03177062, theta=-20.1671829 -> V=0.999999, theta=0.0
% INFO    : Bus 5021	: V=1.01744839, theta=-14.014964 -> V=1.0277795, theta=0.0
% INFO    : Bus 5022	: V=1.01105437, theta=-42.0300461 -> V=1.027779, theta=0.0
% INFO    : Bus 5023	: V=1.01204018, theta=-18.1006139 -> V=1.0158755, theta=0.0
% INFO    : Bus 5024	: V=1.00954045, theta=-33.5375278 -> V=1.0000005, theta=0.0
% INFO    : Bus 5025	: V=1.04316785, theta=-30.2870786 -> V=1.046665, theta=0.0
% INFO    : Bus 5026	: V=1.02679811, theta=-30.8386408 -> V=1.046665, theta=0.0
% INFO    : Bus 5027	: V=1.066, theta=-15.3880993 -> V=1.000001, theta=0.0
% INFO    : Bus 5028	: V=1.01862917, theta=-25.6337514 -> V=1.0000025, theta=0.0
% INFO    : Bus 5029	: V=1.01583474, theta=-38.8969416 -> V=1.022224, theta=0.0
% INFO    : Bus 5030	: V=1.02813365, theta=-37.0588093 -> V=1.022224, theta=0.0
% INFO    : Bus 5031	: V=1.04196846, theta=-28.8186836 -> V=1.0000025, theta=0.0
% INFO    : Bus 5032	: V=1.05693395, theta=-23.7134313 -> V=1.0000025, theta=0.0
% INFO    : Bus 5033	: V=1.006, theta=-21.0779153 -> V=1.0000025, theta=0.0
% INFO    : Bus 5034	: V=1.01475898, theta=-31.4816634 -> V=0.9682545, theta=0.0
% INFO    : Bus 5035	: V=1.01751266, theta=-1.28312675 -> V=1.0158755, theta=0.0
% INFO    : Bus 5036	: V=1.02086278, theta=-29.5834327 -> V=1.0000025, theta=0.0
% INFO    : Bus 5037	: V=1.00809614, theta=-33.2069543 -> V=1.0000005, theta=0.0
% INFO    : Bus 5038	: V=1.05997261, theta=-31.2135666 -> V=1.046665, theta=0.0
% INFO    : Bus 5039	: V=1.03890673, theta=-24.0764915 -> V=1.000001, theta=0.0
% INFO    : Bus 5040	: V=1.03067738, theta=-25.1211664 -> V=1.000001, theta=0.0
% INFO    : Bus 5041	: V=1.00857257, theta=-11.7690953 -> V=0.999999, theta=0.0
% INFO    : Bus 5042	: V=0.995735492, theta=-50.3553252 -> V=1.022224, theta=0.0
% INFO    : Bus 5043	: V=1.00824083, theta=-13.6434473 -> V=0.999999, theta=0.0
% INFO    : Bus 5044	: V=1.02641101, theta=-29.861434 -> V=1.0000025, theta=0.0
% INFO    : Bus 5045	: V=1.02095068, theta=-17.8735575 -> V=1.0158755, theta=0.0
% INFO    : Bus 5046	: V=1.02951861, theta=-28.1093038 -> V=1.022222, theta=0.0
% INFO    : Bus 5047	: V=1.0358157, theta=-3.06366466 -> V=1.0158755, theta=0.0
% INFO    : Bus 5048	: V=1.01424198, theta=-38.8565227 -> V=1.022224, theta=0.0
% INFO    : Bus 5049	: V=1.04452937, theta=-6.62947513 -> V=1.0111115, theta=0.0
% INFO    : Bus 5050	: V=1.01012928, theta=-14.8512021 -> V=1.0277795, theta=0.0
% INFO    : Bus 5051	: V=0.987160859, theta=-34.2169376 -> V=1.0000005, theta=0.0
% INFO    : Bus 5052	: V=1.02914863, theta=-10.4817175 -> V=1.0158755, theta=0.0
% INFO    : Bus 5053	: V=1.02440712, theta=-9.84596058 -> V=1.0158755, theta=0.0
% INFO    : Bus 5054	: V=1.02564535, theta=-23.6865688 -> V=1.0000025, theta=0.0
% INFO    : Bus 5055	: V=1.05057427, theta=-43.5793011 -> V=1.022224, theta=0.0
% INFO    : Bus 5056	: V=1.04525676, theta=-37.6661659 -> V=1.04444, theta=0.0
% INFO    : Bus 5057	: V=1.01442213, theta=-13.4924668 -> V=0.999999, theta=0.0
% INFO    : Bus 5058	: V=1.04750123, theta=-25.1603687 -> V=1.033333, theta=0.0
% INFO    : Bus 5059	: V=1.02751599, theta=-28.6627538 -> V=1.0158755, theta=0.0
% INFO    : Bus 5060	: V=0.976922945, theta=-8.95932003 -> V=1.0158755, theta=0.0
% INFO    : Bus 5061	: V=0.984125398, theta=-34.0523381 -> V=1.0000005, theta=0.0
% INFO    : Bus 5062	: V=1.0318589, theta=-11.4475979 -> V=1.0158755, theta=0.0
% INFO    : Bus 5063	: V=1.02091526, theta=-10.6871714 -> V=1.0158755, theta=0.0
% INFO    : Bus 5064	: V=1.07056141, theta=-15.0030041 -> V=0.9888895, theta=0.0
% INFO    : Bus 5065	: V=1.06339571, theta=-16.1964221 -> V=0.9888895, theta=0.0
% INFO    : Bus 5066	: V=1.08317561, theta=-11.9539018 -> V=1.05263, theta=0.0
% INFO    : Bus 5067	: V=1.08605589, theta=-11.7498082 -> V=1.05263, theta=0.0
% INFO    : Bus 5068	: V=1.0376294, theta=-23.2807093 -> V=1.033333, theta=0.0
% INFO    : Bus 5069	: V=1.02781541, theta=-10.5321139 -> V=1.0158755, theta=0.0
% INFO    : Bus 5070	: V=1.04693197, theta=-25.051081 -> V=1.022222, theta=0.0
% INFO    : Bus 5071	: V=1.04059678, theta=-20.3084758 -> V=0.9888895, theta=0.0
% INFO    : Bus 5072	: V=1.04031261, theta=-20.3532491 -> V=0.9888895, theta=0.0
% INFO    : Bus 5073	: V=1.04513546, theta=-19.0248117 -> V=0.9888895, theta=0.0
% INFO    : Bus 5074	: V=1.05546184, theta=-14.6184784 -> V=1.05263, theta=0.0
% INFO    : Bus 5075	: V=1.06171578, theta=-16.3695362 -> V=0.9888895, theta=0.0
% INFO    : Bus 5076	: V=1.06156703, theta=-16.3975739 -> V=0.9888895, theta=0.0
% INFO    : Bus 5077	: V=1.04632477, theta=-19.5096835 -> V=0.9888895, theta=0.0
% INFO    : Bus 5078	: V=1.03153965, theta=-3.60069659 -> V=1.0158755, theta=0.0
% INFO    : Bus 5079	: V=1.00053163, theta=-8.25913855 -> V=1.0158755, theta=0.0
% INFO    : Bus 5080	: V=1.05327464, theta=-29.4382379 -> V=1.027779, theta=0.0
% INFO    : Bus 5081	: V=1.04278523, theta=-31.6919561 -> V=1.027779, theta=0.0
% INFO    : Bus 5082	: V=1.07010963, theta=-26.6994548 -> V=1.046665, theta=0.0
% INFO    : Bus 5083	: V=1.06803916, theta=-15.0967359 -> V=1.000001, theta=0.0
% INFO    : Bus 5084	: V=1.03535538, theta=-13.322974 -> V=0.999999, theta=0.0
% INFO    : Bus 5085	: V=1.01193325, theta=-43.712296 -> V=1.027779, theta=0.0
% INFO    : Bus 5086	: V=1.01834855, theta=-21.0012519 -> V=0.999999, theta=0.0
% INFO    : Bus 5087	: V=1.02561046, theta=-33.3691479 -> V=1.027779, theta=0.0
% INFO    : Bus 5088	: V=1.04680647, theta=-32.8300784 -> V=1.046665, theta=0.0
% INFO    : Bus 5089	: V=1.05895038, theta=-26.4734817 -> V=1.073685, theta=0.0
% INFO    : Bus 5090	: V=1.01812181, theta=-22.71417 -> V=0.999999, theta=0.0
% INFO    : Bus 5091	: V=1.01998513, theta=-43.1728534 -> V=1.022224, theta=0.0
% INFO    : Bus 5092	: V=1.03672381, theta=-23.7115009 -> V=1.0222235, theta=0.0
% INFO    : Bus 5093	: V=0.938962, theta=-6.54319592 -> V=0.9444445, theta=0.0
% INFO    : Bus 5094	: V=1.0191608, theta=-24.0841394 -> V=0.999999, theta=0.0
% INFO    : Bus 5095	: V=1.03523464, theta=-23.6541225 -> V=1.022224, theta=0.0
% INFO    : Bus 5096	: V=0.99014003, theta=-33.4171051 -> V=1.0000005, theta=0.0
% INFO    : Bus 5097	: V=1.01410979, theta=-40.0285317 -> V=1.022224, theta=0.0
% INFO    : Bus 5098	: V=1.05793323, theta=-20.1749752 -> V=1.0000025, theta=0.0
% INFO    : Bus 5099	: V=1.02518633, theta=-2.58278712 -> V=1.0158755, theta=0.0
% INFO    : Bus 5100	: V=1.01076675, theta=-33.3160903 -> V=1.0000005, theta=0.0
% INFO    : Bus 5101	: V=1.0577762, theta=-36.899416 -> V=1.04444, theta=0.0
% INFO    : Bus 5102	: V=1.02717525, theta=-16.6672179 -> V=0.999999, theta=0.0
% INFO    : Bus 5103	: V=1.03912866, theta=-18.0121555 -> V=0.999999, theta=0.0
% INFO    : Bus 5104	: V=0.942937689, theta=-7.25334442 -> V=0.9444445, theta=0.0
% INFO    : Bus 5105	: V=0.980826441, theta=-11.1591887 -> V=0.9444445, theta=0.0
% INFO    : Bus 5106	: V=1.02508797, theta=-11.5325812 -> V=1.0158755, theta=0.0
% INFO    : Bus 5107	: V=1.03124139, theta=-31.9200543 -> V=1.022224, theta=0.0
% INFO    : Bus 5108	: V=1.05516931, theta=-22.2467378 -> V=0.9933315, theta=0.0
% INFO    : Bus 5109	: V=1.03406286, theta=-20.2221707 -> V=1.0000025, theta=0.0
% INFO    : Bus 5110	: V=1.02104953, theta=-34.4015496 -> V=1.022224, theta=0.0
% INFO    : Bus 5111	: V=1.00672466, theta=-31.4385677 -> V=1.0000005, theta=0.0
% INFO    : Bus 5112	: V=1.06048119, theta=-23.6854488 -> V=1.005558, theta=0.0
% INFO    : Bus 5113	: V=1.0596018, theta=-23.7746329 -> V=1.005558, theta=0.0
% INFO    : Bus 5114	: V=1.05498608, theta=-24.9863145 -> V=1.0000025, theta=0.0
% INFO    : Bus 5115	: V=1.02448982, theta=-22.5897804 -> V=1.0158755, theta=0.0
% INFO    : Bus 5116	: V=1.02340523, theta=-28.6572967 -> V=1.022224, theta=0.0
% INFO    : Bus 5117	: V=0.952733602, theta=-8.26372461 -> V=0.9444445, theta=0.0
% INFO    : Bus 5118	: V=1.01953547, theta=-48.2213411 -> V=1.022224, theta=0.0
% INFO    : Bus 5119	: V=1.0263058, theta=-4.11039537 -> V=1.0158755, theta=0.0
% INFO    : Bus 5120	: V=1.01626584, theta=-21.8874491 -> V=1.015872, theta=0.0
% INFO    : Bus 5121	: V=1.04693266, theta=-32.3492349 -> V=1.022224, theta=0.0
% INFO    : Bus 5122	: V=1.09903354, theta=-16.9533811 -> V=1.0333335, theta=0.0
% INFO    : Bus 5123	: V=1.0327947, theta=-28.7623618 -> V=1.005558, theta=0.0
% INFO    : Bus 5124	: V=1.02736354, theta=-28.8856528 -> V=1.0000025, theta=0.0
% INFO    : Bus 5125	: V=1.04201919, theta=-28.9359591 -> V=1.0000025, theta=0.0
% INFO    : Bus 5126	: V=1.05596379, theta=-29.6953904 -> V=1.046665, theta=0.0
% INFO    : Bus 5127	: V=1.05612744, theta=-29.6814318 -> V=1.046665, theta=0.0
% INFO    : Bus 5128	: V=1.0422456, theta=-21.8772155 -> V=0.9933315, theta=0.0
% INFO    : Bus 5129	: V=0.997377635, theta=-15.0985545 -> V=1.015872, theta=0.0
% INFO    : Bus 5130	: V=1.05231441, theta=-22.0235785 -> V=1.000739, theta=0.0
% INFO    : Bus 5131	: V=1.0616, theta=-33.2579684 -> V=1.027779, theta=0.0
% INFO    : Bus 5132	: V=1.03837137, theta=-27.3667593 -> V=1.0000025, theta=0.0
% INFO    : Bus 5133	: V=1.03062723, theta=-19.3097808 -> V=1.0000025, theta=0.0
% INFO    : Bus 5134	: V=1.02458398, theta=-14.6248629 -> V=0.9888895, theta=0.0
% INFO    : Bus 5135	: V=1.06948991, theta=-20.5428277 -> V=1.046665, theta=0.0
% INFO    : Bus 5136	: V=1.03019395, theta=-19.3884531 -> V=1.0000025, theta=0.0
% INFO    : Bus 5137	: V=1.01390753, theta=-27.098591 -> V=1.015872, theta=0.0
% INFO    : Bus 5138	: V=1.02668696, theta=-13.6849961 -> V=1.0000015, theta=0.0
% INFO    : Bus 5139	: V=1.01889394, theta=-25.486776 -> V=1.0000025, theta=0.0
% INFO    : Bus 5140	: V=1.01490158, theta=-8.68150376 -> V=0.999999, theta=0.0
% INFO    : Bus 5141	: V=1.02560017, theta=-19.5487691 -> V=1.0158755, theta=0.0
% INFO    : Bus 5142	: V=1.03553426, theta=-11.3856505 -> V=0.999999, theta=0.0
% INFO    : Bus 5143	: V=1.02975099, theta=-41.4431817 -> V=1.022224, theta=0.0
% INFO    : Bus 5144	: V=1.00304943, theta=-19.5820604 -> V=0.999999, theta=0.0
% INFO    : Bus 5145	: V=1.04883451, theta=-32.2389127 -> V=1.0000025, theta=0.0
% INFO    : Bus 5146	: V=1.00798869, theta=-33.2280267 -> V=1.0000005, theta=0.0
% INFO    : Bus 5147	: V=1.04991406, theta=-32.1147885 -> V=1.0000025, theta=0.0
% INFO    : Bus 5148	: V=1.02510927, theta=-14.6178351 -> V=0.999999, theta=0.0
% INFO    : Bus 5149	: V=0.992013327, theta=-34.6320574 -> V=1.0000005, theta=0.0
% INFO    : Bus 5150	: V=1.01992597, theta=-30.7429289 -> V=1.0000025, theta=0.0
% INFO    : Bus 5151	: V=1.01553492, theta=-16.7379938 -> V=0.999999, theta=0.0
% INFO    : Bus 5152	: V=1.02703857, theta=-21.5290148 -> V=0.9933315, theta=0.0
% INFO    : Bus 5153	: V=1.03704427, theta=-18.8842912 -> V=1.0000025, theta=0.0
% INFO    : Bus 5154	: V=1.03669115, theta=-18.9264655 -> V=1.0000025, theta=0.0
% INFO    : Bus 5155	: V=1.00004993, theta=-25.3654719 -> V=1.0000025, theta=0.0
% INFO    : Bus 5156	: V=0.999777094, theta=-25.3890209 -> V=1.0000025, theta=0.0
% INFO    : Bus 5157	: V=1.04127626, theta=-25.8836307 -> V=1.0000025, theta=0.0
% INFO    : Bus 5158	: V=1.01843863, theta=-25.8553848 -> V=1.022224, theta=0.0
% INFO    : Bus 5159	: V=1.04611775, theta=-15.2691019 -> V=1.0111115, theta=0.0
% INFO    : Bus 5160	: V=1.03349299, theta=-45.991356 -> V=1.0079355, theta=0.0
% INFO    : Bus 5161	: V=1.0402474, theta=-25.9309657 -> V=1.0000025, theta=0.0
% INFO    : Bus 5162	: V=1.04192889, theta=-25.8635868 -> V=1.0000025, theta=0.0
% INFO    : Bus 5163	: V=1.05763244, theta=-10.3883634 -> V=1.046665, theta=0.0
% INFO    : Bus 5164	: V=1.01431216, theta=-29.7945579 -> V=1.022224, theta=0.0
% INFO    : Bus 5165	: V=1.01430863, theta=-29.7940235 -> V=1.022224, theta=0.0
% INFO    : Bus 5166	: V=1.03212623, theta=-22.9858429 -> V=1.0222235, theta=0.0
% INFO    : Bus 5167	: V=1.04013653, theta=-40.7307998 -> V=1.022224, theta=0.0
% INFO    : Bus 5168	: V=1.03934219, theta=-18.7088176 -> V=1.0000025, theta=0.0
% INFO    : Bus 5169	: V=1.01975758, theta=-28.8161316 -> V=1.0000025, theta=0.0
% INFO    : Bus 5170	: V=1.01746288, theta=-30.25104 -> V=1.0000025, theta=0.0
% INFO    : Bus 5171	: V=1.06311354, theta=-20.7169175 -> V=1.0000025, theta=0.0
% INFO    : Bus 5172	: V=1.01301762, theta=-30.1734132 -> V=1.0000025, theta=0.0
% INFO    : Bus 5173	: V=1.04318821, theta=-23.8127749 -> V=1.0000025, theta=0.0
% INFO    : Bus 5174	: V=1.04039313, theta=-11.710395 -> V=0.999999, theta=0.0
% INFO    : Bus 5175	: V=1.0182967, theta=-51.3044494 -> V=1.0079355, theta=0.0
% INFO    : Bus 5176	: V=1.01309461, theta=-29.5202497 -> V=1.0000025, theta=0.0
% INFO    : Bus 5177	: V=1.0482034, theta=-50.4100794 -> V=1.022224, theta=0.0
% INFO    : Bus 5178	: V=1.00656928, theta=-38.8705473 -> V=1.0000005, theta=0.0
% INFO    : Bus 5179	: V=1.03348467, theta=-22.2509567 -> V=1.0158755, theta=0.0
% INFO    : Bus 5180	: V=1.03063298, theta=-47.5024785 -> V=1.022224, theta=0.0
% INFO    : Bus 5181	: V=1.0136737, theta=-36.2221651 -> V=1.022224, theta=0.0
% INFO    : Bus 5182	: V=1.00798942, theta=-38.8229566 -> V=1.0000005, theta=0.0
% INFO    : Bus 5183	: V=1.03600687, theta=-31.4394573 -> V=1.046665, theta=0.0
% INFO    : Bus 5184	: V=1.01078752, theta=-64.1606103 -> V=1.0079355, theta=0.0
% INFO    : Bus 5185	: V=1.05231433, theta=-11.8114414 -> V=1.0233335, theta=0.0
% INFO    : Bus 5186	: V=1.03571069, theta=-31.5337371 -> V=1.046665, theta=0.0
% INFO    : Bus 5187	: V=1.03445297, theta=-45.9530423 -> V=1.0079355, theta=0.0
% INFO    : Bus 5188	: V=1.0097474, theta=-54.8494652 -> V=1.0079355, theta=0.0
% INFO    : Bus 5189	: V=1.02610369, theta=-17.4607142 -> V=0.999999, theta=0.0
% INFO    : Bus 5190	: V=1.0149704, theta=-46.4548643 -> V=1.022224, theta=0.0
% INFO    : Bus 5191	: V=1.06456053, theta=-18.2568052 -> V=1.0000025, theta=0.0
% INFO    : Bus 5192	: V=1.04998006, theta=-24.2956312 -> V=1.022224, theta=0.0
% INFO    : Bus 5193	: V=1.02624459, theta=-41.5379146 -> V=1.022224, theta=0.0
% INFO    : Bus 5194	: V=1.0489979, theta=-41.9581286 -> V=1.04444, theta=0.0
% INFO    : Bus 5195	: V=1.04613337, theta=-21.2933632 -> V=1.0000025, theta=0.0
% INFO    : Bus 5196	: V=1.02335894, theta=-42.0030773 -> V=1.022224, theta=0.0
% INFO    : Bus 5197	: V=1.03222508, theta=-29.9732923 -> V=1.022224, theta=0.0
% INFO    : Bus 5198	: V=1.02964571, theta=-22.5281079 -> V=1.0222235, theta=0.0
% INFO    : Bus 5199	: V=0.994961044, theta=-14.6775093 -> V=0.999999, theta=0.0
% INFO    : Bus 5200	: V=0.994403996, theta=-10.4787367 -> V=1.0158755, theta=0.0
% INFO    : Bus 5201	: V=1.02962915, theta=-40.659337 -> V=1.022224, theta=0.0
% INFO    : Bus 5202	: V=1.01567899, theta=-43.8962761 -> V=1.022224, theta=0.0
% INFO    : Bus 5203	: V=1.03597295, theta=-14.2114643 -> V=0.999999, theta=0.0
% INFO    : Bus 5204	: V=1.07742745, theta=-0.381449268 -> V=0.9888895, theta=0.0
% INFO    : Bus 5205	: V=1.03119578, theta=-23.6855385 -> V=1.0000025, theta=0.0
% INFO    : Bus 5206	: V=1.01818798, theta=-23.2067379 -> V=1.0158755, theta=0.0
% INFO    : Bus 5207	: V=1.03874684, theta=-13.5318071 -> V=0.999999, theta=0.0
% INFO    : Bus 5208	: V=1.02844663, theta=-10.2026313 -> V=0.999999, theta=0.0
% INFO    : Bus 5209	: V=1.02481587, theta=-7.53567902 -> V=1.0111115, theta=0.0
% INFO    : Bus 5210	: V=1.02820559, theta=-18.3509406 -> V=1.015872, theta=0.0
% INFO    : Bus 5211	: V=1.02653021, theta=-21.4474157 -> V=1.015872, theta=0.0
% INFO    : Bus 5212	: V=1.04709141, theta=-19.798933 -> V=1.046665, theta=0.0
% INFO    : Bus 5213	: V=0.993576825, theta=-23.5940628 -> V=1.015872, theta=0.0
% INFO    : Bus 5214	: V=1.04013632, theta=-31.5561325 -> V=1.0000025, theta=0.0
% INFO    : Bus 5215	: V=1.06672581, theta=-17.9699484 -> V=1.0000025, theta=0.0
% INFO    : Bus 5216	: V=1.06595715, theta=-29.1091226 -> V=1.027779, theta=0.0
% INFO    : Bus 5217	: V=1.01742438, theta=-25.1611724 -> V=1.0000025, theta=0.0
% INFO    : Bus 5218	: V=1.01797819, theta=-25.1458218 -> V=1.0000025, theta=0.0
% INFO    : Bus 5219	: V=1.02780174, theta=-22.3087269 -> V=1.0000025, theta=0.0
% INFO    : Bus 5220	: V=1.05738359, theta=-30.4642006 -> V=1.046665, theta=0.0
% INFO    : Bus 5221	: V=1.03488548, theta=-1.40410689 -> V=1.0158755, theta=0.0
% INFO    : Bus 5222	: V=1.02682743, theta=-22.4513897 -> V=1.0000025, theta=0.0
% INFO    : Bus 5223	: V=1.0577687, theta=-30.4471602 -> V=1.046665, theta=0.0
% INFO    : Bus 5224	: V=1.01492859, theta=-23.5149099 -> V=1.0000025, theta=0.0
% INFO    : Bus 5225	: V=1.02893945, theta=-63.9914007 -> V=1.0079355, theta=0.0
% INFO    : Bus 5226	: V=1.04752546, theta=-28.4378607 -> V=1.0000025, theta=0.0
% INFO    : Bus 5227	: V=1.04543962, theta=-27.0167174 -> V=1.0000025, theta=0.0
% INFO    : Bus 5228	: V=1.04692587, theta=-26.8175941 -> V=1.0000025, theta=0.0
% INFO    : Bus 5229	: V=1.00863872, theta=-28.8432629 -> V=1.0000025, theta=0.0
% INFO    : Bus 5230	: V=1.04647867, theta=-39.2225096 -> V=1.027779, theta=0.0
% INFO    : Bus 5231	: V=1.00876619, theta=-28.9003781 -> V=1.0000025, theta=0.0
% INFO    : Bus 5232	: V=1.02125279, theta=-19.4431357 -> V=1.015872, theta=0.0
% INFO    : Bus 5233	: V=0.997298576, theta=-32.1219223 -> V=1.0000025, theta=0.0
% INFO    : Bus 5234	: V=1.02133294, theta=-28.0849956 -> V=1.0000025, theta=0.0
% INFO    : Bus 5235	: V=1.02630563, theta=-8.14024198 -> V=1.0111115, theta=0.0
% INFO    : Bus 5236	: V=1.02068, theta=-29.253103 -> V=1.0000025, theta=0.0
% INFO    : Bus 5237	: V=1.02060936, theta=-29.3270197 -> V=1.0000025, theta=0.0
% INFO    : Bus 5238	: V=1.01127842, theta=-30.7872773 -> V=1.0158755, theta=0.0
% INFO    : Bus 5239	: V=1.05837788, theta=-12.2653957 -> V=1.000849, theta=0.0
% INFO    : Bus 5240	: V=1.02427732, theta=-34.2186934 -> V=1.022224, theta=0.0
% INFO    : Bus 5241	: V=1.02855261, theta=-24.7771447 -> V=1.022224, theta=0.0
% INFO    : Bus 5242	: V=1.01519937, theta=-6.87076317 -> V=0.999999, theta=0.0
% INFO    : Bus 5243	: V=1.05093387, theta=-23.964483 -> V=1.0222235, theta=0.0
% INFO    : Bus 5244	: V=0.992543933, theta=-12.8247379 -> V=0.9444445, theta=0.0
% INFO    : Bus 5245	: V=1.05115523, theta=-21.1449103 -> V=1.073685, theta=0.0
% INFO    : Bus 5246	: V=1.01064766, theta=-11.4301212 -> V=0.999999, theta=0.0
% INFO    : Bus 5247	: V=1.02186658, theta=-29.4123415 -> V=1.022224, theta=0.0
% INFO    : Bus 5248	: V=1.02229563, theta=-1.4363553 -> V=1.0158755, theta=0.0
% INFO    : Bus 5249	: V=1.03542292, theta=-27.0333288 -> V=1.0000015, theta=0.0
% INFO    : Bus 5250	: V=1.00112309, theta=-35.8748622 -> V=1.022224, theta=0.0
% INFO    : Bus 5251	: V=1.00777197, theta=-31.5576544 -> V=1.0000005, theta=0.0
% INFO    : Bus 5252	: V=1.00895512, theta=-31.5541373 -> V=1.0000005, theta=0.0
% INFO    : Bus 5253	: V=1.02864725, theta=-11.4311193 -> V=0.999999, theta=0.0
% INFO    : Bus 5254	: V=1.03298436, theta=-38.1828871 -> V=1.0032705, theta=0.0
% INFO    : Bus 5255	: V=1.02267662, theta=-16.9479506 -> V=1.015872, theta=0.0
% INFO    : Bus 5256	: V=1.02883351, theta=-10.6773071 -> V=1.0158755, theta=0.0
% INFO    : Bus 5257	: V=1.05621911, theta=-10.6616204 -> V=1.003335, theta=0.0
% INFO    : Bus 5258	: V=1.02919235, theta=-20.5541813 -> V=0.999999, theta=0.0
% INFO    : Bus 5259	: V=1.00412709, theta=-3.73362623 -> V=1.0158755, theta=0.0
% INFO    : Bus 5260	: V=1.02247382, theta=-17.4973567 -> V=1.015872, theta=0.0
% INFO    : Bus 5261	: V=1.00243259, theta=-27.9639931 -> V=1.022224, theta=0.0
% INFO    : Bus 5262	: V=1.00176497, theta=-32.6626199 -> V=1.0000025, theta=0.0
% INFO    : Bus 5263	: V=1.04111516, theta=-29.2115876 -> V=1.046665, theta=0.0
% INFO    : Bus 5264	: V=1.04098589, theta=-29.2389213 -> V=1.046665, theta=0.0
% INFO    : Bus 5265	: V=1.05279082, theta=-37.3516608 -> V=1.04444, theta=0.0
% INFO    : Bus 5266	: V=1.04912052, theta=-52.1015573 -> V=1.04444, theta=0.0
% INFO    : Bus 5267	: V=1.03816118, theta=-61.6215551 -> V=1.0079355, theta=0.0
% INFO    : Bus 5268	: V=1.06816935, theta=-22.0695588 -> V=1.0000025, theta=0.0
% INFO    : Bus 5269	: V=1.0540284, theta=-37.691305 -> V=1.027779, theta=0.0
% INFO    : Bus 5270	: V=1.05748775, theta=-19.1241669 -> V=1.005558, theta=0.0
% INFO    : Bus 5271	: V=1.05346735, theta=-20.0808725 -> V=1.005558, theta=0.0
% INFO    : Bus 5272	: V=1.09099882, theta=-12.741935 -> V=1.046665, theta=0.0
% INFO    : Bus 5273	: V=1.06551538, theta=-22.4341696 -> V=1.0000025, theta=0.0
% INFO    : Bus 5274	: V=1.0241168, theta=-30.8043806 -> V=1.000001, theta=0.0
% INFO    : Bus 5275	: V=1.02734744, theta=-8.6998781 -> V=1.0111115, theta=0.0
% INFO    : Bus 5276	: V=1.00355044, theta=-15.3913194 -> V=0.999999, theta=0.0
% INFO    : Bus 5277	: V=1.01586553, theta=-18.925332 -> V=1.015872, theta=0.0
% INFO    : Bus 5278	: V=1.02351802, theta=-11.4494013 -> V=0.999999, theta=0.0
% INFO    : Bus 5279	: V=1.01150773, theta=-11.3073552 -> V=0.999999, theta=0.0
% INFO    : Bus 5280	: V=1.02311179, theta=-38.6837969 -> V=1.027779, theta=0.0
% INFO    : Bus 5281	: V=1.00711809, theta=-13.9062381 -> V=1.015872, theta=0.0
% INFO    : Bus 5282	: V=1.02904735, theta=-14.8549523 -> V=0.999999, theta=0.0
% INFO    : Bus 5283	: V=1.01008438, theta=-37.6265839 -> V=1.0000005, theta=0.0
% INFO    : Bus 5284	: V=1.02491232, theta=-23.9349435 -> V=1.0158755, theta=0.0
% INFO    : Bus 5285	: V=1.03942689, theta=-34.5254681 -> V=1.027779, theta=0.0
% INFO    : Bus 5286	: V=1.04371029, theta=-25.8934504 -> V=1.022224, theta=0.0
% INFO    : Bus 5287	: V=1.06779463, theta=-9.50722842 -> V=1.0111115, theta=0.0
% INFO    : Bus 5288	: V=1.02347413, theta=-28.5188745 -> V=1.0000025, theta=0.0
% INFO    : Bus 5289	: V=1.00386766, theta=-27.3356913 -> V=1.0000025, theta=0.0
% INFO    : Bus 5290	: V=1.02326897, theta=-28.5072672 -> V=1.0000025, theta=0.0
% INFO    : Bus 5291	: V=1.00525108, theta=-27.2400766 -> V=1.0000025, theta=0.0
% INFO    : Bus 5292	: V=1.0302962, theta=-14.396037 -> V=0.9933315, theta=0.0
% INFO    : Bus 5293	: V=1.03980726, theta=-16.3533667 -> V=0.9888895, theta=0.0
% INFO    : Bus 5294	: V=1.00711205, theta=-13.905818 -> V=1.015872, theta=0.0
% INFO    : Bus 5295	: V=1.02197243, theta=-13.3003189 -> V=1.015872, theta=0.0
% INFO    : Bus 5296	: V=1.02183629, theta=-11.0727512 -> V=1.015872, theta=0.0
% INFO    : Bus 5297	: V=1.04054847, theta=-25.1910083 -> V=1.005558, theta=0.0
% INFO    : Bus 5298	: V=1.0357244, theta=-11.9134047 -> V=0.999999, theta=0.0
% INFO    : Bus 5299	: V=1.04620696, theta=-24.3839449 -> V=1.0222235, theta=0.0
% INFO    : Bus 5300	: V=1.00807075, theta=-15.8059689 -> V=1.015872, theta=0.0
% INFO    : Bus 5301	: V=1.01442434, theta=-16.9307088 -> V=1.0158755, theta=0.0
% INFO    : Bus 5302	: V=1.00977791, theta=-25.7761194 -> V=1.015872, theta=0.0
% INFO    : Bus 5303	: V=1.03198247, theta=-27.5774308 -> V=1.0000025, theta=0.0
% INFO    : Bus 5304	: V=1.04019032, theta=-26.6441703 -> V=1.0000025, theta=0.0
% INFO    : Bus 5305	: V=0.969124164, theta=-28.747199 -> V=1.0158755, theta=0.0
% INFO    : Bus 5306	: V=0.969116525, theta=-28.7487129 -> V=1.0158755, theta=0.0
% INFO    : Bus 5307	: V=1.03045537, theta=-21.8283456 -> V=1.0222235, theta=0.0
% INFO    : Bus 5308	: V=1.03359053, theta=-35.9697131 -> V=1.027779, theta=0.0
% INFO    : Bus 5309	: V=1.05509519, theta=-43.8098688 -> V=1.027779, theta=0.0
% INFO    : Bus 5310	: V=1.01100258, theta=-25.6341084 -> V=1.015872, theta=0.0
% INFO    : Bus 5311	: V=1.03908561, theta=-29.1317649 -> V=1.022224, theta=0.0
% INFO    : Bus 5312	: V=1.04937386, theta=-15.7613275 -> V=0.9888895, theta=0.0
% INFO    : Bus 5313	: V=1.01318061, theta=-38.875119 -> V=1.022224, theta=0.0
% INFO    : Bus 5314	: V=1.00536439, theta=-32.6766877 -> V=1.0000005, theta=0.0
% INFO    : Bus 5315	: V=1.04150913, theta=-27.2467047 -> V=1.0000025, theta=0.0
% INFO    : Bus 5316	: V=1.06011021, theta=-29.0079738 -> V=1.027779, theta=0.0
% INFO    : Bus 5317	: V=1.01733884, theta=-7.33703575 -> V=1.0158755, theta=0.0
% INFO    : Bus 5318	: V=1.02311811, theta=-10.2630735 -> V=0.999999, theta=0.0
% INFO    : Bus 5319	: V=1.07835855, theta=-15.1937804 -> V=1.046665, theta=0.0
% INFO    : Bus 5320	: V=1.02548531, theta=-20.3656868 -> V=1.0158755, theta=0.0
% INFO    : Bus 5321	: V=1.05987537, theta=-44.2732979 -> V=1.04444, theta=0.0
% INFO    : Bus 5322	: V=1.05880914, theta=-16.7880276 -> V=0.9933315, theta=0.0
% INFO    : Bus 5323	: V=1.02468173, theta=-23.6378486 -> V=1.022224, theta=0.0
% INFO    : Bus 5324	: V=1.0312064, theta=-26.9411632 -> V=0.999999, theta=0.0
% INFO    : Bus 5325	: V=1.02567308, theta=-22.2327724 -> V=0.999999, theta=0.0
% INFO    : Bus 5326	: V=1.01898335, theta=-11.3753543 -> V=0.999999, theta=0.0
% INFO    : Bus 5327	: V=1.03701326, theta=-32.2728903 -> V=1.027779, theta=0.0
% INFO    : Bus 5328	: V=1.02717455, theta=-30.9526478 -> V=1.027779, theta=0.0
% INFO    : Bus 5329	: V=0.991805322, theta=-39.3871277 -> V=1.0000005, theta=0.0
% INFO    : Bus 5330	: V=1.0336657, theta=-36.3518474 -> V=1.0000005, theta=0.0
% INFO    : Bus 5331	: V=1.0640976, theta=-31.778585 -> V=1.046665, theta=0.0
% INFO    : Bus 5332	: V=1.08614188, theta=-14.6515473 -> V=1.046665, theta=0.0
% INFO    : Bus 5333	: V=1.01834302, theta=-20.5497411 -> V=1.0000015, theta=0.0
% INFO    : Bus 5334	: V=1.04460782, theta=-10.5422546 -> V=0.9888895, theta=0.0
% INFO    : Bus 5335	: V=1.04641553, theta=-21.293219 -> V=1.0000025, theta=0.0
% INFO    : Bus 5336	: V=1.0609902, theta=-25.4652494 -> V=1.04444, theta=0.0
% INFO    : Bus 5337	: V=1.06468837, theta=-23.2535011 -> V=1.0000025, theta=0.0
% INFO    : Bus 5338	: V=1.04407777, theta=-49.014749 -> V=1.022224, theta=0.0
% INFO    : Bus 5339	: V=1.0543499, theta=-25.5868144 -> V=1.005558, theta=0.0
% INFO    : Bus 5340	: V=1.01209906, theta=-24.9265926 -> V=1.015872, theta=0.0
% INFO    : Bus 5341	: V=1.02760225, theta=-23.1369151 -> V=1.0222235, theta=0.0
% INFO    : Bus 5342	: V=1.02777655, theta=-21.316387 -> V=1.015872, theta=0.0
% INFO    : Bus 5343	: V=1.03441454, theta=-33.9667491 -> V=1.027779, theta=0.0
% INFO    : Bus 5344	: V=1.02083767, theta=-29.3157518 -> V=1.0000025, theta=0.0
% INFO    : Bus 5345	: V=1.04120805, theta=-20.4303107 -> V=1.0222235, theta=0.0
% INFO    : Bus 5346	: V=1.01715054, theta=-62.6782338 -> V=1.0079355, theta=0.0
% INFO    : Bus 5347	: V=1.01794667, theta=-5.01838517 -> V=1.0158755, theta=0.0
% INFO    : Bus 5348	: V=1.0123328, theta=-5.67647964 -> V=1.0158755, theta=0.0
% INFO    : Bus 5349	: V=1.00197168, theta=-24.8562763 -> V=1.0000025, theta=0.0
% INFO    : Bus 5350	: V=1.03337124, theta=-27.0384789 -> V=1.0000025, theta=0.0
% INFO    : Bus 5351	: V=1.02335783, theta=-31.6428784 -> V=1.046665, theta=0.0
% INFO    : Bus 5352	: V=1.02313468, theta=-31.6532955 -> V=1.046665, theta=0.0
% INFO    : Bus 5353	: V=1.01077118, theta=-26.8351395 -> V=1.0222235, theta=0.0
% INFO    : Bus 5354	: V=1.05166886, theta=-12.7975453 -> V=0.999999, theta=0.0
% INFO    : Bus 5355	: V=1.01628091, theta=-35.7379287 -> V=1.022224, theta=0.0
% INFO    : Bus 5356	: V=1.03351638, theta=-10.9826189 -> V=0.999999, theta=0.0
% INFO    : Bus 5357	: V=1.03945598, theta=-25.8443289 -> V=1.0000015, theta=0.0
% INFO    : Bus 5358	: V=1.05828121, theta=-12.2758152 -> V=1.000804, theta=0.0
% INFO    : Bus 5359	: V=1.00409039, theta=-39.1219833 -> V=1.0000005, theta=0.0
% INFO    : Bus 5360	: V=1.02200048, theta=-26.5468582 -> V=1.022224, theta=0.0
% INFO    : Bus 5361	: V=1.03407062, theta=-20.2223912 -> V=1.0000025, theta=0.0
% INFO    : Bus 5362	: V=1.02127528, theta=-38.3703019 -> V=1.022224, theta=0.0
% INFO    : Bus 5363	: V=1.02725822, theta=-29.2806347 -> V=1.005558, theta=0.0
% INFO    : Bus 5364	: V=1.03161306, theta=-21.1483799 -> V=1.0000025, theta=0.0
% INFO    : Bus 5365	: V=1.06749755, theta=-33.9502742 -> V=1.046665, theta=0.0
% INFO    : Bus 5366	: V=1.06711682, theta=-33.987001 -> V=1.046665, theta=0.0
% INFO    : Bus 5367	: V=1.05576449, theta=-7.14973973 -> V=1.0000015, theta=0.0
% INFO    : Bus 5368	: V=1.0109104, theta=-23.463659 -> V=0.999999, theta=0.0
% INFO    : Bus 5369	: V=1.05874361, theta=-26.1373873 -> V=1.005558, theta=0.0
% INFO    : Bus 5370	: V=1.06840844, theta=-21.0605076 -> V=1.0222235, theta=0.0
% INFO    : Bus 5371	: V=1.03578161, theta=-27.3712941 -> V=1.022224, theta=0.0
% INFO    : Bus 5372	: V=1.0345612, theta=-35.3777676 -> V=1.027779, theta=0.0
% INFO    : Bus 5373	: V=1.0568685, theta=-29.2417966 -> V=1.046665, theta=0.0
% INFO    : Bus 5374	: V=1.04935133, theta=-29.5048234 -> V=1.046665, theta=0.0
% INFO    : Bus 5375	: V=1.07762645, theta=-0.0881419984 -> V=0.9888895, theta=0.0
% INFO    : Bus 5376	: V=0.99742823, theta=-34.5064093 -> V=1.0000005, theta=0.0
% INFO    : Bus 5377	: V=1.0227077, theta=-22.6046908 -> V=1.0000025, theta=0.0
% INFO    : Bus 5378	: V=1.01745365, theta=-20.0679493 -> V=1.0158755, theta=0.0
% INFO    : Bus 5379	: V=1.0051282, theta=-38.6087273 -> V=1.0000005, theta=0.0
% INFO    : Bus 5380	: V=1.01617749, theta=-44.8550666 -> V=1.022224, theta=0.0
% INFO    : Bus 5381	: V=1.02800965, theta=-46.3864692 -> V=1.022224, theta=0.0
% INFO    : Bus 5382	: V=1.02841042, theta=-20.4810971 -> V=1.0158755, theta=0.0
% INFO    : Bus 5383	: V=1.00811383, theta=-14.5578397 -> V=0.999999, theta=0.0
% INFO    : Bus 5384	: V=0.999972978, theta=-25.0498072 -> V=1.0158755, theta=0.0
% INFO    : Bus 5385	: V=1.05793919, theta=-18.9136238 -> V=1.04444, theta=0.0
% INFO    : Bus 5386	: V=1.05300968, theta=-12.9051453 -> V=0.999999, theta=0.0
% INFO    : Bus 5387	: V=1.04803303, theta=-27.8611853 -> V=1.0000025, theta=0.0
% INFO    : Bus 5388	: V=1.02063328, theta=-16.0618801 -> V=1.0158755, theta=0.0
% INFO    : Bus 5389	: V=1.0496839, theta=-27.7674972 -> V=1.0000025, theta=0.0
% INFO    : Bus 5390	: V=1.05746099, theta=-18.9760153 -> V=1.04444, theta=0.0
% INFO    : Bus 5391	: V=0.944955273, theta=-8.40927791 -> V=0.9444445, theta=0.0
% INFO    : Bus 5392	: V=1.02176184, theta=-31.8951695 -> V=1.022224, theta=0.0
% INFO    : Bus 5393	: V=1.02623275, theta=-31.4879734 -> V=1.022224, theta=0.0
% INFO    : Bus 5394	: V=1.06279202, theta=-6.51565828 -> V=0.9888895, theta=0.0
% INFO    : Bus 5395	: V=1.03843156, theta=-30.6436157 -> V=1.046665, theta=0.0
% INFO    : Bus 5396	: V=1.03767461, theta=-21.7014402 -> V=1.0222235, theta=0.0
% INFO    : Bus 5397	: V=1.04033386, theta=-22.0637258 -> V=1.0222235, theta=0.0
% INFO    : Bus 5398	: V=1.02575048, theta=-11.9671888 -> V=0.999999, theta=0.0
% INFO    : Bus 5399	: V=1.04075874, theta=-47.0024376 -> V=1.022224, theta=0.0
% INFO    : Bus 5400	: V=1.05208255, theta=-22.020456 -> V=1.000624, theta=0.0
% INFO    : Bus 5401	: V=1.05796491, theta=-28.5224423 -> V=1.04444, theta=0.0
% INFO    : Bus 5402	: V=1.0480518, theta=-24.3638905 -> V=1.022224, theta=0.0
% INFO    : Bus 5403	: V=1.02197495, theta=-18.4194895 -> V=0.999999, theta=0.0
% INFO    : Bus 5404	: V=1.04325474, theta=-21.9219181 -> V=1.022224, theta=0.0
% INFO    : Bus 5405	: V=1.04813808, theta=-8.73683997 -> V=1.0111115, theta=0.0
% INFO    : Bus 5406	: V=1.05072813, theta=-20.50245 -> V=1.0000025, theta=0.0
% INFO    : Bus 5407	: V=1.00906628, theta=-60.957566 -> V=1.0079355, theta=0.0
% INFO    : Bus 5408	: V=1.00653778, theta=-18.2947495 -> V=1.0158755, theta=0.0
% INFO    : Bus 5409	: V=1.00621428, theta=-23.0859297 -> V=1.0158755, theta=0.0
% INFO    : Bus 5410	: V=1.03539771, theta=-41.0924745 -> V=1.022224, theta=0.0
% INFO    : Bus 5411	: V=1.00420186, theta=-25.0143609 -> V=1.0000025, theta=0.0
% INFO    : Bus 5412	: V=1.01578932, theta=-50.1876602 -> V=1.022224, theta=0.0
% INFO    : Bus 5413	: V=1.0218798, theta=-44.1578158 -> V=1.022224, theta=0.0
% INFO    : Bus 5414	: V=1.0472052, theta=-29.9674198 -> V=1.027779, theta=0.0
% INFO    : Bus 5415	: V=1.02287523, theta=-38.0371583 -> V=1.0000005, theta=0.0
% INFO    : Bus 5416	: V=0.966799699, theta=-9.37203184 -> V=0.9444445, theta=0.0
% INFO    : Bus 5417	: V=1.04567051, theta=-19.2973846 -> V=0.9933315, theta=0.0
% INFO    : Bus 5418	: V=1.01877929, theta=-8.19467191 -> V=1.0158755, theta=0.0
% INFO    : Bus 5419	: V=1.01950299, theta=-24.6011254 -> V=1.0000025, theta=0.0
% INFO    : Bus 5420	: V=1.0061951, theta=-19.2291694 -> V=1.0079355, theta=0.0
% INFO    : Bus 5421	: V=1.01551454, theta=-7.32280325 -> V=0.999999, theta=0.0
% INFO    : Bus 5422	: V=1.06583714, theta=-33.3223279 -> V=1.046665, theta=0.0
% INFO    : Bus 5423	: V=1.02453665, theta=-51.0795094 -> V=1.0079355, theta=0.0
% INFO    : Bus 5424	: V=1.06498428, theta=-33.384821 -> V=1.046665, theta=0.0
% INFO    : Bus 5425	: V=1.01677046, theta=-9.84399176 -> V=1.0158755, theta=0.0
% INFO    : Bus 5426	: V=1.03930212, theta=-29.5218898 -> V=1.005558, theta=0.0
% INFO    : Bus 5427	: V=1.0176136, theta=-10.2393507 -> V=1.0158755, theta=0.0
% INFO    : Bus 5428	: V=1.07421222, theta=-7.79174505 -> V=0.9888895, theta=0.0
% INFO    : Bus 5429	: V=1.02270737, theta=-2.33019174 -> V=1.0158755, theta=0.0
% INFO    : Bus 5430	: V=1.07623537, theta=-0.393813479 -> V=0.9888895, theta=0.0
% INFO    : Bus 5431	: V=1.01800672, theta=-12.832639 -> V=1.015872, theta=0.0
% INFO    : Bus 5432	: V=1.05442987, theta=-23.8710345 -> V=1.005558, theta=0.0
% INFO    : Bus 5433	: V=1.04594158, theta=-26.3331454 -> V=1.0000025, theta=0.0
% INFO    : Bus 5434	: V=1.00789911, theta=-37.5569048 -> V=1.0000005, theta=0.0
% INFO    : Bus 5435	: V=1.02279084, theta=-31.6250045 -> V=1.022224, theta=0.0
% INFO    : Bus 5436	: V=1.03720176, theta=-35.8283998 -> V=1.022224, theta=0.0
% INFO    : Bus 5437	: V=1.04814057, theta=-50.2091723 -> V=1.022224, theta=0.0
% INFO    : Bus 5438	: V=1.01955927, theta=-25.6694637 -> V=1.022224, theta=0.0
% INFO    : Bus 5439	: V=1.01330527, theta=-34.496669 -> V=1.0000005, theta=0.0
% INFO    : Bus 5440	: V=1.0113948, theta=-34.7333992 -> V=1.0000005, theta=0.0
% INFO    : Bus 5441	: V=1.04163667, theta=-14.3934878 -> V=1.046665, theta=0.0
% INFO    : Bus 5442	: V=1.04104932, theta=-12.2037667 -> V=1.0111115, theta=0.0
% INFO    : Bus 5443	: V=1.03962178, theta=-26.3672216 -> V=1.0000025, theta=0.0
% INFO    : Bus 5444	: V=1.02628828, theta=-37.4478567 -> V=1.022224, theta=0.0
% INFO    : Bus 5445	: V=1.02046563, theta=-10.1871709 -> V=1.0158755, theta=0.0
% INFO    : Bus 5446	: V=1.01731394, theta=-62.9246655 -> V=1.0079355, theta=0.0
% INFO    : Bus 5447	: V=1.0241221, theta=-66.7747327 -> V=1.0079355, theta=0.0
% INFO    : Bus 5448	: V=1.07400005, theta=-42.0716957 -> V=1.04444, theta=0.0
% INFO    : Bus 5449	: V=1.03400635, theta=-63.2533446 -> V=1.0079355, theta=0.0
% INFO    : Bus 5450	: V=1.02480988, theta=-28.5767128 -> V=1.0000025, theta=0.0
% INFO    : Bus 5451	: V=1.01491775, theta=-23.68735 -> V=1.0000025, theta=0.0
% INFO    : Bus 5452	: V=1.04752506, theta=-26.4557211 -> V=1.0000025, theta=0.0
% INFO    : Bus 5453	: V=1.04948667, theta=-23.4312755 -> V=1.0000025, theta=0.0
% INFO    : Bus 5454	: V=1.04595769, theta=-24.3056234 -> V=1.0000025, theta=0.0
% INFO    : Bus 5455	: V=1.05232476, theta=-25.1047046 -> V=1.022224, theta=0.0
% INFO    : Bus 5456	: V=1.019095, theta=-29.6414893 -> V=1.0000025, theta=0.0
% INFO    : Bus 5457	: V=1.06340968, theta=-9.1373095 -> V=1.046665, theta=0.0
% INFO    : Bus 5458	: V=1.01803522, theta=-30.4997111 -> V=1.0000025, theta=0.0
% INFO    : Bus 5459	: V=1.01890971, theta=-43.607352 -> V=1.022224, theta=0.0
% INFO    : Bus 5460	: V=1.05546204, theta=-31.4776491 -> V=1.0000025, theta=0.0
% INFO    : Bus 5461	: V=1.03170356, theta=-27.2280902 -> V=1.0000025, theta=0.0
% INFO    : Bus 5462	: V=1.05646513, theta=-29.3313177 -> V=1.046665, theta=0.0
% INFO    : Bus 5463	: V=1.01308002, theta=-7.41589814 -> V=1.0158755, theta=0.0
% INFO    : Bus 5464	: V=1.07920189, theta=-13.0774467 -> V=1.046665, theta=0.0
% INFO    : Bus 5465	: V=1.04298538, theta=-7.1233991 -> V=1.0111115, theta=0.0
% INFO    : Bus 5466	: V=1.00539598, theta=-62.9949295 -> V=1.0079355, theta=0.0
% INFO    : Bus 5467	: V=1.09120949, theta=-12.6802859 -> V=1.046665, theta=0.0
% INFO    : Bus 5468	: V=1.00807965, theta=-20.65922 -> V=1.015872, theta=0.0
% INFO    : Bus 5469	: V=1.0306874, theta=-17.7542757 -> V=0.999999, theta=0.0
% INFO    : Bus 5470	: V=0.996683239, theta=-33.7396771 -> V=1.0000005, theta=0.0
% INFO    : Bus 5471	: V=1.03241184, theta=-27.8667314 -> V=1.0000025, theta=0.0
% INFO    : Bus 5472	: V=1.04586297, theta=-25.4934284 -> V=1.0000025, theta=0.0
% INFO    : Bus 5473	: V=1.04084906, theta=-31.8311134 -> V=1.046665, theta=0.0
% INFO    : Bus 5474	: V=1.02310354, theta=-14.3604415 -> V=1.0158755, theta=0.0
% INFO    : Bus 5475	: V=1.0405464, theta=-32.0077466 -> V=1.046665, theta=0.0
% INFO    : Bus 5476	: V=1.01605745, theta=-15.0559507 -> V=0.999999, theta=0.0
% INFO    : Bus 5477	: V=1.03182304, theta=-27.2800514 -> V=0.999999, theta=0.0
% INFO    : Bus 5478	: V=1.00845178, theta=-37.6567221 -> V=1.0000005, theta=0.0
% INFO    : Bus 5479	: V=1.0362582, theta=-19.5588042 -> V=1.0000015, theta=0.0
% INFO    : Bus 5480	: V=1.0450183, theta=-29.2894615 -> V=1.046665, theta=0.0
% INFO    : Bus 5481	: V=1.02268176, theta=-40.3915761 -> V=1.022224, theta=0.0
% INFO    : Bus 5482	: V=1.01196939, theta=-64.366669 -> V=1.0079355, theta=0.0
% INFO    : Bus 5483	: V=1.04710977, theta=-61.6676236 -> V=1.0079355, theta=0.0
% INFO    : Bus 5484	: V=1.03415919, theta=-13.8478779 -> V=0.999999, theta=0.0
% INFO    : Bus 5485	: V=1.03431129, theta=-13.8391588 -> V=0.999999, theta=0.0
% INFO    : Bus 5486	: V=0.990975824, theta=-33.5911174 -> V=1.0000005, theta=0.0
% INFO    : Bus 5487	: V=1.03659761, theta=-26.214058 -> V=1.022224, theta=0.0
% INFO    : Bus 5488	: V=1.04297606, theta=-19.2608712 -> V=0.999999, theta=0.0
% INFO    : Bus 5489	: V=1.02279941, theta=-43.3822084 -> V=1.022224, theta=0.0
% INFO    : Bus 5490	: V=1.04048868, theta=-24.5703093 -> V=1.0000025, theta=0.0
% INFO    : Bus 5491	: V=1.01266686, theta=-7.80907025 -> V=1.0158755, theta=0.0
% INFO    : Bus 5492	: V=1.01242029, theta=-7.82478118 -> V=1.0158755, theta=0.0
% INFO    : Bus 5493	: V=1.0454998, theta=-25.8855142 -> V=1.0000025, theta=0.0
% INFO    : Bus 5494	: V=1.07347239, theta=-6.51071975 -> V=0.9888895, theta=0.0
% INFO    : Bus 5495	: V=1.01429205, theta=-19.0013251 -> V=1.0158755, theta=0.0
% INFO    : Bus 5496	: V=1.06203196, theta=-2.49275092 -> V=0.9888895, theta=0.0
% INFO    : Bus 5497	: V=1.04328312, theta=-18.6143884 -> V=0.9888895, theta=0.0
% INFO    : Bus 5498	: V=1.01136017, theta=-27.425712 -> V=1.0222235, theta=0.0
% INFO    : Bus 5499	: V=1.03494789, theta=-34.7209349 -> V=1.022224, theta=0.0
% INFO    : Bus 5500	: V=1.06595586, theta=-29.1090971 -> V=1.027779, theta=0.0
% INFO    : Bus 5501	: V=1.03356944, theta=-40.2951037 -> V=1.027779, theta=0.0
% INFO    : Bus 5502	: V=1.01027948, theta=-25.1249555 -> V=1.015872, theta=0.0
% INFO    : Bus 5503	: V=1.02205567, theta=-37.9733804 -> V=1.027779, theta=0.0
% INFO    : Bus 5504	: V=1.02412933, theta=-43.8297273 -> V=1.022224, theta=0.0
% INFO    : Bus 5505	: V=1.03520816, theta=-36.2236491 -> V=1.022224, theta=0.0
% INFO    : Bus 5506	: V=0.995882399, theta=-31.1105948 -> V=1.0000005, theta=0.0
% INFO    : Bus 5507	: V=1.00636911, theta=-37.8105423 -> V=1.0000005, theta=0.0
% INFO    : Bus 5508	: V=1.0275944, theta=-24.5970163 -> V=1.0000015, theta=0.0
% INFO    : Bus 5509	: V=1.02477699, theta=-9.91405466 -> V=1.0111115, theta=0.0
% INFO    : Bus 5510	: V=1.03451072, theta=-38.2028985 -> V=1.0040655, theta=0.0
% INFO    : Bus 5511	: V=1.04182717, theta=-8.95202668 -> V=1.0000015, theta=0.0
% INFO    : Bus 5512	: V=1.04562631, theta=-10.8162218 -> V=0.9888895, theta=0.0
% INFO    : Bus 5513	: V=1.057992, theta=-30.8552866 -> V=1.046665, theta=0.0
% INFO    : Bus 5514	: V=1.03282287, theta=-17.8540941 -> V=0.999999, theta=0.0
% INFO    : Bus 5515	: V=1.01862612, theta=-26.1729841 -> V=1.0000025, theta=0.0
% INFO    : Bus 5516	: V=1.01016601, theta=-13.7623671 -> V=1.0000015, theta=0.0
% INFO    : Bus 5517	: V=1.03539382, theta=-27.687237 -> V=1.0000025, theta=0.0
% INFO    : Bus 5518	: V=1.03493334, theta=-27.7371561 -> V=1.0000025, theta=0.0
% INFO    : Bus 5519	: V=1.05551848, theta=-14.2235228 -> V=1.046665, theta=0.0
% INFO    : Bus 5520	: V=1.01259091, theta=-31.4019051 -> V=1.0000005, theta=0.0
% INFO    : Bus 5521	: V=1.0192056, theta=-30.9066966 -> V=1.0000005, theta=0.0
% INFO    : Bus 5522	: V=1.01587949, theta=-26.4199324 -> V=1.046665, theta=0.0
% INFO    : Bus 5523	: V=1.01646397, theta=-13.1891504 -> V=0.999999, theta=0.0
% INFO    : Bus 5524	: V=1.03951642, theta=-27.6798576 -> V=1.0000025, theta=0.0
% INFO    : Bus 5525	: V=1.05065146, theta=-25.3080318 -> V=1.0000025, theta=0.0
% INFO    : Bus 5526	: V=1.0464088, theta=-7.57651874 -> V=1.0111115, theta=0.0
% INFO    : Bus 5527	: V=1.05072933, theta=-25.5668444 -> V=1.0000025, theta=0.0
% INFO    : Bus 5528	: V=1.08786809, theta=-23.323054 -> V=1.046665, theta=0.0
% INFO    : Bus 5529	: V=1.0107139, theta=-34.8266363 -> V=1.022224, theta=0.0
% INFO    : Bus 5530	: V=0.994995799, theta=-39.8888013 -> V=1.0000005, theta=0.0
% INFO    : Bus 5531	: V=1.01737382, theta=-22.4302986 -> V=1.0158755, theta=0.0
% INFO    : Bus 5532	: V=1.00331359, theta=-6.87588807 -> V=1.0158755, theta=0.0
% INFO    : Bus 5533	: V=1.03209129, theta=-17.9274929 -> V=1.015872, theta=0.0
% INFO    : Bus 5534	: V=1.0227355, theta=-10.3184855 -> V=0.999999, theta=0.0
% INFO    : Bus 5535	: V=1.03105699, theta=-31.1858869 -> V=1.0000025, theta=0.0
% INFO    : Bus 5536	: V=1.00743411, theta=-8.74246219 -> V=1.0158755, theta=0.0
% INFO    : Bus 5537	: V=0.991029923, theta=-26.4966636 -> V=1.0158755, theta=0.0
% INFO    : Bus 5538	: V=0.991028779, theta=-26.4947259 -> V=1.0158755, theta=0.0
% INFO    : Bus 5539	: V=1.04488039, theta=-27.9307586 -> V=1.022224, theta=0.0
% INFO    : Bus 5540	: V=1.0009077, theta=-8.78710828 -> V=0.999999, theta=0.0
% INFO    : Bus 5541	: V=1.04774638, theta=-26.9382503 -> V=1.0000015, theta=0.0
% INFO    : Bus 5542	: V=1.05308438, theta=-26.6664304 -> V=1.0000015, theta=0.0
% INFO    : Bus 5543	: V=1.04190063, theta=-11.7689089 -> V=0.999999, theta=0.0
% INFO    : Bus 5544	: V=1.04479396, theta=-24.8213074 -> V=1.0000025, theta=0.0
% INFO    : Bus 5545	: V=1.05061808, theta=-20.4997283 -> V=1.0000025, theta=0.0
% INFO    : Bus 5546	: V=1.09286066, theta=-18.2380624 -> V=1.0333335, theta=0.0
% INFO    : Bus 5547	: V=1.07101935, theta=-20.8323773 -> V=1.0000025, theta=0.0
% INFO    : Bus 5548	: V=1.06942117, theta=-20.8557594 -> V=1.0000025, theta=0.0
% INFO    : Bus 5549	: V=1.01851193, theta=-17.7064745 -> V=1.0158755, theta=0.0
% INFO    : Bus 5550	: V=1.02061484, theta=-13.6721709 -> V=0.999999, theta=0.0
% INFO    : Bus 5551	: V=1.02735056, theta=-11.2126014 -> V=0.999999, theta=0.0
% INFO    : Bus 5552	: V=1.02471348, theta=-16.1355335 -> V=1.0158755, theta=0.0
% INFO    : Bus 5553	: V=1.04404045, theta=-14.9054577 -> V=1.001294, theta=0.0
% INFO    : Bus 5554	: V=1.03400019, theta=-20.220481 -> V=1.0000025, theta=0.0
% INFO    : Bus 5555	: V=1.03429844, theta=-25.4003055 -> V=1.0222235, theta=0.0
% INFO    : Bus 5556	: V=1.01702215, theta=-12.5264967 -> V=1.015872, theta=0.0
% INFO    : Bus 5557	: V=1.03233783, theta=-25.6136252 -> V=1.0222235, theta=0.0
% INFO    : Bus 5558	: V=1.00812927, theta=-37.5169843 -> V=1.0000005, theta=0.0
% INFO    : Bus 5559	: V=1.03618326, theta=-22.0405639 -> V=0.999999, theta=0.0
% INFO    : Bus 5560	: V=1.04563845, theta=-29.7995638 -> V=1.046665, theta=0.0
% INFO    : Bus 5561	: V=1.04666407, theta=-29.8353523 -> V=1.046665, theta=0.0
% INFO    : Bus 5562	: V=1.03835086, theta=-12.0671592 -> V=0.999999, theta=0.0
% INFO    : Bus 5563	: V=1.00925785, theta=-21.7544896 -> V=1.0000015, theta=0.0
% INFO    : Bus 5564	: V=1.02299537, theta=-21.8237705 -> V=1.0000025, theta=0.0
% INFO    : Bus 5565	: V=1.02299396, theta=-21.9032009 -> V=1.0000025, theta=0.0
% INFO    : Bus 5566	: V=1.04400611, theta=-32.6074227 -> V=1.046665, theta=0.0
% INFO    : Bus 5567	: V=1.02735087, theta=-52.8325734 -> V=1.022224, theta=0.0
% INFO    : Bus 5568	: V=1.02235336, theta=-25.0700018 -> V=0.999999, theta=0.0
% INFO    : Bus 5569	: V=1.05661477, theta=-23.1271363 -> V=1.0000025, theta=0.0
% INFO    : Bus 5570	: V=1.05672125, theta=-23.0856712 -> V=1.0000025, theta=0.0
% INFO    : Bus 5571	: V=1.06466803, theta=-21.5141952 -> V=1.0222235, theta=0.0
% INFO    : Bus 5572	: V=1.02381682, theta=-18.967018 -> V=1.015872, theta=0.0
% INFO    : Bus 5573	: V=0.987328131, theta=-23.6544741 -> V=1.0000025, theta=0.0
% INFO    : Bus 5574	: V=0.991457574, theta=-22.6900806 -> V=1.0000025, theta=0.0
% INFO    : Bus 5575	: V=1.03589123, theta=-16.9012002 -> V=0.999999, theta=0.0
% INFO    : Bus 5576	: V=1.01540221, theta=-30.2554944 -> V=1.0000025, theta=0.0
% INFO    : Bus 5577	: V=1.03097572, theta=-27.4994837 -> V=1.0000025, theta=0.0
% INFO    : Bus 5578	: V=1.03106691, theta=-27.5173823 -> V=1.0000025, theta=0.0
% INFO    : Bus 5579	: V=1.05040743, theta=-21.9034918 -> V=1.0000025, theta=0.0
% INFO    : Bus 5580	: V=1.03169816, theta=-26.3537612 -> V=1.0000015, theta=0.0
% INFO    : Bus 5581	: V=1.03026235, theta=-29.9157898 -> V=1.005558, theta=0.0
% INFO    : Bus 5582	: V=1.01990728, theta=-19.628165 -> V=0.999999, theta=0.0
% INFO    : Bus 5583	: V=1.01324621, theta=-16.2261805 -> V=1.0079355, theta=0.0
% INFO    : Bus 5584	: V=1.09895831, theta=-16.9520071 -> V=1.0333335, theta=0.0
% INFO    : Bus 5585	: V=1.03466012, theta=-19.7099782 -> V=1.0000015, theta=0.0
% INFO    : Bus 5586	: V=1.03620395, theta=-19.3046611 -> V=1.0158755, theta=0.0
% INFO    : Bus 5587	: V=1.02813148, theta=-31.061911 -> V=1.027779, theta=0.0
% INFO    : Bus 5588	: V=1.05605871, theta=-60.7357215 -> V=1.0079355, theta=0.0
% INFO    : Bus 5589	: V=1.01812931, theta=-19.0392205 -> V=1.015872, theta=0.0
% INFO    : Bus 5590	: V=1.02741467, theta=-34.8882374 -> V=1.027779, theta=0.0
% INFO    : Bus 5591	: V=1.04176727, theta=-27.1399923 -> V=1.0000025, theta=0.0
% INFO    : Bus 5592	: V=1.05915625, theta=-28.4484549 -> V=1.046665, theta=0.0
% INFO    : Bus 5593	: V=1.04819684, theta=-25.038659 -> V=1.005558, theta=0.0
% INFO    : Bus 5594	: V=1.01108165, theta=-9.17235141 -> V=0.999999, theta=0.0
% INFO    : Bus 5595	: V=1.01197869, theta=-24.5491303 -> V=1.0158755, theta=0.0
% INFO    : Bus 5596	: V=1.01133704, theta=-21.0206089 -> V=1.0158755, theta=0.0
% INFO    : Bus 5597	: V=1.0003626, theta=-20.6694166 -> V=1.015872, theta=0.0
% INFO    : Bus 5598	: V=1.03162332, theta=-21.1486 -> V=1.0000025, theta=0.0
% INFO    : Bus 5599	: V=1.03828691, theta=-26.5626803 -> V=1.0000025, theta=0.0
% INFO    : Bus 5600	: V=1.03933015, theta=-25.7857356 -> V=1.0000025, theta=0.0
% INFO    : Bus 5601	: V=1.04934994, theta=-25.3692044 -> V=1.0000025, theta=0.0
% INFO    : Bus 5602	: V=1.04768421, theta=-25.5021798 -> V=1.0000025, theta=0.0
% INFO    : Bus 5603	: V=1.0510892, theta=-25.2178156 -> V=1.0000025, theta=0.0
% INFO    : Bus 5604	: V=1.03848176, theta=-26.4945038 -> V=1.0000025, theta=0.0
% INFO    : Bus 5605	: V=1.08289378, theta=0.680839628 -> V=0.9907995, theta=0.0
% INFO    : Bus 5606	: V=1.01465992, theta=-26.9948384 -> V=1.015872, theta=0.0
% INFO    : Bus 5607	: V=1.0159624, theta=-62.24529 -> V=1.0079355, theta=0.0
% INFO    : Bus 5608	: V=1.01184771, theta=-27.434291 -> V=1.015872, theta=0.0
% INFO    : Bus 5609	: V=1.01600615, theta=-29.4450443 -> V=1.0000025, theta=0.0
% INFO    : Bus 5610	: V=1.02605096, theta=-12.0524216 -> V=0.999999, theta=0.0
% INFO    : Bus 5611	: V=1.06107956, theta=-33.494099 -> V=1.027779, theta=0.0
% INFO    : Bus 5612	: V=1.02884441, theta=-11.7077189 -> V=0.999999, theta=0.0
% INFO    : Bus 5613	: V=1.06107011, theta=-33.4996569 -> V=1.027779, theta=0.0
% INFO    : Bus 5614	: V=1.01687081, theta=-29.3976028 -> V=1.0000025, theta=0.0
% INFO    : Bus 5615	: V=1.02919281, theta=-9.57121701 -> V=1.0158755, theta=0.0
% INFO    : Bus 5616	: V=1.0304005, theta=-9.45653321 -> V=1.0158755, theta=0.0
% INFO    : Bus 5617	: V=1.05302397, theta=-18.5564907 -> V=1.000224, theta=0.0
% INFO    : Bus 5618	: V=1.01787161, theta=-25.6848404 -> V=1.0000025, theta=0.0
% INFO    : Bus 5619	: V=0.997754849, theta=-51.2819483 -> V=1.022224, theta=0.0
% INFO    : Bus 5620	: V=1.00716821, theta=-37.5602979 -> V=1.015872, theta=0.0
% INFO    : Bus 5621	: V=1.00711826, theta=-37.5670461 -> V=1.015872, theta=0.0
% INFO    : Bus 5622	: V=1.02498813, theta=-41.9406766 -> V=1.022224, theta=0.0
% INFO    : Bus 5623	: V=0.993392657, theta=-36.1310677 -> V=1.022224, theta=0.0
% INFO    : Bus 5624	: V=0.99843349, theta=-53.2376284 -> V=1.022224, theta=0.0
% INFO    : Bus 5625	: V=1.01112865, theta=-60.3751177 -> V=1.0079355, theta=0.0
% INFO    : Bus 5626	: V=1.06073587, theta=-23.3224053 -> V=1.0000015, theta=0.0
% INFO    : Bus 5627	: V=1.0105434, theta=-59.9062536 -> V=1.0079355, theta=0.0
% INFO    : Bus 5628	: V=1.02757032, theta=-19.6073449 -> V=1.0158755, theta=0.0
% INFO    : Bus 5629	: V=1.0084269, theta=-18.936578 -> V=0.999999, theta=0.0
% INFO    : Bus 5630	: V=1.0289939, theta=-10.7520585 -> V=0.999999, theta=0.0
% INFO    : Bus 5631	: V=1.01816132, theta=-47.8817227 -> V=1.022224, theta=0.0
% INFO    : Bus 5632	: V=0.999027744, theta=-65.58835 -> V=1.0079355, theta=0.0
% INFO    : Bus 5633	: V=1.00784414, theta=-14.5704417 -> V=1.015872, theta=0.0
% INFO    : Bus 5634	: V=1.02970163, theta=-22.5904168 -> V=1.0222235, theta=0.0
% INFO    : Bus 5635	: V=1.03717353, theta=-18.0259808 -> V=0.999999, theta=0.0
% INFO    : Bus 5636	: V=1.05761115, theta=-60.5460921 -> V=1.0079355, theta=0.0
% INFO    : Bus 5637	: V=1.03687567, theta=-20.5520122 -> V=0.999999, theta=0.0
% INFO    : Bus 5638	: V=1.07638715, theta=-42.4130686 -> V=1.04444, theta=0.0
% INFO    : Bus 5639	: V=0.984715565, theta=-33.9972499 -> V=1.0000005, theta=0.0
% INFO    : Bus 5640	: V=1.03446423, theta=-34.4555525 -> V=1.027779, theta=0.0
% INFO    : Bus 5641	: V=1.05531616, theta=-17.1839072 -> V=1.0000025, theta=0.0
% INFO    : Bus 5642	: V=0.994686886, theta=-52.069511 -> V=1.022224, theta=0.0
% INFO    : Bus 5643	: V=1.05531616, theta=-17.1839072 -> V=1.0000025, theta=0.0
% INFO    : Bus 5644	: V=1.03743004, theta=-19.6071377 -> V=1.0000015, theta=0.0
% INFO    : Bus 5645	: V=1.00597927, theta=-46.7804286 -> V=1.022224, theta=0.0
% INFO    : Bus 5646	: V=1.06751752, theta=-12.4381236 -> V=1.072365, theta=0.0
% INFO    : Bus 5647	: V=1.03823088, theta=-11.9679551 -> V=0.999999, theta=0.0
% INFO    : Bus 5648	: V=0.998152736, theta=-20.6919096 -> V=1.0199985, theta=0.0
% INFO    : Bus 5649	: V=1.03608631, theta=-12.0528539 -> V=0.999999, theta=0.0
% INFO    : Bus 5650	: V=1.01424374, theta=-38.8538217 -> V=1.022224, theta=0.0
% INFO    : Bus 5651	: V=1.01481635, theta=-6.88651117 -> V=0.999999, theta=0.0
% INFO    : Bus 5652	: V=1.05112635, theta=-31.0220551 -> V=1.0000025, theta=0.0
% INFO    : Bus 5653	: V=1.02261255, theta=-13.468417 -> V=1.015872, theta=0.0
% INFO    : Bus 5654	: V=1.03182499, theta=-27.2800948 -> V=0.999999, theta=0.0
% INFO    : Bus 5655	: V=1.02295186, theta=-12.2167557 -> V=0.999999, theta=0.0
% INFO    : Bus 5656	: V=1.03901156, theta=-29.1428966 -> V=1.022224, theta=0.0
% INFO    : Bus 5657	: V=1.03122495, theta=-16.6654929 -> V=0.999999, theta=0.0
% INFO    : Bus 5658	: V=1.03331329, theta=-15.2077927 -> V=0.999999, theta=0.0
% INFO    : Bus 5659	: V=1.04769285, theta=-17.3883996 -> V=1.046665, theta=0.0
% INFO    : Bus 5660	: V=1.04183394, theta=-14.8204647 -> V=0.9888895, theta=0.0
% INFO    : Bus 5661	: V=1.01790495, theta=-13.1535495 -> V=0.999999, theta=0.0
% INFO    : Bus 5662	: V=1.01699986, theta=-8.11337737 -> V=0.999999, theta=0.0
% INFO    : Bus 5663	: V=1.06618539, theta=-22.6430909 -> V=1.0000015, theta=0.0
% INFO    : Bus 5664	: V=1.0511145, theta=-18.2236362 -> V=0.9933315, theta=0.0
% INFO    : Bus 5665	: V=1.02663897, theta=-28.0193822 -> V=1.005558, theta=0.0
% INFO    : Bus 5666	: V=1.06114773, theta=-36.1232739 -> V=1.04444, theta=0.0
% INFO    : Bus 5667	: V=1.05170575, theta=-18.0385021 -> V=1.046665, theta=0.0
% INFO    : Bus 5668	: V=1.02663414, theta=-11.2171577 -> V=0.999999, theta=0.0
% INFO    : Bus 5669	: V=1.0346394, theta=-38.2049229 -> V=1.0041355, theta=0.0
% INFO    : Bus 5670	: V=0.997699448, theta=-34.9279663 -> V=1.0000005, theta=0.0
% INFO    : Bus 5671	: V=1.05581883, theta=-7.16145768 -> V=1.0111115, theta=0.0
% INFO    : Bus 5672	: V=1.01296536, theta=-24.4352162 -> V=1.0000025, theta=0.0
% INFO    : Bus 5673	: V=1.01179654, theta=-14.0398105 -> V=1.015872, theta=0.0
% INFO    : Bus 5674	: V=1.00974014, theta=-34.8110441 -> V=1.0000005, theta=0.0
% INFO    : Bus 5675	: V=1.03424805, theta=-45.3220388 -> V=1.022224, theta=0.0
% INFO    : Bus 5676	: V=1.02596041, theta=-22.8957279 -> V=1.027779, theta=0.0
% INFO    : Bus 5677	: V=1.00964532, theta=-15.406697 -> V=0.999999, theta=0.0
% INFO    : Bus 5678	: V=1.04643238, theta=-34.247838 -> V=1.046665, theta=0.0
% INFO    : Bus 5679	: V=1.04661089, theta=-33.6971589 -> V=1.046665, theta=0.0
% INFO    : Bus 5680	: V=1.02812784, theta=-37.059015 -> V=1.022224, theta=0.0
% INFO    : Bus 5681	: V=1.01554982, theta=-8.09260006 -> V=0.999999, theta=0.0
% INFO    : Bus 5682	: V=1.04194768, theta=-28.2167201 -> V=1.022224, theta=0.0
% INFO    : Bus 5683	: V=1.04358685, theta=-27.8798488 -> V=1.022224, theta=0.0
% INFO    : Bus 5684	: V=1.05835121, theta=-30.8491362 -> V=1.046665, theta=0.0
% INFO    : Bus 5685	: V=1.04454172, theta=-30.386377 -> V=1.046665, theta=0.0
% INFO    : Bus 5686	: V=1.03033978, theta=-15.8668387 -> V=0.999999, theta=0.0
% INFO    : Bus 5687	: V=1.01668321, theta=-30.4279028 -> V=1.0000025, theta=0.0
% INFO    : Bus 5688	: V=1.01686871, theta=-30.3832746 -> V=1.0000025, theta=0.0
% INFO    : Bus 5689	: V=1.0197923, theta=-2.26289549 -> V=1.0158755, theta=0.0
% INFO    : Bus 5690	: V=1.02436563, theta=-49.5999051 -> V=1.0079355, theta=0.0
% INFO    : Bus 5691	: V=1.025895, theta=-49.5063965 -> V=1.0079355, theta=0.0
% INFO    : Bus 5692	: V=1.00682662, theta=-26.0970714 -> V=1.015872, theta=0.0
% INFO    : Bus 5693	: V=1.01508783, theta=-25.3467533 -> V=1.0222235, theta=0.0
% INFO    : Bus 5694	: V=1.05555536, theta=-24.3862539 -> V=1.0000025, theta=0.0
% INFO    : Bus 5695	: V=1.04125313, theta=-28.5876922 -> V=1.0233335, theta=0.0
% INFO    : Bus 5696	: V=1.0548227, theta=-18.1356709 -> V=0.9933315, theta=0.0
% INFO    : Bus 5697	: V=1.030087, theta=-22.9769023 -> V=0.9933315, theta=0.0
% INFO    : Bus 5698	: V=0.987900334, theta=-35.5760335 -> V=1.0000005, theta=0.0
% INFO    : Bus 5699	: V=1.04664892, theta=-5.34380619 -> V=1.0111115, theta=0.0
% INFO    : Bus 5700	: V=1.00336256, theta=-14.6088557 -> V=1.015872, theta=0.0
% INFO    : Bus 5701	: V=1.05205417, theta=-24.5856496 -> V=1.0000025, theta=0.0
% INFO    : Bus 5702	: V=1.0561202, theta=-13.2270924 -> V=1.046665, theta=0.0
% INFO    : Bus 5703	: V=1.03038217, theta=-27.6375306 -> V=1.022224, theta=0.0
% INFO    : Bus 5704	: V=1.02506789, theta=-17.3847706 -> V=1.015872, theta=0.0
% INFO    : Bus 5705	: V=1.02537281, theta=-41.6465333 -> V=1.022224, theta=0.0
% INFO    : Bus 5706	: V=1.02077039, theta=-22.0147586 -> V=0.999999, theta=0.0
% INFO    : Bus 5707	: V=0.997715712, theta=-39.7654673 -> V=1.0000005, theta=0.0
% INFO    : Bus 5708	: V=1.07296513, theta=-0.332047921 -> V=0.9888895, theta=0.0
% INFO    : Bus 5709	: V=1.09023767, theta=-13.1632316 -> V=1.04538, theta=0.0
% INFO    : Bus 5710	: V=1.0153069, theta=-7.73402866 -> V=1.0158755, theta=0.0
% INFO    : Bus 5711	: V=1.02496628, theta=-34.955195 -> V=1.027779, theta=0.0
% INFO    : Bus 5712	: V=1.07019555, theta=-0.527415633 -> V=0.9888895, theta=0.0
% INFO    : Bus 5713	: V=1.02573812, theta=-34.9315351 -> V=1.027779, theta=0.0
% INFO    : Bus 5714	: V=1.01728908, theta=-35.1868926 -> V=1.022224, theta=0.0
% INFO    : Bus 5715	: V=1.03660199, theta=-31.1756642 -> V=1.046665, theta=0.0
% INFO    : Bus 5716	: V=1.02896089, theta=-64.0241517 -> V=1.0079355, theta=0.0
% INFO    : Bus 5717	: V=1.00171178, theta=-33.0468733 -> V=1.015872, theta=0.0
% INFO    : Bus 5718	: V=1.02559137, theta=-37.5394888 -> V=1.022224, theta=0.0
% INFO    : Bus 5719	: V=1.01667077, theta=-30.1061248 -> V=1.0158755, theta=0.0
% INFO    : Bus 5720	: V=1.02768655, theta=-17.2023988 -> V=0.999999, theta=0.0
% INFO    : Bus 5721	: V=1.00568845, theta=-30.9474984 -> V=1.022224, theta=0.0
% INFO    : Bus 5722	: V=1.02211102, theta=-42.1673828 -> V=1.022224, theta=0.0
% INFO    : Bus 5723	: V=1.01838042, theta=-44.715818 -> V=1.022224, theta=0.0
% INFO    : Bus 5724	: V=1.05615208, theta=-6.74124242 -> V=1.05263, theta=0.0
% INFO    : Bus 5725	: V=1.02935378, theta=-15.13421 -> V=1.0158755, theta=0.0
% INFO    : Bus 5726	: V=1.03907106, theta=-13.2570379 -> V=0.999999, theta=0.0
% INFO    : Bus 5727	: V=1.03005987, theta=-29.5968156 -> V=1.015872, theta=0.0
% INFO    : Bus 5728	: V=1.02316648, theta=-26.333609 -> V=1.0000015, theta=0.0
% INFO    : Bus 5729	: V=1.01313483, theta=-20.8048099 -> V=1.015872, theta=0.0
% INFO    : Bus 5730	: V=1.01631826, theta=-18.1957009 -> V=1.015872, theta=0.0
% INFO    : Bus 5731	: V=1.01324915, theta=-31.506464 -> V=1.015872, theta=0.0
% INFO    : Bus 5732	: V=1.05191384, theta=-26.4177906 -> V=1.0000025, theta=0.0
% INFO    : Bus 5733	: V=1.05238259, theta=-18.1402854 -> V=1.0000025, theta=0.0
% INFO    : Bus 5734	: V=1.01925033, theta=-2.33813651 -> V=1.0158755, theta=0.0
% INFO    : Bus 5735	: V=1.04177191, theta=-10.8687233 -> V=0.999999, theta=0.0
% INFO    : Bus 5736	: V=1.02252157, theta=-2.43959496 -> V=1.0158755, theta=0.0
% INFO    : Bus 5737	: V=1.0100776, theta=-31.023756 -> V=1.0000025, theta=0.0
% INFO    : Bus 5738	: V=1.0389306, theta=-17.8103151 -> V=0.999999, theta=0.0
% INFO    : Bus 5739	: V=1.05261751, theta=-61.3647287 -> V=1.0079355, theta=0.0
% INFO    : Bus 5740	: V=1.02354394, theta=-51.725713 -> V=1.022224, theta=0.0
% INFO    : Bus 5741	: V=1.00771993, theta=-64.5937148 -> V=1.0079355, theta=0.0
% INFO    : Bus 5742	: V=1.02348433, theta=-14.0906621 -> V=1.015872, theta=0.0
% INFO    : Bus 5743	: V=1.06709601, theta=-17.926188 -> V=1.0000025, theta=0.0
% INFO    : Bus 5744	: V=0.940095812, theta=-8.39225951 -> V=0.9444445, theta=0.0
% INFO    : Bus 5745	: V=1.05080793, theta=-18.6532895 -> V=1.046665, theta=0.0
% INFO    : Bus 5746	: V=1.0267849, theta=-25.2081056 -> V=1.0000025, theta=0.0
% INFO    : Bus 5747	: V=0.95914039, theta=-38.2481507 -> V=1.0000025, theta=0.0
% INFO    : Bus 5748	: V=1.01546311, theta=-7.28394331 -> V=0.999999, theta=0.0
% INFO    : Bus 5749	: V=1.01899122, theta=-39.075611 -> V=1.027779, theta=0.0
% INFO    : Bus 5750	: V=1.04558505, theta=-14.33433 -> V=0.999999, theta=0.0
% INFO    : Bus 5751	: V=1.03100143, theta=-20.0978916 -> V=1.0158755, theta=0.0
% INFO    : Bus 5752	: V=1.06031384, theta=-14.98848 -> V=1.0222235, theta=0.0
% INFO    : Bus 5753	: V=1.02628602, theta=-30.3138939 -> V=1.0000025, theta=0.0
% INFO    : Bus 5754	: V=0.954790947, theta=-7.87572893 -> V=0.9444445, theta=0.0
% INFO    : Bus 5755	: V=1.03546252, theta=-26.7047894 -> V=1.0000025, theta=0.0
% INFO    : Bus 5756	: V=1.04047463, theta=-26.2700449 -> V=1.0000025, theta=0.0
% INFO    : Bus 5757	: V=1.02416174, theta=-29.985316 -> V=1.0000025, theta=0.0
% INFO    : Bus 5758	: V=1.04394807, theta=-18.3985235 -> V=1.0000025, theta=0.0
% INFO    : Bus 5759	: V=1.05593309, theta=-43.1155311 -> V=1.04444, theta=0.0
% INFO    : Bus 5760	: V=1.01270529, theta=-31.7758776 -> V=1.0000005, theta=0.0
% INFO    : Bus 5761	: V=1.0151355, theta=-30.4695152 -> V=1.0000025, theta=0.0
% INFO    : Bus 5762	: V=1.05098287, theta=-24.0599875 -> V=1.022224, theta=0.0
% INFO    : Bus 5763	: V=1.025769, theta=-11.0616841 -> V=1.0158755, theta=0.0
% INFO    : Bus 5764	: V=1.03162662, theta=-46.2946748 -> V=1.0079355, theta=0.0
% INFO    : Bus 5765	: V=1.03914377, theta=-28.6535774 -> V=1.022224, theta=0.0
% INFO    : Bus 5766	: V=1.06688948, theta=-6.32492107 -> V=0.9888895, theta=0.0
% INFO    : Bus 5767	: V=1.02979861, theta=-10.1569119 -> V=1.0158755, theta=0.0
% INFO    : Bus 5768	: V=1.00489745, theta=-55.0977935 -> V=1.0079355, theta=0.0
% INFO    : Bus 5769	: V=1.01760443, theta=-37.206946 -> V=1.015872, theta=0.0
% INFO    : Bus 5770	: V=1.03305219, theta=-34.4505193 -> V=1.015872, theta=0.0
% INFO    : Bus 5771	: V=1.01391528, theta=-25.9154821 -> V=0.999999, theta=0.0
% INFO    : Bus 5772	: V=0.977334271, theta=-34.7110092 -> V=1.0000005, theta=0.0
% INFO    : Bus 5773	: V=0.987653369, theta=-33.9802418 -> V=1.0000005, theta=0.0
% INFO    : Bus 5774	: V=1.02880003, theta=-61.6661832 -> V=1.0079355, theta=0.0
% INFO    : Bus 5775	: V=1.0374486, theta=-24.3511821 -> V=1.0000025, theta=0.0
% INFO    : Bus 5776	: V=1.02573557, theta=-37.2315191 -> V=1.027779, theta=0.0
% INFO    : Bus 5777	: V=1.00733179, theta=-18.9781502 -> V=1.0158755, theta=0.0
% INFO    : Bus 5778	: V=1.02565907, theta=-8.26717712 -> V=1.0000015, theta=0.0
% INFO    : Bus 5779	: V=1.02557637, theta=-22.4208389 -> V=1.015872, theta=0.0
% INFO    : Bus 5780	: V=1.02562526, theta=-40.8315206 -> V=1.022224, theta=0.0
% INFO    : Bus 5781	: V=0.999507066, theta=-21.0307769 -> V=0.999999, theta=0.0
% INFO    : Bus 5782	: V=1.07402152, theta=-17.2864497 -> V=1.046665, theta=0.0
% INFO    : Bus 5783	: V=1.05297504, theta=-15.1657432 -> V=1.004279, theta=0.0
% INFO    : Bus 5784	: V=1.02302585, theta=-8.39621376 -> V=1.0000015, theta=0.0
% INFO    : Bus 5785	: V=1.04182592, theta=-8.95199058 -> V=1.0000015, theta=0.0
% INFO    : Bus 5786	: V=1.02322876, theta=-52.8401961 -> V=1.022224, theta=0.0
% INFO    : Bus 5787	: V=1.07381071, theta=-15.736242 -> V=1.046665, theta=0.0
% INFO    : Bus 5788	: V=1.06569383, theta=-18.4106744 -> V=1.005194, theta=0.0
% INFO    : Bus 5789	: V=1.02123999, theta=-18.6543618 -> V=1.015872, theta=0.0
% INFO    : Bus 5790	: V=1.06220554, theta=-12.9434545 -> V=0.999999, theta=0.0
% INFO    : Bus 5791	: V=1.03139589, theta=-47.4779339 -> V=1.022224, theta=0.0
% INFO    : Bus 5792	: V=1.00085015, theta=-36.8401997 -> V=1.0000005, theta=0.0
% INFO    : Bus 5793	: V=1.00746002, theta=-14.0840053 -> V=1.015872, theta=0.0
% INFO    : Bus 5794	: V=0.955337585, theta=-7.8348188 -> V=0.9444445, theta=0.0
% INFO    : Bus 5795	: V=0.982123191, theta=-6.0778151 -> V=0.9444445, theta=0.0
% INFO    : Bus 5796	: V=1.0442989, theta=-15.2755614 -> V=0.999999, theta=0.0
% INFO    : Bus 5797	: V=1.03774167, theta=-15.4776453 -> V=0.999999, theta=0.0
% INFO    : Bus 5798	: V=1.0103184, theta=-34.8868848 -> V=1.022224, theta=0.0
% INFO    : Bus 5799	: V=1.04321592, theta=-28.6692049 -> V=1.022224, theta=0.0
% INFO    : Bus 5800	: V=1.04791044, theta=-50.4561045 -> V=1.022224, theta=0.0
% INFO    : Bus 5801	: V=1.04010564, theta=-39.595527 -> V=1.027779, theta=0.0
% INFO    : Bus 5802	: V=1.02154753, theta=-17.9645941 -> V=1.015872, theta=0.0
% INFO    : Bus 5803	: V=1.02232171, theta=-18.3028662 -> V=1.015872, theta=0.0
% INFO    : Bus 5804	: V=1.03329457, theta=-26.3786148 -> V=1.0000025, theta=0.0
% INFO    : Bus 5805	: V=1.05897339, theta=-20.0257919 -> V=0.9888895, theta=0.0
% INFO    : Bus 5806	: V=1.04039482, theta=-20.373214 -> V=1.0000025, theta=0.0
% INFO    : Bus 5807	: V=1.04068459, theta=-20.3921302 -> V=1.0000025, theta=0.0
% INFO    : Bus 5808	: V=1.00629238, theta=-14.6284678 -> V=0.999999, theta=0.0
% INFO    : Bus 5809	: V=1.00437814, theta=-48.1166819 -> V=1.022224, theta=0.0
% INFO    : Bus 5810	: V=0.936889778, theta=-10.1968036 -> V=0.9444445, theta=0.0
% INFO    : Bus 5811	: V=1.05214064, theta=-17.2347174 -> V=1.001634, theta=0.0
% INFO    : Bus 5812	: V=1.0641614, theta=-21.5833915 -> V=1.0000025, theta=0.0
% INFO    : Bus 5813	: V=1.05320479, theta=-54.4960971 -> V=1.04444, theta=0.0
% INFO    : Bus 5814	: V=1.02339632, theta=-42.0711994 -> V=1.022224, theta=0.0
% INFO    : Bus 5815	: V=1.02965829, theta=-45.8010988 -> V=1.022224, theta=0.0
% INFO    : Bus 5816	: V=1.02110588, theta=-13.7095872 -> V=1.015872, theta=0.0
% INFO    : Bus 5817	: V=1.05386918, theta=-17.4818714 -> V=0.9933315, theta=0.0
% INFO    : Bus 5818	: V=1.03103481, theta=-30.4196441 -> V=1.0000025, theta=0.0
% INFO    : Bus 5819	: V=1.02511968, theta=-23.6653297 -> V=1.022224, theta=0.0
% INFO    : Bus 5820	: V=1.05584645, theta=-19.6176004 -> V=1.0000025, theta=0.0
% INFO    : Bus 5821	: V=0.99756777, theta=-14.2905789 -> V=1.0158755, theta=0.0
% INFO    : Bus 5822	: V=1.05170544, theta=-11.2287111 -> V=1.072285, theta=0.0
% INFO    : Bus 5823	: V=1.05194084, theta=-24.8659987 -> V=1.0000025, theta=0.0
% INFO    : Bus 5824	: V=1.05145236, theta=-24.8226913 -> V=1.0000025, theta=0.0
% INFO    : Bus 5825	: V=1.01185056, theta=-17.3800926 -> V=1.0079355, theta=0.0
% INFO    : Bus 5826	: V=1.01939435, theta=-18.7130694 -> V=1.015872, theta=0.0
% INFO    : Bus 5827	: V=0.972509304, theta=-19.7920636 -> V=1.015872, theta=0.0
% INFO    : Bus 5828	: V=1.03029296, theta=-29.5769327 -> V=1.046665, theta=0.0
% INFO    : Bus 5829	: V=1.01266684, theta=-13.6481554 -> V=0.999999, theta=0.0
% INFO    : Bus 5830	: V=1.01002889, theta=-27.2783142 -> V=1.0000025, theta=0.0
% INFO    : Bus 5831	: V=1.02748798, theta=-17.6746366 -> V=0.999999, theta=0.0
% INFO    : Bus 5832	: V=1.0395521, theta=-10.5844557 -> V=0.999999, theta=0.0
% INFO    : Bus 5833	: V=1.04465231, theta=-27.4744887 -> V=1.0000025, theta=0.0
% INFO    : Bus 5834	: V=1.04423234, theta=-35.1486513 -> V=1.022224, theta=0.0
% INFO    : Bus 5835	: V=0.998844426, theta=-31.1860845 -> V=1.0000005, theta=0.0
% INFO    : Bus 5836	: V=1.02205304, theta=-10.8300632 -> V=0.999999, theta=0.0
% INFO    : Bus 5837	: V=1.02720677, theta=-35.9008006 -> V=1.027779, theta=0.0
% INFO    : Bus 5838	: V=1.02878697, theta=-17.2635696 -> V=0.999999, theta=0.0
% INFO    : Bus 5839	: V=0.957874904, theta=-9.08751575 -> V=0.9444445, theta=0.0
% INFO    : Bus 5840	: V=1.04043177, theta=-26.2691788 -> V=1.0000025, theta=0.0
% INFO    : Bus 5841	: V=1.01865704, theta=-32.9703023 -> V=1.0000005, theta=0.0
% INFO    : Bus 5842	: V=1.04191803, theta=-8.9420714 -> V=1.0000015, theta=0.0
% INFO    : Bus 5843	: V=0.974943578, theta=-24.6178344 -> V=0.999999, theta=0.0
% INFO    : Bus 5844	: V=1.03355153, theta=-28.8624769 -> V=1.022224, theta=0.0
% INFO    : Bus 5845	: V=1.0258499, theta=-25.5126205 -> V=1.0000025, theta=0.0
% INFO    : Bus 5846	: V=1.02814875, theta=-25.4315439 -> V=1.0000025, theta=0.0
% INFO    : Bus 5847	: V=1.00609758, theta=-21.1404656 -> V=1.0000025, theta=0.0
% INFO    : Bus 5848	: V=1.04704013, theta=-6.22925445 -> V=1.0111115, theta=0.0
% INFO    : Bus 5849	: V=0.99847424, theta=-34.8943031 -> V=1.0000005, theta=0.0
% INFO    : Bus 5850	: V=1.04634306, theta=-19.5080607 -> V=0.9933315, theta=0.0
% INFO    : Bus 5851	: V=1.03942015, theta=-32.2709358 -> V=1.027779, theta=0.0
% INFO    : Bus 5852	: V=1.03749864, theta=-31.5837575 -> V=1.027779, theta=0.0
% INFO    : Bus 5853	: V=1.02715142, theta=-21.8823824 -> V=0.999999, theta=0.0
% INFO    : Bus 5854	: V=1.01998283, theta=-43.1725106 -> V=1.022224, theta=0.0
% INFO    : Bus 5855	: V=1.0280394, theta=-4.75581942 -> V=0.975, theta=0.0
% INFO    : Bus 5856	: V=1.0423448, theta=-7.59792301 -> V=0.975, theta=0.0
% INFO    : Bus 5857	: V=1.03630162, theta=5.87891147 -> V=0.975, theta=0.0
% INFO    : Bus 5858	: V=1.03627011, theta=5.87714915 -> V=0.975, theta=0.0
% INFO    : Bus 5859	: V=1.08000152, theta=10.6356447 -> V=0.975, theta=0.0
% INFO    : Bus 5860	: V=1.06814308, theta=-1.8663645 -> V=0.975, theta=0.0
% INFO    : Bus 5861	: V=1.05399251, theta=0.115373769 -> V=0.975, theta=0.0
% INFO    : Bus 5862	: V=1.09693069, theta=5.98376416 -> V=0.975, theta=0.0
% INFO    : Bus 5863	: V=1.02958533, theta=-17.3520265 -> V=0.975, theta=0.0
% INFO    : Bus 5864	: V=1.10827866, theta=1.92270883 -> V=0.975, theta=0.0
% INFO    : Bus 5865	: V=1.10740223, theta=-5.20989745 -> V=0.975, theta=0.0
% INFO    : Bus 5866	: V=1.03595195, theta=-6.74856743 -> V=0.975, theta=0.0
% INFO    : Bus 5867	: V=1.03709875, theta=-3.54140035 -> V=0.975, theta=0.0
% INFO    : Bus 5868	: V=1.02863276, theta=-4.31930226 -> V=0.975, theta=0.0
% INFO    : Bus 5869	: V=1.02849316, theta=-4.3564536 -> V=0.975, theta=0.0
% INFO    : Bus 5870	: V=1.10872055, theta=-1.16723029 -> V=0.975, theta=0.0
% INFO    : Bus 5871	: V=1.05368261, theta=-22.9253545 -> V=0.975, theta=0.0
% INFO    : Bus 5872	: V=1.04491271, theta=-30.7289918 -> V=0.975, theta=0.0
% INFO    : Bus 5873	: V=1.04010179, theta=-29.5962834 -> V=0.975, theta=0.0
% INFO    : Bus 5874	: V=1.07721886, theta=-18.702909 -> V=0.975, theta=0.0
% INFO    : Bus 5875	: V=1.06627135, theta=-33.3350341 -> V=0.975, theta=0.0
% INFO    : Bus 5876	: V=1.06163981, theta=-9.09195724 -> V=0.975, theta=0.0
% INFO    : Bus 5877	: V=1.07118866, theta=-25.2146544 -> V=0.975, theta=0.0
% INFO    : Bus 5878	: V=1.07811711, theta=-19.3399489 -> V=0.975, theta=0.0
% INFO    : Bus 5879	: V=1.0398784, theta=-16.5235581 -> V=0.975, theta=0.0
% INFO    : Bus 5880	: V=1.08048134, theta=-21.3183827 -> V=0.975, theta=0.0
% INFO    : Bus 5881	: V=1.07047184, theta=-19.4323337 -> V=0.975, theta=0.0
% INFO    : Bus 5882	: V=1.05571771, theta=-56.6678866 -> V=0.975, theta=0.0
% INFO    : Bus 5883	: V=1.06901901, theta=-3.48376504 -> V=0.975, theta=0.0
% INFO    : Bus 5884	: V=1.04644036, theta=-34.1438372 -> V=0.975, theta=0.0
% INFO    : Bus 5885	: V=1.07342858, theta=-19.0655324 -> V=0.975, theta=0.0
% INFO    : Bus 5886	: V=1.04909996, theta=-9.48542795 -> V=0.975, theta=0.0
% INFO    : Bus 5887	: V=1.07610583, theta=-21.8216588 -> V=0.975, theta=0.0
% INFO    : Bus 5888	: V=1.04212525, theta=-24.7810343 -> V=0.975, theta=0.0
% INFO    : Bus 5889	: V=1.02335278, theta=-32.4835281 -> V=0.975, theta=0.0
% INFO    : Bus 5890	: V=1.06109412, theta=-36.8163204 -> V=0.975, theta=0.0
% INFO    : Bus 5891	: V=1.08610971, theta=-13.8796715 -> V=0.975, theta=0.0
% INFO    : Bus 5892	: V=1.03797107, theta=-31.9458913 -> V=0.975, theta=0.0
% INFO    : Bus 5893	: V=1.03415684, theta=-31.6858452 -> V=0.975, theta=0.0
% INFO    : Bus 5894	: V=1.05855527, theta=-20.3701176 -> V=0.975, theta=0.0
% INFO    : Bus 5895	: V=1.04898685, theta=-28.7324272 -> V=0.975, theta=0.0
% INFO    : Bus 5896	: V=1.05783959, theta=-16.9061985 -> V=0.975, theta=0.0
% INFO    : Bus 5897	: V=1.0689916, theta=-20.1134099 -> V=0.975, theta=0.0
% INFO    : Bus 5898	: V=1.05881673, theta=-31.5505927 -> V=0.975, theta=0.0
% INFO    : Bus 5899	: V=1.05694342, theta=-7.86459055 -> V=0.975, theta=0.0
% INFO    : Bus 5900	: V=1.03456425, theta=-35.0264483 -> V=0.975, theta=0.0
% INFO    : Bus 5901	: V=1.04545318, theta=-30.9469428 -> V=0.975, theta=0.0
% INFO    : Bus 5902	: V=1.08325109, theta=-14.9517562 -> V=0.975, theta=0.0
% INFO    : Bus 5903	: V=1.04024829, theta=-29.7025502 -> V=0.975, theta=0.0
% INFO    : Bus 5904	: V=1.0769529, theta=-18.2771462 -> V=0.975, theta=0.0
% INFO    : Bus 5905	: V=1.05635254, theta=-8.71980999 -> V=0.975, theta=0.0
% INFO    : Bus 5906	: V=1.08603348, theta=-18.5970239 -> V=0.975, theta=0.0
% INFO    : Bus 5907	: V=1.06664967, theta=-18.343179 -> V=0.975, theta=0.0
% INFO    : Bus 5908	: V=1.03906127, theta=-22.8698156 -> V=0.975, theta=0.0
% INFO    : Bus 5909	: V=1.05389863, theta=-55.3930155 -> V=0.975, theta=0.0
% INFO    : Bus 5910	: V=1.06838864, theta=-3.62768101 -> V=0.975, theta=0.0
% INFO    : Bus 5911	: V=1.05294575, theta=-33.2996584 -> V=0.975, theta=0.0
% INFO    : Bus 5912	: V=1.0464413, theta=-9.24354242 -> V=0.975, theta=0.0
% INFO    : Bus 5913	: V=1.06530862, theta=-29.976649 -> V=0.975, theta=0.0
% INFO    : Bus 5914	: V=1.07613359, theta=-21.6816943 -> V=0.975, theta=0.0
% INFO    : Bus 5915	: V=1.04257237, theta=-25.0215838 -> V=0.975, theta=0.0
% INFO    : Bus 5916	: V=1.03854369, theta=-31.7708393 -> V=0.975, theta=0.0
% INFO    : Bus 5917	: V=1.08620245, theta=-13.8259335 -> V=0.975, theta=0.0
% INFO    : Bus 5918	: V=1.0354502, theta=-31.6775329 -> V=0.975, theta=0.0
% INFO    : Bus 5919	: V=1.05811834, theta=-16.6940702 -> V=0.975, theta=0.0
% INFO    : Bus 5920	: V=1.06973443, theta=-21.8335691 -> V=0.975, theta=0.0
% INFO    : Bus 5921	: V=1.05879178, theta=-31.5800378 -> V=0.975, theta=0.0
% INFO    : Bus 5922	: V=1.06187745, theta=-30.6643955 -> V=0.975, theta=0.0
% INFO    : Bus 5923	: V=1.05306156, theta=-7.04237839 -> V=0.975, theta=0.0
% INFO    : Bus 5924	: V=1.05343289, theta=-22.9812235 -> V=0.975, theta=0.0
% INFO    : Bus 5925	: V=1.06679047, theta=-34.9546594 -> V=0.975, theta=0.0
% INFO    : Bus 5926	: V=1.05120097, theta=-15.4271257 -> V=0.975, theta=0.0
% INFO    : Bus 5927	: V=1.07037164, theta=-34.4444015 -> V=0.975, theta=0.0
% INFO    : Bus 5928	: V=1.02967398, theta=-24.8005373 -> V=0.975, theta=0.0
% INFO    : Bus 5929	: V=1.04270859, theta=-29.8429159 -> V=0.975, theta=0.0
% INFO    : Bus 5930	: V=1.03949126, theta=-34.9974053 -> V=0.975, theta=0.0
% INFO    : Bus 5931	: V=1.04099392, theta=-24.4020438 -> V=0.975, theta=0.0
% INFO    : Bus 5932	: V=1.10047386, theta=-19.1744103 -> V=0.975, theta=0.0
% INFO    : Bus 5933	: V=1.07096012, theta=-10.1615209 -> V=0.975, theta=0.0
% INFO    : Bus 5934	: V=1.05255915, theta=-32.94691 -> V=0.975, theta=0.0
% INFO    : Bus 5935	: V=1.06224846, theta=-30.7517448 -> V=0.975, theta=0.0
% INFO    : Bus 5936	: V=1.0237601, theta=-32.6813962 -> V=0.975, theta=0.0
% INFO    : Bus 5937	: V=1.06134238, theta=-32.5541555 -> V=0.975, theta=0.0
% INFO    : Bus 5938	: V=1.08249945, theta=-6.96421944 -> V=0.975, theta=0.0
% INFO    : Bus 5939	: V=1.06418461, theta=-32.6720285 -> V=0.975, theta=0.0
% INFO    : Bus 5940	: V=1.04600286, theta=-31.1738224 -> V=0.975, theta=0.0
% INFO    : Bus 5941	: V=1.06845623, theta=-33.7983176 -> V=0.975, theta=0.0
% INFO    : Bus 5942	: V=1.0628797, theta=-43.4356111 -> V=0.975, theta=0.0
% INFO    : Bus 5943	: V=1.05111472, theta=-34.5125591 -> V=0.975, theta=0.0
% INFO    : Bus 5944	: V=1.04638312, theta=-34.2106585 -> V=0.975, theta=0.0
% INFO    : Bus 5945	: V=1.06239899, theta=-30.8297135 -> V=0.975, theta=0.0
% INFO    : Bus 5946	: V=1.04470316, theta=-31.7262737 -> V=0.975, theta=0.0
% INFO    : Bus 5947	: V=1.08097781, theta=-7.38875716 -> V=0.975, theta=0.0
% INFO    : Bus 5948	: V=1.06400368, theta=-32.6695463 -> V=0.975, theta=0.0
% INFO    : Bus 5949	: V=1.05971544, theta=-32.1145387 -> V=0.975, theta=0.0
% INFO    : Bus 5950	: V=1.05969062, theta=-29.702115 -> V=0.975, theta=0.0
% INFO    : Bus 5951	: V=1.06639156, theta=-33.5894928 -> V=0.975, theta=0.0
% INFO    : Bus 5952	: V=1.0935766, theta=-13.8034653 -> V=0.975, theta=0.0
% INFO    : Bus 5953	: V=1.06316694, theta=-43.121213 -> V=0.975, theta=0.0
% INFO    : Bus 5954	: V=1.0677428, theta=-16.5276452 -> V=0.975, theta=0.0
% INFO    : Bus 5955	: V=1.06092132, theta=-32.6950819 -> V=0.975, theta=0.0
% INFO    : Bus 5956	: V=1.04881953, theta=-29.6119438 -> V=0.975, theta=0.0
% INFO    : Bus 5957	: V=1.06897577, theta=-0.581720947 -> V=0.975, theta=0.0
% INFO    : Bus 5958	: V=1.11127807, theta=0.260983312 -> V=0.975, theta=0.0
% INFO    : Bus 5959	: V=1.12522695, theta=4.34483154 -> V=0.975, theta=0.0
% INFO    : Bus 5960	: V=1.048966, theta=-38.5266686 -> V=0.975, theta=0.0
% INFO    : Bus 5961	: V=1.05827909, theta=-5.71862668 -> V=0.975, theta=0.0
% INFO    : Bus 5962	: V=1.103, theta=2.70431735 -> V=0.975, theta=0.0
% INFO    : Bus 5963	: V=1.10463304, theta=-2.23160652 -> V=0.975, theta=0.0
% INFO    : Bus 5964	: V=1.06782556, theta=-0.203170883 -> V=0.975, theta=0.0
% INFO    : Bus 5965	: V=1.13890911, theta=1.8304933 -> V=0.975, theta=0.0
% INFO    : Bus 5966	: V=1.08798662, theta=1.34849153 -> V=0.975, theta=0.0
% INFO    : Bus 5967	: V=1.03988524, theta=-10.8160527 -> V=0.975, theta=0.0
% INFO    : Bus 5968	: V=1.0667817, theta=-6.72129622 -> V=0.975, theta=0.0
% INFO    : Bus 5969	: V=1.10417067, theta=-2.34459829 -> V=0.975, theta=0.0
% INFO    : Bus 5970	: V=1.0884348, theta=-13.1134725 -> V=0.975, theta=0.0
% INFO    : Bus 5971	: V=1.09922086, theta=2.77844875 -> V=0.975, theta=0.0
% INFO    : Bus 5972	: V=1.122, theta=4.66243894 -> V=0.975, theta=0.0
% INFO    : Bus 5973	: V=1.08646634, theta=-8.30423733 -> V=0.975, theta=0.0
% INFO    : Bus 5974	: V=1.09305687, theta=-4.07712473 -> V=0.975, theta=0.0
% INFO    : Bus 5975	: V=1.082, theta=-5.63527376 -> V=0.975, theta=0.0
% INFO    : Bus 5976	: V=1.06962729, theta=-10.447042 -> V=0.975, theta=0.0
% INFO    : Bus 5977	: V=1.09036985, theta=-4.01102106 -> V=0.975, theta=0.0
% INFO    : Bus 5978	: V=1.10367962, theta=-4.70902167 -> V=0.975, theta=0.0
% INFO    : Bus 5979	: V=1.09876364, theta=-17.3512986 -> V=0.975, theta=0.0
% INFO    : Bus 5980	: V=1.0211363, theta=-11.24677 -> V=0.975, theta=0.0
% INFO    : Bus 5981	: V=1.08470318, theta=-9.32861746 -> V=0.975, theta=0.0
% INFO    : Bus 5982	: V=1.09417665, theta=-0.295492908 -> V=0.975, theta=0.0
% INFO    : Bus 5983	: V=1.07270034, theta=-7.64054161 -> V=0.975, theta=0.0
% INFO    : Bus 5984	: V=1.06689369, theta=-8.49295642 -> V=0.975, theta=0.0
% INFO    : Bus 5985	: V=1.08410871, theta=-3.71286112 -> V=0.975, theta=0.0
% INFO    : Bus 5986	: V=1.0594716, theta=-4.37803894 -> V=0.975, theta=0.0
% INFO    : Bus 5987	: V=1.11132901, theta=-4.47628079 -> V=0.975, theta=0.0
% INFO    : Bus 5988	: V=1.057, theta=5.75142583 -> V=0.975, theta=0.0
% INFO    : Bus 5989	: V=1.08170771, theta=-8.32996695 -> V=0.975, theta=0.0
% INFO    : Bus 5990	: V=1.09161864, theta=-14.2980564 -> V=0.975, theta=0.0
% INFO    : Bus 5991	: V=1.05767599, theta=5.02893014 -> V=0.975, theta=0.0
% INFO    : Bus 5992	: V=1.10229433, theta=-3.15997866 -> V=0.975, theta=0.0
% INFO    : Bus 5993	: V=1.02750778, theta=-4.69118614 -> V=0.975, theta=0.0
% INFO    : Bus 5994	: V=1.06903556, theta=1.40670434 -> V=0.975, theta=0.0
% INFO    : Bus 5995	: V=1.05844861, theta=-4.13021735 -> V=0.975, theta=0.0
% INFO    : Bus 5996	: V=1.09213156, theta=-13.7928063 -> V=0.975, theta=0.0
% INFO    : Bus 5997	: V=1.08775194, theta=6.00568729 -> V=0.975, theta=0.0
% INFO    : Bus 5998	: V=1.09173485, theta=-12.8018211 -> V=0.975, theta=0.0
% INFO    : Bus 5999	: V=0.999529095, theta=-24.6558027 -> V=0.975, theta=0.0
% INFO    : Bus 6000	: V=1.00019483, theta=-37.6053602 -> V=0.975, theta=0.0
% INFO    : Bus 6001	: V=1.06746551, theta=-10.5949844 -> V=0.975, theta=0.0
% INFO    : Bus 6002	: V=1.09, theta=-5.19306909 -> V=0.975, theta=0.0
% INFO    : Bus 6003	: V=0.993, theta=2.95210888 -> V=0.975, theta=0.0
% INFO    : Bus 6004	: V=1.05966922, theta=-7.22038123 -> V=0.975, theta=0.0
% INFO    : Bus 6005	: V=1.08157047, theta=-7.9500034 -> V=0.975, theta=0.0
% INFO    : Bus 6006	: V=1.068, theta=-8.92020419 -> V=0.975, theta=0.0
% INFO    : Bus 6007	: V=1.08956562, theta=-13.4859021 -> V=0.975, theta=0.0
% INFO    : Bus 6008	: V=1.06273332, theta=-6.99039973 -> V=0.975, theta=0.0
% INFO    : Bus 6009	: V=1.069, theta=1.49110721 -> V=0.975, theta=0.0
% INFO    : Bus 6010	: V=1.069, theta=1.45540284 -> V=0.975, theta=0.0
% INFO    : Bus 6011	: V=1.07031627, theta=-0.0680519237 -> V=0.975, theta=0.0
% INFO    : Bus 6012	: V=1.04973424, theta=-1.8826155 -> V=0.975, theta=0.0
% INFO    : Bus 6013	: V=1.06540739, theta=-10.5198636 -> V=0.975, theta=0.0
% INFO    : Bus 6014	: V=1.142, theta=4.97016054 -> V=0.975, theta=0.0
% INFO    : Bus 6015	: V=0.998149268, theta=-16.7295866 -> V=0.975, theta=0.0
% INFO    : Bus 6016	: V=1.03501537, theta=-4.06067591 -> V=0.975, theta=0.0
% INFO    : Bus 6017	: V=1.08633815, theta=-5.90667295 -> V=0.975, theta=0.0
% INFO    : Bus 6018	: V=1.07782125, theta=-11.5995915 -> V=0.975, theta=0.0
% INFO    : Bus 6019	: V=1.08585275, theta=7.40088207 -> V=0.975, theta=0.0
% INFO    : Bus 6020	: V=1.0860936, theta=7.41755642 -> V=0.975, theta=0.0
% INFO    : Bus 6021	: V=1.073, theta=-0.246126399 -> V=0.975, theta=0.0
% INFO    : Bus 6022	: V=1.07148635, theta=-0.736816059 -> V=0.975, theta=0.0
% INFO    : Bus 6023	: V=1.101, theta=3.31073805 -> V=0.975, theta=0.0
% INFO    : Bus 6024	: V=1.09967981, theta=2.70375261 -> V=0.975, theta=0.0
% INFO    : Bus 6025	: V=1.03449263, theta=5.70495891 -> V=0.975, theta=0.0
% INFO    : Bus 6026	: V=1.023, theta=13.5011667 -> V=0.975, theta=0.0
% INFO    : Bus 6027	: V=1.05739773, theta=5.83208818 -> V=0.975, theta=0.0
% INFO    : Bus 6028	: V=1.05780847, theta=4.34979295 -> V=0.975, theta=0.0
% INFO    : Bus 6029	: V=1.039, theta=-1.46875669 -> V=0.975, theta=0.0
% INFO    : Bus 6030	: V=1.0609138, theta=5.37556335 -> V=0.975, theta=0.0
% INFO    : Bus 6031	: V=1.02556213, theta=-5.06087123 -> V=0.975, theta=0.0
% INFO    : Bus 6032	: V=1.04436582, theta=-7.68432468 -> V=0.975, theta=0.0
% INFO    : Bus 6033	: V=1.07645613, theta=-5.57050346 -> V=0.975, theta=0.0
% INFO    : Bus 6034	: V=1.0860446, theta=-4.12906407 -> V=0.975, theta=0.0
% INFO    : Bus 6035	: V=1.1023091, theta=-0.725599586 -> V=0.975, theta=0.0
% INFO    : Bus 6036	: V=1.04858667, theta=4.51338384 -> V=0.975, theta=0.0
% INFO    : Bus 6037	: V=1.07020036, theta=-1.49685539 -> V=0.975, theta=0.0
% INFO    : Bus 6038	: V=1.10603616, theta=0.359874357 -> V=0.975, theta=0.0
% INFO    : Bus 6039	: V=1.04818925, theta=4.2307942 -> V=0.975, theta=0.0
% INFO    : Bus 6040	: V=1.037, theta=6.03606886 -> V=0.975, theta=0.0
% INFO    : Bus 6041	: V=1.09423939, theta=5.62104051 -> V=0.975, theta=0.0
% INFO    : Bus 6042	: V=1.09492908, theta=5.23371645 -> V=0.975, theta=0.0
% INFO    : Bus 6043	: V=1.0678575, theta=7.34906696 -> V=0.975, theta=0.0
% INFO    : Bus 6044	: V=1.03069239, theta=-17.2030931 -> V=0.975, theta=0.0
% INFO    : Bus 6045	: V=1.12560032, theta=4.17517732 -> V=0.975, theta=0.0
% INFO    : Bus 6046	: V=1.06231582, theta=-2.62862815 -> V=0.975, theta=0.0
% INFO    : Bus 6047	: V=1.08783771, theta=0.166918578 -> V=0.975, theta=0.0
% INFO    : Bus 6048	: V=1.05931976, theta=-8.51592714 -> V=0.975, theta=0.0
% INFO    : Bus 6049	: V=1.11048188, theta=-5.72866578 -> V=0.975, theta=0.0
% INFO    : Bus 6050	: V=1.09995997, theta=-10.8538716 -> V=0.975, theta=0.0
% INFO    : Bus 6051	: V=1.06501807, theta=-10.18193 -> V=0.975, theta=0.0
% INFO    : Bus 6052	: V=1.01894458, theta=-11.1543637 -> V=0.975, theta=0.0
% INFO    : Bus 6053	: V=1.09315253, theta=-2.66251974 -> V=0.975, theta=0.0
% INFO    : Bus 6054	: V=1.11096707, theta=0.398510927 -> V=0.975, theta=0.0
% INFO    : Bus 6055	: V=1.051, theta=4.80642785 -> V=0.975, theta=0.0
% INFO    : Bus 6056	: V=1.10146687, theta=-11.0152375 -> V=0.975, theta=0.0
% INFO    : Bus 6057	: V=1.09190406, theta=-5.16783327 -> V=0.975, theta=0.0
% INFO    : Bus 6058	: V=1.097, theta=-1.54039917 -> V=0.975, theta=0.0
% INFO    : Bus 6059	: V=1.06142433, theta=-9.01606252 -> V=0.975, theta=0.0
% INFO    : Bus 6060	: V=1.06142433, theta=-9.01606252 -> V=0.975, theta=0.0
% INFO    : Bus 6061	: V=1.06276751, theta=-9.60967916 -> V=0.975, theta=0.0
% INFO    : Bus 6062	: V=1.06385079, theta=-9.81156059 -> V=0.975, theta=0.0
% INFO    : Bus 6063	: V=1.03505399, theta=-4.0742079 -> V=0.975, theta=0.0
% INFO    : Bus 6064	: V=1.03488744, theta=-4.07222823 -> V=0.975, theta=0.0
% INFO    : Bus 6065	: V=1.0887101, theta=3.41698318 -> V=0.975, theta=0.0
% INFO    : Bus 6066	: V=1.063, theta=0.344452642 -> V=0.975, theta=0.0
% INFO    : Bus 6067	: V=1.12852986, theta=3.57103843 -> V=0.975, theta=0.0
% INFO    : Bus 6068	: V=1.12850011, theta=3.57826162 -> V=0.975, theta=0.0
% INFO    : Bus 6069	: V=1.12504771, theta=3.90749962 -> V=0.975, theta=0.0
% INFO    : Bus 6070	: V=1.06060925, theta=9.50617771 -> V=0.975, theta=0.0
% INFO    : Bus 6071	: V=1.07128082, theta=9.61387023 -> V=0.975, theta=0.0
% INFO    : Bus 6072	: V=1.08683086, theta=-6.63718702 -> V=0.975, theta=0.0
% INFO    : Bus 6073	: V=1.09031465, theta=2.48909384 -> V=0.975, theta=0.0
% INFO    : Bus 6074	: V=1.11747871, theta=3.34829926 -> V=0.975, theta=0.0
% INFO    : Bus 6075	: V=1.07119142, theta=1.35165682 -> V=0.975, theta=0.0
% INFO    : Bus 6076	: V=1.07018905, theta=-6.54724718 -> V=0.975, theta=0.0
% INFO    : Bus 6077	: V=1.07103676, theta=-4.66015969 -> V=0.975, theta=0.0
% INFO    : Bus 6078	: V=1.08177696, theta=-8.45037531 -> V=0.975, theta=0.0
% INFO    : Bus 6079	: V=1.06846873, theta=8.23181306 -> V=0.975, theta=0.0
% INFO    : Bus 6080	: V=1.10001057, theta=2.95365871 -> V=0.975, theta=0.0
% INFO    : Bus 6081	: V=1.05846177, theta=-4.7122068 -> V=0.975, theta=0.0
% INFO    : Bus 6082	: V=1.10144326, theta=-3.34238548 -> V=0.975, theta=0.0
% INFO    : Bus 6083	: V=1.12546747, theta=4.39711961 -> V=0.975, theta=0.0
% INFO    : Bus 6084	: V=1.10072464, theta=4.56055229 -> V=0.975, theta=0.0
% INFO    : Bus 6085	: V=1.06173855, theta=-1.79151589 -> V=0.975, theta=0.0
% INFO    : Bus 6086	: V=1.10989305, theta=-0.0745086719 -> V=0.975, theta=0.0
% INFO    : Bus 6087	: V=1.02551022, theta=-13.3255855 -> V=0.975, theta=0.0
% INFO    : Bus 6088	: V=1.104, theta=4.9116747 -> V=0.975, theta=0.0
% INFO    : Bus 6089	: V=1.10364551, theta=4.87467631 -> V=0.975, theta=0.0
% INFO    : Bus 6090	: V=1.08, theta=10.6353008 -> V=0.975, theta=0.0
% INFO    : Bus 6091	: V=1.05395829, theta=5.5326126 -> V=0.975, theta=0.0
% INFO    : Bus 6092	: V=1.098, theta=-5.68913387 -> V=0.975, theta=0.0
% INFO    : Bus 6093	: V=1.071, theta=-3.71879472 -> V=0.975, theta=0.0
% INFO    : Bus 6094	: V=1.096, theta=-0.459656199 -> V=0.975, theta=0.0
% INFO    : Bus 6095	: V=1.109, theta=-2.17173891 -> V=0.975, theta=0.0
% INFO    : Bus 6096	: V=1.06811623, theta=-1.87244784 -> V=0.975, theta=0.0
% INFO    : Bus 6097	: V=1.09685545, theta=-5.96561396 -> V=0.975, theta=0.0
% INFO    : Bus 6098	: V=1.07380181, theta=-6.32778391 -> V=0.975, theta=0.0
% INFO    : Bus 6099	: V=1.07512753, theta=-4.26944112 -> V=0.975, theta=0.0
% INFO    : Bus 6100	: V=1.09462878, theta=-0.513435588 -> V=0.975, theta=0.0
% INFO    : Bus 6101	: V=1.10662719, theta=-2.32740835 -> V=0.975, theta=0.0
% INFO    : Bus 6102	: V=1.09503414, theta=-7.44502279 -> V=0.975, theta=0.0
% INFO    : Bus 6103	: V=1.093, theta=0.352526093 -> V=0.975, theta=0.0
% INFO    : Bus 6104	: V=1.065, theta=6.95860042 -> V=0.975, theta=0.0
% INFO    : Bus 6105	: V=1.03977965, theta=-9.52547397 -> V=0.975, theta=0.0
% INFO    : Bus 6106	: V=1.06463932, theta=-9.19882659 -> V=0.975, theta=0.0
% INFO    : Bus 6107	: V=1.08920612, theta=-7.66870591 -> V=0.975, theta=0.0
% INFO    : Bus 6108	: V=1.03268316, theta=-4.19476136 -> V=0.975, theta=0.0
% INFO    : Bus 6109	: V=1.03269424, theta=-4.17785138 -> V=0.975, theta=0.0
% INFO    : Bus 6110	: V=1.05092561, theta=-0.328621454 -> V=0.975, theta=0.0
% INFO    : Bus 6111	: V=1.12565488, theta=4.49486747 -> V=0.975, theta=0.0
% INFO    : Bus 6112	: V=1.055, theta=6.41061631 -> V=0.975, theta=0.0
% INFO    : Bus 6113	: V=1.055, theta=6.09952626 -> V=0.975, theta=0.0
% INFO    : Bus 6114	: V=1.13283011, theta=5.43849072 -> V=0.975, theta=0.0
% INFO    : Bus 6115	: V=1.06829643, theta=-11.0902104 -> V=0.975, theta=0.0
% INFO    : Bus 6116	: V=1.11950646, theta=2.61017431 -> V=0.975, theta=0.0
% INFO    : Bus 6117	: V=1.115, theta=-3.95040167 -> V=0.975, theta=0.0
% INFO    : Bus 6118	: V=1.03270873, theta=-4.12007055 -> V=0.975, theta=0.0
% INFO    : Bus 6119	: V=1.07077749, theta=12.0193737 -> V=0.975, theta=0.0
% INFO    : Bus 6120	: V=1.03317079, theta=-3.52184634 -> V=0.975, theta=0.0
% INFO    : Bus 6121	: V=1.04674398, theta=2.68109354 -> V=0.975, theta=0.0
% INFO    : Bus 6122	: V=1.12245458, theta=3.22240359 -> V=0.975, theta=0.0
% INFO    : Bus 6123	: V=1.08962917, theta=-12.3825057 -> V=0.975, theta=0.0
% INFO    : Bus 6124	: V=1.03270434, theta=-3.64682777 -> V=0.975, theta=0.0
% INFO    : Bus 6125	: V=1.09850203, theta=-3.3146256 -> V=0.975, theta=0.0
% INFO    : Bus 6126	: V=1.097, theta=5.99047662 -> V=0.975, theta=0.0
% INFO    : Bus 6127	: V=1.06404902, theta=-8.86089087 -> V=0.975, theta=0.0
% INFO    : Bus 6128	: V=1.04673483, theta=-6.84844067 -> V=0.975, theta=0.0
% INFO    : Bus 6129	: V=1.06169426, theta=-9.18463298 -> V=0.975, theta=0.0
% INFO    : Bus 6130	: V=1.12683365, theta=4.20524207 -> V=0.975, theta=0.0
% INFO    : Bus 6131	: V=1.02939009, theta=-17.4309442 -> V=0.975, theta=0.0
% INFO    : Bus 6132	: V=1.057, theta=-7.48805191 -> V=0.975, theta=0.0
% INFO    : Bus 6133	: V=1.082, theta=-8.26082671 -> V=0.975, theta=0.0
% INFO    : Bus 6134	: V=1.09168781, theta=-11.4914041 -> V=0.975, theta=0.0
% INFO    : Bus 6135	: V=1.07565652, theta=1.28704221 -> V=0.975, theta=0.0
% INFO    : Bus 6136	: V=1.14293803, theta=4.08164612 -> V=0.975, theta=0.0
% INFO    : Bus 6137	: V=1.08655952, theta=5.8128973 -> V=0.975, theta=0.0
% INFO    : Bus 6138	: V=1.10839922, theta=1.91053299 -> V=0.975, theta=0.0
% INFO    : Bus 6139	: V=1.083, theta=9.53939091 -> V=0.975, theta=0.0
% INFO    : Bus 6140	: V=1.07048389, theta=-8.1700978 -> V=0.975, theta=0.0
% INFO    : Bus 6141	: V=1.09560919, theta=2.21842906 -> V=0.975, theta=0.0
% INFO    : Bus 6142	: V=1.05348426, theta=5.9822355 -> V=0.975, theta=0.0
% INFO    : Bus 6143	: V=1.07253047, theta=-0.14090258 -> V=0.975, theta=0.0
% INFO    : Bus 6144	: V=1.09135847, theta=5.52101747 -> V=0.975, theta=0.0
% INFO    : Bus 6145	: V=1.08644385, theta=-13.4659714 -> V=0.975, theta=0.0
% INFO    : Bus 6146	: V=1.09581796, theta=-2.23537203 -> V=0.975, theta=0.0
% INFO    : Bus 6147	: V=1.08532446, theta=11.3152241 -> V=0.975, theta=0.0
% INFO    : Bus 6148	: V=1.02088957, theta=-10.1104868 -> V=0.975, theta=0.0
% INFO    : Bus 6149	: V=1.07189862, theta=2.97344656 -> V=0.975, theta=0.0
% INFO    : Bus 6150	: V=1.13142959, theta=4.37341935 -> V=0.975, theta=0.0
% INFO    : Bus 6151	: V=1.10364565, theta=4.87467329 -> V=0.975, theta=0.0
% INFO    : Bus 6152	: V=1.10390491, theta=-10.4931919 -> V=0.975, theta=0.0
% INFO    : Bus 6153	: V=1.06520712, theta=-4.58592168 -> V=0.975, theta=0.0
% INFO    : Bus 6154	: V=1.08888714, theta=-4.74171169 -> V=0.975, theta=0.0
% INFO    : Bus 6155	: V=1.08439077, theta=-8.52679363 -> V=0.975, theta=0.0
% INFO    : Bus 6156	: V=1.06696969, theta=-9.5668346 -> V=0.975, theta=0.0
% INFO    : Bus 6157	: V=1.06893691, theta=-10.4930606 -> V=0.975, theta=0.0
% INFO    : Bus 6158	: V=1.12702084, theta=4.21581776 -> V=0.975, theta=0.0
% INFO    : Bus 6159	: V=1.05970591, theta=-8.63387399 -> V=0.975, theta=0.0
% INFO    : Bus 6160	: V=1.10105786, theta=-3.4813007 -> V=0.975, theta=0.0
% INFO    : Bus 6161	: V=1.10179458, theta=4.69780956 -> V=0.975, theta=0.0
% INFO    : Bus 6162	: V=1.084, theta=-11.2206758 -> V=0.975, theta=0.0
% INFO    : Bus 6163	: V=0.871226967, theta=-23.3649665 -> V=0.975, theta=0.0
% INFO    : Bus 6164	: V=1.061396, theta=-7.09342455 -> V=0.975, theta=0.0
% INFO    : Bus 6165	: V=1.088, theta=-5.27922088 -> V=0.975, theta=0.0
% INFO    : Bus 6166	: V=1.10708238, theta=-6.49126011 -> V=0.975, theta=0.0
% INFO    : Bus 6167	: V=1.10750991, theta=-8.22999784 -> V=0.975, theta=0.0
% INFO    : Bus 6168	: V=1.01951845, theta=-11.596704 -> V=0.975, theta=0.0
% INFO    : Bus 6169	: V=1.09194397, theta=-12.6252324 -> V=0.975, theta=0.0
% INFO    : Bus 6170	: V=1.03612825, theta=-6.7789934 -> V=0.975, theta=0.0
% INFO    : Bus 6171	: V=1.07060552, theta=-10.2545654 -> V=0.975, theta=0.0
% INFO    : Bus 6172	: V=1.087, theta=12.5081411 -> V=0.975, theta=0.0
% INFO    : Bus 6173	: V=1.03328084, theta=-10.4350514 -> V=0.975, theta=0.0
% INFO    : Bus 6174	: V=1.065, theta=-9.07265597 -> V=0.975, theta=0.0
% INFO    : Bus 6175	: V=1.09494601, theta=-3.87764903 -> V=0.975, theta=0.0
% INFO    : Bus 6176	: V=1.12858158, theta=4.64845489 -> V=0.975, theta=0.0
% INFO    : Bus 6177	: V=1.06165467, theta=-2.72024004 -> V=0.975, theta=0.0
% INFO    : Bus 6178	: V=1.06792201, theta=-0.184488952 -> V=0.975, theta=0.0
% INFO    : Bus 6179	: V=1.06735626, theta=0.713898878 -> V=0.975, theta=0.0
% INFO    : Bus 6180	: V=1.11890996, theta=4.00800616 -> V=0.975, theta=0.0
% INFO    : Bus 6181	: V=1.02733275, theta=-16.555765 -> V=0.975, theta=0.0
% INFO    : Bus 6182	: V=1.07625081, theta=9.498882 -> V=0.975, theta=0.0
% INFO    : Bus 6183	: V=1.02496426, theta=-8.83859306 -> V=0.975, theta=0.0
% INFO    : Bus 6184	: V=1.088, theta=-5.64968938 -> V=0.975, theta=0.0
% INFO    : Bus 6185	: V=1.10911365, theta=3.50406129 -> V=0.975, theta=0.0
% INFO    : Bus 6186	: V=1.14158312, theta=5.09294416 -> V=0.975, theta=0.0
% INFO    : Bus 6187	: V=1.07163969, theta=8.09088516 -> V=0.975, theta=0.0
% INFO    : Bus 6188	: V=1.111, theta=-4.84829804 -> V=0.975, theta=0.0
% INFO    : Bus 6189	: V=1.09566149, theta=-8.24993908 -> V=0.975, theta=0.0
% INFO    : Bus 6190	: V=1.08471638, theta=-7.19461639 -> V=0.975, theta=0.0
% INFO    : Bus 6191	: V=1.01201883, theta=-12.5932812 -> V=0.975, theta=0.0
% INFO    : Bus 6192	: V=1.02237012, theta=-18.8683772 -> V=0.975, theta=0.0
% INFO    : Bus 6193	: V=1.144, theta=7.61587609 -> V=0.975, theta=0.0
% INFO    : Bus 6194	: V=1.1050989, theta=-9.9648253 -> V=0.975, theta=0.0
% INFO    : Bus 6195	: V=1.0910845, theta=1.63844804 -> V=0.975, theta=0.0
% INFO    : Bus 6196	: V=1.106, theta=-4.14018395 -> V=0.975, theta=0.0
% INFO    : Bus 6197	: V=1.00570829, theta=-24.2528552 -> V=0.975, theta=0.0
% INFO    : Bus 6198	: V=1.008249, theta=2.40572039 -> V=0.975, theta=0.0
% INFO    : Bus 6199	: V=1.04404662, theta=3.83633929 -> V=0.975, theta=0.0
% INFO    : Bus 6200	: V=1.07113869, theta=8.61027328 -> V=0.975, theta=0.0
% INFO    : Bus 6201	: V=1.02050206, theta=12.9523232 -> V=0.975, theta=0.0
% INFO    : Bus 6202	: V=1.02050206, theta=12.9523232 -> V=0.975, theta=0.0
% INFO    : Bus 6203	: V=1.04164061, theta=-7.78935524 -> V=0.975, theta=0.0
% INFO    : Bus 6204	: V=1.17556443, theta=-21.2316625 -> V=0.996475, theta=0.0
% INFO    : Bus 6205	: V=1.0650961, theta=-9.05960037 -> V=0.975, theta=0.0
% INFO    : Bus 6206	: V=1.06758499, theta=5.79340354 -> V=0.975, theta=0.0
% INFO    : Bus 6207	: V=1.05204293, theta=5.40938223 -> V=0.975, theta=0.0
% INFO    : Bus 6208	: V=1.05464308, theta=5.99361404 -> V=0.975, theta=0.0
% INFO    : Bus 6209	: V=1.03772939, theta=-3.1012109 -> V=0.975, theta=0.0
% INFO    : Bus 6210	: V=1.05857491, theta=-8.30842868 -> V=0.975, theta=0.0
% INFO    : Bus 6211	: V=1.03488422, theta=-3.7600756 -> V=0.975, theta=0.0
% INFO    : Bus 6212	: V=1.12858697, theta=4.62800242 -> V=0.975, theta=0.0
% INFO    : Bus 6213	: V=1.06232933, theta=-2.63035837 -> V=0.975, theta=0.0
% INFO    : Bus 6214	: V=1.09266916, theta=-0.0991685456 -> V=0.975, theta=0.0
% INFO    : Bus 6215	: V=1.06368763, theta=0.234075025 -> V=0.975, theta=0.0
% INFO    : Bus 6216	: V=1.06885051, theta=-9.74124651 -> V=0.975, theta=0.0
% INFO    : Bus 6217	: V=1.10466241, theta=-1.02794346 -> V=0.975, theta=0.0
% INFO    : Bus 6218	: V=1.09, theta=-12.184343 -> V=0.975, theta=0.0
% INFO    : Bus 6219	: V=1.039, theta=5.950991 -> V=0.975, theta=0.0
% INFO    : Bus 6220	: V=1.09483556, theta=5.74058163 -> V=0.975, theta=0.0
% INFO    : Bus 6221	: V=1.066, theta=-6.56372038 -> V=0.975, theta=0.0
% INFO    : Bus 6222	: V=1.1, theta=2.07610554 -> V=0.975, theta=0.0
% INFO    : Bus 6223	: V=1.0555764, theta=1.73171762 -> V=0.975, theta=0.0
% INFO    : Bus 6224	: V=1.04658738, theta=0.220831845 -> V=0.975, theta=0.0
% INFO    : Bus 6225	: V=1.06967263, theta=-10.4938214 -> V=0.975, theta=0.0
% INFO    : Bus 6226	: V=1.067, theta=-11.0567119 -> V=0.975, theta=0.0
% INFO    : Bus 6227	: V=1.02385919, theta=-4.75529317 -> V=0.975, theta=0.0
% INFO    : Bus 6228	: V=1.02369612, theta=-4.88716526 -> V=0.975, theta=0.0
% INFO    : Bus 6229	: V=1.06562925, theta=-9.73385809 -> V=0.975, theta=0.0
% INFO    : Bus 6230	: V=1.06360538, theta=-7.61001099 -> V=0.975, theta=0.0
% INFO    : Bus 6231	: V=1.089, theta=-7.2777963 -> V=0.975, theta=0.0
% INFO    : Bus 6232	: V=1.02961843, theta=-11.4394701 -> V=0.975, theta=0.0
% INFO    : Bus 6233	: V=1.07817964, theta=-9.84846647 -> V=0.975, theta=0.0
% INFO    : Bus 6234	: V=1.03389582, theta=-16.2531242 -> V=0.975, theta=0.0
% INFO    : Bus 6235	: V=1.07259585, theta=-13.3782433 -> V=0.975, theta=0.0
% INFO    : Bus 6236	: V=1.11897999, theta=6.50719269 -> V=0.975, theta=0.0
% INFO    : Bus 6237	: V=1.1079594, theta=-1.33974105 -> V=0.975, theta=0.0
% INFO    : Bus 6238	: V=1.06541384, theta=-6.81663302 -> V=0.975, theta=0.0
% INFO    : Bus 6239	: V=1.081, theta=-11.2619674 -> V=0.975, theta=0.0
% INFO    : Bus 6240	: V=1.09823393, theta=1.74196956 -> V=0.975, theta=0.0
% INFO    : Bus 6241	: V=1.12311144, theta=1.76386123 -> V=0.975, theta=0.0
% INFO    : Bus 6242	: V=1.12624752, theta=2.24142853 -> V=0.975, theta=0.0
% INFO    : Bus 6243	: V=1.10445293, theta=0.661057097 -> V=0.975, theta=0.0
% INFO    : Bus 6244	: V=1.12324359, theta=2.34558342 -> V=0.975, theta=0.0
% INFO    : Bus 6245	: V=1.11522378, theta=2.20867678 -> V=0.975, theta=0.0
% INFO    : Bus 6246	: V=1.02802197, theta=-16.0836821 -> V=0.975, theta=0.0
% INFO    : Bus 6247	: V=1.072, theta=-10.7868238 -> V=0.975, theta=0.0
% INFO    : Bus 6248	: V=1.06143423, theta=-4.83957438 -> V=0.975, theta=0.0
% INFO    : Bus 6249	: V=1.06338337, theta=-5.38137313 -> V=0.975, theta=0.0
% INFO    : Bus 6250	: V=1.09520673, theta=2.92830727 -> V=0.975, theta=0.0
% INFO    : Bus 6251	: V=1.04040794, theta=0.870712878 -> V=0.975, theta=0.0
% INFO    : Bus 6252	: V=1.03894884, theta=-0.316876481 -> V=0.975, theta=0.0
% INFO    : Bus 6253	: V=1.06751259, theta=-1.67567231 -> V=0.975, theta=0.0
% INFO    : Bus 6254	: V=1.070639, theta=8.46365187 -> V=0.975, theta=0.0
% INFO    : Bus 6255	: V=0.971645553, theta=-5.52864435 -> V=0.975, theta=0.0
% INFO    : Bus 6256	: V=0.971645553, theta=-5.52864435 -> V=0.975, theta=0.0
% INFO    : Bus 6257	: V=1.08, theta=-20.0704767 -> V=0.975, theta=0.0
% INFO    : Bus 6258	: V=1.08, theta=-20.0704767 -> V=0.975, theta=0.0
% INFO    : Bus 6259	: V=1.084, theta=-18.4435947 -> V=0.975, theta=0.0
% INFO    : Bus 6260	: V=0.98, theta=-11.8546942 -> V=0.975, theta=0.0
% INFO    : Bus 6261	: V=0.948683439, theta=-17.7133514 -> V=0.975, theta=0.0
% INFO    : Bus 6262	: V=0.991, theta=0.992790029 -> V=0.975, theta=0.0
% INFO    : Bus 6263	: V=1.073, theta=-8.63139893 -> V=0.975, theta=0.0
% INFO    : Bus 6264	: V=1.073, theta=-8.63139893 -> V=0.975, theta=0.0
% INFO    : Bus 6265	: V=1.051, theta=-8.68662359 -> V=0.975, theta=0.0
% INFO    : Bus 6266	: V=1.051, theta=-8.68662359 -> V=0.975, theta=0.0
% INFO    : Bus 6267	: V=0.976, theta=-1.10008366 -> V=0.975, theta=0.0
% INFO    : Bus 6268	: V=0.972, theta=-3.54198637 -> V=0.975, theta=0.0
% INFO    : Bus 6269	: V=1.027, theta=0.504246296 -> V=0.975, theta=0.0
% INFO    : Bus 6270	: V=1.025, theta=-0.168716716 -> V=0.975, theta=0.0
% INFO    : Bus 6271	: V=0.948, theta=-0.264752807 -> V=0.975, theta=0.0
% INFO    : Bus 6272	: V=0.951, theta=0.232871612 -> V=0.975, theta=0.0
% INFO    : Bus 6273	: V=1.054, theta=-5.92324598 -> V=0.975, theta=0.0
% INFO    : Bus 6274	: V=1.054, theta=-5.66842612 -> V=0.975, theta=0.0
% INFO    : Bus 6275	: V=1.053, theta=-5.70001277 -> V=0.975, theta=0.0
% INFO    : Bus 6276	: V=1.049, theta=-5.87264402 -> V=0.975, theta=0.0
% INFO    : Bus 6278	: V=1.026, theta=6.69659544 -> V=0.975, theta=0.0
% INFO    : Bus 6279	: V=1.032, theta=6.60048527 -> V=0.975, theta=0.0
% INFO    : Bus 6280	: V=1.032, theta=7.05517593 -> V=0.975, theta=0.0
% INFO    : Bus 6281	: V=1.035, theta=6.67524288 -> V=0.975, theta=0.0
% INFO    : Bus 6282	: V=1.038, theta=6.57497686 -> V=0.975, theta=0.0
% INFO    : Bus 6283	: V=1.035, theta=-2.72489483 -> V=0.975, theta=0.0
% INFO    : Bus 6284	: V=1.028, theta=-2.16173245 -> V=0.975, theta=0.0
% INFO    : Bus 6285	: V=1.035, theta=-2.72489483 -> V=0.975, theta=0.0
% INFO    : Bus 6286	: V=1.028, theta=-2.16173245 -> V=0.975, theta=0.0
% INFO    : Bus 6287	: V=1.028, theta=-2.22059409 -> V=0.975, theta=0.0
% INFO    : Bus 6288	: V=1.034, theta=-13.914281 -> V=0.975, theta=0.0
% INFO    : Bus 6289	: V=1.045, theta=-8.65521831 -> V=0.975, theta=0.0
% INFO    : Bus 6290	: V=0.991, theta=-10.8257274 -> V=0.975, theta=0.0
% INFO    : Bus 6291	: V=0.995, theta=-10.8547477 -> V=0.975, theta=0.0
% INFO    : Bus 6292	: V=0.982, theta=-8.43373691 -> V=0.975, theta=0.0
% INFO    : Bus 6293	: V=0.995, theta=-5.98927202 -> V=0.975, theta=0.0
% INFO    : Bus 6294	: V=0.984, theta=-4.76817295 -> V=0.975, theta=0.0
% INFO    : Bus 6295	: V=1.004, theta=3.70708701 -> V=0.975, theta=0.0
% INFO    : Bus 6296	: V=1.006, theta=3.69233263 -> V=0.975, theta=0.0
% INFO    : Bus 6297	: V=1.006, theta=3.49169052 -> V=0.975, theta=0.0
% INFO    : Bus 6298	: V=1.004, theta=3.27096982 -> V=0.975, theta=0.0
% INFO    : Bus 6299	: V=0.991, theta=-2.72505296 -> V=0.975, theta=0.0
% INFO    : Bus 6300	: V=0.992, theta=-2.75008325 -> V=0.975, theta=0.0
% INFO    : Bus 6301	: V=1.034, theta=-10.0202038 -> V=0.975, theta=0.0
% INFO    : Bus 6302	: V=1.034, theta=-10.0202038 -> V=0.975, theta=0.0
% INFO    : Bus 6303	: V=1.034, theta=-10.0202038 -> V=0.975, theta=0.0
% INFO    : Bus 6304	: V=1.033, theta=-10.0436493 -> V=0.975, theta=0.0
% INFO    : Bus 6305	: V=1.033, theta=-10.0436493 -> V=0.975, theta=0.0
% INFO    : Bus 6306	: V=1.033, theta=-10.0436493 -> V=0.975, theta=0.0
% INFO    : Bus 6307	: V=1.007, theta=-11.9571931 -> V=0.975, theta=0.0
% INFO    : Bus 6308	: V=1.022, theta=13.7018522 -> V=0.975, theta=0.0
% INFO    : Bus 6309	: V=1.029, theta=15.0082737 -> V=0.975, theta=0.0
% INFO    : Bus 6310	: V=1.028, theta=14.8383961 -> V=0.975, theta=0.0
% INFO    : Bus 6311	: V=0.989, theta=-10.5121932 -> V=0.975, theta=0.0
% INFO    : Bus 6312	: V=1.049, theta=-8.43140998 -> V=0.975, theta=0.0
% INFO    : Bus 6313	: V=1.005, theta=-8.37247888 -> V=0.975, theta=0.0
% INFO    : Bus 6314	: V=1.029, theta=-43.7407965 -> V=0.975, theta=0.0
% INFO    : Bus 6315	: V=0.965, theta=2.1891557 -> V=0.975, theta=0.0
% INFO    : Bus 6316	: V=0.965, theta=2.35047014 -> V=0.975, theta=0.0
% INFO    : Bus 6317	: V=1.024, theta=-19.080801 -> V=0.975, theta=0.0
% INFO    : Bus 6319	: V=1.021, theta=-19.0082989 -> V=0.975, theta=0.0
% INFO    : Bus 6320	: V=1.021, theta=-19.0227124 -> V=0.975, theta=0.0
% INFO    : Bus 6321	: V=1.045, theta=11.3057995 -> V=0.975, theta=0.0
% INFO    : Bus 6322	: V=1.019, theta=11.3891856 -> V=0.975, theta=0.0
% INFO    : Bus 6323	: V=1.007, theta=-3.50611206 -> V=0.975, theta=0.0
% INFO    : Bus 6324	: V=1.009, theta=-3.49687706 -> V=0.975, theta=0.0
% INFO    : Bus 6325	: V=0.984, theta=-24.184233 -> V=0.975, theta=0.0
% INFO    : Bus 6326	: V=0.983, theta=-24.2605614 -> V=0.975, theta=0.0
% INFO    : Bus 6327	: V=1.009, theta=-24.2028848 -> V=0.975, theta=0.0
% INFO    : Bus 6328	: V=0.989069875, theta=-41.6152303 -> V=0.975, theta=0.0
% INFO    : Bus 6329	: V=1.025, theta=-35.5327197 -> V=0.975, theta=0.0
% INFO    : Bus 6330	: V=1.025, theta=-35.7075657 -> V=0.975, theta=0.0
% INFO    : Bus 6332	: V=0.979377248, theta=-38.9477482 -> V=0.975, theta=0.0
% INFO    : Bus 6333	: V=1.003, theta=-2.47640831 -> V=0.975, theta=0.0
% INFO    : Bus 6334	: V=1.003, theta=-2.76055116 -> V=0.975, theta=0.0
% INFO    : Bus 6335	: V=1.003, theta=-2.47640831 -> V=0.975, theta=0.0
% INFO    : Bus 6336	: V=1.003, theta=-2.47640831 -> V=0.975, theta=0.0
% INFO    : Bus 6337	: V=1.003, theta=-2.47640831 -> V=0.975, theta=0.0
% INFO    : Bus 6338	: V=1.003, theta=-2.61849609 -> V=0.975, theta=0.0
% INFO    : Bus 6339	: V=1.018, theta=8.14232651 -> V=0.975, theta=0.0
% INFO    : Bus 6340	: V=1.021, theta=8.20094943 -> V=0.975, theta=0.0
% INFO    : Bus 6341	: V=1.023, theta=8.1665677 -> V=0.975, theta=0.0
% INFO    : Bus 6342	: V=1.021, theta=7.88540768 -> V=0.975, theta=0.0
% INFO    : Bus 6343	: V=1.021, theta=-7.36114708 -> V=0.975, theta=0.0
% INFO    : Bus 6344	: V=1.021, theta=-7.26227483 -> V=0.975, theta=0.0
% INFO    : Bus 6345	: V=0.962988299, theta=-17.4354333 -> V=0.975, theta=0.0
% INFO    : Bus 6346	: V=0.992089865, theta=-17.4354575 -> V=0.975, theta=0.0
% INFO    : Bus 6347	: V=1.029, theta=8.55770095 -> V=0.975, theta=0.0
% INFO    : Bus 6348	: V=1.006, theta=-7.49675721 -> V=0.975, theta=0.0
% INFO    : Bus 6349	: V=1.006, theta=-7.49675721 -> V=0.975, theta=0.0
% INFO    : Bus 6350	: V=1.006, theta=-7.44393644 -> V=0.975, theta=0.0
% INFO    : Bus 6351	: V=1.004, theta=-7.31691037 -> V=0.975, theta=0.0
% INFO    : Bus 6352	: V=1.03991913, theta=-14.6527188 -> V=0.975, theta=0.0
% INFO    : Bus 6353	: V=1.044, theta=-16.2047984 -> V=0.975, theta=0.0
% INFO    : Bus 6354	: V=1.044, theta=-17.0497711 -> V=0.975, theta=0.0
% INFO    : Bus 6355	: V=1.023, theta=-4.36992216 -> V=0.975, theta=0.0
% INFO    : Bus 6356	: V=1.028, theta=-5.36606139 -> V=0.975, theta=0.0
% INFO    : Bus 6357	: V=1.026, theta=-6.06088737 -> V=0.975, theta=0.0
% INFO    : Bus 6358	: V=1.026, theta=-5.84853278 -> V=0.975, theta=0.0
% INFO    : Bus 6359	: V=1.028, theta=-5.00248755 -> V=0.975, theta=0.0
% INFO    : Bus 6360	: V=1.031, theta=-4.53508164 -> V=0.975, theta=0.0
% INFO    : Bus 6361	: V=1.036, theta=-4.04518384 -> V=0.975, theta=0.0
% INFO    : Bus 6362	: V=1.039, theta=-4.07787589 -> V=0.975, theta=0.0
% INFO    : Bus 6363	: V=1.02304121, theta=-12.6810395 -> V=0.975, theta=0.0
% INFO    : Bus 6364	: V=1.02304121, theta=-12.6810395 -> V=0.975, theta=0.0
% INFO    : Bus 6365	: V=1.016, theta=-6.59930364 -> V=0.975, theta=0.0
% INFO    : Bus 6366	: V=1.014, theta=-8.50112716 -> V=0.975, theta=0.0
% INFO    : Bus 6367	: V=1.023, theta=-4.66692657 -> V=0.975, theta=0.0
% INFO    : Bus 6368	: V=1.016, theta=-4.7282696 -> V=0.975, theta=0.0
% INFO    : Bus 6369	: V=1.019, theta=-4.74479116 -> V=0.975, theta=0.0
% INFO    : Bus 6370	: V=1.019, theta=-4.55998757 -> V=0.975, theta=0.0
% INFO    : Bus 6371	: V=1.016, theta=-4.71338164 -> V=0.975, theta=0.0
% INFO    : Bus 6372	: V=1.021, theta=-5.42148895 -> V=0.975, theta=0.0
% INFO    : Bus 6373	: V=0.977035931, theta=-17.3098324 -> V=0.975, theta=0.0
% INFO    : Bus 6374	: V=1.018, theta=-34.4766564 -> V=0.975, theta=0.0
% INFO    : Bus 6375	: V=1.036, theta=-20.250932 -> V=0.975, theta=0.0
% INFO    : Bus 6376	: V=0.990363545, theta=-26.2182586 -> V=0.975, theta=0.0
% INFO    : Bus 6377	: V=0.977787883, theta=-24.3704518 -> V=0.975, theta=0.0
% INFO    : Bus 6379	: V=0.969, theta=-2.32432801 -> V=0.975, theta=0.0
% INFO    : Bus 6380	: V=0.969, theta=-2.44271486 -> V=0.975, theta=0.0
% INFO    : Bus 6381	: V=1.044, theta=-19.4966418 -> V=0.975, theta=0.0
% INFO    : Bus 6382	: V=1.045, theta=-19.297694 -> V=0.975, theta=0.0
% INFO    : Bus 6383	: V=1.053, theta=-6.21156789 -> V=0.975, theta=0.0
% INFO    : Bus 6384	: V=1.053, theta=-6.21156789 -> V=0.975, theta=0.0
% INFO    : Bus 6385	: V=1.05374272, theta=-12.6802864 -> V=0.975, theta=0.0
% INFO    : Bus 6386	: V=1.012, theta=-3.44283216 -> V=0.975, theta=0.0
% INFO    : Bus 6387	: V=1.012, theta=-3.44283216 -> V=0.975, theta=0.0
% INFO    : Bus 6388	: V=1.012, theta=-3.62099093 -> V=0.975, theta=0.0
% INFO    : Bus 6389	: V=1.013, theta=-3.26783568 -> V=0.975, theta=0.0
% INFO    : Bus 6390	: V=0.957955337, theta=-17.9864463 -> V=0.975, theta=0.0
% INFO    : Bus 6391	: V=0.984, theta=-10.6659148 -> V=0.975, theta=0.0
% INFO    : Bus 6392	: V=0.984, theta=-10.6659148 -> V=0.975, theta=0.0
% INFO    : Bus 6393	: V=0.995, theta=-3.67538683 -> V=0.975, theta=0.0
% INFO    : Bus 6394	: V=0.996, theta=-1.54504119 -> V=0.975, theta=0.0
% INFO    : Bus 6395	: V=0.999, theta=-2.6235095 -> V=0.975, theta=0.0
% INFO    : Bus 6396	: V=0.995, theta=-3.53482332 -> V=0.975, theta=0.0
% INFO    : Bus 6397	: V=1.017, theta=-11.7669311 -> V=0.975, theta=0.0
% INFO    : Bus 6398	: V=1.017, theta=-11.5893848 -> V=0.975, theta=0.0
% INFO    : Bus 6399	: V=1.017, theta=-11.7669311 -> V=0.975, theta=0.0
% INFO    : Bus 6400	: V=1.012, theta=-12.3806913 -> V=0.975, theta=0.0
% INFO    : Bus 6401	: V=1.011, theta=-9.60245886 -> V=0.975, theta=0.0
% INFO    : Bus 6402	: V=1.011, theta=-9.80047952 -> V=0.975, theta=0.0
% INFO    : Bus 6403	: V=1.011, theta=-9.60245886 -> V=0.975, theta=0.0
% INFO    : Bus 6404	: V=1.011, theta=-9.60245886 -> V=0.975, theta=0.0
% INFO    : Bus 6405	: V=1.009, theta=5.84936088 -> V=0.975, theta=0.0
% INFO    : Bus 6406	: V=1.011, theta=5.63586917 -> V=0.975, theta=0.0
% INFO    : Bus 6407	: V=0.964, theta=-21.4134178 -> V=0.975, theta=0.0
% INFO    : Bus 6408	: V=0.964, theta=-21.4134178 -> V=0.975, theta=0.0
% INFO    : Bus 6409	: V=0.981, theta=-9.7101763 -> V=0.975, theta=0.0
% INFO    : Bus 6410	: V=0.996, theta=-7.95818264 -> V=0.975, theta=0.0
% INFO    : Bus 6411	: V=1.079, theta=-12.7219549 -> V=0.975, theta=0.0
% INFO    : Bus 6412	: V=1.079, theta=-12.7219549 -> V=0.975, theta=0.0
% INFO    : Bus 6413	: V=0.963432007, theta=-23.9601473 -> V=0.975, theta=0.0
% INFO    : Bus 6414	: V=0.963431812, theta=-23.9601449 -> V=0.975, theta=0.0
% INFO    : Bus 6415	: V=1.018, theta=-2.66041793 -> V=0.975, theta=0.0
% INFO    : Bus 6416	: V=1.018, theta=-2.74661785 -> V=0.975, theta=0.0
% INFO    : Bus 6417	: V=1.018, theta=-2.88142962 -> V=0.975, theta=0.0
% INFO    : Bus 6418	: V=1.018, theta=-2.83560997 -> V=0.975, theta=0.0
% INFO    : Bus 6419	: V=0.984, theta=-5.48899024 -> V=0.975, theta=0.0
% INFO    : Bus 6420	: V=0.984, theta=-5.58576819 -> V=0.975, theta=0.0
% INFO    : Bus 6421	: V=1.054, theta=4.92372661 -> V=0.975, theta=0.0
% INFO    : Bus 6422	: V=1.03, theta=5.2547276 -> V=0.975, theta=0.0
% INFO    : Bus 6423	: V=1.035, theta=-13.5908998 -> V=0.975, theta=0.0
% INFO    : Bus 6424	: V=1.004, theta=-12.8428706 -> V=0.975, theta=0.0
% INFO    : Bus 6425	: V=0.951104761, theta=-17.5100037 -> V=0.975, theta=0.0
% INFO    : Bus 6426	: V=0.989, theta=-8.3195088 -> V=0.975, theta=0.0
% INFO    : Bus 6427	: V=1.011, theta=-10.1182391 -> V=0.975, theta=0.0
% INFO    : Bus 6428	: V=1.011, theta=-10.1182391 -> V=0.975, theta=0.0
% INFO    : Bus 6429	: V=1.011, theta=0.300548352 -> V=0.975, theta=0.0
% INFO    : Bus 6430	: V=1.035, theta=-7.22160295 -> V=0.975, theta=0.0
% INFO    : Bus 6431	: V=1.049, theta=-7.32965355 -> V=0.975, theta=0.0
% INFO    : Bus 6432	: V=1.043, theta=-7.17315491 -> V=0.975, theta=0.0
% INFO    : Bus 6433	: V=1.049, theta=-7.31068326 -> V=0.975, theta=0.0
% INFO    : Bus 6434	: V=1.05, theta=-7.67571713 -> V=0.975, theta=0.0
% INFO    : Bus 6435	: V=1.035, theta=-8.06405988 -> V=0.975, theta=0.0
% INFO    : Bus 6436	: V=1.036, theta=-8.2729733 -> V=0.975, theta=0.0
% INFO    : Bus 6437	: V=0.961516231, theta=-26.6027578 -> V=0.975, theta=0.0
% INFO    : Bus 6438	: V=0.961516231, theta=-26.6027578 -> V=0.975, theta=0.0
% INFO    : Bus 6439	: V=1.027, theta=-19.2424136 -> V=0.975, theta=0.0
% INFO    : Bus 6440	: V=0.971178706, theta=-26.6027578 -> V=0.975, theta=0.0
% INFO    : Bus 6441	: V=1.08, theta=-12.6916328 -> V=0.975, theta=0.0
% INFO    : Bus 6442	: V=1.078, theta=-13.2932189 -> V=0.975, theta=0.0
% INFO    : Bus 6443	: V=1.079, theta=-13.1439563 -> V=0.975, theta=0.0
% INFO    : Bus 6444	: V=1.013, theta=-8.56126829 -> V=0.975, theta=0.0
% INFO    : Bus 6445	: V=1.006, theta=-12.599682 -> V=0.975, theta=0.0
% INFO    : Bus 6446	: V=0.968, theta=-13.4096189 -> V=0.975, theta=0.0
% INFO    : Bus 6447	: V=1.031, theta=-4.09122318 -> V=0.975, theta=0.0
% INFO    : Bus 6448	: V=1.031, theta=-4.20788423 -> V=0.975, theta=0.0
% INFO    : Bus 6449	: V=1.001, theta=-5.97104942 -> V=0.975, theta=0.0
% INFO    : Bus 6450	: V=1.03, theta=-4.23443501 -> V=0.975, theta=0.0
% INFO    : Bus 6451	: V=1.03, theta=-4.23547796 -> V=0.975, theta=0.0
% INFO    : Bus 6452	: V=1.06, theta=-6.31122521 -> V=0.975, theta=0.0
% INFO    : Bus 6453	: V=1.059, theta=-12.5599433 -> V=0.975, theta=0.0
% INFO    : Bus 6454	: V=1.03259991, theta=-47.0610631 -> V=0.975, theta=0.0
% INFO    : Bus 6455	: V=1.03260032, theta=-47.0610745 -> V=0.975, theta=0.0
% INFO    : Bus 6456	: V=1.03260091, theta=-47.0610906 -> V=0.975, theta=0.0
% INFO    : Bus 6457	: V=0.986, theta=0.428697518 -> V=0.975, theta=0.0
% INFO    : Bus 6458	: V=0.997366117, theta=-4.5159757 -> V=0.975, theta=0.0
% INFO    : Bus 6459	: V=0.986, theta=0.714482166 -> V=0.975, theta=0.0
% INFO    : Bus 6460	: V=0.997366117, theta=-4.5159757 -> V=0.975, theta=0.0
% INFO    : Bus 6461	: V=1.087, theta=4.70421067 -> V=0.975, theta=0.0
% INFO    : Bus 6462	: V=1.091, theta=3.21381752 -> V=0.975, theta=0.0
% INFO    : Bus 6463	: V=1.022, theta=5.01516477 -> V=0.975, theta=0.0
% INFO    : Bus 6464	: V=1.091, theta=4.62337131 -> V=0.975, theta=0.0
% INFO    : Bus 6465	: V=1.037, theta=-9.23883042 -> V=0.975, theta=0.0
% INFO    : Bus 6466	: V=1.0437404, theta=-13.2018327 -> V=0.975, theta=0.0
% INFO    : Bus 6467	: V=1.041, theta=-9.4271429 -> V=0.975, theta=0.0
% INFO    : Bus 6468	: V=1.0437404, theta=-13.2018327 -> V=0.975, theta=0.0
% INFO    : Bus 6469	: V=1.0437404, theta=-13.2018327 -> V=0.975, theta=0.0
% INFO    : Bus 6470	: V=1.045, theta=-9.04498597 -> V=0.975, theta=0.0
% INFO    : Bus 6471	: V=1.009, theta=-10.8736379 -> V=0.975, theta=0.0
% INFO    : Bus 6472	: V=1.009, theta=-11.0572674 -> V=0.975, theta=0.0
% INFO    : Bus 6473	: V=1.026, theta=-9.83543627 -> V=0.975, theta=0.0
% INFO    : Bus 6474	: V=1.022, theta=-9.7843375 -> V=0.975, theta=0.0
% INFO    : Bus 6475	: V=1.021, theta=-10.0875195 -> V=0.975, theta=0.0
% INFO    : Bus 6476	: V=0.973, theta=-8.58227625 -> V=0.975, theta=0.0
% INFO    : Bus 6477	: V=0.999, theta=-1.03588126 -> V=0.975, theta=0.0
% INFO    : Bus 6478	: V=0.999, theta=-1.03588126 -> V=0.975, theta=0.0
% INFO    : Bus 6479	: V=0.971005865, theta=-5.79706738 -> V=0.975, theta=0.0
% INFO    : Bus 6480	: V=0.976, theta=2.49716771 -> V=0.975, theta=0.0
% INFO    : Bus 6481	: V=0.976, theta=2.42316206 -> V=0.975, theta=0.0
% INFO    : Bus 6482	: V=0.976, theta=2.49716771 -> V=0.975, theta=0.0
% INFO    : Bus 6483	: V=0.976, theta=2.42316206 -> V=0.975, theta=0.0
% INFO    : Bus 6484	: V=1.041, theta=-6.13714861 -> V=0.975, theta=0.0
% INFO    : Bus 6485	: V=1.011, theta=6.26964839 -> V=0.975, theta=0.0
% INFO    : Bus 6486	: V=1.012, theta=6.12220541 -> V=0.975, theta=0.0
% INFO    : Bus 6487	: V=1.011, theta=7.66190276 -> V=0.975, theta=0.0
% INFO    : Bus 6488	: V=1.013, theta=7.88164441 -> V=0.975, theta=0.0
% INFO    : Bus 6489	: V=1.029, theta=14.8682426 -> V=0.975, theta=0.0
% INFO    : Bus 6490	: V=1.029, theta=15.2896582 -> V=0.975, theta=0.0
% INFO    : Bus 6491	: V=1.03, theta=-11.431632 -> V=0.975, theta=0.0
% INFO    : Bus 6492	: V=1.03, theta=-11.3894472 -> V=0.975, theta=0.0
% INFO    : Bus 6493	: V=0.973, theta=-1.61677352 -> V=0.975, theta=0.0
% INFO    : Bus 6494	: V=0.931, theta=-1.28580082 -> V=0.975, theta=0.0
% INFO    : Bus 6495	: V=1.002, theta=-13.4996873 -> V=0.975, theta=0.0
% INFO    : Bus 6496	: V=0.979393202, theta=-18.6046453 -> V=0.975, theta=0.0
% INFO    : Bus 6497	: V=1.01, theta=-13.3487946 -> V=0.975, theta=0.0
% INFO    : Bus 6498	: V=1.01, theta=-13.3955703 -> V=0.975, theta=0.0
% INFO    : Bus 6499	: V=1.031, theta=-12.3127603 -> V=0.975, theta=0.0
% INFO    : Bus 6500	: V=1.03, theta=-12.8569442 -> V=0.975, theta=0.0
% INFO    : Bus 6501	: V=1.03, theta=-12.8569442 -> V=0.975, theta=0.0
% INFO    : Bus 6502	: V=0.958, theta=4.24076537 -> V=0.975, theta=0.0
% INFO    : Bus 6503	: V=1.018, theta=-4.65198977 -> V=0.975, theta=0.0
% INFO    : Bus 6504	: V=1.018, theta=-4.51985678 -> V=0.975, theta=0.0
% INFO    : Bus 6505	: V=1.005, theta=9.981349 -> V=0.975, theta=0.0
% INFO    : Bus 6506	: V=1.002, theta=9.59604808 -> V=0.975, theta=0.0
% INFO    : Bus 6507	: V=1.004, theta=10.014954 -> V=0.975, theta=0.0
% INFO    : Bus 6508	: V=0.999, theta=10.4806147 -> V=0.975, theta=0.0
% INFO    : Bus 6509	: V=1.00932778, theta=-28.7756074 -> V=0.975, theta=0.0
% INFO    : Bus 6510	: V=1.00932778, theta=-28.7756074 -> V=0.975, theta=0.0
% INFO    : Bus 6511	: V=1.00080752, theta=-29.0708561 -> V=0.975, theta=0.0
% INFO    : Bus 6512	: V=0.936, theta=0.541814913 -> V=0.975, theta=0.0
% INFO    : Bus 6513	: V=0.936, theta=0.541814913 -> V=0.975, theta=0.0
% INFO    : Bus 6514	: V=0.936, theta=0.541814913 -> V=0.975, theta=0.0
% INFO    : Bus 6515	: V=1.039, theta=-25.0452126 -> V=0.975, theta=0.0
% INFO    : Bus 6516	: V=1.03, theta=-25.6088965 -> V=0.975, theta=0.0
% INFO    : Bus 6517	: V=1.068, theta=-5.85992381 -> V=0.975, theta=0.0
% INFO    : Bus 6518	: V=1.08, theta=-8.11400326 -> V=0.975, theta=0.0
% INFO    : Bus 6519	: V=1.081, theta=-8.02698736 -> V=0.975, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 4	: Vg=1.025 -> Vg=1.0111115
% INFO    : Gen at bus 4	: Vg=1.025 -> Vg=1.0111115
% INFO    : Gen at bus 5	: Vg=1.016 -> Vg=1.0079355
% INFO    : Gen at bus 11	: Pg=0.05, Qg=0.0 -> Pg=14.0, Qg=0.0
% INFO    : Gen at bus 11	: Vg=1.014 -> Vg=1.000001
% INFO    : Gen at bus 11	: Vg=1.014 -> Vg=1.000001
% INFO    : Gen at bus 17	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 19	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 22	: Vg=1.007 -> Vg=1.0158755
% INFO    : Gen at bus 24	: Vg=1.027 -> Vg=1.033333
% INFO    : Gen at bus 24	: Vg=1.027 -> Vg=1.033333
% INFO    : Gen at bus 25	: Pg=0.22, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 25	: Vg=1.064 -> Vg=1.022222
% INFO    : Gen at bus 25	: Vg=1.064 -> Vg=1.022222
% INFO    : Gen at bus 40	: Vg=1.054 -> Vg=1.027779
% INFO    : Gen at bus 47	: Pg=8.56, Qg=-10.0 -> Pg=8.0, Qg=-0.25
% INFO    : Gen at bus 47	: Vg=1.022 -> Vg=0.999999
% INFO    : Gen at bus 47	: Pg=8.56, Qg=-10.0 -> Pg=8.0, Qg=-0.25
% INFO    : Gen at bus 47	: Vg=1.022 -> Vg=0.999999
% INFO    : Gen at bus 48	: Vg=1.017 -> Vg=1.000001
% INFO    : Gen at bus 48	: Vg=1.017 -> Vg=1.000001
% INFO    : Gen at bus 57	: Pg=4.74, Qg=1.0 -> Pg=6.5, Qg=0.95
% INFO    : Gen at bus 57	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 64	: Vg=1.056 -> Vg=0.9888895
% INFO    : Gen at bus 64	: Vg=1.056 -> Vg=0.9888895
% INFO    : Gen at bus 69	: Vg=1.045 -> Vg=1.0079355
% INFO    : Gen at bus 70	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 85	: Vg=1.042 -> Vg=0.999999
% INFO    : Gen at bus 86	: Vg=1.019 -> Vg=1.022224
% INFO    : Gen at bus 102	: Pg=17.16, Qg=-7.63 -> Pg=23.0, Qg=6.0
% INFO    : Gen at bus 102	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 122	: Pg=6.17, Qg=2.04 -> Pg=6.0, Qg=1.5
% INFO    : Gen at bus 122	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 124	: Vg=1.032 -> Vg=1.022224
% INFO    : Gen at bus 125	: Pg=5.16, Qg=0.0 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 125	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 125	: Pg=1.16, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 125	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 132	: Pg=12.3, Qg=0.8 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 132	: Vg=1.061 -> Vg=1.000001
% INFO    : Gen at bus 132	: Vg=1.061 -> Vg=1.000001
% INFO    : Gen at bus 132	: Vg=1.061 -> Vg=1.000001
% INFO    : Gen at bus 132	: Vg=1.061 -> Vg=1.000001
% INFO    : Gen at bus 137	: Vg=1.021 -> Vg=1.015872
% INFO    : Gen at bus 137	: Pg=7.21, Qg=-0.8 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 137	: Vg=1.021 -> Vg=1.015872
% INFO    : Gen at bus 155	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 158	: Pg=8.29, Qg=2.26 -> Pg=8.95, Qg=-1.5
% INFO    : Gen at bus 158	: Vg=0.959 -> Vg=0.9444445
% INFO    : Gen at bus 158	: Pg=8.29, Qg=2.26 -> Pg=8.95, Qg=-1.5
% INFO    : Gen at bus 158	: Vg=0.959 -> Vg=0.9444445
% INFO    : Gen at bus 176	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 187	: Vg=1.075 -> Vg=1.0000025
% INFO    : Gen at bus 187	: Vg=1.075 -> Vg=1.0000025
% INFO    : Gen at bus 190	: Vg=0.951 -> Vg=0.9444445
% INFO    : Gen at bus 192	: Pg=9.17, Qg=0.0 -> Pg=11.75, Qg=0.0
% INFO    : Gen at bus 192	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 194	: Pg=0.42, Qg=1.0 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 194	: Vg=1.056 -> Vg=1.0000025
% INFO    : Gen at bus 194	: Pg=0.42, Qg=1.0 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 194	: Vg=1.056 -> Vg=1.0000025
% INFO    : Gen at bus 217	: Vg=1.009 -> Vg=1.022224
% INFO    : Gen at bus 224	: Vg=1.099 -> Vg=1.0
% INFO    : Gen at bus 227	: Vg=1.012 -> Vg=1.0079355
% INFO    : Gen at bus 236	: Vg=1.033 -> Vg=1.000001
% INFO    : Gen at bus 236	: Vg=1.033 -> Vg=1.000001
% INFO    : Gen at bus 238	: Vg=1.033 -> Vg=1.022224
% INFO    : Gen at bus 238	: Pg=1.01, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 238	: Vg=1.033 -> Vg=1.022224
% INFO    : Gen at bus 246	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 246	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 246	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 246	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 256	: Pg=7.15, Qg=-5.7 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 256	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 256	: Pg=12.15, Qg=-5.7 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 256	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 258	: Pg=25.37, Qg=0.9 -> Pg=15.0, Qg=0.95
% INFO    : Gen at bus 258	: Vg=1.078 -> Vg=1.000001
% INFO    : Gen at bus 261	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 269	: Vg=1.006 -> Vg=1.0000025
% INFO    : Gen at bus 282	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 295	: Vg=1.044 -> Vg=0.9888895
% INFO    : Gen at bus 296	: Pg=3.05, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 296	: Vg=1.008 -> Vg=1.0158755
% INFO    : Gen at bus 305	: Vg=1.042 -> Vg=0.999999
% INFO    : Gen at bus 312	: Pg=4.2, Qg=0.0 -> Pg=12.9, Qg=0.0
% INFO    : Gen at bus 312	: Vg=1.011 -> Vg=1.000001
% INFO    : Gen at bus 312	: Pg=15.2, Qg=0.0 -> Pg=24.8, Qg=0.0
% INFO    : Gen at bus 312	: Vg=1.011 -> Vg=1.000001
% INFO    : Gen at bus 317	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 317	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 319	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 325	: Vg=1.03 -> Vg=0.999999
% INFO    : Gen at bus 332	: Vg=1.038 -> Vg=1.015872
% INFO    : Gen at bus 333	: Vg=1.048 -> Vg=1.0233335
% INFO    : Gen at bus 336	: Pg=6.4, Qg=0.12 -> Pg=6.5, Qg=-0.5
% INFO    : Gen at bus 336	: Vg=1.023 -> Vg=1.0000025
% INFO    : Gen at bus 338	: Vg=1.076 -> Vg=1.0000025
% INFO    : Gen at bus 338	: Vg=1.076 -> Vg=1.0000025
% INFO    : Gen at bus 345	: Vg=1.027 -> Vg=1.027779
% INFO    : Gen at bus 345	: Vg=1.027 -> Vg=1.027779
% INFO    : Gen at bus 348	: Vg=1.047 -> Vg=1.022222
% INFO    : Gen at bus 357	: Vg=0.996 -> Vg=1.0158755
% INFO    : Gen at bus 357	: Vg=0.996 -> Vg=1.0158755
% INFO    : Gen at bus 364	: Pg=125.15, Qg=17.47 -> Pg=65.0, Qg=16.5
% INFO    : Gen at bus 364	: Vg=1.035 -> Vg=1.046665
% INFO    : Gen at bus 391	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 409	: Vg=1.034 -> Vg=1.015872
% INFO    : Gen at bus 411	: Vg=1.027 -> Vg=1.022224
% INFO    : Gen at bus 411	: Vg=1.027 -> Vg=1.022224
% INFO    : Gen at bus 431	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 440	: Vg=1.023 -> Vg=1.0000025
% INFO    : Gen at bus 447	: Pg=18.4, Qg=0.79 -> Pg=12.5, Qg=-0.5
% INFO    : Gen at bus 447	: Vg=0.997 -> Vg=1.015872
% INFO    : Gen at bus 462	: Vg=1.046 -> Vg=1.0079355
% INFO    : Gen at bus 462	: Vg=1.046 -> Vg=1.0079355
% INFO    : Gen at bus 464	: Pg=3.68, Qg=2.64 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 464	: Vg=1.176 -> Vg=0.98822
% INFO    : Gen at bus 464	: Pg=3.68, Qg=2.64 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 464	: Vg=1.176 -> Vg=0.98822
% INFO    : Gen at bus 466	: Vg=1.035 -> Vg=1.0079355
% INFO    : Gen at bus 470	: Vg=1.045 -> Vg=0.999999
% INFO    : Gen at bus 470	: Vg=1.045 -> Vg=0.999999
% INFO    : Gen at bus 479	: Vg=1.022 -> Vg=0.999999
% INFO    : Gen at bus 479	: Vg=1.022 -> Vg=0.999999
% INFO    : Gen at bus 479	: Vg=1.022 -> Vg=0.999999
% INFO    : Gen at bus 491	: Vg=1.054 -> Vg=1.033334
% INFO    : Gen at bus 508	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 519	: Vg=0.999 -> Vg=1.015874
% INFO    : Gen at bus 520	: Vg=1.025 -> Vg=1.022224
% INFO    : Gen at bus 530	: Pg=1.92, Qg=-0.04 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 530	: Vg=1.039 -> Vg=0.999999
% INFO    : Gen at bus 530	: Pg=1.92, Qg=-0.04 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 530	: Vg=1.039 -> Vg=0.999999
% INFO    : Gen at bus 530	: Pg=1.92, Qg=-0.04 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 530	: Vg=1.039 -> Vg=0.999999
% INFO    : Gen at bus 537	: Vg=1.028 -> Vg=1.022224
% INFO    : Gen at bus 537	: Pg=1.93, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 537	: Vg=1.028 -> Vg=1.022224
% INFO    : Gen at bus 546	: Pg=0.0, Qg=2.0 -> Pg=4.5, Qg=1.95
% INFO    : Gen at bus 546	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 548	: Vg=1.04 -> Vg=1.0000025
% INFO    : Gen at bus 570	: Vg=0.997 -> Vg=1.0158755
% INFO    : Gen at bus 570	: Vg=0.997 -> Vg=1.0158755
% INFO    : Gen at bus 570	: Vg=0.997 -> Vg=1.0158755
% INFO    : Gen at bus 583	: Pg=2.96, Qg=5.22 -> Pg=8.0, Qg=1.5
% INFO    : Gen at bus 583	: Vg=1.009 -> Vg=1.0000005
% INFO    : Gen at bus 585	: Vg=0.986 -> Vg=1.0158755
% INFO    : Gen at bus 586	: Vg=1.025 -> Vg=0.999999
% INFO    : Gen at bus 589	: Vg=1.018 -> Vg=1.000001
% INFO    : Gen at bus 593	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 600	: Vg=1.03 -> Vg=1.015872
% INFO    : Gen at bus 610	: Pg=39.05, Qg=-6.42 -> Pg=22.5, Qg=0.0
% INFO    : Gen at bus 610	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 610	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 612	: Vg=1.0 -> Vg=1.022224
% INFO    : Gen at bus 612	: Vg=1.0 -> Vg=1.022224
% INFO    : Gen at bus 612	: Vg=1.0 -> Vg=1.022224
% INFO    : Gen at bus 613	: Vg=0.994 -> Vg=1.0000005
% INFO    : Gen at bus 613	: Vg=0.994 -> Vg=1.0000005
% INFO    : Gen at bus 624	: Pg=-4.11, Qg=-8.3 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 624	: Vg=1.047 -> Vg=1.0111115
% INFO    : Gen at bus 633	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 636	: Vg=0.999 -> Vg=1.015872
% INFO    : Gen at bus 636	: Pg=1.0, Qg=4.25 -> Pg=7.5, Qg=3.5
% INFO    : Gen at bus 636	: Vg=0.999 -> Vg=1.015872
% INFO    : Gen at bus 646	: Pg=197.89, Qg=5.02 -> Pg=119.5, Qg=2.5
% INFO    : Gen at bus 646	: Vg=1.104 -> Vg=1.078945
% INFO    : Gen at bus 657	: Vg=1.065 -> Vg=1.0000025
% INFO    : Gen at bus 675	: Vg=1.026 -> Vg=1.022224
% INFO    : Gen at bus 675	: Pg=0.14, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 675	: Vg=1.026 -> Vg=1.022224
% INFO    : Gen at bus 676	: Vg=1.025 -> Vg=1.027779
% INFO    : Gen at bus 676	: Vg=1.025 -> Vg=1.027779
% INFO    : Gen at bus 684	: Vg=0.996 -> Vg=1.0218635
% INFO    : Gen at bus 685	: Vg=1.05 -> Vg=1.022224
% INFO    : Gen at bus 689	: Pg=2.31, Qg=1.22 -> Pg=4.5, Qg=0.5
% INFO    : Gen at bus 689	: Vg=0.966 -> Vg=0.9444445
% INFO    : Gen at bus 689	: Pg=2.31, Qg=1.22 -> Pg=4.5, Qg=0.5
% INFO    : Gen at bus 689	: Vg=0.966 -> Vg=0.9444445
% INFO    : Gen at bus 689	: Vg=0.966 -> Vg=0.9444445
% INFO    : Gen at bus 689	: Pg=2.31, Qg=1.22 -> Pg=5.5, Qg=1.5
% INFO    : Gen at bus 689	: Vg=0.966 -> Vg=0.9444445
% INFO    : Gen at bus 700	: Vg=1.033 -> Vg=1.022222
% INFO    : Gen at bus 700	: Vg=1.033 -> Vg=1.022222
% INFO    : Gen at bus 700	: Vg=1.033 -> Vg=1.022222
% INFO    : Gen at bus 704	: Pg=29.21, Qg=-6.36 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 704	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 704	: Pg=27.22, Qg=-6.36 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 704	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 703	: Pg=26.46, Qg=-6.56 -> Pg=18.5, Qg=0.0
% INFO    : Gen at bus 703	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 703	: Pg=28.46, Qg=-6.56 -> Pg=18.5, Qg=0.0
% INFO    : Gen at bus 703	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 702	: Pg=28.46, Qg=-7.06 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 702	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 702	: Pg=28.46, Qg=-7.06 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 702	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 710	: Vg=0.963 -> Vg=0.9444445
% INFO    : Gen at bus 710	: Vg=0.963 -> Vg=0.9444445
% INFO    : Gen at bus 710	: Pg=1.0, Qg=2.16 -> Pg=2.85, Qg=0.0
% INFO    : Gen at bus 710	: Vg=0.963 -> Vg=0.9444445
% INFO    : Gen at bus 710	: Vg=0.963 -> Vg=0.9444445
% INFO    : Gen at bus 737	: Vg=1.021 -> Vg=1.022224
% INFO    : Gen at bus 738	: Pg=26.22, Qg=-3.12 -> Pg=19.5, Qg=0.0
% INFO    : Gen at bus 738	: Vg=0.995 -> Vg=0.999999
% INFO    : Gen at bus 739	: Pg=0.21, Qg=0.0 -> Pg=5.75, Qg=0.0
% INFO    : Gen at bus 739	: Vg=0.995 -> Vg=1.0158755
% INFO    : Gen at bus 739	: Pg=9.21, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 739	: Vg=0.995 -> Vg=1.0158755
% INFO    : Gen at bus 741	: Vg=1.029 -> Vg=1.000001
% INFO    : Gen at bus 741	: Vg=1.029 -> Vg=1.000001
% INFO    : Gen at bus 742	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 749	: Vg=1.008 -> Vg=0.999999
% INFO    : Gen at bus 749	: Vg=1.008 -> Vg=0.999999
% INFO    : Gen at bus 750	: Pg=5.08, Qg=-8.78 -> Pg=13.3, Qg=0.0
% INFO    : Gen at bus 750	: Vg=1.002 -> Vg=0.999999
% INFO    : Gen at bus 751	: Pg=1.88, Qg=2.0 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 751	: Vg=1.014 -> Vg=1.022224
% INFO    : Gen at bus 756	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 763	: Vg=1.05 -> Vg=0.9888895
% INFO    : Gen at bus 765	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 766	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 765	: Pg=16.81, Qg=-6.42 -> Pg=18.75, Qg=1.79
% INFO    : Gen at bus 765	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 766	: Pg=15.91, Qg=-4.04 -> Pg=18.75, Qg=2.0
% INFO    : Gen at bus 766	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 767	: Vg=0.586 -> Vg=0.825
% INFO    : Gen at bus 767	: Vg=0.586 -> Vg=0.825
% INFO    : Gen at bus 767	: Vg=0.586 -> Vg=0.825
% INFO    : Gen at bus 767	: Vg=0.586 -> Vg=0.825
% INFO    : Gen at bus 771	: Vg=1.011 -> Vg=1.0158755
% INFO    : Gen at bus 771	: Pg=1.22, Qg=0.0 -> Pg=17.0, Qg=0.0
% INFO    : Gen at bus 771	: Vg=1.011 -> Vg=1.0158755
% INFO    : Gen at bus 791	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 791	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 792	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 806	: Pg=23.16, Qg=-7.34 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 806	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 806	: Pg=25.15, Qg=-7.34 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 806	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 807	: Pg=25.51, Qg=-5.14 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 807	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 807	: Pg=25.51, Qg=-5.14 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 807	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 808	: Pg=25.51, Qg=-6.15 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 808	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 808	: Pg=24.51, Qg=-6.15 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 808	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 812	: Pg=35.18, Qg=0.0 -> Pg=20.4, Qg=0.0
% INFO    : Gen at bus 812	: Vg=1.017 -> Vg=1.0000025
% INFO    : Gen at bus 820	: Pg=22.51, Qg=0.17 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 820	: Vg=1.022 -> Vg=1.015872
% INFO    : Gen at bus 820	: Vg=1.022 -> Vg=1.015872
% INFO    : Gen at bus 821	: Pg=23.41, Qg=-0.47 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 821	: Vg=1.022 -> Vg=1.015872
% INFO    : Gen at bus 821	: Pg=23.41, Qg=-0.47 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 821	: Vg=1.022 -> Vg=1.015872
% INFO    : Gen at bus 821	: Pg=20.41, Qg=-0.47 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 821	: Vg=1.022 -> Vg=1.015872
% INFO    : Gen at bus 821	: Pg=22.41, Qg=-0.47 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 821	: Vg=1.022 -> Vg=1.015872
% INFO    : Gen at bus 831	: Vg=1.044 -> Vg=1.0000025
% INFO    : Gen at bus 831	: Vg=1.044 -> Vg=1.0000025
% INFO    : Gen at bus 834	: Vg=1.051 -> Vg=1.022222
% INFO    : Gen at bus 835	: Pg=7.42, Qg=-0.3 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 835	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 836	: Vg=0.981 -> Vg=0.9444445
% INFO    : Gen at bus 838	: Vg=1.077 -> Vg=1.0000025
% INFO    : Gen at bus 838	: Vg=1.077 -> Vg=1.0000025
% INFO    : Gen at bus 841	: Pg=3.0, Qg=3.0 -> Pg=7.5, Qg=2.95
% INFO    : Gen at bus 841	: Vg=1.018 -> Vg=1.0000025
% INFO    : Gen at bus 843	: Vg=1.067 -> Vg=1.0000025
% INFO    : Gen at bus 843	: Vg=1.067 -> Vg=1.0000025
% INFO    : Gen at bus 862	: Vg=1.026 -> Vg=1.0000025
% INFO    : Gen at bus 862	: Vg=1.026 -> Vg=1.0000025
% INFO    : Gen at bus 869	: Pg=7.46, Qg=7.0 -> Pg=7.0, Qg=0.0
% INFO    : Gen at bus 869	: Vg=1.028 -> Vg=1.0000025
% INFO    : Gen at bus 870	: Pg=7.14, Qg=7.0 -> Pg=7.0, Qg=0.0
% INFO    : Gen at bus 870	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 890	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 890	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 894	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 894	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 894	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 894	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 912	: Vg=1.053 -> Vg=1.027779
% INFO    : Gen at bus 945	: Pg=3.14, Qg=0.0 -> Pg=4.05, Qg=0.0
% INFO    : Gen at bus 945	: Vg=0.989 -> Vg=1.0000025
% INFO    : Gen at bus 949	: Vg=1.023 -> Vg=1.000001
% INFO    : Gen at bus 970	: Pg=38.32, Qg=3.08 -> Pg=25.0, Qg=9.0
% INFO    : Gen at bus 970	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 972	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 978	: Pg=1.47, Qg=-1.24 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 978	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 978	: Pg=1.47, Qg=-1.24 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 978	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 988	: Vg=1.048 -> Vg=1.027779
% INFO    : Gen at bus 988	: Vg=1.048 -> Vg=1.027779
% INFO    : Gen at bus 988	: Vg=1.048 -> Vg=1.027779
% INFO    : Gen at bus 990	: Vg=1.006 -> Vg=0.984126
% INFO    : Gen at bus 992	: Vg=1.01 -> Vg=1.022224
% INFO    : Gen at bus 1014	: Pg=0.0, Qg=1.0 -> Pg=1.5, Qg=0.95
% INFO    : Gen at bus 1014	: Vg=1.051 -> Vg=1.000001
% INFO    : Gen at bus 1014	: Vg=1.051 -> Vg=1.000001
% INFO    : Gen at bus 1018	: Pg=1.7, Qg=1.97 -> Pg=3.6, Qg=0.0
% INFO    : Gen at bus 1018	: Vg=1.061 -> Vg=1.001649
% INFO    : Gen at bus 1030	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 1053	: Vg=1.006 -> Vg=0.999999
% INFO    : Gen at bus 1055	: Pg=2.04, Qg=0.0 -> Pg=6.9, Qg=0.0
% INFO    : Gen at bus 1055	: Vg=0.98 -> Vg=1.015872
% INFO    : Gen at bus 1055	: Vg=0.98 -> Vg=1.015872
% INFO    : Gen at bus 1062	: Pg=7.0, Qg=2.86 -> Pg=9.4, Qg=1.5
% INFO    : Gen at bus 1062	: Vg=1.062 -> Vg=1.022222
% INFO    : Gen at bus 1063	: Vg=1.028 -> Vg=1.022224
% INFO    : Gen at bus 1070	: Vg=1.023 -> Vg=0.9682545
% INFO    : Gen at bus 1071	: Pg=4.14, Qg=2.0 -> Pg=6.0, Qg=1.95
% INFO    : Gen at bus 1071	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 1075	: Vg=1.006 -> Vg=1.0158755
% INFO    : Gen at bus 1113	: Pg=14.0, Qg=-0.15 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 1113	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 1113	: Pg=5.0, Qg=-0.15 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 1113	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 1113	: Pg=5.0, Qg=-0.15 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 1113	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 1113	: Pg=5.0, Qg=-0.15 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 1113	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 1115	: Pg=7.7, Qg=-3.77 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 1115	: Vg=1.046 -> Vg=1.001754
% INFO    : Gen at bus 1115	: Pg=9.78, Qg=-3.77 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 1115	: Vg=1.046 -> Vg=1.001754
% INFO    : Gen at bus 1130	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 1133	: Vg=1.0 -> Vg=1.022224
% INFO    : Gen at bus 1140	: Vg=1.009 -> Vg=1.0000025
% INFO    : Gen at bus 1152	: Vg=1.024 -> Vg=1.022224
% INFO    : Gen at bus 1152	: Vg=1.024 -> Vg=1.022224
% INFO    : Gen at bus 1215	: Pg=32.29, Qg=5.47 -> Pg=31.0, Qg=0.0
% INFO    : Gen at bus 1215	: Vg=1.091 -> Vg=1.04542
% INFO    : Gen at bus 1216	: Pg=25.2, Qg=-6.87 -> Pg=20.7, Qg=0.415
% INFO    : Gen at bus 1216	: Vg=1.075 -> Vg=1.044445
% INFO    : Gen at bus 1226	: Vg=1.049 -> Vg=1.027779
% INFO    : Gen at bus 1251	: Vg=0.572 -> Vg=0.825
% INFO    : Gen at bus 1251	: Vg=0.572 -> Vg=0.825
% INFO    : Gen at bus 1261	: Vg=1.043 -> Vg=1.0079355
% INFO    : Gen at bus 1263	: Pg=8.17, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1263	: Vg=1.029 -> Vg=1.0158755
% INFO    : Gen at bus 1264	: Pg=8.17, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1264	: Vg=1.027 -> Vg=1.0158755
% INFO    : Gen at bus 1268	: Vg=0.99 -> Vg=1.015872
% INFO    : Gen at bus 1282	: Vg=1.028 -> Vg=1.033333
% INFO    : Gen at bus 1282	: Vg=1.028 -> Vg=1.033333
% INFO    : Gen at bus 1291	: Vg=1.065 -> Vg=1.0000025
% INFO    : Gen at bus 1291	: Vg=1.065 -> Vg=1.0000025
% INFO    : Gen at bus 1291	: Pg=1.08, Qg=2.53 -> Pg=4.0, Qg=-0.1
% INFO    : Gen at bus 1291	: Vg=1.065 -> Vg=1.0000025
% INFO    : Gen at bus 1308	: Vg=1.047 -> Vg=0.975
% INFO    : Gen at bus 1315	: Pg=8.73, Qg=1.0 -> Pg=8.5, Qg=0.95
% INFO    : Gen at bus 1315	: Vg=1.068 -> Vg=1.0000025
% INFO    : Gen at bus 1315	: Pg=8.73, Qg=1.0 -> Pg=8.5, Qg=0.95
% INFO    : Gen at bus 1315	: Vg=1.068 -> Vg=1.0000025
% INFO    : Gen at bus 1315	: Vg=1.068 -> Vg=1.0000025
% INFO    : Gen at bus 1318	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 1318	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 1320	: Vg=1.032 -> Vg=1.022224
% INFO    : Gen at bus 1320	: Vg=1.032 -> Vg=1.022224
% INFO    : Gen at bus 1328	: Vg=0.98 -> Vg=0.9444445
% INFO    : Gen at bus 1330	: Vg=1.053 -> Vg=1.000001
% INFO    : Gen at bus 1330	: Pg=0.13, Qg=1.0 -> Pg=2.5, Qg=0.95
% INFO    : Gen at bus 1330	: Vg=1.053 -> Vg=1.000001
% INFO    : Gen at bus 1345	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 1349	: Pg=0.0, Qg=1.5 -> Pg=5.5, Qg=3.0
% INFO    : Gen at bus 1349	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 1349	: Pg=0.0, Qg=1.5 -> Pg=5.5, Qg=3.0
% INFO    : Gen at bus 1349	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 1359	: Pg=7.26, Qg=0.0 -> Pg=9.075, Qg=0.0
% INFO    : Gen at bus 1359	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 1359	: Pg=26.26, Qg=0.0 -> Pg=17.85, Qg=0.0
% INFO    : Gen at bus 1359	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 1359	: Pg=19.26, Qg=0.0 -> Pg=14.2, Qg=0.0
% INFO    : Gen at bus 1359	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 1362	: Pg=24.38, Qg=-6.67 -> Pg=22.5, Qg=0.0
% INFO    : Gen at bus 1362	: Vg=1.05 -> Vg=0.999999
% INFO    : Gen at bus 1361	: Pg=23.87, Qg=0.34 -> Pg=22.5, Qg=0.0
% INFO    : Gen at bus 1361	: Vg=1.052 -> Vg=0.999999
% INFO    : Gen at bus 1368	: Vg=1.042 -> Vg=1.015872
% INFO    : Gen at bus 1368	: Pg=5.34, Qg=7.56 -> Pg=6.5, Qg=1.28
% INFO    : Gen at bus 1368	: Vg=1.042 -> Vg=1.015872
% INFO    : Gen at bus 1415	: Vg=1.007 -> Vg=1.015872
% INFO    : Gen at bus 1425	: Pg=38.18, Qg=1.59 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 1425	: Vg=1.031 -> Vg=1.000001
% INFO    : Gen at bus 1425	: Pg=38.18, Qg=1.59 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 1425	: Vg=1.031 -> Vg=1.000001
% INFO    : Gen at bus 1438	: Vg=1.008 -> Vg=1.015872
% INFO    : Gen at bus 1445	: Pg=7.31, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 1445	: Vg=1.012 -> Vg=1.015872
% INFO    : Gen at bus 1459	: Vg=0.599 -> Vg=0.825
% INFO    : Gen at bus 1459	: Vg=0.599 -> Vg=0.825
% INFO    : Gen at bus 1459	: Vg=0.599 -> Vg=0.825
% INFO    : Gen at bus 1468	: Vg=1.023 -> Vg=1.0158755
% INFO    : Gen at bus 1469	: Vg=1.021 -> Vg=1.027779
% INFO    : Gen at bus 1479	: Vg=1.033 -> Vg=1.015872
% INFO    : Gen at bus 1500	: Vg=1.034 -> Vg=1.022224
% INFO    : Gen at bus 1502	: Vg=1.034 -> Vg=1.0111115
% INFO    : Gen at bus 1502	: Vg=1.034 -> Vg=1.0111115
% INFO    : Gen at bus 1522	: Pg=213.83, Qg=80.11 -> Pg=141.5, Qg=20.0
% INFO    : Gen at bus 1522	: Vg=1.122 -> Vg=0.975
% INFO    : Gen at bus 1523	: Pg=160.83, Qg=28.17 -> Pg=125.5, Qg=12.5
% INFO    : Gen at bus 1523	: Vg=0.969 -> Vg=0.975
% INFO    : Gen at bus 1553	: Vg=1.023 -> Vg=1.022222
% INFO    : Gen at bus 1553	: Vg=1.023 -> Vg=1.022222
% INFO    : Gen at bus 1560	: Pg=6.2, Qg=3.79 -> Pg=25.0, Qg=6.5
% INFO    : Gen at bus 1560	: Vg=1.033 -> Vg=1.033333
% INFO    : Gen at bus 1564	: Vg=1.054 -> Vg=1.027779
% INFO    : Gen at bus 1564	: Vg=1.054 -> Vg=1.027779
% INFO    : Gen at bus 1565	: Vg=1.068 -> Vg=1.046665
% INFO    : Gen at bus 1566	: Vg=1.02 -> Vg=1.022224
% INFO    : Gen at bus 1570	: Vg=0.965 -> Vg=1.0158755
% INFO    : Gen at bus 1570	: Vg=0.965 -> Vg=1.0158755
% INFO    : Gen at bus 1584	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 1594	: Pg=13.37, Qg=1.59 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 1594	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 1594	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 1599	: Pg=19.28, Qg=7.06 -> Pg=18.0, Qg=-0.5
% INFO    : Gen at bus 1599	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 1599	: Pg=8.28, Qg=7.06 -> Pg=18.0, Qg=-0.5
% INFO    : Gen at bus 1599	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 1605	: Pg=37.24, Qg=15.45 -> Pg=21.0, Qg=5.0
% INFO    : Gen at bus 1605	: Vg=1.034 -> Vg=1.0000005
% INFO    : Gen at bus 1619	: Vg=1.029 -> Vg=1.027779
% INFO    : Gen at bus 1619	: Vg=1.029 -> Vg=1.027779
% INFO    : Gen at bus 1630	: Vg=1.046 -> Vg=1.0377785
% INFO    : Gen at bus 1643	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 1644	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 1644	: Pg=4.01, Qg=0.0 -> Pg=5.95, Qg=0.0
% INFO    : Gen at bus 1644	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 1645	: Pg=2.57, Qg=-0.17 -> Pg=26.0, Qg=-1.5
% INFO    : Gen at bus 1645	: Vg=1.061 -> Vg=1.04444
% INFO    : Gen at bus 1648	: Vg=1.072 -> Vg=1.0000025
% INFO    : Gen at bus 1659	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 1675	: Vg=1.022 -> Vg=1.0111115
% INFO    : Gen at bus 1675	: Vg=1.022 -> Vg=1.0111115
% INFO    : Gen at bus 1684	: Pg=4.18, Qg=-0.36 -> Pg=5.5, Qg=0.0
% INFO    : Gen at bus 1684	: Vg=1.01 -> Vg=1.015872
% INFO    : Gen at bus 1684	: Pg=4.18, Qg=-0.36 -> Pg=5.5, Qg=0.0
% INFO    : Gen at bus 1684	: Vg=1.01 -> Vg=1.015872
% INFO    : Gen at bus 1685	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 1686	: Vg=1.025 -> Vg=1.015872
% INFO    : Gen at bus 1686	: Vg=1.025 -> Vg=1.015872
% INFO    : Gen at bus 1687	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 1688	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 1693	: Pg=2.14, Qg=2.13 -> Pg=3.55, Qg=0.07
% INFO    : Gen at bus 1693	: Vg=1.002 -> Vg=1.0000025
% INFO    : Gen at bus 1697	: Vg=1.036 -> Vg=1.0158755
% INFO    : Gen at bus 1697	: Vg=1.036 -> Vg=1.0158755
% INFO    : Gen at bus 1697	: Vg=1.036 -> Vg=1.0158755
% INFO    : Gen at bus 1700	: Vg=1.073 -> Vg=1.0000025
% INFO    : Gen at bus 1703	: Vg=1.044 -> Vg=1.0000025
% INFO    : Gen at bus 1704	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 1706	: Pg=13.28, Qg=-0.09 -> Pg=14.45, Qg=0.0
% INFO    : Gen at bus 1706	: Vg=1.041 -> Vg=0.999999
% INFO    : Gen at bus 1717	: Vg=1.071 -> Vg=1.015874
% INFO    : Gen at bus 1728	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 1728	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 1731	: Vg=1.035 -> Vg=1.027779
% INFO    : Gen at bus 1733	: Vg=1.034 -> Vg=0.999999
% INFO    : Gen at bus 1740	: Pg=17.09, Qg=2.18 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 1740	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 1740	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 1747	: Pg=35.35, Qg=15.57 -> Pg=20.0, Qg=1.0
% INFO    : Gen at bus 1747	: Vg=1.127 -> Vg=0.975
% INFO    : Gen at bus 1748	: Pg=31.89, Qg=14.97 -> Pg=20.0, Qg=1.0
% INFO    : Gen at bus 1748	: Vg=1.127 -> Vg=0.975
% INFO    : Gen at bus 1749	: Pg=35.35, Qg=14.3 -> Pg=20.0, Qg=1.0
% INFO    : Gen at bus 1749	: Vg=1.124 -> Vg=0.975
% INFO    : Gen at bus 1803	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 1813	: Vg=1.036 -> Vg=1.0000025
% INFO    : Gen at bus 1830	: Vg=1.001 -> Vg=1.022224
% INFO    : Gen at bus 1837	: Vg=1.028 -> Vg=1.0111115
% INFO    : Gen at bus 1843	: Vg=1.028 -> Vg=1.0158755
% INFO    : Gen at bus 1843	: Pg=1.17, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 1843	: Vg=1.028 -> Vg=1.0158755
% INFO    : Gen at bus 1853	: Vg=1.048 -> Vg=1.015872
% INFO    : Gen at bus 1853	: Vg=1.048 -> Vg=1.015872
% INFO    : Gen at bus 1861	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 1864	: Vg=1.077 -> Vg=1.0000025
% INFO    : Gen at bus 1864	: Vg=1.077 -> Vg=1.0000025
% INFO    : Gen at bus 1869	: Pg=1.15, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1869	: Vg=1.023 -> Vg=1.0111115
% INFO    : Gen at bus 1869	: Pg=8.15, Qg=0.0 -> Pg=18.25, Qg=0.0
% INFO    : Gen at bus 1869	: Vg=1.023 -> Vg=1.0111115
% INFO    : Gen at bus 1869	: Pg=11.15, Qg=0.0 -> Pg=21.75, Qg=0.0
% INFO    : Gen at bus 1869	: Vg=1.023 -> Vg=1.0111115
% INFO    : Gen at bus 1870	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 1871	: Pg=38.51, Qg=17.93 -> Pg=22.0, Qg=5.5
% INFO    : Gen at bus 1871	: Vg=1.009 -> Vg=1.0000005
% INFO    : Gen at bus 1872	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 1877	: Vg=1.068 -> Vg=1.000001
% INFO    : Gen at bus 1886	: Vg=1.011 -> Vg=1.022224
% INFO    : Gen at bus 1894	: Pg=16.13, Qg=-0.36 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1894	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 1895	: Pg=13.65, Qg=-0.97 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1895	: Vg=1.04 -> Vg=0.975
% INFO    : Gen at bus 1896	: Pg=17.53, Qg=1.7 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1896	: Vg=1.046 -> Vg=0.975
% INFO    : Gen at bus 1897	: Pg=17.03, Qg=1.68 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1897	: Vg=1.046 -> Vg=0.975
% INFO    : Gen at bus 1909	: Vg=1.024 -> Vg=0.999999
% INFO    : Gen at bus 1928	: Vg=1.066 -> Vg=1.000001
% INFO    : Gen at bus 1941	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 1940	: Vg=1.016 -> Vg=0.999999
% INFO    : Gen at bus 1949	: Vg=1.057 -> Vg=1.0000025
% INFO    : Gen at bus 1960	: Vg=1.017 -> Vg=1.0000025
% INFO    : Gen at bus 1968	: Pg=18.21, Qg=-2.5 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1968	: Vg=1.06 -> Vg=0.975
% INFO    : Gen at bus 1969	: Pg=17.25, Qg=1.41 -> Pg=12.0, Qg=0.705
% INFO    : Gen at bus 1969	: Vg=1.064 -> Vg=0.975
% INFO    : Gen at bus 1970	: Pg=18.19, Qg=-2.0 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1970	: Vg=1.06 -> Vg=0.975
% INFO    : Gen at bus 1971	: Pg=17.7, Qg=1.5 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1971	: Vg=1.064 -> Vg=0.975
% INFO    : Gen at bus 1972	: Pg=16.7, Qg=3.49 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1972	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 1981	: Pg=24.35, Qg=-1.64 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 1981	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 1981	: Pg=23.33, Qg=-1.64 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 1981	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 1982	: Pg=23.88, Qg=-6.82 -> Pg=14.5, Qg=-6.5
% INFO    : Gen at bus 1982	: Vg=1.007 -> Vg=0.999999
% INFO    : Gen at bus 1983	: Pg=24.36, Qg=-3.75 -> Pg=14.5, Qg=-5.0
% INFO    : Gen at bus 1983	: Vg=1.01 -> Vg=0.999999
% INFO    : Gen at bus 1985	: Vg=1.054 -> Vg=1.0000025
% INFO    : Gen at bus 1987	: Pg=0.5, Qg=-0.78 -> Pg=2.55, Qg=0.0
% INFO    : Gen at bus 1987	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 1987	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 1993	: Vg=1.05 -> Vg=0.999999
% INFO    : Gen at bus 2001	: Vg=0.967 -> Vg=0.9444445
% INFO    : Gen at bus 2008	: Pg=40.16, Qg=18.08 -> Pg=23.0, Qg=6.0
% INFO    : Gen at bus 2008	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 2019	: Pg=13.64, Qg=-8.6 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2019	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 2020	: Pg=14.29, Qg=-1.46 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2020	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 2020	: Pg=14.29, Qg=-1.46 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2020	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 2025	: Vg=1.021 -> Vg=1.027779
% INFO    : Gen at bus 2029	: Pg=19.35, Qg=2.48 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 2029	: Vg=1.041 -> Vg=1.000001
% INFO    : Gen at bus 2037	: Vg=1.018 -> Vg=1.0079355
% INFO    : Gen at bus 2051	: Pg=26.96, Qg=4.3 -> Pg=17.0, Qg=1.5
% INFO    : Gen at bus 2051	: Vg=1.023 -> Vg=0.999999
% INFO    : Gen at bus 2061	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 2085	: Vg=1.075 -> Vg=1.0000025
% INFO    : Gen at bus 2098	: Vg=1.013 -> Vg=1.0079355
% INFO    : Gen at bus 2099	: Pg=37.24, Qg=2.03 -> Pg=27.5, Qg=6.0
% INFO    : Gen at bus 2099	: Vg=1.053 -> Vg=1.022222
% INFO    : Gen at bus 2103	: Pg=3.43, Qg=2.85 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 2103	: Vg=1.011 -> Vg=1.0079355
% INFO    : Gen at bus 2123	: Vg=1.019 -> Vg=1.0079355
% INFO    : Gen at bus 2123	: Vg=1.019 -> Vg=1.0079355
% INFO    : Gen at bus 2151	: Vg=1.026 -> Vg=1.022224
% INFO    : Gen at bus 2151	: Vg=1.026 -> Vg=1.022224
% INFO    : Gen at bus 2161	: Pg=12.22, Qg=10.86 -> Pg=14.5, Qg=3.5
% INFO    : Gen at bus 2161	: Vg=1.061 -> Vg=1.027779
% INFO    : Gen at bus 2165	: Pg=39.86, Qg=0.78 -> Pg=22.5, Qg=6.0
% INFO    : Gen at bus 2165	: Vg=1.01 -> Vg=1.0000005
% INFO    : Gen at bus 2166	: Vg=1.058 -> Vg=1.033333
% INFO    : Gen at bus 2182	: Pg=0.08, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2182	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 2182	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 2187	: Vg=1.045 -> Vg=1.027779
% INFO    : Gen at bus 2190	: Vg=1.003 -> Vg=0.9682545
% INFO    : Gen at bus 2190	: Vg=1.003 -> Vg=0.9682545
% INFO    : Gen at bus 2192	: Vg=1.055 -> Vg=1.022222
% INFO    : Gen at bus 2193	: Pg=5.53, Qg=5.47 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 2193	: Vg=0.967 -> Vg=0.9444445
% INFO    : Gen at bus 2195	: Pg=14.8, Qg=2.0 -> Pg=10.0, Qg=1.95
% INFO    : Gen at bus 2195	: Vg=1.063 -> Vg=1.000001
% INFO    : Gen at bus 2226	: Vg=1.04 -> Vg=1.022222
% INFO    : Gen at bus 2226	: Vg=1.04 -> Vg=1.022222
% INFO    : Gen at bus 2245	: Vg=1.005 -> Vg=1.0158755
% INFO    : Gen at bus 2245	: Vg=1.005 -> Vg=1.0158755
% INFO    : Gen at bus 2247	: Vg=1.082 -> Vg=0.975
% INFO    : Gen at bus 2247	: Pg=2.5, Qg=1.23 -> Pg=13.25, Qg=0.0
% INFO    : Gen at bus 2247	: Vg=1.082 -> Vg=0.975
% INFO    : Gen at bus 2281	: Vg=1.019 -> Vg=1.0158755
% INFO    : Gen at bus 2291	: Vg=1.037 -> Vg=1.022224
% INFO    : Gen at bus 2295	: Vg=0.991 -> Vg=1.0000005
% INFO    : Gen at bus 2297	: Vg=1.015 -> Vg=1.0000005
% INFO    : Gen at bus 2303	: Vg=1.011 -> Vg=1.0158755
% INFO    : Gen at bus 2303	: Vg=1.011 -> Vg=1.0158755
% INFO    : Gen at bus 2329	: Vg=1.014 -> Vg=1.0158755
% INFO    : Gen at bus 2335	: Vg=1.024 -> Vg=1.015872
% INFO    : Gen at bus 2339	: Vg=1.051 -> Vg=1.0079355
% INFO    : Gen at bus 2341	: Pg=12.12, Qg=-4.91 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 2341	: Vg=0.987 -> Vg=1.015872
% INFO    : Gen at bus 2341	: Pg=13.12, Qg=-4.91 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 2341	: Vg=0.987 -> Vg=1.015872
% INFO    : Gen at bus 2341	: Pg=15.12, Qg=-4.91 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 2341	: Vg=0.987 -> Vg=1.015872
% INFO    : Gen at bus 2342	: Vg=1.056 -> Vg=1.0000025
% INFO    : Gen at bus 2342	: Vg=1.056 -> Vg=1.0000025
% INFO    : Gen at bus 2343	: Vg=1.01 -> Vg=1.022224
% INFO    : Gen at bus 2364	: Pg=19.32, Qg=10.01 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2364	: Vg=1.101 -> Vg=0.975
% INFO    : Gen at bus 2365	: Pg=19.32, Qg=10.98 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2365	: Vg=1.103 -> Vg=0.975
% INFO    : Gen at bus 2366	: Pg=14.09, Qg=-1.92 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2366	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 2367	: Pg=19.32, Qg=10.88 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2367	: Vg=1.102 -> Vg=0.975
% INFO    : Gen at bus 2368	: Pg=10.02, Qg=16.21 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 2368	: Vg=1.111 -> Vg=0.975
% INFO    : Gen at bus 2378	: Vg=1.019 -> Vg=1.0158755
% INFO    : Gen at bus 2394	: Pg=2.09, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2394	: Vg=1.022 -> Vg=1.0000025
% INFO    : Gen at bus 2396	: Pg=3.1, Qg=0.0 -> Pg=17.45, Qg=0.0
% INFO    : Gen at bus 2396	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 2396	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 2412	: Pg=8.15, Qg=0.25 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 2412	: Vg=1.06 -> Vg=1.000001
% INFO    : Gen at bus 2414	: Vg=1.016 -> Vg=1.0079355
% INFO    : Gen at bus 2414	: Vg=1.016 -> Vg=1.0079355
% INFO    : Gen at bus 2421	: Vg=1.022 -> Vg=1.0158755
% INFO    : Gen at bus 2421	: Vg=1.022 -> Vg=1.0158755
% INFO    : Gen at bus 2421	: Vg=1.022 -> Vg=1.0158755
% INFO    : Gen at bus 2433	: Vg=1.015 -> Vg=1.0079355
% INFO    : Gen at bus 2437	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 2437	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 2440	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 2440	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 2445	: Vg=1.019 -> Vg=1.0079355
% INFO    : Gen at bus 2444	: Vg=1.015 -> Vg=1.0079355
% INFO    : Gen at bus 2460	: Vg=1.091 -> Vg=1.045365
% INFO    : Gen at bus 2461	: Vg=1.0 -> Vg=1.015872
% INFO    : Gen at bus 2461	: Vg=1.0 -> Vg=1.015872
% INFO    : Gen at bus 2464	: Vg=1.006 -> Vg=1.022224
% INFO    : Gen at bus 2475	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 2481	: Pg=18.17, Qg=0.0 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 2481	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 2495	: Vg=1.018 -> Vg=1.015872
% INFO    : Gen at bus 2523	: Pg=38.23, Qg=6.98 -> Pg=44.0, Qg=5.5
% INFO    : Gen at bus 2523	: Vg=1.135 -> Vg=1.049058
% INFO    : Gen at bus 2523	: Pg=39.23, Qg=6.98 -> Pg=44.0, Qg=5.5
% INFO    : Gen at bus 2523	: Vg=1.135 -> Vg=1.049058
% INFO    : Gen at bus 2529	: Pg=7.04, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 2529	: Vg=0.993 -> Vg=1.0000025
% INFO    : Gen at bus 2529	: Pg=14.04, Qg=0.0 -> Pg=18.425, Qg=0.0
% INFO    : Gen at bus 2529	: Vg=0.993 -> Vg=1.0000025
% INFO    : Gen at bus 2530	: Vg=1.01 -> Vg=1.0000025
% INFO    : Gen at bus 2530	: Vg=1.01 -> Vg=1.0000025
% INFO    : Gen at bus 2532	: Pg=3.66, Qg=0.4 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 2532	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 2545	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 2547	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 2555	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 2555	: Pg=8.19, Qg=0.0 -> Pg=17.0, Qg=0.0
% INFO    : Gen at bus 2555	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 2558	: Pg=3.31, Qg=-0.0 -> Pg=8.0, Qg=1.5
% INFO    : Gen at bus 2558	: Vg=1.013 -> Vg=0.999999
% INFO    : Gen at bus 2563	: Vg=1.013 -> Vg=1.0079355
% INFO    : Gen at bus 2576	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 2576	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 2581	: Vg=1.035 -> Vg=1.022224
% INFO    : Gen at bus 2586	: Vg=1.011 -> Vg=1.022224
% INFO    : Gen at bus 2586	: Vg=1.011 -> Vg=1.022224
% INFO    : Gen at bus 2592	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 2601	: Vg=1.004 -> Vg=1.0079355
% INFO    : Gen at bus 2601	: Vg=1.004 -> Vg=1.0079355
% INFO    : Gen at bus 2610	: Pg=14.05, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 2610	: Vg=1.026 -> Vg=1.0000025
% INFO    : Gen at bus 2611	: Vg=0.997 -> Vg=1.015872
% INFO    : Gen at bus 2616	: Vg=1.016 -> Vg=1.022224
% INFO    : Gen at bus 2624	: Vg=1.047 -> Vg=1.0111115
% INFO    : Gen at bus 2624	: Vg=1.047 -> Vg=1.0111115
% INFO    : Gen at bus 2627	: Pg=5.99, Qg=-0.72 -> Pg=14.0, Qg=4.5
% INFO    : Gen at bus 2627	: Vg=0.994 -> Vg=1.0158755
% INFO    : Gen at bus 2640	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 2640	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 2640	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 2643	: Vg=1.029 -> Vg=1.0000025
% INFO    : Gen at bus 2644	: Pg=13.17, Qg=-7.75 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 2644	: Vg=1.029 -> Vg=1.0000025
% INFO    : Gen at bus 2645	: Pg=4.26, Qg=0.31 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 2645	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 2645	: Pg=3.26, Qg=0.31 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 2645	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 2645	: Pg=11.26, Qg=0.31 -> Pg=14.5, Qg=-4.0
% INFO    : Gen at bus 2645	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 2646	: Vg=1.088 -> Vg=1.0042125
% INFO    : Gen at bus 2646	: Vg=1.088 -> Vg=1.0042125
% INFO    : Gen at bus 2646	: Vg=1.088 -> Vg=1.0042125
% INFO    : Gen at bus 2649	: Vg=0.998 -> Vg=1.0158755
% INFO    : Gen at bus 2649	: Vg=0.998 -> Vg=1.0158755
% INFO    : Gen at bus 2652	: Pg=3.24, Qg=4.0 -> Pg=14.0, Qg=3.95
% INFO    : Gen at bus 2652	: Vg=1.067 -> Vg=1.0000025
% INFO    : Gen at bus 2659	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 2659	: Pg=5.16, Qg=-0.66 -> Pg=4.9, Qg=0.0
% INFO    : Gen at bus 2659	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 2660	: Pg=27.35, Qg=9.53 -> Pg=17.5, Qg=-1.5
% INFO    : Gen at bus 2660	: Vg=1.018 -> Vg=1.015872
% INFO    : Gen at bus 2660	: Pg=29.35, Qg=9.53 -> Pg=17.5, Qg=-1.5
% INFO    : Gen at bus 2660	: Vg=1.018 -> Vg=1.015872
% INFO    : Gen at bus 2663	: Vg=1.048 -> Vg=0.975
% INFO    : Gen at bus 2664	: Pg=1.22, Qg=0.9 -> Pg=3.5, Qg=0.95
% INFO    : Gen at bus 2664	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 2663	: Vg=1.048 -> Vg=0.975
% INFO    : Gen at bus 2662	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 2664	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 2665	: Pg=2.05, Qg=4.43 -> Pg=6.0, Qg=-1.285
% INFO    : Gen at bus 2665	: Vg=1.048 -> Vg=1.0000025
% INFO    : Gen at bus 2669	: Vg=0.62 -> Vg=0.825
% INFO    : Gen at bus 2669	: Vg=0.62 -> Vg=0.825
% INFO    : Gen at bus 2669	: Vg=0.62 -> Vg=0.825
% INFO    : Gen at bus 2669	: Vg=0.62 -> Vg=0.825
% INFO    : Gen at bus 2669	: Vg=0.62 -> Vg=0.825
% INFO    : Gen at bus 2674	: Vg=0.997 -> Vg=1.0079355
% INFO    : Gen at bus 2688	: Pg=1.14, Qg=0.0 -> Pg=18.2, Qg=0.0
% INFO    : Gen at bus 2688	: Vg=1.055 -> Vg=1.033333
% INFO    : Gen at bus 2695	: Pg=4.09, Qg=-4.01 -> Pg=7.5, Qg=-0.5
% INFO    : Gen at bus 2695	: Vg=1.0 -> Vg=1.0000005
% INFO    : Gen at bus 2729	: Vg=1.039 -> Vg=1.022224
% INFO    : Gen at bus 2734	: Pg=2.06, Qg=-0.76 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 2734	: Vg=1.053 -> Vg=1.000001
% INFO    : Gen at bus 2734	: Pg=2.06, Qg=-0.76 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 2734	: Vg=1.053 -> Vg=1.000001
% INFO    : Gen at bus 2766	: Pg=8.15, Qg=0.0 -> Pg=13.25, Qg=0.0
% INFO    : Gen at bus 2766	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 2776	: Vg=1.019 -> Vg=1.0158755
% INFO    : Gen at bus 2812	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 2813	: Pg=4.22, Qg=0.0 -> Pg=8.075, Qg=0.0
% INFO    : Gen at bus 2813	: Vg=1.011 -> Vg=0.984126
% INFO    : Gen at bus 2818	: Vg=1.055 -> Vg=1.0000025
% INFO    : Gen at bus 2822	: Vg=1.059 -> Vg=1.022224
% INFO    : Gen at bus 2833	: Pg=6.17, Qg=4.89 -> Pg=6.0, Qg=1.5
% INFO    : Gen at bus 2833	: Vg=1.01 -> Vg=1.0000005
% INFO    : Gen at bus 2838	: Vg=1.05 -> Vg=1.033334
% INFO    : Gen at bus 2840	: Pg=4.19, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 2840	: Vg=1.036 -> Vg=1.022224
% INFO    : Gen at bus 2840	: Pg=0.19, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2840	: Vg=1.036 -> Vg=1.022224
% INFO    : Gen at bus 2843	: Vg=0.988 -> Vg=1.022224
% INFO    : Gen at bus 2843	: Pg=1.87, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 2843	: Vg=0.988 -> Vg=1.022224
% INFO    : Gen at bus 2845	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 2845	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 2857	: Vg=1.048 -> Vg=1.0079355
% INFO    : Gen at bus 2868	: Vg=1.014 -> Vg=1.022224
% INFO    : Gen at bus 2874	: Vg=1.058 -> Vg=1.027779
% INFO    : Gen at bus 2876	: Vg=1.006 -> Vg=1.022224
% INFO    : Gen at bus 2876	: Vg=1.006 -> Vg=1.022224
% INFO    : Gen at bus 2884	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 2899	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 2899	: Pg=4.0, Qg=-0.54 -> Pg=16.25, Qg=0.0
% INFO    : Gen at bus 2899	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 2899	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 2904	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 2904	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 2904	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 2908	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 2928	: Vg=1.0 -> Vg=0.999999
% INFO    : Gen at bus 2929	: Vg=1.029 -> Vg=1.000001
% INFO    : Gen at bus 2941	: Vg=1.012 -> Vg=1.022224
% INFO    : Gen at bus 2948	: Vg=0.987 -> Vg=1.0158755
% INFO    : Gen at bus 2954	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 2954	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 2975	: Vg=1.019 -> Vg=1.0158755
% INFO    : Gen at bus 2982	: Vg=1.048 -> Vg=1.027779
% INFO    : Gen at bus 2993	: Pg=10.28, Qg=-3.36 -> Pg=17.0, Qg=0.0
% INFO    : Gen at bus 2993	: Vg=1.05 -> Vg=0.999999
% INFO    : Gen at bus 3020	: Vg=1.009 -> Vg=1.0158755
% INFO    : Gen at bus 3020	: Vg=1.009 -> Vg=1.0158755
% INFO    : Gen at bus 3021	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 3022	: Pg=7.2, Qg=-3.58 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 3022	: Vg=1.044 -> Vg=1.001294
% INFO    : Gen at bus 3022	: Pg=7.2, Qg=-3.58 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 3022	: Vg=1.044 -> Vg=1.001294
% INFO    : Gen at bus 3024	: Vg=1.014 -> Vg=1.022224
% INFO    : Gen at bus 3027	: Vg=1.028 -> Vg=1.0000025
% INFO    : Gen at bus 3027	: Vg=1.028 -> Vg=1.0000025
% INFO    : Gen at bus 3029	: Vg=1.045 -> Vg=1.022222
% INFO    : Gen at bus 3036	: Vg=1.016 -> Vg=1.015872
% INFO    : Gen at bus 3038	: Vg=1.074 -> Vg=1.044445
% INFO    : Gen at bus 3049	: Pg=2.24, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 3049	: Vg=0.999 -> Vg=1.015872
% INFO    : Gen at bus 3059	: Vg=1.038 -> Vg=0.999999
% INFO    : Gen at bus 3060	: Vg=1.014 -> Vg=1.022224
% INFO    : Gen at bus 3070	: Pg=4.13, Qg=0.0 -> Pg=8.625, Qg=0.0
% INFO    : Gen at bus 3070	: Vg=0.994 -> Vg=1.015872
% INFO    : Gen at bus 3098	: Vg=0.991 -> Vg=0.9444445
% INFO    : Gen at bus 3107	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 3110	: Vg=1.052 -> Vg=1.0377785
% INFO    : Gen at bus 3113	: Vg=1.01 -> Vg=1.0079355
% INFO    : Gen at bus 3116	: Pg=33.38, Qg=1.75 -> Pg=19.0, Qg=0.5
% INFO    : Gen at bus 3116	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 3117	: Pg=29.86, Qg=12.44 -> Pg=19.0, Qg=0.5
% INFO    : Gen at bus 3117	: Vg=1.108 -> Vg=0.975
% INFO    : Gen at bus 3118	: Pg=30.85, Qg=11.52 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3118	: Vg=1.105 -> Vg=0.975
% INFO    : Gen at bus 3122	: Vg=1.029 -> Vg=1.022224
% INFO    : Gen at bus 3123	: Vg=1.039 -> Vg=0.999999
% INFO    : Gen at bus 3123	: Vg=1.039 -> Vg=0.999999
% INFO    : Gen at bus 3125	: Pg=6.99, Qg=0.0 -> Pg=10.4, Qg=0.0
% INFO    : Gen at bus 3125	: Vg=1.023 -> Vg=0.999999
% INFO    : Gen at bus 3126	: Vg=1.045 -> Vg=1.0000025
% INFO    : Gen at bus 3131	: Vg=0.985 -> Vg=1.015872
% INFO    : Gen at bus 3132	: Vg=1.01 -> Vg=1.022224
% INFO    : Gen at bus 3132	: Vg=1.01 -> Vg=1.022224
% INFO    : Gen at bus 3136	: Pg=5.14, Qg=1.0 -> Pg=5.5, Qg=0.95
% INFO    : Gen at bus 3136	: Vg=1.065 -> Vg=1.000001
% INFO    : Gen at bus 3136	: Pg=5.14, Qg=0.1 -> Pg=7.0, Qg=0.0
% INFO    : Gen at bus 3136	: Vg=1.065 -> Vg=1.000001
% INFO    : Gen at bus 3140	: Vg=1.066 -> Vg=1.0377785
% INFO    : Gen at bus 3140	: Vg=1.066 -> Vg=1.0377785
% INFO    : Gen at bus 3142	: Vg=1.036 -> Vg=1.0000025
% INFO    : Gen at bus 3147	: Pg=1.07, Qg=0.0 -> Pg=5.25, Qg=0.0
% INFO    : Gen at bus 3147	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 3147	: Pg=3.07, Qg=0.0 -> Pg=4.3, Qg=0.0
% INFO    : Gen at bus 3147	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 3151	: Vg=0.994 -> Vg=1.0158755
% INFO    : Gen at bus 3157	: Pg=38.21, Qg=2.37 -> Pg=26.5, Qg=6.0
% INFO    : Gen at bus 3157	: Vg=1.049 -> Vg=1.0111115
% INFO    : Gen at bus 3159	: Pg=5.09, Qg=1.0 -> Pg=8.0, Qg=0.95
% INFO    : Gen at bus 3159	: Vg=1.067 -> Vg=1.000001
% INFO    : Gen at bus 3159	: Pg=5.09, Qg=1.0 -> Pg=8.0, Qg=0.95
% INFO    : Gen at bus 3159	: Vg=1.067 -> Vg=1.000001
% INFO    : Gen at bus 3159	: Pg=3.2, Qg=2.77 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3159	: Vg=1.067 -> Vg=1.000001
% INFO    : Gen at bus 3178	: Vg=1.017 -> Vg=1.0
% INFO    : Gen at bus 3178	: Vg=1.017 -> Vg=1.0
% INFO    : Gen at bus 3185	: Vg=1.024 -> Vg=1.000001
% INFO    : Gen at bus 3185	: Vg=1.024 -> Vg=1.000001
% INFO    : Gen at bus 3188	: Pg=2.22, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3188	: Vg=1.061 -> Vg=1.003564
% INFO    : Gen at bus 3188	: Vg=1.061 -> Vg=1.003564
% INFO    : Gen at bus 3210	: Pg=6.23, Qg=0.81 -> Pg=10.0, Qg=1.0
% INFO    : Gen at bus 3210	: Vg=1.099 -> Vg=1.0
% INFO    : Gen at bus 3219	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 3219	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 3238	: Vg=1.009 -> Vg=1.0158755
% INFO    : Gen at bus 3239	: Pg=13.4, Qg=2.0 -> Pg=11.0, Qg=1.95
% INFO    : Gen at bus 3239	: Vg=1.067 -> Vg=1.000001
% INFO    : Gen at bus 3241	: Vg=0.999 -> Vg=0.999999
% INFO    : Gen at bus 3244	: Vg=1.038 -> Vg=1.027779
% INFO    : Gen at bus 3246	: Pg=3.98, Qg=2.6 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3246	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 3250	: Vg=1.019 -> Vg=1.022224
% INFO    : Gen at bus 3260	: Vg=1.039 -> Vg=1.027779
% INFO    : Gen at bus 3264	: Pg=0.08, Qg=0.1 -> Pg=3.0, Qg=0.0
% INFO    : Gen at bus 3264	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 3265	: Pg=10.19, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3265	: Vg=1.037 -> Vg=1.022224
% INFO    : Gen at bus 3265	: Pg=6.19, Qg=0.0 -> Pg=16.35, Qg=0.0
% INFO    : Gen at bus 3265	: Vg=1.037 -> Vg=1.022224
% INFO    : Gen at bus 3265	: Vg=1.037 -> Vg=1.022224
% INFO    : Gen at bus 3266	: Pg=25.23, Qg=11.76 -> Pg=21.0, Qg=2.5
% INFO    : Gen at bus 3266	: Vg=1.056 -> Vg=1.0
% INFO    : Gen at bus 3266	: Pg=29.38, Qg=11.76 -> Pg=21.0, Qg=2.5
% INFO    : Gen at bus 3266	: Vg=1.056 -> Vg=1.0
% INFO    : Gen at bus 3276	: Vg=1.039 -> Vg=1.0000025
% INFO    : Gen at bus 3276	: Vg=1.039 -> Vg=1.0000025
% INFO    : Gen at bus 3280	: Pg=30.88, Qg=15.37 -> Pg=18.05, Qg=2.5
% INFO    : Gen at bus 3280	: Vg=1.129 -> Vg=0.975
% INFO    : Gen at bus 3281	: Pg=31.47, Qg=13.08 -> Pg=18.05, Qg=2.5
% INFO    : Gen at bus 3281	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 3282	: Pg=31.47, Qg=4.84 -> Pg=18.05, Qg=2.5
% INFO    : Gen at bus 3282	: Vg=1.05 -> Vg=0.975
% INFO    : Gen at bus 3295	: Vg=1.014 -> Vg=0.999999
% INFO    : Gen at bus 3301	: Pg=4.95, Qg=1.33 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 3301	: Vg=1.057 -> Vg=1.019842
% INFO    : Gen at bus 3308	: Pg=3.86, Qg=1.0 -> Pg=8.5, Qg=0.95
% INFO    : Gen at bus 3308	: Vg=1.014 -> Vg=1.0000025
% INFO    : Gen at bus 3308	: Pg=3.86, Qg=1.0 -> Pg=8.5, Qg=0.95
% INFO    : Gen at bus 3308	: Vg=1.014 -> Vg=1.0000025
% INFO    : Gen at bus 3313	: Vg=1.031 -> Vg=0.999999
% INFO    : Gen at bus 3313	: Pg=1.29, Qg=0.0 -> Pg=5.1, Qg=0.0
% INFO    : Gen at bus 3313	: Vg=1.031 -> Vg=0.999999
% INFO    : Gen at bus 3315	: Vg=1.034 -> Vg=1.022224
% INFO    : Gen at bus 3315	: Vg=1.034 -> Vg=1.022224
% INFO    : Gen at bus 3339	: Vg=0.994 -> Vg=1.022224
% INFO    : Gen at bus 3345	: Vg=1.052 -> Vg=0.999999
% INFO    : Gen at bus 3377	: Vg=1.036 -> Vg=1.027779
% INFO    : Gen at bus 3377	: Vg=1.036 -> Vg=1.027779
% INFO    : Gen at bus 3382	: Pg=0.08, Qg=0.0 -> Pg=19.9, Qg=0.0
% INFO    : Gen at bus 3382	: Vg=1.044 -> Vg=1.0111115
% INFO    : Gen at bus 3383	: Vg=1.055 -> Vg=1.0000025
% INFO    : Gen at bus 3405	: Pg=38.19, Qg=15.94 -> Pg=21.5, Qg=6.0
% INFO    : Gen at bus 3405	: Vg=1.035 -> Vg=1.0158755
% INFO    : Gen at bus 3408	: Pg=7.51, Qg=-7.0 -> Pg=12.0, Qg=-0.255
% INFO    : Gen at bus 3408	: Vg=1.053 -> Vg=1.000214
% INFO    : Gen at bus 3418	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 3418	: Pg=2.27, Qg=1.0 -> Pg=3.75, Qg=0.0
% INFO    : Gen at bus 3418	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 3418	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 3418	: Pg=2.27, Qg=1.0 -> Pg=3.75, Qg=0.0
% INFO    : Gen at bus 3418	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 3418	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 3423	: Pg=2.16, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 3423	: Vg=1.034 -> Vg=1.022224
% INFO    : Gen at bus 3423	: Pg=3.16, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3423	: Vg=1.034 -> Vg=1.022224
% INFO    : Gen at bus 3424	: Pg=11.1, Qg=-1.24 -> Pg=11.55, Qg=0.0
% INFO    : Gen at bus 3424	: Vg=1.003 -> Vg=0.999999
% INFO    : Gen at bus 3424	: Pg=11.1, Qg=-1.24 -> Pg=11.55, Qg=0.0
% INFO    : Gen at bus 3424	: Vg=1.003 -> Vg=0.999999
% INFO    : Gen at bus 3431	: Vg=0.997 -> Vg=1.015872
% INFO    : Gen at bus 3434	: Vg=1.005 -> Vg=1.022224
% INFO    : Gen at bus 3437	: Vg=1.041 -> Vg=1.022224
% INFO    : Gen at bus 3440	: Vg=1.064 -> Vg=1.0080855
% INFO    : Gen at bus 3440	: Vg=1.064 -> Vg=1.0080855
% INFO    : Gen at bus 3445	: Vg=1.038 -> Vg=1.0079355
% INFO    : Gen at bus 3450	: Vg=1.032 -> Vg=1.0079355
% INFO    : Gen at bus 3451	: Vg=1.021 -> Vg=1.0079355
% INFO    : Gen at bus 3454	: Vg=1.049 -> Vg=1.027779
% INFO    : Gen at bus 3461	: Pg=0.98, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3461	: Vg=0.994 -> Vg=1.0158755
% INFO    : Gen at bus 3468	: Pg=6.99, Qg=-2.27 -> Pg=6.6, Qg=0.0
% INFO    : Gen at bus 3468	: Vg=1.029 -> Vg=0.999999
% INFO    : Gen at bus 3488	: Vg=1.025 -> Vg=1.0079355
% INFO    : Gen at bus 3491	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 3491	: Pg=40.76, Qg=-7.08 -> Pg=26.5, Qg=3.5
% INFO    : Gen at bus 3491	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 3495	: Vg=1.004 -> Vg=1.0079355
% INFO    : Gen at bus 3504	: Pg=23.36, Qg=-5.03 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 3504	: Vg=1.073 -> Vg=1.044445
% INFO    : Gen at bus 3505	: Vg=1.024 -> Vg=0.975
% INFO    : Gen at bus 3507	: Vg=1.04 -> Vg=0.999999
% INFO    : Gen at bus 3508	: Vg=1.038 -> Vg=0.999999
% INFO    : Gen at bus 3513	: Pg=17.16, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3513	: Vg=1.018 -> Vg=1.0158755
% INFO    : Gen at bus 3513	: Pg=1.16, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 3513	: Vg=1.018 -> Vg=1.0158755
% INFO    : Gen at bus 3521	: Vg=1.06 -> Vg=0.999999
% INFO    : Gen at bus 3530	: Pg=5.19, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3530	: Vg=0.989 -> Vg=1.015872
% INFO    : Gen at bus 3544	: Pg=5.4, Qg=-1.37 -> Pg=6.4, Qg=0.0
% INFO    : Gen at bus 3544	: Vg=1.042 -> Vg=0.999999
% INFO    : Gen at bus 3545	: Vg=1.056 -> Vg=1.0079355
% INFO    : Gen at bus 3550	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 3550	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 3550	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 3549	: Vg=1.124 -> Vg=1.0414805
% INFO    : Gen at bus 3584	: Vg=1.035 -> Vg=1.027779
% INFO    : Gen at bus 3587	: Pg=15.15, Qg=-2.52 -> Pg=10.4, Qg=-2.0
% INFO    : Gen at bus 3587	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 3587	: Pg=14.16, Qg=-2.52 -> Pg=10.4, Qg=0.0
% INFO    : Gen at bus 3587	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 3586	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 3586	: Pg=15.28, Qg=-2.53 -> Pg=10.4, Qg=0.0
% INFO    : Gen at bus 3586	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 3600	: Pg=11.96, Qg=-1.39 -> Pg=11.5, Qg=0.5
% INFO    : Gen at bus 3600	: Vg=1.069 -> Vg=1.000001
% INFO    : Gen at bus 3600	: Pg=11.96, Qg=-1.39 -> Pg=11.5, Qg=0.5
% INFO    : Gen at bus 3600	: Vg=1.069 -> Vg=1.000001
% INFO    : Gen at bus 3600	: Pg=12.94, Qg=-1.39 -> Pg=11.5, Qg=0.5
% INFO    : Gen at bus 3600	: Vg=1.069 -> Vg=1.000001
% INFO    : Gen at bus 3604	: Pg=11.31, Qg=3.66 -> Pg=0.0, Qg=10.0
% INFO    : Gen at bus 3604	: Vg=1.008 -> Vg=0.999999
% INFO    : Gen at bus 3604	: Pg=11.31, Qg=3.66 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 3604	: Vg=1.008 -> Vg=0.999999
% INFO    : Gen at bus 3636	: Vg=1.051 -> Vg=1.001569
% INFO    : Gen at bus 3646	: Pg=1.13, Qg=0.0 -> Pg=7.445, Qg=0.0
% INFO    : Gen at bus 3646	: Vg=0.987 -> Vg=1.0000025
% INFO    : Gen at bus 3646	: Pg=24.13, Qg=0.0 -> Pg=17.385, Qg=0.0
% INFO    : Gen at bus 3646	: Vg=0.987 -> Vg=1.0000025
% INFO    : Gen at bus 3649	: Vg=1.007 -> Vg=1.022224
% INFO    : Gen at bus 3651	: Pg=0.0, Qg=1.0 -> Pg=3.5, Qg=0.95
% INFO    : Gen at bus 3651	: Vg=1.057 -> Vg=1.0000025
% INFO    : Gen at bus 3651	: Pg=0.0, Qg=1.0 -> Pg=3.5, Qg=0.95
% INFO    : Gen at bus 3651	: Vg=1.057 -> Vg=1.0000025
% INFO    : Gen at bus 3652	: Vg=1.034 -> Vg=1.0158755
% INFO    : Gen at bus 3657	: Vg=1.021 -> Vg=1.0000025
% INFO    : Gen at bus 3660	: Vg=1.027 -> Vg=1.0158755
% INFO    : Gen at bus 3661	: Vg=1.021 -> Vg=1.0079355
% INFO    : Gen at bus 3667	: Vg=1.0 -> Vg=0.999999
% INFO    : Gen at bus 3667	: Vg=1.0 -> Vg=0.999999
% INFO    : Gen at bus 3668	: Vg=1.031 -> Vg=0.999999
% INFO    : Gen at bus 3684	: Vg=1.034 -> Vg=1.015872
% INFO    : Gen at bus 3686	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 3692	: Pg=0.1, Qg=-0.14 -> Pg=4.75, Qg=0.0
% INFO    : Gen at bus 3692	: Vg=1.04 -> Vg=0.999999
% INFO    : Gen at bus 3694	: Vg=1.05 -> Vg=1.0111115
% INFO    : Gen at bus 3696	: Vg=1.038 -> Vg=0.999999
% INFO    : Gen at bus 3713	: Vg=1.038 -> Vg=1.0079355
% INFO    : Gen at bus 3715	: Pg=8.58, Qg=7.61 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3715	: Vg=1.048 -> Vg=1.027779
% INFO    : Gen at bus 3716	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 3717	: Pg=39.27, Qg=1.34 -> Pg=22.0, Qg=0.0
% INFO    : Gen at bus 3717	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 3744	: Vg=1.049 -> Vg=0.999999
% INFO    : Gen at bus 3748	: Pg=6.38, Qg=0.91 -> Pg=8.4, Qg=0.25
% INFO    : Gen at bus 3748	: Vg=1.029 -> Vg=0.999999
% INFO    : Gen at bus 3753	: Pg=5.89, Qg=0.0 -> Pg=21.5, Qg=0.0
% INFO    : Gen at bus 3753	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 3758	: Pg=0.21, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3758	: Vg=1.025 -> Vg=0.984126
% INFO    : Gen at bus 3758	: Pg=5.21, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 3758	: Vg=1.025 -> Vg=0.984126
% INFO    : Gen at bus 3760	: Vg=1.008 -> Vg=1.0079355
% INFO    : Gen at bus 3761	: Pg=4.07, Qg=0.6 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3761	: Vg=1.011 -> Vg=1.0158755
% INFO    : Gen at bus 3796	: Vg=1.061 -> Vg=1.0000025
% INFO    : Gen at bus 3796	: Vg=1.061 -> Vg=1.0000025
% INFO    : Gen at bus 3799	: Pg=2.22, Qg=0.0 -> Pg=13.125, Qg=0.0
% INFO    : Gen at bus 3799	: Vg=1.028 -> Vg=1.0000025
% INFO    : Gen at bus 3799	: Pg=5.22, Qg=0.0 -> Pg=10.125, Qg=0.0
% INFO    : Gen at bus 3799	: Vg=1.028 -> Vg=1.0000025
% INFO    : Gen at bus 3799	: Vg=1.028 -> Vg=1.0000025
% INFO    : Gen at bus 3801	: Pg=2.08, Qg=0.0 -> Pg=10.01, Qg=0.0
% INFO    : Gen at bus 3801	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 3801	: Pg=1.08, Qg=0.0 -> Pg=10.175, Qg=0.0
% INFO    : Gen at bus 3801	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 3816	: Pg=33.19, Qg=-3.65 -> Pg=18.9, Qg=2.0
% INFO    : Gen at bus 3816	: Vg=1.05 -> Vg=0.975
% INFO    : Gen at bus 3817	: Pg=33.19, Qg=-0.03 -> Pg=18.9, Qg=2.0
% INFO    : Gen at bus 3817	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 3818	: Pg=33.17, Qg=1.41 -> Pg=18.9, Qg=2.0
% INFO    : Gen at bus 3818	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 3822	: Vg=1.025 -> Vg=1.022224
% INFO    : Gen at bus 3826	: Pg=1.14, Qg=0.0 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 3826	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 3836	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 3842	: Pg=5.69, Qg=-3.13 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3842	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 3842	: Pg=5.69, Qg=-3.13 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 3842	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 3853	: Pg=4.2, Qg=-2.93 -> Pg=11.0, Qg=1.0
% INFO    : Gen at bus 3853	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 3863	: Vg=1.041 -> Vg=1.022224
% INFO    : Gen at bus 3868	: Pg=2.77, Qg=3.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 3868	: Vg=1.011 -> Vg=1.022224
% INFO    : Gen at bus 3869	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 3876	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 3889	: Vg=1.011 -> Vg=1.0277795
% INFO    : Gen at bus 3893	: Vg=1.034 -> Vg=1.0079355
% INFO    : Gen at bus 3893	: Vg=1.034 -> Vg=1.0079355
% INFO    : Gen at bus 3904	: Vg=1.028 -> Vg=1.0079355
% INFO    : Gen at bus 3904	: Vg=1.028 -> Vg=1.0079355
% INFO    : Gen at bus 3919	: Vg=1.055 -> Vg=1.0000025
% INFO    : Gen at bus 3924	: Pg=0.18, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 3924	: Vg=1.045 -> Vg=1.015874
% INFO    : Gen at bus 3925	: Pg=9.15, Qg=0.0 -> Pg=27.5, Qg=0.0
% INFO    : Gen at bus 3925	: Vg=1.039 -> Vg=1.026667
% INFO    : Gen at bus 3927	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 3939	: Vg=1.028 -> Vg=1.000001
% INFO    : Gen at bus 3940	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 3951	: Pg=0.21, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3951	: Vg=1.009 -> Vg=1.0158755
% INFO    : Gen at bus 3969	: Pg=33.15, Qg=-2.05 -> Pg=20.5, Qg=0.0
% INFO    : Gen at bus 3969	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 3969	: Pg=34.14, Qg=-2.05 -> Pg=20.5, Qg=0.0
% INFO    : Gen at bus 3969	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 3968	: Pg=32.05, Qg=-1.23 -> Pg=20.5, Qg=-5.0
% INFO    : Gen at bus 3968	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 3968	: Pg=31.06, Qg=-1.23 -> Pg=20.5, Qg=-5.0
% INFO    : Gen at bus 3968	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 3977	: Vg=1.021 -> Vg=1.000001
% INFO    : Gen at bus 3977	: Vg=1.021 -> Vg=1.000001
% INFO    : Gen at bus 3987	: Vg=1.001 -> Vg=1.015872
% INFO    : Gen at bus 3987	: Vg=1.001 -> Vg=1.015872
% INFO    : Gen at bus 3987	: Pg=1.29, Qg=2.37 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 3987	: Vg=1.001 -> Vg=1.015872
% INFO    : Gen at bus 3998	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 3998	: Pg=11.16, Qg=0.0 -> Pg=12.4, Qg=0.0
% INFO    : Gen at bus 3998	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 4000	: Vg=1.039 -> Vg=1.022222
% INFO    : Gen at bus 4000	: Pg=0.11, Qg=0.0 -> Pg=11.35, Qg=0.0
% INFO    : Gen at bus 4000	: Vg=1.039 -> Vg=1.022222
% INFO    : Gen at bus 4025	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 4029	: Vg=0.964 -> Vg=0.9444445
% INFO    : Gen at bus 4031	: Vg=1.027 -> Vg=1.0111115
% INFO    : Gen at bus 4031	: Vg=1.027 -> Vg=1.0111115
% INFO    : Gen at bus 4054	: Vg=1.005 -> Vg=1.0079355
% INFO    : Gen at bus 4055	: Pg=18.93, Qg=4.68 -> Pg=13.5, Qg=-2.5
% INFO    : Gen at bus 4055	: Vg=1.025 -> Vg=1.015872
% INFO    : Gen at bus 4055	: Pg=18.93, Qg=4.68 -> Pg=13.5, Qg=-2.5
% INFO    : Gen at bus 4055	: Vg=1.025 -> Vg=1.015872
% INFO    : Gen at bus 4065	: Vg=1.029 -> Vg=1.0079355
% INFO    : Gen at bus 4071	: Vg=1.05 -> Vg=1.027779
% INFO    : Gen at bus 4108	: Vg=1.03 -> Vg=1.022224
% INFO    : Gen at bus 4125	: Vg=1.016 -> Vg=1.0079355
% INFO    : Gen at bus 4129	: Pg=7.25, Qg=-0.72 -> Pg=6.15, Qg=0.0
% INFO    : Gen at bus 4129	: Vg=1.033 -> Vg=0.999999
% INFO    : Gen at bus 4129	: Vg=1.033 -> Vg=0.999999
% INFO    : Gen at bus 4129	: Pg=6.25, Qg=-0.72 -> Pg=6.15, Qg=0.0
% INFO    : Gen at bus 4129	: Vg=1.033 -> Vg=0.999999
% INFO    : Gen at bus 4131	: Vg=0.985 -> Vg=1.015872
% INFO    : Gen at bus 4131	: Vg=0.985 -> Vg=1.015872
% INFO    : Gen at bus 4169	: Pg=17.2, Qg=0.9 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 4169	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 4198	: Vg=1.03 -> Vg=1.022224
% INFO    : Gen at bus 4198	: Vg=1.03 -> Vg=1.022224
% INFO    : Gen at bus 4217	: Vg=1.036 -> Vg=1.0158755
% INFO    : Gen at bus 4216	: Vg=1.036 -> Vg=1.0158755
% INFO    : Gen at bus 4231	: Pg=8.15, Qg=3.48 -> Pg=6.5, Qg=6.5
% INFO    : Gen at bus 4231	: Vg=1.025 -> Vg=0.999999
% INFO    : Gen at bus 4235	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 4244	: Pg=37.3, Qg=8.51 -> Pg=21.0, Qg=0.0
% INFO    : Gen at bus 4244	: Vg=1.067 -> Vg=1.000001
% INFO    : Gen at bus 4245	: Pg=11.88, Qg=5.21 -> Pg=9.5, Qg=0.105
% INFO    : Gen at bus 4245	: Vg=0.971 -> Vg=1.015872
% INFO    : Gen at bus 4260	: Vg=1.014 -> Vg=1.0079355
% INFO    : Gen at bus 4260	: Vg=1.014 -> Vg=1.0079355
% INFO    : Gen at bus 4274	: Pg=6.89, Qg=4.3 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4274	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 4274	: Pg=6.68, Qg=1.28 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4274	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 4275	: Vg=1.056 -> Vg=1.019107
% INFO    : Gen at bus 4275	: Pg=6.93, Qg=5.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4275	: Vg=1.056 -> Vg=1.019107
% INFO    : Gen at bus 4293	: Vg=1.004 -> Vg=1.015872
% INFO    : Gen at bus 4299	: Pg=17.31, Qg=-0.71 -> Pg=23.0, Qg=-7.0
% INFO    : Gen at bus 4299	: Vg=1.017 -> Vg=0.999999
% INFO    : Gen at bus 4300	: Vg=1.046 -> Vg=0.999999
% INFO    : Gen at bus 4301	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 4305	: Vg=1.028 -> Vg=1.0079355
% INFO    : Gen at bus 4309	: Vg=1.052 -> Vg=0.999999
% INFO    : Gen at bus 4309	: Vg=1.052 -> Vg=0.999999
% INFO    : Gen at bus 4315	: Pg=39.29, Qg=13.31 -> Pg=22.0, Qg=0.0
% INFO    : Gen at bus 4315	: Vg=1.045 -> Vg=1.000119
% INFO    : Gen at bus 4319	: Pg=13.36, Qg=-2.12 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 4319	: Vg=1.062 -> Vg=1.000001
% INFO    : Gen at bus 4320	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 4324	: Vg=1.048 -> Vg=1.0111115
% INFO    : Gen at bus 4326	: Vg=1.039 -> Vg=1.0079355
% INFO    : Gen at bus 4326	: Vg=1.039 -> Vg=1.0079355
% INFO    : Gen at bus 4327	: Pg=20.35, Qg=0.53 -> Pg=19.5, Qg=0.0
% INFO    : Gen at bus 4327	: Vg=1.008 -> Vg=0.999999
% INFO    : Gen at bus 4337	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 4337	: Pg=3.13, Qg=0.0 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 4337	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 4345	: Pg=20.15, Qg=2.0 -> Pg=13.0, Qg=1.95
% INFO    : Gen at bus 4345	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 4352	: Vg=1.045 -> Vg=1.0000025
% INFO    : Gen at bus 4371	: Pg=2.55, Qg=3.0 -> Pg=7.5, Qg=2.95
% INFO    : Gen at bus 4371	: Vg=1.043 -> Vg=1.000001
% INFO    : Gen at bus 4371	: Vg=1.043 -> Vg=1.000001
% INFO    : Gen at bus 4376	: Vg=0.98 -> Vg=1.0158755
% INFO    : Gen at bus 4379	: Vg=1.036 -> Vg=1.022224
% INFO    : Gen at bus 4384	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 4384	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 4384	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 4393	: Vg=1.019 -> Vg=1.0079355
% INFO    : Gen at bus 4413	: Vg=1.022 -> Vg=1.0079355
% INFO    : Gen at bus 4413	: Vg=1.022 -> Vg=1.0079355
% INFO    : Gen at bus 4414	: Vg=0.967 -> Vg=1.006081
% INFO    : Gen at bus 4414	: Vg=0.967 -> Vg=1.006081
% INFO    : Gen at bus 4415	: Vg=1.036 -> Vg=1.015872
% INFO    : Gen at bus 4431	: Vg=1.017 -> Vg=1.0000025
% INFO    : Gen at bus 4449	: Vg=1.002 -> Vg=0.999999
% INFO    : Gen at bus 4449	: Vg=1.002 -> Vg=0.999999
% INFO    : Gen at bus 4451	: Pg=1.55, Qg=16.07 -> Pg=13.0, Qg=-0.465
% INFO    : Gen at bus 4451	: Vg=1.052 -> Vg=1.0233335
% INFO    : Gen at bus 4451	: Pg=1.55, Qg=16.07 -> Pg=13.0, Qg=-0.465
% INFO    : Gen at bus 4451	: Vg=1.052 -> Vg=1.0233335
% INFO    : Gen at bus 4455	: Pg=20.18, Qg=0.0 -> Pg=14.95, Qg=0.0
% INFO    : Gen at bus 4455	: Vg=1.054 -> Vg=1.0000025
% INFO    : Gen at bus 4456	: Pg=4.76, Qg=0.0 -> Pg=6.85, Qg=0.0
% INFO    : Gen at bus 4456	: Vg=1.028 -> Vg=1.0000025
% INFO    : Gen at bus 4475	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 4477	: Vg=1.016 -> Vg=1.0000025
% INFO    : Gen at bus 4478	: Pg=17.13, Qg=1.8 -> Pg=11.85, Qg=0.01
% INFO    : Gen at bus 4478	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 4479	: Pg=18.82, Qg=1.21 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4479	: Vg=1.056 -> Vg=0.975
% INFO    : Gen at bus 4480	: Pg=19.02, Qg=1.24 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4480	: Vg=1.056 -> Vg=0.975
% INFO    : Gen at bus 4481	: Pg=19.02, Qg=0.25 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4481	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 4482	: Pg=19.02, Qg=4.24 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4482	: Vg=1.06 -> Vg=0.975
% INFO    : Gen at bus 4495	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 4508	: Vg=1.004 -> Vg=1.015872
% INFO    : Gen at bus 4511	: Pg=11.25, Qg=-0.42 -> Pg=10.5, Qg=1.1
% INFO    : Gen at bus 4511	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 4511	: Pg=11.25, Qg=-0.42 -> Pg=10.5, Qg=1.0
% INFO    : Gen at bus 4511	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 4515	: Pg=37.99, Qg=-24.34 -> Pg=43.5, Qg=0.43
% INFO    : Gen at bus 4515	: Vg=1.074 -> Vg=1.044445
% INFO    : Gen at bus 4524	: Pg=13.3, Qg=1.51 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 4524	: Vg=1.056 -> Vg=1.006274
% INFO    : Gen at bus 4524	: Pg=13.3, Qg=1.51 -> Pg=11.0, Qg=1.0
% INFO    : Gen at bus 4524	: Vg=1.056 -> Vg=1.006274
% INFO    : Gen at bus 4538	: Vg=0.615 -> Vg=0.825
% INFO    : Gen at bus 4538	: Vg=0.615 -> Vg=0.825
% INFO    : Gen at bus 4538	: Vg=0.615 -> Vg=0.825
% INFO    : Gen at bus 4538	: Vg=0.615 -> Vg=0.825
% INFO    : Gen at bus 4538	: Vg=0.615 -> Vg=0.825
% INFO    : Gen at bus 4567	: Pg=11.2, Qg=7.1 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 4567	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 4571	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 4574	: Pg=41.0, Qg=23.19 -> Pg=44.5, Qg=9.0
% INFO    : Gen at bus 4574	: Vg=1.036 -> Vg=1.0377785
% INFO    : Gen at bus 4574	: Pg=43.0, Qg=23.19 -> Pg=44.5, Qg=9.0
% INFO    : Gen at bus 4574	: Vg=1.036 -> Vg=1.0377785
% INFO    : Gen at bus 4582	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 4583	: Vg=1.04 -> Vg=0.999999
% INFO    : Gen at bus 4585	: Vg=1.003 -> Vg=1.015872
% INFO    : Gen at bus 4588	: Pg=0.45, Qg=1.99 -> Pg=6.35, Qg=0.0
% INFO    : Gen at bus 4588	: Vg=1.023 -> Vg=1.0000025
% INFO    : Gen at bus 4588	: Pg=0.45, Qg=1.0 -> Pg=6.35, Qg=0.95
% INFO    : Gen at bus 4588	: Vg=1.023 -> Vg=1.0000025
% INFO    : Gen at bus 4623	: Pg=0.03, Qg=0.0 -> Pg=18.4, Qg=0.0
% INFO    : Gen at bus 4623	: Vg=1.009 -> Vg=1.022224
% INFO    : Gen at bus 4634	: Vg=1.034 -> Vg=1.022224
% INFO    : Gen at bus 4635	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 4636	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 4645	: Pg=0.14, Qg=0.0 -> Pg=15.75, Qg=0.0
% INFO    : Gen at bus 4645	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 4646	: Vg=1.021 -> Vg=1.022224
% INFO    : Gen at bus 4651	: Vg=1.066 -> Vg=1.027779
% INFO    : Gen at bus 4657	: Vg=1.078 -> Vg=1.0000025
% INFO    : Gen at bus 4661	: Vg=1.018 -> Vg=1.022224
% INFO    : Gen at bus 4662	: Pg=3.18, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 4662	: Vg=1.03 -> Vg=1.022224
% INFO    : Gen at bus 4669	: Vg=1.017 -> Vg=1.022224
% INFO    : Gen at bus 4669	: Vg=1.017 -> Vg=1.022224
% INFO    : Gen at bus 4674	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 4674	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 4674	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 4674	: Pg=2.28, Qg=0.1 -> Pg=3.5, Qg=0.0
% INFO    : Gen at bus 4674	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 4674	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 4686	: Vg=1.027 -> Vg=1.000001
% INFO    : Gen at bus 4701	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 4701	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 4701	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 4718	: Pg=1.19, Qg=0.8 -> Pg=5.75, Qg=0.0
% INFO    : Gen at bus 4718	: Vg=1.056 -> Vg=1.0000025
% INFO    : Gen at bus 4718	: Vg=1.056 -> Vg=1.0000025
% INFO    : Gen at bus 4719	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 4719	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 4720	: Vg=1.014 -> Vg=1.0158755
% INFO    : Gen at bus 4721	: Pg=1.06, Qg=1.0 -> Pg=5.0, Qg=0.95
% INFO    : Gen at bus 4721	: Vg=1.061 -> Vg=1.0000025
% INFO    : Gen at bus 4721	: Pg=4.06, Qg=1.0 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 4721	: Vg=1.061 -> Vg=1.0000025
% INFO    : Gen at bus 4721	: Pg=6.06, Qg=1.0 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 4721	: Vg=1.061 -> Vg=1.0000025
% INFO    : Gen at bus 4757	: Vg=1.054 -> Vg=1.0000025
% INFO    : Gen at bus 4758	: Pg=4.13, Qg=2.18 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4758	: Vg=1.005 -> Vg=1.015872
% INFO    : Gen at bus 4758	: Pg=4.13, Qg=2.18 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4758	: Vg=1.005 -> Vg=1.015872
% INFO    : Gen at bus 4759	: Pg=4.13, Qg=4.17 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4759	: Vg=1.005 -> Vg=1.015872
% INFO    : Gen at bus 4759	: Pg=4.13, Qg=4.17 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4759	: Vg=1.005 -> Vg=1.015872
% INFO    : Gen at bus 4768	: Pg=12.11, Qg=2.76 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 4768	: Vg=1.049 -> Vg=1.0233335
% INFO    : Gen at bus 4771	: Vg=1.048 -> Vg=1.027779
% INFO    : Gen at bus 4778	: Vg=1.016 -> Vg=1.0000025
% INFO    : Gen at bus 4783	: Pg=0.11, Qg=0.0 -> Pg=14.0, Qg=0.0
% INFO    : Gen at bus 4783	: Vg=1.011 -> Vg=1.0000005
% INFO    : Gen at bus 4789	: Vg=1.018 -> Vg=1.022224
% INFO    : Gen at bus 4794	: Vg=1.052 -> Vg=0.999999
% INFO    : Gen at bus 4805	: Pg=15.38, Qg=-0.21 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 4805	: Vg=1.007 -> Vg=0.999999
% INFO    : Gen at bus 4815	: Vg=1.047 -> Vg=1.027779
% INFO    : Gen at bus 4818	: Pg=1.57, Qg=-0.64 -> Pg=3.2, Qg=0.0
% INFO    : Gen at bus 4818	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 4819	: Pg=9.24, Qg=-0.35 -> Pg=8.0, Qg=-0.45
% INFO    : Gen at bus 4819	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 4819	: Pg=10.24, Qg=-0.35 -> Pg=7.5, Qg=-0.5
% INFO    : Gen at bus 4819	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 4820	: Pg=9.25, Qg=-0.86 -> Pg=7.5, Qg=-0.5
% INFO    : Gen at bus 4820	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 4820	: Pg=8.25, Qg=-0.86 -> Pg=8.0, Qg=-0.45
% INFO    : Gen at bus 4820	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 4827	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 4830	: Pg=121.5, Qg=17.31 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4830	: Vg=1.079 -> Vg=0.975
% INFO    : Gen at bus 4830	: Pg=123.44, Qg=17.31 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4830	: Vg=1.079 -> Vg=0.975
% INFO    : Gen at bus 4829	: Pg=122.55, Qg=24.14 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4829	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 4829	: Pg=121.58, Qg=24.14 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4829	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 4826	: Pg=121.58, Qg=22.2 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4826	: Vg=1.087 -> Vg=0.975
% INFO    : Gen at bus 4826	: Pg=126.43, Qg=22.2 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4826	: Vg=1.087 -> Vg=0.975
% INFO    : Gen at bus 4825	: Pg=124.49, Qg=23.68 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4825	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 4825	: Pg=125.46, Qg=23.68 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4825	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 4828	: Pg=126.6, Qg=13.26 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 4828	: Vg=1.087 -> Vg=0.975
% INFO    : Gen at bus 4828	: Pg=118.84, Qg=13.26 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 4828	: Vg=1.087 -> Vg=0.975
% INFO    : Gen at bus 4827	: Pg=128.19, Qg=22.02 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 4827	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 4837	: Vg=1.036 -> Vg=0.984126
% INFO    : Gen at bus 4837	: Vg=1.036 -> Vg=0.984126
% INFO    : Gen at bus 4848	: Vg=1.051 -> Vg=1.001574
% INFO    : Gen at bus 4856	: Vg=0.945 -> Vg=0.9444445
% INFO    : Gen at bus 4856	: Vg=0.945 -> Vg=0.9444445
% INFO    : Gen at bus 4869	: Vg=1.017 -> Vg=0.999999
% INFO    : Gen at bus 4869	: Vg=1.017 -> Vg=0.999999
% INFO    : Gen at bus 4876	: Vg=1.03 -> Vg=1.033334
% INFO    : Gen at bus 4883	: Pg=6.66, Qg=-2.22 -> Pg=6.4, Qg=0.0
% INFO    : Gen at bus 4883	: Vg=1.029 -> Vg=0.999999
% INFO    : Gen at bus 4887	: Pg=14.13, Qg=0.0 -> Pg=17.51, Qg=0.0
% INFO    : Gen at bus 4887	: Vg=1.024 -> Vg=1.0111115
% INFO    : Gen at bus 4887	: Pg=3.13, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 4887	: Vg=1.024 -> Vg=1.0111115
% INFO    : Gen at bus 4899	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 4903	: Vg=1.021 -> Vg=0.999999
% INFO    : Gen at bus 4905	: Pg=2.19, Qg=0.0 -> Pg=10.8, Qg=0.0
% INFO    : Gen at bus 4905	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 4905	: Pg=1.19, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 4905	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 4905	: Pg=1.19, Qg=0.0 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 4905	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 4925	: Pg=22.1, Qg=7.21 -> Pg=16.0, Qg=2.0
% INFO    : Gen at bus 4925	: Vg=1.002 -> Vg=1.015872
% INFO    : Gen at bus 4928	: Pg=25.34, Qg=2.35 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 4928	: Vg=1.026 -> Vg=1.0000025
% INFO    : Gen at bus 4935	: Vg=1.048 -> Vg=1.027779
% INFO    : Gen at bus 4951	: Pg=3.93, Qg=1.93 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 4951	: Vg=0.958 -> Vg=0.9444445
% INFO    : Gen at bus 4955	: Vg=1.036 -> Vg=1.027779
% INFO    : Gen at bus 4966	: Pg=3.11, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 4966	: Vg=1.049 -> Vg=1.022224
% INFO    : Gen at bus 4966	: Pg=3.11, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 4966	: Vg=1.049 -> Vg=1.022224
% INFO    : Gen at bus 4973	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 4973	: Pg=25.18, Qg=-5.4 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 4973	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 4986	: Pg=1.23, Qg=-0.46 -> Pg=16.0, Qg=-1.0
% INFO    : Gen at bus 4986	: Vg=1.024 -> Vg=0.999999
% INFO    : Gen at bus 4987	: Pg=26.31, Qg=12.0 -> Pg=17.55, Qg=-4.5
% INFO    : Gen at bus 4987	: Vg=1.108 -> Vg=0.975
% INFO    : Gen at bus 4988	: Pg=27.95, Qg=12.0 -> Pg=17.55, Qg=-4.5
% INFO    : Gen at bus 4988	: Vg=1.12 -> Vg=0.975
% INFO    : Gen at bus 4989	: Pg=28.45, Qg=12.0 -> Pg=17.55, Qg=-4.5
% INFO    : Gen at bus 4989	: Vg=1.12 -> Vg=0.975
% INFO    : Gen at bus 4996	: Vg=1.008 -> Vg=1.0158755
% INFO    : Gen at bus 4997	: Vg=1.019 -> Vg=1.0158755
% INFO    : Gen at bus 5015	: Pg=3.23, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 5015	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 5015	: Pg=8.23, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 5015	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 5017	: Vg=1.029 -> Vg=1.022224
% INFO    : Gen at bus 5023	: Pg=4.05, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 5023	: Vg=1.013 -> Vg=1.0158755
% INFO    : Gen at bus 5027	: Pg=15.38, Qg=4.0 -> Pg=18.0, Qg=3.95
% INFO    : Gen at bus 5027	: Vg=1.066 -> Vg=1.000001
% INFO    : Gen at bus 5033	: Pg=43.03, Qg=-7.79 -> Pg=25.3, Qg=0.505
% INFO    : Gen at bus 5033	: Vg=1.006 -> Vg=1.0000025
% INFO    : Gen at bus 5041	: Vg=1.003 -> Vg=0.999999
% INFO    : Gen at bus 5042	: Vg=1.003 -> Vg=1.022224
% INFO    : Gen at bus 5044	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 5044	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 5046	: Vg=1.029 -> Vg=1.022222
% INFO    : Gen at bus 5046	: Vg=1.029 -> Vg=1.022222
% INFO    : Gen at bus 5050	: Vg=1.011 -> Vg=1.0277795
% INFO    : Gen at bus 5052	: Vg=1.03 -> Vg=1.0158755
% INFO    : Gen at bus 5052	: Vg=1.03 -> Vg=1.0158755
% INFO    : Gen at bus 5058	: Vg=1.049 -> Vg=1.033333
% INFO    : Gen at bus 5958	: Vg=1.111 -> Vg=0.975
% INFO    : Gen at bus 5958	: Vg=1.111 -> Vg=0.975
% INFO    : Gen at bus 5958	: Vg=1.111 -> Vg=0.975
% INFO    : Gen at bus 5959	: Vg=1.12 -> Vg=0.975
% INFO    : Gen at bus 5959	: Vg=1.12 -> Vg=0.975
% INFO    : Gen at bus 5961	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 5962	: Pg=976.35, Qg=5.86 -> Pg=700.0, Qg=70.0
% INFO    : Gen at bus 5962	: Vg=1.103 -> Vg=0.975
% INFO    : Gen at bus 5962	: Pg=997.35, Qg=5.86 -> Pg=700.0, Qg=70.0
% INFO    : Gen at bus 5962	: Vg=1.103 -> Vg=0.975
% INFO    : Gen at bus 5964	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 5965	: Vg=1.121 -> Vg=0.975
% INFO    : Gen at bus 5967	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 5967	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 5968	: Vg=1.067 -> Vg=0.975
% INFO    : Gen at bus 5968	: Vg=1.067 -> Vg=0.975
% INFO    : Gen at bus 5972	: Pg=495.36, Qg=-156.09 -> Pg=275.0, Qg=-40.0
% INFO    : Gen at bus 5972	: Vg=1.122 -> Vg=0.975
% INFO    : Gen at bus 5975	: Pg=80.6, Qg=-32.88 -> Pg=42.62, Qg=-3.655
% INFO    : Gen at bus 5975	: Vg=1.082 -> Vg=0.975
% INFO    : Gen at bus 5975	: Pg=80.6, Qg=-32.88 -> Pg=42.62, Qg=-3.655
% INFO    : Gen at bus 5975	: Vg=1.082 -> Vg=0.975
% INFO    : Gen at bus 5983	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 5983	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 5986	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 5986	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 5988	: Pg=419.43, Qg=2.22 -> Pg=225.0, Qg=0.0
% INFO    : Gen at bus 5988	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 5988	: Pg=418.43, Qg=2.22 -> Pg=225.0, Qg=0.0
% INFO    : Gen at bus 5988	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 5997	: Vg=1.103 -> Vg=0.975
% INFO    : Gen at bus 5997	: Vg=1.103 -> Vg=0.975
% INFO    : Gen at bus 6002	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6002	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6002	: Pg=52.37, Qg=3.96 -> Pg=28.5, Qg=0.0
% INFO    : Gen at bus 6002	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6002	: Pg=52.37, Qg=3.96 -> Pg=28.5, Qg=0.0
% INFO    : Gen at bus 6002	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6002	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6002	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6003	: Pg=244.58, Qg=51.26 -> Pg=124.61, Qg=0.0
% INFO    : Gen at bus 6003	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 6003	: Pg=246.56, Qg=51.26 -> Pg=125.6, Qg=0.0
% INFO    : Gen at bus 6003	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 6003	: Pg=392.93, Qg=51.26 -> Pg=198.785, Qg=0.0
% INFO    : Gen at bus 6003	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 6006	: Pg=526.12, Qg=54.23 -> Pg=265.45, Qg=0.0
% INFO    : Gen at bus 6006	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 6009	: Pg=370.45, Qg=-22.32 -> Pg=450.0, Qg=0.0
% INFO    : Gen at bus 6009	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 6010	: Pg=213.42, Qg=-33.68 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 6010	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 6014	: Pg=1.72, Qg=5.35 -> Pg=301.5, Qg=66.5
% INFO    : Gen at bus 6014	: Vg=1.142 -> Vg=0.975
% INFO    : Gen at bus 6014	: Vg=1.142 -> Vg=0.975
% INFO    : Gen at bus 6014	: Vg=1.142 -> Vg=0.975
% INFO    : Gen at bus 6014	: Pg=7.73, Qg=5.35 -> Pg=279.0, Qg=98.0
% INFO    : Gen at bus 6014	: Vg=1.142 -> Vg=0.975
% INFO    : Gen at bus 6022	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6021	: Pg=45.32, Qg=-81.18 -> Pg=24.95, Qg=-33.13
% INFO    : Gen at bus 6021	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 6023	: Pg=251.28, Qg=-1.42 -> Pg=127.93, Qg=0.0
% INFO    : Gen at bus 6023	: Vg=1.101 -> Vg=0.975
% INFO    : Gen at bus 6026	: Pg=484.03, Qg=-73.63 -> Pg=244.255, Qg=0.0
% INFO    : Gen at bus 6026	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6027	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 6029	: Pg=1051.34, Qg=44.86 -> Pg=653.0, Qg=235.0
% INFO    : Gen at bus 6029	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 6029	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 6029	: Pg=407.34, Qg=44.86 -> Pg=304.0, Qg=84.0
% INFO    : Gen at bus 6029	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 6029	: Pg=407.34, Qg=44.86 -> Pg=304.0, Qg=72.5
% INFO    : Gen at bus 6029	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 6040	: Pg=98.0, Qg=0.54 -> Pg=350.0, Qg=142.5
% INFO    : Gen at bus 6040	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 6045	: Vg=1.119 -> Vg=0.975
% INFO    : Gen at bus 6049	: Vg=1.113 -> Vg=0.975
% INFO    : Gen at bus 6055	: Pg=503.41, Qg=83.61 -> Pg=254.0, Qg=0.0
% INFO    : Gen at bus 6055	: Vg=1.051 -> Vg=0.975
% INFO    : Gen at bus 6058	: Pg=1082.77, Qg=24.61 -> Pg=543.72, Qg=0.0
% INFO    : Gen at bus 6058	: Vg=1.097 -> Vg=0.975
% INFO    : Gen at bus 6066	: Pg=1038.37, Qg=87.36 -> Pg=675.0, Qg=70.0
% INFO    : Gen at bus 6066	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 6066	: Pg=504.37, Qg=87.36 -> Pg=605.0, Qg=70.0
% INFO    : Gen at bus 6066	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 6066	: Pg=478.37, Qg=87.36 -> Pg=605.0, Qg=70.0
% INFO    : Gen at bus 6066	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 6069	: Vg=1.12 -> Vg=0.975
% INFO    : Gen at bus 6070	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 6083	: Vg=1.121 -> Vg=0.975
% INFO    : Gen at bus 6084	: Vg=1.107 -> Vg=0.975
% INFO    : Gen at bus 6088	: Pg=1380.43, Qg=15.17 -> Pg=692.5, Qg=0.0
% INFO    : Gen at bus 6088	: Vg=1.104 -> Vg=0.975
% INFO    : Gen at bus 6089	: Vg=1.104 -> Vg=0.975
% INFO    : Gen at bus 6090	: Pg=215.49, Qg=66.99 -> Pg=110.0, Qg=0.5
% INFO    : Gen at bus 6090	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6092	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 6093	: Pg=38.34, Qg=47.99 -> Pg=21.5, Qg=17.55
% INFO    : Gen at bus 6093	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 6092	: Pg=38.36, Qg=-23.88 -> Pg=21.5, Qg=-5.55
% INFO    : Gen at bus 6092	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 6092	: Pg=17.36, Qg=-23.88 -> Pg=11.0, Qg=-8.7
% INFO    : Gen at bus 6092	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 6095	: Pg=121.76, Qg=75.0 -> Pg=63.215, Qg=18.535
% INFO    : Gen at bus 6095	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6094	: Pg=17.91, Qg=17.21 -> Pg=11.28, Qg=5.225
% INFO    : Gen at bus 6094	: Vg=1.096 -> Vg=0.975
% INFO    : Gen at bus 6103	: Pg=1217.03, Qg=-212.46 -> Pg=610.835, Qg=0.0
% INFO    : Gen at bus 6103	: Vg=1.093 -> Vg=0.975
% INFO    : Gen at bus 6104	: Pg=436.44, Qg=4.55 -> Pg=225.0, Qg=0.0
% INFO    : Gen at bus 6104	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6106	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 6113	: Pg=257.42, Qg=1.54 -> Pg=131.0, Qg=0.0
% INFO    : Gen at bus 6113	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 6112	: Pg=253.42, Qg=1.06 -> Pg=129.0, Qg=0.0
% INFO    : Gen at bus 6112	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 6113	: Pg=253.42, Qg=1.54 -> Pg=129.0, Qg=0.0
% INFO    : Gen at bus 6113	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 6112	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 6115	: Vg=1.07 -> Vg=0.975
% INFO    : Gen at bus 6115	: Vg=1.07 -> Vg=0.975
% INFO    : Gen at bus 6117	: Pg=221.95, Qg=123.44 -> Pg=113.33, Qg=27.72
% INFO    : Gen at bus 6117	: Vg=1.115 -> Vg=0.975
% INFO    : Gen at bus 6126	: Pg=734.44, Qg=-31.49 -> Pg=369.5, Qg=0.0
% INFO    : Gen at bus 6126	: Vg=1.097 -> Vg=0.975
% INFO    : Gen at bus 6130	: Vg=1.116 -> Vg=0.975
% INFO    : Gen at bus 6132	: Pg=2.38, Qg=-5.58 -> Pg=3.545, Qg=-1.73
% INFO    : Gen at bus 6132	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 6133	: Pg=180.29, Qg=-9.47 -> Pg=92.5, Qg=0.0
% INFO    : Gen at bus 6133	: Vg=1.082 -> Vg=0.975
% INFO    : Gen at bus 6133	: Pg=184.29, Qg=-9.47 -> Pg=94.5, Qg=0.0
% INFO    : Gen at bus 6133	: Vg=1.082 -> Vg=0.975
% INFO    : Gen at bus 6134	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6134	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6134	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6134	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6139	: Pg=451.47, Qg=51.56 -> Pg=228.0, Qg=0.0
% INFO    : Gen at bus 6139	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6139	: Pg=149.47, Qg=51.0 -> Pg=77.0, Qg=2.4
% INFO    : Gen at bus 6139	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6139	: Pg=45.47, Qg=51.0 -> Pg=25.0, Qg=18.0
% INFO    : Gen at bus 6139	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6139	: Pg=88.47, Qg=51.0 -> Pg=46.5, Qg=11.55
% INFO    : Gen at bus 6139	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6139	: Pg=68.47, Qg=51.0 -> Pg=36.5, Qg=14.55
% INFO    : Gen at bus 6139	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6146	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 6157	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 6157	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 6158	: Vg=1.118 -> Vg=0.975
% INFO    : Gen at bus 6160	: Vg=1.105 -> Vg=0.975
% INFO    : Gen at bus 6162	: Pg=359.26, Qg=10.63 -> Pg=182.035, Qg=0.0
% INFO    : Gen at bus 6162	: Vg=1.084 -> Vg=0.975
% INFO    : Gen at bus 6162	: Pg=193.85, Qg=10.63 -> Pg=99.33, Qg=0.0
% INFO    : Gen at bus 6162	: Vg=1.084 -> Vg=0.975
% INFO    : Gen at bus 6165	: Pg=182.55, Qg=0.21 -> Pg=93.59, Qg=0.0
% INFO    : Gen at bus 6165	: Vg=1.088 -> Vg=0.975
% INFO    : Gen at bus 6165	: Pg=182.55, Qg=0.21 -> Pg=93.59, Qg=0.0
% INFO    : Gen at bus 6165	: Vg=1.088 -> Vg=0.975
% INFO    : Gen at bus 6172	: Pg=2850.78, Qg=252.48 -> Pg=1427.63, Qg=0.0
% INFO    : Gen at bus 6172	: Vg=1.087 -> Vg=0.975
% INFO    : Gen at bus 6173	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6174	: Pg=16.03, Qg=11.2 -> Pg=10.405, Qg=2.585
% INFO    : Gen at bus 6174	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6174	: Pg=16.03, Qg=11.2 -> Pg=10.405, Qg=2.585
% INFO    : Gen at bus 6174	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6176	: Vg=1.123 -> Vg=0.975
% INFO    : Gen at bus 6179	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 6184	: Pg=81.3, Qg=89.16 -> Pg=135.0, Qg=0.0
% INFO    : Gen at bus 6184	: Vg=1.088 -> Vg=0.975
% INFO    : Gen at bus 6188	: Pg=290.41, Qg=-19.78 -> Pg=147.56, Qg=0.0
% INFO    : Gen at bus 6188	: Vg=1.111 -> Vg=0.975
% INFO    : Gen at bus 6188	: Pg=290.41, Qg=-19.78 -> Pg=147.56, Qg=0.0
% INFO    : Gen at bus 6188	: Vg=1.111 -> Vg=0.975
% INFO    : Gen at bus 6189	: Vg=1.097 -> Vg=0.975
% INFO    : Gen at bus 6193	: Pg=345.29, Qg=13.8 -> Pg=385.0, Qg=0.0
% INFO    : Gen at bus 6193	: Vg=1.144 -> Vg=0.975
% INFO    : Gen at bus 6193	: Pg=343.28, Qg=13.8 -> Pg=385.0, Qg=0.0
% INFO    : Gen at bus 6193	: Vg=1.144 -> Vg=0.975
% INFO    : Gen at bus 6194	: Vg=1.123 -> Vg=0.975
% INFO    : Gen at bus 6194	: Vg=1.123 -> Vg=0.975
% INFO    : Gen at bus 6194	: Vg=1.123 -> Vg=0.975
% INFO    : Gen at bus 6195	: Vg=1.092 -> Vg=0.975
% INFO    : Gen at bus 6196	: Vg=1.106 -> Vg=0.975
% INFO    : Gen at bus 6196	: Pg=18.57, Qg=-108.9 -> Pg=11.64, Qg=-51.01
% INFO    : Gen at bus 6196	: Vg=1.106 -> Vg=0.975
% INFO    : Gen at bus 6212	: Vg=1.123 -> Vg=0.975
% INFO    : Gen at bus 6215	: Vg=1.064 -> Vg=0.975
% INFO    : Gen at bus 6216	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 6216	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 6216	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 6218	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6218	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6218	: Pg=190.17, Qg=33.15 -> Pg=125.0, Qg=0.0
% INFO    : Gen at bus 6218	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6218	: Pg=184.17, Qg=33.15 -> Pg=125.0, Qg=0.0
% INFO    : Gen at bus 6218	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6218	: Pg=192.17, Qg=33.15 -> Pg=125.0, Qg=0.0
% INFO    : Gen at bus 6218	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6218	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6218	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6219	: Pg=660.43, Qg=-79.48 -> Pg=332.5, Qg=142.5
% INFO    : Gen at bus 6219	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 6221	: Pg=85.56, Qg=-12.63 -> Pg=45.12, Qg=0.0
% INFO    : Gen at bus 6221	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 6222	: Pg=1037.35, Qg=-176.63 -> Pg=700.0, Qg=70.0
% INFO    : Gen at bus 6222	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 6226	: Pg=90.51, Qg=-15.87 -> Pg=47.625, Qg=0.0
% INFO    : Gen at bus 6226	: Vg=1.067 -> Vg=0.975
% INFO    : Gen at bus 6229	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 6229	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 6231	: Pg=113.44, Qg=55.6 -> Pg=59.06, Qg=10.09
% INFO    : Gen at bus 6231	: Vg=1.089 -> Vg=0.975
% INFO    : Gen at bus 6231	: Pg=113.44, Qg=55.6 -> Pg=59.06, Qg=10.09
% INFO    : Gen at bus 6231	: Vg=1.089 -> Vg=0.975
% INFO    : Gen at bus 6239	: Pg=348.27, Qg=-15.24 -> Pg=176.54, Qg=0.0
% INFO    : Gen at bus 6239	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 6245	: Vg=1.112 -> Vg=0.975
% INFO    : Gen at bus 6247	: Pg=514.57, Qg=-9.65 -> Pg=625.0, Qg=-14.0
% INFO    : Gen at bus 6247	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6247	: Pg=365.21, Qg=-9.65 -> Pg=285.0, Qg=-44.0
% INFO    : Gen at bus 6247	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6247	: Pg=365.21, Qg=-9.65 -> Pg=285.0, Qg=-44.0
% INFO    : Gen at bus 6247	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6255	: Vg=0.969 -> Vg=0.975
% INFO    : Gen at bus 6256	: Vg=0.969 -> Vg=0.975
% INFO    : Gen at bus 6257	: Pg=10.9, Qg=8.77 -> Pg=11.5, Qg=2.565
% INFO    : Gen at bus 6257	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6258	: Pg=10.9, Qg=8.77 -> Pg=11.5, Qg=2.565
% INFO    : Gen at bus 6258	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6259	: Pg=16.82, Qg=9.92 -> Pg=13.5, Qg=4.515
% INFO    : Gen at bus 6259	: Vg=1.084 -> Vg=0.975
% INFO    : Gen at bus 6260	: Pg=66.43, Qg=26.68 -> Pg=43.0, Qg=16.295
% INFO    : Gen at bus 6260	: Vg=0.98 -> Vg=0.975
% INFO    : Gen at bus 6261	: Vg=0.949 -> Vg=0.975
% INFO    : Gen at bus 6262	: Pg=95.74, Qg=8.96 -> Pg=62.0, Qg=28.595
% INFO    : Gen at bus 6262	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6263	: Pg=20.31, Qg=10.25 -> Pg=16.0, Qg=1.73
% INFO    : Gen at bus 6263	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 6264	: Pg=20.31, Qg=10.25 -> Pg=16.0, Qg=1.73
% INFO    : Gen at bus 6264	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 6265	: Pg=19.6, Qg=3.82 -> Pg=16.0, Qg=1.545
% INFO    : Gen at bus 6265	: Vg=1.051 -> Vg=0.975
% INFO    : Gen at bus 6266	: Pg=19.6, Qg=3.82 -> Pg=16.0, Qg=1.545
% INFO    : Gen at bus 6266	: Vg=1.051 -> Vg=0.975
% INFO    : Gen at bus 6267	: Pg=76.46, Qg=-20.44 -> Pg=46.0, Qg=14.82
% INFO    : Gen at bus 6267	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6268	: Pg=43.81, Qg=-25.81 -> Pg=46.0, Qg=14.82
% INFO    : Gen at bus 6268	: Vg=0.972 -> Vg=0.975
% INFO    : Gen at bus 6269	: Pg=69.55, Qg=11.03 -> Pg=46.0, Qg=17.7
% INFO    : Gen at bus 6269	: Vg=1.027 -> Vg=0.975
% INFO    : Gen at bus 6270	: Pg=61.31, Qg=9.34 -> Pg=46.0, Qg=17.7
% INFO    : Gen at bus 6270	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 6271	: Pg=66.1, Qg=-38.73 -> Pg=46.0, Qg=11.985
% INFO    : Gen at bus 6271	: Vg=0.948 -> Vg=0.975
% INFO    : Gen at bus 6272	: Pg=71.84, Qg=-36.43 -> Pg=46.0, Qg=13.135
% INFO    : Gen at bus 6272	: Vg=0.951 -> Vg=0.975
% INFO    : Gen at bus 6273	: Pg=933.27, Qg=188.14 -> Pg=593.11, Qg=-42.045
% INFO    : Gen at bus 6273	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6274	: Pg=970.23, Qg=193.52 -> Pg=630.08, Qg=-32.72
% INFO    : Gen at bus 6274	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6275	: Pg=964.27, Qg=188.23 -> Pg=609.11, Qg=-38.01
% INFO    : Gen at bus 6275	: Vg=1.053 -> Vg=0.975
% INFO    : Gen at bus 6276	: Pg=934.26, Qg=145.24 -> Pg=594.11, Qg=-41.905
% INFO    : Gen at bus 6276	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 6278	: Pg=226.85, Qg=65.33 -> Pg=204.0, Qg=31.78
% INFO    : Gen at bus 6278	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 6279	: Pg=223.81, Qg=78.87 -> Pg=202.0, Qg=31.955
% INFO    : Gen at bus 6279	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6280	: Pg=218.15, Qg=38.83 -> Pg=202.0, Qg=22.52
% INFO    : Gen at bus 6280	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6281	: Pg=252.38, Qg=36.89 -> Pg=213.5, Qg=42.55
% INFO    : Gen at bus 6281	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6282	: Pg=125.74, Qg=19.99 -> Pg=122.0, Qg=17.885
% INFO    : Gen at bus 6282	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 6283	: Pg=53.37, Qg=21.3 -> Pg=29.0, Qg=0.375
% INFO    : Gen at bus 6283	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6284	: Pg=53.37, Qg=16.07 -> Pg=29.0, Qg=1.79
% INFO    : Gen at bus 6284	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6285	: Pg=53.37, Qg=21.3 -> Pg=29.0, Qg=0.375
% INFO    : Gen at bus 6285	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6286	: Pg=53.37, Qg=16.07 -> Pg=29.0, Qg=1.79
% INFO    : Gen at bus 6286	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6287	: Pg=52.78, Qg=15.97 -> Pg=29.0, Qg=1.74
% INFO    : Gen at bus 6287	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6288	: Pg=135.33, Qg=135.64 -> Pg=198.0, Qg=45.885
% INFO    : Gen at bus 6288	: Vg=1.034 -> Vg=0.975
% INFO    : Gen at bus 6289	: Pg=97.33, Qg=7.04 -> Pg=69.5, Qg=21.71
% INFO    : Gen at bus 6289	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 6290	: Pg=33.67, Qg=-1.12 -> Pg=24.5, Qg=4.605
% INFO    : Gen at bus 6290	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6291	: Pg=33.67, Qg=-1.14 -> Pg=24.5, Qg=4.57
% INFO    : Gen at bus 6291	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 6292	: Pg=15.25, Qg=-11.37 -> Pg=16.0, Qg=4.37
% INFO    : Gen at bus 6292	: Vg=0.982 -> Vg=0.975
% INFO    : Gen at bus 6293	: Pg=9.33, Qg=-14.94 -> Pg=16.0, Qg=2.37
% INFO    : Gen at bus 6293	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 6294	: Pg=12.33, Qg=-13.79 -> Pg=16.0, Qg=4.21
% INFO    : Gen at bus 6294	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6295	: Pg=932.42, Qg=185.6 -> Pg=602.1, Qg=161.365
% INFO    : Gen at bus 6295	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6296	: Pg=922.84, Qg=196.81 -> Pg=601.21, Qg=162.89
% INFO    : Gen at bus 6296	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6297	: Pg=910.71, Qg=202.76 -> Pg=592.09, Qg=146.155
% INFO    : Gen at bus 6297	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6298	: Pg=870.81, Qg=173.43 -> Pg=591.19, Qg=146.165
% INFO    : Gen at bus 6298	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6299	: Pg=1281.61, Qg=123.68 -> Pg=813.0, Qg=218.085
% INFO    : Gen at bus 6299	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6300	: Pg=1281.61, Qg=133.06 -> Pg=813.0, Qg=218.085
% INFO    : Gen at bus 6300	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6301	: Pg=29.24, Qg=3.07 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6301	: Vg=1.034 -> Vg=0.975
% INFO    : Gen at bus 6302	: Pg=29.24, Qg=3.07 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6302	: Vg=1.034 -> Vg=0.975
% INFO    : Gen at bus 6303	: Pg=29.24, Qg=3.07 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6303	: Vg=1.034 -> Vg=0.975
% INFO    : Gen at bus 6304	: Pg=29.0, Qg=2.53 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6304	: Vg=1.033 -> Vg=0.975
% INFO    : Gen at bus 6305	: Pg=29.0, Qg=2.53 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6305	: Vg=1.033 -> Vg=0.975
% INFO    : Gen at bus 6306	: Pg=29.0, Qg=2.53 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6306	: Vg=1.033 -> Vg=0.975
% INFO    : Gen at bus 6307	: Pg=15.14, Qg=10.36 -> Pg=10.0, Qg=1.615
% INFO    : Gen at bus 6307	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6308	: Pg=1285.88, Qg=233.85 -> Pg=833.5, Qg=226.955
% INFO    : Gen at bus 6308	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 6309	: Pg=1290.91, Qg=281.98 -> Pg=863.5, Qg=235.535
% INFO    : Gen at bus 6309	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6310	: Pg=1251.91, Qg=264.09 -> Pg=863.5, Qg=235.535
% INFO    : Gen at bus 6310	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6311	: Pg=61.92, Qg=1.47 -> Pg=45.0, Qg=10.005
% INFO    : Gen at bus 6311	: Vg=0.989 -> Vg=0.975
% INFO    : Gen at bus 6312	: Pg=71.16, Qg=5.15 -> Pg=47.5, Qg=10.18
% INFO    : Gen at bus 6312	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 6313	: Pg=66.11, Qg=4.78 -> Pg=51.0, Qg=12.17
% INFO    : Gen at bus 6313	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6314	: Pg=1.4, Qg=92.95 -> Pg=1.45, Qg=91.015
% INFO    : Gen at bus 6314	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6315	: Pg=201.05, Qg=-44.36 -> Pg=0.0, Qg=32.44
% INFO    : Gen at bus 6315	: Vg=0.965 -> Vg=0.975
% INFO    : Gen at bus 6316	: Pg=206.01, Qg=-43.23 -> Pg=0.0, Qg=33.005
% INFO    : Gen at bus 6316	: Vg=0.965 -> Vg=0.975
% INFO    : Gen at bus 6317	: Pg=932.35, Qg=285.07 -> Pg=584.03, Qg=170.355
% INFO    : Gen at bus 6317	: Vg=1.024 -> Vg=0.975
% INFO    : Gen at bus 6319	: Pg=945.07, Qg=266.78 -> Pg=595.06, Qg=190.47
% INFO    : Gen at bus 6319	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6320	: Pg=943.07, Qg=266.45 -> Pg=593.06, Qg=199.795
% INFO    : Gen at bus 6320	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6321	: Pg=1498.32, Qg=529.32 -> Pg=953.0, Qg=217.35
% INFO    : Gen at bus 6321	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 6322	: Pg=1498.32, Qg=360.58 -> Pg=953.0, Qg=217.35
% INFO    : Gen at bus 6322	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 6323	: Pg=1493.15, Qg=84.47 -> Pg=948.0, Qg=-28.08
% INFO    : Gen at bus 6323	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6324	: Pg=1493.15, Qg=97.16 -> Pg=948.0, Qg=-38.82
% INFO    : Gen at bus 6324	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 6325	: Pg=66.04, Qg=2.79 -> Pg=66.75, Qg=21.35
% INFO    : Gen at bus 6325	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6326	: Pg=64.04, Qg=0.96 -> Pg=66.75, Qg=21.35
% INFO    : Gen at bus 6326	: Vg=0.983 -> Vg=0.975
% INFO    : Gen at bus 6327	: Pg=123.99, Qg=12.02 -> Pg=76.2, Qg=35.07
% INFO    : Gen at bus 6327	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 6328	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6329	: Pg=543.98, Qg=208.65 -> Pg=460.0, Qg=94.405
% INFO    : Gen at bus 6329	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 6330	: Pg=549.93, Qg=211.47 -> Pg=460.0, Qg=55.15
% INFO    : Gen at bus 6330	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 6332	: Vg=0.982 -> Vg=0.975
% INFO    : Gen at bus 6333	: Pg=38.45, Qg=12.16 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6333	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6334	: Pg=36.45, Qg=11.74 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6334	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6335	: Pg=38.45, Qg=12.16 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6335	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6336	: Pg=38.45, Qg=12.16 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6336	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6337	: Pg=38.45, Qg=12.16 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6337	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6338	: Pg=37.45, Qg=11.95 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6338	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6339	: Pg=955.27, Qg=234.57 -> Pg=640.0, Qg=196.325
% INFO    : Gen at bus 6339	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6340	: Pg=966.27, Qg=260.2 -> Pg=640.0, Qg=196.325
% INFO    : Gen at bus 6340	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6341	: Pg=966.28, Qg=277.29 -> Pg=640.0, Qg=218.295
% INFO    : Gen at bus 6341	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6342	: Pg=925.38, Qg=256.12 -> Pg=605.0, Qg=208.07
% INFO    : Gen at bus 6342	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6343	: Pg=27.55, Qg=7.27 -> Pg=28.5, Qg=4.565
% INFO    : Gen at bus 6343	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6344	: Pg=28.53, Qg=7.38 -> Pg=28.5, Qg=4.565
% INFO    : Gen at bus 6344	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6345	: Vg=0.961 -> Vg=0.975
% INFO    : Gen at bus 6346	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 6347	: Pg=412.02, Qg=24.06 -> Pg=341.3, Qg=54.86
% INFO    : Gen at bus 6347	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6348	: Pg=918.08, Qg=196.11 -> Pg=577.95, Qg=187.455
% INFO    : Gen at bus 6348	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6349	: Pg=918.08, Qg=196.11 -> Pg=577.95, Qg=187.455
% INFO    : Gen at bus 6349	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6350	: Pg=925.08, Qg=197.22 -> Pg=584.95, Qg=188.785
% INFO    : Gen at bus 6350	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6351	: Pg=940.09, Qg=179.49 -> Pg=599.96, Qg=191.73
% INFO    : Gen at bus 6351	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6352	: Vg=1.024 -> Vg=0.975
% INFO    : Gen at bus 6353	: Pg=1307.45, Qg=216.15 -> Pg=860.0, Qg=-28.245
% INFO    : Gen at bus 6353	: Vg=1.044 -> Vg=0.975
% INFO    : Gen at bus 6354	: Pg=1188.46, Qg=208.77 -> Pg=860.0, Qg=-28.245
% INFO    : Gen at bus 6354	: Vg=1.044 -> Vg=0.975
% INFO    : Gen at bus 6355	: Pg=24.87, Qg=-3.38 -> Pg=15.75, Qg=4.47
% INFO    : Gen at bus 6355	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6356	: Pg=53.81, Qg=14.19 -> Pg=32.5, Qg=7.34
% INFO    : Gen at bus 6356	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6357	: Pg=51.12, Qg=13.3 -> Pg=35.0, Qg=0.32
% INFO    : Gen at bus 6357	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 6358	: Pg=54.11, Qg=13.73 -> Pg=32.5, Qg=8.95
% INFO    : Gen at bus 6358	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 6359	: Pg=57.1, Qg=14.96 -> Pg=32.5, Qg=10.38
% INFO    : Gen at bus 6359	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6360	: Pg=56.74, Qg=15.41 -> Pg=35.0, Qg=9.63
% INFO    : Gen at bus 6360	: Vg=1.031 -> Vg=0.975
% INFO    : Gen at bus 6361	: Pg=1303.17, Qg=185.21 -> Pg=798.0, Qg=36.21
% INFO    : Gen at bus 6361	: Vg=1.036 -> Vg=0.975
% INFO    : Gen at bus 6362	: Pg=1303.17, Qg=214.88 -> Pg=798.0, Qg=36.21
% INFO    : Gen at bus 6362	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 6363	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 6364	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 6365	: Pg=409.35, Qg=93.1 -> Pg=273.76, Qg=84.835
% INFO    : Gen at bus 6365	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 6366	: Pg=27.1, Qg=-1.47 -> Pg=18.0, Qg=-1.11
% INFO    : Gen at bus 6366	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 6367	: Pg=932.86, Qg=267.58 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6367	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6368	: Pg=942.15, Qg=235.05 -> Pg=607.0, Qg=190.895
% INFO    : Gen at bus 6368	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 6369	: Pg=942.15, Qg=259.91 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6369	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 6370	: Pg=942.15, Qg=241.36 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6370	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 6371	: Pg=942.15, Qg=235.31 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6371	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 6372	: Pg=835.71, Qg=244.55 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6372	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6373	: Vg=0.978 -> Vg=0.975
% INFO    : Gen at bus 6374	: Pg=430.29, Qg=79.89 -> Pg=336.8, Qg=72.235
% INFO    : Gen at bus 6374	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6375	: Pg=248.16, Qg=100.36 -> Pg=195.0, Qg=33.755
% INFO    : Gen at bus 6375	: Vg=1.036 -> Vg=0.975
% INFO    : Gen at bus 6376	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 6377	: Vg=0.981 -> Vg=0.975
% INFO    : Gen at bus 6379	: Pg=34.39, Qg=-11.76 -> Pg=28.5, Qg=10.395
% INFO    : Gen at bus 6379	: Vg=0.969 -> Vg=0.975
% INFO    : Gen at bus 6380	: Pg=33.41, Qg=-11.92 -> Pg=28.5, Qg=10.315
% INFO    : Gen at bus 6380	: Vg=0.969 -> Vg=0.975
% INFO    : Gen at bus 6381	: Pg=19.09, Qg=9.96 -> Pg=8.0, Qg=6.455
% INFO    : Gen at bus 6381	: Vg=1.044 -> Vg=0.975
% INFO    : Gen at bus 6382	: Pg=20.09, Qg=10.14 -> Pg=15.5, Qg=5.97
% INFO    : Gen at bus 6382	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 6383	: Pg=10.85, Qg=-1.8 -> Pg=9.75, Qg=1.46
% INFO    : Gen at bus 6383	: Vg=1.053 -> Vg=0.975
% INFO    : Gen at bus 6384	: Pg=10.85, Qg=-1.8 -> Pg=9.75, Qg=1.46
% INFO    : Gen at bus 6384	: Vg=1.053 -> Vg=0.975
% INFO    : Gen at bus 6385	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 6386	: Pg=27.19, Qg=9.05 -> Pg=17.5, Qg=0.905
% INFO    : Gen at bus 6386	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6387	: Pg=27.19, Qg=9.05 -> Pg=17.5, Qg=0.905
% INFO    : Gen at bus 6387	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6388	: Pg=26.2, Qg=9.07 -> Pg=17.5, Qg=-0.15
% INFO    : Gen at bus 6388	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6389	: Pg=28.19, Qg=9.25 -> Pg=17.5, Qg=1.005
% INFO    : Gen at bus 6389	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 6390	: Vg=0.959 -> Vg=0.975
% INFO    : Gen at bus 6391	: Pg=39.18, Qg=-4.78 -> Pg=23.5, Qg=2.41
% INFO    : Gen at bus 6391	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6392	: Pg=39.18, Qg=-4.78 -> Pg=23.5, Qg=2.41
% INFO    : Gen at bus 6392	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6393	: Pg=48.77, Qg=-1.59 -> Pg=36.5, Qg=10.17
% INFO    : Gen at bus 6393	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 6394	: Pg=55.83, Qg=1.28 -> Pg=34.5, Qg=13.355
% INFO    : Gen at bus 6394	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 6395	: Pg=55.83, Qg=0.04 -> Pg=38.0, Qg=11.28
% INFO    : Gen at bus 6395	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 6396	: Pg=50.79, Qg=-1.32 -> Pg=38.75, Qg=10.505
% INFO    : Gen at bus 6396	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 6397	: Pg=19.98, Qg=8.22 -> Pg=15.5, Qg=2.14
% INFO    : Gen at bus 6397	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6398	: Pg=20.93, Qg=8.38 -> Pg=15.5, Qg=2.14
% INFO    : Gen at bus 6398	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6399	: Pg=19.98, Qg=8.22 -> Pg=15.5, Qg=2.14
% INFO    : Gen at bus 6399	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6400	: Pg=33.33, Qg=27.62 -> Pg=25.0, Qg=8.08
% INFO    : Gen at bus 6400	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6401	: Pg=23.92, Qg=0.39 -> Pg=18.5, Qg=3.79
% INFO    : Gen at bus 6401	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6402	: Pg=22.94, Qg=0.19 -> Pg=18.5, Qg=3.79
% INFO    : Gen at bus 6402	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6403	: Pg=23.92, Qg=0.39 -> Pg=18.5, Qg=3.79
% INFO    : Gen at bus 6403	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6404	: Pg=23.92, Qg=0.39 -> Pg=18.5, Qg=3.79
% INFO    : Gen at bus 6404	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6405	: Pg=215.56, Qg=35.76 -> Pg=193.5, Qg=68.455
% INFO    : Gen at bus 6405	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 6406	: Pg=207.57, Qg=39.47 -> Pg=193.5, Qg=68.455
% INFO    : Gen at bus 6406	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6407	: Pg=6.35, Qg=1.63 -> Pg=9.5, Qg=1.75
% INFO    : Gen at bus 6407	: Vg=0.964 -> Vg=0.975
% INFO    : Gen at bus 6408	: Pg=6.35, Qg=1.63 -> Pg=9.5, Qg=1.75
% INFO    : Gen at bus 6408	: Vg=0.964 -> Vg=0.975
% INFO    : Gen at bus 6409	: Pg=94.43, Qg=-9.75 -> Pg=61.0, Qg=7.46
% INFO    : Gen at bus 6409	: Vg=0.981 -> Vg=0.975
% INFO    : Gen at bus 6410	: Pg=378.82, Qg=0.7 -> Pg=310.9, Qg=26.99
% INFO    : Gen at bus 6410	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 6411	: Pg=37.16, Qg=34.57 -> Pg=26.0, Qg=10.215
% INFO    : Gen at bus 6411	: Vg=1.079 -> Vg=0.975
% INFO    : Gen at bus 6412	: Pg=37.16, Qg=34.57 -> Pg=26.0, Qg=10.215
% INFO    : Gen at bus 6412	: Vg=1.079 -> Vg=0.975
% INFO    : Gen at bus 6413	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 6414	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 6415	: Pg=202.26, Qg=23.27 -> Pg=4.5, Qg=69.52
% INFO    : Gen at bus 6415	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6416	: Pg=198.32, Qg=22.49 -> Pg=4.5, Qg=69.84
% INFO    : Gen at bus 6416	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6417	: Pg=194.3, Qg=21.24 -> Pg=4.5, Qg=69.84
% INFO    : Gen at bus 6417	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6418	: Pg=195.28, Qg=21.52 -> Pg=4.5, Qg=69.935
% INFO    : Gen at bus 6418	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6419	: Pg=48.02, Qg=-5.91 -> Pg=32.5, Qg=12.59
% INFO    : Gen at bus 6419	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6420	: Pg=46.98, Qg=-6.08 -> Pg=32.5, Qg=12.59
% INFO    : Gen at bus 6420	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6421	: Pg=868.7, Qg=404.09 -> Pg=593.5, Qg=182.745
% INFO    : Gen at bus 6421	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6422	: Pg=896.69, Qg=205.35 -> Pg=593.5, Qg=193.685
% INFO    : Gen at bus 6422	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6423	: Pg=228.6, Qg=80.5 -> Pg=242.0, Qg=22.125
% INFO    : Gen at bus 6423	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6424	: Pg=186.1, Qg=78.55 -> Pg=149.0, Qg=42.4
% INFO    : Gen at bus 6424	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6425	: Vg=0.949 -> Vg=0.975
% INFO    : Gen at bus 6426	: Pg=1289.35, Qg=236.99 -> Pg=824.5, Qg=229.315
% INFO    : Gen at bus 6426	: Vg=0.989 -> Vg=0.975
% INFO    : Gen at bus 6427	: Pg=51.29, Qg=20.61 -> Pg=30.5, Qg=2.34
% INFO    : Gen at bus 6427	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6428	: Pg=51.29, Qg=20.61 -> Pg=30.5, Qg=2.34
% INFO    : Gen at bus 6428	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6429	: Pg=27.74, Qg=9.87 -> Pg=17.5, Qg=6.57
% INFO    : Gen at bus 6429	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6430	: Pg=1279.42, Qg=329.72 -> Pg=865.0, Qg=235.84
% INFO    : Gen at bus 6430	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6431	: Pg=1299.53, Qg=433.43 -> Pg=865.0, Qg=235.84
% INFO    : Gen at bus 6431	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 6432	: Pg=1305.53, Qg=400.22 -> Pg=865.0, Qg=230.335
% INFO    : Gen at bus 6432	: Vg=1.043 -> Vg=0.975
% INFO    : Gen at bus 6433	: Pg=1285.06, Qg=477.41 -> Pg=820.0, Qg=210.31
% INFO    : Gen at bus 6433	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 6434	: Pg=5.14, Qg=10.85 -> Pg=25.9, Qg=13.51
% INFO    : Gen at bus 6434	: Vg=1.05 -> Vg=0.975
% INFO    : Gen at bus 6435	: Pg=1311.29, Qg=379.12 -> Pg=860.0, Qg=234.135
% INFO    : Gen at bus 6435	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6436	: Pg=1274.54, Qg=390.48 -> Pg=860.0, Qg=234.135
% INFO    : Gen at bus 6436	: Vg=1.036 -> Vg=0.975
% INFO    : Gen at bus 6437	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 6438	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 6439	: Pg=581.67, Qg=322.32 -> Pg=393.0, Qg=119.02
% INFO    : Gen at bus 6439	: Vg=1.027 -> Vg=0.975
% INFO    : Gen at bus 6440	: Vg=0.975 -> Vg=0.975
% INFO    : Gen at bus 6441	: Pg=30.71, Qg=19.6 -> Pg=21.5, Qg=6.31
% INFO    : Gen at bus 6441	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6442	: Pg=26.97, Qg=18.83 -> Pg=21.5, Qg=6.31
% INFO    : Gen at bus 6442	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 6443	: Pg=27.91, Qg=19.02 -> Pg=21.5, Qg=6.31
% INFO    : Gen at bus 6443	: Vg=1.079 -> Vg=0.975
% INFO    : Gen at bus 6444	: Pg=59.91, Qg=-0.83 -> Pg=40.0, Qg=10.44
% INFO    : Gen at bus 6444	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 6445	: Pg=236.53, Qg=93.69 -> Pg=165.0, Qg=16.655
% INFO    : Gen at bus 6445	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6446	: Pg=419.66, Qg=46.37 -> Pg=450.0, Qg=57.26
% INFO    : Gen at bus 6446	: Vg=0.968 -> Vg=0.975
% INFO    : Gen at bus 6447	: Pg=45.19, Qg=0.05 -> Pg=28.0, Qg=4.12
% INFO    : Gen at bus 6447	: Vg=1.031 -> Vg=0.975
% INFO    : Gen at bus 6448	: Pg=44.18, Qg=-0.15 -> Pg=28.0, Qg=4.12
% INFO    : Gen at bus 6448	: Vg=1.031 -> Vg=0.975
% INFO    : Gen at bus 6449	: Pg=0.65, Qg=-0.32 -> Pg=29.0, Qg=29.66
% INFO    : Gen at bus 6449	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 6450	: Pg=16.4, Qg=3.53 -> Pg=11.55, Qg=3.15
% INFO    : Gen at bus 6450	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6451	: Pg=16.4, Qg=3.53 -> Pg=11.55, Qg=3.14
% INFO    : Gen at bus 6451	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6452	: Pg=410.43, Qg=184.29 -> Pg=335.3, Qg=88.785
% INFO    : Gen at bus 6452	: Vg=1.06 -> Vg=0.975
% INFO    : Gen at bus 6453	: Pg=36.1, Qg=14.36 -> Pg=20.5, Qg=2.215
% INFO    : Gen at bus 6453	: Vg=1.059 -> Vg=0.975
% INFO    : Gen at bus 6454	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 6455	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 6456	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 6457	: Pg=25.85, Qg=-1.06 -> Pg=16.0, Qg=4.57
% INFO    : Gen at bus 6457	: Vg=0.986 -> Vg=0.975
% INFO    : Gen at bus 6458	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 6459	: Pg=27.34, Qg=-0.75 -> Pg=16.0, Qg=4.57
% INFO    : Gen at bus 6459	: Vg=0.986 -> Vg=0.975
% INFO    : Gen at bus 6460	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 6461	: Pg=145.28, Qg=94.36 -> Pg=0.0, Qg=22.435
% INFO    : Gen at bus 6461	: Vg=1.087 -> Vg=0.975
% INFO    : Gen at bus 6462	: Pg=141.79, Qg=84.82 -> Pg=0.0, Qg=13.035
% INFO    : Gen at bus 6462	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 6463	: Pg=143.78, Qg=4.07 -> Pg=0.0, Qg=22.435
% INFO    : Gen at bus 6463	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 6464	: Pg=143.78, Qg=100.08 -> Pg=0.0, Qg=22.435
% INFO    : Gen at bus 6464	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 6465	: Pg=22.59, Qg=-1.22 -> Pg=16.0, Qg=4.095
% INFO    : Gen at bus 6465	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 6466	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6467	: Pg=21.59, Qg=0.12 -> Pg=14.5, Qg=3.765
% INFO    : Gen at bus 6467	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 6468	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6469	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6470	: Pg=24.49, Qg=6.32 -> Pg=22.0, Qg=4.315
% INFO    : Gen at bus 6470	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 6471	: Pg=25.52, Qg=4.43 -> Pg=15.5, Qg=2.94
% INFO    : Gen at bus 6471	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 6472	: Pg=24.54, Qg=4.24 -> Pg=15.5, Qg=2.94
% INFO    : Gen at bus 6472	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 6473	: Pg=19.89, Qg=-8.59 -> Pg=19.0, Qg=4.36
% INFO    : Gen at bus 6473	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 6474	: Pg=20.87, Qg=-8.52 -> Pg=19.0, Qg=4.225
% INFO    : Gen at bus 6474	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 6475	: Pg=18.9, Qg=-8.78 -> Pg=19.0, Qg=4.225
% INFO    : Gen at bus 6475	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6476	: Pg=42.52, Qg=-6.33 -> Pg=33.0, Qg=7.725
% INFO    : Gen at bus 6476	: Vg=0.973 -> Vg=0.975
% INFO    : Gen at bus 6477	: Pg=42.24, Qg=0.58 -> Pg=42.0, Qg=15.305
% INFO    : Gen at bus 6477	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 6478	: Pg=42.24, Qg=0.58 -> Pg=42.0, Qg=15.305
% INFO    : Gen at bus 6478	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 6479	: Vg=0.954 -> Vg=0.975
% INFO    : Gen at bus 6480	: Pg=72.46, Qg=-8.54 -> Pg=40.5, Qg=11.12
% INFO    : Gen at bus 6480	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6481	: Pg=71.46, Qg=-8.73 -> Pg=40.5, Qg=11.12
% INFO    : Gen at bus 6481	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6482	: Pg=72.46, Qg=-8.54 -> Pg=40.5, Qg=11.12
% INFO    : Gen at bus 6482	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6483	: Pg=71.46, Qg=-8.73 -> Pg=40.5, Qg=11.12
% INFO    : Gen at bus 6483	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6484	: Pg=116.13, Qg=17.76 -> Pg=65.0, Qg=6.33
% INFO    : Gen at bus 6484	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 6485	: Pg=1307.8, Qg=285.61 -> Pg=807.0, Qg=215.91
% INFO    : Gen at bus 6485	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6486	: Pg=1281.8, Qg=290.29 -> Pg=807.0, Qg=215.91
% INFO    : Gen at bus 6486	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6487	: Pg=277.71, Qg=33.68 -> Pg=217.5, Qg=91.59
% INFO    : Gen at bus 6487	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6488	: Pg=537.89, Qg=114.03 -> Pg=410.0, Qg=53.715
% INFO    : Gen at bus 6488	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 6489	: Pg=387.1, Qg=140.68 -> Pg=285.0, Qg=60.695
% INFO    : Gen at bus 6489	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6490	: Pg=410.1, Qg=144.35 -> Pg=285.0, Qg=62.485
% INFO    : Gen at bus 6490	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6491	: Pg=44.79, Qg=14.3 -> Pg=25.0, Qg=1.74
% INFO    : Gen at bus 6491	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6492	: Pg=45.1, Qg=14.38 -> Pg=25.0, Qg=1.74
% INFO    : Gen at bus 6492	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6493	: Pg=21.54, Qg=5.89 -> Pg=15.0, Qg=4.19
% INFO    : Gen at bus 6493	: Vg=0.973 -> Vg=0.975
% INFO    : Gen at bus 6494	: Pg=21.55, Qg=-4.26 -> Pg=15.0, Qg=4.19
% INFO    : Gen at bus 6494	: Vg=0.931 -> Vg=0.975
% INFO    : Gen at bus 6495	: Pg=58.63, Qg=20.9 -> Pg=42.5, Qg=19.785
% INFO    : Gen at bus 6495	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 6496	: Vg=0.975 -> Vg=0.975
% INFO    : Gen at bus 6497	: Pg=922.28, Qg=209.1 -> Pg=589.89, Qg=197.89
% INFO    : Gen at bus 6497	: Vg=1.01 -> Vg=0.975
% INFO    : Gen at bus 6498	: Pg=915.28, Qg=207.76 -> Pg=592.89, Qg=198.435
% INFO    : Gen at bus 6498	: Vg=1.01 -> Vg=0.975
% INFO    : Gen at bus 6499	: Pg=32.84, Qg=16.04 -> Pg=24.5, Qg=0.785
% INFO    : Gen at bus 6499	: Vg=1.031 -> Vg=0.975
% INFO    : Gen at bus 6500	: Pg=27.88, Qg=15.36 -> Pg=24.5, Qg=0.785
% INFO    : Gen at bus 6500	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6501	: Pg=27.88, Qg=15.36 -> Pg=24.5, Qg=0.785
% INFO    : Gen at bus 6501	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6502	: Pg=122.7, Qg=-36.76 -> Pg=78.0, Qg=32.39
% INFO    : Gen at bus 6502	: Vg=0.958 -> Vg=0.975
% INFO    : Gen at bus 6503	: Pg=71.71, Qg=10.76 -> Pg=49.5, Qg=-5.525
% INFO    : Gen at bus 6503	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6504	: Pg=73.69, Qg=11.11 -> Pg=49.5, Qg=-5.525
% INFO    : Gen at bus 6504	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6505	: Pg=931.13, Qg=259.26 -> Pg=630.0, Qg=121.775
% INFO    : Gen at bus 6505	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6506	: Pg=901.96, Qg=252.19 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 6506	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 6507	: Pg=960.0, Qg=260.49 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 6507	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6508	: Pg=960.33, Qg=228.46 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 6508	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 6509	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6510	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6511	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6512	: Pg=59.36, Qg=5.05 -> Pg=0.0, Qg=19.4
% INFO    : Gen at bus 6512	: Vg=0.936 -> Vg=0.975
% INFO    : Gen at bus 6513	: Pg=59.36, Qg=5.05 -> Pg=0.0, Qg=19.4
% INFO    : Gen at bus 6513	: Vg=0.936 -> Vg=0.975
% INFO    : Gen at bus 6514	: Pg=59.36, Qg=5.05 -> Pg=0.0, Qg=19.4
% INFO    : Gen at bus 6514	: Vg=0.936 -> Vg=0.975
% INFO    : Gen at bus 6515	: Pg=252.87, Qg=148.09 -> Pg=203.0, Qg=30.365
% INFO    : Gen at bus 6515	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 6516	: Pg=228.86, Qg=123.39 -> Pg=203.0, Qg=30.365
% INFO    : Gen at bus 6516	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6517	: Pg=163.25, Qg=48.33 -> Pg=90.0, Qg=27.8
% INFO    : Gen at bus 6517	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 6518	: Pg=57.64, Qg=49.61 -> Pg=68.0, Qg=43.88
% INFO    : Gen at bus 6518	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6519	: Pg=58.79, Qg=49.83 -> Pg=64.0, Qg=38.95
% INFO    : Gen at bus 6519	: Vg=1.081 -> Vg=0.975
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
