%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%CASE9241PEGASE  Power flow data for European system.
%   Please see CASEFORMAT for details on the case file format.
%
%   This case accurately represents the size and complexity of the European
%   high voltage transmission network. The network contains 9,241 buses,
%   1,445 generators, and 16,049 branches and it operates at 750, 400, 380,
%   330, 220, 154, 150, 120, and 110 kV. Please note that the data are
%   fictitious and do not correspond to real world data. They can thus be
%   used to validate methods and tools but should not be used for operation
%   and planning of the European grid.
%
%   The data stems from the Pan European Grid Advanced Simulation and State
%   Estimation (PEGASE) project, part of the 7th Framework Program of the
%   European Union (http://www.fp7-pegase.com/). When publishing results
%   based on this data, please cite:
%
%     S. Fliscounakis, P. Panciatici, F. Capitanescu, and L. Wehenkel,
%     "Contingency ranking with respect to overloads in very large power
%     systems taking into account uncertainty, preventive and corrective
%     actions", Power Systems, IEEE Trans. on, (28)4:4909-4917, 2013.
%     http://dx.doi.org/10.1109/TPWRS.2013.2251015
%
%   Remarks:
%
%   1. Line flow limits are the current flow limits found in PEGASE data.
%
%   2. PEGASE data contains asymmetric shunt conductance and susceptance in
%   the PI transmission line model of branches. Thus total line charging
%   susceptance of branches is set to 0 p.u. and the nodal representation
%   of shunt condutance and susceptance is used. As a result, power flow
%   equations are left unchanged compared with original PEGASE data.
%   However, line flow constraints in the optimal flow problem are
%   modified.
%
%   3. Identical linear costs are used for all generators to form a loss
%   minimizing OPF objective function.
%
%   4. Since some parts of the network are aggregated, some generators
%   (e.g. with negative PMIN) represent aggregations of multiple loads
%   and generators.
%
%   Cédric Josz, Stéphane Fliscounakis, Jean Maeght, Patrick Panciatici
%   firstname.lastname@rte-france.com
%   Réseau de Transport d'Electricité (French Transmission System Operator)
%   Département Expertise Système, Immeuble "Le Colbert"
%   9 rue de la Porte de Buc, 78000 Versailles Cedex, France
%   March 18th, 2015
%
%   Copyright (c) 2015 by Cédric Josz, Stéphane Fliscounakis, Jean Maeght,
%   and Patrick Panciatici
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case9241_pegase
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 1	 378.4	 98.5	 0.0	 16.61	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3	 1	 151.0	 48.8	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4	 1	 171.41	 23.4	 0.0	 2.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5	 1	 45.95	 14.0	 0.0	 13.34	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7	 1	 31.03	 10.3	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9	 1	 14.3	 2.0	 0.0	 1.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10	 1	 134.0	 24.7	 0.0	 12.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12	 1	 -6.11	 2.0	 0.0	 0.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13	 1	 -22.74	 -8.32	 0.0	 6.5	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	14	 1	 13.5	 14.8	 0.0	 132.435168	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	15	 1	 59.67	 26.7	 0.0	 12.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	16	 1	 30.6	 4.3	 0.0	 5.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	17	 1	 67.68	 12.1	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	18	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	19	 1	 25.33	 7.5	 0.0	 2.39	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	20	 1	 1.4	 0.2	 0.0	 4.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	21	 1	 161.2	 39.3	 0.0	 30.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	22	 1	 0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	23	 1	 19.62	 7.1	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	24	 1	 17.22	 5.7	 0.0	 1.22	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	25	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	26	 1	 167.3	 54.8	 0.0	 110.54	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	27	 1	 -0.0	 -0.0	 0.0	 14.82	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	28	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	29	 1	 152.9	 49.4	 0.0	 27.65	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	30	 1	 -0.0	 0.0	 0.0	 0.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	31	 1	 69.68	 43.2	 0.0	 6.3	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	32	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	33	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	34	 1	 13.52	 4.9	 0.0	 1.8	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	35	 1	 10.51	 3.5	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	36	 1	 -0.0	 -0.0	 0.12	 15.34	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	37	 1	 9.21	 2.6	 0.0	 2.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	38	 1	 42.75	 12.8	 0.0	 13.3	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	39	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	40	 1	 16.02	 4.54	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	41	 1	 27.9	 4.0	 0.0	 4.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	42	 1	 20.82	 7.9	 0.0	 26.89	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	43	 1	 12.6	 1.8	 0.0	 2.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	44	 1	 -0.0	 0.0	 0.0	 7.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	45	 1	 10.11	 3.7	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	46	 1	 10.01	 2.7	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	47	 1	 6.31	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	48	 1	 2.9	 0.9	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	49	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	50	 1	 48.8	 6.9	 0.0	 8.71	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	51	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	52	 1	 127.6	 31.8	 0.0	 20.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	53	 1	 48.65	 16.1	 0.0	 7.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	54	 1	 110.5	 -26.8	 0.0	 16.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	55	 1	 0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	56	 1	 140.0	 79.7	 0.0	 6.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	57	 1	 21.6	 3.0	 0.0	 3.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	58	 1	 0.0	 0.0	 0.0	 2.31	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	59	 1	 119.2	 20.7	 0.0	 3.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	60	 1	 0.24	 -1.66	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	61	 1	 -0.0	 0.0	 0.0	 58.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	62	 1	 -0.0	 0.0	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	63	 1	 187.9	 110.2	 0.0	 21.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	64	 1	 14.92	 5.5	 0.0	 1.31	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	65	 1	 -18.52	 6.1	 0.0	 0.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	66	 1	 4.61	 1.7	 0.0	 2.32	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	67	 1	 0.0	 0.0	 0.099501	 82.133595	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	68	 1	 10.81	 5.1	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	69	 1	 62.87	 20.5	 0.0	 1.15	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	70	 1	 0.0	 0.0	 0.0	 2.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	71	 1	 126.3	 42.4	 0.0	 55.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	72	 1	 6.91	 -4.6	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	73	 1	 15.72	 5.2	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	74	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	75	 1	 38.74	 6.1	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	76	 1	 22.13	 10.7	 0.0	 14.21	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	77	 1	 -0.0	 -0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	78	 1	 0.0	 -0.0	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	79	 1	 138.8	 136.7	 0.0	 8.76	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	80	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	81	 1	 67.76	 19.18	 0.0	 1.47	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	82	 1	 22.02	 5.1	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	83	 1	 0.0	 0.0	 0.0	 6.62	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	84	 1	 1.0	 0.3	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	85	 1	 20.9	 3.0	 0.0	 5.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	86	 1	 0.0	 0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	87	 1	 21.52	 5.1	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	88	 1	 71.98	 28.8	 0.0	 11.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	89	 1	 0.0	 0.0	 0.199111	 4.530599	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	90	 1	 363.25	 115.39	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	91	 1	 -0.0	 0.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	92	 1	 192.9	 73.3	 0.0	 20.75	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	93	 1	 17.52	 6.3	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	94	 1	 33.14	 12.0	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	95	 1	 40.45	 25.0	 0.0	 9.82	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	96	 1	 193.17	 53.37	 0.0	 4.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	97	 1	 0.0	 0.0	 0.0	 9.38	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	98	 1	 90.7	 25.5	 0.0	 3.11	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	99	 1	 176.3	 -58.9	 0.0	 24.77	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	100	 1	 35.94	 22.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	101	 1	 -0.0	 0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	102	 1	 0.0	 -0.0	 0.0	 3.77	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	103	 1	 65.07	 40.3	 0.0	 5.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	104	 1	 51.36	 -8.8	 0.0	 2.15	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	105	 1	 -0.0	 -0.0	 0.0	 82.55	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	106	 1	 0.0	 -0.0	 0.0	 31.19	 0	    1.00000	    0.00000	 380.0	 23	    1.30000	    0.70000;
	107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.30000	    0.70000;
	108	 1	 3.8	 1.3	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	109	 1	 137.0	 19.5	 0.0	 4.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	110	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	111	 1	 61.07	 36.0	 0.0	 3.09	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	112	 1	 0.0	 0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	113	 1	 -0.0	 -0.0	 0.0	 6.532711	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	114	 1	 55.7	 7.9	 0.0	 4.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	115	 1	 0.0	 -0.0	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	116	 1	 1.8	 0.7	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	117	 1	 40.04	 16.0	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	118	 1	 -0.0	 0.0	 0.0	 36.562834	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	119	 1	 0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	120	 1	 140.6	 20.1	 0.0	 13.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	121	 1	 45.15	 14.1	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	122	 1	 -0.0	 0.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	123	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	124	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	125	 1	 3.42	 2.68	 0.0	 1.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	126	 1	 0.0	 -0.0	 0.0	 2.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	127	 1	 -0.0	 -0.0	 0.0	 4.3	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	128	 1	 23.73	 12.7	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	129	 1	 121.9	 7.4	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	130	 1	 -0.0	 0.0	 0.135375	 47.750675	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	131	 1	 47.35	 16.4	 0.0	 4.08	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	132	 1	 0.0	 -0.0	 0.0	 21.39	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	133	 1	 38.14	 12.5	 0.0	 6.28	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	134	 1	 54.2	 7.8	 0.0	 94.9	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	135	 1	 130.6	 84.9	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	136	 1	 7.91	 2.6	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	137	 1	 42.1	 74.61	 0.0	 37.58	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	138	 1	 -75.38	 7.8	 0.0	 29.9	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	139	 1	 -0.0	 -0.0	 0.0	 36.92	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	140	 1	 0.0	 0.0	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	141	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	142	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	143	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	144	 1	 0.0	 0.0	 0.0	 98.53	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	145	 1	 38.34	 5.6	 0.0	 7.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	146	 1	 269.6	 65.7	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 20	    1.30000	    0.70000;
	147	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	148	 1	 32.34	 12.0	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	149	 1	 100.1	 45.1	 0.0	 1.11	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	151	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	152	 1	 7.0	 1.0	 0.0	 4.69	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	153	 1	 -0.0	 0.0	 0.0	 0.56	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	154	 1	 0.0	 0.0	 0.0	 1.29	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	155	 1	 -0.0	 -0.0	 0.0	 1.7	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	156	 1	 40.34	 25.0	 0.0	 1.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	157	 1	 9.21	 3.3	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	158	 1	 166.0	 60.3	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	159	 1	 0.0	 -0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	160	 1	 79.4	 11.3	 0.0	 4.92	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	161	 1	 -0.0	 -0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	162	 1	 0.0	 0.0	 0.0	 66.65	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	163	 1	 147.76	 32.73	 0.0	 8.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	164	 1	 0.0	 -0.0	 0.0	 5.17	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	165	 1	 26.8	 -3.7	 0.0	 51.261678	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	166	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	167	 1	 257.5	 131.1	 0.0	 1.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	168	 1	 16.7	 2.4	 0.0	 6.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	169	 1	 0.0	 0.0	 0.0	 1.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	170	 1	 -0.0	 -0.0	 0.0	 2.35	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	171	 1	 100.8	 13.2	 0.0	 5.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	172	 1	 111.7	 10.96	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	173	 1	 90.38	 -5.05	 0.0	 8.49	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	174	 1	 370.5	 -17.0	 0.0	 9.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	175	 1	 9.91	 3.2	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	176	 1	 -0.69	 -5.46	 0.0	 5.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	177	 1	 94.9	 36.2	 0.0	 16.46	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	178	 1	 81.09	 48.0	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	180	 1	 0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	181	 1	 54.96	 16.9	 0.0	 3.37	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	182	 1	 19.32	 26.0	 0.0	 0.69	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	183	 1	 0.0	 0.0	 0.0	 1.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	184	 1	 -0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	185	 1	 20.9	 3.0	 0.0	 4.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	186	 1	 19.92	 6.6	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	187	 1	 57.16	 2.0	 0.0	 1.48	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	188	 1	 36.84	 13.9	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	189	 1	 -15.04	 -5.12	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	190	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	191	 1	 0.0	 -0.0	 0.0	 14.19	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	193	 1	 119.9	 3.7	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	194	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	195	 1	 73.14	 21.55	 0.0	 8.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	196	 1	 0.0	 -0.0	 0.0	 12.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	197	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	198	 1	 39.74	 11.8	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	199	 1	 86.8	 28.4	 0.0	 1.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	200	 1	 22.42	 2.1	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	201	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	202	 1	 110.9	 32.7	 0.0	 15.4	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	203	 1	 18.2	 2.6	 0.0	 12.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	204	 1	 -0.0	 -0.0	 0.181549	 14.690889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	205	 1	 46.15	 18.2	 0.0	 1.29	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	206	 1	 34.04	 12.3	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	207	 1	 321.98	 84.4	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	208	 1	 33.44	 10.0	 0.0	 1.36	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	209	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	210	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	211	 1	 75.28	 19.2	 0.0	 1.9	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	212	 1	 95.69	 24.54	 0.0	 2.85	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	213	 1	 37.34	 10.9	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	214	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	215	 1	 -0.0	 0.0	 0.0	 4.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	216	 1	 155.6	 54.7	 0.0	 2.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	217	 1	 105.2	 0.1	 0.0	 7.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	218	 1	 69.83	 15.12	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	219	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	220	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	221	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	223	 1	 27.03	 8.8	 0.0	 1.84	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	224	 1	 2.6	 0.5	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	225	 1	 0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	226	 1	 14.62	 4.8	 0.0	 1.02	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	227	 1	 -0.0	 0.0	 0.0	 2.55	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	228	 1	 -23.43	 57.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	229	 1	 426.6	 93.7	 0.0	 80.94	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	230	 1	 152.07	 22.52	 0.0	 7.87	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	231	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	232	 1	 0.0	 0.0	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	233	 1	 2.5	 3.8	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	234	 1	 16.7	 2.4	 0.0	 0.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	235	 1	 34.04	 4.4	 0.0	 1.25	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	236	 1	 45.85	 7.0	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	237	 1	 0.0	 -0.0	 0.0	 30.97	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	238	 1	 0.0	 -0.0	 0.0	 19.36	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	239	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	240	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	241	 1	 -0.0	 0.0	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	242	 1	 167.9	 18.2	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	243	 1	 0.0	 -0.01	 0.0	 13.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	244	 1	 -0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	245	 1	 16.62	 5.5	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	246	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	247	 1	 0.0	 0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	248	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	249	 1	 -0.0	 -0.0	 0.0	 26.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	250	 1	 0.0	 0.0	 0.0	 13.85	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	251	 1	 118.4	 16.9	 0.0	 8.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	252	 1	 -0.0	 0.0	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	253	 1	 0.0	 -0.0	 0.0	 4.06	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	254	 1	 -0.0	 -0.0	 0.135493	 12.74062	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	255	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	256	 1	 0.0	 -0.0	 0.0	 7.09	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	257	 1	 113.9	 24.5	 0.0	 6.72	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	258	 1	 88.0	 12.6	 0.0	 22.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	259	 1	 42.67	 12.11	 0.0	 14.84	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	260	 1	 216.8	 40.5	 0.0	 5.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	261	 1	 -0.0	 0.0	 0.0	 1.29	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	262	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	263	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	264	 1	 38.74	 9.0	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	265	 1	 350.4	 29.3	 0.0	 19.31	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	266	 1	 0.0	 -0.0	 0.0	 140.96	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	267	 1	 103.8	 2.7	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	268	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	269	 1	 0.0	 -0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	270	 1	 -0.0	 0.0	 0.0	 6.34	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	271	 1	 96.7	 26.8	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	272	 1	 0.0	 0.0	 0.0	 19.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	273	 1	 -0.0	 -0.0	 0.0	 14.87	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	274	 1	 19.02	 6.0	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	275	 1	 102.1	 25.3	 0.0	 1.11	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	276	 1	 -0.0	 0.0	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	277	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	279	 1	 8.31	 3.0	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	280	 1	 119.6	 29.6	 0.0	 5.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	281	 1	 -0.0	 -0.0	 0.0	 18.07	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	282	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	283	 1	 27.33	 11.9	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	284	 1	 191.2	 -3.4	 0.0	 19.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	285	 1	 0.0	 0.0	 0.029916	 18.291787	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	286	 1	 101.6	 14.5	 0.0	 1.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	287	 1	 177.1	 66.9	 0.0	 71.03	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	288	 1	 0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	289	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	290	 1	 53.46	 18.7	 0.0	 1.64	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	291	 1	 0.0	 -0.0	 0.0	 12.73	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	292	 1	 13.82	 1.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	293	 1	 85.1	 67.0	 0.0	 0.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	294	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	295	 1	 0.0	 0.0	 0.0	 0.08	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	296	 1	 189.3	 76.7	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	297	 1	 23.73	 9.4	 0.0	 1.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	298	 1	 10.01	 -21.0	 0.0	 8.59	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	299	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	300	 1	 0.0	 0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	301	 1	 -14.85	 -4.95	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	302	 1	 20.9	 3.0	 0.0	 2.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	303	 1	 431.7	 121.6	 0.0	 1.14	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	304	 1	 2.2	 0.5	 0.0	 0.21	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	305	 1	 103.0	 12.0	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	306	 1	 -0.0	 0.0	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	307	 1	 0.0	 0.0	 0.0	 25.85	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	308	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	309	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	310	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	311	 1	 42.05	 17.2	 0.0	 1.31	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	312	 1	 -0.16	 -2.91	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	313	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	314	 1	 163.1	 46.3	 0.0	 10.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	315	 1	 -0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	316	 1	 0.0	 -0.0	 0.0	 2.81	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	317	 1	 -0.0	 -0.0	 0.045946	 -1.82203	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	318	 1	 -0.0	 -0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	319	 1	 153.3	 21.8	 0.0	 18.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	320	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	321	 1	 67.17	 -23.9	 0.0	 0.93	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	322	 1	 303.8	 85.4	 0.0	 3.63	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	323	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	324	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	325	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	326	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	327	 1	 0.0	 0.0	 0.0	 12.29	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	329	 1	 24.23	 7.1	 0.0	 1.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	330	 1	 108.6	 2.6	 0.0	 31.8	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	331	 1	 4.0	 2.4	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	332	 1	 30.03	 10.9	 0.0	 1.45	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	333	 1	 524.5	 43.0	 0.0	 6.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	334	 1	 129.9	 18.5	 0.0	 0.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	335	 1	 -0.0	 0.0	 0.0	 1.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	336	 1	 4.4	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	337	 1	 9.22	 1.2	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	339	 1	 -0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	340	 1	 186.6	 56.6	 0.0	 30.24	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	341	 1	 -0.0	 -0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	342	 1	 35.41	 20.3	 0.0	 10.07	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	343	 1	 3.2	 1.2	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	344	 1	 372.8	 147.5	 0.0	 27.73	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	345	 1	 0.0	 0.0	 0.080094	 -0.240282	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	346	 1	 197.5	 48.3	 0.0	 0.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	347	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	348	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	349	 1	 -0.0	 0.0	 0.0	 15.15	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	350	 1	 110.4	 26.2	 0.0	 5.62	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	351	 1	 -0.15	 -1.93	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	353	 1	 -0.0	 -0.0	 0.0	 14.6	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	354	 1	 -0.0	 0.0	 0.0	 8.67	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	355	 1	 -4.86	 -2.15	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	356	 1	 141.1	 2.1	 0.0	 4.78	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	357	 1	 52.96	 32.8	 0.0	 14.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	358	 1	 13.9	 1.9	 0.0	 0.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	359	 1	 0.0	 0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	360	 1	 35.54	 11.5	 0.0	 3.65	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	361	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.30000	    0.70000;
	362	 1	 48.92	 14.52	 0.0	 2.85	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	363	 1	 -0.0	 0.0	 0.0	 26.52	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	364	 1	 10.01	 4.0	 0.0	 8.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	365	 1	 0.0	 -0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	366	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	367	 1	 65.17	 -51.5	 0.0	 4.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	368	 1	 -0.0	 0.0	 0.0	 7.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	369	 1	 -0.0	 0.0	 0.0	 3.78	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	370	 1	 56.76	 23.2	 0.0	 0.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	371	 1	 0.0	 0.0	 0.0	 11.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	372	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	373	 1	 -0.0	 0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	374	 1	 -0.0	 -0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	375	 1	 -0.0	 0.0	 0.0	 1.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	376	 1	 0.01	 0.0	 0.0	 35.09	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	377	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	378	 1	 221.35	 51.8	 0.0	 8.81	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	379	 1	 23.83	 7.9	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	380	 1	 -95.71	 -2.8	 0.0	 7.25	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	381	 1	 44.05	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	382	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	383	 1	 19.02	 11.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	384	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	385	 1	 -0.0	 -0.0	 0.0	 105.84	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	386	 1	 0.0	 -0.0	 0.0	 28.09	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	387	 1	 -0.19	 -4.38	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	388	 1	 0.0	 -0.0	 0.0	 7.15	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	389	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	390	 1	 27.93	 10.1	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	391	 1	 34.94	 21.6	 0.0	 0.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	392	 1	 134.1	 34.2	 0.0	 0.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	393	 1	 17.72	 5.9	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	394	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	395	 1	 -0.0	 -0.0	 0.0	 7.85	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	396	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	397	 1	 77.79	 -40.8	 0.0	 12.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	398	 1	 11.91	 3.8	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	399	 1	 5.01	 2.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	400	 1	 -19.66	 -10.83	 0.0	 0.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	401	 1	 56.5	 36.29	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	402	 1	 -0.0	 -0.0	 0.0	 16.38	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	403	 1	 -0.0	 -0.0	 0.090774	 7.330444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	404	 1	 3.81	 0.24	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	405	 1	 254.7	 79.4	 0.0	 9.43	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	406	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	407	 1	 69.5	 9.9	 0.0	 98.63	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	408	 1	 129.1	 7.4	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	410	 1	 170.89	 50.38	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	411	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	412	 1	 26.4	 3.8	 0.0	 4.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	413	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	414	 1	 20.52	 10.3	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	415	 1	 4.71	 0.7	 0.0	 11.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	416	 1	 70.68	 13.5	 0.0	 6.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	417	 1	 187.19	 1.8	 0.0	 20.47	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	418	 1	 24.43	 8.7	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	419	 1	 8.81	 3.2	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	420	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	421	 1	 33.74	 20.9	 0.0	 1.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	422	 1	 35.84	 12.5	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	423	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	424	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	425	 1	 -0.0	 0.0	 0.0	 2.72	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	426	 1	 123.1	 6.5	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	427	 1	 -0.0	 0.0	 0.0	 1.24	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	428	 1	 0.1	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	429	 1	 26.93	 -22.4	 0.0	 4.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	430	 1	 29.03	 9.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	431	 1	 188.42	 106.93	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	432	 1	 -0.0	 -0.0	 0.0	 68.517663	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	433	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	434	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	435	 1	 33.14	 11.6	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	436	 1	 18.3	 8.2	 0.0	 35.421268	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	437	 1	 69.08	 24.0	 0.0	 1.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	438	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	439	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	441	 1	 -0.0	 0.0	 0.199768	 27.888516	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	442	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	443	 1	 -12.61	 4.1	 0.0	 1.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	444	 1	 0.0	 -0.0	 0.0	 2.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	445	 1	 36.74	 10.3	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	446	 1	 100.53	 43.37	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	447	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	448	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	449	 1	 0.0	 0.0	 0.0	 29.42	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	450	 1	 42.04	 43.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	451	 1	 -0.0	 -0.0	 0.0	 22.71	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	452	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	453	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	454	 1	 23.7	 3.4	 0.0	 8.13	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	455	 1	 274.32	 5.66	 0.0	 13.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	456	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	457	 1	 1.8	 0.7	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	458	 1	 0.0	 0.0	 0.190956	 35.262077	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	459	 1	 97.0	 40.3	 0.0	 16.79	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	460	 1	 0.0	 -0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	461	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	462	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	463	 1	 24.33	 7.6	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	464	 1	 44.75	 0.9	 0.0	 6.67	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	465	 1	 -0.0	 0.0	 0.11	 2.57	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	466	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	467	 1	 40.5	 5.7	 0.0	 3.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	468	 1	 9.01	 6.8	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	469	 1	 81.09	 48.0	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	470	 1	 -0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	471	 1	 0.0	 0.0	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	472	 1	 336.2	 131.6	 0.0	 64.01	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	473	 1	 -22.95	 -3.72	 0.0	 14.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	474	 1	 -0.0	 0.0	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	475	 1	 0.0	 0.0	 0.0	 9.41	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	476	 1	 67.3	 94.8	 0.0	 7.96	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	477	 1	 0.0	 0.0	 0.0	 70.37	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	478	 1	 0.0	 -0.0	 0.0	 33.23	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	479	 1	 16.62	 3.1	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	480	 1	 5.81	 1.1	 0.0	 4.02	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	481	 1	 -0.0	 0.0	 0.0	 17.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	482	 1	 0.0	 0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	483	 1	 57.26	 15.6	 0.0	 3.43	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	484	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	485	 1	 0.0	 0.0	 0.0	 4.9	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	486	 1	 7.01	 2.0	 0.0	 0.44	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	487	 1	 87.8	 12.5	 0.0	 0.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	488	 1	 6.61	 2.92	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	489	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	490	 1	 20.52	 4.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	491	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	492	 1	 68.18	 22.0	 0.0	 2.42	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	493	 1	 23.23	 7.6	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	494	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	495	 1	 181.7	 51.0	 0.0	 73.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	496	 1	 -0.0	 -0.0	 0.0	 10.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	497	 1	 40.0	 5.7	 0.0	 2.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	498	 1	 31.23	 11.3	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	499	 1	 287.31	 -5.58	 0.0	 19.9	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	500	 1	 144.4	 35.5	 0.0	 7.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	501	 1	 -0.0	 0.0	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	502	 1	 -0.0	 0.0	 0.0	 1.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	503	 1	 4.1	 -607.0	 0.256125	 85.984967	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	504	 1	 18.62	 6.2	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	505	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	506	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	507	 1	 23.43	 8.5	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	508	 1	 23.92	 7.75	 0.0	 1.91	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	509	 1	 77.29	 7.0	 0.0	 17.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	510	 1	 -0.0	 -0.0	 0.0	 1.5	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	511	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	512	 1	 10.11	 2.8	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	513	 1	 57.46	 17.1	 0.0	 1.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	514	 1	 9.61	 3.1	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	515	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	516	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	517	 1	 7.71	 16.7	 0.0	 3.59	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	518	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	519	 1	 207.2	 9.4	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	520	 1	 118.5	 20.4	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	521	 1	 14.72	 5.3	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	522	 1	 11.61	 7.2	 0.0	 28.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	523	 1	 189.9	 74.7	 0.0	 26.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	524	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	525	 1	 36.54	 27.4	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	526	 1	 176.7	 25.6	 0.0	 2.01	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	527	 1	 277.7	 45.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	528	 1	 0.0	 -0.0	 0.0	 3.46	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	529	 1	 0.0	 -0.0	 0.0	 28.16	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	530	 1	 25.0	 3.6	 0.0	 4.73	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	531	 1	 0.0	 -0.0	 0.0	 47.4	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	532	 1	 0.0	 0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	533	 1	 16.52	 3.8	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	534	 1	 118.1	 16.8	 0.0	 2.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	535	 1	 11.51	 3.8	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	536	 1	 87.8	 -1.4	 0.079073	 36.047349	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	537	 1	 27.53	 17.0	 0.0	 0.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	538	 1	 21.02	 13.0	 0.0	 1.17	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	539	 1	 57.96	 18.9	 0.0	 14.91	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	540	 1	 166.9	 86.1	 0.0	 4.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	541	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	542	 1	 2.0	 0.7	 0.0	 0.02	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	543	 1	 72.0	 10.3	 0.0	 6.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	544	 1	 79.69	 39.6	 0.0	 18.83	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	545	 1	 -0.0	 -0.0	 0.0	 8.48	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	546	 1	 -0.0	 -0.0	 0.0	 29.89	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	547	 1	 30.03	 14.0	 0.0	 0.61	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	548	 1	 30.93	 8.9	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	549	 1	 0.0	 -0.0	 0.0	 5.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	550	 1	 0.0	 -0.0	 0.0	 10.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	551	 1	 17.72	 5.9	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	552	 1	 180.8	 90.8	 0.0	 2.42	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	553	 1	 0.0	 0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	554	 1	 0.0	 -0.0	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	555	 1	 0.0	 -0.0	 0.0	 7.35	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	556	 1	 16.52	 9.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	557	 1	 0.0	 0.0	 0.0	 12.14	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	558	 1	 -0.18	 -3.57	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	559	 1	 42.25	 16.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	560	 1	 3.8	 1.3	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	561	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	562	 1	 0.0	 -0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	563	 1	 -0.0	 0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	565	 1	 198.4	 32.7	 0.0	 31.82	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	566	 1	 5.81	 3.8	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	567	 1	 0.0	 -0.0	 0.0	 14.5	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	568	 1	 20.22	 7.3	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	569	 1	 -0.0	 0.0	 0.0	 35.364539	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	570	 1	 47.95	 29.7	 0.0	 1.59	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	571	 1	 120.63	 56.2	 0.0	 3.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	572	 1	 27.13	 8.9	 0.0	 1.37	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	573	 1	 10.71	 3.5	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	574	 1	 82.89	 26.8	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	575	 1	 0.0	 -0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	576	 1	 108.6	 38.7	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	577	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	578	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	579	 1	 17.32	 6.6	 0.0	 16.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	580	 1	 322.7	 11.9	 0.0	 10.28	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	581	 1	 48.8	 6.9	 0.0	 0.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	582	 1	 51.16	 18.2	 0.0	 5.23	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	583	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	584	 1	 151.2	 72.4	 0.0	 4.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	585	 1	 21.12	 8.3	 0.0	 4.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	586	 1	 9.51	 3.2	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	587	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	588	 1	 1.5	 0.8	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	589	 1	 27.03	 9.8	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	590	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	591	 1	 -0.0	 0.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	592	 1	 0.0	 -0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	593	 1	 -0.0	 0.0	 0.0	 29.2	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	594	 1	 67.57	 17.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	595	 1	 47.55	 5.3	 0.0	 7.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	596	 1	 24.83	 7.6	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	597	 1	 33.34	 15.7	 0.0	 64.15	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	598	 1	 -0.0	 0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	599	 1	 0.0	 -0.0	 0.0	 37.635138	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	600	 1	 -0.0	 0.0	 0.0	 8.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	601	 1	 140.6	 42.6	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	602	 1	 110.8	 -8.8	 0.0	 3.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	603	 1	 48.9	 28.6	 0.0	 98.806507	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	604	 1	 33.24	 4.4	 0.0	 24.54	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	605	 1	 23.4	 3.3	 0.0	 1.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	606	 1	 0.0	 -0.0	 0.0	 19.56	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	607	 1	 -0.0	 0.0	 0.0	 7.06	 0	    1.00000	    0.00000	 330.0	 24	    1.10000	    0.90000;
	608	 1	 150.9	 10.4	 0.0	 4.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	609	 1	 -0.0	 -0.0	 0.0	 5.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	610	 1	 -0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	611	 1	 -0.0	 0.0	 0.09381	 0.90492	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	612	 1	 -0.0	 -0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	613	 1	 181.1	 25.8	 0.0	 1.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	614	 1	 18.5	 3.7	 0.0	 0.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	615	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	616	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	617	 1	 -0.92	 -4.99	 0.0	 1.86	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	618	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	619	 1	 72.88	 14.4	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	620	 1	 15.42	 5.8	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	621	 1	 21.42	 8.1	 0.0	 7.38	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	622	 1	 0.0	 -0.0	 0.0	 11.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	623	 1	 36.1	 5.2	 0.0	 11.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	624	 1	 111.4	 36.5	 0.0	 70.21	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	625	 1	 0.0	 0.0	 0.0	 4.43	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	626	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	627	 1	 116.8	 60.3	 0.0	 9.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	628	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	629	 1	 177.2	 32.3	 0.0	 6.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	630	 1	 -0.0	 -0.0	 0.0	 17.07	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	631	 1	 0.0	 0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	632	 1	 -0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	633	 1	 2.5	 -0.0	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	634	 1	 0.0	 0.0	 0.0	 104.15	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	635	 1	 -0.0	 -0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	636	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	637	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	638	 1	 181.41	 16.52	 0.0	 4.07	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	639	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	640	 1	 102.0	 26.6	 0.0	 2.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	641	 1	 45.32	 18.5	 0.0	 0.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	643	 1	 15.52	 6.3	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	644	 1	 192.3	 27.4	 0.0	 30.64	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	645	 1	 26.33	 9.5	 0.0	 1.85	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	646	 1	 -0.59	 -0.83	 0.0	 5.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	647	 1	 48.05	 15.8	 0.0	 6.08	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	648	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	649	 1	 40.94	 19.2	 0.0	 5.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	650	 1	 17.22	 4.4	 0.0	 1.71	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	651	 1	 62.46	 7.15	 0.0	 10.06	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	652	 1	 0.0	 -0.0	 0.0	 5.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	653	 1	 10.31	 2.3	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	654	 1	 205.6	 74.0	 0.0	 5.56	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	655	 1	 9.7	 1.4	 0.0	 6.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	656	 1	 -0.15	 -1.93	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	657	 1	 65.27	 30.9	 0.0	 3.1	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	658	 1	 258.4	 66.7	 0.0	 5.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	659	 1	 -0.0	 -0.0	 0.174507	 73.977052	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	660	 1	 584.3	 166.3	 0.0	 48.159681	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	661	 1	 -0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	662	 1	 0.0	 -0.0	 0.0	 4.14	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	663	 1	 0.0	 0.0	 0.12	 12.89	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	664	 1	 38.04	 11.7	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	665	 1	 0.0	 -0.0	 0.0	 7.2	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	666	 1	 -5.61	 -2.79	 0.0	 150.93	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	667	 1	 -0.0	 -0.0	 0.0	 2.76	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	668	 1	 48.8	 6.9	 0.0	 5.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	669	 1	 -0.0	 -0.0	 0.0	 29.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	670	 1	 5.51	 17.7	 0.0	 0.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	671	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	672	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	673	 1	 0.0	 0.0	 0.0	 12.75	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	674	 1	 -0.0	 -0.0	 0.0	 65.82	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	675	 1	 5.11	 -0.1	 0.0	 3.73	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	676	 1	 109.3	 35.4	 0.0	 1.91	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	677	 1	 30.83	 10.8	 0.0	 2.59	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	678	 1	 232.1	 89.8	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	679	 1	 -0.0	 -0.0	 0.0	 3.94	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	680	 1	 79.59	 50.5	 0.0	 14.31	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	681	 1	 0.0	 0.0	 0.0	 14.54	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	682	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	683	 1	 169.8	 55.5	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	684	 1	 60.07	 28.0	 0.0	 4.13	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	685	 1	 0.0	 0.0	 0.0	 47.77	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	686	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	687	 1	 -0.0	 0.0	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	688	 1	 -3.4	 -1.3	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	689	 1	 124.8	 23.5	 0.0	 5.84	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	690	 1	 22.42	 8.2	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	691	 1	 83.6	 11.9	 0.0	 3.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	692	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 6	    1.10000	    0.90000;
	693	 1	 -0.0	 0.0	 0.0	 93.75	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	694	 1	 0.0	 0.0	 0.12	 6.65	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	695	 1	 96.41	 26.5	 0.0	 0.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	696	 1	 12.4	 6.89	 0.0	 0.63	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	698	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	699	 1	 36.54	 8.4	 0.0	 6.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	700	 1	 12.71	 0.8	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	701	 1	 20.32	 6.7	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	702	 1	 -0.0	 -0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	703	 1	 0.0	 0.0	 0.0	 7.84	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	704	 1	 41.05	 14.3	 0.0	 11.53	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	705	 1	 8.3	 1.2	 0.0	 1.6	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	706	 1	 114.8	 22.8	 0.0	 5.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	707	 1	 83.99	 21.2	 0.0	 5.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	708	 1	 0.0	 -0.0	 0.0	 9.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	709	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	710	 1	 76.38	 5.1	 0.0	 3.97	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	711	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	712	 1	 110.4	 41.9	 0.0	 1.88	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	713	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	714	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	715	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	716	 1	 29.63	 10.8	 0.0	 2.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	717	 1	 4.5	 -5.6	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	718	 1	 135.11	 41.0	 0.0	 5.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	719	 1	 -0.54	 -0.99	 0.0	 1.13	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	720	 1	 -0.0	 -0.0	 0.0	 23.554121	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	721	 1	 -0.0	 -0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	722	 1	 0.0	 -0.0	 0.0	 0.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	723	 1	 104.6	 14.9	 0.0	 7.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	724	 1	 30.83	 6.6	 0.0	 3.19	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	725	 1	 0.0	 -0.0	 0.0	 34.82	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	726	 1	 400.3	 189.9	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	727	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 19	    1.30000	    0.70000;
	728	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	729	 1	 0.0	 -0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	730	 1	 20.62	 6.5	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	731	 1	 0.0	 0.0	 0.0	 61.48	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	732	 1	 -0.0	 -0.0	 0.0	 11.12	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	733	 1	 58.36	 10.7	 0.0	 8.41	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	734	 1	 109.23	 66.36	 0.0	 5.44	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	735	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	736	 1	 45.56	 -1.51	 0.0	 19.94	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	737	 1	 8.11	 2.0	 0.0	 1.95	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	738	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	739	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	740	 1	 22.22	 13.7	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	741	 1	 -0.0	 -0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	742	 1	 0.0	 -0.0	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	743	 1	 5.01	 2.0	 0.0	 2.99	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	744	 1	 6.51	 4.1	 0.0	 1.27	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	745	 1	 90.4	 15.2	 0.0	 0.07	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	746	 1	 2.5	 1.3	 0.0	 0.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	747	 1	 69.58	 16.0	 0.0	 3.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	748	 1	 0.0	 -0.0	 0.0	 5.2	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	749	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	750	 1	 -0.0	 -0.0	 0.0	 18.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	751	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	752	 1	 -0.0	 -0.0	 0.0	 4.15	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	753	 1	 1.9	 0.6	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	754	 1	 132.1	 32.4	 0.0	 58.29	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	755	 1	 28.9	 4.2	 0.0	 2.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	756	 1	 36.74	 8.9	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	757	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	758	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	759	 1	 -0.0	 -0.0	 0.0	 9.58	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	760	 1	 0.0	 -0.0	 0.0	 1.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	761	 1	 -0.0	 0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	762	 1	 -0.0	 -0.0	 0.0	 0.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	763	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	765	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	766	 1	 -0.0	 0.0	 0.0	 7.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	767	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	768	 1	 0.0	 -0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	769	 1	 152.57	 40.0	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	770	 1	 -0.0	 0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	771	 1	 46.15	 20.9	 0.0	 1.4	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	772	 1	 343.9	 141.9	 0.0	 5.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	773	 1	 -14.87	 -4.17	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	774	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	775	 1	 -55.14	 -27.14	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	777	 1	 0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	778	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	779	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	780	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	781	 1	 34.04	 11.0	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	782	 1	 -0.0	 -0.0	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	783	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	784	 1	 -26.0	 -14.72	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	785	 1	 -0.0	 -0.0	 0.0	 4.03	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	786	 1	 -0.0	 0.0	 0.0	 0.79	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	787	 1	 125.7	 17.9	 0.0	 0.2	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	788	 1	 18.02	 6.4	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	789	 1	 -0.0	 -0.0	 0.0	 6.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	790	 1	 -0.15	 -1.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	791	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	792	 1	 295.3	 41.9	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	793	 1	 9.7	 1.4	 0.0	 4.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	794	 1	 0.0	 -0.0	 0.0	 1.653516	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	795	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	796	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	797	 1	 2.0	 114.6	 0.0	 16.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	798	 1	 235.2	 41.1	 0.0	 10.01	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	799	 1	 26.73	 10.8	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	800	 1	 50.56	 18.0	 0.0	 0.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	801	 1	 9.71	 3.0	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	802	 1	 0.0	 -0.0	 0.0	 12.42	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	803	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	804	 1	 -0.0	 -0.0	 0.0	 7.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	805	 1	 124.5	 29.6	 0.0	 15.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	806	 1	 -0.0	 -0.0	 0.0	 32.02	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	808	 1	 24.53	 8.6	 0.0	 7.01	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	809	 1	 0.0	 -0.0	 0.0	 58.088687	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	810	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	811	 1	 17.83	 -9.5	 0.0	 2.79	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	812	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	813	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	814	 1	 287.7	 16.3	 0.0	 12.86	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	815	 1	 25.27	 5.71	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	816	 1	 234.7	 -12.0	 0.0	 23.35	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	817	 1	 333.1	 17.5	 0.0	 18.86	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	818	 1	 0.0	 -0.0	 0.0	 8.73	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	819	 1	 0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	820	 1	 12.6	 1.8	 0.0	 1.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	821	 1	 -0.0	 0.0	 0.0	 22.93	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	822	 1	 121.9	 -0.2	 0.0	 12.83	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	824	 1	 32.1	 4.5	 0.0	 8.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	825	 1	 0.0	 0.0	 0.0	 29.76	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	826	 1	 31.94	 7.7	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	827	 1	 167.8	 77.0	 0.0	 12.66	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	828	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	829	 1	 113.6	 122.7	 0.0	 8.74	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	830	 1	 303.1	 75.5	 0.0	 22.74	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	831	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	832	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	833	 1	 15.02	 10.0	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	834	 1	 52.76	 17.2	 0.0	 38.38	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	835	 1	 -0.0	 0.0	 0.0	 24.4	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	836	 1	 -0.0	 -0.0	 0.0	 56.7	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	837	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	838	 1	 615.81	 286.69	 0.0	 101.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	839	 1	 -0.0	 -0.0	 0.0	 8.17514	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	840	 1	 0.0	 0.0	 0.0	 2.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	841	 1	 -0.0	 0.0	 0.135375	 32.572175	 0	    1.00000	    0.00000	 380.0	 18	    1.30000	    0.70000;
	842	 1	 0.0	 0.0	 0.0	 2.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	843	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	844	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	845	 1	 -0.0	 0.0	 0.0	 1.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	846	 1	 159.2	 59.9	 0.0	 37.33	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	847	 1	 13.9	 1.9	 0.0	 7.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	848	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	849	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	850	 1	 -0.0	 -0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	852	 1	 -0.0	 0.0	 0.0	 5.46	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	853	 1	 190.0	 43.3	 0.0	 12.94	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	854	 1	 49.96	 7.5	 0.0	 8.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	855	 1	 10.01	 3.3	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	856	 1	 -28.93	 9.5	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	857	 1	 21.72	 4.8	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	858	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	859	 1	 0.0	 0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	860	 1	 32.1	 4.5	 0.0	 4.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	861	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	862	 1	 36.44	 12.5	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	863	 1	 111.4	 15.9	 0.0	 2.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	864	 1	 1.3	 0.6	 0.0	 1.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	865	 1	 43.45	 26.9	 0.0	 3.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	866	 1	 -0.0	 -0.0	 0.0	 20.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	867	 1	 25.13	 14.0	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	868	 1	 13.82	 5.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	869	 1	 94.2	 5.5	 0.0	 6.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	870	 1	 110.0	 3.4	 0.0	 11.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	871	 1	 108.89	 -21.76	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	872	 1	 185.6	 26.4	 0.0	 32.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	873	 1	 143.9	 123.2	 0.0	 72.64	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	874	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	875	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	876	 1	 42.25	 13.9	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	877	 1	 2.0	 0.6	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	878	 1	 0.0	 -0.0	 0.0	 25.28	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	879	 1	 7.71	 3.3	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	880	 1	 0.0	 -0.0	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	881	 1	 -0.0	 0.0	 0.0	 1.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	882	 1	 394.9	 77.0	 0.0	 44.93	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	883	 1	 192.5	 78.3	 0.0	 6.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	884	 1	 13.82	 5.0	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	885	 1	 23.03	 14.3	 0.0	 6.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	886	 1	 -2.85	 -7.24	 0.0	 0.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	887	 1	 0.0	 0.0	 0.3205	 28.133148	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	888	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	889	 1	 3.9	 1.4	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	890	 1	 8.91	 3.8	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	891	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	892	 1	 -0.0	 -0.0	 0.0	 9.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	893	 1	 -0.0	 -0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	894	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	895	 1	 -0.0	 -0.0	 0.234854	 36.333138	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	897	 1	 153.5	 21.9	 0.0	 7.79	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	898	 1	 25.63	 7.9	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	899	 1	 -0.0	 -0.01	 0.0	 59.04	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	900	 1	 0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	901	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	902	 1	 -4.94	 -3.67	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	903	 1	 82.69	 20.1	 0.0	 1.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	904	 1	 146.9	 60.6	 0.0	 26.49	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	905	 1	 0.0	 -0.0	 0.0	 18.004129	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	906	 1	 -0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	907	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	908	 1	 125.9	 -0.5	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	909	 1	 12.61	 4.5	 0.0	 2.63	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	910	 1	 6.3	 0.9	 0.0	 3.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	911	 1	 13.21	 2.2	 0.0	 10.05	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	912	 1	 22.02	 13.2	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	913	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	914	 1	 -0.0	 0.0	 0.0	 89.51	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	915	 1	 24.53	 7.9	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	916	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	917	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	918	 1	 110.1	 29.4	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	919	 1	 -0.0	 0.0	 0.0	 13.89	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	920	 1	 34.44	 8.5	 0.0	 1.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	921	 1	 -0.0	 -0.0	 0.126343	 6.455031	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	922	 1	 15.22	 7.6	 0.0	 1.56	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	923	 1	 62.07	 14.7	 0.0	 4.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	924	 1	 10.01	 5.0	 0.0	 0.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	925	 1	 8.01	 4.1	 0.0	 2.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	926	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	927	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	928	 1	 112.9	 19.3	 0.0	 17.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	929	 1	 43.75	 12.4	 0.0	 9.35	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	931	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	932	 1	 77.59	 12.3	 0.0	 5.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	933	 1	 -0.0	 0.0	 0.0	 22.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	934	 1	 2.5	 1.3	 0.0	 2.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	935	 1	 -0.0	 0.0	 0.0	 9.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	936	 1	 0.0	 -0.0	 0.0	 1.93	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	937	 1	 -12.51	 4.1	 0.0	 0.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	938	 1	 0.0	 -0.0	 0.0	 31.47	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	939	 1	 150.1	 35.0	 0.0	 3.55	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	940	 1	 50.06	 16.3	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	941	 1	 26.03	 9.8	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	942	 1	 0.0	 0.0	 0.0	 34.26	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	943	 1	 -0.0	 0.0	 0.0	 3.37	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	944	 1	 30.33	 11.0	 0.0	 1.43	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	945	 1	 0.2	 0.1	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	946	 1	 189.1	 -11.9	 0.0	 27.462397	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	947	 1	 90.7	 5.8	 0.0	 4.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	948	 1	 15.82	 4.0	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	949	 1	 4.81	 2.2	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	950	 1	 69.08	 22.6	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	951	 1	 0.5	 -271.9	 0.0	 3.12	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	952	 1	 0.0	 0.0	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	953	 1	 108.7	 -12.15	 0.0	 37.11	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	954	 1	 66.27	 13.6	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	955	 1	 244.2	 152.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	956	 1	 19.42	 11.6	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	957	 1	 65.77	 16.1	 0.0	 1.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	958	 1	 -0.0	 0.0	 0.0	 51.29	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	959	 1	 166.6	 8.1	 0.0	 10.11	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	960	 1	 -0.0	 -0.0	 0.0	 108.728602	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	961	 1	 32.94	 20.4	 0.0	 8.95	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	962	 1	 42.55	 17.1	 0.0	 1.67	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	963	 1	 0.0	 0.0	 0.0	 12.74	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	964	 1	 88.5	 16.5	 0.0	 146.44	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	965	 1	 45.05	 9.9	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	966	 1	 190.91	 55.46	 0.0	 14.77	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	967	 1	 1.3	 0.4	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	968	 1	 -0.0	 0.0	 0.0	 49.26	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	969	 1	 0.4	 1.1	 0.0	 1.99	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	970	 1	 62.27	 -2.1	 0.0	 8.01	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	971	 1	 0.0	 0.0	 0.099501	 68.573595	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	972	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	973	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	974	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	975	 1	 33.24	 11.1	 0.0	 1.56	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	977	 1	 95.58	 -14.0	 0.0	 4.48	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	978	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	979	 1	 21.12	 7.7	 0.0	 1.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	980	 1	 14.71	 4.6	 0.0	 7.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	981	 1	 0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	982	 1	 62.7	 9.0	 0.0	 2.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	984	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	985	 1	 17.52	 4.6	 0.0	 11.82	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	986	 1	 15.98	 0.86	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	987	 1	 -0.0	 0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	988	 1	 -0.0	 -0.0	 0.0	 8.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	989	 1	 32.34	 10.6	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	990	 1	 -0.0	 0.0	 0.0	 8.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	991	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	992	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	993	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	994	 1	 -0.0	 -0.0	 0.0	 25.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	995	 1	 0.0	 -0.0	 0.0	 7.66	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	996	 1	 0.0	 0.0	 0.0	 0.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	997	 1	 0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	998	 1	 22.32	 13.8	 0.0	 2.96	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	999	 1	 20.02	 6.8	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1000	 1	 0.0	 -0.0	 0.0	 1.8	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1001	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1002	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1003	 1	 24.03	 8.0	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1004	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1005	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1006	 1	 -0.0	 -0.0	 0.0	 45.31	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1007	 1	 -0.0	 -0.0	 0.0	 1.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1008	 1	 0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1009	 1	 0.2	 0.4	 0.0	 0.73	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1010	 1	 21.32	 7.3	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1011	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1012	 1	 -0.0	 -0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1013	 1	 136.06	 40.4	 0.0	 12.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1014	 1	 -0.0	 0.0	 0.0	 1.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1015	 1	 44.55	 0.0	 0.0	 4.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1016	 1	 -0.0	 -0.0	 0.0	 15.04	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1017	 1	 26.93	 9.5	 0.0	 7.65	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1018	 1	 21.02	 7.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1019	 1	 0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1020	 1	 8.21	 3.31	 0.0	 8.38	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1021	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1022	 1	 0.0	 0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1023	 1	 -0.0	 0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1024	 1	 27.9	 4.0	 0.0	 0.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1025	 1	 241.4	 -2.5	 0.224624	 31.280331	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1026	 1	 201.4	 53.0	 0.0	 9.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1027	 1	 -5.91	 -2.33	 0.0	 30.393595	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1028	 1	 13.82	 5.0	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1029	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1030	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1031	 1	 84.59	 -18.5	 0.0	 64.57	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1032	 1	 27.03	 13.0	 0.0	 2.32	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1033	 1	 26.33	 5.3	 0.0	 4.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1034	 1	 -0.0	 -0.0	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1035	 1	 382.5	 57.9	 0.0	 8.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1037	 1	 -0.0	 0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1038	 1	 3.7	 -0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1039	 1	 34.64	 -0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1040	 1	 31.94	 8.8	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1041	 1	 12.11	 4.4	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1042	 1	 34.2	 4.9	 0.0	 9.08	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1044	 1	 40.5	 5.7	 0.0	 3.2	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1045	 1	 8.91	 5.1	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1046	 1	 47.05	 19.3	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1047	 1	 1.9	 0.8	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1048	 1	 27.8	 -2.03	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1049	 1	 -0.0	 -0.0	 0.0	 28.8	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	1050	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1051	 1	 -0.0	 0.0	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1052	 1	 67.48	 32.6	 0.0	 13.11	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1053	 1	 39.14	 13.2	 0.0	 2.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1054	 1	 83.6	 11.9	 0.0	 6.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1055	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1056	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1057	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1058	 1	 0.0	 -0.0	 0.0	 11.96	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1059	 1	 -0.0	 0.0	 0.0	 62.76	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1060	 1	 -0.0	 0.0	 0.0	 75.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1061	 1	 -0.0	 0.01	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1062	 1	 84.89	 32.4	 0.0	 7.77	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1063	 1	 50.06	 17.0	 0.0	 1.61	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1064	 1	 215.2	 -7.6	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1065	 1	 89.6	 20.0	 0.0	 9.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1066	 1	 0.0	 -0.0	 0.0	 9.67	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1067	 1	 279.4	 22.9	 0.0	 15.24	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1068	 1	 35.24	 11.6	 0.0	 1.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1069	 1	 -0.0	 0.0	 0.0	 8.72	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1070	 1	 1.6	 -0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1071	 1	 83.3	 47.9	 0.0	 6.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1072	 1	 -0.0	 -0.0	 0.0	 68.81	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1073	 1	 21.92	 7.2	 0.0	 3.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1074	 1	 403.9	 -0.1	 0.0	 143.1	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1075	 1	 9.08	 3.94	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	1076	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1077	 1	 -0.0	 0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1078	 1	 -0.0	 -0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1079	 1	 0.2	 1.3	 0.337525	 10.582137	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1080	 1	 48.8	 6.9	 0.0	 7.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1081	 1	 277.86	 58.95	 0.0	 182.880644	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1082	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1083	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1084	 1	 42.15	 14.2	 0.0	 1.71	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1085	 1	 162.1	 43.2	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1086	 1	 12.01	 5.6	 0.0	 39.29	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1087	 1	 -0.0	 0.0	 0.0	 3.75	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1088	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1089	 1	 -7.61	 2.5	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1090	 1	 56.06	 18.7	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1091	 1	 -24.85	 -3.56	 0.0	 1.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1092	 1	 30.93	 -46.6	 0.0	 1.62	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1093	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1094	 1	 28.53	 11.3	 0.0	 3.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1095	 1	 -0.0	 0.0	 0.0	 43.02	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1096	 1	 0.0	 -0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1098	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.30000	    0.70000;
	1099	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1100	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1101	 1	 -0.0	 -0.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1102	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1103	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	1104	 1	 5.11	 3.8	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1105	 1	 29.83	 7.3	 0.0	 6.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1106	 1	 192.4	 63.9	 0.0	 10.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1107	 1	 1.8	 0.6	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1108	 1	 -0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1109	 1	 -54.06	 13.1	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1110	 1	 227.34	 236.13	 0.0	 66.84	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	1111	 1	 0.0	 0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1112	 1	 10.91	 3.6	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1113	 1	 20.9	 3.0	 0.0	 5.46	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1114	 1	 59.27	 5.1	 0.0	 26.03	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1115	 1	 -40.54	 9.3	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1116	 1	 70.28	 58.9	 0.0	 7.33	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1117	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1118	 1	 254.0	 74.3	 0.0	 54.48	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	1119	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1120	 1	 244.8	 119.3	 0.0	 3.78	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1121	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1122	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1123	 1	 -9.0	 -10.19	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1124	 1	 -0.0	 -0.0	 0.0	 8.61	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1125	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	1126	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1127	 1	 0.0	 -0.0	 0.086633	 0.514111	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	1128	 1	 -878.1	 -312.7	 0.0	 31.21	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1129	 1	 190.47	 55.03	 0.0	 6.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1130	 1	 22.5	 3.2	 0.0	 5.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1131	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1132	 1	 7.8	 50.9	 0.0	 87.765989	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1133	 1	 115.2	 319.2	 0.0	 290.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1134	 1	 103.9	 14.8	 0.0	 1.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1135	 1	 1.4	 0.6	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1136	 1	 16.22	 2.0	 0.0	 0.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1137	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	1139	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	1140	 1	 0.0	 0.0	 0.0	 1.78	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1141	 1	 0.0	 0.0	 0.0	 23.36	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1142	 1	 45.9	 36.8	 0.0	 55.224909	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1143	 1	 0.0	 0.0	 0.210571	 8.306088	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1144	 1	 39.04	 -5.0	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	1146	 1	 32.84	 -0.0	 0.0	 1.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1147	 1	 20.02	 15.0	 0.0	 1.56	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1148	 1	 141.4	 123.0	 0.0	 8.52	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1149	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1150	 1	 0.0	 0.0	 0.0	 24.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1151	 1	 -0.0	 -0.0	 0.0	 18.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1152	 1	 -0.0	 0.0	 0.0	 46.01	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1153	 1	 12.41	 3.9	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1154	 1	 55.7	 7.9	 0.0	 2.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1155	 1	 -0.0	 0.0	 0.0	 1.91	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1156	 1	 65.67	 24.0	 0.0	 9.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1157	 1	 3.7	 0.6	 0.0	 0.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1158	 1	 24.13	 12.7	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1159	 1	 112.4	 13.0	 0.0	 3.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1160	 1	 0.1	 0.5	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1161	 1	 170.2	 60.8	 0.0	 16.27	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1162	 1	 0.0	 0.0	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1163	 1	 -0.0	 -0.0	 0.0	 16.04	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1164	 1	 26.43	 16.4	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1165	 1	 0.0	 -0.0	 0.0	 14.13	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1166	 1	 -39.81	 -10.9	 0.0	 3.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1167	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1168	 1	 0.0	 -0.0	 0.0	 89.06	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1169	 1	 116.2	 16.5	 0.0	 7.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1170	 1	 -9.51	 -3.32	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1171	 1	 79.89	 29.0	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1172	 1	 -0.0	 -0.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1173	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1174	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1175	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1176	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1177	 1	 -2.35	 -2.06	 0.0	 3.38	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1178	 1	 35.84	 11.8	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1179	 1	 86.6	 23.4	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1180	 1	 43.75	 16.8	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	1181	 1	 0.1	 -19.3	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1182	 1	 10.81	 3.9	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	1183	 1	 199.4	 -19.9	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1184	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1185	 1	 150.4	 15.3	 0.0	 8.09	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1186	 1	 62.7	 9.0	 0.0	 3.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1187	 1	 67.57	 21.2	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1188	 1	 30.93	 6.6	 0.0	 9.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1189	 1	 96.41	 18.1	 0.0	 2.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1190	 1	 14.62	 5.6	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1191	 1	 37.3	 5.4	 0.0	 0.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1192	 1	 13.21	 9.2	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1193	 1	 181.5	 21.2	 0.0	 64.45	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1194	 1	 129.6	 13.3	 0.0	 13.98	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1195	 1	 3.8	 2.5	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1196	 1	 -0.0	 -0.0	 0.181549	 8.450889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	1197	 1	 25.23	 10.6	 0.0	 1.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1198	 1	 0.0	 0.0	 0.0	 30.637696	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1199	 1	 -0.0	 -0.0	 0.052811	 29.652975	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	1200	 1	 124.8	 7.9	 0.0	 48.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1201	 1	 114.1	 23.5	 0.0	 1.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1202	 1	 -0.0	 0.0	 0.0	 46.28	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	1203	 1	 41.8	 5.9	 0.0	 1.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1204	 1	 0.0	 0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1205	 1	 -0.19	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1206	 1	 27.13	 16.8	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1207	 1	 70.18	 28.7	 0.0	 0.8	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1208	 1	 13.9	 1.9	 0.0	 0.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1209	 1	 183.03	 15.7	 0.0	 1.83	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1210	 1	 -15.82	 5.2	 0.0	 1.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1211	 1	 -0.59	 -2.55	 0.04975	 111.131798	 0	    1.00000	    0.00000	 380.0	 18	    1.30000	    0.70000;
	1212	 1	 -0.0	 -0.0	 0.0	 35.18	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	1213	 1	 29.8	 4.3	 0.0	 2.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1214	 1	 105.0	 412.0	 0.0	 37.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1215	 1	 0.0	 0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1216	 1	 0.0	 0.0	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1217	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1218	 1	 30.83	 13.2	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1219	 1	 1.4	 0.5	 0.0	 1.87	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1220	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1221	 1	 230.5	 91.0	 0.0	 57.67	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1222	 1	 23.03	 14.3	 0.0	 16.88	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1223	 1	 26.4	 3.8	 0.0	 0.7	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1224	 1	 168.3	 -57.1	 0.0	 16.319522	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1226	 1	 -0.0	 0.0	 0.0	 0.21	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1227	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1228	 1	 53.16	 17.7	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1229	 1	 5.51	 2.0	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1230	 1	 0.0	 -0.0	 0.0	 2.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1231	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1232	 1	 0.0	 -0.0	 0.0	 81.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1233	 1	 0.0	 -0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1234	 1	 71.78	 17.9	 0.0	 1.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1235	 1	 4.3	 0.6	 0.0	 4.43	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1236	 1	 105.5	 24.7	 0.0	 58.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	1238	 1	 60.37	 35.4	 0.0	 14.88	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1239	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1240	 1	 23.53	 4.0	 0.0	 9.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1241	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1242	 1	 226.3	 51.7	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1243	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1244	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1245	 1	 -4.57	 -1.31	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1246	 1	 2.0	 1.0	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1247	 1	 23.03	 8.3	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1248	 1	 0.0	 0.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1249	 1	 141.26	 30.6	 0.0	 18.01	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1250	 1	 39.44	 24.9	 0.0	 4.18	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1251	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1252	 1	 0.0	 0.0	 0.0	 6.56	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1253	 1	 186.6	 155.8	 0.0	 28.99	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1254	 1	 -0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1255	 1	 20.62	 8.2	 0.0	 6.62	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1256	 1	 1.9	 1.3	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1257	 1	 -0.0	 0.0	 0.0	 13.02	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1258	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1259	 1	 -0.0	 -0.0	 0.0	 39.46	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	1260	 1	 50.86	 36.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1261	 1	 279.5	 25.8	 0.0	 20.3	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1262	 1	 -0.0	 0.0	 0.0	 10.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1263	 1	 -0.0	 -0.0	 0.256113	 11.74089	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1264	 1	 224.9	 -32.5	 0.0	 63.28	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1265	 1	 173.0	 -21.3	 0.0	 5.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1266	 1	 15.42	 2.2	 0.0	 1.46	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1268	 1	 151.2	 96.4	 0.279148	 38.889483	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1269	 1	 112.8	 27.6	 0.0	 35.18	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1270	 1	 1.8	 0.7	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1271	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1272	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1273	 1	 7.01	 2.3	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1274	 1	 149.9	 53.2	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1275	 1	 52.46	 2.9	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1276	 1	 -0.0	 0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1277	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1278	 1	 0.0	 0.0	 0.0	 28.5	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1279	 1	 -0.0	 -0.0	 0.0	 1.56	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1280	 1	 0.0	 -0.0	 0.0	 107.39	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1281	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1282	 1	 202.0	 34.1	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1283	 1	 42.75	 15.2	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	1284	 1	 19.02	 9.1	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1285	 1	 -0.0	 -0.2	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1286	 1	 7.61	 2.5	 0.0	 1.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1287	 1	 -0.19	 -78.58	 0.0	 2.31	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1288	 1	 9.61	 5.9	 0.0	 1.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1289	 1	 18.82	 6.2	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1290	 1	 22.32	 7.3	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1291	 1	 124.1	 17.6	 0.0	 6.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1292	 1	 23.4	 3.3	 0.0	 6.88	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1293	 1	 50.26	 19.3	 0.0	 2.1	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1294	 1	 6.11	 -0.0	 0.0	 2.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1295	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1296	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1297	 1	 19.02	 8.0	 0.0	 2.05	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1298	 1	 -0.0	 0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1299	 1	 30.53	 10.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1300	 1	 42.95	 26.6	 0.0	 2.95	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1301	 1	 479.0	 99.2	 0.0	 10.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1302	 1	 -19.83	 -6.01	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1303	 1	 -0.0	 0.0	 0.0	 3.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1304	 1	 5.41	 1.8	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1305	 1	 -0.0	 -0.0	 0.0	 4.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1306	 1	 8.51	 6.4	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1307	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	1308	 1	 71.38	 10.3	 0.0	 4.56	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1309	 1	 17.72	 3.8	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1310	 1	 -0.0	 -0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1311	 1	 37.94	 15.2	 0.0	 35.31	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1312	 1	 18.2	 2.6	 0.0	 1.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1313	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1314	 1	 -0.0	 -0.0	 0.0	 2.79	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1315	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.30000	    0.70000;
	1316	 1	 13.82	 3.6	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1317	 1	 149.3	 -2.0	 0.0	 20.77	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1318	 1	 0.2	 0.8	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1319	 1	 -0.0	 -0.0	 0.0	 0.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1320	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1321	 1	 11.41	 5.1	 0.0	 1.04	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1322	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1323	 1	 118.9	 129.2	 0.0	 10.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1324	 1	 37.14	 11.6	 0.0	 1.8	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1325	 1	 37.69	 -19.49	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1326	 1	 0.0	 0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1327	 1	 135.7	 31.6	 0.0	 26.65	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1328	 1	 0.0	 -0.0	 0.0	 50.16	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1329	 1	 105.8	 15.1	 0.0	 4.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1330	 1	 100.6	 15.3	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1331	 1	 -0.17	 -1.82	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1332	 1	 -0.0	 0.0	 0.0	 2.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1333	 1	 -9.61	 3.2	 0.0	 0.75	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1334	 1	 0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1335	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 23	    1.10000	    0.90000;
	1336	 1	 13.9	 1.9	 0.0	 1.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1337	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	1338	 1	 29.03	 9.4	 0.0	 5.11	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1339	 1	 108.4	 -2.4	 0.0	 80.12	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1340	 1	 13.21	 6.6	 0.0	 1.19	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1341	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1342	 1	 14.31	 0.87	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1343	 1	 -0.0	 -0.0	 0.0	 58.3	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1344	 1	 -0.0	 0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1345	 1	 1.91	 3.95	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1346	 1	 -0.0	 0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1347	 1	 0.0	 -0.0	 0.0	 12.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1348	 1	 34.9	 5.0	 0.0	 6.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1349	 1	 -0.0	 -0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1350	 1	 30.53	 13.8	 0.0	 2.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1351	 1	 0.0	 0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1352	 1	 28.93	 11.9	 0.0	 3.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1353	 1	 6.41	 2.3	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1354	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1355	 1	 -3.29	 -1.32	 0.0	 190.704588	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1356	 1	 538.3	 90.8	 0.0	 21.34	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1357	 1	 2.1	 0.3	 0.0	 2.83	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1358	 1	 100.3	 4.8	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1359	 1	 60.17	 30.6	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1360	 1	 -0.0	 0.0	 0.27075	 68.09435	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	1361	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1362	 1	 -0.0	 -0.0	 0.0	 6.93	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1363	 1	 0.0	 0.0	 0.316851	 27.808806	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	1364	 1	 40.85	 14.5	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1365	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1366	 1	 22.02	 7.7	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1367	 1	 0.0	 -0.0	 0.175687	 -1.509401	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1368	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1369	 1	 0.0	 0.0	 0.258764	 32.105228	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1370	 1	 46.55	 28.8	 0.0	 1.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1371	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1372	 1	 50.96	 16.8	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1373	 1	 -0.0	 0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1374	 1	 0.0	 -0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1375	 1	 10.11	 8.9	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1376	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1377	 1	 18.02	 6.0	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1378	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1379	 1	 2.91	 -1.45	 0.0	 5.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1380	 1	 145.2	 21.4	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1381	 1	 93.9	 13.4	 0.0	 5.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1382	 1	 10.81	 3.5	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1383	 1	 0.0	 0.0	 0.0	 3.97	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1384	 1	 0.0	 -0.0	 0.0	 42.32	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	1385	 1	 14.75	 -0.07	 0.0	 3.07	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1386	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1387	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	1388	 1	 20.32	 6.7	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1389	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1390	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	1391	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1392	 1	 -0.0	 -0.0	 0.0	 4.2	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1393	 1	 2.4	 0.7	 0.0	 10.69	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1394	 1	 30.93	 7.6	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1395	 1	 52.96	 15.2	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	1396	 1	 -0.0	 -6.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1397	 1	 0.0	 -0.0	 0.0	 2.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1398	 1	 196.7	 44.2	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1399	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1400	 1	 39.25	 71.7	 0.0	 33.75	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1401	 1	 11.91	 2.9	 0.0	 5.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1402	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	1403	 1	 -22.07	 -1.97	 0.0	 13.85	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1404	 1	 69.3	 9.9	 0.0	 0.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1405	 1	 -0.0	 0.0	 0.0	 1.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1406	 1	 157.9	 26.0	 0.0	 3.74	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1407	 1	 0.0	 -0.0	 0.0	 4.15	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1408	 1	 15.52	 5.2	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1410	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1411	 1	 0.0	 -0.0	 0.0	 7.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1412	 1	 5.11	 0.9	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1413	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1414	 1	 144.7	 20.3	 0.0	 6.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1415	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1416	 1	 7.81	 2.6	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1417	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1418	 1	 40.55	 3.6	 0.0	 1.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1419	 1	 16.52	 3.3	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1420	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1421	 1	 42.95	 19.8	 0.0	 3.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1423	 1	 -0.0	 -0.0	 0.0	 8.53	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1424	 1	 -4.89	 -2.35	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1425	 1	 0.3	 0.2	 0.0	 4.7	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1426	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1427	 1	 0.0	 0.0	 0.0	 1.85	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1428	 1	 22.83	 7.5	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1429	 1	 -0.0	 0.0	 0.0	 121.27	 0	    1.00000	    0.00000	 380.0	 22	    1.10000	    0.90000;
	1430	 1	 20.82	 7.9	 0.0	 5.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1431	 1	 -8.31	 2.7	 0.0	 0.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1432	 1	 193.2	 121.7	 0.0	 11.94	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1433	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1434	 1	 -0.0	 0.0	 0.0	 4.88	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1435	 1	 -0.0	 0.0	 0.0	 3.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1437	 1	 204.6	 53.2	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1438	 1	 0.0	 -0.0	 0.31	 25.37	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1439	 1	 110.1	 2.0	 0.0	 13.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1441	 1	 60.07	 20.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1442	 1	 89.3	 12.8	 0.0	 4.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1443	 1	 171.96	 40.73	 0.0	 23.47	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	1444	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1445	 1	 238.4	 210.9	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	1446	 1	 10.91	 3.0	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1447	 1	 4.61	 1.7	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1448	 1	 0.0	 0.0	 0.0	 9.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1449	 1	 -0.0	 0.0	 0.0	 6.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1450	 1	 39.54	 14.3	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1451	 1	 20.52	 6.7	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1452	 1	 -0.0	 -0.0	 0.0	 2.3	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1453	 1	 80.09	 26.3	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1454	 1	 20.62	 10.7	 0.0	 0.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1455	 1	 18.02	 4.8	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1456	 1	 0.0	 0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1457	 1	 20.82	 36.0	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1458	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1459	 1	 -0.0	 -0.0	 0.0	 3.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1460	 1	 67.4	 9.6	 0.0	 4.68	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1461	 1	 0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1462	 1	 -0.0	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1463	 1	 109.6	 36.4	 0.0	 13.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1464	 1	 22.73	 6.4	 0.0	 2.1	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1465	 1	 -11.03	 -5.11	 0.0	 29.706803	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1466	 1	 42.95	 26.6	 0.0	 3.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1467	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1468	 1	 0.0	 -0.0	 0.0	 17.6	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1469	 1	 0.0	 0.0	 0.0	 6.4	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1470	 1	 18.12	 -11.6	 0.0	 14.14	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1471	 1	 95.61	 8.6	 0.0	 3.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1472	 1	 0.0	 -0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1473	 1	 0.0	 0.0	 0.15	 6.49	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	1474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1475	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1476	 1	 30.63	 19.0	 0.0	 2.33	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	1477	 1	 0.0	 -0.0	 0.0	 5.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1478	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1479	 1	 82.19	 23.4	 0.0	 17.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1480	 1	 100.1	 45.6	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1482	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1483	 1	 0.0	 0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1484	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1485	 1	 144.9	 87.7	 0.214796	 36.223148	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1486	 1	 79.59	 18.8	 0.0	 6.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1487	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1488	 1	 -0.0	 -0.0	 0.0	 1.66	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1489	 1	 0.0	 -0.0	 0.0	 2.54	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1490	 1	 23.03	 14.2	 0.0	 1.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1491	 1	 117.5	 -3.0	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1492	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1493	 1	 1.1	 2.5	 0.229158	 23.95807	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1494	 1	 -1.85	 -1.63	 0.0	 31.424588	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1495	 1	 18.02	 6.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1496	 1	 0.7	 0.2	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1497	 1	 0.0	 0.0	 0.0	 11.44	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1498	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1499	 1	 6.41	 2.3	 0.0	 1.51	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1500	 1	 13.82	 5.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1501	 1	 -0.0	 -0.0	 0.0	 12.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1502	 1	 -0.0	 0.0	 0.0	 37.116157	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1503	 1	 142.8	 -6.4	 0.0	 12.36	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1504	 1	 0.0	 -0.0	 0.0	 1.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1505	 1	 6.71	 3.3	 0.0	 1.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1506	 1	 0.0	 0.0	 0.0	 149.14	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	1507	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1508	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1509	 1	 16.42	 5.9	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1510	 1	 -0.0	 0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1511	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1512	 1	 339.1	 89.0	 0.0	 80.71	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1513	 1	 -35.74	 38.6	 0.0	 4.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1514	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1515	 1	 0.0	 -0.0	 0.0	 28.31	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1516	 1	 22.02	 9.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1517	 1	 7.41	 2.7	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1518	 1	 0.0	 -0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1519	 1	 -10.51	 3.5	 0.0	 0.8	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1520	 1	 173.6	 72.9	 0.0	 2.5	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1521	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1522	 1	 72.1	 71.8	 0.0	 22.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1523	 1	 57.86	 23.2	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1524	 1	 -0.0	 -0.0	 0.0	 7.22	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1525	 1	 0.0	 -0.0	 0.0	 17.24	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1526	 1	 -10.86	 -5.93	 0.0	 12.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1527	 1	 39.64	 11.9	 0.0	 2.86	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1528	 1	 5.81	 2.0	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1529	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1530	 1	 0.0	 8.4	 0.0	 15.21	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1531	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1532	 1	 2.5	 1.3	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1533	 1	 43.8	 20.7	 0.0	 133.678646	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1534	 1	 -0.0	 -0.0	 0.261953	 32.381259	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	1535	 1	 20.32	 8.9	 0.0	 1.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1536	 1	 0.0	 0.0	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1537	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1538	 1	 36.34	 15.2	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1539	 1	 73.58	 3.24	 0.0	 52.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1540	 1	 0.0	 -0.0	 0.27075	 74.70435	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	1541	 1	 125.4	 45.8	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1542	 1	 170.4	 81.9	 0.0	 59.64	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	1543	 1	 116.7	 64.0	 0.0	 10.41	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1544	 1	 -0.0	 0.0	 0.0	 44.56	 0	    1.00000	    0.00000	 380.0	 23	    1.30000	    0.70000;
	1545	 1	 42.55	 8.2	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1546	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1547	 1	 -0.0	 -0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1548	 1	 7.61	 2.5	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1549	 1	 300.2	 -3.1	 0.0	 29.94	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1550	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	1551	 1	 -0.0	 -0.0	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1552	 1	 20.42	 8.1	 0.0	 35.15	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1553	 1	 -21.62	 -3.9	 0.0	 4.01	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1554	 1	 0.0	 -0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1555	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	1556	 1	 -0.0	 -0.0	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1557	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1558	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1559	 1	 -0.0	 -0.0	 0.0	 2.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1560	 1	 -0.5	 -1.0	 0.0	 0.68	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1561	 1	 175.2	 82.4	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1562	 1	 77.39	 24.1	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1563	 1	 -0.0	 -0.0	 0.090774	 1.980444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	1564	 1	 140.4	 49.4	 0.0	 4.5	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1565	 1	 16.7	 2.4	 0.0	 3.57	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1566	 1	 156.9	 -4.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1567	 1	 60.07	 27.0	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	1568	 1	 69.08	 21.5	 0.0	 1.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1569	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1570	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1571	 1	 329.4	 12.9	 0.0	 34.36	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1572	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1573	 1	 12.6	 1.8	 0.0	 1.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1574	 1	 34.04	 4.4	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1575	 1	 0.0	 0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	1576	 1	 0.0	 0.0	 0.0	 29.73	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1577	 1	 32.04	 19.8	 0.0	 0.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1578	 1	 0.0	 -0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1579	 1	 -0.0	 0.0	 0.0	 16.56	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1580	 1	 -0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1581	 1	 146.6	 3.3	 0.0	 18.83	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1582	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1583	 1	 -4.14	 -1.83	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1584	 1	 0.0	 -0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1585	 1	 30.53	 10.4	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1586	 1	 -0.0	 -0.0	 0.0	 21.01	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1587	 1	 78.5	 137.8	 0.0	 3.01	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1588	 1	 104.5	 -56.4	 0.0	 23.22	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1589	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1590	 1	 25.73	 9.3	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1591	 1	 -0.16	 -11.88	 0.0	 16.12	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1592	 1	 28.33	 44.8	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1593	 1	 -0.0	 -0.0	 0.0	 3.01	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1594	 1	 0.0	 0.0	 0.0	 288.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1595	 1	 71.77	 13.57	 0.0	 3.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1596	 1	 76.28	 45.7	 0.0	 10.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1597	 1	 51.96	 13.4	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1598	 1	 58.87	 36.4	 0.0	 3.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1599	 1	 0.0	 0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1600	 1	 38.74	 14.1	 0.0	 12.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1601	 1	 63.5	 -381.2	 0.52638	 207.010914	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1602	 1	 45.75	 4.2	 0.0	 4.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1603	 1	 137.2	 16.1	 0.0	 5.26	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1604	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1605	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1606	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	1607	 1	 73.78	 -0.0	 0.0	 2.69	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1608	 1	 25.13	 15.6	 0.0	 4.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1609	 1	 0.0	 0.0	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1610	 1	 164.8	 42.5	 0.0	 32.849681	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1611	 1	 274.1	 166.5	 0.0	 0.56	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1612	 1	 18.5	 2.6	 0.0	 3.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1613	 1	 149.8	 63.1	 0.0	 34.02	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1614	 1	 -0.0	 0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1615	 1	 50.06	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	1616	 1	 0.0	 0.0	 0.0	 14.45	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1617	 1	 14.72	 5.3	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1618	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1619	 1	 20.32	 2.5	 0.0	 5.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1620	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1621	 1	 4.0	 0.6	 0.0	 3.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1622	 1	 -0.22	 -0.4	 0.0	 6.67	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1623	 1	 -0.0	 0.0	 0.0	 7.74	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1624	 1	 164.2	 -10.7	 0.0	 11.44	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1625	 1	 73.18	 22.3	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1626	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1627	 1	 123.5	 -49.4	 0.0	 2.9	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1628	 1	 3.3	 1.1	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1629	 1	 41.95	 8.5	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1630	 1	 0.0	 0.0	 0.0	 20.95	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1631	 1	 -0.0	 -0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1632	 1	 20.82	 7.9	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1633	 1	 -0.0	 -0.0	 0.0	 45.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1634	 1	 5.31	 2.3	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1635	 1	 -0.18	 -1.06	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1636	 1	 -0.0	 -0.0	 0.129305	 29.161483	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1637	 1	 -8.41	 2.7	 0.0	 0.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1638	 1	 70.08	 11.1	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1639	 1	 51.66	 8.0	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1640	 1	 33.6	 4.8	 0.0	 5.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1641	 1	 33.24	 11.5	 0.0	 1.61	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1643	 1	 95.71	 25.9	 0.0	 11.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1644	 1	 -33.1	 -14.35	 0.0	 94.55	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1645	 1	 60.27	 9.4	 0.0	 0.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1646	 1	 15.34	 -1.3	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1647	 1	 13.31	 4.8	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1648	 1	 103.7	 14.9	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	1649	 1	 33.04	 15.7	 0.0	 1.5	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	1650	 1	 -0.0	 0.0	 0.0	 12.5	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1651	 1	 -0.0	 -0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1652	 1	 22.02	 11.9	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	1653	 1	 0.0	 -0.0	 0.207485	 26.23319	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1654	 1	 0.0	 -0.0	 0.0	 45.19	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	1655	 1	 15.22	 7.6	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1656	 1	 -0.0	 -0.0	 0.0	 48.74	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1657	 1	 257.2	 -26.8	 0.0	 5.2	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1658	 1	 25.83	 5.7	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1659	 1	 20.9	 3.0	 0.0	 1.49	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1660	 1	 -13.91	 4.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1661	 1	 22.02	 7.5	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1662	 1	 3.67	 -1.86	 0.0	 3.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1663	 1	 -592.21	 -227.4	 0.497795	 203.015172	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1664	 1	 125.4	 17.8	 0.0	 3.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1665	 1	 20.02	 6.6	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1666	 1	 34.04	 0.0	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1667	 1	 -0.75	 -5.36	 0.0	 10.46	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1668	 1	 -0.0	 0.0	 0.259637	 9.774901	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	1669	 1	 0.0	 0.0	 0.181549	 8.990889	 0	    1.00000	    0.00000	 220.0	 18	    1.30000	    0.70000;
	1670	 1	 46.45	 19.1	 0.0	 6.66	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1671	 1	 3.3	 1.1	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1672	 1	 -28.13	 -0.83	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1673	 1	 4.68	 88.21	 0.0	 6.79	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1674	 1	 16.92	 5.6	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1675	 1	 55.26	 -11.1	 0.0	 1.45	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1676	 1	 -0.0	 0.0	 0.171586	 -1.4632	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1677	 1	 9.21	 3.3	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1678	 1	 -0.0	 0.0	 0.0	 15.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1679	 1	 0.0	 0.0	 0.0	 21.06	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1680	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1681	 1	 7.41	 2.7	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1682	 1	 22.28	 5.67	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1683	 1	 -0.0	 0.0	 0.0	 86.56	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	1684	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1685	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1686	 1	 0.0	 -0.0	 0.37285	 19.231353	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	1687	 1	 0.0	 -0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1688	 1	 72.18	 31.9	 0.0	 27.25	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1689	 1	 -0.0	 -0.0	 0.0	 58.96	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1690	 1	 118.2	 -33.0	 0.0	 12.02	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1691	 1	 36.5	 5.2	 0.0	 1.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1692	 1	 83.19	 25.8	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1693	 1	 28.74	 1.23	 0.0	 2.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1694	 1	 59.9	 8.5	 0.0	 7.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1695	 1	 0.0	 -0.0	 0.090774	 3.510444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	1696	 1	 12.41	 4.4	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	1697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1698	 1	 14.72	 5.3	 0.0	 1.72	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1699	 1	 4.3	 1.8	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1700	 1	 5.01	 2.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	1701	 1	 0.0	 0.0	 0.0	 1.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1702	 1	 47.45	 18.7	 0.0	 1.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1703	 1	 68.28	 39.0	 0.19855	 79.84755	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1704	 1	 62.16	 8.0	 0.0	 2.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1705	 1	 15.22	 2.5	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1706	 1	 -0.0	 -0.0	 0.0	 12.18	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1707	 1	 92.6	 36.3	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1708	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1709	 1	 -15.38	 -4.94	 0.0	 33.241519	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1710	 1	 138.2	 40.3	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	1711	 1	 25.13	 -61.6	 0.0	 3.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1712	 1	 2.5	 0.6	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1713	 1	 4.91	 1.4	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1714	 1	 53.56	 17.2	 0.0	 1.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1715	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	1716	 1	 0.0	 -0.0	 0.0	 16.62	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1717	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1718	 1	 -14.32	 4.7	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1719	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1720	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1722	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1723	 1	 0.0	 -0.0	 0.0	 57.29	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	1724	 1	 8.01	 4.9	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1725	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1726	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	1727	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1728	 1	 34.44	 14.4	 0.0	 48.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1729	 1	 68.38	 42.4	 0.0	 1.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1730	 1	 -17.18	 -4.35	 0.0	 44.419365	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1731	 1	 19.92	 6.6	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1732	 1	 -0.0	 0.0	 0.135375	 28.222175	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	1733	 1	 16.02	 5.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1734	 1	 -0.0	 0.0	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1735	 1	 -0.0	 0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1736	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	1737	 1	 9.71	 3.5	 0.0	 1.44	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1738	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1739	 1	 -0.0	 -0.0	 0.0	 5.09	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1740	 1	 10.11	 2.5	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1741	 1	 162.5	 48.4	 0.0	 5.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1742	 1	 0.0	 0.0	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1743	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1744	 1	 2.0	 0.3	 0.0	 1.02	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1745	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1746	 1	 -0.0	 0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1747	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1748	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1749	 1	 39.24	 24.3	 0.0	 0.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1750	 1	 58.46	 6.6	 0.0	 10.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1751	 1	 11.51	 2.3	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1752	 1	 85.8	 13.4	 0.0	 3.23	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1753	 1	 0.0	 -0.0	 0.12	 1.51	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	1754	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1755	 1	 -9.78	 -3.29	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1756	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	1757	 1	 80.09	 20.0	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1758	 1	 0.0	 -0.0	 0.0	 121.29	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1759	 1	 -0.0	 -0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1760	 1	 328.9	 30.4	 0.0	 66.79	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1761	 1	 11.11	 6.9	 0.0	 1.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1762	 1	 45.75	 20.1	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1763	 1	 -0.0	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1764	 1	 25.43	 14.7	 0.0	 7.79	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	1765	 1	 122.2	 68.9	 0.0	 0.58	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1766	 1	 26.03	 8.7	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1767	 1	 333.5	 -1.4	 0.0	 8.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1768	 1	 73.98	 22.5	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1769	 1	 35.14	 1.8	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1770	 1	 -0.0	 -0.0	 0.0	 2.55	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1771	 1	 22.43	 29.5	 0.0	 0.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1772	 1	 12.6	 1.8	 0.0	 3.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1773	 1	 -0.0	 -0.0	 0.0	 11.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1774	 1	 -32.04	 10.3	 0.0	 82.52	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1775	 1	 -0.0	 0.0	 0.0	 1.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1777	 1	 0.0	 -0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1778	 1	 -0.18	 -3.85	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1779	 1	 5.51	 2.0	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1780	 1	 -1.8	 -4.8	 0.0	 0.44	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1781	 1	 16.52	 5.5	 0.0	 1.59	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1782	 1	 28.63	 10.0	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1783	 1	 -0.0	 -0.8	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1784	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1785	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1786	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1787	 1	 32.94	 10.1	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1788	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1789	 1	 45.75	 27.5	 0.0	 4.37	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1790	 1	 -0.0	 -0.0	 0.0	 2.19	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1791	 1	 -19.32	 6.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1792	 1	 -0.0	 -0.0	 0.0	 6.8	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1793	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1794	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1795	 1	 71.18	 23.8	 0.0	 0.07	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1796	 1	 13.31	 7.9	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1798	 1	 -0.63	 -0.83	 0.0	 22.810288	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1799	 1	 -0.0	 -0.0	 0.0	 1.46	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1800	 1	 8.3	 1.2	 0.0	 4.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1801	 1	 -0.0	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1802	 1	 8.51	 3.2	 0.0	 2.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1803	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1804	 1	 23.02	 10.5	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1805	 1	 112.6	 16.1	 0.0	 3.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1806	 1	 25.43	 8.3	 0.0	 1.35	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1807	 1	 -0.0	 0.0	 0.0	 24.17	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1809	 1	 -0.0	 0.0	 0.0	 239.642195	 0	    1.00000	    0.00000	 750.0	 20	    1.10000	    0.90000;
	1810	 1	 52.46	 11.3	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1811	 1	 99.51	 1.5	 0.0	 32.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1812	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1813	 1	 88.92	 19.79	 0.0	 2.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1815	 1	 63.66	 9.7	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	1816	 1	 335.3	 -101.3	 0.0	 32.69	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	1817	 1	 108.91	 33.7	 0.0	 56.24	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1818	 1	 -29.73	 9.8	 0.0	 2.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1819	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1820	 1	 -0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1821	 1	 14.62	 2.0	 0.0	 10.89	 0	    1.00000	    0.00000	 220.0	 18	    1.30000	    0.70000;
	1822	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1824	 1	 -0.65	 -1.81	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1825	 1	 -0.0	 0.0	 0.0	 0.38	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1826	 1	 56.46	 22.0	 0.0	 41.96	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1827	 1	 114.2	 16.3	 0.0	 57.91	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1828	 1	 2.5	 0.6	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1829	 1	 5.01	 13.0	 0.0	 30.48	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	1830	 1	 17.82	 6.7	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	1831	 1	 0.0	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1832	 1	 34.14	 21.1	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1833	 1	 0.0	 0.0	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1834	 1	 8.21	 2.5	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1835	 1	 44.23	 22.19	 0.0	 4.35	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1836	 1	 62.37	 25.5	 0.0	 3.98	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1837	 1	 113.27	 27.67	 0.0	 3.61	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1838	 1	 0.0	 -0.0	 0.0	 3.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1839	 1	 0.4	 -170.2	 0.0	 3.04	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1840	 1	 -0.0	 0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1841	 1	 56.26	 8.5	 0.0	 5.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1842	 1	 -0.0	 -0.0	 0.0	 25.22	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1843	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1844	 1	 -28.14	 -0.76	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1845	 1	 123.9	 17.6	 0.0	 11.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1846	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1847	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1848	 1	 22.02	 21.8	 0.0	 10.29	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1849	 1	 5.11	 2.4	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1850	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1852	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1853	 1	 25.73	 8.9	 0.0	 1.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1854	 1	 0.2	 0.5	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1855	 1	 0.0	 0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1856	 1	 5.51	 2.0	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1857	 1	 0.0	 0.0	 0.0	 1.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1858	 1	 10.51	 4.7	 0.0	 1.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1859	 1	 369.5	 16.7	 0.0	 10.6	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1860	 1	 88.8	 -3.2	 0.0	 13.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1861	 1	 0.0	 -0.0	 0.0	 19.01	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1862	 1	 177.4	 41.7	 0.0	 2.98	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1863	 1	 -0.0	 0.0	 0.0	 15.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1864	 1	 -19.62	 28.6	 0.0	 1.69	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1865	 1	 55.26	 23.2	 0.0	 8.01	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	1866	 1	 209.2	 23.5	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1867	 1	 0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1868	 1	 11.71	 3.8	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1869	 1	 -2.23	 -1.27	 0.0	 3.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1870	 1	 -0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1871	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1872	 1	 94.3	 13.8	 0.0	 5.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1873	 1	 83.29	 30.1	 0.0	 4.68	 0	    1.00000	    0.00000	 110.0	 19	    1.30000	    0.70000;
	1874	 1	 223.9	 72.6	 0.0	 2.04	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1875	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1876	 1	 -0.0	 -0.0	 0.0	 6.273568	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1877	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1878	 1	 0.0	 0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1879	 1	 -0.0	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1880	 1	 50.26	 16.4	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1881	 1	 -0.0	 -0.0	 0.0	 50.2	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1882	 1	 64.27	 20.1	 0.0	 5.4	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1883	 1	 27.33	 5.0	 0.0	 6.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1884	 1	 264.33	 86.69	 0.0	 91.94	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	1885	 1	 -0.0	 0.0	 0.0	 29.88	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1886	 1	 2.2	 1.1	 0.0	 1.57	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1887	 1	 103.1	 14.7	 0.0	 4.43	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1888	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1889	 1	 57.16	 0.0	 0.0	 6.58	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1890	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1891	 1	 28.63	 17.8	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1892	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1893	 1	 0.0	 0.0	 0.0	 11.82	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1894	 1	 22.22	 5.9	 0.0	 10.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1895	 1	 20.82	 -0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1896	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1897	 1	 53.96	 4.9	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1898	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1899	 1	 0.0	 -0.0	 0.202076	 48.319777	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1900	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1901	 1	 0.2	 1.4	 0.0	 0.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1902	 1	 26.43	 7.7	 0.0	 7.88	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1903	 1	 -0.0	 0.0	 0.0	 3.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1904	 1	 16.02	 5.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1905	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	1906	 1	 25.0	 3.6	 0.0	 2.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1907	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1908	 1	 -11.95	 -3.92	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1909	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1910	 1	 -0.0	 0.0	 0.0	 2.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1911	 1	 39.54	 14.3	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1912	 1	 52.06	 14.3	 0.0	 1.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1913	 1	 91.1	 54.8	 0.0	 30.59	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1915	 1	 33.64	 3.9	 0.0	 3.37	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1916	 1	 10.51	 3.5	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1917	 1	 197.5	 -31.0	 0.0	 17.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1918	 1	 -0.0	 0.0	 0.0	 21.97	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1919	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1920	 1	 0.0	 0.0	 0.0	 94.987645	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	1921	 1	 49.25	 4.9	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1922	 1	 -0.0	 -0.0	 0.126343	 10.705031	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1923	 1	 192.11	 45.5	 0.0	 68.04	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1924	 1	 108.3	 62.0	 0.0	 36.65	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1925	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1926	 1	 14.92	 4.9	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1927	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1928	 1	 0.0	 0.0	 0.0	 2.16	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1929	 1	 45.6	 6.5	 0.0	 95.24	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1930	 1	 14.8	 6.6	 0.0	 84.333648	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	1931	 1	 24.33	 15.0	 0.0	 2.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1932	 1	 51.86	 13.9	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1933	 1	 -0.0	 0.0	 0.0	 45.35	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1934	 1	 -0.0	 -0.0	 0.0	 0.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1935	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1936	 1	 0.0	 0.0	 0.0	 30.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1937	 1	 -0.0	 -0.0	 0.0	 4.76	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1938	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1939	 1	 -11.44	 -3.29	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1940	 1	 0.0	 0.0	 0.0	 1.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1941	 1	 0.0	 -0.0	 0.0	 68.01	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1942	 1	 44.75	 4.1	 0.0	 3.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1943	 1	 4.4	 99.7	 0.0	 40.45	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1944	 1	 -0.0	 -0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1945	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1946	 1	 19.42	 -0.8	 0.0	 0.78	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1947	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1948	 1	 32.2	 4.6	 0.0	 2.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1949	 1	 159.8	 45.0	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1950	 1	 -0.0	 0.0	 0.0	 2.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1951	 1	 -0.0	 -0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1952	 1	 115.1	 10.4	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	1953	 1	 0.0	 -0.0	 0.059832	 20.003574	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1954	 1	 21.62	 13.4	 0.0	 1.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1955	 1	 0.0	 0.0	 0.0	 10.51	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1956	 1	 0.0	 0.0	 0.0	 51.66	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1957	 1	 76.28	 2.9	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1958	 1	 119.9	 17.1	 0.0	 8.99	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1959	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1960	 1	 -0.0	 -0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1961	 1	 3.2	 1.5	 0.0	 1.81	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1962	 1	 0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1963	 1	 29.43	 10.7	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1964	 1	 -0.0	 -0.0	 0.0	 30.05	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	1965	 1	 248.7	 8.1	 0.0	 12.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1966	 1	 -20.6	 -9.4	 0.0	 1.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1967	 1	 46.05	 16.7	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1968	 1	 118.4	 137.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1969	 1	 0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1970	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1971	 1	 89.0	 -1.8	 0.0	 6.15	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1972	 1	 1.8	 4.9	 0.0	 92.20984	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	1973	 1	 210.1	 66.2	 0.0	 59.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1974	 1	 241.9	 38.8	 0.0	 12.46	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1975	 1	 16.7	 2.4	 0.0	 2.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1976	 1	 0.0	 -0.0	 0.0	 12.41	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1977	 1	 -0.0	 0.0	 0.0	 116.64	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1978	 1	 0.0	 -0.0	 0.135493	 29.07062	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	1979	 1	 0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1980	 1	 177.3	 36.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1981	 1	 12.41	 3.9	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1982	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1983	 1	 188.1	 26.8	 0.0	 5.85	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1984	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1985	 1	 147.4	 -55.9	 0.0	 1.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1986	 1	 0.0	 -0.0	 0.0	 1.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1987	 1	 70.18	 44.7	 0.0	 8.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1988	 1	 50.26	 5.5	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1989	 1	 69.78	 20.3	 0.0	 10.26	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1990	 1	 61.87	 -12.4	 0.0	 0.83	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1991	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1992	 1	 0.2	 0.2	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1993	 1	 89.5	 33.9	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1994	 1	 0.0	 0.0	 0.414968	 57.524024	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1995	 1	 -0.0	 -0.0	 0.0	 10.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1996	 1	 15.22	 5.1	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1997	 1	 0.9	 0.5	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1998	 1	 25.73	 7.3	 0.0	 2.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1999	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2000	 1	 54.0	 29.1	 0.0	 204.291522	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	2001	 1	 82.6	 11.7	 0.0	 0.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2002	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2003	 1	 139.1	 60.4	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2004	 1	 -0.0	 0.0	 0.0	 3.72	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2005	 1	 54.66	 -0.0	 0.0	 2.97	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2006	 1	 -40.44	 1.5	 0.0	 14.2	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2007	 1	 82.1	 11.7	 0.0	 3.76	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2008	 1	 11.41	 4.4	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2009	 1	 154.8	 -47.1	 0.0	 4.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2010	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2011	 1	 -0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2012	 1	 41.45	 4.9	 0.0	 18.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2013	 1	 0.0	 -0.0	 0.0	 18.99	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2014	 1	 0.0	 -0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	2015	 1	 25.93	 8.0	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2016	 1	 119.0	 -315.3	 0.0	 41.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2017	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2018	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2019	 1	 72.08	 21.3	 0.0	 7.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2020	 1	 0.0	 0.0	 0.0	 9.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2021	 1	 3.9	 1.0	 0.0	 3.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2022	 1	 8.11	 2.9	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2023	 1	 36.44	 12.0	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2024	 1	 8.91	 1.8	 0.0	 1.78	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2025	 1	 89.1	 2.3	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2026	 1	 16.02	 4.0	 0.0	 5.56	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	2027	 1	 0.0	 -0.0	 0.181549	 5.390889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2028	 1	 110.9	 15.8	 0.0	 30.2	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2029	 1	 90.1	 12.7	 0.0	 10.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2030	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2031	 1	 -0.0	 -0.0	 0.104186	 55.436651	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2032	 1	 56.86	 35.2	 0.0	 2.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2033	 1	 -0.0	 -0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2034	 1	 153.64	 29.2	 0.0	 7.65	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2035	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2036	 1	 6.31	 3.8	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2037	 1	 28.83	 9.6	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2038	 1	 0.0	 0.0	 0.0	 14.4	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2039	 1	 297.7	 258.6	 0.0	 65.78	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2040	 1	 178.4	 69.1	 0.0	 14.2	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2041	 1	 -0.0	 -0.0	 0.273444	 108.530355	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	2042	 1	 14.02	 6.5	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2043	 1	 3.2	 1.7	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2044	 1	 0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2045	 1	 -0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2046	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2047	 1	 -0.65	 -1.44	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2048	 1	 19.22	 6.9	 0.0	 1.16	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2049	 1	 29.3	 4.2	 0.0	 5.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2050	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2051	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	2052	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2053	 1	 -0.0	 0.0	 0.0	 2.99	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2054	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2055	 1	 52.66	 21.5	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2056	 1	 -0.0	 0.0	 0.0	 7.338808	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2057	 1	 120.2	 20.5	 0.0	 19.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2058	 1	 0.0	 0.0	 0.0	 1.31	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2059	 1	 0.0	 0.0	 0.0	 16.08	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	2060	 1	 115.1	 23.5	 0.0	 3.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2061	 1	 -0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2062	 1	 -0.61	 -1.33	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2063	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2064	 1	 14.4	 2.0	 0.0	 4.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2065	 1	 98.6	 14.0	 0.0	 12.86	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2066	 1	 -0.0	 -0.0	 0.0	 5.18	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2067	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2068	 1	 50.16	 18.0	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2069	 1	 1.4	 -2.0	 0.0	 5.05	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2070	 1	 14.0	 2.0	 0.0	 3.32	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2071	 1	 -0.0	 0.0	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2072	 1	 101.2	 2.1	 0.0	 38.43	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2073	 1	 86.9	 30.3	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2074	 1	 -0.0	 -0.0	 0.0	 5.7	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2075	 1	 -0.0	 -0.0	 0.0	 20.79	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2076	 1	 7.0	 1.0	 0.0	 1.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2077	 1	 72.18	 44.9	 0.0	 6.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2078	 1	 77.19	 18.6	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2079	 1	 0.0	 -0.0	 0.0	 13.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2080	 1	 163.7	 94.1	 0.0	 18.55	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2081	 1	 30.93	 2.8	 0.0	 2.11	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2082	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2083	 1	 121.4	 20.2	 0.0	 16.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2084	 1	 -0.0	 -0.0	 0.0	 6.01	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2086	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2087	 1	 23.7	 3.4	 0.0	 4.27	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2088	 1	 -0.0	 0.0	 0.0	 6.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2089	 1	 199.86	 56.93	 0.0	 46.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2090	 1	 11.2	 1.6	 0.0	 4.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2092	 1	 110.09	 53.32	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2093	 1	 -5.64	 -2.84	 0.0	 34.582195	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2094	 1	 65.87	 31.4	 0.0	 3.46	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2095	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2097	 1	 54.26	 19.5	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2098	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2099	 1	 -3.7	 -8.0	 0.0	 19.02	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	2100	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2101	 1	 -0.0	 -0.0	 0.0	 38.32	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2102	 1	 -0.0	 0.0	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2103	 1	 0.0	 0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2104	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2105	 1	 0.0	 -0.0	 0.0	 6.22	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2106	 1	 -0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2108	 1	 0.0	 0.0	 0.090774	 10.830444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2109	 1	 529.9	 23.3	 0.0	 57.66	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2110	 1	 -0.0	 -0.0	 0.136871	 2.413044	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	2111	 1	 12.81	 4.4	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2112	 1	 152.5	 -0.1	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2113	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	2114	 1	 5.71	 2.0	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2115	 1	 11.0	 3.15	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2116	 1	 53.36	 7.1	 0.0	 6.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2117	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2118	 1	 -0.0	 0.0	 0.0	 3.61	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2119	 1	 4.0	 0.6	 0.0	 3.46	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2120	 1	 -0.19	 -3.76	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2121	 1	 133.2	 24.8	 0.0	 74.43	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2122	 1	 0.0	 0.0	 0.0	 2.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2123	 1	 19.82	 6.0	 0.0	 1.68	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2124	 1	 8.07	 1.23	 0.0	 3.91	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2125	 1	 0.0	 0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2126	 1	 92.3	 14.6	 0.0	 1.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2127	 1	 30.33	 11.0	 0.0	 2.29	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2128	 1	 79.09	 18.7	 0.0	 10.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2129	 1	 0.0	 0.0	 0.0	 56.686515	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2130	 1	 34.34	 12.5	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2131	 1	 16.22	 4.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2132	 1	 107.3	 14.2	 0.0	 20.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2133	 1	 -0.0	 0.0	 0.0	 11.63	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2134	 1	 -0.0	 -0.0	 0.0	 25.72	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2135	 1	 78.69	 56.7	 0.0	 10.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2136	 1	 23.2	 3.3	 0.0	 3.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2137	 1	 141.5	 20.1	 0.0	 5.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2138	 1	 137.8	 64.5	 0.0	 18.2	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2139	 1	 0.0	 0.0	 0.0	 9.51	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2140	 1	 0.0	 0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2141	 1	 29.4	 4.2	 0.0	 5.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2142	 1	 0.0	 -0.0	 0.0	 7.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2143	 1	 129.5	 38.3	 0.0	 5.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2144	 1	 -0.0	 0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	2145	 1	 130.9	 37.8	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2146	 1	 10.81	 1.3	 0.0	 2.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2147	 1	 6.11	 -0.0	 0.0	 0.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2148	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2149	 1	 17.62	 5.8	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2151	 1	 -0.0	 0.0	 0.0	 116.62	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2152	 1	 -0.0	 0.0	 0.181549	 4.450889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2153	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2154	 1	 0.0	 0.0	 0.29	 13.47	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2155	 1	 63.67	 20.2	 0.0	 6.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2156	 1	 6.01	 2.2	 0.0	 1.91	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2157	 1	 0.0	 -0.0	 0.0	 3.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2158	 1	 -0.0	 -0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2159	 1	 51.96	 32.2	 0.0	 0.84	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	2160	 1	 304.2	 114.1	 0.0	 26.84	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2161	 1	 35.66	 -9.39	 0.0	 7.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2162	 1	 12.21	 4.4	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2164	 1	 15.82	 9.8	 0.0	 4.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2165	 1	 0.0	 -0.0	 0.0	 10.34	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2166	 1	 20.92	 7.7	 0.0	 1.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2167	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2168	 1	 8.6	 -1.48	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2169	 1	 -0.0	 -0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2170	 1	 0.0	 -0.0	 0.090774	 6.319044	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2171	 1	 37.6	 5.4	 0.0	 2.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2172	 1	 114.2	 34.4	 0.0	 10.29	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2173	 1	 396.7	 62.8	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 20	    1.10000	    0.90000;
	2174	 1	 0.0	 0.0	 0.0	 61.795782	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2175	 1	 0.0	 0.0	 0.153288	 -0.361586	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2176	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2177	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2178	 1	 40.65	 13.2	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2179	 1	 0.0	 0.0	 0.0	 0.78	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2180	 1	 0.0	 -0.0	 0.0	 2.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2181	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2182	 1	 25.0	 3.6	 0.0	 13.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2183	 1	 0.0	 0.0	 0.0	 32.849821	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2184	 1	 0.0	 -0.0	 0.0	 1.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2185	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2186	 1	 16.7	 2.4	 0.0	 15.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2187	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2188	 1	 25.23	 11.9	 0.0	 18.72	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2189	 1	 -0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2190	 1	 -14.27	 -6.6	 0.0	 0.91	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2191	 1	 0.0	 0.0	 0.0	 9.9	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2192	 1	 -19.79	 -21.11	 0.159201	 65.262484	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2193	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2194	 1	 0.0	 0.0	 0.0	 23.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2195	 1	 55.46	 18.5	 0.0	 2.23	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2196	 1	 -0.0	 0.0	 0.0	 5.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2197	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2198	 1	 34.14	 11.4	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2199	 1	 297.2	 93.2	 0.0	 23.74	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2200	 1	 137.3	 -2.8	 0.0	 16.39	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2201	 1	 29.03	 9.6	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2202	 1	 213.0	 39.6	 0.0	 20.63	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2203	 1	 0.0	 -0.0	 0.316851	 27.238806	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	2204	 1	 -0.0	 0.0	 0.0	 -0.46	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2205	 1	 11.01	 3.6	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2206	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2207	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2208	 1	 74.98	 26.9	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2209	 1	 6.01	 4.1	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2210	 1	 -0.0	 -7.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2211	 1	 44.55	 16.1	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2212	 1	 60.07	 45.0	 0.0	 2.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2213	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2214	 1	 54.32	 7.98	 0.0	 13.58	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2215	 1	 23.7	 3.4	 0.0	 2.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2216	 1	 -0.0	 -0.0	 0.0	 47.421898	 0	    1.00000	    0.00000	 380.0	 13	    1.30000	    0.70000;
	2217	 1	 0.0	 0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2218	 1	 -0.0	 0.0	 0.0	 1.6	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2219	 1	 20.32	 6.7	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2220	 1	 0.0	 -0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2221	 1	 14.26	 -1.13	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2222	 1	 0.0	 0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2223	 1	 142.8	 19.5	 0.0	 10.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2224	 1	 78.79	 27.4	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2226	 1	 145.7	 83.6	 0.135375	 53.822175	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	2227	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2228	 1	 143.1	 18.9	 0.0	 3.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2229	 1	 0.0	 -0.0	 0.0	 2.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2230	 1	 0.0	 -0.0	 0.0	 1.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2231	 1	 0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2232	 1	 19.52	 11.0	 0.0	 1.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2233	 1	 269.9	 12.4	 0.0	 4.09	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2234	 1	 63.67	 39.5	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2235	 1	 193.1	 69.9	 0.0	 28.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2236	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2238	 1	 0.0	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2239	 1	 -3.51	 -0.52	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2240	 1	 66.87	 21.8	 0.0	 12.3	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2241	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2242	 1	 -0.0	 -0.0	 0.0	 2.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2243	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2244	 1	 0.0	 -0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2245	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2246	 1	 7.61	 2.5	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2247	 1	 47.46	 11.54	 0.0	 14.15	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2248	 1	 110.3	 28.7	 0.0	 0.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2249	 1	 1.8	 0.7	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2250	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2251	 1	 25.33	 12.7	 0.181549	 6.830889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2252	 1	 100.7	 -4.2	 0.0	 1.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2253	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	2254	 1	 0.0	 -8.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2255	 1	 76.6	 10.9	 0.0	 12.63	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2256	 1	 23.03	 8.3	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2257	 1	 97.0	 18.7	 0.0	 21.46	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2258	 1	 -14.83	 -3.56	 0.0	 0.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2259	 1	 5.71	 1.6	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2260	 1	 305.6	 207.3	 0.0	 52.37	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2261	 1	 0.0	 -0.0	 0.0	 20.5	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2262	 1	 -0.0	 -0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2263	 1	 1.9	 0.7	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2264	 1	 117.6	 16.7	 0.0	 10.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2265	 1	 27.9	 4.0	 0.0	 2.16	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2266	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2268	 1	 0.0	 -0.0	 0.183167	 22.675025	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2269	 1	 -0.0	 0.0	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2270	 1	 0.0	 0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2271	 1	 0.0	 -0.01	 0.0	 5.48	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2272	 1	 0.0	 0.0	 0.0	 26.22	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2273	 1	 141.3	 32.4	 0.0	 7.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2274	 1	 268.56	 29.72	 0.0	 6.5	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2275	 1	 91.9	 5.5	 0.0	 7.02	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2276	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2277	 1	 -0.0	 0.0	 0.0	 15.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2279	 1	 73.18	 22.2	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2280	 1	 11.61	 5.8	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2281	 1	 30.6	 4.3	 0.0	 7.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2282	 1	 0.0	 0.0	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2283	 1	 1.4	 0.5	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2284	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2285	 1	 -0.0	 0.0	 0.0	 3.82	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2286	 1	 208.88	 60.8	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2287	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2288	 1	 170.9	 39.0	 0.0	 11.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2289	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2290	 1	 -0.0	 -0.0	 0.0	 15.02	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2292	 1	 13.04	 7.4	 0.0	 5.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2293	 1	 -0.0	 0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2294	 1	 71.88	 51.3	 0.0	 24.75	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	2295	 1	 15.02	 5.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2296	 1	 30.83	 4.4	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2297	 1	 93.2	 13.6	 0.0	 14.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2298	 1	 162.7	 23.2	 0.0	 1.7	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2299	 1	 402.1	 110.2	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2300	 1	 -0.0	 0.0	 0.0	 13.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2301	 1	 82.39	 12.3	 0.0	 9.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2302	 1	 628.5	 91.8	 0.0	 19.83	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2303	 1	 0.0	 -0.0	 0.0	 7.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2304	 1	 88.7	 -0.1	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2305	 1	 21.22	 8.3	 0.0	 19.1	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2306	 1	 -27.25	 -9.38	 0.0	 18.78	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2307	 1	 45.75	 3.3	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	2308	 1	 32.04	 6.6	 0.0	 0.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2309	 1	 -1.8	 -12.01	 0.294347	 159.376332	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2310	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	2311	 1	 8.41	 3.0	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2312	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2313	 1	 0.0	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2314	 1	 110.6	 20.4	 0.0	 26.9	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2315	 1	 13.9	 1.9	 0.0	 0.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2316	 1	 264.0	 40.1	 0.0	 9.489841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2317	 1	 0.0	 0.0	 0.0	 20.53	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2318	 1	 12.51	 3.3	 0.0	 1.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2319	 1	 39.64	 20.9	 0.0	 0.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2320	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2321	 1	 8.41	 2.8	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2322	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2323	 1	 -0.0	 0.0	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2324	 1	 0.0	 -0.0	 0.0	 4.16	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2325	 1	 0.0	 -0.0	 0.0	 101.48	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2326	 1	 24.23	 6.6	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2327	 1	 114.5	 25.2	 0.0	 17.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2328	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2329	 1	 0.0	 -0.0	 0.0	 28.53	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2330	 1	 -0.2	 -1.33	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2331	 1	 -0.15	 -1.4	 0.0	 0.01	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2332	 1	 -0.0	 -0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2333	 1	 27.93	 6.4	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2334	 1	 0.0	 0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2335	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2336	 1	 90.5	 12.8	 0.0	 0.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2337	 1	 103.4	 27.0	 0.0	 1.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2338	 1	 12.71	 4.9	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2339	 1	 24.33	 15.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2340	 1	 96.91	 13.9	 0.0	 3.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2341	 1	 -0.0	 0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2342	 1	 -0.0	 -0.0	 0.0	 12.77	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2343	 1	 33.04	 5.6	 0.0	 14.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2344	 1	 -0.0	 0.0	 0.0	 426.57	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2345	 1	 -0.0	 0.0	 0.0	 2.92	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	2346	 1	 53.3	 7.6	 0.0	 10.7	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2347	 1	 0.0	 0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2348	 1	 33.24	 11.1	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2349	 1	 0.0	 -0.0	 0.12	 1.55	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	2350	 1	 -0.0	 0.0	 0.0	 7.03	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2352	 1	 4.91	 1.4	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2353	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2354	 1	 75.78	 46.9	 0.0	 3.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2355	 1	 54.46	 11.9	 0.0	 3.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2356	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2357	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2358	 1	 52.96	 8.2	 0.0	 5.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2359	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2360	 1	 215.5	 31.3	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2361	 1	 16.9	 3.85	 0.0	 25.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2362	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2363	 1	 0.0	 -0.0	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2364	 1	 0.0	 0.0	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2365	 1	 37.94	 15.4	 0.0	 117.386167	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2366	 1	 -0.0	 0.0	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2367	 1	 -15.92	 5.2	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2368	 1	 178.5	 65.8	 0.0	 93.42	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	2369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	2370	 1	 -0.0	 -0.0	 0.0	 2.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2371	 1	 -0.0	 0.0	 0.0	 28.65	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2372	 1	 0.0	 -0.0	 0.0	 14.490904	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2373	 1	 153.3	 21.8	 0.0	 10.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2374	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2375	 1	 131.1	 18.7	 0.0	 6.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2376	 1	 17.12	 3.8	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2377	 1	 101.7	 17.6	 0.0	 13.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2378	 1	 -41.25	 13.5	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2379	 1	 -5.51	 1.8	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2380	 1	 -0.0	 -0.0	 0.0	 5.43	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2381	 1	 32.94	 13.0	 0.0	 4.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2382	 1	 0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2383	 1	 52.26	 44.2	 0.181549	 9.190889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2384	 1	 0.0	 0.0	 0.0	 9.85	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2385	 1	 122.1	 16.7	 0.0	 27.05	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2386	 1	 24.13	 8.7	 0.083411	 0.134843	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	2387	 1	 0.1	 1.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2388	 1	 57.56	 24.0	 0.0	 1.01	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2389	 1	 -0.0	 0.0	 0.0	 4.02	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	2390	 1	 -0.0	 0.0	 0.0	 0.79	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2391	 1	 20.12	 12.5	 0.0	 2.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2392	 1	 173.7	 23.0	 0.0	 18.4	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2393	 1	 20.82	 0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2394	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2395	 1	 80.29	 28.4	 0.0	 8.67	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	2396	 1	 72.4	 10.3	 0.0	 8.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2397	 1	 -0.0	 -0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2398	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	2399	 1	 69.38	 43.0	 0.0	 3.22	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2400	 1	 0.0	 -0.0	 0.0	 3.99	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2401	 1	 -0.0	 -0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2402	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	2403	 1	 37.24	 5.3	 0.0	 14.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2404	 1	 0.0	 -0.0	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2405	 1	 9.7	 1.4	 0.0	 5.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2406	 1	 0.0	 0.0	 0.0	 1.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2407	 1	 117.13	 52.4	 0.0	 7.51	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2408	 1	 30.6	 4.3	 0.0	 2.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2409	 1	 64.8	 99.1	 0.0	 4.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2410	 1	 3.9	 -35.8	 0.0	 4.71	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2411	 1	 0.0	 -0.0	 0.0	 9.14	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2412	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2413	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2414	 1	 30.6	 4.3	 0.0	 7.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2415	 1	 5.51	 2.0	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2416	 1	 14.32	 5.6	 0.0	 88.82	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2417	 1	 -0.54	 -1.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2418	 1	 15.9	 116.3	 0.0	 5.1	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2419	 1	 -0.0	 -0.0	 0.258771	 12.056323	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	2420	 1	 3.4	 123.8	 0.0	 64.94	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2421	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2422	 1	 39.34	 24.3	 0.0	 3.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2423	 1	 523.3	 137.2	 0.0	 65.61	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2424	 1	 44.55	 16.8	 0.0	 2.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2425	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2426	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2427	 1	 0.0	 -0.0	 0.27075	 102.13435	 0	    1.00000	    0.00000	 380.0	 18	    1.30000	    0.70000;
	2428	 1	 -0.0	 -0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2429	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2430	 1	 -0.0	 0.0	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2431	 1	 9.61	 1.8	 0.0	 2.84	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2432	 1	 291.2	 35.4	 0.0	 21.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2433	 1	 0.0	 -0.0	 0.0	 2.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2434	 1	 0.0	 0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2435	 1	 -0.0	 -0.0	 0.0	 16.92	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	2436	 1	 0.0	 0.0	 0.0	 91.66	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2437	 1	 -0.0	 -8.6	 0.0	 297.94	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2438	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2439	 1	 -0.0	 -0.0	 0.0	 8.66	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2440	 1	 0.0	 -0.0	 0.0	 10.21	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2441	 1	 0.0	 -0.0	 0.242534	 1.143584	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2442	 1	 2.43	 0.49	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2443	 1	 45.6	 142.0	 0.0	 3.17	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2444	 1	 0.0	 -0.0	 0.0	 18.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2445	 1	 -0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2446	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2447	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2448	 1	 34.24	 16.5	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	2449	 1	 301.9	 -103.2	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2450	 1	 20.3	 3.7	 0.0	 0.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2451	 1	 -0.0	 -0.0	 0.0	 3.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2452	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2453	 1	 98.36	 -0.47	 0.0	 5.44	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2454	 1	 -0.0	 -0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2455	 1	 0.0	 0.0	 0.0	 63.59	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2456	 1	 262.5	 18.9	 0.0	 39.85	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2457	 1	 30.73	 9.6	 0.0	 2.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2458	 1	 132.0	 26.0	 0.0	 27.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2459	 1	 -0.0	 0.0	 0.0	 145.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2460	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2461	 1	 3.3	 1.9	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2462	 1	 -5.22	 -3.77	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2463	 1	 0.0	 -0.0	 0.0	 32.55	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2464	 1	 1.5	 0.4	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2465	 1	 314.65	 87.51	 0.0	 42.61	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2466	 1	 0.0	 0.5	 0.0	 1.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2467	 1	 0.0	 -0.0	 0.0	 11.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2468	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2469	 1	 -0.0	 0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2470	 1	 0.0	 -0.0	 0.0	 1.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2471	 1	 103.5	 21.7	 0.0	 8.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2472	 1	 76.58	 14.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2473	 1	 40.44	 12.8	 0.0	 1.04	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2474	 1	 35.04	 16.0	 0.0	 12.14	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	2475	 1	 0.0	 0.0	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2476	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2477	 1	 4.2	 0.6	 0.0	 4.73	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2478	 1	 50.96	 6.8	 0.0	 9.13	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2479	 1	 -2.65	 -1.17	 0.0	 65.673108	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2480	 1	 -0.0	 -0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	2481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2482	 1	 -0.21	 -1.98	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2483	 1	 26.6	 3.8	 0.0	 6.43	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2484	 1	 -0.0	 0.0	 0.0	 2.43	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2485	 1	 33.5	 4.8	 0.0	 1.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2486	 1	 79.09	 -36.9	 0.0	 4.58	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2487	 1	 0.0	 -0.0	 0.0	 13.39	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2488	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2489	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2490	 1	 42.2	 6.0	 0.0	 5.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2491	 1	 48.8	 6.9	 0.0	 3.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2492	 1	 0.0	 0.0	 0.0	 7.67	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	2493	 1	 74.18	 22.6	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2494	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2495	 1	 0.0	 0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2496	 1	 50.56	 4.6	 0.0	 1.74	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2497	 1	 0.0	 0.0	 0.0	 9.36	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2498	 1	 87.7	 22.2	 0.0	 7.35	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2499	 1	 -0.0	 0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2500	 1	 0.0	 -0.0	 0.0	 4.8	 0	    1.00000	    0.00000	 380.0	 23	    1.30000	    0.70000;
	2501	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2502	 1	 0.0	 -0.0	 0.0	 84.7	 0	    1.00000	    0.00000	 380.0	 22	    1.10000	    0.90000;
	2503	 1	 -0.0	 0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2504	 1	 119.2	 32.1	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2505	 1	 48.75	 16.2	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2506	 1	 -14.9	 -4.81	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2507	 1	 -0.0	 0.0	 0.0	 36.17	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2508	 1	 41.8	 5.9	 0.0	 4.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2509	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2510	 1	 115.87	 29.41	 0.0	 7.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2511	 1	 174.1	 -519.7	 0.0	 54.02	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2512	 1	 0.0	 0.0	 0.0	 18.83	 0	    1.00000	    0.00000	 380.0	 12	    1.10000	    0.90000;
	2513	 1	 0.0	 -0.0	 0.0	 29.79	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2514	 1	 18.2	 2.6	 0.0	 1.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2515	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2516	 1	 -0.0	 -0.0	 0.0	 6.66	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2517	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2518	 1	 -5.29	 -1.91	 0.0	 42.622979	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2519	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2520	 1	 -0.0	 -0.0	 0.057433	 3.80797	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2521	 1	 90.5	 12.9	 0.0	 2.99	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2522	 1	 59.7	 26.3	 0.0	 37.680934	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	2523	 1	 0.0	 0.0	 0.0	 7.06	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	2524	 1	 11.2	 1.6	 0.0	 3.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2525	 1	 18.32	 14.1	 0.0	 3.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2526	 1	 238.45	 46.86	 0.0	 125.534496	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2527	 1	 59.77	 16.7	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2528	 1	 -10.41	 -3.3	 0.0	 4.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2529	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2530	 1	 77.39	 20.7	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	2531	 1	 1.3	 -0.0	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2532	 1	 -0.0	 -0.0	 0.08367	 4.954954	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2533	 1	 56.7	 8.0	 0.0	 4.42	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2534	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2535	 1	 51.56	 2.1	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2536	 1	 15.12	 9.4	 0.0	 0.69	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2537	 1	 70.28	 16.2	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2538	 1	 118.8	 39.5	 0.0	 2.61	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2539	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2540	 1	 278.35	 90.4	 0.0	 12.1	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2541	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2542	 1	 72.68	 45.0	 0.0	 8.25	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2543	 1	 38.44	 13.2	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2544	 1	 27.33	 5.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2545	 1	 0.0	 0.0	 0.0	 10.78	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2546	 1	 -0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	2547	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2548	 1	 -4.88	 5.5	 0.0	 1.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2549	 1	 0.0	 -0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2550	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2551	 1	 205.3	 27.8	 0.0	 8.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2552	 1	 28.53	 11.3	 0.0	 6.81	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2553	 1	 25.77	 -36.0	 0.0	 9.85	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2554	 1	 32.54	 10.6	 0.0	 1.22	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2555	 1	 -0.15	 -1.0	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2556	 1	 0.0	 0.0	 0.0	 2.75	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2557	 1	 -0.0	 -0.2	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2558	 1	 159.27	 38.31	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2559	 1	 17.02	 5.9	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2560	 1	 6.51	 1.4	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2561	 1	 1.8	 0.7	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2562	 1	 -88.6	 -24.2	 0.0	 5.66	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2563	 1	 52.86	 13.0	 0.0	 6.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2564	 1	 0.0	 0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2565	 1	 -0.0	 -0.0	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2566	 1	 0.0	 -0.0	 0.0	 68.93	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2567	 1	 25.43	 7.1	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2568	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2569	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2570	 1	 -28.96	 -8.62	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2571	 1	 -0.0	 -0.0	 0.0	 1.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2572	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2573	 1	 152.18	 23.99	 0.0	 14.75	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2574	 1	 100.1	 44.5	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2575	 1	 62.97	 17.4	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2576	 1	 27.05	 22.7	 0.0	 14.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2577	 1	 0.0	 0.0	 0.0	 87.06	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2578	 1	 -0.0	 0.0	 0.0	 -0.3	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2579	 1	 -0.0	 -0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2580	 1	 0.0	 -0.0	 0.0	 1.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2581	 1	 -15.72	 5.2	 0.0	 1.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2582	 1	 2.3	 0.8	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2583	 1	 174.6	 48.9	 0.0	 7.46	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2584	 1	 13.9	 1.9	 0.0	 6.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2585	 1	 -0.0	 0.0	 0.1083	 35.537525	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	2586	 1	 0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2587	 1	 39.04	 24.2	 0.0	 13.22	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2588	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	2589	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2590	 1	 0.0	 0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	2591	 1	 253.77	 84.6	 0.0	 20.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2592	 1	 28.13	 14.2	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2593	 1	 -9.51	 3.1	 0.0	 0.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2594	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2595	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2596	 1	 0.0	 -0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2597	 1	 14.72	 5.4	 0.0	 0.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2598	 1	 25.63	 12.7	 0.0	 8.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2599	 1	 48.8	 6.9	 0.0	 9.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2600	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2601	 1	 -0.0	 0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2602	 1	 -23.13	 -8.4	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2603	 1	 -0.0	 0.0	 0.0	 5.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2604	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2605	 1	 115.3	 -8.8	 0.0	 16.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2606	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2607	 1	 -0.0	 0.0	 0.0	 11.54	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2608	 1	 226.8	 53.2	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2609	 1	 14.92	 4.4	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2610	 1	 499.8	 110.3	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2611	 1	 0.0	 -0.0	 0.0	 9.49	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2612	 1	 -0.0	 0.0	 0.0	 29.89	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2613	 1	 0.0	 -0.0	 0.0	 31.53	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	2614	 1	 0.0	 0.0	 0.0	 7.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2615	 1	 -0.0	 0.0	 0.0	 23.88	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2616	 1	 -0.0	 0.0	 0.0	 1.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2617	 1	 14.74	 14.7	 0.0	 7.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2618	 1	 69.7	 9.9	 0.0	 2.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2619	 1	 0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2620	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	2621	 1	 112.1	 16.0	 0.0	 0.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2622	 1	 -0.0	 0.0	 0.0	 6.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2623	 1	 64.4	 9.1	 0.0	 1.61	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2624	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2625	 1	 10.61	 3.5	 0.0	 1.61	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2626	 1	 5.51	 2.0	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2628	 1	 0.0	 -0.0	 0.0	 1.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2629	 1	 203.1	 65.2	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2630	 1	 166.7	 87.6	 0.0	 60.34	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2631	 1	 29.93	 -4.2	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2632	 1	 655.8	 72.8	 0.0	 10.76	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2633	 1	 3.7	 1.3	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2634	 1	 0.0	 -0.0	 0.0	 44.86	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2635	 1	 42.95	 26.6	 0.0	 3.89	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	2636	 1	 98.3	 25.9	 0.0	 3.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2637	 1	 33.04	 12.1	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2638	 1	 21.72	 7.2	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2639	 1	 45.05	 -4.5	 0.0	 1.57	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	2640	 1	 37.6	 5.4	 0.0	 4.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2641	 1	 0.0	 0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2643	 1	 2.0	 0.5	 0.0	 1.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2644	 1	 0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2645	 1	 -0.0	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2646	 1	 123.1	 3.9	 0.0	 59.08	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	2647	 1	 70.18	 30.5	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2648	 1	 46.65	 15.1	 0.0	 9.79	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2649	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 22	    1.10000	    0.90000;
	2650	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2651	 1	 0.0	 0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2652	 1	 93.1	 43.7	 0.0	 11.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2653	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2654	 1	 207.1	 50.4	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2655	 1	 -0.0	 -0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2656	 1	 -0.72	 0.0	 0.0	 69.582294	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2657	 1	 0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2659	 1	 -0.0	 -0.0	 0.0	 64.39	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2660	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2661	 1	 45.45	 28.1	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2662	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2663	 1	 150.0	 104.3	 0.0	 9.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2664	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2665	 1	 -0.0	 0.0	 0.0	 2.73	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2666	 1	 30.6	 4.3	 0.0	 8.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2667	 1	 70.68	 10.7	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2668	 1	 252.9	 95.6	 0.0	 1.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2669	 1	 223.5	 48.0	 0.0	 12.74	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2670	 1	 20.92	 1.1	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2671	 1	 16.82	 5.5	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2672	 1	 7.41	 1.8	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2673	 1	 13.21	 4.4	 0.0	 1.17	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2674	 1	 0.0	 -0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2675	 1	 0.0	 -0.0	 0.0	 11.28	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2676	 1	 123.24	 23.65	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2677	 1	 -0.0	 0.0	 0.252685	 32.19909	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	2678	 1	 10.61	 3.8	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2679	 1	 27.93	 10.1	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2680	 1	 -0.0	 0.0	 0.0	 100.092366	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2681	 1	 0.0	 0.0	 0.0	 29.87	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2682	 1	 -0.0	 -0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	2683	 1	 -0.0	 -0.0	 0.0	 23.22	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2684	 1	 394.9	 45.9	 0.0	 19.569841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2685	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2686	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2687	 1	 2.0	 1.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2688	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2689	 1	 0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2690	 1	 -0.0	 0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2691	 1	 -5.89	 -3.59	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2692	 1	 285.2	 65.3	 0.0	 11.28	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2693	 1	 149.6	 21.3	 0.0	 2.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2694	 1	 681.5	 57.7	 0.0	 66.36	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2695	 1	 16.22	 8.9	 0.0	 2.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2696	 1	 0.0	 0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2697	 1	 -0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2698	 1	 0.0	 -1.2	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2699	 1	 23.13	 8.8	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2700	 1	 -0.0	 0.0	 0.0	 3.08	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2701	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2702	 1	 151.7	 27.6	 0.0	 6.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2703	 1	 -0.2	 -4.97	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2704	 1	 56.26	 18.5	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2705	 1	 117.4	 12.1	 0.0	 1.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2706	 1	 118.0	 37.8	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2707	 1	 0.0	 0.0	 0.099501	 119.783595	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	2708	 1	 47.75	 18.8	 0.0	 4.42	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2709	 1	 189.7	 52.0	 0.0	 30.21	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2710	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2711	 1	 106.6	 15.2	 0.0	 0.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2712	 1	 104.8	 22.0	 0.0	 6.99	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2713	 1	 11.01	 4.0	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2714	 1	 -0.0	 8.4	 0.0	 12.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2715	 1	 90.5	 27.8	 0.0	 7.85	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2716	 1	 -0.0	 0.0	 0.349307	 35.121782	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	2717	 1	 32.04	 11.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2718	 1	 48.8	 6.9	 0.0	 5.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2719	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2720	 1	 13.01	 14.2	 0.0	 15.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2721	 1	 -0.0	 0.0	 0.0	 10.040547	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2722	 1	 0.0	 0.0	 0.0	 56.39	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2723	 1	 3.8	 0.6	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2724	 1	 151.2	 81.3	 0.0	 50.19	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2725	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2726	 1	 0.0	 0.0	 0.0	 4.68	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2727	 1	 32.54	 11.7	 0.0	 1.02	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2728	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	2729	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2730	 1	 0.1	 152.7	 0.0	 233.41	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2731	 1	 44.05	 14.6	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2732	 1	 85.59	 20.72	 0.0	 142.79	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2733	 1	 36.19	 10.75	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2734	 1	 -61.67	 -0.9	 0.0	 12.33	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2735	 1	 29.5	 4.3	 0.0	 21.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2736	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2737	 1	 -0.0	 -0.0	 0.12635	 9.466325	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	2738	 1	 0.0	 0.0	 0.0	 4.52	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	2739	 1	 -0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2740	 1	 36.24	 5.7	 0.0	 15.06	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2741	 1	 148.5	 21.2	 0.0	 1.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2742	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2743	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2744	 1	 -9.82	 -3.4	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2745	 1	 0.0	 -0.0	 0.0	 56.27	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2746	 1	 27.9	 4.0	 0.0	 2.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2747	 1	 -11.77	 -3.81	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2748	 1	 65.47	 26.7	 0.0	 18.6	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2749	 1	 55.56	 26.5	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2750	 1	 118.4	 16.9	 0.0	 41.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2751	 1	 34.54	 8.6	 0.0	 5.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2752	 1	 12.21	 1.0	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2753	 1	 -0.63	 -1.17	 0.0	 1.92	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2754	 1	 -0.0	 0.0	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2755	 1	 0.0	 -0.0	 0.0	 3.22	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2756	 1	 159.3	 13.5	 0.0	 62.36	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2757	 1	 -0.0	 -0.0	 0.0	 1.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2758	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	2759	 1	 90.4	 13.8	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2760	 1	 64.87	 25.6	 0.0	 14.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2761	 1	 8.51	 2.8	 0.0	 1.35	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2762	 1	 59.9	 8.5	 0.0	 1.27	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2763	 1	 16.52	 6.0	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2765	 1	 40.5	 5.7	 0.0	 4.13	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2766	 1	 0.0	 -0.0	 0.0	 12.96	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2767	 1	 0.0	 0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2768	 1	 34.9	 5.0	 0.0	 2.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2769	 1	 98.6	 28.3	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	2770	 1	 85.39	 14.3	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2771	 1	 57.21	 -7.12	 0.0	 6.86	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2772	 1	 103.1	 3.1	 0.0	 61.7	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	2773	 1	 4.7	 1.8	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2774	 1	 1.5	 0.3	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2775	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2776	 1	 16.76	 -0.51	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2777	 1	 26.63	 7.6	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2778	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2779	 1	 35.34	 21.9	 0.0	 3.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2780	 1	 2.9	 0.8	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2781	 1	 -9.41	 3.1	 0.0	 0.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2782	 1	 -28.13	 -0.81	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2783	 1	 0.0	 -0.0	 0.0	 4.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2784	 1	 0.3	 1.3	 0.0	 0.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2785	 1	 189.4	 25.8	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2786	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	2787	 1	 0.0	 -0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2788	 1	 129.5	 26.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2789	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2790	 1	 -0.0	 -0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2791	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2792	 1	 3.0	 0.1	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2793	 1	 16.7	 2.4	 0.0	 2.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2794	 1	 0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2795	 1	 -0.0	 -0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2796	 1	 100.7	 17.5	 0.0	 6.54	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2798	 1	 8.91	 2.7	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2799	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2800	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2801	 1	 0.0	 -0.0	 0.0	 12.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2802	 1	 24.63	 8.1	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2803	 1	 69.08	 68.0	 0.0	 2.93	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2804	 1	 31.33	 9.6	 0.0	 1.86	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2805	 1	 390.8	 79.5	 0.0	 20.79	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2806	 1	 -0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2807	 1	 327.4	 125.3	 0.0	 34.36	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	2808	 1	 72.0	 10.3	 0.0	 5.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2809	 1	 27.53	 11.0	 0.0	 2.49	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2810	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2811	 1	 6.91	 2.3	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2812	 1	 97.0	 18.6	 0.0	 1.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2813	 1	 32.94	 11.8	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2814	 1	 0.0	 0.0	 0.0	 52.89	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	2815	 1	 25.33	 14.2	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2817	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2818	 1	 76.6	 10.9	 0.0	 2.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2819	 1	 22.02	 2.2	 0.0	 2.4	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2820	 1	 0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2821	 1	 81.19	 31.4	 0.0	 2.04	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2822	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2823	 1	 19.32	 6.4	 0.0	 3.74	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2824	 1	 -0.0	 -0.0	 0.0	 4.17	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	2825	 1	 0.0	 -0.0	 0.0	 31.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2826	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2827	 1	 8.91	 4.9	 0.0	 4.58	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2828	 1	 166.7	 87.6	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2829	 1	 69.28	 23.8	 0.0	 2.56	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2830	 1	 46.55	 9.1	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2831	 1	 7.41	 2.7	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2832	 1	 48.15	 14.8	 0.0	 2.16	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2833	 1	 62.7	 9.0	 0.0	 8.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2834	 1	 3.8	 1.3	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2835	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	2836	 1	 31.28	 5.34	 0.0	 8.75	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2837	 1	 -0.0	 -0.0	 0.0	 21.27	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2838	 1	 -9.31	 3.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2839	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2840	 1	 330.9	 51.9	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 20	    1.10000	    0.90000;
	2841	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2843	 1	 25.13	 15.6	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2844	 1	 179.0	 50.5	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2845	 1	 21.22	 5.3	 0.0	 1.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2846	 1	 42.25	 4.4	 0.0	 9.58843	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	2847	 1	 40.14	 8.8	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2848	 1	 453.23	 139.16	 0.0	 25.583218	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2849	 1	 0.0	 0.0	 0.0	 70.11	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2850	 1	 -0.0	 -0.0	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2851	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2852	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2853	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2854	 1	 -12.33	 -2.65	 0.0	 69.323028	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2855	 1	 -0.0	 0.0	 0.234854	 45.08542	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	2856	 1	 7.11	 4.4	 0.0	 0.97	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2857	 1	 4.2	 1.1	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2858	 1	 192.3	 84.6	 0.0	 38.41	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	2859	 1	 -57.0	 -24.9	 0.0	 8.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2860	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2861	 1	 17.72	 5.9	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2862	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2863	 1	 37.73	 13.84	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2864	 1	 30.03	 10.0	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2865	 1	 46.35	 16.8	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	2866	 1	 -0.0	 0.0	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2867	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	2868	 1	 0.0	 -0.0	 0.0	 1.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2869	 1	 18.8	 8.5	 0.0	 75.218793	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	2870	 1	 -0.0	 0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2871	 1	 59.32	 -20.32	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2872	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2873	 1	 33.36	 20.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	2874	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2875	 1	 69.28	 23.1	 0.0	 4.86	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2876	 1	 24.13	 15.0	 0.0	 3.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2877	 1	 29.93	 -0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2878	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2879	 1	 13.82	 5.0	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2880	 1	 -0.0	 -0.0	 0.0	 14.2	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2881	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2882	 1	 -7.47	 -6.45	 0.0	 1.08	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2883	 1	 205.9	 38.3	 0.0	 6.54	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2884	 1	 282.5	 17.4	 0.0	 20.04	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2885	 1	 0.0	 -0.0	 0.0	 24.73	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2886	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2887	 1	 57.66	 61.0	 0.0	 6.46	 0	    1.00000	    0.00000	 220.0	 17	    1.10000	    0.90000;
	2888	 1	 -0.0	 0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2889	 1	 -0.0	 0.0	 0.0	 3.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2890	 1	 102.8	 30.8	 0.0	 2.66	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2891	 1	 254.9	 71.4	 0.0	 0.7	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2892	 1	 10.11	 3.7	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.30000	    0.70000;
	2893	 1	 -0.0	 -0.0	 0.0	 2.82	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2894	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2895	 1	 151.0	 45.7	 0.0	 3.02	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2897	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	2898	 1	 56.76	 13.4	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2899	 1	 -0.0	 -0.0	 0.0	 44.66	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2900	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2901	 1	 -0.51	 -20.69	 0.0	 2.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2902	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2903	 1	 133.7	 59.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2904	 1	 0.0	 -0.0	 0.37905	 21.97435	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	2905	 1	 -0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2906	 1	 255.8	 144.8	 0.0	 52.33	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2907	 1	 241.0	 32.3	 0.0	 34.74	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2908	 1	 203.8	 61.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2909	 1	 -0.0	 0.0	 0.0	 5.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2910	 1	 -0.0	 0.0	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2911	 1	 10.91	 3.6	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2912	 1	 46.25	 32.2	 0.0	 1.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2913	 1	 51.96	 9.4	 0.0	 42.51	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2914	 1	 -0.0	 -0.0	 0.0	 3.43	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2915	 1	 -0.0	 -0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2916	 1	 63.47	 30.2	 0.0	 81.36	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2917	 1	 31.64	 7.5	 0.0	 21.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2918	 1	 0.0	 0.0	 0.0	 53.25003	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2919	 1	 -0.0	 0.0	 0.0	 32.049116	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2920	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2921	 1	 37.24	 7.1	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2922	 1	 34.04	 12.3	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2923	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2924	 1	 19.92	 7.4	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2925	 1	 19.04	 7.9	 0.0	 4.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2926	 1	 61.97	 14.3	 0.0	 8.38	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2927	 1	 -0.0	 0.0	 0.0	 26.18	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2928	 1	 0.0	 -0.0	 0.0	 92.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2929	 1	 -0.0	 -0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2931	 1	 230.7	 19.3	 0.0	 4.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2932	 1	 17.7	 -333.3	 0.132526	 89.131068	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2933	 1	 70.08	 10.0	 0.0	 33.04	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	2934	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2935	 1	 -0.0	 -0.0	 0.0	 -4.4045	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	2936	 1	 -0.0	 -0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2937	 1	 16.72	 6.1	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2938	 1	 0.0	 -0.0	 0.0	 137.29	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2939	 1	 0.0	 0.0	 0.26	 6.5	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	2940	 1	 103.0	 28.7	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2941	 1	 0.0	 0.0	 0.0	 35.93	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2942	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	2943	 1	 0.0	 -0.0	 0.0	 0.75	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2944	 1	 0.0	 0.0	 0.0	 2.32	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2945	 1	 41.95	 26.0	 0.0	 12.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2946	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2947	 1	 -21.38	 -13.23	 0.0	 2.52	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2948	 1	 215.7	 60.28	 0.0	 97.42	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	2949	 1	 -0.0	 -0.0	 0.0	 11.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2950	 1	 16.22	 5.7	 0.0	 4.68	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2951	 1	 104.6	 40.7	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2952	 1	 94.3	 13.4	 0.0	 0.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2953	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2954	 1	 4.81	 1.2	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2955	 1	 188.2	 23.4	 0.0	 17.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2956	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2957	 1	 81.19	 24.4	 0.0	 0.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2958	 1	 16.72	 5.5	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2959	 1	 -0.45	 -0.03	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2960	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2961	 1	 159.9	 53.2	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2962	 1	 93.5	 42.5	 0.0	 133.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2963	 1	 -0.0	 -0.0	 0.0	 22.54	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	2964	 1	 0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2965	 1	 -29.96	 -21.31	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2966	 1	 4.4	 1.5	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2967	 1	 0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2968	 1	 112.51	 16.51	 0.0	 1.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2969	 1	 9.31	 3.0	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2970	 1	 -0.0	 -0.0	 0.0	 1.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2971	 1	 0.0	 0.0	 0.0	 11.55	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2972	 1	 97.82	 20.59	 0.0	 6.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2973	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2974	 1	 65.47	 26.7	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2975	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2976	 1	 0.0	 0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2977	 1	 5.81	 1.3	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2978	 1	 0.0	 0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2979	 1	 13.9	 1.9	 0.0	 1.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2980	 1	 -0.0	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2981	 1	 -0.0	 0.0	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2982	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2983	 1	 26.83	 13.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2984	 1	 17.35	 -0.8	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2985	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2986	 1	 0.0	 0.0	 0.0	 21.88	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2988	 1	 27.03	 9.0	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2989	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2990	 1	 0.0	 -0.0	 0.0	 12.22	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2991	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	2992	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 12	    1.30000	    0.70000;
	2993	 1	 17.72	 7.3	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2994	 1	 5.81	 1.9	 0.0	 3.45	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2995	 1	 0.0	 -0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2996	 1	 31.84	 5.5	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2997	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.30000	    0.70000;
	2998	 1	 17.02	 6.2	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2999	 1	 48.8	 6.9	 0.0	 14.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3000	 1	 139.6	 68.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3001	 1	 87.73	 23.17	 0.0	 2.68	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3002	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3003	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3004	 1	 -0.0	 0.0	 0.0	 0.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3005	 1	 -0.0	 -0.0	 0.0	 2.03	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3006	 1	 87.6	 27.4	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3007	 1	 108.8	 33.2	 0.358716	 45.62985	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3008	 1	 0.0	 0.0	 0.0	 22.7	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3009	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3010	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3011	 1	 33.34	 11.0	 0.0	 1.16	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3012	 1	 -1398.9	 -380.6	 0.0	 58.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3013	 1	 2.2	 1.1	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3014	 1	 12.81	 3.9	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3015	 1	 -0.0	 -0.0	 0.0	 17.77	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3016	 1	 30.23	 10.0	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3017	 1	 -0.0	 -0.0	 0.27075	 22.54135	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	3018	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3019	 1	 0.0	 -0.0	 0.0	 1.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3020	 1	 0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3021	 1	 74.38	 8.8	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3022	 1	 149.0	 19.8	 0.0	 23.89	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3023	 1	 0.0	 -0.0	 0.0	 27.69	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3024	 1	 -0.0	 0.0	 0.0	 1.57	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3025	 1	 -0.0	 -0.0	 0.169151	 40.514944	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	3026	 1	 0.0	 -0.0	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3027	 1	 0.0	 0.0	 0.0	 1.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3028	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3029	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3030	 1	 78.59	 25.6	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3031	 1	 6.61	 2.4	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3032	 1	 -0.0	 0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3033	 1	 41.15	 5.7	 0.0	 4.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3034	 1	 4.61	 1.4	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3035	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3036	 1	 116.93	 33.6	 0.0	 3.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3037	 1	 221.0	 146.8	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3038	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3039	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3040	 1	 -0.0	 0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3041	 1	 0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3042	 1	 0.0	 -0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	3043	 1	 26.93	 8.0	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3044	 1	 29.33	 5.6	 0.0	 6.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3045	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3046	 1	 -0.0	 -0.0	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3047	 1	 0.0	 -0.0	 0.0	 3.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3048	 1	 95.91	 -15.4	 0.0	 1.51	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3049	 1	 -0.0	 0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3050	 1	 -0.54	 -0.77	 0.181549	 1.270889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3051	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3052	 1	 0.0	 -0.0	 0.0	 8.21	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3053	 1	 10.31	 4.6	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3054	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3055	 1	 1.4	 0.2	 0.0	 5.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3056	 1	 22.5	 9.5	 0.0	 29.37436	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	3057	 1	 -17.8	 -3.68	 0.110438	 41.234223	 0	    1.00000	    0.00000	 380.0	 3	    1.30000	    0.70000;
	3058	 1	 0.0	 -0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3059	 1	 -14.85	 -4.99	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3060	 1	 0.0	 0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3061	 1	 493.4	 53.5	 0.0	 58.09	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3062	 1	 8.71	 1.6	 0.0	 1.23	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3063	 1	 71.28	 6.9	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3064	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3065	 1	 55.86	 8.8	 0.0	 4.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3066	 1	 119.7	 3.7	 0.0	 0.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3067	 1	 272.3	 58.5	 0.0	 23.57	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3068	 1	 566.1	 54.2	 0.0	 44.559841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3069	 1	 89.6	 22.7	 0.0	 4.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3070	 1	 0.0	 -0.0	 0.0	 4.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3071	 1	 0.0	 -0.0	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3072	 1	 92.9	 27.7	 0.0	 5.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3073	 1	 100.7	 -23.3	 0.0	 2.97	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3074	 1	 0.0	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3075	 1	 30.33	 10.5	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3076	 1	 164.0	 42.3	 0.0	 8.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3077	 1	 11.91	 3.0	 0.0	 1.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3078	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3079	 1	 10.11	 3.3	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3080	 1	 -0.0	 -0.0	 0.256503	 101.229042	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3081	 1	 0.0	 0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3082	 1	 0.0	 0.0	 0.0	 75.076038	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3083	 1	 567.97	 130.73	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3085	 1	 64.67	 24.5	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3086	 1	 0.0	 0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3087	 1	 0.0	 0.0	 0.0	 3.64	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3088	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3089	 1	 15.22	 4.2	 0.0	 1.35	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3092	 1	 28.63	 12.1	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3093	 1	 11.21	 3.7	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3094	 1	 4.1	 1.5	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3095	 1	 69.78	 15.3	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3097	 1	 128.11	 64.9	 0.0	 19.1	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3098	 1	 -0.0	 -0.0	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	3099	 1	 380.9	 85.1	 0.0	 57.449841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3100	 1	 -0.0	 -0.0	 0.0	 4.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3101	 1	 0.0	 8.4	 0.0	 15.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3102	 1	 125.2	 105.4	 0.0	 76.73	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3103	 1	 -0.0	 -0.0	 0.06	 11.38	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3104	 1	 -0.0	 0.0	 0.11	 2.05	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3105	 1	 2.3	 0.8	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3106	 1	 30.63	 11.6	 0.0	 52.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3107	 1	 -0.0	 -0.0	 0.0	 2.65	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3108	 1	 -0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3109	 1	 -0.0	 0.0	 0.0	 8.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3110	 1	 -0.19	 -73.31	 0.0	 2.36	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3111	 1	 0.0	 0.0	 0.0	 20.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3112	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3113	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3114	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3115	 1	 -0.0	 0.0	 0.0	 113.7	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	3116	 1	 57.86	 70.5	 0.495087	 218.066972	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3117	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3118	 1	 0.0	 -0.0	 0.0	 4.36	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3119	 1	 99.9	 20.1	 0.0	 17.41	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3120	 1	 0.0	 0.0	 0.181549	 15.300889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3121	 1	 242.16	 73.64	 0.0	 12.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3122	 1	 13.21	 4.4	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3123	 1	 115.5	 71.5	 0.0	 150.47	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3124	 1	 0.0	 -0.0	 0.0	 3.13	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3125	 1	 -0.0	 0.0	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3126	 1	 104.78	 20.92	 0.0	 6.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3127	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3128	 1	 2.5	 0.5	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3129	 1	 109.5	 22.8	 0.0	 7.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3130	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	3131	 1	 3.5	 1.4	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3132	 1	 -14.9	 -4.6	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3133	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3135	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3136	 1	 7.61	 2.5	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3137	 1	 0.0	 -0.0	 0.0	 0.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3138	 1	 0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3139	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3140	 1	 13.9	 1.9	 0.0	 2.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3141	 1	 20.72	 6.3	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3142	 1	 100.5	 37.0	 0.0	 14.95	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	3143	 1	 91.7	 13.0	 0.0	 2.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3144	 1	 19.82	 7.2	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3145	 1	 -0.0	 -0.0	 0.0	 24.909116	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3146	 1	 -0.0	 0.0	 0.0	 45.39	 0	    1.00000	    0.00000	 380.0	 15	    1.30000	    0.70000;
	3147	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.30000	    0.70000;
	3148	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3149	 1	 80.09	 -1.8	 0.0	 4.09	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3151	 1	 8.31	 3.0	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3152	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	3153	 1	 68.68	 19.1	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3154	 1	 -0.0	 0.0	 0.0	 0.21	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3155	 1	 0.0	 0.0	 0.0	 19.63	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3156	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3157	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3159	 1	 136.7	 19.3	 0.0	 37.5	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3160	 1	 10.61	 51.2	 0.203187	 8.281355	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3161	 1	 59.98	 15.54	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3162	 1	 8.31	 2.5	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3164	 1	 83.9	 11.9	 0.0	 1.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3165	 1	 -16.5	 3.6	 0.0	 1.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3166	 1	 184.91	 32.8	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3167	 1	 11.11	 3.6	 0.0	 3.36	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3168	 1	 -0.0	 0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3169	 1	 0.0	 0.0	 0.0	 75.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3170	 1	 39.64	 9.8	 0.0	 1.08	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3171	 1	 13.84	 1.85	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3172	 1	 -0.0	 -0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3173	 1	 0.0	 -0.0	 0.22	 21.48	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	3174	 1	 292.8	 114.2	 0.0	 22.01	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3175	 1	 0.0	 0.0	 0.0	 1.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3176	 1	 132.9	 40.5	 0.0	 6.92	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3177	 1	 39.34	 11.2	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3178	 1	 180.2	 46.4	 0.0	 9.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3179	 1	 23.63	 7.8	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3180	 1	 0.0	 -0.0	 0.0	 62.76	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3181	 1	 -0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3182	 1	 31.94	 12.6	 0.0	 10.67	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3184	 1	 14.12	 7.7	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3185	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3186	 1	 -20.92	 2.5	 0.0	 16.42	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3187	 1	 107.0	 34.7	 0.0	 1.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3188	 1	 75.58	 30.3	 0.0	 34.66	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3189	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3190	 1	 0.0	 -0.0	 0.0	 35.14	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3191	 1	 127.8	 15.2	 0.0	 9.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3192	 1	 -0.0	 0.0	 0.370251	 146.807945	 0	    1.00000	    0.00000	 380.0	 18	    1.30000	    0.70000;
	3193	 1	 0.0	 0.0	 0.0	 207.85	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3194	 1	 -0.0	 -0.0	 0.0	 54.23	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3195	 1	 104.5	 31.8	 0.0	 0.71	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3196	 1	 398.0	 11.5	 0.0	 7.749841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3197	 1	 15.92	 12.0	 0.0	 6.79	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	3198	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	3199	 1	 23.8	 3.4	 0.0	 6.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3200	 1	 86.2	 19.9	 0.0	 5.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3201	 1	 -0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3202	 1	 0.2	 0.9	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3203	 1	 27.03	 9.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3204	 1	 8.51	 3.2	 0.0	 0.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3205	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3206	 1	 146.7	 20.7	 0.0	 62.64	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3207	 1	 98.01	 16.6	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3208	 1	 0.0	 -0.0	 0.0	 104.11	 0	    1.00000	    0.00000	 380.0	 22	    1.10000	    0.90000;
	3209	 1	 2.3	 0.8	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3210	 1	 -0.0	 -0.0	 0.0	 47.99	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3211	 1	 0.0	 0.0	 0.0	 5.21	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3212	 1	 62.7	 9.0	 0.0	 3.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3213	 1	 0.0	 0.0	 0.181549	 5.810889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3214	 1	 0.0	 -0.0	 0.0	 1.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3215	 1	 63.07	 25.8	 0.0	 18.63	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3216	 1	 73.58	 30.1	 0.0	 6.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3217	 1	 64.0	 9.1	 0.0	 12.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3218	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3219	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3220	 1	 -0.0	 -0.0	 0.0	 24.67	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3221	 1	 76.38	 24.8	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3222	 1	 9.01	 1.1	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3223	 1	 0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3224	 1	 0.0	 -0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	3225	 1	 81.2	 89.3	 0.0	 15.55	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3226	 1	 77.7	 11.1	 0.0	 4.49	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3227	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3228	 1	 -0.0	 0.0	 0.0	 3.58	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3229	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3230	 1	 18.5	 2.7	 0.0	 0.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3231	 1	 251.3	 42.6	 0.0	 5.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3232	 1	 133.9	 32.4	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3233	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3234	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3235	 1	 -6.58	 -1.67	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3236	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	3237	 1	 16.42	 5.9	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3238	 1	 0.0	 -0.0	 0.0	 6.19	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3239	 1	 -5.06	 -1.84	 0.0	 187.327025	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3240	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3241	 1	 132.0	 27.0	 0.0	 4.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3242	 1	 296.1	 82.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3243	 1	 -0.0	 0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3244	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3245	 1	 0.0	 0.0	 0.0	 17.82055	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	3246	 1	 20.9	 -171.5	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3247	 1	 113.0	 56.5	 0.0	 4.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3248	 1	 84.19	 17.3	 0.0	 6.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3249	 1	 -0.0	 -0.0	 0.0	 17.65	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3250	 1	 26.33	 7.6	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3251	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3252	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3253	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3254	 1	 -0.0	 -0.0	 0.0	 45.7	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3255	 1	 0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3256	 1	 -0.0	 0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3257	 1	 0.0	 -0.0	 0.0	 3.71	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3258	 1	 -11.71	 3.8	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3259	 1	 -0.0	 0.0	 0.0	 53.64	 0	    1.00000	    0.00000	 380.0	 15	    1.30000	    0.70000;
	3260	 1	 83.6	 11.9	 0.0	 5.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3261	 1	 87.0	 29.6	 0.0	 4.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3262	 1	 -0.0	 -0.0	 0.2166	 10.9704	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	3263	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3264	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3265	 1	 0.0	 -0.0	 0.0	 61.52	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3266	 1	 -0.0	 0.0	 0.0	 4.62	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3267	 1	 -0.0	 0.0	 0.0	 21.82	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3268	 1	 -0.0	 -0.0	 0.0	 29.27	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3269	 1	 115.6	 16.4	 0.0	 2.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3270	 1	 0.0	 0.0	 0.0	 5.12	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3271	 1	 -0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3272	 1	 -30.03	 9.9	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3273	 1	 -0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3274	 1	 12.11	 5.5	 0.0	 1.19	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3275	 1	 -0.0	 0.0	 0.0	 17.75	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3276	 1	 -0.0	 -0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3277	 1	 0.0	 0.0	 0.294847	 40.776932	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	3278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3279	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3280	 1	 -0.0	 0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3281	 1	 10.61	 3.8	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3282	 1	 -0.0	 0.0	 0.0	 9.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3283	 1	 5.5	 0.8	 0.0	 1.19	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3284	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3285	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3286	 1	 0.0	 0.0	 0.0	 5.67	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3287	 1	 27.8	 4.0	 0.0	 9.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3288	 1	 -0.57	 -0.91	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3289	 1	 11.01	 6.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3290	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	3291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3292	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3293	 1	 33.14	 11.6	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3294	 1	 5.51	 2.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3295	 1	 -0.01	 0.0	 0.0	 30.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3296	 1	 -0.0	 0.0	 0.0	 1.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3297	 1	 -0.0	 -0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3298	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3299	 1	 332.9	 99.6	 0.0	 0.53	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3300	 1	 12.01	 3.9	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3301	 1	 72.08	 29.5	 0.0	 1.06	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3302	 1	 34.9	 5.0	 0.0	 11.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3303	 1	 0.0	 0.0	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3304	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3305	 1	 13.9	 1.9	 0.0	 3.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3306	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3307	 1	 -0.0	 -0.0	 0.0	 1.84	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3308	 1	 -0.0	 -0.0	 0.0	 7.75	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3309	 1	 32.64	 11.8	 0.0	 2.07	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3310	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3311	 1	 19.82	 7.3	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3312	 1	 -10.11	 3.3	 0.0	 0.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3313	 1	 0.0	 -0.0	 0.0	 34.49	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3314	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3315	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3316	 1	 50.56	 16.6	 0.0	 2.02	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3317	 1	 89.5	 12.8	 0.0	 5.08	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3318	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3319	 1	 120.4	 39.5	 0.0	 47.2	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3320	 1	 -0.0	 -0.0	 0.0	 0.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3321	 1	 -0.0	 -0.0	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3322	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3323	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3324	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3325	 1	 -0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3326	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3327	 1	 -0.0	 -0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3328	 1	 14.72	 4.6	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3329	 1	 2.3	 0.8	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3331	 1	 -0.0	 -0.0	 0.0	 4.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3332	 1	 -10.59	 -5.25	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3333	 1	 34.04	 11.0	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3334	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3335	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3336	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3337	 1	 236.2	 116.4	 0.0	 16.22	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3338	 1	 14.72	 6.7	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3339	 1	 0.0	 -0.0	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3340	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	3341	 1	 46.85	 16.6	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3342	 1	 76.18	 13.2	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3343	 1	 379.9	 73.0	 0.0	 59.58	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3344	 1	 83.29	 24.1	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3345	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3346	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3347	 1	 38.04	 20.0	 0.0	 0.03	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3348	 1	 -0.0	 0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3349	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3350	 1	 1.3	 0.4	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3351	 1	 129.5	 51.8	 0.0	 107.08	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3352	 1	 -0.0	 -0.0	 0.0	 5.22	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3353	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3354	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3355	 1	 0.0	 -0.0	 0.0	 5.14	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3356	 1	 -0.0	 -0.0	 0.185125	 56.232473	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	3357	 1	 36.54	 27.4	 0.0	 0.16	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3358	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	3359	 1	 -0.0	 -0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3360	 1	 -0.0	 -0.0	 0.0	 6.1	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3361	 1	 -0.0	 -0.0	 0.0	 7.68	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3362	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3363	 1	 155.8	 38.4	 0.0	 3.77	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3364	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3365	 1	 -0.0	 -0.0	 0.090774	 0.080444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3366	 1	 3.8	 1.3	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3367	 1	 57.46	 15.3	 0.0	 4.37	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3368	 1	 143.79	 106.96	 0.0	 99.84	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	3369	 1	 3.4	 1.4	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3370	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3371	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	3372	 1	 0.0	 -0.0	 0.13	 10.79	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3373	 1	 0.5	 0.5	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3374	 1	 156.2	 24.5	 0.0	 2.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3375	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	3376	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3377	 1	 77.49	 21.4	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3378	 1	 -0.0	 -0.0	 0.0	 13.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3379	 1	 13.9	 1.9	 0.0	 5.68	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3380	 1	 50.06	 19.7	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	3381	 1	 8.31	 3.0	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3382	 1	 115.0	 -4.5	 0.0	 15.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3383	 1	 47.15	 15.2	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3384	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3385	 1	 -0.0	 0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3386	 1	 82.6	 11.7	 0.0	 1.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3387	 1	 4.61	 1.7	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3388	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3389	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	3390	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3391	 1	 302.5	 65.1	 0.0	 8.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3392	 1	 -0.0	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3393	 1	 15.57	 9.59	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3394	 1	 27.13	 9.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3395	 1	 -0.0	 -0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3396	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3397	 1	 24.12	 9.8	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3398	 1	 -0.75	 -0.93	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3399	 1	 50.06	 16.0	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3400	 1	 0.0	 0.0	 0.0	 17.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3401	 1	 23.22	 6.3	 0.0	 0.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3402	 1	 115.0	 16.4	 0.0	 3.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3403	 1	 234.2	 33.3	 0.0	 0.88	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3404	 1	 140.93	 18.71	 0.0	 12.73	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3405	 1	 -0.76	 -0.86	 0.0	 6.15	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	3406	 1	 0.0	 -0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3407	 1	 108.7	 26.3	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3408	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3409	 1	 -0.0	 -0.0	 0.0	 16.4	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3410	 1	 52.06	 17.0	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3411	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3412	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3413	 1	 19.42	 7.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3414	 1	 78.09	 27.0	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3415	 1	 14.72	 5.3	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3416	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3417	 1	 0.0	 0.0	 0.0	 1.78	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3418	 1	 -0.0	 -0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3419	 1	 0.0	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	3420	 1	 6.71	 2.4	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3421	 1	 11.51	 4.2	 0.0	 3.64	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3423	 1	 173.1	 4.6	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3424	 1	 11.5	 1.7	 0.0	 3.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3425	 1	 83.59	 21.6	 0.0	 25.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3426	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3427	 1	 146.9	 26.6	 0.0	 11.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3428	 1	 -0.0	 -0.0	 0.0	 17.92	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3429	 1	 175.4	 28.8	 0.0	 2.03	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3430	 1	 125.1	 44.0	 0.0	 6.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3431	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3432	 1	 39.05	 -11.82	 0.0	 1.12	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3433	 1	 -0.0	 0.0	 0.121066	 38.317958	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	3434	 1	 4.2	 2.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3435	 1	 -0.0	 0.0	 0.0	 10.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3437	 1	 0.0	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3438	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3439	 1	 9.7	 1.4	 0.0	 4.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3440	 1	 0.0	 0.0	 0.0	 80.21	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	3441	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3442	 1	 54.96	 12.2	 0.0	 7.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3443	 1	 -0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3444	 1	 5.11	 1.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3445	 1	 -7.63	 -4.3	 0.0	 94.00001	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3446	 1	 271.43	 74.55	 0.0	 78.4	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	3447	 1	 120.1	 30.5	 0.0	 5.26	 0	    1.00000	    0.00000	 220.0	 17	    1.10000	    0.90000;
	3448	 1	 -15.8	 -2.8	 0.0	 7.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3449	 1	 0.0	 -0.0	 0.0	 25.28	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3450	 1	 78.99	 16.2	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3451	 1	 20.82	 9.5	 0.0	 1.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3452	 1	 15.63	 4.8	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3453	 1	 3.9	 0.9	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3454	 1	 0.0	 0.0	 0.0	 33.22	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	3455	 1	 -18.8	 -5.9	 0.0	 6.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3456	 1	 -0.0	 0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3457	 1	 23.13	 8.8	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3458	 1	 4.2	 0.6	 0.0	 4.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3459	 1	 76.6	 10.9	 0.0	 9.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3460	 1	 0.0	 -0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3461	 1	 119.1	 60.5	 0.0	 2.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3462	 1	 209.5	 95.0	 0.0	 24.39	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3463	 1	 0.0	 0.0	 0.0	 0.69	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3464	 1	 -0.0	 -0.0	 0.0	 7.49	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3465	 1	 119.1	 22.3	 0.0	 2.71	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3466	 1	 7.71	 2.2	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3467	 1	 1.5	 0.5	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3468	 1	 50.36	 -36.2	 0.0	 1.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3469	 1	 0.0	 -0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3470	 1	 123.1	 51.8	 0.0	 1.68	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3471	 1	 18.72	 5.5	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3472	 1	 18.02	 -15.7	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	3473	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3474	 1	 23.93	 8.7	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3475	 1	 0.0	 -0.0	 0.0	 64.67	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3476	 1	 0.0	 0.0	 0.0	 8.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3477	 1	 22.12	 7.9	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3478	 1	 -3.4	 -0.5	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3479	 1	 124.9	 104.0	 0.0	 4.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3481	 1	 142.5	 23.6	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3482	 1	 22.02	 13.7	 0.0	 0.44	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3483	 1	 -0.0	 -0.0	 0.0	 91.192543	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3484	 1	 -0.0	 0.0	 0.0	 37.1	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3485	 1	 -0.0	 0.0	 0.0	 6.501668	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3486	 1	 101.5	 -18.3	 0.0	 8.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3487	 1	 16.32	 7.6	 0.0	 3.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3488	 1	 55.66	 4.5	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3489	 1	 0.0	 -0.0	 0.0	 12.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3490	 1	 12.51	 4.1	 0.0	 0.71	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3491	 1	 15.92	 5.2	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3492	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3493	 1	 226.3	 61.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3494	 1	 0.0	 0.0	 0.230863	 107.524848	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	3495	 1	 36.34	 3.3	 0.0	 2.16	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3496	 1	 99.3	 23.3	 0.0	 1.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3497	 1	 100.5	 32.0	 0.0	 1.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3498	 1	 138.5	 19.3	 0.0	 5.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3499	 1	 180.4	 71.6	 0.0	 81.042938	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3500	 1	 94.2	 21.6	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3501	 1	 33.5	 4.8	 0.0	 3.47	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3502	 1	 98.2	 19.1	 0.0	 10.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3503	 1	 -0.0	 0.0	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3504	 1	 8.91	 2.5	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3505	 1	 0.0	 0.0	 0.0	 3.49	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	3506	 1	 0.0	 0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3507	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3508	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	3509	 1	 23.62	 16.5	 0.0	 8.39	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3510	 1	 0.0	 -0.0	 0.0	 43.87	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	3511	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3512	 1	 65.64	 -0.98	 0.0	 11.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3513	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3514	 1	 -0.64	 -3.53	 0.0	 8.84	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3515	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3516	 1	 -0.0	 0.0	 0.0	 3.48	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3517	 1	 -0.0	 0.0	 0.0	 42.71	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3518	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 330.0	 24	    1.10000	    0.90000;
	3519	 1	 -0.0	 0.0	 0.0	 68.053762	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3520	 1	 -0.0	 0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3521	 1	 9.7	 1.4	 0.0	 2.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3522	 1	 -0.0	 -0.0	 0.0	 13.79	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3523	 1	 29.33	 9.6	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3524	 1	 29.93	 10.8	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3525	 1	 0.0	 -0.0	 0.040985	 0.716371	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3526	 1	 33.34	 13.2	 0.0	 0.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3527	 1	 -0.0	 0.0	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3528	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3529	 1	 -0.0	 0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3530	 1	 118.5	 21.0	 0.0	 2.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3531	 1	 7.81	 2.8	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3532	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3533	 1	 159.1	 -28.7	 0.0	 2.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3534	 1	 8.61	 3.1	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3535	 1	 -0.0	 0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3536	 1	 -0.48	 0.1	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3537	 1	 96.5	 -43.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3538	 1	 0.0	 0.0	 0.0	 4.17	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3539	 1	 97.0	 -52.1	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3540	 1	 6.01	 3.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3541	 1	 0.0	 -0.0	 0.0	 3.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3542	 1	 0.0	 -0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3543	 1	 -0.0	 -0.0	 0.0	 14.079026	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3544	 1	 0.0	 -0.0	 0.0	 83.96	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3545	 1	 20.12	 7.6	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3546	 1	 -0.0	 -0.0	 0.0	 48.46	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3547	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3548	 1	 10.01	 3.0	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3549	 1	 0.0	 0.0	 0.0	 3.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3550	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3551	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	3552	 1	 -0.0	 0.0	 0.0	 18.31	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3553	 1	 0.0	 0.0	 0.0	 0.25	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3554	 1	 362.2	 -10.5	 0.0	 19.86	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3555	 1	 0.0	 -0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3556	 1	 31.23	 12.9	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3557	 1	 87.2	 31.8	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3558	 1	 -0.0	 0.0	 0.0	 2.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3559	 1	 4.1	 0.9	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3560	 1	 47.95	 17.2	 0.0	 7.91	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3561	 1	 60.67	 37.6	 0.0	 0.92	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3562	 1	 6.31	 1.3	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3563	 1	 392.8	 70.6	 0.0	 13.309841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3564	 1	 0.0	 -0.0	 0.0	 5.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3565	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3566	 1	 5.21	 1.5	 0.0	 1.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3567	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3568	 1	 30.6	 4.3	 0.0	 8.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3569	 1	 215.3	 37.7	 0.0	 14.36	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3570	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3571	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3572	 1	 8.31	 3.0	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3573	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3574	 1	 -0.0	 0.0	 0.0	 32.63	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	3575	 1	 24.43	 8.7	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3576	 1	 1.4	 0.5	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3577	 1	 -38.7	 -12.99	 0.0	 13.47383	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3578	 1	 -0.0	 0.0	 0.0	 11.06	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3579	 1	 277.72	 7.35	 0.0	 3.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3580	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3581	 1	 -10.61	 3.5	 0.0	 1.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3582	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3583	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3584	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3585	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3586	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3587	 1	 0.0	 -0.0	 0.0	 78.22	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3588	 1	 0.0	 -0.0	 0.0	 1.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3589	 1	 37.54	 18.3	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3590	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3591	 1	 13.9	 1.9	 0.0	 4.47	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3592	 1	 102.7	 77.5	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3593	 1	 84.09	 52.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3594	 1	 31.43	 6.6	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3595	 1	 14.02	 7.6	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3596	 1	 86.7	 34.6	 0.0	 2.73	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3597	 1	 0.0	 -0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3598	 1	 4.4	 2.2	 0.0	 1.79	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3599	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	3600	 1	 -11.01	 3.6	 0.0	 0.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3601	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3602	 1	 86.6	 14.9	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3603	 1	 0.0	 -0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3604	 1	 124.3	 39.4	 0.0	 6.43	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	3605	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3606	 1	 194.3	 27.9	 0.0	 3.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3607	 1	 95.1	 -19.36	 0.0	 12.46	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3608	 1	 0.0	 -0.0	 0.0	 58.146813	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3609	 1	 -28.13	 -0.82	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3610	 1	 185.8	 31.8	 0.0	 3.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3611	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3612	 1	 -0.0	 -0.0	 0.0	 4.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3613	 1	 152.5	 14.4	 0.0	 24.61	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3614	 1	 9.21	 3.3	 0.0	 1.13	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3615	 1	 0.0	 -0.0	 0.0	 13.51	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3616	 1	 108.43	 31.33	 0.0	 0.88	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3617	 1	 81.79	 51.1	 0.0	 3.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3618	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3619	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3620	 1	 35.14	 16.1	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3621	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3622	 1	 -0.0	 -0.0	 0.0	 53.84	 0	    1.00000	    0.00000	 380.0	 12	    1.10000	    0.90000;
	3623	 1	 0.0	 -0.0	 0.0	 4.08	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3624	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3625	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3626	 1	 13.62	 8.4	 0.0	 2.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3627	 1	 -0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3628	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3629	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3630	 1	 21.52	 7.6	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3631	 1	 -0.0	 -0.0	 0.0	 11.98	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3632	 1	 -12.3	 -10.6	 0.0	 3.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3633	 1	 -0.0	 0.0	 0.0	 15.23	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3634	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3635	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3636	 1	 0.0	 0.0	 0.0	 10.82	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3637	 1	 23.93	 5.8	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3638	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3639	 1	 1.7	 0.3	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3640	 1	 0.0	 -0.0	 0.0	 7.1	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3641	 1	 30.33	 11.0	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3642	 1	 1.3	 0.4	 0.0	 1.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3643	 1	 24.23	 6.4	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3644	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3645	 1	 42.55	 17.6	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3646	 1	 32.24	 11.7	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3647	 1	 -668.3	 -230.2	 0.0	 0.52	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3648	 1	 -0.0	 0.0	 0.0	 57.87	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3649	 1	 -0.0	 -0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3650	 1	 0.0	 -0.0	 0.0	 4.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3651	 1	 0.0	 -0.0	 0.0	 11.87	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3652	 1	 61.4	 8.8	 0.0	 3.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3653	 1	 11.5	 6.16	 0.0	 1.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3654	 1	 20.72	 5.0	 0.0	 6.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3655	 1	 114.8	 121.5	 0.0	 24.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3657	 1	 131.0	 1.3	 0.0	 120.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3658	 1	 0.0	 -0.0	 0.0	 2.8	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3659	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3660	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3661	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3662	 1	 -0.0	 -0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3663	 1	 50.2	 7.1	 0.0	 8.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3664	 1	 -0.2	 -0.96	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3665	 1	 295.4	 42.0	 0.0	 0.83	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3666	 1	 -0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3667	 1	 -0.0	 -0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3668	 1	 -0.0	 0.0	 0.0	 13.93	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3669	 1	 -0.0	 -0.0	 0.0	 2.04	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3670	 1	 28.03	 6.5	 0.0	 6.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3671	 1	 22.83	 9.7	 0.0	 5.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3672	 1	 82.99	 25.9	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3673	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3674	 1	 155.05	 39.56	 0.0	 6.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3675	 1	 -0.0	 0.0	 0.0	 -0.73	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3676	 1	 95.0	 10.43	 0.0	 89.57	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	3677	 1	 5.51	 2.2	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3678	 1	 4.69	 1.89	 0.0	 2.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3679	 1	 49.91	 23.81	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3680	 1	 -0.0	 -0.0	 0.0	 12.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3681	 1	 -0.0	 0.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3682	 1	 2.5	 1.3	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3683	 1	 28.93	 10.5	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3684	 1	 182.3	 65.9	 0.0	 62.49	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	3685	 1	 52.79	 2.64	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3686	 1	 -0.0	 0.01	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3687	 1	 0.0	 -0.0	 0.0	 70.71	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3688	 1	 -0.0	 0.0	 0.1	 5.73	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3689	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3690	 1	 -17.62	 5.8	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3691	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3692	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3693	 1	 0.0	 0.0	 0.0	 1.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3694	 1	 16.4	 2.3	 0.0	 3.43	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3695	 1	 -0.0	 -0.0	 0.0	 0.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3696	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3697	 1	 -32.71	 -13.76	 0.0	 135.136611	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3698	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3699	 1	 16.62	 -10.3	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3700	 1	 -4.86	 -2.12	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3701	 1	 -0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3702	 1	 0.0	 -0.0	 0.0	 13.3	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	3703	 1	 0.0	 0.0	 0.0	 1.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3704	 1	 72.68	 45.0	 0.0	 6.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3705	 1	 120.7	 24.3	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3706	 1	 2.5	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3707	 1	 77.49	 17.3	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3708	 1	 32.1	 4.5	 0.0	 2.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3709	 1	 -0.0	 -0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3710	 1	 0.0	 0.0	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3711	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3712	 1	 -0.19	 -0.87	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3713	 1	 24.03	 8.0	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3714	 1	 -2835.7	 -818.9	 0.0	 56.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3715	 1	 68.78	 13.0	 0.0	 10.45	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3716	 1	 85.1	 -122.4	 0.0	 6.67	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3717	 1	 -0.0	 -0.0	 0.0	 4.67	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3718	 1	 179.4	 58.3	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3719	 1	 4.4	 2.2	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3720	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3721	 1	 -0.0	 0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3722	 1	 65.1	 26.4	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	3723	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3724	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3725	 1	 50.96	 17.0	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3726	 1	 16.52	 7.1	 0.0	 1.1	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3727	 1	 165.3	 89.2	 0.0	 13.47	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3728	 1	 67.77	 10.4	 0.0	 7.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3729	 1	 -0.0	 0.0	 0.27075	 43.13435	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	3730	 1	 2.3	 0.8	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3731	 1	 0.0	 -0.0	 0.090774	 3.980444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3732	 1	 -24.87	 -3.7	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3733	 1	 -0.0	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3734	 1	 51.36	 -0.7	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3735	 1	 -0.0	 -0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3736	 1	 45.15	 4.1	 0.0	 2.61	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3737	 1	 42.48	 10.36	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3738	 1	 18.42	 6.0	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3739	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3740	 1	 0.0	 -0.0	 0.0	 13.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3741	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3742	 1	 122.3	 45.9	 0.0	 4.03	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3743	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3744	 1	 93.9	 10.95	 0.0	 4.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3745	 1	 5.51	 2.0	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3746	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3747	 1	 39.44	 5.9	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3748	 1	 194.6	 48.3	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3749	 1	 115.1	 16.4	 0.0	 7.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3750	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3751	 1	 2.5	 0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3752	 1	 7.61	 0.5	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3753	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3754	 1	 -24.93	 11.8	 0.0	 3.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3755	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3756	 1	 35.54	 11.7	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3757	 1	 4.0	 1.3	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3758	 1	 83.49	 17.4	 0.0	 19.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3759	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3760	 1	 163.5	 44.9	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3761	 1	 71.08	 16.2	 0.0	 11.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3762	 1	 338.22	 104.11	 0.0	 91.11	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	3763	 1	 119.1	 61.4	 0.0	 1.9	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3764	 1	 37.84	 23.4	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3765	 1	 18.02	 6.5	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3766	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3767	 1	 33.04	 21.6	 0.0	 26.59	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3768	 1	 19.82	 10.9	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3769	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3770	 1	 27.13	 8.9	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3771	 1	 34.14	 13.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3772	 1	 2.2	 -48.8	 0.0	 39.69	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3773	 1	 0.0	 0.0	 0.0	 30.09	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3774	 1	 -0.0	 0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3775	 1	 55.54	 15.06	 0.0	 6.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3776	 1	 0.0	 -0.0	 0.0	 5.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3777	 1	 77.19	 25.4	 0.0	 4.13	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3778	 1	 -0.0	 0.0	 0.0	 6.96	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3779	 1	 0.0	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3780	 1	 -0.0	 0.0	 0.0	 7.6	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3781	 1	 52.46	 19.0	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3782	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3783	 1	 -0.0	 -0.0	 0.0	 10.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3784	 1	 46.35	 86.9	 0.0	 10.32	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3785	 1	 27.8	 4.0	 0.0	 3.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3786	 1	 -0.0	 -0.0	 0.0	 26.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3787	 1	 80.56	 20.85	 0.0	 10.33	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3788	 1	 23.93	 8.7	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3789	 1	 0.0	 -0.0	 0.0	 9.09	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3790	 1	 -0.0	 -0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	3791	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3792	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3793	 1	 197.7	 67.65	 0.0	 13.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3794	 1	 165.3	 7.4	 0.0	 28.32	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3795	 1	 -0.0	 0.0	 0.0	 0.96	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3796	 1	 2.8	 0.6	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	3798	 1	 -0.0	 0.0	 0.0	 17.64	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3799	 1	 39.0	 5.5	 0.0	 18.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3800	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3801	 1	 -0.0	 -0.0	 0.0	 2.97	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3802	 1	 0.0	 0.0	 0.181549	 6.920889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3803	 1	 23.3	 3.3	 0.0	 9.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3804	 1	 10.11	 5.6	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3805	 1	 8.91	 1.3	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3806	 1	 5.01	 2.0	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	3807	 1	 258.3	 166.0	 0.0	 16.31	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	3809	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3810	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3811	 1	 159.9	 10.6	 0.0	 69.6	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3812	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3813	 1	 226.0	 55.79	 0.0	 18.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3814	 1	 130.5	 24.7	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3815	 1	 16.32	 2.8	 0.0	 1.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3816	 1	 0.0	 -0.0	 0.0	 6.32	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3817	 1	 0.0	 -0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3818	 1	 44.45	 10.9	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3819	 1	 0.0	 -0.0	 0.0	 35.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3820	 1	 5.31	 1.8	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3821	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3822	 1	 -0.0	 -0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3823	 1	 227.6	 37.8	 0.0	 39.33	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3824	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3825	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3826	 1	 0.0	 0.0	 0.0	 9.47	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	3827	 1	 40.5	 5.7	 0.0	 5.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3828	 1	 18.82	 6.8	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3829	 1	 0.0	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3830	 1	 -0.0	 0.0	 0.0	 97.326028	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3831	 1	 74.98	 46.4	 0.0	 2.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3832	 1	 130.1	 19.3	 0.0	 19.24	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3833	 1	 14.22	 6.1	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3834	 1	 160.0	 69.2	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3835	 1	 180.4	 119.2	 0.0	 53.22	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3836	 1	 44.15	 10.6	 0.0	 1.62	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3837	 1	 36.74	 22.7	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3838	 1	 89.1	 27.5	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3839	 1	 28.83	 9.6	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3840	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3841	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3842	 1	 6.41	 2.3	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3843	 1	 123.9	 32.6	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3844	 1	 12.91	 4.7	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3845	 1	 16.7	 2.4	 0.0	 2.73	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3846	 1	 -0.0	 0.0	 0.0	 5.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3847	 1	 6.81	 2.3	 0.0	 1.88	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3848	 1	 123.09	 9.2	 0.0	 0.92	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3849	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3850	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3852	 1	 -0.0	 -0.0	 0.0	 6.39	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3853	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3854	 1	 85.5	 118.1	 0.0	 5.09	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3855	 1	 -38.73	 -15.32	 0.0	 97.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3856	 1	 28.03	 8.8	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3857	 1	 -0.0	 -0.0	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3858	 1	 0.0	 -0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3859	 1	 -0.0	 -0.0	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3860	 1	 0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3861	 1	 -0.58	 -2.28	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3862	 1	 0.0	 0.0	 0.0	 8.07	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3863	 1	 -18.32	 6.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3864	 1	 0.0	 0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3865	 1	 -0.0	 -0.0	 0.0	 2.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3866	 1	 201.06	 19.46	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3867	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3868	 1	 -8.43	 -7.98	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3869	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3870	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3871	 1	 50.06	 23.0	 0.0	 0.24	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3872	 1	 115.3	 16.4	 0.0	 2.45	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3873	 1	 58.97	 18.1	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3874	 1	 51.26	 -17.2	 0.0	 100.22	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3875	 1	 11.61	 4.3	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3876	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3877	 1	 31.74	 3.8	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3878	 1	 -0.0	 -0.0	 0.0	 9.19	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3879	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3880	 1	 -28.13	 -0.82	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3881	 1	 0.0	 0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3882	 1	 56.26	 20.1	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3883	 1	 3.2	 1.2	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3884	 1	 293.0	 -45.9	 0.0	 33.199841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3885	 1	 0.0	 -0.0	 0.381919	 69.809723	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	3886	 1	 94.3	 -27.5	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3887	 1	 -49.05	 1.0	 0.0	 32.5	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	3888	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3889	 1	 -10.41	 3.4	 0.0	 0.99	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3890	 1	 4.61	 1.7	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3891	 1	 0.0	 0.0	 0.0	 7.89	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3892	 1	 19.62	 -3.1	 0.0	 10.98	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3893	 1	 8.91	 5.1	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3894	 1	 0.0	 0.0	 0.0	 4.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3895	 1	 -272.2	 6.6	 0.0	 29.33	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3896	 1	 33.04	 12.1	 0.0	 1.19	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3897	 1	 23.43	 8.4	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3898	 1	 121.5	 29.6	 0.0	 2.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3899	 1	 5.11	 2.3	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3900	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3901	 1	 0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3902	 1	 20.12	 8.6	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3903	 1	 0.0	 0.0	 0.0	 4.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3904	 1	 7.61	 2.5	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3905	 1	 195.3	 87.6	 0.0	 9.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3906	 1	 0.0	 0.0	 0.0	 98.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3907	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3908	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3909	 1	 -0.0	 -0.0	 0.0	 8.16	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3910	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	3911	 1	 -3.3	 -0.7	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3912	 1	 0.0	 -0.0	 0.0	 19.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3913	 1	 143.9	 85.2	 0.0	 3.1	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3914	 1	 16.32	 5.3	 0.0	 1.04	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3915	 1	 0.0	 0.0	 0.086633	 0.534111	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3916	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3917	 1	 20.32	 6.7	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3918	 1	 -11.8	 -5.47	 0.0	 88.050735	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3919	 1	 -0.0	 0.0	 0.0	 39.95	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3920	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	3921	 1	 39.34	 10.3	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3922	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3923	 1	 11.11	 4.0	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3924	 1	 227.4	 40.3	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3925	 1	 89.3	 25.1	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3926	 1	 29.73	 -0.0	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3927	 1	 35.64	 22.0	 0.0	 5.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3928	 1	 105.2	 24.2	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3929	 1	 48.95	 11.6	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3930	 1	 0.0	 0.0	 0.0	 45.86	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	3931	 1	 0.0	 -0.0	 0.0	 14.83	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3932	 1	 -0.0	 0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3933	 1	 37.94	 23.5	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3934	 1	 236.2	 45.1	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3935	 1	 0.0	 -0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3936	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3937	 1	 83.19	 11.4	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3938	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3939	 1	 27.9	 4.0	 0.0	 0.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3940	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	3941	 1	 4.81	 1.3	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3942	 1	 1.1	 -0.0	 0.0	 26.91	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	3943	 1	 90.5	 12.8	 0.0	 7.61	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3944	 1	 -0.0	 0.0	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3945	 1	 0.0	 0.0	 0.0	 9.05	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3946	 1	 71.88	 44.5	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3947	 1	 20.02	 15.0	 0.0	 2.11	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3948	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3949	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3950	 1	 0.4	 0.9	 0.0	 0.38	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3951	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3952	 1	 5.11	 3.8	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3953	 1	 108.31	 14.23	 0.0	 8.47	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3954	 1	 310.8	 162.6	 0.0	 19.47	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3955	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 16	    1.10000	    0.90000;
	3956	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3957	 1	 -0.0	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3958	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3959	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3960	 1	 0.0	 -0.0	 0.0	 5.62	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3961	 1	 42.35	 7.2	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3962	 1	 19.42	 11.8	 0.0	 2.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3963	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3964	 1	 1.3	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3965	 1	 4.2	 0.9	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3966	 1	 220.7	 -14.8	 0.0	 125.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3967	 1	 3.9	 1.4	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3968	 1	 -0.18	 -2.27	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3969	 1	 -0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3970	 1	 5.11	 1.1	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3971	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3972	 1	 419.5	 114.1	 0.0	 55.629522	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3973	 1	 2.51	 -1.64	 0.0	 6.26	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3974	 1	 -0.18	 -1.42	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3975	 1	 148.0	 26.1	 0.0	 9.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3976	 1	 -0.0	 0.0	 0.0	 4.39	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3977	 1	 29.83	 14.4	 0.0	 8.89	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3978	 1	 -0.0	 0.0	 0.0	 28.93	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3979	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3980	 1	 13.9	 1.9	 0.0	 3.72	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3981	 1	 0.0	 -0.0	 0.359411	 37.9409	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	3982	 1	 130.5	 18.6	 0.0	 4.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3984	 1	 33.34	 20.7	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3985	 1	 77.19	 26.5	 0.0	 6.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3986	 1	 14.15	 3.8	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3988	 1	 22.73	 5.8	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	3989	 1	 76.6	 10.9	 0.0	 1.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3990	 1	 7.01	 1.8	 0.0	 35.44	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3991	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3992	 1	 34.64	 21.4	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3993	 1	 -0.0	 -0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3994	 1	 36.34	 10.4	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3995	 1	 -7.91	 2.6	 0.0	 1.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3996	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3997	 1	 26.13	 9.7	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3998	 1	 0.0	 -0.0	 0.0	 0.99	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3999	 1	 110.8	 36.9	 0.0	 23.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4000	 1	 -0.0	 0.0	 0.0	 24.103274	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4001	 1	 18.2	 2.6	 0.0	 6.72	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4002	 1	 88.93	 16.75	 0.0	 6.75	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4003	 1	 0.0	 0.0	 0.0	 10.43	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4004	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4005	 1	 171.18	 28.49	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4006	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4007	 1	 76.6	 10.9	 0.0	 7.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4008	 1	 -0.0	 -0.0	 0.649603	 14.162287	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	4009	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4010	 1	 19.32	 6.0	 0.0	 1.38	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4011	 1	 144.8	 39.7	 0.0	 12.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4012	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4013	 1	 0.0	 -0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4014	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4015	 1	 -0.0	 0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4016	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4017	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 6	    1.10000	    0.90000;
	4018	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4019	 1	 394.9	 -17.3	 0.0	 30.22	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4020	 1	 0.0	 -0.0	 0.0	 14.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4021	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4022	 1	 -0.0	 -0.0	 0.0	 53.04	 0	    1.00000	    0.00000	 380.0	 12	    1.10000	    0.90000;
	4023	 1	 -1270.6	 -476.3	 0.0	 154.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4024	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4025	 1	 0.0	 0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4026	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4027	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4028	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4029	 1	 20.92	 10.3	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4030	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4031	 1	 0.0	 -0.0	 0.0	 6.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4032	 1	 265.7	 113.5	 0.0	 1.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4033	 1	 54.96	 31.7	 0.0	 8.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4034	 1	 24.03	 7.9	 0.0	 1.08	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4035	 1	 58.56	 15.9	 0.0	 3.75	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4036	 1	 -0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4037	 1	 352.6	 193.5	 0.0	 39.3	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4038	 1	 15.52	 4.1	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4039	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4040	 1	 37.24	 40.5	 0.0	 67.07	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4041	 1	 -0.0	 0.0	 0.0	 19.37	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4042	 1	 8.9	 1.3	 0.0	 3.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4043	 1	 76.6	 10.9	 0.0	 3.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4044	 1	 1.9	 0.7	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4045	 1	 0.0	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4046	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	4047	 1	 -0.0	 -0.0	 0.0	 23.74	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4048	 1	 -0.0	 0.0	 0.0	 17.54	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4049	 1	 -0.0	 -0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4050	 1	 -0.0	 -0.0	 0.0	 107.36	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4051	 1	 27.58	 -33.38	 0.0	 13.08	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4052	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4053	 1	 0.0	 -0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4054	 1	 0.0	 -0.0	 0.0	 2.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4055	 1	 347.7	 96.6	 0.0	 101.73	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	4056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4057	 1	 74.78	 -31.4	 0.0	 1.74	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4058	 1	 0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4059	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4060	 1	 -0.0	 0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4061	 1	 0.0	 0.0	 0.0	 5.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4062	 1	 6.31	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4063	 1	 56.53	 15.4	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	4064	 1	 131.35	 63.6	 0.0	 8.55	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4065	 1	 14.72	 5.3	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4066	 1	 111.4	 15.9	 0.0	 1.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4067	 1	 -0.0	 -0.0	 0.0	 3.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4068	 1	 18.22	 2.3	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4069	 1	 7.29	 -0.73	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4070	 1	 35.44	 22.0	 0.0	 0.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4071	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4072	 1	 4.2	 2.0	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4073	 1	 0.0	 -0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4074	 1	 0.0	 -0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	4075	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4076	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	4077	 1	 0.0	 -0.0	 0.0	 23.27	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4078	 1	 8.3	 1.2	 0.0	 1.07	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4079	 1	 0.0	 0.0	 0.16	 31.35	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	4080	 1	 0.0	 -0.0	 0.0	 1.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4081	 1	 -0.0	 -0.0	 0.0	 6.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4082	 1	 -0.0	 0.0	 0.0	 1.14	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4083	 1	 113.0	 57.3	 0.0	 12.82	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4086	 1	 62.7	 9.0	 0.0	 8.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4087	 1	 -0.0	 -0.0	 0.0	 26.36	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4088	 1	 -0.0	 0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4089	 1	 195.2	 92.2	 0.0	 11.67	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4091	 1	 -0.0	 -0.0	 0.0	 28.29	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	4092	 1	 0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4093	 1	 40.24	 24.9	 0.0	 1.81	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4094	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4095	 1	 65.27	 6.0	 0.0	 3.89	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4096	 1	 47.65	 7.1	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4097	 1	 0.0	 0.0	 0.0	 4.05	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4098	 1	 61.67	 28.3	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4099	 1	 173.0	 11.3	 0.0	 8.41	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4100	 1	 -0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4101	 1	 128.0	 72.9	 0.0	 14.95	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4102	 1	 5.31	 2.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4103	 1	 81.09	 12.5	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4104	 1	 40.34	 10.4	 0.0	 7.02	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4105	 1	 0.5	 12.4	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4106	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4107	 1	 -0.0	 -0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4108	 1	 -0.0	 0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4109	 1	 0.0	 -0.0	 0.0	 5.16	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4110	 1	 13.01	 3.8	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4111	 1	 -0.0	 0.0	 0.009025	 43.164575	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	4112	 1	 64.77	 6.4	 0.0	 3.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4113	 1	 -0.0	 0.0	 0.0	 84.33	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4114	 1	 9.91	 5.4	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4115	 1	 -0.0	 0.0	 0.08	 -0.24	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	4116	 1	 2.2	 0.5	 0.0	 2.31	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4117	 1	 -0.0	 0.0	 0.0	 18.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4118	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4119	 1	 0.0	 0.0	 0.0	 19.2	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4120	 1	 -0.54	 -1.0	 0.0	 4.8	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4121	 1	 -0.0	 -0.0	 0.316107	 31.224257	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4122	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4123	 1	 0.0	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4124	 1	 230.42	 -7.87	 0.0	 5.13	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4125	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4126	 1	 0.0	 0.0	 0.0	 1.48	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4127	 1	 39.14	 7.7	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4128	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4129	 1	 -0.02	 -0.51	 0.0	 1.61	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4130	 1	 0.0	 -0.0	 0.0	 2.1	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4131	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4132	 1	 25.43	 7.9	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4133	 1	 145.8	 42.4	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4134	 1	 -0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4135	 1	 52.6	 7.5	 0.0	 3.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4136	 1	 13.31	 4.4	 0.0	 1.51	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4137	 1	 13.64	 9.0	 0.0	 1.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4138	 1	 137.8	 22.9	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4139	 1	 -0.0	 0.0	 0.0	 20.86	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4140	 1	 -0.0	 -0.0	 0.0	 11.85	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4141	 1	 -0.62	 0.0	 0.0	 75.020288	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4142	 1	 -0.0	 0.0	 0.0	 30.64	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4143	 1	 11.11	 4.1	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4144	 1	 310.2	 4.5	 0.0	 8.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4145	 1	 128.18	 35.03	 0.0	 1.76	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4146	 1	 246.9	 20.3	 0.0	 4.52	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4147	 1	 -0.0	 -0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4148	 1	 -13.26	 -7.13	 0.0	 23.16	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4149	 1	 6.71	 1.3	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4150	 1	 1.9	 9.2	 0.0	 7.57	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	4151	 1	 91.4	 -88.2	 0.0	 0.29	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4152	 1	 71.68	 14.8	 0.0	 13.66	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4153	 1	 0.0	 0.0	 0.0	 2.69	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4154	 1	 110.7	 94.3	 0.0	 6.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4155	 1	 15.02	 7.0	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	4156	 1	 0.2	 109.4	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4157	 1	 0.0	 0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4158	 1	 121.4	 40.0	 0.0	 11.16	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4159	 1	 175.2	 70.7	 0.0	 109.1	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4160	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4161	 1	 29.03	 10.1	 0.0	 2.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4162	 1	 0.0	 -0.0	 0.0	 4.37	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	4163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4164	 1	 0.0	 0.0	 0.0	 14.62	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4165	 1	 325.2	 38.1	 0.0	 19.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4166	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4167	 1	 50.86	 -23.0	 0.0	 16.36	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4168	 1	 200.2	 90.6	 0.0	 24.07	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4169	 1	 62.07	 20.0	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4170	 1	 -0.0	 0.0	 0.0	 12.88	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4171	 1	 7.91	 3.8	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4172	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4173	 1	 34.9	 5.0	 0.0	 1.72	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4174	 1	 -0.0	 0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4175	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4176	 1	 144.5	 40.9	 0.0	 17.35	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4177	 1	 20.22	 5.7	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4178	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4180	 1	 -0.0	 -0.0	 0.0	 4.04	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4181	 1	 195.6	 -1.0	 0.0	 3.19	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4182	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4184	 1	 26.73	 9.6	 0.0	 2.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4185	 1	 87.5	 21.3	 0.0	 7.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4186	 1	 -0.0	 0.0	 0.0	 5.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4187	 1	 0.0	 0.0	 0.090774	 6.020444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	4188	 1	 59.17	 19.3	 0.0	 1.16	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4189	 1	 200.65	 30.72	 0.0	 9.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4190	 1	 0.0	 0.0	 0.0	 42.131932	 0	    1.00000	    0.00000	 380.0	 24	    1.10000	    0.90000;
	4191	 1	 12.71	 2.5	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4193	 1	 0.0	 0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4194	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4195	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	4196	 1	 -3.2	 -1.05	 0.0	 48.471563	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4197	 1	 9.01	 4.9	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4198	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4199	 1	 50.3	 7.2	 0.0	 8.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4200	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4201	 1	 318.3	 76.8	 0.146686	 63.265082	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	4202	 1	 53.86	 18.7	 0.0	 3.48	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4203	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4204	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4205	 1	 5.81	 1.7	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4206	 1	 0.0	 -0.0	 0.0	 39.36	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4207	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	4208	 1	 0.0	 0.0	 0.0	 10.1	 0	    1.00000	    0.00000	 380.0	 15	    1.30000	    0.70000;
	4209	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4210	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4211	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4212	 1	 0.0	 0.0	 0.0	 61.61	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4213	 1	 32.34	 14.1	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4214	 1	 -806.3	 -50.1	 0.0	 4.19	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4215	 1	 -0.0	 -0.0	 0.0	 17.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4216	 1	 -0.17	 -8.06	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4217	 1	 -0.0	 -0.0	 0.117325	 64.47707	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4218	 1	 0.0	 0.0	 0.0	 27.56	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4219	 1	 8.41	 2.5	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4220	 1	 27.63	 9.2	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4221	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4222	 1	 -0.66	 -2.79	 0.0	 2.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4223	 1	 0.0	 -0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4224	 1	 -20.56	 -3.88	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4225	 1	 46.8	 6.7	 0.0	 25.55	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4226	 1	 0.0	 0.0	 0.0	 122.87	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4227	 1	 -9.87	 -3.76	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4228	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4229	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	4230	 1	 57.76	 16.0	 0.0	 2.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4231	 3	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4232	 1	 11.01	 3.1	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4233	 1	 -0.0	 0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4234	 1	 0.0	 0.0	 0.0	 8.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4235	 1	 -0.0	 -0.0	 0.0	 12.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4236	 1	 19.52	 6.4	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4237	 1	 -0.0	 0.0	 0.0	 42.02	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4238	 1	 -0.0	 -0.0	 0.0	 8.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4239	 1	 190.7	 52.0	 0.0	 20.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4240	 1	 44.35	 14.8	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4241	 1	 -0.0	 -0.0	 0.0	 93.61	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4242	 1	 269.22	 97.24	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	4243	 1	 188.48	 128.3	 0.0	 18.06	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4244	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	4245	 1	 24.93	 9.6	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4246	 1	 24.23	 5.5	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4247	 1	 33.54	 20.8	 0.0	 2.42	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	4248	 1	 0.0	 -0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	4249	 1	 57.06	 15.6	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4250	 1	 -10.71	 3.5	 0.0	 0.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4251	 1	 47.15	 15.7	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4252	 1	 -0.0	 0.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4253	 1	 105.0	 18.0	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4254	 1	 44.55	 27.6	 0.0	 1.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4255	 1	 2.7	 0.4	 0.0	 4.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4256	 1	 -0.0	 0.0	 0.0	 6.76	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4257	 1	 100.42	 58.37	 0.0	 40.35	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	4258	 1	 9.51	 5.9	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4259	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4260	 1	 0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4261	 1	 0.0	 -0.0	 0.0	 7.91	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4262	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4263	 1	 -11.81	 -4.02	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4264	 1	 0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4265	 1	 -0.0	 -0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4266	 1	 61.4	 8.8	 0.0	 4.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4267	 1	 70.78	 19.6	 0.0	 7.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4268	 1	 303.7	 247.8	 0.0	 8.79	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4269	 1	 24.93	 8.2	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4270	 1	 128.7	 25.6	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4271	 1	 66.97	 45.1	 0.0	 2.04	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4272	 1	 184.7	 71.5	 0.0	 95.42	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4273	 1	 31.94	 10.0	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4274	 1	 35.49	 11.53	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4275	 1	 5.71	 2.1	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4276	 1	 -0.0	 0.0	 0.0	 60.39	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4277	 1	 -0.0	 0.0	 0.0	 1.63	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4279	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4280	 1	 11.91	 4.3	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4281	 1	 -0.0	 -0.0	 0.0	 11.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4282	 1	 22.22	 6.0	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4283	 1	 -0.0	 0.0	 0.0	 8.45	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4284	 1	 214.4	 52.9	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4285	 1	 -0.0	 -0.0	 0.0	 14.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4286	 1	 -253.24	 -29.59	 0.0	 10.61	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4287	 1	 0.5	 0.3	 0.0	 0.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4288	 1	 -0.0	 -0.0	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4289	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4290	 1	 -1.9	 -28.1	 0.0	 100.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4292	 1	 0.0	 -0.0	 0.0	 7.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4293	 1	 80.59	 7.3	 0.0	 18.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4294	 1	 63.87	 55.1	 0.0	 14.84	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4295	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4296	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4297	 1	 26.63	 9.7	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4298	 1	 0.0	 0.0	 0.0	 6.93	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4299	 1	 0.0	 0.0	 0.0	 3.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4300	 1	 81.49	 25.1	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4301	 1	 -0.0	 -0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4302	 1	 30.53	 9.0	 0.0	 1.9	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4303	 1	 90.5	 12.8	 0.0	 15.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4304	 1	 2.4	 0.9	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4305	 1	 0.0	 -0.0	 0.0	 138.24	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4306	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4307	 1	 8.21	 2.7	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4308	 1	 33.5	 4.8	 0.0	 3.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4309	 1	 60.07	 -4.7	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	4310	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	4311	 1	 8.91	 2.5	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4312	 1	 11.41	 -3.7	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4313	 1	 133.4	 29.4	 0.0	 10.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4314	 1	 26.13	 2.7	 0.0	 1.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4315	 1	 -113.33	 45.2	 0.0	 67.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4316	 1	 -9.01	 21.8	 0.0	 4.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4317	 1	 -0.0	 0.0	 0.0	 3.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4318	 1	 51.06	 16.5	 0.0	 2.37	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4319	 1	 55.4	 7.9	 0.0	 0.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4320	 1	 50.35	 24.3	 0.0	 3.64	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	4321	 1	 -0.0	 0.0	 0.0	 28.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4322	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	4323	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	4324	 1	 -0.0	 0.0	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4325	 1	 0.0	 0.0	 0.0	 18.33	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4326	 1	 10.81	 3.6	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4327	 1	 -0.0	 -0.0	 0.054465	 9.927347	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	4328	 1	 0.0	 0.0	 0.0	 1.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4329	 1	 96.2	 37.3	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	4330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4332	 1	 -0.0	 -0.0	 0.0	 7.13	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4333	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4334	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4335	 1	 -0.0	 0.0	 0.135375	 4.892175	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	4336	 1	 55.46	 8.4	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4337	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4339	 1	 -0.0	 -0.0	 0.0	 42.345005	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4340	 1	 -0.0	 -0.0	 0.0	 4.03	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	4341	 1	 18.62	 6.8	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4342	 1	 14.32	 7.2	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4343	 1	 43.55	 14.3	 0.0	 1.63	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4344	 1	 68.48	 -10.6	 0.0	 2.65	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4345	 1	 0.0	 0.0	 0.0	 18.8	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4346	 1	 57.0	 39.9	 0.0	 153.693557	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	4347	 1	 31.2	 4.4	 0.0	 1.61	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4348	 1	 0.0	 -0.0	 0.0	 31.35	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4349	 1	 24.13	 29.4	 0.0	 146.51	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4350	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4351	 1	 0.0	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4352	 1	 163.63	 23.0	 0.0	 5.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4353	 1	 165.8	 44.0	 0.0	 6.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4354	 1	 -0.73	 -1.93	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	4355	 1	 65.07	 15.0	 0.0	 1.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4356	 1	 22.12	 6.5	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4357	 1	 235.0	 58.9	 0.0	 14.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4358	 1	 3.7	 0.6	 0.0	 5.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4359	 1	 5.11	 2.3	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4360	 1	 20.82	 8.2	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4361	 1	 0.0	 -0.0	 0.05	 4.54	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	4362	 1	 43.75	 17.3	 0.0	 7.73	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4363	 1	 0.0	 -0.0	 0.0	 18.66	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4364	 1	 1.3	 -0.0	 0.0	 1.48	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4365	 1	 -13.72	 4.5	 0.0	 0.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4366	 1	 156.9	 122.5	 0.0	 17.71	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4367	 1	 23.23	 7.6	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4368	 1	 90.6	 15.8	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4369	 1	 136.1	 18.8	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4370	 1	 18.9	 2.7	 0.0	 5.84	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4371	 1	 72.28	 6.6	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4372	 1	 2.8	 1.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4373	 1	 28.63	 5.6	 0.0	 1.28	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4374	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4375	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	4376	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4377	 1	 37.6	 5.4	 0.0	 5.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4378	 1	 -0.0	 -0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4379	 1	 0.0	 0.0	 0.0	 9.57	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4380	 1	 -67.31	 -44.04	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4381	 1	 -0.0	 0.0	 0.0	 3.16	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4382	 1	 35.24	 12.7	 0.0	 3.4	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4383	 1	 17.82	 5.9	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4384	 1	 33.74	 11.8	 0.0	 1.66	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	4385	 1	 60.97	 19.7	 0.0	 2.22	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4386	 1	 16.7	 2.4	 0.0	 3.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4387	 1	 10.91	 3.6	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4388	 1	 -0.0	 0.0	 0.26	 6.56	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	4389	 1	 -0.0	 0.0	 0.0	 20.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4390	 1	 -0.0	 0.0	 0.0	 72.64	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4391	 1	 -0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4392	 1	 62.07	 20.7	 0.0	 6.92	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	4393	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4394	 1	 -0.0	 0.0	 0.135375	 53.752175	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	4395	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4396	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 18	    1.30000	    0.70000;
	4397	 1	 193.0	 17.6	 0.0	 4.74	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4398	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4399	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4400	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	4401	 1	 -0.0	 0.0	 0.0	 8.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4402	 1	 -0.0	 0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4403	 1	 35.24	 12.3	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	4404	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4405	 1	 -15.02	 4.9	 0.0	 0.26	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4406	 1	 29.13	 9.6	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4407	 1	 -0.0	 -0.0	 0.0	 51.43	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4408	 1	 11.01	 3.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4409	 1	 -5.15	 -16.03	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4410	 1	 45.05	 13.2	 0.0	 44.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4411	 1	 -0.0	 0.0	 0.0	 6.72	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4412	 1	 19.4	 2.8	 0.0	 2.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4413	 1	 0.0	 0.0	 0.0	 13.44	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4414	 1	 303.6	 47.5	 0.0	 14.96	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4415	 1	 30.03	 9.7	 0.0	 4.1	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4416	 1	 117.4	 12.5	 0.0	 5.16	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4417	 1	 0.0	 -0.0	 0.0	 5.12	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	4418	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4419	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4420	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4421	 1	 32.84	 9.3	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4422	 1	 77.19	 47.8	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4423	 1	 -0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4424	 1	 0.0	 -0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4425	 1	 -0.0	 0.0	 0.0	 3.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4426	 1	 485.5	 -63.38	 0.0	 34.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4427	 1	 296.8	 77.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4428	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4429	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4430	 1	 -0.0	 0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4431	 1	 19.52	 5.6	 0.0	 1.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4432	 1	 -0.0	 0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4433	 1	 142.49	 523.51	 0.0	 34.96	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4434	 1	 60.07	 45.0	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4435	 1	 -0.0	 -0.0	 0.0	 102.217726	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4436	 1	 0.01	 -0.01	 0.0	 420.1	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4437	 1	 0.0	 -0.0	 0.17	 11.68	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	4438	 1	 5.51	 2.0	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4439	 1	 13.82	 4.5	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4441	 1	 1.3	 0.4	 0.0	 1.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4442	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4443	 1	 5.21	 1.0	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4444	 1	 16.52	 4.8	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4445	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4446	 1	 0.0	 -0.0	 0.0	 9.25	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4447	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	4448	 1	 182.18	 36.4	 0.0	 7.79	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4449	 1	 32.8	 4.7	 0.0	 8.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4450	 1	 140.2	 11.2	 0.0	 9.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4451	 1	 8.91	 8.9	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4452	 1	 0.0	 -0.0	 0.0	 0.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4453	 1	 52.6	 110.6	 0.0	 2.72	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4454	 1	 -0.0	 -0.0	 0.0	 1.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4455	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4456	 1	 0.0	 -0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4457	 1	 55.7	 7.9	 0.0	 2.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4458	 1	 413.0	 -353.0	 0.0	 8.88	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4459	 1	 5.5	 0.8	 0.0	 1.57	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4460	 1	 0.0	 0.0	 0.0	 39.29	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	4461	 1	 -0.0	 -0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4462	 1	 22.42	 4.8	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	4463	 1	 0.0	 -0.0	 0.083969	 -0.251906	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	4464	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4465	 1	 15.12	 5.0	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4466	 1	 0.0	 0.0	 0.0	 7.75	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4467	 1	 -0.0	 0.0	 0.0	 7.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4468	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4469	 1	 -0.0	 -0.0	 0.0	 53.34	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4470	 1	 0.0	 -0.0	 0.0	 6.45	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4471	 1	 37.44	 -28.3	 0.0	 9.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4472	 1	 0.0	 -0.0	 0.0	 31.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4473	 1	 0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4474	 1	 0.0	 0.0	 0.0	 9.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4475	 1	 49.45	 30.6	 0.0	 1.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4476	 1	 24.93	 15.4	 0.0	 5.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4477	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4478	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4479	 1	 0.0	 0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4481	 1	 0.0	 0.0	 0.0	 2.7	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4483	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4484	 1	 69.78	 25.0	 0.0	 14.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4485	 1	 0.0	 0.0	 0.0	 18.32	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4487	 1	 -0.0	 0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4488	 1	 71.88	 -2.2	 0.0	 0.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4489	 1	 0.0	 -0.0	 0.0	 5.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4490	 1	 -0.0	 0.0	 0.0	 12.29	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	4491	 1	 0.0	 -0.0	 0.0	 1.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4492	 1	 -0.0	 0.0	 0.0	 18.07	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4493	 1	 15.32	 18.2	 0.0	 27.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4494	 1	 -0.0	 0.0	 0.0	 55.514618	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4495	 1	 336.3	 104.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4496	 1	 0.0	 -0.0	 0.0	 2.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4497	 1	 -0.0	 0.0	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4498	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4499	 1	 80.09	 20.0	 0.0	 6.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4500	 1	 199.3	 53.7	 0.0	 12.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4501	 1	 65.6	 -382.0	 0.218901	 57.448127	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4502	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4503	 1	 20.72	 6.8	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4504	 1	 170.1	 -9.3	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4505	 1	 95.51	 17.1	 0.0	 8.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4506	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4507	 1	 -0.0	 0.0	 0.0	 43.44	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4508	 1	 55.98	 18.47	 0.0	 9.45	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4509	 1	 77.99	 30.8	 0.0	 2.41	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4510	 1	 75.38	 21.8	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4511	 1	 81.89	 19.9	 0.0	 5.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4512	 1	 -0.0	 0.0	 0.0	 12.9	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4513	 1	 92.1	 29.5	 0.0	 3.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4514	 1	 60.9	 8.7	 0.0	 1.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4515	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	4516	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4517	 1	 7.0	 1.0	 0.0	 3.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4518	 1	 12.91	 4.0	 0.0	 1.66	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4519	 1	 97.5	 13.9	 0.0	 29.65	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4520	 1	 -0.0	 -0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4521	 1	 349.6	 22.0	 0.0	 10.29	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4522	 1	 91.1	 36.1	 0.0	 1.01	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4523	 1	 114.2	 16.3	 0.0	 2.85	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4524	 1	 19.4	 2.8	 0.0	 1.61	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4525	 1	 -0.0	 0.0	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4526	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4527	 1	 34.04	 21.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4528	 1	 3.2	 8.3	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4529	 1	 48.48	 8.7	 0.0	 10.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4530	 1	 113.6	 16.2	 0.0	 1.83	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4531	 1	 15.32	 9.5	 0.0	 5.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4532	 1	 5.11	 1.9	 0.0	 2.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4533	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.30000	    0.70000;
	4534	 1	 3.2	 0.4	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4535	 1	 -0.0	 -0.0	 0.174597	 35.618105	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4536	 1	 14.92	 5.4	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4537	 1	 7.71	 1.3	 0.0	 2.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4538	 1	 -14.82	 -5.03	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4539	 1	 -15.88	 -4.9	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4540	 1	 0.0	 -0.0	 0.0	 14.72	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4541	 1	 0.0	 -0.0	 0.0	 150.797812	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4542	 1	 -0.0	 0.0	 0.0	 38.49	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4543	 1	 -0.0	 0.0	 0.0	 2.32	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4544	 1	 -0.0	 -0.0	 0.0	 14.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4545	 1	 21.12	 13.1	 0.0	 0.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4546	 1	 2.8	 0.5	 0.0	 2.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4547	 1	 33.04	 10.9	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4548	 1	 20.02	 9.0	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	4549	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4550	 1	 0.0	 -0.0	 0.0	 124.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4551	 1	 0.0	 0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4552	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4553	 1	 179.8	 76.5	 0.0	 8.05	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4554	 1	 119.0	 21.9	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4555	 1	 48.45	 16.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4556	 1	 138.2	 21.3	 0.0	 2.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4557	 1	 93.0	 66.0	 0.0	 2.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4558	 1	 6.41	 2.3	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4559	 1	 0.0	 -0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	4560	 1	 13.92	 6.3	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4561	 1	 101.0	 20.6	 0.0	 54.5	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4562	 1	 130.5	 25.7	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4563	 1	 -9.87	 -3.77	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4565	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4566	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4567	 1	 92.4	 13.1	 0.0	 98.17	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4568	 1	 0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4569	 1	 -0.0	 -0.0	 0.158724	 -1.020369	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4570	 1	 11.91	 4.3	 0.0	 1.68	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4571	 1	 73.28	 9.4	 0.0	 24.65	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4572	 1	 47.95	 16.3	 0.0	 3.46	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4573	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4574	 1	 -31.26	 -13.2	 0.0	 2.81	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4575	 1	 8.51	 2.8	 0.0	 1.16	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4576	 1	 311.4	 43.0	 0.0	 37.55	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4577	 1	 2.2	 0.6	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4578	 1	 50.66	 56.5	 0.0	 6.86	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4579	 1	 19.52	 6.4	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4580	 1	 11.01	 3.9	 0.0	 7.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4581	 1	 36.28	 -45.18	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4582	 1	 13.9	 1.9	 0.0	 4.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4583	 1	 -0.0	 0.0	 0.0	 2.07	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4584	 1	 -0.0	 0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4585	 1	 -0.0	 -0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4586	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4587	 1	 12.21	 7.9	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4588	 1	 -0.0	 0.0	 0.0	 75.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4589	 1	 5.77	 2.68	 0.0	 1.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4590	 1	 -6.7	 -7.5	 0.0	 1.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4591	 1	 0.0	 0.0	 0.0	 3.16	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4592	 1	 183.8	 2.2	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4593	 1	 20.32	 -24.8	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4594	 1	 -1.73	 -1.71	 0.0	 22.062314	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4595	 1	 84.59	 42.82	 0.0	 0.86	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4596	 1	 4.3	 1.4	 0.0	 1.59	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4597	 1	 -0.0	 -0.0	 0.0	 4.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4598	 1	 -0.0	 0.0	 0.0	 52.958443	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4599	 1	 0.0	 -0.0	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4600	 1	 19.12	 7.4	 0.0	 21.97	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4601	 1	 0.0	 -0.0	 0.0	 37.74	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4602	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	4603	 1	 70.28	 10.3	 0.0	 13.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4604	 1	 0.0	 -0.0	 0.0	 4.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4605	 1	 10.11	 3.7	 0.0	 2.15	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4606	 1	 -0.0	 -0.0	 0.0	 1.69	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4607	 1	 10.11	 0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4608	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4609	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4610	 1	 -0.0	 0.0	 0.0	 16.93	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4611	 1	 0.0	 -0.0	 0.0	 2.72	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4612	 1	 16.52	 5.5	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4613	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4614	 1	 74.18	 14.6	 0.0	 11.71	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4615	 1	 42.55	 17.6	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4616	 1	 30.83	 16.5	 0.0	 3.83	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4617	 1	 64.57	 10.0	 0.0	 4.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4618	 1	 1.9	 0.6	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4619	 1	 74.68	 46.3	 0.0	 4.98	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4620	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.30000	    0.70000;
	4621	 1	 26.03	 16.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4622	 1	 40.04	 15.0	 0.0	 1.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4623	 1	 0.0	 -0.0	 0.0	 80.388213	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4624	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4625	 1	 162.1	 73.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	4626	 1	 44.6	 6.4	 0.0	 2.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4627	 1	 7.0	 1.0	 0.0	 0.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4628	 1	 194.1	 27.6	 0.0	 3.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4629	 1	 16.7	 2.4	 0.0	 14.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4630	 1	 18.2	 2.6	 0.0	 1.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4631	 1	 350.0	 129.4	 0.0	 33.52	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4632	 1	 0.0	 -0.0	 0.0	 3.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4633	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4634	 1	 137.8	 64.5	 0.0	 5.41	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4635	 1	 16.12	 4.3	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	4636	 1	 -0.0	 0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4637	 1	 75.58	 -7.5	 0.0	 8.08	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4638	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	4639	 1	 17.92	 7.2	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4640	 1	 -0.0	 -0.0	 0.0	 1.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4641	 1	 1.7	 0.6	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4642	 1	 -0.0	 -0.0	 0.0	 1.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4643	 1	 3.7	 1.3	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4644	 1	 18.22	 8.6	 0.0	 34.7	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4645	 1	 -0.0	 0.0	 0.305544	 0.218877	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4646	 1	 0.0	 0.0	 0.0	 2.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4647	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4648	 1	 41.75	 13.2	 0.0	 3.36	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4649	 1	 5.01	 2.0	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	4650	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4651	 1	 0.0	 0.0	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4652	 1	 -0.0	 0.0	 0.0	 165.63	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4653	 1	 0.0	 0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4655	 1	 4.61	 1.7	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4656	 1	 93.9	 -0.4	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4657	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4658	 1	 51.06	 7.4	 0.0	 2.49	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4659	 1	 27.13	 16.8	 0.0	 0.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4660	 1	 16.52	 3.2	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4661	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4662	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4663	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4664	 1	 -0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4665	 1	 390.5	 62.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4666	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4667	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4668	 1	 28.03	 10.2	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4669	 1	 11.41	 5.1	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4671	 1	 44.35	 14.8	 0.0	 1.94	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4672	 1	 91.2	 56.1	 0.0	 8.3	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4673	 1	 0.0	 -0.0	 0.0	 1.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4674	 1	 124.0	 29.2	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4675	 1	 0.2	 0.8	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 18	    1.30000	    0.70000;
	4677	 1	 0.0	 0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4678	 1	 25.13	 8.2	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4679	 1	 102.7	 17.8	 0.0	 48.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4680	 1	 344.7	 -31.1	 0.0	 39.129841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4681	 1	 84.09	 1.0	 0.0	 32.3	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	4682	 1	 2.5	 1.3	 0.0	 1.55	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4683	 1	 38.84	 8.5	 0.0	 7.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4684	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4685	 1	 46.15	 11.2	 0.0	 10.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4686	 1	 16.02	 5.1	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4687	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4688	 1	 0.0	 0.0	 0.0	 43.7	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4689	 1	 109.7	 15.0	 0.0	 30.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4690	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4691	 1	 -0.0	 8.3	 0.0	 10.19	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	4692	 1	 -0.0	 0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4693	 1	 29.38	 -14.09	 0.0	 1.33	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4694	 1	 10.81	 3.9	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	4695	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4696	 1	 15.82	 7.2	 0.0	 1.9	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4697	 1	 -0.0	 0.0	 0.147967	 92.214944	 0	    1.00000	    0.00000	 380.0	 18	    1.30000	    0.70000;
	4698	 1	 25.33	 8.8	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4699	 1	 -0.0	 -0.0	 0.0	 3.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4700	 1	 162.0	 83.6	 0.0	 5.32	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4701	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4702	 1	 136.8	 4.8	 0.0	 10.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4703	 1	 19.72	 7.1	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	4704	 1	 0.0	 -0.0	 0.304554	 30.256205	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4705	 1	 19.62	 7.4	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	4706	 1	 0.0	 -0.0	 0.0	 20.81	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4707	 1	 -0.0	 -0.0	 0.0	 1.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4708	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4709	 1	 0.0	 -0.0	 0.0	 27.85	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4710	 1	 195.4	 76.84	 0.0	 8.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4711	 1	 -0.0	 0.0	 0.0	 16.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4712	 1	 -0.0	 0.0	 0.073728	 5.986272	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4713	 1	 14.22	 5.1	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	4714	 1	 -0.0	 0.0	 0.0	 13.16	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4715	 1	 -0.0	 0.0	 0.0	 23.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4716	 1	 392.0	 177.7	 0.181549	 10.880889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	4717	 1	 0.0	 0.0	 0.0	 46.25	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4718	 1	 97.0	 57.4	 0.0	 93.82	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4719	 1	 -2.91	 -0.6	 0.0	 0.02	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4720	 1	 -0.0	 -0.0	 0.0	 4.51	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4721	 1	 0.0	 -0.0	 0.0	 6.11	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4722	 1	 19.4	 2.8	 0.0	 11.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4723	 1	 -0.0	 -0.0	 0.0	 35.78	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4724	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4725	 1	 4.91	 1.6	 0.0	 4.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4726	 1	 47.55	 -1.41	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4727	 1	 2.0	 0.6	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4728	 1	 3.1	 0.1	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4729	 1	 0.0	 0.0	 0.0	 2.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4730	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4731	 1	 -0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4732	 1	 17.7	 -334.5	 0.132526	 55.711068	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4733	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4734	 1	 0.0	 0.0	 0.0	 25.339116	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4735	 1	 0.0	 0.0	 0.0	 13.59	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4736	 1	 0.0	 0.0	 0.099501	 43.903596	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	4737	 1	 277.9	 143.1	 0.0	 0.69	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4738	 1	 101.89	 25.72	 0.0	 5.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4739	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4740	 1	 -0.15	 -0.9	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4741	 1	 10.5	 7.32	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4742	 1	 -0.0	 0.0	 0.0	 2.03	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4743	 1	 13.77	 18.73	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4744	 1	 2.2	 0.0	 0.0	 4.81	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4745	 1	 63.67	 21.3	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4746	 1	 0.0	 0.0	 0.181549	 17.630889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	4747	 1	 93.3	 27.8	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4748	 1	 -0.0	 -0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4749	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4750	 1	 137.7	 32.6	 0.0	 5.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4751	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4752	 1	 101.1	 19.8	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4753	 1	 -0.0	 -0.0	 0.0	 1.4	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4754	 1	 59.17	 14.0	 0.0	 4.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4755	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4756	 1	 10.97	 -6.31	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4757	 1	 147.0	 56.3	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4758	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4759	 1	 45.05	 19.2	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4760	 1	 65.07	 30.0	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	4761	 1	 173.4	 31.0	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4762	 1	 0.0	 0.0	 0.0	 0.65	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	4763	 1	 31.94	 10.5	 0.0	 1.02	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4764	 1	 14.92	 5.1	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4765	 1	 33.04	 10.1	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4766	 1	 -16.84	 -7.96	 0.0	 53.85	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4767	 1	 -0.0	 -0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4768	 1	 13.9	 1.9	 0.0	 3.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4769	 1	 -0.0	 -0.0	 0.0	 25.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4770	 1	 51.86	 19.2	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4771	 1	 0.0	 0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4772	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4773	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4774	 1	 63.27	 28.9	 0.0	 2.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4775	 1	 153.2	 31.5	 0.0	 12.56	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	4776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4777	 1	 97.5	 13.9	 0.0	 1.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4778	 1	 0.0	 -0.0	 0.0	 0.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4779	 1	 0.0	 0.0	 0.0	 3.52	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4780	 1	 2.5	 1.5	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4781	 1	 40.14	 24.9	 0.0	 5.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4782	 1	 21.02	 14.8	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4783	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4784	 1	 69.78	 22.4	 0.0	 2.72	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4785	 1	 -0.0	 -0.0	 0.0	 6.26	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4786	 1	 89.9	 40.2	 0.0	 0.37	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4787	 1	 71.98	 27.1	 0.0	 7.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4788	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	4789	 1	 146.9	 -5.1	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4790	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4791	 1	 9.11	 3.0	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4792	 1	 0.0	 0.0	 0.0	 29.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4793	 1	 336.9	 81.0	 0.0	 19.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4794	 1	 11.41	 3.8	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4795	 1	 0.0	 0.0	 0.0	 81.29	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4796	 1	 -9.6	 -2.5	 0.0	 2.15	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	4797	 1	 -0.01	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4798	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4799	 1	 0.0	 0.0	 0.0	 2.62	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4800	 1	 -0.0	 -0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4801	 1	 -0.0	 0.0	 0.252818	 66.30157	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	4802	 1	 20.12	 4.9	 0.0	 1.61	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4803	 1	 0.0	 -0.0	 0.0	 2.03	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4804	 1	 118.6	 43.4	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4805	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4806	 1	 210.8	 -0.7	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4807	 1	 39.84	 6.4	 0.0	 34.58	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4808	 1	 7.01	 1.0	 0.0	 0.92	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	4809	 1	 151.0	 7.1	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4810	 1	 -0.0	 0.0	 0.07	 3.65	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4811	 1	 -875.4	 -172.2	 0.0	 40.13	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4812	 1	 11.2	 1.6	 0.0	 4.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4813	 1	 141.36	 53.5	 0.0	 2.76	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4814	 1	 41.25	 13.5	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4815	 1	 0.0	 -0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4817	 1	 270.5	 77.8	 0.0	 81.25	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	4818	 1	 110.2	 15.7	 0.0	 2.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4819	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4820	 1	 0.0	 -0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 120.0	 6	    1.10000	    0.90000;
	4821	 1	 0.0	 -0.0	 0.0	 0.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4822	 1	 78.49	 48.6	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4824	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	4825	 1	 -0.0	 0.0	 0.0	 46.7	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4826	 1	 103.6	 16.0	 0.0	 11.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4827	 1	 0.0	 -0.0	 0.0	 3.38	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4828	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4829	 1	 171.9	 39.1	 0.0	 4.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4830	 1	 -0.0	 -0.0	 0.127127	 25.564419	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	4831	 1	 130.4	 44.33	 0.0	 5.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4832	 1	 19.22	 6.4	 0.0	 31.78	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4833	 1	 5.11	 2.5	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4834	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4835	 1	 34.14	 21.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	4836	 1	 -0.0	 -0.0	 0.11	 4.95	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4837	 1	 -10.28	 -2.68	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4838	 1	 19.82	 6.5	 0.0	 1.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4839	 1	 0.01	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4840	 1	 151.1	 66.9	 0.0	 0.41	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4841	 1	 25.23	 15.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4842	 1	 -5.01	 -1.81	 0.0	 15.16	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	4843	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4844	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4845	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4846	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4847	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	4848	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	4849	 1	 0.2	 0.5	 0.684311	 47.304488	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4850	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4851	 1	 2.3	 0.3	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4852	 1	 45.55	 -59.9	 0.0	 30.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4853	 1	 -0.0	 -0.0	 0.0	 12.98	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4854	 1	 -0.0	 -0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4855	 1	 127.9	 -34.0	 0.0	 19.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4856	 1	 45.95	 7.5	 0.0	 8.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4857	 1	 78.69	 19.6	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	4858	 1	 -0.0	 -0.0	 0.0	 53.97	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4859	 1	 261.2	 105.6	 0.0	 28.53	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4860	 1	 0.0	 -0.0	 0.0	 29.32	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4861	 1	 0.0	 -0.0	 0.09	 7.22	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	4862	 1	 -5.88	 -3.76	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4863	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4864	 1	 -28.21	 -6.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4865	 1	 0.0	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4866	 1	 169.0	 56.4	 0.0	 8.06	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4867	 1	 65.77	 27.3	 0.0	 0.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4868	 1	 2.2	 0.5	 0.0	 2.88	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4869	 1	 -0.0	 0.0	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4870	 1	 65.5	 9.3	 0.0	 5.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4871	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	4872	 1	 15.42	 3.9	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4873	 1	 262.6	 31.8	 0.0	 8.13	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4874	 1	 -0.58	 -53.03	 0.0	 6.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4875	 1	 -0.0	 -0.0	 0.0	 2.74	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4876	 1	 230.9	 42.6	 0.0	 12.62	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4877	 1	 0.9	 0.3	 0.0	 1.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4878	 1	 5.11	 1.7	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4879	 1	 0.0	 -0.0	 0.0	 3.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4881	 1	 5.11	 0.0	 0.0	 4.97	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4882	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4883	 1	 0.0	 -0.0	 0.0	 1.26	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4884	 1	 0.0	 0.0	 0.0	 9.77	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4885	 1	 166.4	 50.4	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4886	 1	 -0.0	 0.0	 0.0	 3.08	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4887	 1	 53.56	 33.2	 0.0	 3.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4888	 1	 186.9	 26.6	 0.0	 11.96	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4889	 1	 74.98	 19.8	 0.0	 6.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4890	 1	 185.0	 43.6	 0.0	 6.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4891	 1	 25.1	 3.6	 0.0	 1.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4892	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4893	 1	 -0.0	 -0.0	 0.0	 39.21	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4894	 1	 21.62	 7.8	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 19	    1.30000	    0.70000;
	4895	 1	 -7.61	 2.5	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4896	 1	 329.7	 32.4	 0.0	 4.5	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4897	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4898	 1	 55.7	 7.9	 0.0	 0.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4899	 1	 0.0	 -0.0	 0.12	 12.76	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	4900	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4901	 1	 -0.0	 0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	4902	 1	 1.9	 -0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4903	 1	 -0.0	 -0.0	 0.0	 220.46	 0	    1.00000	    0.00000	 380.0	 18	    1.30000	    0.70000;
	4904	 1	 96.0	 33.3	 0.0	 16.89	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4905	 1	 17.12	 5.6	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4906	 1	 175.8	 70.7	 0.0	 19.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4907	 1	 125.16	 29.2	 0.0	 2.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4908	 1	 50.06	 9.9	 0.0	 11.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4909	 1	 220.6	 83.4	 0.0	 17.73	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	4910	 1	 -0.0	 0.0	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4911	 1	 -0.0	 -0.0	 0.0	 1.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4912	 1	 -0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	4913	 1	 -24.03	 7.9	 0.0	 0.25	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4914	 1	 14.91	 -8.73	 0.0	 34.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4915	 1	 0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4916	 1	 0.0	 -0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4917	 1	 71.6	 10.2	 0.0	 58.47	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4918	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4919	 1	 15.82	 9.8	 0.0	 7.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4920	 1	 -0.0	 0.0	 0.0	 145.62	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4921	 1	 0.0	 -0.0	 0.0	 18.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4922	 1	 0.0	 -0.0	 0.0	 2.57	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4923	 1	 0.0	 0.0	 0.0	 26.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4924	 1	 71.76	 11.37	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	4925	 1	 -0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4926	 1	 3.8	 1.1	 0.0	 10.69	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4927	 1	 46.2	 6.6	 0.0	 1.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4928	 1	 40.04	 10.0	 0.0	 23.59	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4929	 1	 37.0	 8.7	 0.070441	 50.913893	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	4930	 1	 2.5	 1.3	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4931	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4932	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4933	 1	 -19.22	 6.3	 0.0	 1.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4934	 1	 22.42	 7.3	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4935	 1	 -0.0	 0.0	 0.0	 15.76	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	4936	 1	 312.2	 28.0	 0.0	 48.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4937	 1	 11.61	 2.5	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	4938	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	4939	 1	 56.76	 31.1	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4940	 1	 0.0	 0.0	 0.0	 5.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4941	 1	 59.67	 25.6	 0.0	 11.54	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4942	 1	 109.9	 33.6	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4943	 1	 0.0	 -0.0	 0.0	 0.83	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4944	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4945	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4946	 1	 329.7	 220.4	 0.0	 46.92	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4947	 1	 88.3	 2.8	 0.0	 5.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4948	 1	 10.21	 -3.2	 0.0	 5.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4949	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4950	 1	 218.7	 -9.1	 0.0	 49.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4951	 1	 71.98	 34.1	 0.0	 7.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4952	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4953	 1	 66.77	 11.1	 0.0	 2.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4954	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4955	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4956	 1	 0.0	 -0.0	 0.0	 0.99	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4957	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4958	 1	 -0.0	 -0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4959	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4960	 1	 12.91	 7.1	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4961	 1	 62.97	 68.0	 0.0	 13.59	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	4962	 1	 29.13	 18.0	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4963	 1	 -0.0	 -0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4964	 1	 -0.0	 -0.0	 0.0	 29.32	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4965	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4966	 1	 110.7	 78.7	 0.0	 5.27	 0	    1.00000	    0.00000	 220.0	 17	    1.10000	    0.90000;
	4967	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4968	 1	 -0.0	 -0.0	 0.0	 16.57	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4969	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	4970	 1	 -0.0	 -0.0	 0.0	 171.931977	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4971	 1	 130.0	 128.0	 0.0	 7.73	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4972	 1	 13.9	 1.9	 0.0	 4.71	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4973	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4974	 1	 89.08	 26.9	 0.0	 4.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4975	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	4976	 1	 23.43	 7.5	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4977	 1	 -0.0	 -0.0	 0.181549	 24.230889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	4978	 1	 0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4979	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4980	 1	 51.8	 7.4	 0.0	 3.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4981	 1	 -0.0	 0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4982	 1	 4.81	 1.6	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4983	 1	 0.0	 -0.0	 0.0	 16.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4984	 1	 10.11	 1.6	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4985	 1	 32.5	 30.5	 0.0	 265.721081	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	4986	 1	 -22.8	 -16.4	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4987	 1	 -4.66	 1.11	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4988	 1	 11.41	 3.8	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4989	 1	 -4.89	 -2.4	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4990	 1	 0.0	 -0.0	 0.090774	 3.730444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	4991	 1	 501.1	 10.7	 0.0	 18.07	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4992	 1	 58.36	 42.7	 0.0	 1.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4993	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4994	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4995	 1	 190.7	 13.3	 0.0	 4.61	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4996	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4997	 1	 0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	4998	 1	 -0.0	 -0.0	 0.0	 1.433772	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	4999	 1	 73.7	 10.5	 0.0	 4.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5000	 1	 -0.0	 -0.0	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	5001	 1	 82.49	 24.5	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5002	 1	 -0.0	 0.0	 0.0	 4.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5003	 1	 17.87	 -8.59	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5004	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5005	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5006	 1	 -58.77	 18.7	 0.0	 4.23	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5007	 1	 0.0	 0.0	 0.0	 40.291745	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5008	 1	 0.0	 -0.0	 0.0	 23.76	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5009	 1	 0.0	 -0.0	 0.27075	 87.43435	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	5010	 1	 11.2	 1.6	 0.0	 3.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5011	 1	 0.0	 -0.0	 0.0	 11.27	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5012	 1	 5.11	 2.5	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5013	 1	 -0.0	 -0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5014	 1	 70.08	 35.0	 0.0	 1.45	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5015	 1	 27.13	 9.8	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5016	 1	 -0.0	 0.0	 0.0	 8.347383	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5017	 1	 0.1	 -9.6	 0.0	 1.3	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5018	 1	 9.51	 2.8	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5019	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5020	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5021	 1	 0.0	 -0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5022	 1	 38.64	 23.9	 0.0	 0.94	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5023	 1	 -0.0	 0.0	 0.0	 2.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5024	 1	 9.51	 3.1	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5025	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5026	 1	 -0.0	 -0.0	 0.0	 20.11	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5027	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5028	 1	 38.1	 5.5	 0.0	 3.32	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5029	 1	 -12.92	 -1.53	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5030	 1	 30.33	 18.8	 0.0	 1.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5031	 1	 174.7	 35.0	 0.0	 2.14	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5032	 1	 14.32	 4.4	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5033	 1	 18.9	 2.7	 0.0	 2.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5034	 1	 32.24	 4.8	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5035	 1	 -0.0	 -0.0	 0.0	 13.25	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5037	 1	 10.31	 4.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5038	 1	 -0.0	 0.0	 0.0	 2.02	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5039	 1	 20.32	 10.1	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5040	 1	 55.7	 7.9	 0.0	 11.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5041	 1	 0.0	 8.8	 0.0	 18.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5042	 1	 24.33	 10.0	 0.0	 84.57	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	5044	 1	 0.0	 -0.0	 0.0	 12.01	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5045	 1	 11.41	 2.5	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5046	 1	 -0.0	 -0.0	 0.07356	 1.029149	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5047	 1	 4.61	 1.3	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5048	 1	 -0.0	 0.0	 0.0	 9.59	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5049	 1	 136.6	 29.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5050	 1	 0.0	 0.0	 0.181549	 18.620889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5051	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5052	 1	 -0.0	 -0.0	 0.0	 5.173673	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	5053	 1	 43.45	 26.9	 0.0	 6.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5054	 1	 55.16	 19.8	 0.0	 135.46	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5055	 1	 0.0	 0.0	 0.263214	 3.036617	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	5056	 1	 62.7	 9.0	 0.0	 4.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5057	 1	 0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5058	 1	 9.51	 0.5	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5059	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5060	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5061	 1	 205.8	 66.8	 0.0	 3.65	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5062	 1	 160.6	 51.2	 0.0	 46.39	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	5063	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5064	 1	 22.32	 7.3	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5065	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5066	 1	 35.64	 22.0	 0.0	 4.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5067	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5068	 1	 3.8	 1.3	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5069	 1	 -19.07	 -6.06	 0.0	 16.68	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	5070	 1	 50.06	 25.0	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5071	 1	 0.0	 0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5072	 1	 0.0	 0.0	 0.0	 22.93	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	5073	 1	 49.8	 7.1	 0.0	 1.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5074	 1	 5.11	 2.5	 0.0	 1.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5075	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5076	 1	 19.12	 2.8	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5077	 1	 30.93	 5.8	 0.0	 4.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5078	 1	 92.4	 6.3	 0.0	 4.32	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5079	 1	 -0.0	 0.0	 0.0	 49.26	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5080	 1	 0.0	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5081	 1	 3.7	 1.3	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5082	 1	 43.15	 11.1	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5083	 1	 80.39	 10.8	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5084	 1	 0.0	 -0.0	 0.0	 494.41	 0	    1.00000	    0.00000	 750.0	 1	    1.10000	    0.90000;
	5085	 1	 6.61	 3.3	 0.0	 2.67	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5086	 1	 7.41	 2.7	 0.0	 1.08	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5087	 1	 -14.81	 -0.52	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5088	 1	 87.38	 -90.15	 0.0	 16.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5089	 1	 155.25	 23.3	 0.0	 3.74	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5090	 1	 0.0	 -0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5092	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	5093	 1	 70.78	 28.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5094	 1	 -0.0	 -0.0	 0.0	 5.02	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5095	 1	 -0.0	 0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5096	 1	 -2.27	 -1.81	 0.0	 42.76	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5098	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5099	 1	 0.0	 0.0	 0.0	 9.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5100	 1	 117.7	 115.0	 0.0	 12.29	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5101	 1	 -0.0	 0.0	 0.093329	 56.622656	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5102	 1	 99.4	 -347.1	 0.0	 31.86	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5103	 1	 10.81	 1.9	 0.0	 1.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5104	 1	 -0.0	 0.0	 0.0	 9.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5105	 1	 37.0	 5.3	 0.0	 1.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5106	 1	 39.94	 13.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5107	 1	 122.9	 19.3	 0.0	 68.84	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	5108	 1	 -55.83	 -31.99	 0.0	 2.88	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5109	 1	 213.1	 -12.3	 0.0	 30.87	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5110	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5111	 1	 139.9	 1.1	 0.0	 5.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5112	 1	 41.35	 25.6	 0.0	 9.9	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5113	 1	 -0.0	 -0.0	 0.0	 11.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5114	 1	 -0.0	 0.0	 0.0	 3.41	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5115	 1	 2.47	 -0.62	 0.0	 2.54	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5116	 1	 124.9	 77.0	 0.0	 23.05	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5117	 1	 46.25	 13.1	 0.0	 1.29	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5118	 1	 111.4	 15.9	 0.0	 19.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5119	 1	 1.4	 0.5	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5120	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5121	 1	 23.4	 8.38	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5122	 1	 163.1	 23.2	 0.0	 3.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5123	 1	 -15.91	 -6.11	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	5124	 1	 -0.0	 -0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5125	 1	 0.0	 0.0	 0.0	 16.06	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5126	 1	 17.82	 7.3	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5127	 1	 66.47	 22.1	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5128	 1	 20.9	 3.0	 0.0	 3.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5129	 1	 102.3	 14.6	 0.0	 1.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5130	 1	 572.3	 159.7	 0.0	 19.88	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5131	 1	 -0.0	 0.0	 0.0	 7.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5132	 1	 12.31	 3.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5133	 1	 0.0	 0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5135	 1	 0.0	 0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5136	 1	 52.96	 32.8	 0.0	 5.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5137	 1	 16.92	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5139	 1	 24.63	 2.1	 0.0	 1.26	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5140	 1	 26.35	 30.0	 0.0	 1.82	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5141	 1	 18.92	 6.6	 0.0	 1.4	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5142	 1	 0.0	 0.0	 0.0	 15.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5143	 1	 0.0	 -0.0	 0.0	 1.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5144	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5146	 1	 229.9	 48.9	 0.0	 8.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5147	 1	 -0.0	 0.0	 0.0	 17.81	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5148	 1	 139.77	 41.14	 0.0	 15.57	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5149	 1	 0.2	 1.6	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5150	 1	 -0.0	 0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5151	 1	 -0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5152	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5153	 1	 18.52	 6.1	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5154	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5155	 1	 411.3	 168.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5156	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5157	 1	 -0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5159	 1	 21.12	 7.7	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5160	 1	 -0.0	 -0.0	 0.094757	 -0.276956	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	5161	 1	 0.0	 -0.0	 0.0	 6.89	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	5162	 1	 55.26	 0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5163	 1	 -11.81	 -12.0	 0.0	 19.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5164	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5165	 1	 -0.0	 -0.0	 0.0	 35.06	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5166	 1	 0.0	 -0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5167	 1	 12.01	 0.7	 0.0	 0.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5168	 1	 -0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5169	 1	 0.0	 0.0	 0.0	 30.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5170	 1	 0.0	 0.0	 0.0	 19.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5171	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5172	 1	 3.0	 1.7	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	5173	 1	 -0.0	 -0.0	 0.0	 1.41	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5174	 1	 0.0	 -0.0	 0.0	 8.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5175	 1	 -0.0	 -0.0	 0.087808	 3.044992	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5176	 1	 1.9	 0.7	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5177	 1	 0.0	 0.0	 0.44806	 95.507515	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	5178	 1	 90.2	 5.8	 0.0	 18.69	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5179	 1	 179.8	 5.67	 0.0	 12.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5180	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5181	 1	 45.05	 15.3	 0.0	 12.29	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5182	 1	 0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5183	 1	 0.0	 0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5184	 1	 0.0	 0.2	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5185	 1	 0.0	 0.0	 0.090774	 3.340444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5186	 1	 36.34	 22.5	 0.0	 2.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5187	 1	 10.8	 1.6	 0.0	 2.88	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5188	 1	 107.9	 17.6	 0.0	 1.03	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5189	 1	 24.33	 5.8	 0.0	 13.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5190	 1	 0.0	 0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5191	 1	 67.98	 9.2	 0.0	 7.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5193	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5194	 1	 102.7	 39.0	 0.0	 135.53	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5195	 1	 33.24	 11.1	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5196	 1	 7.01	 2.3	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5197	 1	 35.14	 12.6	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5198	 1	 7.41	 2.7	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5199	 1	 76.08	 17.1	 0.0	 5.78	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	5200	 1	 214.8	 30.6	 0.0	 3.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5201	 1	 35.94	 26.0	 0.0	 8.07	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5202	 1	 85.09	 13.4	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5203	 1	 221.9	 86.3	 0.0	 2.18	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5204	 1	 18.8	 2.7	 0.0	 0.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5205	 1	 -0.0	 -0.0	 0.0	 2.84	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5206	 1	 -0.0	 -0.0	 0.0	 4.99	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5207	 1	 11.71	 3.9	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5208	 1	 41.65	 13.6	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5209	 1	 158.79	 39.45	 0.0	 63.31	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	5210	 1	 347.61	 74.37	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	5211	 1	 0.0	 -0.0	 0.0	 18.22	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5212	 1	 -0.0	 0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5213	 1	 246.8	 36.3	 0.0	 16.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5214	 1	 0.0	 -0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5215	 1	 -0.0	 -0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5216	 1	 0.0	 -0.0	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5217	 1	 12.11	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5218	 1	 68.68	 21.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5219	 1	 23.03	 8.3	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5220	 1	 58.5	 8.3	 0.0	 4.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5221	 1	 0.0	 -0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5222	 1	 13.9	 1.9	 0.0	 3.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5223	 1	 4.61	 1.7	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5224	 1	 27.73	 17.2	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5226	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	5227	 1	 1.9	 1.4	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5228	 1	 44.95	 18.7	 0.0	 5.36	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5229	 1	 -0.0	 0.0	 0.0	 50.54	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	5230	 1	 102.3	 14.5	 0.0	 22.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5231	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5232	 1	 53.46	 15.4	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5233	 1	 -0.0	 -0.0	 0.0	 14.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5234	 1	 264.3	 111.6	 0.0	 34.93	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5235	 1	 14.22	 4.7	 0.0	 2.05	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5236	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5238	 1	 30.03	 10.0	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5239	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5240	 1	 27.6	 4.0	 0.0	 6.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5241	 1	 0.0	 -0.0	 0.0	 70.905048	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5242	 1	 0.0	 0.0	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5243	 1	 -0.0	 -0.0	 0.0	 29.01	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5244	 1	 20.9	 3.0	 0.0	 3.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5245	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5246	 1	 0.0	 -0.0	 0.0	 1.06	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5247	 1	 0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5248	 1	 4.0	 0.1	 0.0	 0.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5249	 1	 -4.88	 -2.79	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5250	 1	 101.2	 48.9	 0.0	 7.78	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5251	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5252	 1	 0.0	 -0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5253	 1	 69.18	 38.1	 0.0	 28.66	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5254	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5255	 1	 43.95	 8.5	 0.0	 29.29	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5256	 1	 91.0	 36.0	 0.0	 5.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5257	 1	 -0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5258	 1	 -0.0	 -0.0	 0.0	 14.79	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5259	 1	 -17.8	 -3.78	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5260	 1	 0.0	 0.0	 0.0	 2.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5261	 1	 77.0	 -239.9	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5262	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	5263	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	5264	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5265	 1	 18.12	 11.2	 0.0	 2.96	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5266	 1	 2.2	 0.5	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5267	 1	 72.18	 44.7	 0.0	 2.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5268	 1	 66.97	 41.5	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5269	 1	 40.44	 13.3	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5270	 1	 -0.0	 -0.0	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5271	 1	 69.18	 19.7	 0.0	 6.99	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5272	 1	 -0.0	 -0.0	 0.0	 8.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5273	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5274	 1	 2.2	 0.5	 0.0	 1.84	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5275	 1	 66.47	 14.14	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5276	 1	 143.2	 5.9	 0.0	 5.79	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5277	 1	 78.5	 11.2	 0.0	 1.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5279	 1	 158.8	 105.3	 0.0	 21.76	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5280	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5281	 1	 19.82	 12.3	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5282	 1	 63.5	 9.1	 0.0	 51.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5283	 1	 13.92	 6.9	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5284	 1	 0.0	 -0.0	 0.0	 26.46055	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	5285	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	5286	 1	 17.22	 5.1	 0.0	 0.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5287	 1	 7.0	 1.0	 0.0	 8.71	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5288	 1	 -0.0	 -0.0	 0.0	 3.06	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5289	 1	 -0.0	 -0.0	 0.0	 165.34	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5290	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5291	 1	 25.0	 3.6	 0.0	 1.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5292	 1	 -0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5293	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5294	 1	 31.2	 4.4	 0.0	 0.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5295	 1	 -0.0	 -0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5296	 1	 16.02	 4.7	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5297	 1	 55.26	 11.0	 0.0	 7.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5298	 1	 0.0	 -0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5299	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5300	 1	 -0.0	 -0.0	 0.0	 1.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5301	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5302	 1	 267.1	 57.4	 0.0	 13.64	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5303	 1	 40.05	 20.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5304	 1	 -0.0	 0.0	 0.0	 4.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5305	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5306	 1	 -0.47	 0.1	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5307	 1	 -0.0	 0.0	 0.0	 6.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5308	 1	 0.0	 -0.0	 0.0	 42.19206	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5309	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5310	 1	 97.06	 -0.33	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5311	 1	 -0.0	 -0.0	 0.0	 7.85	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5312	 1	 59.87	 19.9	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5313	 1	 15.22	 2.5	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5314	 1	 0.0	 0.0	 0.0	 29.25	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5315	 1	 0.0	 -0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5316	 1	 -0.0	 -0.0	 0.0	 30.04	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5317	 1	 293.2	 87.4	 0.0	 26.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5318	 1	 46.95	 54.6	 0.0	 29.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5319	 1	 21.12	 7.7	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5320	 1	 18.12	 5.9	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5321	 1	 185.2	 26.4	 0.0	 12.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5322	 1	 41.2	 56.52	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5323	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5324	 1	 0.0	 0.0	 0.0	 15.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5325	 1	 46.55	 -18.9	 0.0	 14.78	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5326	 1	 42.45	 -10.2	 0.0	 10.02	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	5327	 1	 -0.0	 -0.0	 0.225625	 26.287525	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	5328	 1	 288.7	 117.3	 0.0	 183.57	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5330	 1	 -12.61	 4.1	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5331	 1	 -0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5332	 1	 366.6	 57.4	 0.0	 60.78	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5333	 1	 83.59	 -7.2	 0.0	 12.95	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5334	 1	 17.52	 6.6	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5335	 1	 1.6	 0.8	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5336	 1	 -0.0	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5337	 1	 0.0	 0.0	 0.090774	 1.480444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5338	 1	 19.4	 2.8	 0.0	 4.73	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5339	 1	 -16.62	 8.7	 0.0	 7.68	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5340	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5341	 1	 64.27	 17.5	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5342	 1	 32.14	 13.1	 0.0	 1.72	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5343	 1	 -0.0	 -0.0	 0.0	 142.05	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	5344	 1	 21.72	 7.2	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5345	 1	 0.0	 0.0	 0.0	 3.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5346	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5347	 1	 8.71	 2.5	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5348	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5349	 1	 5.5	 0.8	 0.0	 7.28	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5350	 1	 0.0	 0.0	 0.0	 28.208233	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5351	 1	 0.0	 0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5353	 1	 0.0	 -0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	5354	 1	 70.18	 19.5	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5355	 1	 229.0	 77.1	 0.0	 36.732397	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5356	 1	 7.0	 1.0	 0.0	 4.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5357	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5358	 1	 0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5359	 1	 0.0	 -0.0	 0.0	 1.54	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	5360	 1	 173.6	 105.6	 0.0	 21.26	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5361	 1	 -0.0	 0.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5362	 1	 152.73	 -17.2	 0.0	 45.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5363	 1	 79.79	 49.4	 0.0	 2.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5364	 1	 110.6	 38.1	 0.0	 0.98	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5365	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5366	 1	 66.07	 12.5	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5367	 1	 40.5	 5.7	 0.0	 5.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5370	 1	 13.92	 4.1	 0.0	 2.27	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5371	 1	 -13.32	 20.6	 0.0	 1.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5372	 1	 21.02	 8.0	 0.0	 13.14	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5373	 1	 -8.71	 2.9	 0.0	 0.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5374	 1	 13.2	 3.25	 0.0	 5.66	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5375	 1	 48.8	 6.9	 0.0	 1.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5376	 1	 408.3	 84.5	 0.0	 18.02	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5377	 1	 -0.0	 -0.0	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5378	 1	 13.21	 4.4	 0.0	 0.86	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5379	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	5380	 1	 127.3	 90.5	 0.0	 6.8	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5381	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5382	 1	 0.8	 0.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5383	 1	 0.0	 -0.0	 0.0	 24.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5384	 1	 48.05	 28.8	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5385	 1	 0.0	 0.0	 0.0	 17.83	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5386	 1	 243.45	 104.28	 0.0	 4.66	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5387	 1	 37.94	 51.4	 0.0	 0.55	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5388	 1	 159.5	 42.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5389	 1	 0.0	 -0.0	 0.0	 55.700331	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	5390	 1	 0.0	 -0.0	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5391	 1	 57.06	 11.9	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5392	 1	 -0.0	 0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5393	 1	 -0.0	 0.0	 0.0	 9.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5394	 1	 0.0	 0.0	 0.0	 2.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5395	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5396	 1	 -0.0	 -0.0	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5397	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5398	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5399	 1	 20.9	 3.0	 0.0	 2.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5400	 1	 241.62	 52.78	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5401	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5402	 1	 54.76	 33.9	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5403	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5404	 1	 5.21	 1.7	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5405	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5406	 1	 0.0	 -0.0	 0.0	 36.42	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	5407	 1	 6.61	 2.4	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5408	 1	 11.91	 4.3	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5410	 1	 69.78	 26.0	 0.0	 5.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5411	 1	 -0.0	 -0.0	 0.0	 3.79	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5412	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	5413	 1	 -0.0	 -0.0	 0.0	 5.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5414	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5415	 1	 -0.0	 0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5416	 1	 0.0	 0.0	 0.0	 25.13	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5417	 1	 32.74	 5.3	 0.0	 3.07	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5418	 1	 -0.0	 0.0	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5419	 1	 349.3	 144.3	 0.0	 0.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5420	 1	 56.96	 1.94	 0.0	 26.48	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5421	 1	 -0.0	 -0.0	 0.0	 0.92	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5422	 1	 104.5	 14.9	 0.0	 0.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5423	 1	 28.63	 7.3	 0.0	 4.36	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5424	 1	 0.0	 0.0	 0.0	 2.04	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5425	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5426	 1	 152.8	 38.0	 0.0	 1.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5427	 1	 233.8	 33.4	 0.0	 1.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5428	 1	 53.36	 44.2	 0.0	 22.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5429	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5430	 1	 26.4	 3.8	 0.0	 9.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5431	 1	 58.5	 8.3	 0.0	 1.2	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5432	 1	 -0.0	 -0.0	 0.0	 106.24	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5433	 1	 121.6	 49.3	 0.0	 10.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5434	 1	 69.5	 9.8	 0.0	 1.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5435	 1	 103.3	 24.1	 0.0	 9.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5436	 1	 -4.86	 -2.12	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5437	 1	 -0.0	 0.0	 0.0	 11.59	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5438	 1	 104.7	 -12.8	 0.0	 2.25	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5439	 1	 -0.0	 0.0	 0.0	 2.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5440	 1	 116.4	 -8.8	 0.0	 8.39	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5441	 1	 138.01	 34.55	 0.0	 8.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5442	 1	 -0.17	 -0.84	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5443	 1	 2.8	 1.0	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5444	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5445	 1	 45.45	 7.1	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	5446	 1	 -0.0	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5447	 1	 3.33	 2.95	 0.0	 1.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5448	 1	 -0.0	 -0.0	 0.0	 1.06	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	5449	 1	 27.9	 4.0	 0.0	 4.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5450	 1	 -0.0	 -0.0	 0.0	 1.17	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5451	 1	 -0.0	 -0.0	 0.0	 1.82	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5452	 1	 82.09	 39.8	 0.0	 2.35	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5453	 1	 45.58	 -1.95	 0.0	 1.8	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5454	 1	 0.0	 -0.0	 0.0	 1.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5455	 1	 -0.0	 -0.0	 0.0	 5.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5456	 1	 0.0	 -0.0	 0.0	 1.84	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5457	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5458	 1	 0.0	 0.0	 0.0	 9.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5459	 1	 211.3	 69.3	 0.0	 7.96	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5460	 1	 -15.89	 -6.42	 0.0	 38.657071	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5461	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5462	 1	 114.42	 23.58	 0.0	 46.99	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	5463	 1	 88.4	 -5.9	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5464	 1	 25.23	 3.3	 0.0	 35.45	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5465	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5466	 1	 67.5	 9.6	 0.0	 26.5	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5467	 1	 1.0	 0.3	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5468	 1	 110.0	 6.83	 0.0	 13.51	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	5469	 1	 106.6	 -18.8	 0.0	 4.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5470	 1	 3.3	 1.1	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5471	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5472	 1	 1.3	 0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5473	 1	 -0.0	 0.0	 0.0	 4.42	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5474	 1	 8.91	 2.5	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5475	 1	 1.0	 1.0	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	5476	 1	 0.0	 0.0	 0.0	 90.33	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5477	 1	 -0.0	 -0.0	 0.0	 18.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5478	 1	 -0.0	 0.0	 0.0	 91.78	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5479	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	5480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	5481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5483	 1	 144.0	 56.6	 0.0	 5.61	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5484	 1	 0.0	 0.0	 0.0	 30.55	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	5485	 1	 -0.0	 0.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5487	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5488	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5489	 1	 11.81	 2.4	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5490	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5491	 1	 0.0	 -0.0	 0.505613	 83.804783	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5492	 1	 -0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5493	 1	 0.0	 0.0	 0.0	 3.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5494	 1	 0.0	 -0.0	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5495	 1	 195.74	 -32.87	 0.0	 0.83	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5496	 1	 1.63	 8.8	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5497	 1	 0.0	 0.0	 0.252685	 6.907589	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	5498	 1	 574.3	 94.6	 0.0	 16.63	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5499	 1	 20.12	 7.9	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5500	 1	 111.5	 24.8	 0.0	 9.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5501	 1	 -0.0	 0.0	 0.0	 16.84	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	5502	 1	 -0.0	 -0.0	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5503	 1	 342.7	 82.2	 0.0	 75.02	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	5504	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5505	 1	 92.59	 8.37	 0.0	 16.58	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	5506	 1	 29.53	 25.1	 0.0	 0.8	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	5507	 1	 17.62	 7.7	 0.0	 10.73	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5508	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5509	 1	 0.0	 0.0	 0.314057	 17.296509	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5510	 1	 499.0	 191.1	 0.0	 60.73	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5511	 1	 67.68	 6.2	 0.0	 6.83	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5512	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5513	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5514	 1	 0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5515	 1	 22.12	 8.0	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5516	 1	 18.22	 6.0	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5517	 1	 34.24	 -19.6	 0.0	 3.59	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5518	 1	 4.4	 2.2	 0.0	 1.19	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5519	 1	 0.0	 -0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5520	 1	 55.7	 7.9	 0.0	 0.76	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5521	 1	 30.43	 10.1	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5522	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5523	 1	 150.2	 25.5	 0.0	 42.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5524	 1	 14.52	 5.3	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5525	 1	 236.33	 59.35	 0.0	 18.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5526	 1	 -8.71	 -19.54	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5527	 1	 -0.0	 -0.0	 0.0	 58.79	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	5528	 1	 93.6	 77.1	 0.0	 91.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5529	 1	 0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5530	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5531	 1	 -0.0	 -0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5532	 1	 -0.0	 0.0	 0.0	 53.24	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5533	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5534	 1	 -0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5535	 1	 68.08	 42.2	 0.0	 4.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5536	 1	 85.8	 12.2	 0.0	 1.7	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5537	 1	 -0.53	 -0.91	 0.090774	 7.680444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5538	 1	 91.9	 13.1	 0.0	 7.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5539	 1	 12.21	 4.4	 0.0	 2.77	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5540	 1	 0.0	 -0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5541	 1	 11.71	 2.2	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	5542	 1	 6.71	 3.0	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5543	 1	 0.0	 -0.0	 0.0	 7.08	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5544	 1	 47.65	 29.5	 0.0	 4.19	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	5545	 1	 33.04	 8.1	 0.0	 1.55	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5546	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5547	 1	 10.01	 3.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5548	 1	 -0.94	 -6.39	 0.0	 1.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5549	 1	 30.03	 12.2	 0.0	 0.93	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5550	 1	 0.0	 -0.0	 0.0	 10.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5551	 1	 15.12	 5.0	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5552	 1	 23.93	 8.7	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5553	 1	 2.22	 7.8	 0.0	 19.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5554	 1	 50.26	 16.5	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5555	 1	 0.0	 -0.0	 0.0	 17.79	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5556	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5557	 1	 21.22	 6.7	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5558	 1	 -0.0	 -0.0	 0.0	 15.17	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5559	 1	 0.0	 -0.0	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5560	 1	 0.0	 -0.0	 0.0	 1.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5561	 1	 31.13	 12.0	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5562	 1	 -0.0	 0.0	 0.19855	 29.549	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	5563	 1	 21.62	 7.8	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5565	 1	 5.11	 1.8	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5566	 1	 -0.0	 0.0	 0.0	 1.59	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5567	 1	 0.0	 0.0	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5568	 1	 -0.0	 -0.0	 0.0	 6.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5569	 1	 -0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5570	 1	 23.53	 8.5	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5571	 1	 -0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5572	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5573	 1	 0.0	 -0.0	 0.0	 2.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5574	 1	 99.7	 6.0	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5575	 1	 -0.0	 0.0	 0.0	 59.52	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5576	 1	 220.0	 68.3	 0.0	 3.09	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5577	 1	 0.0	 -0.0	 0.0	 19.73	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5578	 1	 26.63	 8.6	 0.0	 4.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5579	 1	 16.22	 5.3	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5580	 1	 130.7	 89.1	 0.0	 0.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5581	 1	 0.0	 0.0	 0.0	 88.66	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5582	 1	 3.2	 1.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5583	 1	 1.9	 0.7	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5584	 1	 -0.19	 -14.8	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5585	 1	 0.0	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5586	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5587	 1	 -0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5588	 1	 0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5589	 1	 0.0	 0.0	 0.0	 173.904854	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5590	 1	 55.4	 7.9	 0.0	 6.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5591	 1	 118.6	 41.5	 0.0	 0.58	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5592	 1	 20.82	 7.9	 0.0	 18.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5593	 1	 19.52	 7.0	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5594	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	5595	 1	 168.5	 54.8	 0.0	 5.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5596	 1	 172.8	 11.3	 0.0	 8.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5597	 1	 72.0	 10.3	 0.0	 5.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5598	 1	 -0.0	 0.0	 0.0	 14.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5599	 1	 8.3	 1.2	 0.0	 4.2	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5600	 1	 -0.0	 -0.0	 0.062219	 7.992656	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5601	 1	 0.0	 0.0	 0.0	 12.61	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5602	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5603	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5604	 1	 83.4	 11.9	 0.0	 1.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5605	 1	 -0.0	 0.0	 0.0	 20.96	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5606	 1	 -0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5607	 1	 34.14	 12.4	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5608	 1	 449.4	 14.6	 0.0	 87.31	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5609	 1	 23.31	 -6.67	 0.0	 2.15	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5610	 1	 99.5	 9.2	 0.0	 27.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5611	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5612	 1	 22.4	 3.1	 0.0	 3.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5613	 1	 76.6	 10.9	 0.0	 3.49	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5614	 1	 0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5615	 1	 48.8	 6.9	 0.0	 6.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5616	 1	 225.2	 35.2	 0.0	 11.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5617	 1	 38.04	 3.4	 0.0	 3.43	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5618	 1	 -0.0	 0.0	 0.0	 1.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5619	 1	 -0.0	 -0.0	 0.181549	 16.110889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5620	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	5621	 1	 6.51	 3.7	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5622	 1	 158.3	 -20.5	 0.0	 2.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5623	 1	 513.4	 199.8	 0.0	 90.272366	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5624	 1	 152.7	 6.0	 0.0	 0.36	 0	    1.00000	    0.00000	 120.0	 20	    1.10000	    0.90000;
	5625	 1	 0.0	 0.0	 0.0	 80.0	 0	    1.00000	    0.00000	 380.0	 12	    1.10000	    0.90000;
	5626	 1	 13.72	 4.7	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5627	 1	 -0.0	 -0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5628	 1	 -4.43	 -3.56	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5629	 1	 0.0	 -0.0	 0.0	 1.36	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5630	 1	 0.0	 0.0	 0.0	 11.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5631	 1	 105.5	 31.1	 0.0	 9.63	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5632	 1	 27.46	 5.87	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5633	 1	 29.13	 13.5	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5634	 1	 21.12	 13.1	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5635	 1	 0.0	 0.0	 0.0	 13.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5636	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5637	 1	 1.38	 -1.15	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5638	 1	 0.0	 -0.0	 0.0	 4.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5639	 1	 -0.0	 0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5640	 1	 64.33	 -57.14	 0.0	 8.9	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5641	 1	 -0.0	 -0.0	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5642	 1	 72.78	 45.1	 0.0	 11.93	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5643	 1	 -0.0	 -0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5644	 1	 45.05	 40.0	 0.0	 1.79	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5645	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5646	 1	 20.02	 8.5	 0.0	 1.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5647	 1	 6.31	 2.5	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5648	 1	 -0.0	 -0.0	 0.0	 115.528858	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5649	 1	 55.7	 7.9	 0.0	 5.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5650	 1	 -0.0	 -0.0	 0.0	 18.66	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5651	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5652	 1	 45.05	 5.0	 0.0	 33.8	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	5653	 1	 96.59	 7.28	 0.0	 2.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5654	 1	 -0.14	 -1.51	 0.0	 1.85	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5655	 1	 -0.21	 -1.04	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5657	 1	 0.0	 0.0	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	5658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5659	 1	 -27.43	 9.0	 0.0	 0.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5660	 1	 30.03	 9.9	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5661	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5662	 1	 185.7	 18.4	 0.0	 23.68	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5663	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5664	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5665	 1	 -0.0	 -0.0	 0.0	 6.53	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5666	 1	 124.8	 34.7	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5667	 1	 75.2	 10.7	 0.0	 3.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5668	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5669	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5671	 1	 25.03	 1.4	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5672	 1	 139.7	 9.7	 0.0	 12.61	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5673	 1	 67.27	 1.5	 0.0	 16.46	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5674	 1	 0.0	 0.0	 0.0	 41.27	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5675	 1	 54.96	 17.6	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5676	 1	 6.21	 2.2	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5677	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5678	 1	 25.13	 8.8	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5679	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5680	 1	 153.5	 46.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5681	 1	 198.1	 33.9	 0.0	 22.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5682	 1	 -0.0	 0.0	 0.0	 6.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5683	 1	 -0.0	 -0.0	 0.0	 64.07	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5684	 1	 0.0	 -0.0	 0.0	 71.79	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	5685	 1	 34.74	 16.3	 0.0	 33.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5686	 1	 52.26	 19.6	 0.0	 2.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5687	 1	 19.12	 11.9	 0.0	 1.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5688	 1	 14.12	 5.2	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5689	 1	 41.8	 5.9	 0.0	 5.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5690	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5691	 1	 195.1	 -14.2	 0.0	 12.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5692	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5693	 1	 -0.0	 -0.0	 0.0	 6.13	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5694	 1	 40.24	 14.4	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5695	 1	 142.8	 20.3	 0.0	 6.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5696	 1	 45.35	 28.1	 0.0	 1.9	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5697	 1	 131.6	 33.8	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5698	 1	 11.81	 4.2	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5699	 1	 -0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5700	 1	 31.94	 4.4	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5701	 1	 20.9	 3.0	 0.0	 5.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5702	 1	 -0.0	 -0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	5703	 1	 29.03	 18.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5704	 1	 119.6	 10.6	 0.0	 0.9	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5705	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 6	    1.10000	    0.90000;
	5706	 1	 32.24	 11.7	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5707	 1	 -0.0	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5708	 1	 30.5	 4.3	 0.0	 2.99	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5709	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5710	 1	 0.4	 0.3	 0.0	 1.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5711	 1	 0.0	 -0.0	 0.0	 32.63	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5712	 1	 183.07	 44.65	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5713	 1	 20.72	 -2.5	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5714	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5715	 1	 89.51	 -12.51	 0.0	 7.04	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5716	 1	 -0.0	 -0.0	 0.0	 21.85	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5717	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5718	 1	 -0.0	 0.0	 0.0	 5.05	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	5719	 1	 -0.0	 -0.0	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5720	 1	 337.6	 -15.4	 0.0	 6.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5722	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5723	 1	 141.2	 45.4	 0.0	 7.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5724	 1	 20.12	 8.6	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5725	 1	 19.42	 6.3	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5726	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5727	 1	 42.45	 14.0	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5728	 1	 4.61	 0.9	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5729	 1	 -0.0	 -0.0	 0.0	 1.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5730	 1	 0.0	 0.0	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5731	 1	 0.0	 0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	5732	 1	 37.14	 4.02	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5733	 1	 0.0	 0.0	 0.0	 42.8	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	5734	 1	 34.9	 5.0	 0.0	 5.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5735	 1	 161.3	 10.04	 0.0	 4.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5736	 1	 15.32	 3.5	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5737	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5738	 1	 -0.0	 -0.0	 0.0	 8.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5739	 1	 0.0	 0.0	 0.0	 2.69	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5740	 1	 -0.0	 0.0	 0.0	 1.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5741	 1	 38.64	 13.8	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5742	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5743	 1	 -0.0	 0.0	 0.0	 4.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5744	 1	 0.0	 0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5745	 1	 13.72	 4.5	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5746	 1	 71.98	 28.8	 0.0	 4.88	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5747	 1	 371.2	 73.5	 0.0	 39.869841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5748	 1	 -0.0	 -0.0	 0.0	 4.27	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5749	 1	 -928.0	 -491.4	 0.0	 0.73	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5750	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5751	 1	 175.6	 25.0	 0.0	 20.78	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5752	 1	 52.96	 50.3	 0.0	 0.71	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5753	 1	 -0.0	 -0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5754	 1	 222.6	 62.6	 0.0	 30.19	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5755	 1	 -0.0	 -0.0	 0.0	 5.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5756	 1	 16.7	 2.4	 0.0	 3.27	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5757	 1	 210.7	 30.0	 0.0	 116.98	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5758	 1	 0.0	 0.0	 0.0	 9.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5759	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	5760	 1	 0.0	 -0.0	 0.0	 41.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5761	 1	 0.0	 0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5762	 1	 0.0	 0.0	 0.0	 2.23	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5763	 1	 -0.0	 0.0	 0.0	 4.95	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5764	 1	 99.4	 4.3	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5765	 1	 9.8	 1.4	 0.0	 0.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5766	 1	 176.4	 17.2	 0.0	 18.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5767	 1	 -0.0	 0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5768	 1	 0.0	 -0.0	 0.0	 22.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5769	 1	 -0.0	 0.0	 0.0	 3.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5770	 1	 -0.0	 0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5771	 1	 190.5	 70.9	 0.0	 21.3	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5772	 1	 -38.01	 -22.73	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5773	 1	 0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5774	 1	 0.0	 0.0	 0.0	 8.92	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5775	 1	 30.03	 10.0	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5776	 1	 222.7	 80.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5777	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5778	 1	 -0.0	 -0.0	 0.0	 2.16	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5779	 1	 86.2	 -30.7	 0.0	 8.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5780	 1	 0.0	 -0.0	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5781	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5782	 1	 -0.0	 -0.0	 0.0	 19.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5783	 1	 69.08	 -49.6	 0.0	 3.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5784	 1	 -0.0	 0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5785	 1	 54.2	 7.8	 0.0	 21.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5786	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5787	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5788	 1	 12.6	 1.8	 0.0	 3.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5789	 1	 0.0	 0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5790	 1	 4.4	 1.1	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5791	 1	 0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5792	 1	 40.95	 13.4	 0.0	 51.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5793	 1	 6.11	 0.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5794	 1	 0.0	 0.0	 0.0	 4.64	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5795	 1	 124.6	 15.9	 0.0	 2.29	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5796	 1	 0.0	 0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5797	 1	 334.1	 103.5	 0.0	 14.78	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5798	 1	 5.04	 6.1	 0.0	 8.68	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5799	 1	 -0.0	 -0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5800	 1	 12.6	 1.8	 0.0	 3.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5801	 1	 0.0	 0.0	 0.0	 35.66	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	5802	 1	 -0.0	 -0.0	 0.0	 0.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5803	 1	 0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5804	 1	 36.24	 12.8	 0.0	 2.99	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5805	 1	 167.6	 -9.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5806	 1	 0.0	 -0.0	 0.0	 0.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5807	 1	 0.0	 0.0	 0.0	 18.62	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5808	 1	 -7.91	 2.6	 0.0	 1.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5809	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5810	 1	 -0.0	 -0.0	 0.0	 10.45	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5811	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5812	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5813	 1	 0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5815	 1	 5.21	 1.3	 0.0	 24.85	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	5816	 1	 13.01	 2.4	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5817	 1	 7.0	 1.0	 0.0	 4.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5818	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5819	 1	 343.1	 109.5	 0.0	 41.33	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	5820	 1	 -0.0	 -0.0	 0.0	 2.02	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5821	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5822	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.30000	    0.70000;
	5823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5824	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	5825	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5826	 1	 50.2	 7.1	 0.0	 7.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5827	 1	 83.5	 41.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5828	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5829	 1	 155.5	 38.3	 0.0	 52.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5830	 1	 53.86	 17.7	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5831	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5832	 1	 -0.0	 0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	5833	 1	 -46.15	 15.1	 0.0	 0.64	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5834	 1	 0.9	 0.3	 0.0	 2.19	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5835	 1	 0.0	 0.0	 0.0	 3.32	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5836	 1	 244.09	 48.92	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5837	 1	 -0.0	 -0.0	 0.0	 132.04744	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5838	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5839	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5840	 1	 0.0	 -0.0	 0.0	 8.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5841	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5842	 1	 -0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5843	 1	 -0.0	 0.0	 0.0	 8.58	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5844	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5845	 1	 23.7	 3.4	 0.0	 2.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5846	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5847	 1	 0.0	 -0.0	 0.0	 15.97	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	5848	 1	 0.0	 -0.0	 0.29	 -0.42	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5849	 1	 20.52	 7.6	 0.0	 2.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5850	 1	 -0.0	 0.0	 0.0	 49.904544	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	5851	 1	 0.9	 0.1	 0.0	 8.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5852	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5853	 1	 122.5	 38.9	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5854	 1	 18.42	 1.2	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5855	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	5856	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5857	 1	 78.39	 21.2	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5858	 1	 -0.0	 -0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5859	 1	 2.2	 -0.48	 0.0	 3.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5860	 1	 18.52	 11.5	 0.0	 4.41	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5861	 1	 0.0	 -0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5862	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5863	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5864	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5865	 1	 20.72	 6.8	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5866	 1	 10.01	 -30.0	 0.0	 0.74	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5867	 1	 55.26	 34.2	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5868	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5869	 1	 145.7	 122.2	 0.0	 4.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5870	 1	 0.0	 -0.0	 0.0	 3.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5871	 1	 28.83	 -3.8	 0.0	 7.4	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5872	 1	 177.5	 72.5	 0.0	 46.35	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5873	 1	 0.0	 0.0	 0.0	 132.84	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5874	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5875	 1	 2.0	 1.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5876	 1	 0.0	 -0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5877	 1	 -0.0	 0.0	 0.0	 67.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5878	 1	 -0.0	 0.0	 0.0	 8.17	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5879	 1	 -0.0	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5880	 1	 159.98	 76.4	 0.0	 22.64	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5881	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5882	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	5883	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	5884	 1	 -0.0	 -0.0	 0.0	 68.73	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5885	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5886	 1	 16.42	 5.3	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5887	 1	 6.91	 -11.1	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5888	 1	 -0.0	 -0.0	 0.0	 93.07	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5889	 1	 27.9	 4.0	 0.0	 3.43	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5890	 1	 0.0	 -0.0	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5891	 1	 14.02	 5.5	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5892	 1	 49.86	 14.1	 0.0	 11.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5893	 1	 26.03	 10.6	 0.0	 2.14	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5894	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5895	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5897	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5898	 1	 -85.69	 -2.0	 0.0	 21.28	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5899	 1	 83.6	 11.9	 0.0	 3.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5900	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5901	 1	 7.21	 3.3	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5902	 1	 -0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5903	 1	 0.0	 -7.2	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5904	 1	 64.4	 9.1	 0.0	 2.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5905	 1	 196.3	 -10.4	 0.0	 8.97	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5906	 1	 5.31	 2.3	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5907	 1	 186.1	 14.8	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5908	 1	 10.51	 1.3	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5909	 1	 181.9	 92.6	 0.0	 4.15	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5910	 1	 42.55	 14.0	 0.0	 7.52	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5911	 1	 -0.0	 -0.0	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5912	 1	 -0.0	 -0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5913	 1	 80.99	 30.1	 0.0	 29.8	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5914	 1	 94.1	 39.0	 0.0	 27.61	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5915	 1	 -0.0	 0.0	 0.0	 4.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5916	 1	 -57.59	 -30.52	 0.0	 2.45	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5917	 1	 61.67	 17.4	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5918	 1	 73.83	 16.41	 0.0	 15.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5919	 1	 -0.0	 0.0	 0.0	 33.03	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5920	 1	 0.0	 0.0	 0.0	 30.48	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5921	 1	 -0.0	 -0.0	 0.0	 34.98	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5922	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5923	 1	 74.08	 10.7	 0.0	 13.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5924	 1	 29.03	 18.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5925	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5926	 1	 0.0	 -0.0	 0.0	 3.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5927	 1	 -0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5928	 1	 -0.0	 0.0	 0.0	 1.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5929	 1	 0.0	 0.0	 0.0	 1.74	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	5931	 1	 53.06	 17.4	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5932	 1	 22.3	 3.1	 0.0	 0.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5933	 1	 78.49	 18.5	 0.0	 6.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5934	 1	 0.0	 0.0	 0.0	 37.02	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5935	 1	 -0.0	 0.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5936	 1	 0.0	 0.0	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5937	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5938	 1	 -0.0	 -0.0	 0.0	 15.14	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5939	 1	 0.0	 -0.0	 0.0	 0.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5940	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5941	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5942	 1	 5.21	 1.7	 0.0	 1.37	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5943	 1	 15.12	 7.5	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5944	 1	 71.88	 21.7	 0.0	 9.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5945	 1	 0.0	 -0.0	 0.0	 28.22	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5946	 1	 0.0	 -0.0	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5947	 1	 0.0	 0.0	 0.0	 1.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5948	 1	 57.06	 13.3	 0.0	 19.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5949	 1	 160.7	 40.3	 0.0	 3.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5950	 1	 24.93	 22.9	 0.0	 2.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5951	 1	 -0.0	 -0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5952	 1	 40.34	 15.9	 0.0	 1.31	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5953	 1	 -7.97	 6.3	 0.0	 2.73	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5954	 1	 106.7	 33.6	 0.0	 3.28	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5955	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5956	 1	 0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5957	 1	 208.06	 36.6	 0.0	 3.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5958	 1	 209.8	 102.6	 0.0	 24.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5959	 1	 160.0	 50.0	 0.0	 23.19	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5960	 1	 -0.0	 0.0	 0.0	 2.78	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5961	 1	 113.5	 11.5	 0.0	 5.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5962	 1	 64.27	 22.9	 0.0	 3.06	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5963	 1	 0.0	 -0.0	 0.0	 11.87	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5964	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5965	 1	 144.5	 67.8	 0.0	 2.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5966	 1	 62.57	 22.7	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5967	 1	 -0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5968	 1	 -0.0	 -0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5969	 1	 99.5	 28.09	 0.0	 6.23	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5970	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5971	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	5972	 1	 148.2	 65.3	 0.0	 10.51	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5973	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5974	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5975	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5976	 1	 0.0	 -0.0	 0.0	 6.35	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	5977	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5978	 1	 3.5	 0.9	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5979	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5980	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5981	 1	 17.12	 1.3	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5982	 1	 0.0	 0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5984	 1	 27.53	 12.1	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5985	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	5986	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.30000	    0.70000;
	5987	 1	 24.04	 1.68	 0.0	 4.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5988	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	5989	 1	 83.1	 26.1	 0.0	 23.95	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	5990	 1	 0.0	 -0.0	 0.0	 4.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5991	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5992	 1	 408.9	 77.3	 0.0	 13.58	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5993	 1	 0.0	 -0.0	 0.0	 2.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5994	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5995	 1	 18.52	 6.1	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5996	 1	 -0.0	 -0.0	 0.164188	 4.023827	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5997	 1	 25.83	 12.5	 0.0	 0.2	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5998	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5999	 1	 36.04	 -8.0	 0.0	 32.73	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	6000	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.30000	    0.70000;
	6001	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6002	 1	 4.61	 1.7	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6003	 1	 7.01	 2.3	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6004	 1	 0.0	 0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6005	 1	 0.0	 -0.0	 0.0	 50.27	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	6006	 1	 0.0	 0.0	 0.25	 20.36	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	6007	 1	 191.96	 38.57	 0.0	 122.89	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	6008	 1	 0.0	 -0.0	 0.0	 219.65	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6009	 1	 20.82	 7.9	 0.0	 6.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6010	 1	 0.0	 0.0	 0.0	 1.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6011	 1	 11.41	 0.7	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6012	 1	 -8.81	 2.9	 0.0	 0.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6013	 1	 105.8	 51.8	 0.0	 5.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6014	 1	 0.04	 -0.05	 0.0	 20.75	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	6015	 1	 -0.0	 0.0	 0.0	 25.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6016	 1	 92.1	 45.0	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6017	 1	 -0.0	 0.0	 0.0	 23.15	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6018	 1	 27.53	 17.0	 0.0	 0.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6019	 1	 0.0	 0.0	 0.0	 10.52	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6020	 1	 0.1	 -19.3	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6021	 1	 -0.0	 0.0	 0.0	 76.15	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6022	 1	 -0.0	 -0.0	 0.0	 5.5	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6023	 1	 9.01	 3.0	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	6024	 1	 -0.0	 -0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6025	 1	 -0.16	 -1.92	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6026	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6027	 1	 61.27	 11.0	 0.0	 50.16	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6028	 1	 0.0	 0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6029	 1	 23.03	 7.6	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6030	 1	 48.8	 6.9	 0.0	 12.07	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6031	 1	 0.0	 0.0	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6032	 1	 -0.0	 0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6033	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6034	 1	 0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6035	 1	 -18.52	 6.1	 0.0	 0.26	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6037	 1	 21.62	 9.8	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6038	 1	 43.55	 -20.5	 0.0	 2.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6039	 1	 165.9	 154.6	 0.0	 15.17	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6040	 1	 -57.46	 -30.3	 0.0	 5.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6041	 1	 0.0	 0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6042	 1	 -0.0	 -0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6043	 1	 49.76	 15.0	 0.0	 1.22	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6044	 1	 117.5	 16.7	 0.0	 3.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6045	 1	 -0.2	 -0.98	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6046	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 19	    1.30000	    0.70000;
	6047	 1	 79.49	 22.7	 0.0	 9.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6048	 1	 6.61	 1.9	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6049	 1	 -0.0	 -0.0	 0.0	 3.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6050	 1	 0.0	 0.0	 0.0	 42.02	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6051	 1	 5.61	 2.0	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6052	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6053	 1	 412.1	 79.3	 0.0	 7.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6054	 1	 4.1	 1.4	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6055	 1	 19.32	 7.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6056	 1	 0.0	 0.0	 0.0	 1.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6057	 1	 47.65	 19.4	 0.0	 0.79	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6058	 1	 0.0	 -0.0	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6059	 1	 35.14	 14.3	 0.0	 7.31	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6060	 1	 0.0	 0.0	 0.0	 80.66	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6061	 1	 15.02	 9.0	 0.0	 0.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6062	 1	 13.31	 2.8	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6063	 1	 61.36	 23.66	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6064	 1	 -0.0	 0.0	 0.0	 14.03	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	6065	 1	 25.73	 9.3	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6066	 1	 0.0	 0.0	 0.0	 30.94	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6067	 1	 -0.0	 -0.0	 0.0	 10.33	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6068	 1	 0.0	 0.0	 0.0	 33.08	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6069	 1	 -0.0	 -0.0	 0.285753	 52.671068	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6070	 1	 -14.58	 -5.96	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6071	 1	 163.5	 35.6	 0.0	 4.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6072	 1	 47.6	 41.3	 0.0	 295.019105	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	6073	 1	 27.9	 4.0	 0.0	 1.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6074	 1	 2.7	 0.9	 0.0	 1.49	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6075	 1	 0.0	 -0.0	 0.0	 4.17	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6076	 1	 1.8	 0.7	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6077	 1	 -0.0	 0.0	 0.0	 -1.896325	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6078	 1	 0.0	 -0.0	 0.0	 1.25	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6079	 1	 160.2	 89.89	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6080	 1	 0.0	 0.0	 0.361	 33.735	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6081	 1	 5.81	 1.4	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6082	 1	 6.01	 1.5	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6083	 1	 111.5	 147.5	 0.0	 26.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6084	 1	 -0.0	 -0.0	 0.072589	 52.192656	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6085	 1	 -0.0	 0.0	 0.0	 22.6	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6086	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6087	 1	 27.9	 4.0	 0.0	 3.97	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6088	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	6089	 1	 26.23	 8.6	 0.0	 6.14	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6091	 1	 -0.0	 -0.0	 0.0	 17.336728	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	6092	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6093	 1	 21.02	 12.4	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6094	 1	 0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6095	 1	 0.0	 -0.0	 0.0	 10.05	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6096	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6097	 1	 -0.0	 0.0	 0.0	 3.87	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6098	 1	 -0.0	 -0.0	 0.135493	 28.29062	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	6099	 1	 0.3	 2.0	 0.0	 10.34	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	6100	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6101	 1	 103.0	 40.2	 0.0	 1.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6102	 1	 -0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6103	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	6104	 1	 93.12	 4.99	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6105	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6106	 1	 1.3	 3.8	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6107	 1	 128.6	 27.8	 0.0	 36.2	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6108	 1	 -0.0	 -0.0	 0.0	 24.64	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6109	 1	 176.75	 51.7	 0.0	 39.79	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	6110	 1	 78.59	 16.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6111	 1	 13.9	 1.9	 0.0	 0.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6112	 1	 45.28	 15.27	 0.0	 7.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6113	 1	 0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6114	 1	 0.0	 0.0	 0.0	 8.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6115	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6116	 1	 0.0	 -0.0	 0.118007	 -0.299556	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6117	 1	 0.0	 -0.0	 0.0	 1.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6118	 1	 82.55	 30.58	 0.0	 4.26	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6119	 1	 221.25	 72.56	 0.0	 8.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6120	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6121	 1	 16.12	 5.8	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6122	 1	 3.7	 1.4	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6123	 1	 55.8	 7.9	 0.0	 11.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6124	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6125	 1	 0.0	 -0.0	 0.0	 1.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6126	 1	 118.4	 16.9	 0.0	 0.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6127	 1	 -0.1	 68.5	 0.0	 17.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6128	 1	 27.23	 8.9	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6129	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6130	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6131	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.30000	    0.70000;
	6132	 1	 60.67	 5.9	 0.0	 5.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6133	 1	 109.0	 28.3	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6134	 1	 42.55	 6.5	 0.0	 3.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6135	 1	 2.2	 0.5	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6136	 1	 58.8	 8.4	 0.0	 5.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6137	 1	 -0.0	 -0.0	 0.0	 37.02	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6139	 1	 76.89	 35.1	 0.0	 1.9	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6140	 1	 11.51	 3.8	 0.0	 7.14	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6141	 1	 44.05	 16.0	 0.0	 1.63	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6142	 1	 116.2	 16.5	 0.0	 2.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6143	 1	 39.0	 5.5	 0.0	 7.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6144	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6146	 1	 0.0	 -0.0	 0.0	 3.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6147	 1	 -0.0	 0.0	 0.0	 0.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6148	 1	 8.71	 5.4	 0.0	 0.84	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6149	 1	 39.05	 24.8	 0.0	 7.47	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6150	 1	 15.32	 5.0	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6151	 1	 60.67	 33.2	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6152	 1	 -0.0	 -0.0	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6153	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6154	 1	 0.0	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6155	 1	 67.98	 54.6	 0.0	 3.39	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6156	 1	 95.9	 26.2	 0.0	 16.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6157	 1	 160.2	 88.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6158	 1	 -0.0	 -0.0	 0.25	 2.3	 0	    1.00000	    0.00000	 220.0	 19	    1.30000	    0.70000;
	6159	 1	 0.0	 -0.0	 0.173089	 4.478398	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6160	 1	 -0.0	 -0.0	 0.0	 16.34	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6161	 1	 383.6	 -37.9	 0.0	 21.3	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6162	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6163	 1	 0.0	 -0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6164	 1	 -0.0	 -0.0	 0.215903	 26.017449	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6165	 1	 -0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6166	 1	 67.28	 -0.33	 0.0	 8.4	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6167	 1	 152.6	 61.8	 0.0	 2.35	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6168	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6169	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6170	 1	 47.3	 6.7	 0.0	 2.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6171	 1	 28.93	 0.2	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6172	 1	 66.97	 14.1	 0.0	 5.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6173	 1	 -6.3	 -3.18	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6174	 1	 289.1	 84.2	 0.0	 17.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6175	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6176	 1	 16.72	 5.5	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6177	 1	 18.42	 5.3	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6178	 1	 91.0	 28.4	 0.0	 10.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6180	 1	 0.0	 -0.0	 0.0	 20.11	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6181	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6182	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	6183	 1	 59.37	 12.7	 0.0	 22.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6184	 1	 16.72	 5.5	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6185	 1	 -0.0	 -0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6186	 1	 63.07	 13.4	 0.0	 15.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6187	 1	 -0.0	 0.0	 0.361	 25.935	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6188	 1	 209.9	 38.0	 0.0	 5.26	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6189	 1	 131.9	 50.6	 0.0	 79.02	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6190	 1	 141.52	 50.48	 0.0	 66.28	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	6191	 1	 -2.91	 -0.62	 0.0	 0.01	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6192	 1	 50.56	 5.9	 0.0	 10.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6193	 1	 165.4	 130.5	 0.0	 28.06	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6194	 1	 0.0	 -0.0	 0.0	 3.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6195	 1	 0.0	 0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 150.0	 6	    1.10000	    0.90000;
	6196	 1	 17.52	 6.1	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6197	 1	 126.7	 46.1	 0.0	 5.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6198	 1	 154.2	 22.0	 0.0	 12.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6199	 1	 -4.82	 -0.88	 0.0	 224.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6200	 1	 0.0	 -0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6201	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6202	 1	 83.79	 33.1	 0.0	 65.16	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6203	 1	 14.02	 5.6	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6204	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	6205	 1	 -0.0	 0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6206	 1	 -7.62	 -2.52	 0.0	 33.197994	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6207	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6208	 1	 18.72	 7.9	 0.0	 1.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6209	 1	 69.48	 19.7	 0.0	 22.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6210	 1	 253.2	 78.1	 0.0	 10.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6211	 1	 48.8	 6.9	 0.0	 3.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6212	 1	 117.0	 19.2	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6213	 1	 -0.0	 -0.0	 0.0	 2.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6214	 1	 7.61	 2.5	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6215	 1	 -0.0	 0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6216	 1	 13.72	 4.5	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6217	 1	 -0.0	 -0.0	 0.0	 3.88	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6218	 1	 88.8	 35.1	 0.0	 1.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6219	 1	 -0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6220	 1	 231.9	 27.6	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6221	 1	 0.0	 0.0	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6222	 1	 -11.79	 -22.64	 0.10131	 0.71027	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6223	 1	 0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6224	 1	 0.0	 0.0	 0.0	 58.990785	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6225	 1	 -0.0	 0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6226	 1	 -0.0	 0.0	 0.0	 1.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6227	 1	 88.0	 70.3	 0.0	 36.55	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6228	 1	 26.9	 3.8	 0.0	 4.69	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6229	 1	 26.43	 5.5	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6230	 1	 -0.0	 -0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6231	 1	 -0.0	 0.0	 0.0	 11.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6232	 1	 49.25	 12.0	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6233	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6234	 1	 227.6	 71.0	 0.0	 8.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6235	 1	 16.52	 -0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6236	 1	 2.5	 -0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6238	 1	 -0.0	 0.0	 0.0	 49.59	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	6239	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6240	 1	 0.0	 -0.0	 0.0	 6.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6241	 1	 -0.0	 0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6242	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6243	 1	 88.41	 34.42	 0.0	 3.45	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6244	 1	 0.0	 -0.0	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6245	 1	 -0.0	 -0.0	 0.27075	 34.52435	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	6246	 1	 -0.0	 0.0	 0.0	 86.73	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6247	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6248	 1	 -0.6	 -1.58	 0.0	 0.22	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	6249	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6250	 1	 0.0	 -0.0	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6251	 1	 380.53	 113.37	 0.0	 115.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	6252	 1	 164.7	 44.5	 0.0	 3.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6253	 1	 128.8	 29.3	 0.0	 26.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6254	 1	 0.0	 -0.0	 0.0	 9.9	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6255	 1	 -0.0	 0.0	 0.0	 26.52	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	6256	 1	 0.0	 0.0	 0.16245	 33.4651	 0	    1.00000	    0.00000	 380.0	 18	    1.30000	    0.70000;
	6257	 1	 0.0	 -0.0	 0.0	 36.48	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	6258	 1	 11.61	 2.5	 0.0	 3.84	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6259	 1	 178.0	 33.8	 0.0	 2.73	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6260	 1	 47.55	 29.4	 0.0	 5.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6261	 1	 75.88	 11.2	 0.0	 4.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6262	 1	 12.81	 4.7	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6263	 1	 0.0	 -0.0	 0.0	 42.81	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6264	 1	 0.0	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6265	 1	 46.56	 9.25	 0.0	 2.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6266	 1	 32.1	 4.5	 0.0	 2.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6267	 1	 91.3	 18.1	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6268	 1	 112.17	 -11.06	 0.0	 13.68	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6269	 1	 -0.0	 0.0	 0.0	 2.28	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6270	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6271	 1	 3.7	 2.6	 0.0	 4.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6272	 1	 125.9	 -21.2	 0.0	 18.41	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6273	 1	 12.11	 4.4	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6274	 1	 441.2	 200.7	 0.0	 42.12	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6275	 1	 122.8	 37.2	 0.0	 37.13	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6276	 1	 65.07	 40.3	 0.0	 5.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6277	 1	 153.7	 21.9	 0.0	 17.71	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6278	 1	 15.22	 4.9	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6279	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6280	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6281	 1	 52.9	 7.6	 0.0	 4.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6282	 1	 -0.28	 -5.54	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6283	 1	 0.0	 -0.0	 0.0	 18.64	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6284	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6285	 1	 51.96	 22.8	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6286	 1	 0.0	 0.0	 0.0	 1.51	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6287	 1	 -0.0	 -0.0	 0.0	 7.1	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6288	 1	 25.23	 10.3	 0.0	 2.69	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6289	 1	 0.0	 -0.0	 0.0	 3.19	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6290	 1	 47.65	 20.4	 0.0	 3.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6292	 1	 186.5	 49.9	 0.0	 13.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6293	 1	 -0.0	 0.0	 0.0	 33.66	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6294	 1	 90.5	 12.8	 0.0	 2.68	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6295	 1	 0.0	 -0.0	 0.0	 46.83	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6296	 1	 15.02	 6.0	 0.0	 6.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6297	 1	 20.02	 8.0	 0.0	 5.4	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6298	 1	 0.0	 -0.0	 0.274712	 52.929035	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6299	 1	 -0.0	 -0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6300	 1	 139.1	 19.8	 0.0	 16.14	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6301	 1	 -0.57	 -1.0	 0.0	 2.27	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6302	 1	 134.05	 13.3	 0.0	 25.19	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6303	 1	 49.96	 15.6	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6304	 1	 1.7	 0.6	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6305	 1	 31.33	 6.4	 0.0	 1.96	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6306	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6307	 1	 132.4	 -10.4	 0.0	 3.02	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6308	 1	 0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6309	 1	 0.0	 -7.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6310	 1	 0.0	 0.0	 0.0	 22.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6311	 1	 0.0	 -0.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6312	 1	 -0.0	 -0.0	 0.0	 1.66	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6313	 1	 48.95	 14.9	 0.0	 4.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6314	 1	 30.03	 15.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	6315	 1	 95.71	 19.6	 0.0	 20.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6316	 1	 474.3	 203.4	 0.0	 47.469681	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6317	 1	 -0.0	 0.0	 0.090774	 7.310444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6318	 1	 0.0	 0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6319	 1	 -0.0	 0.0	 0.135375	 10.042175	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	6320	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6321	 1	 128.8	 70.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6322	 1	 0.0	 0.0	 0.0	 1.99	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6323	 1	 116.1	 30.2	 0.0	 4.38	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6324	 1	 13.9	 1.9	 0.0	 2.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6325	 1	 23.0	 3.2	 0.0	 3.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6326	 1	 9.7	 1.4	 0.0	 7.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6327	 1	 -5.01	 -0.0	 0.0	 3.54	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6328	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6330	 1	 -0.0	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6332	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6333	 1	 42.75	 4.0	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6334	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6335	 1	 92.76	 -46.04	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6336	 1	 245.51	 46.8	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6337	 1	 0.0	 0.0	 0.0	 8.26	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6339	 1	 7.21	 2.4	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6340	 1	 -0.0	 0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6341	 1	 22.73	 5.3	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6342	 1	 -0.0	 0.0	 0.0	 3.25	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6343	 1	 143.9	 123.3	 0.203819	 60.947564	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6344	 1	 -0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6345	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6346	 1	 -0.0	 0.0	 0.0	 3.8	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6347	 1	 22.22	 13.8	 0.0	 3.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6348	 1	 32.04	 15.0	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	6349	 1	 55.46	 14.1	 0.0	 0.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6350	 1	 35.04	 20.0	 0.0	 2.49	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	6351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6352	 1	 -0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6353	 1	 0.6	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6354	 1	 0.0	 -0.0	 0.0	 47.06	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6355	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6356	 1	 44.95	 12.8	 0.0	 2.61	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6357	 1	 430.8	 107.9	 0.0	 11.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6358	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6359	 1	 74.68	 10.8	 0.0	 5.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6360	 1	 0.0	 0.0	 0.0	 1.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6361	 1	 8.11	 1.4	 0.0	 1.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6362	 1	 24.03	 8.0	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 6	    1.10000	    0.90000;
	6363	 1	 12.94	 4.9	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6364	 1	 -0.0	 -0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6365	 1	 0.0	 -0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6366	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	6367	 1	 7.41	 2.7	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6369	 1	 -0.0	 -0.0	 0.0	 14.29	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6370	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6371	 1	 -0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6372	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6373	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	6374	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6375	 1	 -18.69	 -7.9	 0.0	 2.09	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6376	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6377	 1	 11.61	 7.2	 0.0	 16.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6378	 1	 11.31	 3.7	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6379	 1	 118.4	 16.9	 0.0	 27.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6380	 1	 -0.0	 -0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6381	 1	 246.2	 119.1	 0.0	 31.72	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6382	 1	 75.43	 10.49	 0.0	 7.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6383	 1	 15.62	 5.3	 0.0	 2.17	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6384	 1	 159.9	 47.4	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6385	 1	 5.41	 2.81	 0.0	 1.9	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6386	 1	 20.9	 3.0	 0.0	 1.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6387	 1	 0.0	 0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6388	 1	 27.9	 4.0	 0.0	 6.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6389	 1	 -0.0	 0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6390	 1	 -0.0	 0.0	 0.0	 3.36	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6391	 1	 74.32	 11.08	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6392	 1	 80.09	 19.0	 0.0	 1.88	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6393	 1	 93.7	 29.9	 0.0	 2.1	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6394	 1	 53.86	 -15.3	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6395	 1	 154.7	 48.2	 0.0	 5.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6396	 1	 4.0	 0.1	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	6397	 1	 0.0	 0.0	 0.0	 27.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6398	 1	 0.0	 0.0	 0.0	 249.421581	 0	    1.00000	    0.00000	 750.0	 24	    1.10000	    0.90000;
	6399	 1	 44.05	 18.0	 0.0	 0.88	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6400	 1	 64.0	 9.1	 0.0	 9.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6401	 1	 62.7	 9.0	 0.0	 1.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6402	 1	 7.91	 2.6	 0.0	 1.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6403	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6404	 1	 0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6405	 1	 76.48	 19.8	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6406	 1	 2.5	 1.3	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6407	 1	 0.3	 -34.1	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6408	 1	 126.9	 80.5	 0.0	 46.82	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6409	 1	 10.44	 2.73	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6410	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6411	 1	 115.2	 38.9	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6412	 1	 -0.0	 0.0	 0.0	 5.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6413	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6414	 1	 8.0	 1.1	 0.0	 3.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6415	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6416	 1	 67.67	 16.4	 0.0	 3.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6417	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6418	 1	 43.75	 2.2	 0.0	 1.36	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6419	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6420	 1	 0.0	 -0.0	 0.0	 5.96	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6421	 1	 174.3	 11.8	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6422	 1	 17.25	 4.26	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6423	 1	 -0.0	 0.0	 0.0	 2.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6424	 1	 -0.18	 -2.28	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6425	 1	 0.0	 -0.0	 0.0	 1.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6426	 1	 10.21	 3.8	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6427	 1	 83.19	 22.9	 0.0	 28.5	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6428	 1	 93.1	 43.7	 0.0	 2.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6429	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6430	 1	 0.0	 -0.0	 0.0	 6.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6431	 1	 1.4	 0.5	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6432	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6433	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	6434	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 19	    1.30000	    0.70000;
	6435	 1	 28.63	 11.0	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6437	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6438	 1	 0.1	 -19.1	 0.0	 0.26	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6439	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6440	 1	 81.79	 10.8	 0.0	 10.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6441	 1	 3.9	 1.1	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6442	 1	 163.3	 70.3	 0.0	 5.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6443	 1	 43.95	 15.5	 0.0	 6.36	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6444	 1	 193.8	 18.0	 0.0	 82.73	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6445	 1	 1.0	 -2.3	 0.0	 6.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6446	 1	 77.19	 23.0	 0.0	 63.4	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	6447	 1	 54.96	 13.2	 0.0	 2.95	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6448	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6449	 1	 0.0	 -0.0	 0.135375	 37.092175	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	6450	 1	 5.51	 2.1	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6451	 1	 139.8	 -25.8	 0.0	 22.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6452	 1	 -0.0	 0.0	 0.0	 5.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6453	 1	 8.31	 3.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6454	 1	 -0.0	 -0.0	 0.0	 11.67	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6455	 1	 20.52	 13.3	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6456	 1	 159.4	 28.4	 0.0	 15.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6457	 1	 -1.5	 -41.98	 0.0	 36.76	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6458	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6459	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6460	 1	 169.8	 -19.6	 0.0	 53.619841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6461	 1	 22.22	 8.0	 0.0	 5.7	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	6462	 1	 11.1	 1.6	 0.0	 3.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6463	 1	 -4.17	 -2.16	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6464	 1	 9.41	 13.8	 0.0	 65.59	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6465	 1	 3.2	 -0.4	 0.0	 1.76	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6466	 1	 1.83	 -5.69	 0.0	 5.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6467	 1	 25.0	 3.6	 0.0	 3.86	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6468	 1	 172.5	 48.7	 0.0	 54.92	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	6469	 1	 -0.0	 0.0	 0.0	 2.55	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6470	 1	 -0.0	 -0.0	 0.225551	 5.082241	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6471	 1	 34.14	 11.5	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6472	 1	 0.0	 -0.0	 0.0	 9.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6473	 1	 76.6	 10.9	 0.0	 6.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6475	 1	 -0.0	 0.0	 0.0	 149.047157	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6476	 1	 59.2	 8.4	 0.0	 2.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6477	 1	 0.0	 0.0	 0.0	 1.99	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6478	 1	 141.2	 34.8	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6479	 1	 0.0	 -0.0	 0.0	 23.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6480	 1	 -0.21	 -1.04	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6481	 1	 -0.0	 -0.0	 0.090774	 1.940444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6482	 1	 -0.0	 0.0	 0.0	 29.2	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6483	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6484	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6485	 1	 0.0	 -0.0	 0.643825	 106.534876	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6486	 1	 31.74	 17.4	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6487	 1	 18.62	 3.6	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6488	 1	 0.0	 0.0	 0.0	 23.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6489	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6490	 1	 84.59	 12.9	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6491	 1	 0.0	 0.0	 0.0	 17.82	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	6492	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6493	 1	 9.51	 4.6	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6494	 1	 0.0	 -0.0	 0.0	 8.2	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6495	 1	 49.66	 12.3	 0.0	 2.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6496	 1	 0.0	 -0.0	 0.0	 24.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6497	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6498	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6499	 1	 -0.0	 -0.0	 0.0	 13.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6500	 1	 25.13	 9.0	 0.0	 1.46	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6501	 1	 25.83	 9.4	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6502	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6503	 1	 13.21	 3.5	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6504	 1	 49.26	 30.9	 0.097351	 12.97086	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6505	 1	 0.0	 -0.0	 0.0	 5.19	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	6506	 1	 41.31	 5.96	 0.0	 0.89	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6507	 1	 41.8	 5.9	 0.0	 10.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6508	 1	 -0.0	 0.0	 0.0	 4.52	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6509	 1	 0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6510	 1	 88.2	 26.7	 0.0	 8.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6511	 1	 20.02	 9.6	 0.0	 0.17	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6512	 1	 -0.0	 0.0	 0.0	 3.4	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6513	 1	 13.92	 4.3	 0.0	 1.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6514	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6515	 1	 20.32	 8.6	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6516	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6517	 1	 -14.73	 -9.85	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6518	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6519	 1	 -0.19	 -1.94	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6520	 1	 20.32	 -22.0	 0.0	 5.35	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6521	 1	 0.0	 0.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6522	 1	 30.43	 12.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6523	 1	 24.83	 9.0	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6524	 1	 113.4	 61.91	 0.0	 1.51	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6525	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6526	 1	 8.41	 2.6	 0.0	 1.77	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6527	 1	 100.1	 48.9	 0.0	 0.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6528	 1	 69.08	 24.0	 0.0	 4.79	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6529	 1	 446.5	 105.6	 0.0	 38.83	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6530	 1	 42.85	 14.3	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6531	 1	 -0.0	 -0.0	 0.0	 31.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6532	 1	 120.69	 18.1	 0.0	 15.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6533	 1	 37.59	 21.67	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	6534	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6535	 1	 27.9	 4.0	 0.0	 1.86	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6536	 1	 34.9	 5.0	 0.0	 1.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6537	 1	 20.72	 7.5	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6538	 1	 349.2	 61.3	 0.225755	 37.035147	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6539	 1	 68.48	 22.4	 0.0	 4.38	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6540	 1	 0.9	 0.3	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6541	 1	 27.43	 -36.4	 0.0	 2.2	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6542	 1	 208.24	 11.9	 0.0	 24.11	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	6543	 1	 118.4	 7.1	 0.0	 11.11	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6544	 1	 62.17	 0.7	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6545	 1	 92.4	 13.1	 0.0	 0.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6546	 1	 1.1	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6547	 1	 26.33	 8.7	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6548	 1	 7.61	 1.3	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6549	 1	 -0.0	 -0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	6550	 1	 3.1	 -5.2	 0.0	 0.86	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6551	 1	 20.1	 2.9	 0.0	 10.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6552	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6553	 1	 14.0	 1.9	 0.0	 1.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6554	 1	 262.1	 13.9	 0.0	 10.23	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6555	 1	 -37.81	 -21.64	 0.0	 83.362314	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6556	 1	 -0.0	 -0.0	 0.0	 4.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6557	 1	 3.7	 1.3	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6558	 1	 -0.0	 0.0	 0.0	 17.75	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6559	 1	 105.5	 35.3	 0.0	 1.23	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6560	 1	 488.7	 118.4	 0.0	 75.45	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6561	 1	 216.0	 56.2	 0.0	 6.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6562	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6563	 1	 0.0	 -0.0	 0.0	 8.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6564	 1	 328.9	 -9.3	 0.0	 28.37	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6565	 1	 0.0	 -0.0	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6566	 1	 43.15	 14.4	 0.0	 1.73	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6567	 1	 43.15	 14.8	 0.0	 17.41	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6568	 1	 -0.0	 -0.0	 0.0	 59.04	 0	    1.00000	    0.00000	 380.0	 19	    1.30000	    0.70000;
	6569	 1	 178.62	 14.44	 0.0	 136.23	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	6570	 1	 -0.0	 0.0	 0.0	 32.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6571	 1	 0.0	 -0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6572	 1	 23.93	 7.9	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6573	 1	 114.8	 33.1	 0.0	 2.03	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6574	 1	 -0.0	 -0.0	 0.0	 24.57	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6575	 1	 -0.0	 -0.0	 0.0	 26.84	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6576	 1	 51.76	 21.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	6577	 1	 15.14	 11.3	 0.0	 13.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6578	 1	 0.0	 0.0	 0.0	 3.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6579	 1	 8.91	 2.4	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6580	 1	 26.63	 9.4	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6581	 1	 153.8	 23.4	 0.0	 87.73	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6582	 1	 0.0	 -0.0	 0.0	 10.15	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6583	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6584	 1	 -22.27	 -8.9	 0.090706	 32.332802	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6585	 1	 24.73	 6.4	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	6586	 1	 0.0	 0.0	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6587	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6588	 1	 0.0	 0.0	 0.0	 34.29	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6589	 1	 124.8	 45.6	 0.0	 3.12	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6590	 1	 -0.0	 0.0	 0.0	 23.92	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6591	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6592	 1	 1.3	 0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6593	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6594	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6595	 1	 8.81	 2.9	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6596	 1	 109.1	 15.0	 0.0	 8.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6597	 1	 52.36	 7.4	 0.0	 26.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6598	 1	 16.52	 2.1	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6599	 1	 69.98	 23.1	 0.0	 2.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6600	 1	 25.83	 7.2	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6601	 1	 77.58	 -6.54	 0.0	 10.66	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6602	 1	 -0.0	 -0.0	 0.0	 16.66	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	6603	 1	 174.0	 49.6	 0.0	 14.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6604	 1	 15.22	 7.2	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6605	 1	 137.4	 81.7	 0.0	 6.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6606	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6607	 1	 0.0	 0.0	 0.0	 40.86	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6608	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6609	 1	 483.8	 105.2	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 20	    1.10000	    0.90000;
	6610	 1	 14.02	 6.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6611	 1	 0.0	 0.0	 0.0	 11.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6612	 1	 41.14	 15.25	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6613	 1	 0.0	 -0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6614	 1	 13.31	 3.5	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6615	 1	 -0.0	 -0.0	 0.0	 11.08	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6616	 1	 -0.0	 -0.0	 0.0	 3.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6617	 1	 69.7	 9.9	 0.0	 4.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6618	 1	 60.7	 8.7	 0.0	 3.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6619	 1	 -0.0	 -0.0	 0.0	 10.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6620	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6621	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6622	 1	 0.0	 -0.0	 0.0	 7.88	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6623	 1	 62.7	 9.0	 0.0	 5.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6624	 1	 -37.33	 -11.88	 0.0	 145.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6625	 1	 18.82	 1.7	 0.0	 6.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6626	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	6628	 1	 35.04	 12.9	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6629	 1	 62.63	 16.3	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6630	 1	 134.1	 24.8	 0.0	 13.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6631	 1	 57.56	 21.1	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6632	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6633	 1	 -0.0	 0.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6634	 1	 -0.0	 0.0	 0.0	 4.18	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6635	 1	 23.43	 14.5	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6636	 1	 -0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6637	 1	 -0.0	 0.0	 0.0	 26.92	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6638	 1	 61.65	 10.24	 0.0	 3.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6639	 1	 176.7	 41.2	 0.0	 10.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6640	 1	 20.9	 3.0	 0.0	 2.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6642	 1	 4.81	 1.0	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6643	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	6644	 1	 -0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6645	 1	 27.63	 17.1	 0.0	 5.89	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6646	 1	 48.8	 6.9	 0.0	 3.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6647	 1	 -5.92	 -2.24	 0.0	 1.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6648	 1	 -26.03	 -0.84	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6649	 1	 -0.0	 -0.0	 0.0	 0.69	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6650	 1	 15.32	 5.0	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6651	 1	 4.61	 1.7	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6652	 1	 -9.32	 -10.58	 0.0	 11.38	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6653	 1	 -0.0	 0.0	 0.062219	 66.642656	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6655	 1	 117.5	 40.0	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6657	 1	 -0.0	 0.0	 0.0	 19.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6658	 1	 29.73	 11.0	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6659	 1	 199.6	 27.1	 0.0	 33.58	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6660	 1	 435.2	 1.3	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6661	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6662	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6663	 1	 74.58	 16.6	 0.0	 2.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6664	 1	 -0.0	 0.0	 0.0	 10.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6665	 1	 0.0	 -0.0	 0.090774	 3.610444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6666	 1	 -0.0	 0.0	 0.214323	 70.931612	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	6667	 1	 0.0	 0.0	 0.0	 35.98	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6668	 1	 261.7	 104.6	 0.0	 29.76	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6669	 1	 132.9	 13.6	 0.0	 3.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6670	 1	 -0.0	 -0.0	 0.0	 3.87	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6671	 1	 -0.0	 0.0	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6672	 1	 0.0	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6673	 1	 20.02	 6.0	 0.0	 1.96	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6674	 1	 40.5	 5.7	 0.0	 2.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6675	 1	 37.94	 7.5	 0.0	 11.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6676	 1	 27.93	 17.29	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6677	 1	 3.7	 0.9	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6678	 1	 85.9	 12.2	 0.0	 2.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6679	 1	 0.0	 -0.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6680	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6681	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6682	 1	 -0.0	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	6683	 1	 66.67	 27.8	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6684	 1	 -0.0	 0.0	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6685	 1	 70.68	 11.9	 0.0	 4.34	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	6686	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6687	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6688	 1	 -0.0	 -0.0	 0.0	 32.21	 0	    1.00000	    0.00000	 380.0	 12	    1.30000	    0.70000;
	6689	 1	 -7.1	 -4.02	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6690	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6691	 1	 42.55	 12.5	 0.0	 1.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6692	 1	 10.33	 3.3	 0.0	 4.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6693	 1	 0.0	 0.0	 0.0	 21.03	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6694	 1	 -0.0	 -0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6695	 1	 45.95	 16.7	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6696	 1	 -0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6697	 1	 309.0	 74.5	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6698	 1	 -0.0	 -0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6699	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6700	 1	 12.6	 1.8	 0.0	 1.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6701	 1	 11.91	 1.8	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6702	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6703	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 18	    1.30000	    0.70000;
	6704	 1	 -0.0	 -0.0	 0.211099	 0.672832	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6705	 1	 89.2	 42.7	 0.0	 13.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6706	 1	 0.1	 4.4	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6707	 1	 119.5	 44.5	 0.0	 3.61	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6708	 1	 46.08	 -47.15	 0.0	 11.39	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6709	 1	 33.24	 11.1	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6710	 1	 0.0	 -0.0	 0.0	 37.35	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	6711	 1	 12.11	 5.4	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6712	 1	 7.61	 6.3	 0.0	 1.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6713	 1	 72.48	 44.9	 0.0	 1.75	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6714	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6715	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6716	 1	 -0.0	 0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6717	 1	 -20.82	 -8.8	 0.0	 9.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6718	 1	 139.8	 -23.6	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6719	 1	 61.07	 11.1	 0.0	 4.8	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6720	 1	 -1.6	 -0.9	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	6721	 1	 32.54	 11.7	 0.0	 1.17	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6722	 1	 18.02	 5.9	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6723	 1	 0.0	 0.0	 0.0	 1.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6724	 1	 151.56	 -314.2	 0.0	 60.91	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6725	 1	 487.2	 116.7	 0.0	 56.29	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6726	 1	 18.12	 6.0	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6727	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6728	 1	 4.2	 0.6	 0.0	 3.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6729	 1	 0.0	 0.0	 0.27075	 91.79435	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	6730	 1	 -0.0	 0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6731	 1	 62.7	 9.0	 0.0	 1.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6732	 1	 -6.71	 -2.4	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6733	 1	 24.38	 5.91	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6734	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6735	 1	 -0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6736	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6737	 1	 0.0	 -0.0	 0.0	 9.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6738	 1	 -4.91	 -2.53	 0.0	 120.576812	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6739	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6740	 1	 0.0	 0.0	 0.0	 19.54	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6741	 1	 0.0	 0.0	 0.0	 38.84	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	6742	 1	 137.4	 23.9	 0.0	 7.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6743	 1	 -0.0	 -0.0	 0.0	 79.151368	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	6744	 1	 244.12	 95.29	 0.0	 7.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6745	 1	 25.63	 51.6	 0.0	 2.79	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6746	 1	 -0.0	 -0.0	 0.0	 9.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6747	 1	 0.0	 -0.0	 0.0	 75.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6748	 1	 0.0	 -0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6749	 1	 5.91	 1.7	 0.0	 8.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6750	 1	 267.1	 57.4	 0.0	 21.33	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6751	 1	 76.6	 10.9	 0.0	 2.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6752	 1	 6.81	 2.5	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6753	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6754	 1	 0.0	 0.0	 0.0	 34.44	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6755	 1	 18.42	 6.0	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6756	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6757	 1	 0.0	 0.0	 0.0	 6.57	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6758	 1	 53.66	 19.5	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6759	 1	 -0.0	 0.0	 0.0	 2.94	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6760	 1	 4.21	 1.2	 0.0	 30.55	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6761	 1	 34.35	 3.62	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6762	 1	 207.2	 28.6	 0.0	 13.85	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	6763	 1	 0.0	 -0.0	 0.0	 5.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6765	 1	 12.62	 7.8	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6766	 1	 -0.0	 0.0	 0.0	 5.12	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6767	 1	 -0.0	 0.0	 0.0	 5.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6768	 1	 27.53	 9.9	 0.0	 85.25	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6769	 1	 99.0	 23.2	 0.0	 10.16	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6770	 1	 60.27	 21.3	 0.0	 1.87	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6771	 1	 -0.0	 0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6772	 1	 61.37	 23.2	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6773	 1	 0.0	 -0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6774	 1	 34.14	 21.1	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6775	 1	 283.2	 101.8	 0.230421	 43.471474	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	6776	 1	 139.9	 -26.2	 0.0	 5.42	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6777	 1	 -1377.93	 -320.0	 0.0	 36.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6778	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6779	 1	 74.68	 46.3	 0.0	 12.92	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6780	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	6781	 1	 -0.0	 0.0	 0.0	 20.44	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6782	 1	 18.2	 2.6	 0.0	 12.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6783	 1	 140.1	 25.5	 0.0	 10.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6784	 1	 11.91	 4.4	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6785	 1	 0.0	 0.0	 0.0	 8.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6786	 1	 -6.77	 -2.13	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6787	 1	 0.0	 -0.0	 0.090774	 7.550444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6788	 1	 15.22	 3.9	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6789	 1	 0.0	 0.0	 0.0	 4.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6790	 1	 154.9	 25.0	 0.0	 72.89	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	6791	 1	 46.35	 9.1	 0.0	 18.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6792	 1	 43.35	 16.2	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6793	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6794	 1	 79.49	 17.0	 0.0	 29.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6795	 1	 -73.98	 -29.8	 0.0	 17.77	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6796	 1	 -0.0	 0.0	 0.0	 1.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6797	 1	 42.25	 5.9	 0.0	 13.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6798	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6799	 1	 253.4	 81.7	 0.0	 16.85	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	6800	 1	 -6.84	 -0.61	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6801	 1	 4.2	 0.7	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6802	 1	 -0.0	 0.0	 0.0	 7.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6803	 1	 55.76	 19.9	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6804	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6805	 1	 -0.5	 -0.17	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6806	 1	 135.84	 15.97	 0.0	 4.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6808	 1	 270.14	 57.56	 0.0	 4.32	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6809	 1	 76.79	 30.7	 0.0	 17.7	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6810	 1	 20.02	 10.0	 0.0	 8.08	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6811	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6812	 1	 55.7	 7.9	 0.0	 14.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6813	 1	 -0.0	 -0.0	 0.0	 15.06	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6814	 1	 0.0	 0.0	 0.0	 27.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6815	 1	 3.4	 1.1	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6817	 1	 106.0	 24.6	 0.0	 5.9	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6818	 1	 -0.0	 -0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6819	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6820	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6821	 1	 162.7	 23.2	 0.0	 4.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6822	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6823	 1	 36.84	 14.4	 0.0	 5.09	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6824	 1	 68.78	 28.2	 0.0	 0.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6825	 1	 211.1	 93.1	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6826	 1	 326.9	 -82.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	6827	 1	 55.46	 18.5	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6828	 1	 58.16	 16.5	 0.0	 6.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6829	 1	 46.2	 28.47	 0.0	 4.19	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6830	 1	 0.0	 -0.0	 0.0	 8.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6831	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6832	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6833	 1	 0.0	 0.0	 0.246363	 4.841277	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6834	 1	 3.8	 2.8	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6835	 1	 -0.15	 -1.93	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6836	 1	 184.88	 -21.11	 0.0	 39.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6837	 1	 47.75	 11.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6838	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6839	 1	 78.74	 17.8	 0.0	 0.58	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6840	 1	 0.0	 0.0	 0.0	 2.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6841	 1	 122.8	 20.8	 0.0	 0.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6842	 1	 98.0	 21.7	 0.0	 6.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6843	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6844	 1	 -0.0	 -0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6845	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6846	 1	 44.35	 19.3	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6847	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6848	 1	 153.3	 27.6	 0.0	 23.2	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6849	 1	 50.46	 36.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6850	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6851	 1	 2.5	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6852	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6853	 1	 71.08	 44.0	 0.0	 3.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6854	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6855	 1	 -16.82	 5.5	 0.0	 0.63	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6856	 1	 16.52	 5.5	 0.0	 3.5	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6857	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6858	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6859	 1	 -0.0	 8.5	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6860	 1	 0.0	 0.0	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 15	    1.10000	    0.90000;
	6861	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6862	 1	 -42.25	 2.8	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6863	 1	 -0.0	 -0.0	 0.0	 11.39	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6864	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6865	 1	 -0.0	 0.0	 0.0	 3.37	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6866	 1	 6.41	 2.1	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6867	 1	 1.2	 0.4	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6868	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6869	 1	 54.9	 -96.8	 0.0	 16.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6870	 1	 0.0	 0.0	 0.0	 3.67	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6871	 1	 0.0	 0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6872	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6873	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6874	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6875	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6876	 1	 1.8	 0.6	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6877	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6878	 1	 25.23	 8.3	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6879	 1	 199.6	 24.4	 0.0	 10.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6880	 1	 0.0	 0.0	 0.0	 1.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6881	 1	 11.41	 5.1	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6882	 1	 67.47	 6.1	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6883	 1	 0.0	 -0.0	 0.0	 12.4	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6884	 1	 -0.12	 -1.31	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6885	 1	 25.73	 15.9	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6886	 1	 119.3	 -2.8	 0.0	 0.87	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6887	 1	 -0.0	 -0.0	 0.0	 3.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6888	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6889	 1	 -12.49	 -5.83	 0.0	 6.235224	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6890	 1	 -0.0	 0.0	 0.0	 5.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6891	 1	 135.61	 26.86	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6892	 1	 -53.06	 -100.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6893	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6894	 1	 -1235.46	 -43.0	 0.0	 90.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6895	 1	 182.5	 47.0	 0.0	 33.69	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6896	 1	 8.31	 2.7	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6897	 1	 176.8	 39.4	 0.0	 28.24	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6898	 1	 31.03	 10.0	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6899	 1	 8.01	 2.6	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6900	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6901	 1	 -37.84	 -19.23	 0.0	 28.140258	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6902	 1	 0.3	 -9.0	 0.0	 1.96	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6903	 1	 20.0	 2.9	 0.0	 2.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6904	 1	 0.0	 0.0	 0.0	 6.97	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6905	 1	 -0.0	 -0.0	 0.0	 4.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6906	 1	 115.2	 55.1	 0.0	 30.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6907	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	6908	 1	 0.0	 0.0	 0.0	 3.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6909	 1	 122.5	 8.7	 0.0	 15.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6910	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6911	 1	 18.72	 7.7	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6912	 1	 -0.0	 0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6913	 1	 18.41	 41.8	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6915	 1	 11.71	 3.7	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6916	 1	 -0.0	 0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6917	 1	 -0.0	 -0.0	 0.0	 96.89	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6918	 1	 6.71	 1.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6919	 1	 21.62	 9.8	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6920	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6921	 1	 -37.34	 -13.33	 0.0	 251.529665	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6922	 1	 113.6	 44.7	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6923	 1	 33.34	 8.6	 0.0	 3.93	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6924	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	6925	 1	 -10.36	 -4.66	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	6926	 1	 124.5	 101.4	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6927	 1	 47.3	 6.7	 0.0	 4.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6928	 1	 0.0	 -0.0	 0.0	 1.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6929	 1	 -92.2	 -244.4	 0.0	 7.23	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	6931	 1	 20.9	 3.0	 0.0	 7.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6932	 1	 117.0	 20.4	 0.0	 22.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6933	 1	 -0.0	 0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6934	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6935	 1	 0.0	 0.0	 0.0	 2.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6936	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6937	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6938	 1	 3.2	 1.1	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6939	 1	 135.0	 25.7	 0.0	 43.01	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6940	 1	 0.0	 -0.0	 0.0	 10.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6941	 1	 43.7	 6.2	 0.0	 1.73	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6942	 1	 21.62	 7.8	 0.0	 1.43	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6943	 1	 -0.0	 0.0	 0.0	 1.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6944	 1	 -0.0	 -0.0	 0.0	 1.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6945	 1	 11.8	 1.7	 0.0	 3.85	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6946	 1	 0.2	 1.8	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6947	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6948	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6949	 1	 35.44	 5.3	 0.0	 2.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6950	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6951	 1	 22.8	 3.2	 0.0	 9.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6952	 1	 180.9	 33.2	 0.0	 29.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6953	 1	 61.77	 10.2	 0.0	 4.01	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6954	 1	 18.12	 10.0	 0.0	 1.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6955	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6956	 1	 86.5	 29.0	 0.0	 1.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6957	 1	 27.86	 14.22	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6958	 1	 20.02	 9.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6959	 1	 -0.0	 -0.0	 0.0	 4.07	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6960	 1	 389.8	 -68.1	 0.0	 5.03	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6961	 1	 56.56	 18.4	 0.0	 3.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6962	 1	 -0.0	 -0.0	 0.464351	 40.788627	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	6963	 1	 -0.0	 0.0	 0.0	 0.69	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6964	 1	 120.1	 2.5	 0.0	 6.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6965	 1	 125.0	 107.2	 0.21016	 53.165208	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6966	 1	 94.4	 13.5	 0.0	 5.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6967	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	6968	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6969	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6970	 1	 0.0	 0.0	 0.0	 27.8	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6971	 1	 0.0	 -0.0	 0.0	 7.51	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	6972	 1	 83.36	 2.6	 0.0	 1.06	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6973	 1	 92.1	 43.8	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6974	 1	 -0.0	 0.0	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6975	 1	 0.6	 0.1	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6976	 1	 36.04	 22.3	 0.0	 4.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6977	 1	 53.06	 75.8	 0.0	 51.93	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6978	 1	 -0.0	 -0.0	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6979	 1	 19.4	 2.8	 0.0	 9.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6980	 1	 -0.0	 -0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6981	 1	 195.5	 67.9	 0.0	 6.17	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6982	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6983	 1	 -0.0	 -0.0	 0.0	 12.69	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6984	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	6985	 1	 125.2	 1.2	 0.0	 15.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6986	 1	 -0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6987	 1	 112.1	 36.3	 0.0	 6.4	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6988	 1	 0.0	 0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6989	 1	 0.0	 0.0	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6990	 1	 -0.0	 0.0	 0.0	 4.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6991	 1	 -20.38	 -7.04	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6992	 1	 89.7	 17.5	 0.0	 4.06	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6993	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6994	 1	 0.0	 0.0	 0.0	 11.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6995	 1	 -0.0	 0.0	 0.0	 3.42	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	6996	 1	 0.0	 -0.0	 0.0	 1.37	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6997	 1	 190.3	 84.7	 0.0	 7.15	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6998	 1	 30.03	 8.6	 0.0	 21.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6999	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 19	    1.30000	    0.70000;
	7000	 1	 2.3	 0.8	 0.0	 0.06	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7001	 1	 46.35	 28.7	 0.0	 16.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7002	 1	 51.16	 12.0	 0.0	 6.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7003	 1	 2.9	 0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7004	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7005	 1	 10.01	 2.0	 0.0	 0.61	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	7006	 1	 -0.0	 0.0	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7007	 1	 9.31	 0.8	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	7008	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	7009	 1	 4.2	 0.6	 0.0	 7.92	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7010	 1	 -0.0	 0.0	 0.090774	 2.110444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7011	 1	 84.59	 21.7	 0.0	 7.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7012	 1	 -15.12	 5.0	 0.0	 0.25	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7013	 1	 18.5	 3.8	 0.0	 0.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7014	 1	 0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7015	 1	 -0.0	 -0.0	 0.0	 3.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7016	 1	 190.0	 72.7	 0.0	 30.78	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7017	 1	 0.0	 -0.0	 0.149251	 110.015393	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	7018	 1	 53.26	 29.5	 0.0	 41.35	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7019	 1	 52.56	 12.8	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7020	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7021	 1	 226.8	 53.3	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7022	 1	 14.92	 5.4	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7023	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7024	 1	 -0.0	 0.0	 0.0	 1.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7025	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7026	 1	 0.0	 0.0	 0.0	 51.27	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7027	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7028	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7029	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7030	 1	 0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7031	 1	 -0.0	 -0.0	 0.0	 42.94	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7032	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7033	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 15	    1.30000	    0.70000;
	7034	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7035	 1	 0.0	 -0.0	 0.386679	 23.856092	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7037	 1	 -0.0	 -0.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7038	 1	 19.52	 6.4	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7039	 1	 324.9	 37.3	 0.0	 10.15	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7040	 1	 21.82	 6.3	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7041	 1	 -175.8	 -19.6	 0.0	 14.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7042	 1	 220.98	 91.0	 0.0	 1.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7043	 1	 6.91	 1.9	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7044	 1	 120.6	 35.1	 0.0	 20.052	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7045	 1	 1.9	 -0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7046	 1	 0.0	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7047	 1	 339.9	 70.5	 0.0	 28.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7048	 1	 12.91	 5.1	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7049	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7050	 1	 120.0	 26.0	 0.0	 22.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7051	 1	 0.0	 0.0	 0.0	 21.19	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7052	 1	 111.0	 36.6	 0.0	 2.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7053	 1	 -0.0	 0.0	 0.0	 34.13	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7054	 1	 129.7	 27.1	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7055	 1	 125.2	 8.5	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7057	 1	 -0.0	 0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7058	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7059	 1	 28.93	 8.3	 0.0	 0.42	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7060	 1	 0.0	 0.0	 0.0	 4.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7061	 1	 0.0	 0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7062	 1	 -20.12	 6.6	 0.0	 3.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7063	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	7064	 1	 -0.0	 0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7065	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	7066	 1	 41.25	 48.4	 0.0	 16.52	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7067	 1	 6.31	 5.1	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7068	 1	 2.8	 1.0	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7069	 1	 258.79	 42.82	 0.0	 9.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7070	 1	 142.9	 25.8	 0.0	 24.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7071	 1	 80.19	 23.6	 0.0	 19.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7072	 1	 62.67	 14.6	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7073	 1	 -0.0	 -0.0	 0.0	 15.47	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7074	 1	 15.72	 9.7	 0.0	 1.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7075	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7076	 1	 0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7077	 1	 18.82	 6.8	 0.0	 2.15	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7078	 1	 -13.82	 4.6	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7079	 1	 -0.0	 0.0	 0.0	 2.2	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7080	 1	 -0.0	 -0.0	 0.0	 1.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7081	 1	 -0.0	 -0.0	 0.0	 63.75	 0	    1.00000	    0.00000	 380.0	 22	    1.10000	    0.90000;
	7082	 1	 152.2	 53.2	 0.0	 33.26	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7083	 1	 0.0	 -0.0	 0.0	 27.92	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7084	 1	 236.6	 33.7	 0.0	 0.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7086	 1	 10.81	 3.6	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7087	 1	 20.22	 7.3	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7088	 1	 -0.0	 -0.0	 0.0	 30.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7089	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	7090	 1	 82.89	 41.3	 0.0	 36.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7091	 1	 0.0	 0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7092	 1	 44.65	 8.8	 0.0	 20.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7093	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7094	 1	 22.3	 3.1	 0.0	 4.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7095	 1	 -0.0	 -0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7096	 1	 -0.0	 -0.0	 0.0	 57.66	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7097	 1	 109.5	 33.6	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7098	 1	 0.0	 -0.0	 0.0	 7.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7099	 1	 102.0	 26.6	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7100	 1	 35.94	 22.3	 0.0	 1.63	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7101	 1	 4.61	 1.7	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7102	 1	 -0.0	 0.0	 0.185509	 0.457193	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7103	 1	 0.0	 0.0	 0.0	 16.39	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7104	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7105	 1	 0.0	 0.0	 0.0	 7.46	 0	    1.00000	    0.00000	 380.0	 12	    1.10000	    0.90000;
	7106	 1	 -0.0	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	7108	 1	 282.5	 56.2	 0.0	 8.6	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7109	 1	 -0.0	 0.0	 0.0	 1.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7110	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7111	 1	 0.0	 -0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7112	 1	 0.1	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7113	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7114	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	7115	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7116	 1	 117.5	 91.0	 0.373436	 45.743751	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7117	 1	 0.0	 -0.6	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7118	 1	 0.0	 0.0	 0.0	 39.83	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	7119	 1	 149.53	 34.9	 0.0	 8.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7120	 1	 0.0	 -0.0	 0.0	 6.17	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7121	 1	 29.43	 10.7	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7122	 1	 0.0	 -0.0	 0.0	 13.03	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	7123	 1	 38.34	 12.5	 0.0	 1.59	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7124	 1	 -0.0	 0.0	 0.0	 16.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7125	 1	 0.1	 2.2	 0.0	 1.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7126	 1	 5.71	 3.0	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7127	 1	 231.2	 103.5	 0.0	 10.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7128	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7129	 1	 33.34	 5.0	 0.0	 0.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7130	 1	 19.32	 7.0	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7131	 1	 -4.73	 4.23	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	7132	 1	 222.0	 90.5	 0.0	 0.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7133	 1	 102.3	 19.0	 0.0	 1.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7135	 1	 0.0	 0.0	 0.321419	 66.618267	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7136	 1	 29.23	 9.4	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7138	 1	 150.2	 51.6	 0.0	 2.79	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7139	 1	 99.4	 22.2	 0.0	 2.16	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7140	 1	 51.0	 7.3	 0.0	 6.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7141	 1	 64.2	 26.4	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	7142	 1	 32.34	 16.8	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7143	 1	 0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7144	 1	 8.48	 -1.82	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7145	 1	 46.75	 24.4	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7146	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7147	 1	 41.8	 5.9	 0.0	 7.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7148	 1	 -0.0	 -0.0	 0.0	 10.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7149	 1	 6.01	 2.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7150	 1	 26.03	 -14.1	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	7151	 1	 -0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7152	 1	 89.8	 19.7	 0.0	 0.36	 0	    1.00000	    0.00000	 120.0	 20	    1.10000	    0.90000;
	7153	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	7154	 1	 73.58	 26.8	 0.0	 3.76	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7155	 1	 -8.01	 -3.24	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	7156	 1	 -0.0	 -0.0	 0.0	 14.82	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7157	 1	 0.0	 -0.0	 0.0	 10.34	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7158	 1	 -0.0	 0.0	 0.0	 40.44	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7159	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7160	 1	 0.0	 -0.0	 0.0	 9.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7161	 1	 122.8	 20.4	 0.0	 0.77	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7162	 1	 -0.0	 0.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7163	 1	 -0.0	 0.0	 0.0	 2.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7164	 1	 -18.6	 -6.72	 0.0	 152.683271	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7165	 1	 -0.0	 -0.0	 0.0	 9.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7166	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7167	 1	 64.47	 40.0	 0.0	 5.82	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7168	 1	 -20.82	 6.8	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7169	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7170	 1	 -1083.9	 -433.7	 0.0	 2.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7171	 1	 0.1	 -9.6	 0.0	 1.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7172	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7173	 1	 51.7	 7.4	 0.0	 2.07	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7174	 1	 77.91	 5.03	 0.0	 19.71	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7175	 1	 -0.0	 0.0	 0.0	 10.22	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7176	 1	 10.21	 3.3	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7177	 1	 17.62	 7.7	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7178	 1	 -0.0	 -0.0	 0.0	 2.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7179	 1	 47.0	 6.7	 0.0	 6.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7180	 1	 -0.0	 0.0	 0.234234	 4.220723	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7181	 1	 1.0	 0.2	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7182	 1	 290.8	 30.5	 0.0	 29.529841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	7184	 1	 16.7	 2.4	 0.0	 3.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7185	 1	 -18.52	 6.1	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7186	 1	 4.75	 -0.16	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7187	 1	 7.21	 2.4	 0.0	 1.67	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7188	 1	 25.1	 3.6	 0.0	 6.2	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7189	 1	 -0.0	 0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7190	 1	 -0.0	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7191	 1	 55.46	 15.7	 0.0	 13.46	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7192	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7193	 1	 -0.0	 -0.0	 0.0	 7.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7194	 1	 456.6	 227.7	 0.0	 0.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7195	 1	 99.9	 19.9	 0.0	 6.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7196	 1	 72.68	 1.1	 0.0	 6.06	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7197	 1	 -0.0	 0.0	 0.08	 4.38	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7198	 1	 83.19	 21.8	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7199	 1	 6.31	 1.3	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7200	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7201	 1	 8.11	 3.8	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7202	 1	 18.62	 6.1	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7203	 1	 43.25	 15.7	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7204	 1	 -241.32	 -48.72	 0.0	 16.62	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	7205	 1	 48.05	 23.0	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	7206	 1	 8.3	 1.2	 0.0	 3.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7207	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7208	 1	 46.55	 15.5	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7209	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7210	 1	 -0.0	 0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	7211	 1	 6.61	 1.6	 0.0	 2.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7212	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7213	 1	 20.9	 3.0	 0.0	 0.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7214	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	7215	 1	 19.22	 3.8	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7216	 1	 -0.0	 0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7217	 1	 -0.0	 -0.0	 0.0	 3.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7218	 1	 0.0	 -0.0	 0.0	 6.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7219	 1	 89.7	 40.5	 0.0	 38.13	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7220	 1	 -0.0	 0.2	 0.0	 2.19	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7221	 1	 17.72	 6.3	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7222	 1	 0.0	 -0.0	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7223	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7224	 1	 0.0	 -0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7225	 1	 -0.0	 0.0	 0.181549	 13.990889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7226	 1	 144.0	 31.3	 0.0	 3.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7227	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7228	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	7229	 1	 0.0	 -0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7230	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7231	 1	 0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7232	 1	 7.61	 2.5	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7233	 1	 -0.0	 0.0	 0.0	 21.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7234	 1	 388.7	 97.7	 0.0	 41.94	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7235	 1	 0.0	 0.0	 0.0	 3.6	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7236	 1	 0.0	 0.0	 0.0	 1.99	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7237	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7238	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7239	 1	 200.4	 115.2	 0.0	 6.18	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7240	 1	 0.0	 -0.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7241	 1	 11.21	 3.7	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7242	 1	 3.4	 1.2	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7243	 1	 -0.0	 -0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7244	 1	 16.7	 2.4	 0.0	 1.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7245	 1	 -0.0	 -0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7246	 1	 7.41	 2.7	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7247	 1	 -0.0	 -0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7248	 1	 233.2	 39.4	 0.0	 104.569841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7249	 1	 37.94	 9.8	 0.0	 2.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7250	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7251	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7252	 1	 220.8	 68.6	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7253	 1	 7.51	 3.1	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7254	 1	 0.0	 -0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7255	 1	 4.61	 1.5	 0.0	 1.23	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7256	 1	 392.25	 92.02	 0.0	 9.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7257	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7258	 1	 10.61	 3.5	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7259	 1	 82.39	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7260	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7261	 1	 96.7	 23.7	 0.0	 39.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7262	 1	 -0.0	 -0.0	 0.0	 35.98	 0	    1.00000	    0.00000	 380.0	 12	    1.10000	    0.90000;
	7263	 1	 185.0	 26.3	 0.0	 11.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7264	 1	 0.0	 -0.0	 0.0	 3.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7265	 1	 7.61	 3.8	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7266	 1	 -0.0	 -0.0	 0.0	 2.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7268	 1	 406.3	 92.5	 0.0	 66.92	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7269	 1	 0.0	 0.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7270	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7271	 1	 -0.0	 0.0	 0.090774	 6.600444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7272	 1	 18.62	 6.7	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	7273	 1	 219.6	 36.4	 0.0	 17.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7274	 1	 54.93	 16.5	 0.0	 6.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7275	 1	 79.39	 31.3	 0.0	 2.23	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7276	 1	 -0.0	 -0.0	 0.0	 8.38	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7277	 1	 0.0	 0.0	 0.0	 10.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7279	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	7280	 1	 7.41	 2.7	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7281	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7282	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7283	 1	 101.1	 6.6	 0.0	 5.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7284	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7285	 1	 0.0	 -0.0	 0.0	 20.08	 0	    1.00000	    0.00000	 380.0	 12	    1.30000	    0.70000;
	7286	 1	 11.91	 4.4	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	7287	 1	 0.0	 -0.0	 0.0	 46.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7288	 1	 0.0	 0.0	 0.0	 4.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7289	 1	 0.0	 -0.0	 0.0	 26.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7290	 1	 0.0	 -0.0	 0.0	 21.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7291	 1	 0.0	 0.0	 0.0	 15.49	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7292	 1	 11.71	 3.8	 0.0	 2.39	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7293	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7294	 1	 2.7	 0.8	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7295	 1	 -0.0	 0.0	 0.0	 2.63	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7296	 1	 36.84	 13.3	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7297	 1	 -0.0	 0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7298	 1	 97.41	 -4.48	 0.0	 16.55	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7299	 1	 0.0	 -0.0	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7300	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7301	 1	 36.04	 12.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7302	 1	 0.0	 -0.0	 0.0	 2.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7303	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7304	 1	 0.4	 0.1	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7305	 1	 82.89	 32.6	 0.0	 45.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7306	 1	 -0.0	 0.0	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7307	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7308	 1	 -9.86	 -2.8	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7309	 1	 0.0	 -0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7310	 1	 256.0	 69.9	 0.0	 43.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7311	 1	 102.6	 12.0	 0.0	 66.849841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7312	 1	 56.66	 15.6	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7313	 1	 0.0	 0.0	 0.0	 16.07	 0	    1.00000	    0.00000	 380.0	 23	    1.30000	    0.70000;
	7314	 1	 0.0	 0.0	 0.12635	 23.056325	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	7315	 1	 29.53	 2.4	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	7316	 1	 -0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7317	 1	 210.9	 48.3	 0.0	 9.75	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7318	 1	 0.0	 0.0	 0.0	 2.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7319	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7320	 1	 0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7321	 1	 201.4	 47.5	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7322	 1	 36.94	 62.6	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7323	 1	 18.22	 6.3	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7324	 1	 0.0	 0.0	 0.0	 2.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7325	 1	 0.0	 0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7326	 1	 69.7	 9.9	 0.0	 1.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7327	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 15	    1.30000	    0.70000;
	7331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7332	 1	 -0.0	 0.0	 0.0	 11.4	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7333	 1	 36.54	 22.6	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7334	 1	 26.43	 9.9	 0.0	 9.57	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7335	 1	 25.13	 14.0	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7336	 1	 45.75	 15.8	 0.0	 3.42	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7337	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7338	 1	 0.0	 -0.0	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7339	 1	 0.0	 -0.0	 0.0	 8.41	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7340	 1	 23.83	 8.6	 0.0	 3.08	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7341	 1	 37.44	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7342	 1	 169.0	 70.8	 0.0	 5.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7343	 1	 -0.0	 0.0	 0.0	 61.36	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7344	 1	 31.03	 8.9	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7345	 1	 0.0	 0.0	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7346	 1	 -0.0	 0.0	 0.0	 17.3	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7347	 1	 101.3	 17.6	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7348	 1	 16.52	 6.3	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.30000	    0.70000;
	7349	 1	 75.56	 13.04	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7350	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7351	 1	 61.67	 16.3	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7352	 1	 0.0	 -0.0	 0.0	 4.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7353	 1	 127.3	 26.7	 0.0	 7.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7354	 1	 28.53	 11.5	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7355	 1	 0.0	 0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7356	 1	 12.71	 4.2	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7357	 1	 0.0	 -0.0	 0.0	 3.77	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7358	 1	 -40.95	 -28.4	 0.0	 7.29	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7359	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7360	 1	 88.2	 21.0	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7361	 1	 -0.0	 -0.0	 0.0	 14.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7362	 1	 223.31	 61.3	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7363	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7364	 1	 -0.0	 -0.0	 0.23465	 19.69065	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	7365	 1	 6.31	 1.3	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7366	 1	 70.48	 22.5	 0.0	 4.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7367	 1	 1.5	 0.4	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7368	 1	 -0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7369	 1	 -0.0	 0.0	 0.0	 7.35	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7370	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7371	 1	 34.9	 5.0	 0.0	 2.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7372	 1	 10.01	 4.3	 0.0	 5.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7373	 1	 0.0	 -0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7374	 1	 -0.2	 -0.83	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7375	 1	 53.06	 19.2	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7376	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	7377	 1	 0.0	 0.0	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7378	 1	 -0.0	 0.0	 0.0	 14.06	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7379	 1	 41.5	 5.9	 0.0	 8.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7380	 1	 105.67	 0.56	 0.0	 18.05	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7381	 1	 -0.0	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7382	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7383	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	7384	 1	 6.11	 2.2	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7385	 1	 1.1	 0.0	 0.0	 1.53	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7386	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7387	 1	 -0.0	 -0.0	 0.0	 1.68	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7388	 1	 0.0	 0.0	 0.0	 12.79	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7389	 1	 0.0	 -0.0	 0.0	 4.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7390	 1	 16.62	 5.5	 0.0	 1.68	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7391	 1	 -23.83	 7.8	 0.0	 2.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7392	 1	 142.0	 27.8	 0.0	 17.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7393	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	7394	 1	 55.66	 22.4	 0.0	 2.11	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7395	 1	 0.0	 -0.0	 0.0	 87.69	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7396	 1	 -0.0	 0.0	 0.0	 5.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7397	 1	 41.45	 17.3	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7398	 1	 100.3	 17.2	 0.0	 6.63	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7399	 1	 168.9	 113.0	 0.0	 123.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7400	 1	 30.03	 18.6	 0.0	 0.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7401	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7402	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7403	 1	 59.67	 6.0	 0.0	 3.6	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7404	 1	 19.02	 5.4	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7405	 1	 0.0	 -0.8	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	7406	 1	 94.5	 -27.8	 0.0	 5.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7407	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7408	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7409	 1	 0.0	 -0.0	 0.0	 1.03	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	7410	 1	 107.2	 45.6	 0.0	 5.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7411	 1	 -0.0	 0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7412	 1	 -0.0	 -0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7413	 1	 33.64	 13.7	 0.0	 0.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7414	 1	 23.43	 8.5	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7415	 1	 16.22	 5.0	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7416	 1	 -0.0	 0.0	 0.153313	 36.266993	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7417	 1	 106.4	 19.0	 0.0	 4.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7418	 1	 0.0	 0.0	 0.099436	 90.374061	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	7419	 1	 18.02	 12.2	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7420	 1	 415.5	 103.4	 0.0	 37.13	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7421	 1	 8.11	 2.7	 0.0	 2.03	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7422	 1	 65.67	 25.6	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7423	 1	 -0.0	 0.0	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7424	 1	 123.1	 20.9	 0.0	 25.95	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7425	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7426	 1	 1.8	 0.6	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7427	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	7428	 1	 0.0	 -0.0	 0.0	 120.17	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7429	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7430	 1	 60.37	 54.7	 0.0	 0.62	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7431	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7432	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	7433	 1	 116.8	 59.0	 0.0	 1.63	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7434	 1	 0.0	 0.0	 0.0	 13.33	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7435	 1	 0.0	 -0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7436	 1	 0.0	 -0.0	 0.0	 19.61	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7437	 1	 18.32	 5.3	 0.0	 7.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7438	 1	 121.3	 20.7	 0.0	 2.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7439	 1	 12.71	 2.5	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7440	 1	 0.0	 -0.0	 0.0	 22.76	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7441	 1	 5.44	 2.14	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7442	 1	 -0.0	 0.0	 0.0	 36.77	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7443	 1	 0.0	 0.0	 0.0	 17.05	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7444	 1	 111.9	 118.3	 0.0	 11.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7445	 1	 -0.0	 0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7446	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7447	 1	 34.9	 5.0	 0.0	 3.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7448	 1	 -0.0	 0.0	 0.0	 92.73	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	7449	 1	 15.96	 2.18	 0.0	 3.58	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7450	 1	 108.8	 28.1	 0.0	 30.9	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7451	 1	 227.49	 61.6	 0.0	 13.7	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7452	 1	 49.45	 16.5	 0.0	 4.13	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7453	 1	 -0.0	 0.0	 0.0	 1.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7454	 1	 -0.0	 -0.0	 0.0	 3.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7455	 1	 -0.0	 0.0	 0.135493	 90.112445	 0	    1.00000	    0.00000	 380.0	 19	    1.30000	    0.70000;
	7456	 1	 9.01	 3.3	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7457	 1	 96.2	 23.3	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7458	 1	 0.0	 -0.0	 0.0	 83.185177	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	7459	 1	 -7.41	 -1.6	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7460	 1	 -0.0	 -0.0	 0.0	 37.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7461	 1	 10.11	 3.7	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7462	 1	 -0.0	 -0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7463	 1	 178.7	 31.3	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7464	 1	 0.0	 -0.0	 0.0	 7.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7465	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7466	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7467	 1	 -11.14	 -3.38	 0.0	 2.35	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7468	 1	 15.72	 5.2	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7469	 1	 1.5	 0.4	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7470	 1	 13.72	 8.5	 0.0	 19.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7471	 1	 -18.95	 -6.93	 0.0	 33.11439	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7472	 1	 -0.0	 -0.0	 0.0	 20.52	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	7473	 1	 251.47	 90.86	 0.0	 14.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7475	 1	 84.79	 12.5	 0.0	 2.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7476	 1	 59.67	 27.1	 0.0	 43.03	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7477	 1	 106.8	 22.2	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7478	 1	 47.95	 29.7	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7479	 1	 0.0	 0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7480	 1	 -0.18	 -3.54	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7481	 1	 0.0	 0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7482	 1	 -0.0	 0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7483	 1	 -1316.59	 -129.9	 0.234668	 22.607741	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7484	 1	 0.4	 0.1	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7485	 1	 44.35	 10.8	 0.0	 8.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7486	 1	 4.41	 2.7	 0.0	 1.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7487	 1	 38.04	 18.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7488	 1	 0.2	 0.7	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7489	 1	 70.08	 35.0	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7490	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7491	 1	 0.0	 -0.0	 0.0	 4.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7492	 1	 -0.0	 -0.0	 0.0	 43.34	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7493	 1	 0.0	 -0.0	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7494	 1	 -6.79	 -1.45	 0.0	 6.66	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7495	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7496	 1	 10.11	 3.7	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7497	 1	 4.4	 2.2	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7498	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7499	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7500	 1	 136.2	 4.8	 0.0	 7.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7501	 1	 39.84	 24.6	 0.0	 13.99	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7502	 1	 128.9	 73.7	 0.0	 25.37	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7503	 1	 -0.0	 -0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7504	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7505	 1	 0.0	 0.0	 0.0	 5.56	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7506	 1	 0.0	 -0.0	 0.135375	 8.900675	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	7507	 1	 4.0	 0.8	 0.0	 17.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7508	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7509	 1	 88.0	 36.2	 0.0	 60.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7510	 1	 46.35	 14.9	 0.0	 20.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7511	 1	 0.1	 -0.0	 0.0	 5.01	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7512	 1	 -0.0	 -0.0	 0.0	 2.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7513	 1	 0.0	 -0.0	 0.0	 38.549494	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7514	 1	 1.4	 100.0	 0.0	 21.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7515	 1	 -0.0	 -0.0	 0.090774	 3.150444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7516	 1	 3.8	 0.6	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7517	 1	 9.01	 4.0	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	7518	 1	 -14.89	 -4.46	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7519	 1	 97.97	 31.8	 0.0	 5.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7520	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7521	 1	 0.0	 0.0	 0.15	 5.08	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	7522	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7523	 1	 -0.0	 0.0	 0.0	 2.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7524	 1	 -0.0	 -0.0	 0.0	 6.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7525	 1	 -8.66	 -6.01	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7526	 1	 0.0	 -0.0	 0.0	 1.88	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7527	 1	 125.4	 17.8	 0.0	 7.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7528	 1	 211.0	 59.3	 0.0	 3.46	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7529	 1	 -0.0	 0.0	 0.0	 13.62	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7530	 1	 0.0	 0.0	 0.0	 31.242294	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7531	 1	 26.23	 8.4	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7532	 1	 13.82	 5.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	7533	 1	 43.15	 15.4	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	7534	 1	 20.62	 6.7	 0.0	 0.71	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7535	 1	 0.0	 0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7536	 1	 21.83	 6.3	 0.0	 2.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7537	 1	 0.0	 0.0	 0.0	 17.184121	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7538	 1	 130.5	 17.2	 0.0	 5.65	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7539	 1	 40.85	 15.7	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7540	 1	 -0.0	 0.0	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7541	 1	 346.42	 89.04	 0.0	 43.55	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7542	 1	 -0.0	 0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7543	 1	 72.48	 44.9	 0.0	 3.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7544	 1	 29.65	 7.18	 0.0	 4.51	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7545	 1	 0.0	 0.0	 0.237048	 35.833975	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7546	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7547	 1	 -0.0	 -0.0	 0.0	 26.93	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	7548	 1	 281.3	 40.9	 0.0	 33.56	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	7549	 1	 20.92	 9.35	 0.0	 1.56	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7550	 1	 0.0	 -0.0	 0.0	 5.55	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7551	 1	 101.48	 19.53	 0.0	 4.41	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7552	 1	 -0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7553	 1	 -0.0	 0.0	 0.0	 22.68	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	7554	 1	 2.9	 1.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7555	 1	 2.1	 0.8	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7556	 1	 0.0	 -0.0	 0.0	 3.1	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7557	 1	 34.44	 12.1	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	7558	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7559	 1	 8.98	 -3.79	 0.0	 2.86	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7560	 1	 34.64	 12.4	 0.0	 2.66	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7561	 1	 0.0	 0.0	 0.0	 20.54	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7562	 1	 218.0	 18.6	 0.0	 36.29	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	7563	 1	 531.7	 -12.8	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	7564	 1	 -0.0	 0.0	 0.0	 -0.17	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7565	 1	 -0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7566	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7567	 1	 13.9	 1.9	 0.0	 2.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7568	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	7569	 1	 0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7570	 1	 80.8	 11.6	 0.0	 6.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7571	 1	 -0.0	 -0.0	 0.0	 13.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7572	 1	 0.0	 0.0	 0.0	 48.75	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	7573	 1	 126.6	 28.7	 0.0	 15.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7574	 1	 0.0	 -0.0	 0.0	 2.12	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7575	 1	 29.03	 6.1	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7576	 1	 0.0	 0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7577	 1	 0.0	 0.0	 0.0	 6.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7578	 1	 45.95	 15.4	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7579	 1	 136.9	 11.4	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7580	 1	 0.0	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7581	 1	 32.1	 4.5	 0.0	 3.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7582	 1	 0.0	 -0.0	 0.0	 3.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7583	 1	 5.01	 1.8	 0.0	 3.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7584	 1	 127.6	 45.3	 0.0	 57.43	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7585	 1	 27.93	 8.9	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7586	 1	 -18.27	 -12.99	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7587	 1	 -0.0	 -0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7588	 1	 10.11	 4.4	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7589	 1	 9.71	 3.2	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7590	 1	 0.0	 0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7591	 1	 11.21	 3.7	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7592	 1	 159.4	 -7.3	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7593	 1	 58.77	 16.1	 0.0	 4.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7594	 1	 116.5	 33.4	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7595	 1	 30.43	 10.0	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7596	 1	 59.07	 23.4	 0.0	 21.88	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7597	 1	 18.02	 4.0	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	7598	 1	 0.5	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7599	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7600	 1	 119.0	 31.7	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7601	 1	 -0.0	 0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7602	 1	 119.7	 43.4	 0.0	 0.92	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7603	 1	 5.51	 2.2	 0.0	 1.43	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7604	 1	 87.0	 30.8	 0.0	 2.43	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7605	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7606	 1	 2.8	 0.5	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7607	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7608	 1	 8.31	 3.0	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7609	 1	 24.03	 -56.8	 0.0	 2.69	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7610	 1	 26.82	 24.2	 0.0	 2.89	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7611	 1	 115.4	 31.0	 0.0	 28.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7612	 1	 -20.12	 6.6	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7613	 1	 6.31	 2.5	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7614	 1	 41.8	 5.9	 0.0	 2.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7615	 1	 70.48	 17.6	 0.0	 3.92	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7616	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	7617	 1	 -0.0	 0.0	 0.203547	 31.507823	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7618	 1	 -0.0	 -0.0	 0.0	 1.69	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7619	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7620	 1	 136.95	 87.7	 0.0	 7.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7621	 1	 0.0	 0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7622	 1	 0.0	 0.0	 0.0	 14.94	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7623	 1	 90.5	 12.8	 0.0	 6.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7624	 1	 32.74	 10.5	 0.0	 1.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7625	 1	 164.41	 101.14	 0.0	 61.4	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	7626	 1	 78.89	 45.6	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	7628	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7629	 1	 0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7630	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7631	 1	 -0.0	 0.0	 0.0	 2.82	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7632	 1	 37.94	 3.4	 0.0	 11.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7633	 1	 91.6	 20.3	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7634	 1	 5.5	 0.8	 0.0	 1.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7635	 1	 0.0	 0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7636	 1	 -12.62	 11.6	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7637	 1	 0.0	 0.0	 0.29	 6.18	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7638	 1	 429.5	 163.1	 0.0	 28.67	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	7639	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7640	 1	 68.78	 35.0	 0.0	 34.52	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7642	 1	 0.0	 -0.0	 0.0	 138.75	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7643	 1	 90.3	 5.7	 0.0	 19.04	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7644	 1	 124.1	 -30.3	 0.0	 14.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7645	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7646	 1	 0.0	 0.0	 0.0	 33.48	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7647	 1	 -0.0	 -0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7648	 1	 15.12	 5.4	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	7649	 1	 29.13	 11.3	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7650	 1	 439.0	 254.8	 0.0	 148.04	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7651	 1	 61.97	 38.4	 0.0	 7.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7652	 1	 255.3	 78.7	 0.0	 6.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7653	 1	 33.94	 11.4	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7654	 1	 41.8	 5.9	 0.0	 3.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7655	 1	 117.0	 15.2	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	7657	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	7658	 1	 -0.0	 -0.0	 0.0	 35.28	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7659	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7660	 1	 -0.0	 0.0	 0.090774	 5.169044	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7661	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7662	 1	 -0.21	 -2.37	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7663	 1	 37.14	 2.7	 0.0	 2.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7664	 1	 256.8	 -61.8	 0.0	 36.73	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7665	 1	 16.52	 5.5	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7666	 1	 93.4	 27.8	 0.0	 29.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7667	 1	 42.66	 -22.22	 0.0	 0.66	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7668	 1	 27.7	 4.0	 0.0	 13.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7669	 1	 67.08	 25.2	 0.0	 8.11	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7671	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7672	 1	 -0.0	 -0.0	 0.0	 35.53	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7673	 1	 20.82	 7.9	 0.0	 42.36	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7674	 1	 0.0	 0.0	 0.24033	 46.858516	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	7675	 1	 66.07	 21.6	 0.0	 0.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7677	 1	 0.0	 -0.0	 0.0	 5.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7678	 1	 0.0	 0.0	 0.0	 2.257591	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	7679	 1	 -0.0	 -0.0	 0.0	 9.70055	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	7680	 1	 -22.2	 -5.79	 0.0	 5.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7681	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7682	 1	 0.0	 -0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7683	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7684	 1	 -0.0	 0.0	 0.0	 1.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7685	 1	 49.45	 6.5	 0.0	 3.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7686	 1	 -0.0	 0.0	 0.0	 48.77	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7687	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7688	 1	 12.71	 5.1	 0.0	 15.31	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7689	 1	 95.6	 13.6	 0.0	 21.47	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7690	 1	 0.0	 0.0	 0.0	 5.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7691	 1	 0.0	 -0.0	 0.0	 96.48	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7692	 1	 0.0	 -0.0	 0.17252	 3.43811	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7693	 1	 25.13	 15.6	 0.0	 4.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7694	 1	 -14.96	 -4.7	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7695	 1	 0.0	 0.0	 0.0	 10.69	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	7696	 1	 10.91	 2.5	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7698	 1	 0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7699	 1	 -0.0	 0.0	 0.0	 19.62	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7700	 1	 66.17	 27.4	 0.0	 14.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7701	 1	 11.91	 3.5	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7702	 1	 -0.0	 -0.0	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7703	 1	 51.96	 6.5	 0.0	 5.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7704	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7705	 1	 0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7706	 1	 -0.0	 0.0	 0.0	 1.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7707	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7708	 1	 0.2	 88.5	 0.0	 2.21	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7709	 1	 2.2	 0.5	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7710	 1	 60.07	 36.0	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7711	 1	 126.2	 -12.5	 0.0	 10.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7712	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7713	 1	 15.12	 4.9	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7714	 1	 0.0	 0.0	 0.0	 1.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7715	 1	 85.9	 93.8	 0.0	 3.93	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7716	 1	 15.6	 2.2	 0.0	 2.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7717	 1	 0.0	 0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7718	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7719	 1	 -0.0	 0.0	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7720	 1	 70.78	 43.8	 0.0	 2.12	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	7721	 1	 38.94	 11.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	7722	 1	 17.02	 5.5	 0.0	 1.02	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7723	 1	 220.2	 83.2	 0.0	 0.61	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	7724	 1	 39.64	 4.4	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	7725	 1	 65.97	 64.1	 0.0	 29.14	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7726	 1	 0.0	 0.0	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7727	 1	 46.05	 22.0	 0.0	 2.95	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7728	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7729	 1	 20.82	 6.7	 0.0	 2.25	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7730	 1	 0.0	 0.0	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7731	 1	 71.58	 48.2	 0.288552	 130.762047	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7732	 1	 137.0	 33.2	 0.0	 3.82	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7733	 1	 7.0	 1.0	 0.0	 1.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7734	 1	 65.57	 44.6	 0.0	 5.95	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7735	 1	 -0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7736	 1	 0.0	 -0.0	 0.0	 55.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7737	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7738	 1	 31.84	 9.2	 0.0	 5.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7739	 1	 82.29	 29.6	 0.0	 1.86	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7740	 1	 0.0	 -0.0	 0.0	 0.97	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7741	 1	 -24.99	 -4.94	 0.0	 6.99	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7742	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7743	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7744	 1	 8.31	 3.0	 0.0	 1.37	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7745	 1	 24.23	 4.7	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7746	 1	 58.5	 8.3	 0.0	 4.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7747	 1	 -0.0	 -0.0	 0.0	 5.53	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7748	 1	 122.7	 -29.8	 0.0	 7.11	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7749	 1	 10.9	 1.6	 0.0	 1.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7750	 1	 0.0	 -0.0	 0.0	 9.41	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7751	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7752	 1	 524.5	 126.0	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7753	 1	 -0.0	 0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7754	 1	 76.6	 10.9	 0.0	 2.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7755	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7756	 1	 8.03	 5.5	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7757	 1	 17.52	 5.7	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7758	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	7759	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	7760	 1	 10.61	 1.0	 0.0	 1.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7761	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7762	 1	 -0.0	 0.0	 0.304243	 48.453399	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7763	 1	 -0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7764	 1	 0.0	 -0.0	 0.0	 25.67	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7765	 1	 11.01	 3.6	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7766	 1	 78.89	 25.6	 0.0	 1.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7767	 1	 0.0	 -0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7768	 1	 11.91	 3.9	 0.0	 2.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7769	 1	 3.4	 0.5	 0.0	 3.28	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7770	 1	 47.15	 15.5	 0.0	 9.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7771	 1	 -0.0	 0.0	 0.0	 13.4	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7772	 1	 223.6	 51.8	 0.0	 18.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7773	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7774	 1	 27.23	 10.1	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7775	 1	 151.5	 7.9	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	7777	 1	 -0.0	 -0.0	 0.0	 49.86	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	7778	 1	 153.0	 21.5	 0.0	 28.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7779	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7780	 1	 0.0	 0.0	 0.0	 13.33	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7781	 1	 108.5	 35.3	 0.0	 49.63	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7782	 1	 1.4	 0.5	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7783	 1	 26.13	 8.5	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7784	 1	 11.01	 5.5	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7785	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7786	 1	 113.4	 11.9	 0.0	 5.4	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7787	 1	 30.03	 9.6	 0.0	 4.38	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7788	 1	 7.0	 1.0	 0.0	 1.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7789	 1	 -0.0	 0.0	 0.0	 55.79	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7790	 1	 0.0	 0.0	 0.1	 -0.29	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	7791	 1	 -0.0	 0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7792	 1	 0.0	 -0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7793	 1	 7.81	 2.8	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7794	 1	 97.5	 13.9	 0.0	 2.42	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7795	 1	 44.35	 5.1	 0.0	 4.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7796	 1	 12.91	 4.7	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7797	 1	 -0.0	 -0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7798	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7799	 1	 86.5	 29.0	 0.0	 1.45	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7800	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7801	 1	 -0.0	 -0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7802	 1	 223.1	 31.8	 0.0	 23.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7803	 1	 -0.0	 0.0	 0.378102	 20.394045	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7804	 1	 91.1	 33.5	 0.0	 1.8	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7805	 1	 -0.0	 0.0	 0.0	 30.46	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7806	 1	 -0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7807	 1	 -0.0	 0.0	 0.0	 56.53	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	7808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7809	 1	 169.5	 27.7	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7810	 1	 0.0	 -0.0	 0.0	 43.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7811	 1	 -0.0	 0.0	 0.0	 3.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7812	 1	 22.83	 3.8	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7813	 1	 1.8	 0.5	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7814	 1	 34.9	 5.0	 0.0	 2.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7815	 1	 149.1	 -18.3	 0.0	 10.76	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7816	 1	 40.24	 16.0	 0.0	 17.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7817	 1	 14.82	 -0.0	 0.0	 4.07	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7818	 1	 -41.65	 13.7	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7819	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7820	 1	 127.2	 -10.7	 0.0	 7.8	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7821	 1	 179.0	 22.9	 0.0	 25.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7822	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	7823	 1	 34.34	 12.2	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7824	 1	 9.21	 3.4	 0.0	 2.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7825	 1	 0.0	 0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7826	 1	 32.44	 20.1	 0.0	 2.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7827	 1	 137.2	 41.9	 0.101088	 13.207291	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7828	 1	 -0.0	 -0.0	 0.090774	 13.090445	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7829	 1	 -3.2	 -7.9	 0.0	 1.95	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	7830	 1	 0.0	 0.0	 0.135493	 30.26062	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	7831	 1	 -17.17	 -7.1	 0.0	 57.019803	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7832	 1	 -0.0	 0.0	 0.0	 22.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7833	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7834	 1	 134.7	 17.5	 0.0	 4.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7835	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7836	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7837	 1	 0.0	 -0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7838	 1	 10.11	 4.3	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7839	 1	 -9.78	 -3.66	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7840	 1	 -0.0	 0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7841	 1	 26.53	 7.1	 0.0	 11.02	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7843	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7844	 1	 -0.0	 0.0	 0.0	 27.39	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7845	 1	 38.64	 6.0	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7846	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7847	 1	 0.0	 -0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7848	 1	 -0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7849	 1	 -0.0	 0.0	 0.0	 15.21	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7850	 1	 12.6	 1.8	 0.0	 4.19	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7851	 1	 -0.0	 0.0	 0.0	 3.98	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7852	 1	 -3.53	 -4.62	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7853	 1	 40.65	 16.0	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7854	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7855	 1	 -0.0	 -0.0	 0.0	 13.08	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7856	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7857	 1	 0.0	 0.0	 0.0	 2.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7858	 1	 -0.01	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7859	 1	 0.0	 0.0	 0.0	 5.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7860	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7861	 1	 178.9	 9.1	 0.0	 15.71	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7862	 1	 0.0	 0.0	 0.0	 9.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7863	 1	 -0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7864	 1	 11.41	 0.3	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7865	 1	 84.99	 19.6	 0.0	 4.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7866	 1	 2.2	 0.8	 0.0	 1.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7867	 1	 88.5	 10.8	 0.0	 9.54	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	7868	 1	 0.0	 0.0	 0.0	 0.26	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7869	 1	 101.9	 20.0	 0.0	 22.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7870	 1	 -0.0	 0.0	 0.0	 77.584854	 0	    1.00000	    0.00000	 380.0	 24	    1.10000	    0.90000;
	7871	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7872	 1	 17.02	 2.0	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7873	 1	 -20.94	 -6.16	 0.0	 11.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7874	 1	 -0.0	 0.0	 0.0	 12.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7875	 1	 -0.0	 0.0	 0.0	 6.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7876	 1	 0.0	 0.0	 0.039888	 30.741787	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7877	 1	 64.21	 5.59	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7878	 1	 0.3	 -97.2	 0.0	 0.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7879	 1	 73.58	 48.6	 0.0	 2.87	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7881	 1	 -0.0	 -0.0	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7882	 1	 26.63	 9.7	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7883	 1	 47.55	 17.8	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7884	 1	 35.84	 14.1	 0.0	 50.11	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7885	 1	 142.4	 20.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7886	 1	 162.5	 42.7	 0.0	 12.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7887	 1	 41.88	 3.02	 0.0	 5.65	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7888	 1	 -0.0	 -0.0	 0.0	 4.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7889	 1	 -0.0	 -0.0	 0.090774	 2.080444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7890	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7891	 1	 427.9	 145.8	 0.0	 40.72	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7892	 1	 36.94	 11.0	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7893	 1	 0.0	 -0.0	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7894	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7895	 1	 338.7	 52.5	 0.0	 11.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7897	 1	 3.2	 0.6	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7898	 1	 -0.0	 0.0	 0.0	 25.73	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7899	 1	 31.74	 6.3	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7900	 1	 26.93	 9.6	 0.0	 1.41	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7901	 1	 191.7	 6.8	 0.0	 11.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7902	 1	 0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7903	 1	 0.0	 -0.0	 0.0	 7.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7904	 1	 30.35	 30.5	 0.0	 0.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7905	 1	 347.1	 87.2	 0.0	 88.35	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7906	 1	 7.0	 1.0	 0.0	 4.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7907	 1	 -0.0	 -0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7908	 1	 77.2	 11.0	 0.0	 9.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7909	 1	 0.0	 0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7910	 1	 -0.0	 0.0	 0.0	 7.73	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7911	 1	 0.0	 8.3	 0.0	 10.19	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	7912	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7913	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7914	 1	 -596.4	 -284.9	 0.302939	 3.153549	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7915	 1	 -0.18	 -1.31	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7916	 1	 35.14	 7.6	 0.0	 6.49	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7917	 1	 -0.0	 0.0	 0.0	 2.74	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7918	 1	 -0.0	 -0.0	 0.0	 117.47	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7919	 1	 -0.0	 0.0	 0.0	 14.34	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7920	 1	 160.3	 89.7	 0.0	 47.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7921	 1	 38.14	 23.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7922	 1	 0.0	 0.0	 0.12	 20.1	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7923	 1	 0.0	 -0.0	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7924	 1	 106.1	 -6.8	 0.0	 22.23	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7925	 1	 36.84	 14.1	 0.0	 33.55	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7926	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7927	 1	 2.2	 0.5	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7928	 1	 0.0	 -0.0	 0.0	 65.24	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7929	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7930	 1	 17.52	 9.1	 0.0	 2.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7931	 1	 -0.67	 -2.78	 0.0	 11.64	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	7932	 1	 -0.0	 0.0	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7933	 1	 -14.91	 -5.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7934	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7935	 1	 4.5	 1.1	 0.0	 12.56	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7936	 1	 115.8	 29.3	 0.0	 4.31	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7937	 1	 56.06	 17.0	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7938	 1	 31.03	 10.3	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7939	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7940	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7941	 1	 0.0	 -0.0	 0.0	 4.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7942	 1	 100.9	 26.7	 0.0	 118.53	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7943	 1	 38.44	 2.0	 0.0	 0.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7944	 1	 0.0	 0.0	 0.0	 2.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7945	 1	 17.92	 5.8	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7946	 1	 -0.0	 -0.0	 0.181549	 21.720889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7947	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7948	 1	 56.56	 3.5	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7949	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7950	 1	 125.4	 17.8	 0.0	 4.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7951	 1	 156.0	 60.7	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7952	 1	 60.07	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7953	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	7954	 1	 0.0	 -0.0	 0.0	 27.42	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7955	 1	 111.6	 8.9	 0.0	 16.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7956	 1	 -0.0	 0.0	 0.0	 5.78	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7957	 1	 -0.0	 -0.0	 0.0	 8.63	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7958	 1	 -0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7959	 1	 -0.0	 -0.0	 0.0	 59.88	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	7960	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7961	 1	 50.56	 8.1	 0.0	 8.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7962	 1	 0.0	 -0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7963	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7964	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7965	 1	 0.0	 0.0	 0.0	 79.5	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7966	 1	 124.5	 59.2	 0.0	 77.23	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7967	 1	 0.0	 -0.0	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7968	 1	 4.81	 1.6	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7969	 1	 0.0	 -0.0	 0.2527	 79.80215	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7970	 1	 30.03	 10.0	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7971	 1	 -0.0	 0.0	 0.0	 21.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7972	 1	 237.9	 68.5	 0.0	 5.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7973	 1	 115.7	 10.7	 0.0	 19.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7974	 1	 234.0	 13.1	 0.0	 51.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7975	 1	 -0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7976	 1	 0.0	 0.0	 0.0	 1.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7977	 1	 110.2	 15.7	 0.0	 1.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7978	 1	 -0.0	 0.0	 0.12	 15.18	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	7979	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	7980	 1	 233.5	 151.0	 0.0	 35.31	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7981	 1	 3.0	 1.5	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	7982	 1	 112.0	 19.7	 0.0	 38.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7984	 1	 126.98	 12.83	 0.0	 9.13	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7985	 1	 -0.0	 0.0	 0.0	 107.2	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7986	 1	 62.7	 9.0	 0.0	 5.83	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7987	 1	 -0.0	 -8.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7988	 1	 -3.55	 -1.43	 0.0	 11.834121	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7989	 1	 0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7990	 1	 12.61	 7.8	 0.0	 2.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7991	 1	 -0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7992	 1	 400.4	 23.6	 0.590405	 133.314256	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	7993	 1	 18.22	 6.3	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7994	 1	 11.91	 3.3	 0.0	 6.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7995	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7996	 1	 0.0	 -0.0	 0.0	 55.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7997	 1	 25.23	 47.6	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7998	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7999	 1	 0.0	 -0.0	 0.0	 9.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8000	 1	 -0.0	 0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8001	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8002	 1	 0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8003	 1	 -0.0	 -0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8004	 1	 -0.0	 0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8005	 1	 -0.0	 -0.0	 0.0	 16.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8006	 1	 0.0	 -0.0	 0.0	 21.18	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8007	 1	 7.91	 2.7	 0.0	 0.01	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8008	 1	 13.9	 1.9	 0.0	 6.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8009	 1	 -0.0	 -0.0	 0.0	 4.29	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8010	 1	 3.2	 1.5	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8011	 1	 0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8012	 1	 36.84	 14.1	 0.0	 17.84	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8013	 1	 40.04	 15.1	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8014	 1	 149.63	 59.0	 0.0	 4.99	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8015	 1	 28.83	 10.4	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8016	 1	 23.33	 9.1	 0.0	 15.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8017	 1	 -0.0	 -0.0	 0.0	 8.99	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8018	 1	 9.41	 2.3	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8019	 1	 0.0	 0.0	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8020	 1	 1.8	 0.7	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8021	 1	 14.22	 4.7	 0.0	 5.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8022	 1	 209.1	 1.7	 0.0	 18.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8023	 1	 0.0	 -0.0	 0.0	 4.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8024	 1	 -0.0	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8025	 1	 -0.0	 0.0	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8026	 1	 52.48	 6.43	 0.0	 1.47	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8027	 1	 0.0	 -0.0	 0.0	 21.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8028	 1	 -0.0	 -0.0	 0.0	 4.28	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8029	 1	 8.31	 3.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8030	 1	 -0.0	 0.0	 0.0	 122.13	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8031	 1	 12.91	 4.2	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8032	 1	 -0.0	 0.0	 0.0	 6.54	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8033	 1	 -0.0	 -0.0	 0.0	 4.79	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8034	 1	 83.99	 6.0	 0.0	 65.12	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8035	 1	 -0.0	 0.0	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8037	 1	 0.0	 -0.0	 0.0	 5.73	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8038	 1	 12.11	 5.1	 0.0	 6.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8039	 1	 27.9	 4.0	 0.0	 4.85	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8040	 1	 70.38	 27.5	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	8041	 1	 93.8	 15.9	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	8042	 1	 -0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8044	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8045	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8046	 1	 106.4	 24.2	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8047	 1	 25.0	 3.6	 0.0	 2.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8048	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8049	 1	 -0.0	 -0.0	 0.0	 66.29	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8050	 1	 42.35	 13.5	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8051	 1	 19.02	 6.0	 0.0	 1.45	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8052	 1	 53.56	 18.8	 0.0	 1.45	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	8053	 1	 -0.0	 -0.0	 0.0	 0.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8054	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8055	 1	 28.63	 8.8	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8056	 1	 14.32	 2.2	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8057	 1	 69.18	 9.5	 0.0	 3.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8058	 1	 10.71	 17.7	 0.0	 10.58	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8059	 1	 170.8	 70.4	 0.0	 7.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8060	 1	 0.0	 -0.0	 0.0	 9.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8061	 1	 -19.32	 6.4	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8062	 1	 25.33	 8.9	 0.0	 5.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8063	 1	 36.9	 5.3	 0.0	 3.7	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8064	 1	 135.2	 70.6	 0.0	 9.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8065	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	8066	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8067	 1	 66.77	 19.8	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	8068	 1	 41.74	 7.4	 0.0	 18.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8069	 1	 174.2	 54.3	 0.0	 23.93	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8070	 1	 3.8	 1.3	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8071	 1	 0.0	 0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8072	 1	 -0.0	 -0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8073	 1	 68.48	 42.7	 0.0	 6.37	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8074	 1	 33.14	 20.5	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8075	 1	 14.2	 2.0	 0.0	 1.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8076	 1	 6.21	 1.5	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8077	 1	 -0.0	 0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8078	 1	 130.0	 18.5	 0.0	 0.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8079	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8080	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8081	 1	 35.95	 22.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8082	 1	 -0.65	 -3.26	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8083	 1	 92.9	 13.2	 0.0	 4.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8084	 1	 35.14	 11.0	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8086	 1	 0.0	 0.0	 0.0	 17.69	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8087	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8088	 1	 0.0	 -0.0	 0.379958	 52.33965	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8089	 1	 316.1	 45.0	 0.0	 15.2	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8090	 1	 39.34	 24.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8091	 1	 73.18	 23.4	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8092	 1	 -0.0	 0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8093	 1	 41.85	 15.2	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8094	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8095	 1	 21.88	 4.73	 0.0	 -8.06	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8097	 1	 7.61	 0.0	 0.0	 6.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8098	 1	 206.4	 21.0	 0.0	 8.55	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8099	 1	 0.0	 0.0	 0.0	 13.33	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8100	 1	 25.0	 3.6	 0.0	 1.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8101	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	8102	 1	 82.1	 29.1	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	8103	 1	 39.34	 -10.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8104	 1	 127.2	 40.8	 0.0	 0.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8105	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8106	 1	 59.9	 8.5	 0.0	 0.88	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8107	 1	 68.18	 16.1	 0.0	 3.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8108	 1	 35.84	 13.0	 0.0	 2.26	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8109	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8110	 1	 0.0	 -0.0	 0.0	 0.03	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8111	 1	 -0.0	 -0.0	 0.0	 4.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8112	 1	 87.9	 29.3	 0.0	 1.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8113	 1	 107.0	 43.0	 0.0	 8.34	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8114	 1	 -0.0	 0.0	 0.0	 30.39	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8115	 1	 19.02	 6.3	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8116	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8117	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8118	 1	 111.1	 35.6	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	8119	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8120	 1	 0.01	 -0.0	 0.0	 26.46	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8121	 1	 0.0	 0.0	 0.0	 1.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8122	 1	 164.4	 23.4	 0.0	 10.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8123	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8124	 1	 80.49	 7.3	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8125	 1	 -0.0	 -0.0	 0.0	 7.21	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8126	 1	 -0.0	 0.0	 0.0	 23.91	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8127	 1	 8.91	 2.5	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8128	 1	 -0.0	 0.0	 0.0	 8.1	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8129	 1	 -0.0	 0.0	 0.0	 1.4	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8130	 1	 34.44	 27.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	8131	 1	 -0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8132	 1	 12.61	 6.3	 0.0	 14.98	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8133	 1	 19.4	 2.8	 0.0	 3.46	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8135	 1	 47.4	 6.7	 0.0	 3.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8136	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8137	 1	 0.0	 0.0	 0.04975	 68.521798	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	8138	 1	 -0.0	 0.0	 0.0	 6.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8139	 1	 242.4	 46.7	 0.0	 75.67	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8140	 1	 18.72	 6.6	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8141	 1	 0.0	 0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8142	 1	 10.01	 2.0	 0.0	 0.73	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	8143	 1	 22.32	 4.0	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	8144	 1	 0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8145	 1	 169.93	 42.88	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 17	    1.10000	    0.90000;
	8146	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8147	 1	 303.5	 56.2	 0.0	 21.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8148	 1	 3.8	 1.9	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8149	 1	 111.36	 27.44	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8150	 1	 35.1	 5.0	 0.0	 1.57	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8151	 1	 0.0	 0.0	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8152	 1	 0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8153	 1	 21.52	 5.1	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8154	 1	 -0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8155	 1	 125.3	 34.6	 0.0	 4.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8156	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	8157	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8159	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8160	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8161	 1	 -34.04	 -2.0	 0.0	 197.23	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8162	 1	 -0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8163	 1	 76.58	 16.2	 0.0	 21.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8164	 1	 1.8	 0.6	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8165	 1	 0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8166	 1	 -0.0	 -0.0	 0.090774	 5.709044	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	8167	 1	 -0.0	 0.0	 0.0	 1.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8168	 1	 20.62	 7.5	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8169	 1	 -0.0	 0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8170	 1	 -12.15	 -0.84	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8171	 1	 2.8	 14.6	 0.0	 113.059828	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	8172	 1	 0.0	 -0.0	 0.0	 5.39	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	8173	 1	 22.12	 8.0	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8174	 1	 0.0	 -0.0	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8175	 1	 13.11	 3.6	 0.0	 0.38	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8176	 1	 10.81	 3.6	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8177	 1	 41.8	 5.9	 0.0	 10.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8178	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8179	 1	 -0.0	 0.0	 0.194464	 19.1468	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8180	 1	 291.6	 47.0	 0.0	 2.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8181	 1	 0.0	 -0.0	 0.210824	 6.620599	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8182	 1	 73.58	 -13.1	 0.0	 7.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8183	 1	 0.0	 0.0	 0.0	 2.97	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8184	 1	 -0.0	 0.0	 0.0	 3.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8185	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8186	 1	 99.6	 22.9	 0.0	 15.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8187	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8188	 1	 120.2	 30.7	 0.0	 9.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8189	 1	 0.0	 -0.0	 0.0	 9.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8190	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8191	 1	 0.0	 0.0	 0.0	 11.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8192	 1	 2.0	 1.0	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8193	 1	 0.0	 0.0	 0.564887	 82.937717	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8194	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8195	 1	 -15.25	 -6.42	 0.0	 43.956703	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8196	 1	 20.2	 2.9	 0.0	 5.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8197	 1	 -134.35	 -6.5	 0.0	 3.38	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8198	 1	 165.9	 49.6	 0.0	 6.13	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8199	 1	 169.6	 98.3	 0.0	 27.8	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8200	 1	 0.0	 -0.0	 0.0	 39.58	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8201	 1	 0.18	 87.5	 0.0	 3.94	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8202	 1	 11.8	 1.7	 0.0	 6.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8203	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8204	 1	 -0.0	 -0.0	 0.0	 0.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8205	 1	 4.0	 1.3	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8206	 1	 0.0	 0.0	 0.062219	 26.452656	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8207	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8208	 1	 3.8	 3.8	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8209	 1	 83.39	 16.5	 0.0	 16.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8210	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8211	 1	 -0.0	 0.0	 0.0	 65.93	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8212	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8213	 1	 207.9	 25.4	 0.0	 1.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8214	 1	 58.97	 11.1	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8215	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8216	 1	 0.0	 -0.0	 0.0	 10.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8217	 1	 63.77	 39.5	 0.0	 1.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8218	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8219	 1	 0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8220	 1	 -0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8221	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8223	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8224	 1	 92.7	 -5.6	 0.2527	 35.620175	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8226	 1	 65.5	 9.3	 0.0	 7.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8227	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8228	 1	 -0.0	 0.0	 0.500102	 38.553095	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	8229	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8230	 1	 0.0	 0.0	 0.0	 59.43	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8231	 1	 0.0	 0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8232	 1	 1.8	 0.7	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8233	 1	 0.0	 0.0	 0.0	 1.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8234	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8235	 1	 1.9	 1.3	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8236	 1	 118.1	 20.2	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8237	 1	 370.2	 107.7	 0.0	 81.59	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8238	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8239	 1	 16.52	 6.6	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8240	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8241	 1	 5.11	 2.5	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8242	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8243	 1	 44.75	 27.7	 0.0	 1.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8244	 1	 0.0	 0.0	 0.0	 8.13	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8245	 1	 216.8	 30.7	 0.0	 58.2	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	8246	 1	 50.76	 17.5	 0.0	 8.97	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8247	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8248	 1	 0.0	 0.0	 0.0	 8.88	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8249	 1	 0.0	 0.0	 0.0	 17.8	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8250	 1	 196.1	 32.1	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8251	 1	 9.61	 2.5	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8252	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8253	 1	 -0.57	 -1.0	 0.0	 3.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8254	 1	 -0.0	 0.0	 0.0	 1.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8255	 1	 39.04	 13.1	 0.0	 3.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8256	 1	 -0.24	 -23.15	 0.0	 26.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8257	 1	 70.08	 43.4	 0.0	 1.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8258	 1	 0.0	 -0.0	 0.0	 69.23	 0	    1.00000	    0.00000	 380.0	 23	    1.30000	    0.70000;
	8259	 1	 19.4	 2.8	 0.0	 6.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8260	 1	 0.0	 -0.0	 0.0	 10.21	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8261	 1	 69.38	 22.5	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8262	 1	 7.0	 1.0	 0.0	 4.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8263	 1	 255.9	 128.3	 0.0	 54.58	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	8264	 1	 0.0	 -0.0	 0.0	 65.73	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8265	 1	 40.44	 20.5	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8266	 1	 316.7	 46.1	 0.0	 46.23	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8268	 1	 0.0	 -0.0	 0.0	 24.67	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	8269	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8270	 1	 -632.1	 -447.0	 0.0	 6.4	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8271	 1	 15.62	 2.8	 0.0	 0.71	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8272	 1	 7.41	 2.7	 0.0	 1.28	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8273	 1	 120.6	 35.7	 0.0	 15.36	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8274	 1	 15.62	 5.7	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8275	 1	 40.05	 20.0	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8276	 1	 73.68	 15.4	 0.0	 3.73	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8277	 1	 57.66	 6.1	 0.0	 1.77	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8279	 1	 -0.0	 -0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	8280	 1	 14.32	 5.5	 0.0	 3.15	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8281	 1	 9.41	 5.6	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8282	 1	 -0.0	 0.0	 0.0	 36.43	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8283	 1	 -0.0	 -0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8284	 1	 -0.12	 -1.31	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8285	 1	 156.6	 16.9	 0.0	 12.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8286	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8287	 1	 0.0	 -0.0	 0.0	 2.56	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8288	 1	 16.02	 5.1	 0.0	 8.6	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8289	 1	 -29.84	 -2.96	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8290	 1	 0.0	 0.0	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8291	 1	 0.0	 -0.0	 0.0	 6.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8292	 1	 141.5	 70.8	 0.0	 4.92	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8293	 1	 112.7	 14.5	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8294	 1	 14.22	 6.3	 0.0	 0.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8295	 1	 5.01	 2.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	8296	 1	 0.0	 -0.0	 0.0	 5.81	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8297	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8298	 1	 0.0	 0.0	 0.0	 14.35	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8299	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8300	 1	 0.0	 0.0	 0.0	 15.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8301	 1	 59.67	 9.2	 0.0	 18.03	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8302	 1	 13.92	 3.8	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8303	 1	 -0.0	 0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8304	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8305	 1	 -0.0	 0.0	 0.0	 8.18	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8306	 1	 99.3	 23.6	 0.0	 1.77	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8307	 1	 -0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8308	 1	 33.44	 11.0	 0.0	 4.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8309	 1	 11.2	 1.6	 0.0	 2.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8310	 1	 -0.0	 0.0	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8311	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8312	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8313	 1	 -9.75	 -2.74	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8314	 1	 13.92	 8.9	 0.0	 2.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8315	 1	 19.32	 7.0	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8316	 1	 0.0	 0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8317	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8318	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8319	 1	 18.02	 6.5	 0.0	 2.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8320	 1	 313.75	 96.8	 0.0	 5.67	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8321	 1	 74.78	 26.4	 0.0	 2.42	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8322	 1	 0.0	 0.0	 0.278602	 31.723346	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	8323	 1	 8.3	 1.2	 0.0	 2.86	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8324	 1	 0.0	 -0.0	 0.0	 3.03	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8325	 1	 41.45	 56.2	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 17	    1.10000	    0.90000;
	8326	 1	 0.0	 0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8327	 1	 -0.0	 -8.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8328	 1	 82.39	 14.4	 0.0	 13.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8329	 1	 0.0	 0.0	 0.149712	 2.04987	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8330	 1	 89.44	 63.66	 0.0	 2.6	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8331	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8332	 1	 0.0	 0.0	 0.0	 9.41	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8333	 1	 174.7	 31.0	 0.216349	 27.621586	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8334	 1	 0.0	 0.0	 0.0	 33.298535	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8335	 1	 637.92	 139.57	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8336	 1	 257.6	 -303.12	 0.244607	 64.309042	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8337	 1	 149.9	 -0.0	 0.0	 28.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8338	 1	 -2.3	 -3.34	 0.0	 8.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8339	 1	 0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	8340	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8341	 1	 133.7	 19.0	 0.0	 4.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8342	 1	 97.0	 -539.3	 0.0	 50.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8343	 1	 44.05	 14.4	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8344	 1	 0.0	 -0.0	 0.0	 58.09	 0	    1.00000	    0.00000	 380.0	 15	    1.30000	    0.70000;
	8345	 1	 19.2	 9.3	 0.0	 128.079082	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	8346	 1	 80.29	 -4.1	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8347	 1	 -2.09	 -1.43	 0.0	 48.358243	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8348	 1	 2.5	 1.3	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8349	 1	 0.1	 -0.9	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8350	 1	 92.3	 13.1	 0.0	 2.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8351	 1	 14.86	 2.99	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8352	 1	 67.27	 15.9	 0.0	 2.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8353	 1	 155.1	 39.9	 0.0	 6.37	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8354	 1	 32.84	 20.3	 0.0	 7.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8355	 1	 0.0	 0.0	 0.0	 8.82	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8356	 1	 -0.0	 -0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8357	 1	 50.96	 17.0	 0.0	 2.66	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8358	 1	 0.0	 0.0	 0.135493	 21.11062	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	8359	 1	 27.9	 4.0	 0.0	 2.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8360	 1	 2.8	 1.0	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8361	 1	 126.54	 29.1	 0.0	 12.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8362	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8363	 1	 6.31	 2.5	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8364	 1	 12.01	 4.0	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8365	 1	 69.7	 9.9	 0.0	 6.07	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8366	 1	 66.4	 9.4	 0.0	 4.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8367	 1	 77.99	 19.3	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8368	 1	 -0.0	 0.0	 0.0	 4.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8369	 1	 -0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8370	 1	 81.2	 23.4	 0.0	 52.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8371	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 12	    1.30000	    0.70000;
	8372	 1	 14.72	 5.3	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8373	 1	 216.3	 -6.9	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8374	 1	 153.4	 86.8	 0.0	 53.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8375	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8376	 1	 0.0	 0.0	 0.0	 33.61	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	8377	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8378	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8379	 1	 -0.0	 0.0	 0.0	 2.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8380	 1	 0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8381	 1	 -0.0	 -0.0	 0.0	 17.92	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8382	 1	 -0.0	 -0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8383	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8384	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8385	 1	 0.0	 -0.0	 0.0	 0.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8386	 1	 6.73	 14.7	 0.0	 11.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8387	 1	 115.03	 2.21	 0.0	 10.42	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8388	 1	 96.8	 76.1	 0.23521	 14.338731	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8389	 1	 72.18	 49.6	 0.0	 37.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8390	 1	 107.9	 15.3	 0.0	 99.52	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8391	 1	 4.2	 0.6	 0.0	 2.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8392	 1	 100.8	 32.3	 0.0	 7.16	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8393	 1	 0.0	 0.0	 0.0	 37.57	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8394	 1	 70.88	 43.9	 0.0	 3.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8395	 1	 117.13	 33.86	 0.0	 6.04	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8396	 1	 131.7	 32.9	 0.0	 108.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8397	 1	 -0.0	 0.0	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8398	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8399	 1	 79.39	 24.7	 0.0	 198.67	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8400	 1	 15.82	 9.5	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8401	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	8402	 1	 -0.0	 -0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8403	 1	 0.0	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8404	 1	 -0.0	 0.0	 0.0	 12.64	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8405	 1	 40.75	 12.5	 0.0	 2.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8406	 1	 0.0	 0.0	 0.0	 14.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8407	 1	 39.94	 13.3	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8408	 1	 64.57	 23.1	 0.0	 1.88	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8409	 1	 -0.0	 -0.0	 0.0	 19.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8410	 1	 -0.0	 0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	8411	 1	 39.64	 9.6	 0.0	 1.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8412	 1	 33.84	 11.1	 0.0	 1.57	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8413	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8414	 1	 -0.24	 -25.61	 0.0	 11.32	 0	    1.00000	    0.00000	 220.0	 3	    1.30000	    0.70000;
	8415	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8416	 1	 0.0	 -0.0	 0.0	 91.64	 0	    1.00000	    0.00000	 380.0	 20	    1.30000	    0.70000;
	8417	 1	 266.0	 62.8	 0.0	 1.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8418	 1	 18.52	 6.1	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8419	 1	 99.1	 -98.6	 0.0	 6.83	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8420	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8421	 1	 223.3	 -7.6	 0.0	 19.97	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8422	 1	 68.6	 9.8	 0.0	 117.06	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8423	 1	 19.72	 6.5	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8424	 1	 -0.0	 -0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8425	 1	 11.21	 4.4	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8426	 1	 176.2	 -46.9	 0.0	 5.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8427	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8428	 1	 0.0	 0.0	 0.0	 1.67	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8429	 1	 0.0	 0.0	 0.0	 14.69	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8430	 1	 88.5	 27.4	 0.0	 0.04	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8431	 1	 -0.0	 -0.0	 0.0	 2.64	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8432	 1	 -0.19	 -17.71	 0.0	 28.98	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8433	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	8434	 1	 133.0	 18.9	 0.0	 18.79	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8435	 1	 0.0	 -0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8436	 1	 8.81	 5.5	 0.0	 2.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8437	 1	 35.04	 12.0	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8438	 1	 125.5	 22.5	 0.0	 9.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8439	 1	 380.8	 62.8	 0.0	 7.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8440	 1	 139.3	 19.9	 0.0	 0.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8441	 1	 -0.0	 -0.0	 0.0	 0.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8442	 1	 31.44	 12.4	 0.0	 2.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8443	 1	 332.8	 92.2	 0.0	 29.46	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8444	 1	 0.0	 0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8445	 1	 -7.6	 28.6	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8446	 1	 33.64	 4.5	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8447	 1	 17.02	 5.6	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8448	 1	 286.1	 89.3	 0.0	 8.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8449	 1	 111.08	 -44.35	 0.0	 7.94	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8450	 1	 19.82	 5.8	 0.0	 4.99	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8451	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8452	 1	 -0.0	 0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8453	 1	 35.84	 10.9	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8454	 1	 143.3	 71.4	 0.0	 11.16	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8455	 1	 13.92	 10.1	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8456	 1	 24.22	 -1.06	 0.0	 2.92	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8457	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8458	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8459	 1	 285.2	 83.5	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8460	 1	 -0.0	 -0.0	 0.0	 1.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8461	 1	 -0.0	 -0.0	 0.0	 2.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8462	 1	 -0.59	 -0.86	 0.0	 0.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8463	 1	 24.13	 10.8	 0.0	 15.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8464	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8465	 1	 0.0	 0.0	 0.0	 23.94	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8466	 1	 0.0	 -0.0	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8467	 1	 216.2	 75.3	 0.0	 2.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8468	 1	 21.42	 11.8	 0.0	 28.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8469	 1	 10.81	 3.9	 0.0	 1.64	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8470	 1	 0.0	 -0.0	 0.0	 2.78	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	8471	 1	 -0.0	 -0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8472	 1	 19.4	 2.8	 0.0	 3.63	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	8475	 1	 -0.0	 0.0	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8476	 1	 17.12	 6.3	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8477	 1	 0.0	 0.0	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8478	 1	 -0.0	 0.0	 0.0	 3.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8479	 1	 161.28	 54.0	 0.0	 2.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8480	 1	 0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8482	 1	 0.0	 -0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8483	 1	 -0.17	 -1.82	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8484	 1	 0.0	 0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8485	 1	 149.0	 99.8	 0.0	 9.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8487	 1	 44.45	 7.68	 0.0	 17.83	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8488	 1	 66.67	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8489	 1	 0.0	 0.0	 0.0	 21.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8490	 1	 -0.19	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8491	 1	 20.9	 3.0	 0.0	 2.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8492	 1	 98.6	 27.1	 0.0	 42.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8493	 1	 -0.0	 -0.0	 0.0	 13.01	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8494	 1	 235.97	 34.52	 0.0	 7.15	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8495	 1	 9.51	 3.4	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8496	 1	 0.0	 0.0	 0.123474	 4.29472	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8497	 1	 38.84	 14.2	 0.0	 3.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8498	 1	 236.44	 -98.55	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8499	 1	 -14.89	 -4.43	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8500	 1	 0.0	 0.0	 0.0	 15.91	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8501	 1	 10.11	 -0.0	 0.0	 1.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8502	 1	 -0.0	 0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8503	 1	 97.6	 33.9	 0.0	 6.47	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8504	 1	 6.41	 2.2	 0.0	 52.07	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8505	 1	 -0.59	 -2.63	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8506	 1	 0.0	 -0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8507	 1	 37.44	 9.1	 0.0	 7.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8508	 1	 -8.02	 -15.14	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8509	 1	 -0.0	 0.0	 0.0	 3.76	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8510	 1	 0.0	 0.0	 0.0	 8.78	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	8511	 1	 93.6	 -43.5	 0.0	 33.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8512	 1	 140.7	 10.4	 0.0	 2.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8513	 1	 13.51	 5.6	 0.0	 0.86	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8514	 1	 30.33	 11.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8515	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8516	 1	 104.3	 12.3	 0.0	 8.29	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8517	 1	 268.2	 -257.9	 0.0	 42.56	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8518	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8519	 1	 13.71	 8.5	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8520	 1	 -0.0	 -0.0	 0.0	 4.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8521	 1	 53.86	 33.4	 0.0	 12.95	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8522	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8523	 1	 20.9	 3.0	 0.0	 7.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8524	 1	 -0.0	 0.0	 0.0	 11.14	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8525	 1	 -0.0	 -3.7	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8526	 1	 0.0	 0.0	 0.0	 45.57454	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	8527	 1	 28.13	 10.2	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8528	 1	 0.0	 0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8529	 1	 76.99	 -0.7	 0.0	 1.06	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8530	 1	 -0.0	 0.0	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8531	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	8532	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8533	 1	 12.31	 4.1	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8534	 1	 295.2	 39.3	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8535	 1	 72.68	 24.3	 0.0	 3.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8536	 1	 36.44	 22.6	 0.0	 2.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8537	 1	 187.64	 31.94	 0.0	 4.75	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8538	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8539	 1	 0.0	 -0.0	 0.0	 15.15	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8540	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8541	 1	 0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8542	 1	 87.7	 26.0	 0.0	 47.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8543	 1	 10.0	 1.4	 0.0	 5.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8544	 1	 -0.0	 -0.0	 0.0	 2.74	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8545	 1	 9.91	 3.3	 0.0	 6.72	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8546	 1	 5.01	 1.8	 0.0	 0.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8547	 1	 21.22	 9.9	 0.0	 4.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8548	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8549	 1	 -0.0	 -0.0	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8550	 1	 0.0	 0.0	 0.0	 1.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8551	 1	 0.0	 0.0	 0.176855	 3.419803	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	8552	 1	 0.0	 0.0	 0.0	 5.51	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8553	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8554	 1	 0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8555	 1	 22.02	 7.7	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8556	 1	 128.1	 42.8	 0.0	 25.57	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	8557	 1	 0.0	 -0.0	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8558	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8559	 1	 -0.0	 -7.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8560	 1	 -0.0	 0.0	 0.0	 1.11	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8561	 1	 -0.0	 -0.0	 0.0	 237.54	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8562	 1	 0.0	 0.0	 0.379262	 96.912184	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	8563	 1	 172.6	 24.6	 0.0	 11.39	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8565	 1	 -0.19	 -0.92	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8566	 1	 38.04	 15.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8567	 1	 15.42	 4.4	 0.0	 10.84	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8568	 1	 175.7	 56.2	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8569	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8570	 1	 0.0	 -0.0	 0.0	 1.71	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8571	 1	 126.8	 21.4	 0.0	 11.43	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8572	 1	 0.39	 -0.24	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8573	 1	 0.0	 -0.0	 0.0	 22.04	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8574	 1	 -0.0	 0.0	 0.447839	 20.994738	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8575	 1	 89.6	 13.1	 0.0	 8.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8576	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8577	 1	 10.91	 3.6	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8578	 1	 0.0	 -0.0	 0.0	 4.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8579	 1	 9.91	 3.3	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8580	 1	 -0.0	 -0.0	 0.0	 72.611776	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	8581	 1	 0.0	 -0.0	 0.0	 1.79	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8582	 1	 27.83	 -2.6	 0.0	 6.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8583	 1	 -0.0	 -0.0	 0.0	 6.29	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	8584	 1	 9.7	 1.4	 0.0	 2.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8585	 1	 0.0	 -0.0	 0.0	 8.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8586	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8587	 1	 27.53	 17.0	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8588	 1	 317.9	 55.4	 0.0	 37.61	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8589	 1	 -0.0	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8590	 1	 -33.74	 11.1	 0.0	 1.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8591	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8592	 1	 -0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8593	 1	 171.3	 13.9	 0.0	 59.09	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8594	 1	 3.8	 3.8	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8595	 1	 72.4	 10.3	 0.0	 6.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8596	 1	 0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	8597	 1	 65.2	 9.3	 0.0	 3.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8598	 1	 -0.0	 -0.0	 0.0	 6.07	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8599	 1	 26.93	 9.6	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8600	 1	 -0.0	 -0.0	 0.0	 4.82	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8601	 1	 0.0	 0.0	 0.0	 1.96	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8602	 1	 -0.0	 0.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8603	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8604	 1	 0.0	 -0.0	 0.0	 20.81	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8605	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8606	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8607	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8608	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8609	 1	 382.4	 86.3	 0.0	 22.29	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	8610	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8611	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8612	 1	 -0.0	 0.0	 0.0	 12.69	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	8613	 1	 101.8	 20.2	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8614	 1	 0.0	 0.0	 0.0	 36.99	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8615	 1	 -0.0	 -0.0	 0.0	 1.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8616	 1	 -0.0	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8617	 1	 0.0	 -0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8618	 1	 -0.0	 -0.0	 0.0	 5.72	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	8619	 1	 -0.0	 0.0	 0.0	 13.3	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8620	 1	 76.68	 23.3	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8621	 1	 -70.45	 -35.14	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8622	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8623	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8624	 1	 25.03	 18.8	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8625	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8626	 1	 136.0	 36.1	 0.0	 6.07	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8627	 1	 -0.0	 0.0	 0.0	 4.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8628	 1	 277.1	 37.0	 0.0	 21.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8629	 1	 98.61	 50.3	 0.0	 0.17	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8630	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8631	 1	 -0.0	 -0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8632	 1	 -0.0	 -0.0	 0.0	 2.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8633	 1	 0.0	 -0.0	 0.090774	 8.200444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	8634	 1	 74.18	 27.3	 0.0	 25.25	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8635	 1	 282.0	 21.5	 0.0	 21.3	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8636	 1	 31.43	 10.6	 0.0	 1.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8637	 1	 -20.32	 6.7	 0.0	 0.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8638	 1	 62.27	 23.8	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8639	 1	 130.2	 88.8	 0.0	 0.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8640	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	8641	 1	 -0.0	 -0.0	 0.0	 15.67	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	8642	 1	 163.2	 31.9	 0.0	 4.9	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8643	 1	 29.13	 9.5	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8644	 1	 -0.0	 0.0	 0.0	 32.28	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	8645	 1	 25.18	 3.37	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8646	 1	 -2.3	 -0.8	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8647	 1	 0.0	 0.0	 0.0	 4.63	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8648	 1	 20.9	 3.0	 0.0	 2.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8649	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8650	 1	 4.4	 2.2	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8651	 1	 162.49	 45.11	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8652	 1	 0.0	 0.0	 0.0	 21.22	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8653	 1	 44.55	 7.5	 0.0	 0.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8654	 1	 125.2	 17.8	 0.0	 2.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8655	 1	 -16.42	 5.4	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8656	 1	 5.51	 1.3	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8657	 1	 0.0	 -0.0	 0.0	 61.44	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8658	 1	 38.54	 12.0	 0.0	 16.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8659	 1	 0.0	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8660	 1	 129.8	 67.2	 0.0	 2.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8661	 1	 226.7	 39.3	 0.0	 0.99	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8662	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8663	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8664	 1	 34.54	 15.4	 0.0	 29.82	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8665	 1	 45.45	 14.9	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8666	 1	 1.3	 0.5	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8667	 1	 9.91	 3.3	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8668	 1	 69.88	 19.3	 0.0	 1.63	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8669	 1	 74.98	 10.5	 0.0	 12.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8671	 1	 62.77	 5.7	 0.0	 2.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8672	 1	 -0.0	 -0.0	 0.0	 28.515005	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8673	 1	 -0.0	 -0.0	 0.0	 13.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8674	 1	 -0.0	 0.0	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8675	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8677	 1	 0.0	 0.0	 0.0	 2.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8678	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8679	 1	 -0.0	 -0.0	 0.0	 29.01	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8680	 1	 0.0	 -0.0	 0.0	 90.93	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8681	 1	 0.0	 0.0	 0.0	 4.26	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8682	 1	 34.9	 5.0	 0.0	 7.79	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8683	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8684	 1	 0.0	 -0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8685	 1	 168.13	 36.31	 0.0	 88.12	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	8686	 1	 -0.0	 -0.0	 0.0	 0.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8687	 1	 -0.15	 -152.82	 0.390048	 24.599897	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8688	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8689	 1	 42.65	 18.2	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8690	 1	 -0.0	 -0.0	 0.0	 2.81	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8691	 1	 305.04	 77.16	 0.0	 17.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8692	 1	 0.0	 0.0	 0.090774	 21.420444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	8693	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8694	 1	 -0.0	 0.0	 0.0	 20.75	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8695	 1	 5.5	 0.8	 0.0	 0.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8696	 1	 -0.0	 -0.0	 0.0	 6.52	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8697	 1	 -0.0	 -0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8698	 1	 20.02	 15.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8699	 1	 89.3	 10.0	 0.0	 9.62	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8700	 1	 0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8701	 1	 82.59	 23.4	 0.0	 6.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8702	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8703	 1	 0.0	 -0.0	 0.0	 3.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8704	 1	 180.7	 71.8	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8705	 1	 -0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8706	 1	 40.34	 15.9	 0.0	 6.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8707	 1	 101.9	 24.3	 0.0	 8.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8708	 1	 -0.0	 -0.0	 0.0	 11.22	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8709	 1	 3.7	 1.3	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8710	 1	 124.5	 -6.0	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8711	 1	 0.0	 0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8712	 1	 3.04	 -13.76	 0.0	 4.17	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8713	 1	 0.0	 -0.0	 0.0	 1.13	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8714	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8715	 1	 0.0	 0.0	 0.0	 90.194994	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	8716	 1	 0.0	 0.0	 0.0	 14.27	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8717	 1	 23.53	 8.5	 0.0	 1.28	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8718	 1	 15.32	 5.0	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8719	 1	 91.8	 8.3	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8720	 1	 3.5	 2.7	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8722	 1	 -0.0	 0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8723	 1	 -0.0	 0.0	 0.0	 3.41	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8724	 1	 127.9	 3.7	 0.0	 41.47	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8725	 1	 126.3	 109.2	 0.0	 54.97	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8726	 1	 100.4	 1.4	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	8727	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8728	 1	 443.8	 172.1	 0.0	 52.54	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	8729	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8730	 1	 0.0	 -0.0	 0.0	 3.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8731	 1	 191.2	 16.4	 0.0	 17.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8732	 1	 66.27	 19.3	 0.0	 12.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8733	 1	 25.0	 3.6	 0.0	 3.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8734	 1	 -0.0	 -0.0	 0.12	 8.51	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	8735	 1	 13.41	 3.4	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8736	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8737	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8738	 1	 -0.0	 0.0	 0.0	 3.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8739	 1	 105.8	 53.6	 0.0	 6.27	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8740	 1	 2.5	 0.6	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8741	 1	 -0.0	 -0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8742	 1	 -0.0	 0.0	 0.0	 31.05	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	8743	 1	 11.61	 7.6	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8744	 1	 0.0	 0.0	 0.0	 25.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8745	 1	 -0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8746	 1	 -0.0	 0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8747	 1	 0.0	 0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8748	 1	 279.7	 4.6	 0.0	 3.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8749	 1	 5.11	 2.5	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8750	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8751	 1	 0.0	 -0.0	 0.0	 4.15	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8752	 1	 61.98	 39.2	 0.0	 5.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8753	 1	 -23.09	 -46.44	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8754	 1	 30.03	 15.0	 0.0	 2.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8755	 1	 19.02	 3.8	 0.0	 4.55	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8756	 1	 54.66	 18.6	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8757	 1	 43.05	 25.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8758	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8759	 1	 -0.0	 0.0	 0.206089	 25.776518	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8760	 1	 92.1	 38.0	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	8761	 1	 18.36	 -0.95	 0.0	 3.83	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8762	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8763	 1	 0.0	 -0.0	 0.0	 215.65	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8765	 1	 -0.0	 -0.0	 0.0	 11.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8766	 1	 9.7	 1.4	 0.0	 4.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8767	 1	 17.52	 6.5	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8768	 1	 25.73	 9.3	 0.0	 1.49	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8769	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8770	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8771	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8772	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8773	 1	 0.0	 -0.0	 0.0	 30.31	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8774	 1	 0.0	 -0.0	 0.0	 15.04	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8775	 1	 45.25	 19.1	 0.0	 1.89	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8776	 1	 -0.0	 -0.0	 0.0	 6.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8777	 1	 7.61	 6.3	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8778	 1	 35.34	 37.8	 0.0	 9.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8779	 1	 292.4	 -228.7	 0.0	 106.08	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8780	 1	 1.8	 0.8	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8781	 1	 8.81	 2.2	 0.0	 4.78	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8782	 1	 26.23	 9.5	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8783	 1	 11.51	 3.8	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8784	 1	 100.5	 19.3	 0.0	 13.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8785	 1	 0.0	 0.0	 0.0	 15.18	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8786	 1	 128.8	 54.5	 0.0	 24.74	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8787	 1	 22.83	 8.0	 0.0	 3.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8788	 1	 143.8	 46.45	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8789	 1	 -29.73	 23.6	 0.0	 11.75	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8790	 1	 0.0	 0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8791	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8792	 1	 107.9	 35.9	 0.0	 5.48	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8793	 1	 179.6	 25.6	 0.0	 149.28	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8794	 1	 3.8	 -12.7	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8795	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8796	 1	 0.0	 -0.0	 0.0	 6.59	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8798	 1	 80.59	 5.2	 0.0	 7.77	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8799	 1	 24.03	 5.6	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	8800	 1	 9.91	 3.3	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8801	 1	 31.03	 8.9	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8802	 1	 0.0	 0.0	 0.0	 23.68	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8803	 1	 31.21	 -13.87	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8804	 1	 22.02	 4.4	 0.0	 4.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8805	 1	 35.24	 11.4	 0.0	 1.84	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8806	 1	 -0.0	 0.0	 0.0	 342.15	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8808	 1	 203.6	 19.81	 0.0	 15.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8809	 1	 101.2	 -2.9	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8810	 1	 0.3	 1.5	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8811	 1	 47.35	 15.5	 0.0	 1.41	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8812	 1	 32.24	 10.1	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8813	 1	 -0.0	 0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8814	 1	 89.9	 29.3	 0.0	 6.77	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8815	 1	 12.02	 3.6	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8816	 1	 82.19	 15.6	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8817	 1	 15.7	 2.2	 0.0	 2.88	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8818	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8819	 1	 37.87	 11.59	 0.0	 1.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8820	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	8821	 1	 8.31	 3.0	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8822	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	8823	 1	 -0.0	 0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8824	 1	 21.9	 3.1	 0.0	 4.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8825	 1	 0.0	 -0.0	 0.0	 44.95	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8826	 1	 75.3	 7.1	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	8827	 1	 -0.0	 0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8828	 1	 0.0	 0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8829	 1	 91.6	 27.1	 0.0	 10.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8830	 1	 21.32	 7.2	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8831	 1	 26.33	 10.3	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8832	 1	 0.0	 -0.0	 0.0	 2.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8833	 1	 0.0	 0.0	 0.0	 12.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8834	 1	 -0.0	 0.0	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8835	 1	 113.7	 22.3	 0.0	 15.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8836	 1	 54.56	 16.7	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8837	 1	 13.31	 4.4	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8838	 1	 20.02	 12.4	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8839	 1	 86.7	 41.5	 0.0	 18.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8840	 1	 1.5	 0.3	 0.0	 1.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8841	 1	 8.31	 2.7	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8842	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8843	 1	 208.7	 63.0	 0.0	 3.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8844	 1	 1.3	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8845	 1	 13.0	 8.8	 0.0	 78.85984	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	8846	 1	 20.82	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8847	 1	 -0.0	 0.0	 0.18076	 -0.881251	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8848	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	8849	 1	 4.4	 2.2	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8850	 1	 7.41	 2.4	 0.0	 2.23	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8852	 1	 6.01	 2.2	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8853	 1	 410.3	 91.6	 0.0	 13.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8854	 1	 69.18	 35.1	 0.0	 12.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8855	 1	 88.4	 51.1	 0.161949	 133.035662	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8856	 1	 -0.57	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8857	 1	 -0.0	 -0.0	 0.0	 2.29	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8858	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8859	 1	 -0.0	 -0.0	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 15	    1.10000	    0.90000;
	8860	 1	 57.16	 19.7	 0.0	 22.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8861	 1	 -0.0	 0.0	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8862	 1	 50.96	 15.7	 0.0	 1.52	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8863	 1	 55.56	 34.4	 0.0	 2.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8864	 1	 0.0	 0.0	 0.0	 6.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8865	 1	 50.96	 16.7	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8866	 1	 -0.0	 0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8867	 1	 131.5	 12.9	 0.0	 18.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8868	 1	 0.0	 -0.0	 0.0	 5.58	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8869	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8870	 1	 -0.0	 0.0	 0.0	 129.47	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8871	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8872	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8873	 1	 0.0	 -0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8874	 1	 285.2	 61.4	 0.0	 26.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8875	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8876	 1	 0.0	 -0.0	 0.0	 31.34	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8877	 1	 -0.0	 0.0	 0.0	 1.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8878	 1	 58.26	 16.9	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8879	 1	 0.0	 0.0	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8880	 1	 9.21	 3.4	 0.0	 1.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8881	 1	 0.0	 0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8882	 1	 -0.16	 -1.44	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8883	 1	 0.0	 0.0	 0.0	 49.35	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8884	 1	 35.64	 10.7	 0.0	 5.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8885	 1	 0.0	 0.0	 0.1444	 24.6772	 0	    1.00000	    0.00000	 380.0	 19	    1.30000	    0.70000;
	8886	 1	 0.0	 -0.0	 0.0	 -1.392036	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8887	 1	 0.0	 0.0	 0.0	 102.70867	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8888	 1	 101.6	 4.5	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8889	 1	 -8.15	 -5.23	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8890	 1	 22.12	 8.0	 0.0	 1.51	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8891	 1	 18.32	 6.6	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	8892	 1	 132.1	 13.2	 0.0	 6.9	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8893	 1	 278.3	 33.6	 0.0	 25.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8894	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 12	    1.10000	    0.90000;
	8895	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8897	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8898	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8899	 1	 0.0	 -0.0	 0.245843	 35.267139	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8900	 1	 3.1	 1.6	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8901	 1	 36.04	 22.3	 0.0	 2.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8902	 1	 5.51	 2.2	 0.0	 3.41	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8903	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8904	 1	 24.63	 15.31	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8905	 1	 -0.0	 -0.0	 0.11521	 58.265737	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	8906	 1	 91.0	 21.0	 0.0	 11.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8907	 1	 29.23	 -49.9	 0.0	 5.49	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8908	 1	 -0.0	 -0.0	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8909	 1	 98.7	 14.0	 0.0	 1.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8910	 1	 33.54	 12.2	 0.0	 2.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8911	 1	 32.1	 4.5	 0.0	 2.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8912	 1	 -6.81	 2.2	 0.0	 0.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8913	 1	 -0.0	 0.0	 0.0	 1.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8915	 1	 -0.0	 -0.0	 0.0	 4.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8916	 1	 0.0	 0.0	 0.0	 4.8	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8917	 1	 59.67	 13.1	 0.0	 2.26	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8918	 1	 10.11	 2.5	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8919	 1	 93.1	 -15.12	 0.0	 1.04	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8920	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8921	 1	 0.0	 0.0	 0.0	 16.37	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8922	 1	 3.4	 1.1	 0.0	 2.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8923	 1	 7.41	 2.7	 0.0	 3.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8924	 1	 66.58	 0.56	 0.0	 7.63	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8925	 1	 6.41	 2.3	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8926	 1	 67.08	 35.5	 0.0	 32.32	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8927	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8928	 1	 122.3	 17.5	 0.0	 1.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8929	 1	 93.9	 21.6	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8930	 1	 139.4	 21.2	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8931	 1	 -0.56	 -0.0	 0.0	 108.21	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8932	 1	 0.0	 -7.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8933	 1	 0.0	 -0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8934	 1	 -10.07	 -3.91	 0.0	 14.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8935	 1	 0.0	 -0.0	 0.0	 26.15	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8936	 1	 -0.0	 -0.0	 0.0	 3.13	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8937	 1	 62.7	 9.0	 0.0	 4.6	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8938	 1	 -2.35	 -2.06	 0.0	 18.45	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8939	 1	 186.8	 22.9	 0.0	 9.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8940	 1	 15.82	 3.7	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8941	 1	 4.2	 1.4	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8942	 1	 19.92	 6.6	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8943	 1	 -0.0	 0.0	 0.0	 6.315866	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	8944	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8945	 1	 0.0	 0.0	 0.0	 43.7	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8946	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8947	 1	 3.7	 0.2	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8948	 1	 -0.0	 0.0	 0.0	 3.03	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8949	 1	 20.32	 6.3	 0.0	 0.05	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8950	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8951	 1	 0.0	 -0.0	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8952	 1	 142.2	 33.7	 0.0	 6.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8953	 1	 516.7	 144.3	 0.0	 2.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8954	 1	 51.56	 18.7	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8955	 1	 0.0	 0.0	 0.0	 16.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8956	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8957	 1	 0.0	 0.0	 0.0	 4.39	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8958	 1	 28.63	 17.7	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8959	 1	 -0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8960	 1	 -0.0	 -0.0	 0.0	 9.64	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8961	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8962	 1	 44.05	 21.0	 0.0	 0.03	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8963	 1	 -0.0	 0.0	 0.0	 2.78	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8964	 1	 925.91	 147.97	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8965	 1	 45.05	 12.7	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8966	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8967	 1	 23.43	 8.4	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8968	 1	 261.5	 95.0	 0.0	 49.05	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8969	 1	 0.0	 0.0	 0.0	 1.29	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8970	 1	 -17.32	 5.7	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8971	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8972	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8973	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8974	 1	 -0.0	 -0.0	 0.0	 44.96	 0	    1.00000	    0.00000	 380.0	 22	    1.10000	    0.90000;
	8975	 1	 0.0	 -0.0	 0.0	 11.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8977	 1	 81.29	 26.5	 0.0	 7.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8978	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8979	 1	 0.0	 -0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8980	 1	 63.97	 12.8	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8981	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8982	 1	 0.0	 0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8983	 1	 4.1	 1.5	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8984	 1	 18.52	 11.1	 0.0	 0.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8985	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8986	 1	 92.9	 48.4	 0.0	 5.76	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8988	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8989	 1	 88.5	 24.5	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8990	 1	 2.0	 1.0	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8991	 1	 -8.49	 -17.09	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8992	 1	 -0.0	 -0.0	 0.0	 14.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8993	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8994	 1	 69.28	 31.3	 0.0	 32.76	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8995	 1	 11.5	 1.7	 0.0	 3.08	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8996	 1	 8.7	 1.2	 0.0	 2.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8997	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8998	 1	 -0.0	 0.0	 0.0	 4.08	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8999	 1	 41.15	 10.3	 0.0	 2.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9000	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9001	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9002	 1	 119.02	 12.54	 0.0	 23.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9003	 1	 -0.0	 0.0	 0.0	 31.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9004	 1	 102.6	 14.7	 0.0	 2.97	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	9005	 1	 -0.0	 0.0	 0.048364	 5.54206	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	9006	 1	 -0.0	 0.0	 0.0	 -0.44	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9007	 1	 73.68	 24.0	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9008	 1	 27.13	 16.8	 0.0	 1.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9009	 1	 145.3	 3.8	 0.0	 41.054794	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9010	 1	 -0.0	 0.0	 0.270022	 107.094537	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	9011	 1	 88.4	 25.2	 0.0	 12.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9012	 1	 25.63	 6.5	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9013	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9014	 1	 70.78	 19.6	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9015	 1	 15.63	 3.27	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9016	 1	 0.0	 0.0	 0.280385	 9.908955	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	9017	 1	 5.11	 1.3	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9018	 1	 55.46	 16.9	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9019	 1	 91.4	 18.1	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9020	 1	 6.41	 4.3	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9021	 1	 152.18	 21.63	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9022	 1	 -0.0	 -0.0	 0.0	 249.03	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	9023	 1	 80.49	 30.0	 0.0	 5.89	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9024	 1	 0.0	 0.0	 0.141019	 25.246	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9025	 1	 0.0	 -0.0	 0.205903	 3.0768	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9026	 1	 0.2	 0.1	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9027	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	9028	 1	 81.99	 32.2	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9029	 1	 -0.0	 -0.0	 0.0	 7.92	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9030	 1	 132.2	 49.1	 0.0	 69.43	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	9031	 1	 54.3	 7.8	 0.0	 4.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9032	 1	 0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	9033	 1	 76.88	 16.4	 0.0	 6.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9034	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9035	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9036	 1	 -19.83	 -13.51	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9037	 1	 -22.37	 -8.9	 0.162285	 11.818574	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9038	 1	 0.0	 -0.0	 0.0	 1.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9039	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9040	 1	 78.01	 4.25	 0.0	 12.32	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9041	 1	 0.0	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9042	 1	 0.0	 0.0	 0.0	 6.27	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9044	 1	 0.0	 0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	9045	 1	 60.57	 18.9	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9046	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9047	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9048	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9049	 1	 36.84	 14.1	 0.0	 3.8	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9050	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.30000	    0.70000;
	9051	 1	 0.0	 -0.0	 0.0	 2.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9052	 1	 121.8	 17.4	 0.0	 1.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9053	 1	 -0.0	 -0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9054	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 21	    1.30000	    0.70000;
	9055	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9056	 1	 11.35	 3.27	 0.0	 1.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9057	 1	 72.38	 23.0	 0.0	 0.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9058	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	9059	 1	 0.0	 -0.0	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9060	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	9061	 1	 27.9	 4.0	 0.0	 4.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9062	 1	 86.1	 40.6	 0.0	 7.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9063	 1	 -41.57	 -23.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9064	 1	 0.0	 -0.0	 0.0	 15.26	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9065	 1	 -0.0	 -0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9066	 1	 23.26	 3.01	 0.0	 9.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9067	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9068	 1	 -0.0	 -0.0	 0.0	 11.35	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9069	 1	 13.9	 1.9	 0.0	 3.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9070	 1	 0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9071	 1	 8.3	 1.2	 0.0	 0.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9072	 1	 0.0	 -0.0	 0.0	 1.41	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9073	 1	 -0.0	 0.0	 0.0	 5.05	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	9074	 1	 46.9	 6.7	 0.0	 3.45	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9075	 1	 242.4	 5.1	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9076	 1	 0.0	 0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9077	 1	 213.61	 50.1	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9078	 1	 24.33	 9.9	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9079	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9080	 1	 188.6	 164.9	 0.0	 21.03	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9081	 1	 0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9082	 1	 50.2	 7.1	 0.0	 3.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9083	 1	 88.1	 36.0	 0.0	 27.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9084	 1	 0.0	 -0.0	 0.0	 5.88	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9085	 1	 41.6	 5.9	 0.0	 2.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9086	 1	 125.0	 9.6	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9087	 1	 33.5	 4.8	 0.0	 1.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9088	 1	 55.9	 102.9	 0.0	 23.9	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9089	 1	 -0.0	 -0.0	 0.0	 4.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9090	 1	 0.0	 0.0	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9091	 1	 0.0	 0.0	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9092	 1	 13.94	 9.5	 0.0	 3.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9093	 1	 3.8	 2.5	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9094	 1	 187.4	 72.8	 0.0	 34.95	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9095	 1	 119.0	 97.8	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9096	 1	 7.0	 1.0	 0.0	 0.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9098	 1	 0.0	 -0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9099	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9100	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9101	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9102	 1	 -0.0	 0.0	 0.0	 2.83	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9103	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9104	 1	 11.31	 13.8	 0.0	 1.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9105	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.30000	    0.70000;
	9106	 1	 -0.0	 0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9107	 1	 87.4	 35.5	 0.0	 16.41	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	9108	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9109	 1	 0.0	 -0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9110	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.30000	    0.70000;
	9111	 1	 35.14	 12.7	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9112	 1	 0.0	 -0.0	 0.0	 19.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9113	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9114	 1	 0.0	 0.0	 0.0	 47.1	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	9115	 1	 25.03	 12.0	 0.0	 2.76	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9116	 1	 152.7	 81.0	 0.0	 17.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9117	 1	 36.74	 14.1	 0.0	 16.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9118	 1	 -0.22	 -3.34	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9119	 1	 -0.0	 0.0	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9120	 1	 0.0	 0.0	 0.0	 4.13	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9121	 1	 349.6	 96.3	 0.0	 105.72	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9122	 1	 50.46	 -10.8	 0.0	 42.99	 0	    1.00000	    0.00000	 380.0	 1	    1.30000	    0.70000;
	9123	 1	 13.9	 1.9	 0.0	 5.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9124	 1	 22.02	 7.1	 0.0	 1.38	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9125	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	9126	 1	 0.0	 -0.0	 0.0	 32.64	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9127	 1	 38.84	 9.6	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9128	 1	 50.56	 8.7	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9129	 1	 39.5	 5.6	 0.0	 8.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9130	 1	 245.51	 9.17	 0.0	 24.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9131	 1	 -0.0	 -0.0	 0.0	 6.62	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9132	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9133	 1	 0.0	 0.0	 0.0	 7.12	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	9134	 1	 21.72	 13.4	 0.0	 2.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9135	 1	 169.04	 33.9	 0.0	 5.48	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9136	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	9137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9138	 1	 16.7	 2.4	 0.0	 2.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9139	 1	 431.5	 111.5	 0.0	 36.709841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9140	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9141	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9142	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9143	 1	 89.6	 96.2	 0.0	 48.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9144	 1	 0.0	 0.0	 0.24842	 10.168602	 0	    1.00000	    0.00000	 220.0	 19	    1.30000	    0.70000;
	9145	 1	 66.57	 23.6	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9146	 1	 35.44	 11.4	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9147	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9148	 1	 15.22	 5.1	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9149	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9151	 1	 5.5	 0.8	 0.0	 8.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9152	 1	 -0.0	 0.0	 0.0	 17.63	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9153	 1	 2.2	 1.1	 0.0	 1.31	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9154	 1	 83.19	 37.3	 0.0	 28.16	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9155	 1	 -0.0	 -0.0	 0.0	 5.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9156	 1	 0.0	 8.5	 0.0	 12.99	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9157	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9158	 1	 54.96	 9.42	 0.0	 5.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9159	 1	 -0.0	 -0.0	 0.0	 81.15	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9160	 1	 311.4	 310.5	 0.199001	 104.051798	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9161	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9162	 1	 94.9	 40.3	 0.0	 17.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9163	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9164	 1	 7.71	 2.4	 0.0	 6.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9165	 1	 244.6	 96.3	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9166	 1	 9.91	 2.0	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9167	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9168	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	9169	 1	 126.21	 -7.73	 0.0	 6.2	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9170	 1	 43.15	 26.7	 0.0	 0.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9171	 1	 6.01	 3.0	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	9172	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9173	 1	 66.07	 15.6	 0.0	 5.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9174	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9175	 1	 20.32	 6.7	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9176	 1	 -0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9177	 1	 11.41	 3.7	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9178	 1	 4.61	 0.8	 0.0	 2.46	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9179	 1	 -0.68	 -2.44	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9180	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9181	 1	 2.43	 1.35	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9182	 1	 29.7	 4.3	 0.0	 13.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9183	 1	 156.3	 34.9	 0.0	 125.56	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	9184	 1	 50.06	 44.0	 0.0	 52.57	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	9185	 1	 66.97	 18.6	 0.0	 18.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9186	 1	 -28.33	 9.3	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9187	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9188	 1	 78.0	 11.1	 0.0	 1.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9189	 1	 62.57	 -61.0	 0.0	 55.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9190	 1	 0.0	 0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9191	 1	 -0.0	 -0.0	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9192	 1	 17.92	 23.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	9193	 1	 0.0	 -0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9194	 1	 0.0	 0.0	 0.262086	 66.559018	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	9195	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	9196	 1	 18.71	 0.64	 0.0	 1.58	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9197	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9198	 1	 282.2	 268.3	 0.0	 0.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9199	 1	 14.42	 3.8	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9200	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9201	 1	 137.9	 25.6	 0.0	 8.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9202	 1	 15.42	 6.6	 0.0	 2.46	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9203	 1	 -0.0	 -0.0	 0.0	 50.185221	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9204	 1	 11.71	 3.8	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9205	 1	 23.43	 7.3	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9206	 1	 226.1	 88.8	 0.0	 122.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9207	 1	 160.2	 22.8	 0.0	 14.42	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9208	 1	 -0.0	 0.0	 0.0	 2.29	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9209	 1	 11.44	 2.38	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9210	 1	 12.11	 4.4	 0.0	 2.35	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9211	 1	 217.7	 164.6	 0.0	 11.88	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9212	 1	 14.81	 0.6	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	9213	 1	 -0.0	 -0.0	 0.0	 10.210952	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9214	 1	 1.3	 -0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9215	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9216	 1	 103.6	 4.69	 0.0	 36.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9217	 1	 -0.0	 0.0	 0.0	 6.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9218	 1	 -0.0	 -0.0	 0.048364	 5.66206	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	9219	 1	 39.34	 13.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9220	 1	 26.4	 3.8	 0.0	 7.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9221	 1	 0.0	 0.0	 0.0	 6.58	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9222	 1	 -5.15	 -2.04	 0.0	 154.446402	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9223	 1	 133.5	 24.1	 0.0	 2.92	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9224	 1	 -0.0	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9225	 1	 -0.0	 0.0	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9226	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9227	 1	 -0.0	 0.0	 0.090774	 11.940444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	9228	 1	 -0.0	 -0.0	 0.0	 6.95	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9229	 1	 38.34	 12.6	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9230	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	9231	 1	 242.08	 59.98	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9232	 1	 31.94	 8.8	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9233	 1	 157.0	 44.2	 0.0	 22.63	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	9234	 1	 -121.89	 -52.61	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9235	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	9236	 1	 246.5	 -1.9	 0.0	 31.37	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9237	 1	 -0.0	 -0.0	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9238	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.30000	    0.70000;
	9239	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9240	 1	 0.0	 -0.0	 0.0	 3.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9241	 1	 0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	2	 -4.265	 10.87	 42.19	 -20.45	 1.0	 100.0	 1	 100.0	 -108.53; % NG
	6	 800.0	 156.48	 524.53	 -211.57	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	8	 262.34	 2.74	 251.73	 -246.25	 1.0	 100.0	 1	 524.68	 0.0; % COW
	18	 333.335	 59.745	 212.97	 -93.48	 1.0	 100.0	 1	 500.0	 166.67; % NG
	25	 200.0	 56.61	 179.43	 -66.21	 1.0	 100.0	 1	 400.0	 0.0; % COW
	32	 8.1	 0.675	 5.91	 -4.56	 1.0	 100.0	 1	 16.2	 0.0; % PEL
	33	 2.69	 0.595	 2.27	 -1.08	 1.0	 100.0	 1	 5.38	 0.0; % NG
	39	 20.0	 5.31	 17.76	 -7.14	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	49	 240.0	 71.275	 218.52	 -75.97	 1.0	 100.0	 1	 480.0	 0.0; % NG
	51	 -46.335	 0.645	 5.48	 -4.19	 1.0	 100.0	 1	 100.0	 -192.67; % COW
	80	 64.4	 48.08	 139.94	 -43.78	 1.0	 100.0	 1	 100.0	 28.8; % COW
	107	 400.0	 70.03	 253.85	 -113.79	 1.0	 100.0	 1	 600.0	 200.0; % COW
	123	 20.0	 6.39	 18.84	 -6.06	 1.0	 100.0	 1	 40.0	 0.0; % COW
	124	 666.665	 133.865	 440.32	 -172.59	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	141	 1.2	 6.13	 18.59	 -6.33	 1.0	 100.0	 1	 100.0	 -97.6; % NG
	142	 90.0	 22.875	 78.15	 -32.4	 1.0	 100.0	 1	 180.0	 0.0; % COW
	147	 39.335	 20.31	 70.12	 -29.5	 1.0	 100.0	 1	 100.0	 -21.33; % COW
	150	 80.0	 27.275	 77.09	 -22.54	 1.0	 100.0	 1	 160.0	 0.0; % NG
	151	 -23.565	 -10.105	 37.97	 -58.18	 1.0	 100.0	 1	 100.0	 -147.13; % COW
	166	 150.0	 35.57	 127.67	 -56.53	 1.0	 100.0	 1	 300.0	 0.0; % NG
	179	 -69.465	 0.46	 52.64	 -51.72	 1.0	 100.0	 1	 100.0	 -238.93; % NG
	190	 60.0	 16.805	 54.24	 -20.63	 1.0	 100.0	 1	 120.0	 0.0; % NG
	192	 100.0	 30.315	 91.61	 -30.98	 1.0	 100.0	 1	 200.0	 0.0; % NG
	194	 200.0	 38.33	 130.19	 -53.53	 1.0	 100.0	 1	 300.0	 100.0; % NG
	197	 150.0	 32.175	 123.89	 -59.54	 1.0	 100.0	 1	 300.0	 0.0; % COW
	201	 2.685	 0.6	 2.27	 -1.07	 1.0	 100.0	 1	 5.37	 0.0; % NG
	209	 20.0	 6.265	 18.7	 -6.17	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	214	 -66.8	 69.555	 192.0	 -52.89	 1.0	 100.0	 1	 100.0	 -233.6; % NG
	219	 1333.335	 324.635	 937.43	 -288.16	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	220	 600.0	 127.985	 402.92	 -146.95	 1.0	 100.0	 1	 900.0	 300.0; % COW
	221	 266.665	 59.31	 183.92	 -65.3	 1.0	 100.0	 1	 400.0	 133.33; % NG
	222	 -48.2	 3.445	 12.51	 -5.62	 1.0	 100.0	 1	 100.0	 -196.4; % COW
	239	 45.3	 13.64	 38.52	 -11.24	 1.0	 100.0	 1	 100.0	 -9.4; % NG
	246	 533.335	 132.745	 378.08	 -112.59	 1.0	 100.0	 1	 800.0	 266.67; % COW
	248	 -64.665	 12.56	 37.47	 -12.35	 1.0	 100.0	 1	 100.0	 -229.33; % COW
	255	 333.335	 67.385	 220.66	 -85.89	 1.0	 100.0	 1	 500.0	 166.67; % NG
	262	 -26.935	 13.19	 38.1	 -11.72	 1.0	 100.0	 1	 100.0	 -153.87; % NG
	263	 27.065	 -0.95	 5.05	 -6.95	 1.0	 100.0	 1	 100.0	 -45.87; % NG
	278	 7.265	 12.805	 37.7	 -12.09	 1.0	 100.0	 1	 100.0	 -85.47; % NG
	282	 1333.335	 312.145	 924.64	 -300.35	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	289	 30.0	 7.605	 26.02	 -10.81	 1.0	 100.0	 1	 60.0	 0.0; % PEL
	294	 320.0	 11.89	 45.1	 -21.32	 1.0	 100.0	 1	 480.0	 160.0; % NG
	299	 1066.665	 231.27	 721.25	 -258.71	 1.0	 100.0	 1	 1600.0	 533.33; % COW
	309	 50.0	 11.95	 42.62	 -18.72	 1.0	 100.0	 1	 100.0	 0.0; % NG
	310	 450.0	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	313	 5.04	 -1.17	 4.83	 -7.17	 1.0	 100.0	 1	 10.08	 0.0; % NG
	320	 1208.0	 -261.96	 320.04	 -843.96	 1.0	 100.0	 1	 1812.0	 604.0; % NUC
	324	 100.0	 34.015	 95.32	 -27.29	 1.0	 100.0	 1	 200.0	 0.0; % NG
	325	 35.735	 0.46	 1.93	 -1.01	 1.0	 100.0	 1	 100.0	 -28.53; % NG
	328	 -1.935	 66.385	 188.91	 -56.14	 1.0	 100.0	 1	 100.0	 -103.87; % NG
	338	 60.0	 18.19	 55.54	 -19.16	 1.0	 100.0	 1	 120.0	 0.0; % NG
	347	 26.71	 -4.67	 33.33	 -42.67	 1.0	 100.0	 1	 53.42	 0.0; % NG
	348	 120.0	 36.835	 110.57	 -36.9	 1.0	 100.0	 1	 240.0	 0.0; % NG
	352	 1333.335	 314.335	 926.35	 -297.68	 1.0	 100.0	 1	 2000.0	 666.67; % NG
	361	 266.665	 63.945	 186.39	 -58.5	 1.0	 100.0	 1	 400.0	 133.33; % NG
	366	 130.665	 -29.15	 61.97	 -120.27	 1.0	 100.0	 1	 196.0	 65.33; % NG
	372	 13.4	 99.325	 282.95	 -84.3	 1.0	 100.0	 1	 100.0	 -73.2; % NG
	382	 40.0	 13.48	 38.4	 -11.44	 1.0	 100.0	 1	 80.0	 0.0; % NG
	389	 60.0	 19.445	 56.73	 -17.84	 1.0	 100.0	 1	 120.0	 0.0; % COW
	394	 1866.665	 367.045	 1224.26	 -490.17	 1.0	 100.0	 1	 2800.0	 933.33; % NG
	406	 30.615	 2.435	 22.22	 -17.35	 1.0	 100.0	 1	 61.23	 0.0; % NG
	409	 8.665	 -2.675	 24.32	 -29.67	 1.0	 100.0	 1	 100.0	 -82.67; % COW
	411	 20.0	 5.195	 17.66	 -7.27	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	413	 140.0	 37.14	 124.12	 -49.84	 1.0	 100.0	 1	 280.0	 0.0; % COW
	423	 37.2	 1.31	 5.22	 -2.6	 1.0	 100.0	 1	 100.0	 -25.6; % NG
	424	 466.665	 89.45	 304.38	 -125.48	 1.0	 100.0	 1	 700.0	 233.33; % COW
	433	 333.335	 63.98	 217.18	 -89.22	 1.0	 100.0	 1	 500.0	 166.67; % COW
	434	 48.135	 -0.25	 2.75	 -3.25	 1.0	 100.0	 1	 100.0	 -3.73; % NG
	438	 50.0	 14.46	 45.1	 -16.18	 1.0	 100.0	 1	 100.0	 0.0; % NG
	439	 200.0	 52.975	 175.16	 -69.21	 1.0	 100.0	 1	 400.0	 0.0; % NG
	440	 60.0	 18.36	 55.73	 -19.01	 1.0	 100.0	 1	 120.0	 0.0; % NG
	442	 23.1	 0.51	 1.95	 -0.93	 1.0	 100.0	 1	 100.0	 -53.8; % NG
	447	 20.0	 4.4	 16.84	 -8.04	 1.0	 100.0	 1	 40.0	 0.0; % NG
	452	 12.135	 12.96	 37.86	 -11.94	 1.0	 100.0	 1	 100.0	 -75.73; % NG
	453	 270.0	 91.415	 257.23	 -74.4	 1.0	 100.0	 1	 540.0	 0.0; % NG
	456	 31.28	 2.495	 44.8	 -39.81	 1.0	 100.0	 1	 100.0	 -37.44; % NG
	484	 150.0	 40.78	 132.41	 -50.85	 1.0	 100.0	 1	 300.0	 0.0; % COW
	489	 -21.6	 0.73	 6.28	 -4.82	 1.0	 100.0	 1	 100.0	 -143.2; % NG
	491	 100.0	 33.23	 94.56	 -28.1	 1.0	 100.0	 1	 200.0	 0.0; % NG
	505	 58.015	 -10.495	 37.34	 -58.33	 1.0	 100.0	 1	 116.03	 0.0; % COW
	511	 100.0	 33.17	 94.38	 -28.04	 1.0	 100.0	 1	 200.0	 0.0; % NG
	515	 450.0	 22.63	 72.5	 -27.24	 1.0	 100.0	 1	 700.0	 200.0; % COW
	516	 400.0	 77.56	 261.79	 -106.67	 1.0	 100.0	 1	 600.0	 200.0; % COW
	518	 -223.535	 24.21	 85.63	 -37.21	 1.0	 100.0	 1	 100.0	 -547.07; % NG
	524	 36.225	 -6.46	 30.15	 -43.07	 1.0	 100.0	 1	 72.45	 0.0; % PEL
	541	 62.095	 -9.69	 7.81	 -27.19	 1.0	 100.0	 1	 124.19	 0.0; % NG
	564	 15.555	 -0.44	 18.47	 -19.35	 1.0	 100.0	 1	 100.0	 -68.89; % NG
	578	 -23.535	 7.435	 25.88	 -11.01	 1.0	 100.0	 1	 100.0	 -147.07; % NG
	583	 -130.0	 5.425	 17.88	 -7.03	 1.0	 100.0	 1	 100.0	 -360.0; % NG
	587	 266.665	 63.085	 185.56	 -59.39	 1.0	 100.0	 1	 400.0	 133.33; % NG
	590	 183.565	 135.115	 380.31	 -110.08	 1.0	 100.0	 1	 300.0	 67.13; % NG
	615	 20.0	 4.65	 17.09	 -7.79	 1.0	 100.0	 1	 40.0	 0.0; % NG
	616	 320.0	 68.37	 217.9	 -81.16	 1.0	 100.0	 1	 480.0	 160.0; % NG
	618	 533.335	 106.035	 351.18	 -139.11	 1.0	 100.0	 1	 800.0	 266.67; % COW
	628	 90.0	 23.55	 78.79	 -31.69	 1.0	 100.0	 1	 180.0	 0.0; % NG
	636	 60.0	 15.56	 52.99	 -21.87	 1.0	 100.0	 1	 120.0	 0.0; % NG
	637	 11.16	 1.38	 11.2	 -8.44	 1.0	 100.0	 1	 22.32	 0.0; % PEL
	639	 19.2	 48.31	 135.52	 -38.9	 1.0	 100.0	 1	 100.0	 -61.6; % NG
	642	 138.045	 -1.45	 90.13	 -93.03	 1.0	 100.0	 1	 276.09	 0.0; % COW
	648	 40.0	 13.04	 37.95	 -11.87	 1.0	 100.0	 1	 80.0	 0.0; % NG
	672	 102.905	 4.2	 71.32	 -62.92	 1.0	 100.0	 1	 205.81	 0.0; % NG
	682	 40.0	 13.855	 38.77	 -11.06	 1.0	 100.0	 1	 80.0	 0.0; % NG
	686	 35.57	 0.245	 34.75	 -34.26	 1.0	 100.0	 1	 100.0	 -28.86; % NG
	692	 266.665	 59.69	 182.17	 -62.79	 1.0	 100.0	 1	 400.0	 133.33; % NG
	697	 533.335	 112.325	 357.4	 -132.75	 1.0	 100.0	 1	 800.0	 266.67; % COW
	698	 200.0	 38.015	 129.94	 -53.91	 1.0	 100.0	 1	 300.0	 100.0; % NG
	709	 32.65	 0.7	 22.23	 -20.83	 1.0	 100.0	 1	 65.3	 0.0; % PEL
	711	 59.265	 131.69	 377.01	 -113.63	 1.0	 100.0	 1	 100.0	 18.53; % NG
	713	 60.0	 16.595	 53.98	 -20.79	 1.0	 100.0	 1	 120.0	 0.0; % NG
	714	 533.335	 131.14	 376.36	 -114.08	 1.0	 100.0	 1	 800.0	 266.67; % NUC
	715	 244.0	 -56.765	 66.42	 -179.95	 1.0	 100.0	 1	 366.0	 122.0; % NG
	727	 533.335	 134.26	 379.61	 -111.09	 1.0	 100.0	 1	 800.0	 266.67; % COW
	728	 37.14	 -4.29	 35.73	 -44.31	 1.0	 100.0	 1	 74.28	 0.0; % PEL
	735	 89.25	 -16.06	 89.94	 -122.06	 1.0	 100.0	 1	 178.5	 0.0; % NG
	738	 172.995	 6.355	 107.86	 -95.15	 1.0	 100.0	 1	 311.39	 34.6; % COW
	739	 333.335	 59.76	 212.97	 -93.45	 1.0	 100.0	 1	 500.0	 166.67; % NG
	749	 120.0	 30.925	 105.69	 -43.84	 1.0	 100.0	 1	 240.0	 0.0; % NG
	751	 150.0	 44.85	 136.94	 -47.24	 1.0	 100.0	 1	 300.0	 0.0; % NG
	757	 60.0	 13.945	 51.3	 -23.41	 1.0	 100.0	 1	 120.0	 0.0; % COW
	763	 30.0	 9.455	 27.88	 -8.97	 1.0	 100.0	 1	 60.0	 0.0; % COW
	764	 266.665	 51.525	 174.17	 -71.12	 1.0	 100.0	 1	 400.0	 133.33; % COW
	765	 90.0	 21.46	 76.76	 -33.84	 1.0	 100.0	 1	 180.0	 0.0; % NG
	774	 70.56	 10.415	 81.57	 -60.74	 1.0	 100.0	 1	 141.12	 0.0; % NG
	776	 -24.265	 5.715	 18.16	 -6.73	 1.0	 100.0	 1	 100.0	 -148.53; % NG
	778	 16.79	 1.505	 12.37	 -9.36	 1.0	 100.0	 1	 33.58	 0.0; % NG
	779	 22.5	 4.88	 17.34	 -7.58	 1.0	 100.0	 1	 45.0	 0.0; % NG
	780	 40.0	 12.555	 37.43	 -12.32	 1.0	 100.0	 1	 80.0	 0.0; % NG
	791	 800.0	 200.075	 567.63	 -167.48	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	795	 40.0	 11.855	 36.75	 -13.04	 1.0	 100.0	 1	 80.0	 0.0; % NG
	796	 40.0	 14.13	 39.0	 -10.74	 1.0	 100.0	 1	 80.0	 0.0; % NG
	803	 -9.465	 24.245	 74.03	 -25.54	 1.0	 100.0	 1	 100.0	 -118.93; % NG
	807	 1333.335	 251.75	 864.47	 -360.97	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	813	 401.335	 9.075	 309.08	 -290.93	 1.0	 100.0	 1	 602.0	 200.67; % COW
	823	 1333.335	 314.185	 926.68	 -298.31	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	828	 29.35	 -0.78	 20.87	 -22.43	 1.0	 100.0	 1	 58.7	 0.0; % NG
	831	 60.0	 18.205	 55.59	 -19.18	 1.0	 100.0	 1	 120.0	 0.0; % NG
	832	 400.0	 80.94	 264.71	 -102.83	 1.0	 100.0	 1	 600.0	 200.0; % COW
	837	 30.0	 8.765	 27.19	 -9.66	 1.0	 100.0	 1	 60.0	 0.0; % PEL
	844	 60.0	 16.94	 54.35	 -20.47	 1.0	 100.0	 1	 120.0	 0.0; % NG
	848	 51.345	 5.755	 49.63	 -38.12	 1.0	 100.0	 1	 100.0	 2.69; % NG
	849	 8.785	 0.77	 6.45	 -4.91	 1.0	 100.0	 1	 17.57	 0.0; % NG
	851	 100.0	 34.415	 96.64	 -27.81	 1.0	 100.0	 1	 200.0	 0.0; % NG
	858	 666.665	 134.26	 440.67	 -172.15	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	861	 60.0	 20.65	 57.98	 -16.68	 1.0	 100.0	 1	 120.0	 0.0; % COW
	875	 333.335	 74.985	 228.16	 -78.19	 1.0	 100.0	 1	 500.0	 166.67; % NG
	888	 200.0	 46.665	 138.6	 -45.27	 1.0	 100.0	 1	 300.0	 100.0; % COW
	891	 1600.0	 361.75	 1097.41	 -373.91	 1.0	 100.0	 1	 2400.0	 800.0; % COW
	894	 160.0	 42.095	 141.93	 -57.74	 1.0	 100.0	 1	 320.0	 0.0; % NG
	896	 48.2	 -1.4	 8.6	 -11.4	 1.0	 100.0	 1	 100.0	 -3.6; % NG
	913	 1133.335	 251.085	 772.11	 -269.94	 1.0	 100.0	 1	 1700.0	 566.67; % COW
	916	 150.0	 42.345	 134.45	 -49.76	 1.0	 100.0	 1	 300.0	 0.0; % COW
	917	 20.0	 5.745	 18.22	 -6.73	 1.0	 100.0	 1	 40.0	 0.0; % NG
	926	 314.665	 56.58	 201.12	 -87.96	 1.0	 100.0	 1	 472.0	 157.33; % COW
	927	 30.0	 10.265	 28.69	 -8.16	 1.0	 100.0	 1	 60.0	 0.0; % NG
	930	 600.0	 130.955	 406.66	 -144.75	 1.0	 100.0	 1	 900.0	 300.0; % COW
	972	 1333.335	 321.605	 934.73	 -291.52	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	974	 60.0	 17.075	 54.36	 -20.21	 1.0	 100.0	 1	 120.0	 0.0; % COW
	976	 53.915	 0.335	 36.02	 -35.35	 1.0	 100.0	 1	 107.83	 0.0; % COW
	978	 7.575	 1.72	 6.43	 -2.99	 1.0	 100.0	 1	 15.15	 0.0; % PEL
	983	 1333.335	 335.545	 948.36	 -277.27	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	984	 1066.665	 249.045	 738.93	 -240.84	 1.0	 100.0	 1	 1600.0	 533.33; % COW
	991	 20.0	 4.39	 16.83	 -8.05	 1.0	 100.0	 1	 40.0	 0.0; % NG
	992	 30.0	 7.55	 25.97	 -10.87	 1.0	 100.0	 1	 60.0	 0.0; % NG
	993	 -41.265	 5.39	 17.85	 -7.07	 1.0	 100.0	 1	 100.0	 -182.53; % NG
	1001	 60.0	 17.605	 55.02	 -19.81	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1002	 100.0	 27.2	 89.55	 -35.15	 1.0	 100.0	 1	 200.0	 0.0; % NG
	1004	 50.0	 13.295	 43.99	 -17.4	 1.0	 100.0	 1	 100.0	 0.0; % NG
	1021	 -69.535	 21.055	 58.34	 -16.23	 1.0	 100.0	 1	 100.0	 -239.07; % NG
	1029	 100.0	 29.455	 90.64	 -31.73	 1.0	 100.0	 1	 200.0	 0.0; % COW
	1030	 250.0	 21.885	 71.66	 -27.89	 1.0	 100.0	 1	 400.0	 100.0; % NG
	1036	 200.0	 45.47	 137.39	 -46.45	 1.0	 100.0	 1	 300.0	 100.0; % NG
	1043	 600.0	 112.24	 387.88	 -163.4	 1.0	 100.0	 1	 900.0	 300.0; % COW
	1050	 385.385	 50.855	 173.5	 -71.79	 1.0	 100.0	 1	 518.72	 252.05; % NG
	1082	 266.665	 49.06	 171.62	 -73.5	 1.0	 100.0	 1	 400.0	 133.33; % NG
	1083	 60.0	 17.515	 54.91	 -19.88	 1.0	 100.0	 1	 120.0	 0.0; % COW
	1088	 22.995	 2.2	 8.06	 -3.66	 1.0	 100.0	 1	 45.99	 0.0; % NG
	1093	 800.0	 182.77	 550.69	 -185.15	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	1097	 9.19	 -0.235	 6.17	 -6.64	 1.0	 100.0	 1	 18.38	 0.0; % NG
	1098	 133.335	 30.09	 91.42	 -31.24	 1.0	 100.0	 1	 200.0	 66.67; % NG
	1100	 40.0	 11.895	 36.8	 -13.01	 1.0	 100.0	 1	 80.0	 0.0; % COW
	1102	 -32.77	 13.23	 38.05	 -11.59	 1.0	 100.0	 1	 100.0	 -165.54; % NG
	1103	 533.335	 132.0	 376.66	 -112.66	 1.0	 100.0	 1	 800.0	 266.67; % COW
	1117	 576.0	 -89.82	 307.47	 -487.11	 1.0	 100.0	 1	 864.0	 288.0; % COW
	1119	 200.0	 34.58	 126.49	 -57.33	 1.0	 100.0	 1	 300.0	 100.0; % NG
	1121	 180.0	 47.695	 158.2	 -62.81	 1.0	 100.0	 1	 360.0	 0.0; % COW
	1122	 95.14	 5.96	 68.0	 -56.08	 1.0	 100.0	 1	 190.28	 0.0; % NG
	1125	 120.0	 39.915	 114.57	 -34.74	 1.0	 100.0	 1	 240.0	 0.0; % NG
	1131	 600.0	 132.025	 407.66	 -143.61	 1.0	 100.0	 1	 900.0	 300.0; % COW
	1138	 666.665	 125.87	 432.44	 -180.7	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	1139	 120.0	 33.195	 107.89	 -41.5	 1.0	 100.0	 1	 240.0	 0.0; % COW
	1145	 245.12	 4.415	 153.07	 -144.24	 1.0	 100.0	 1	 452.53	 37.71; % NG
	1173	 -33.135	 0.485	 1.85	 -0.88	 1.0	 100.0	 1	 100.0	 -166.27; % NG
	1174	 20.0	 6.165	 18.61	 -6.28	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	1175	 450.0	 34.615	 108.35	 -39.12	 1.0	 100.0	 1	 700.0	 200.0; % COW
	1176	 52.23	 33.02	 94.13	 -28.09	 1.0	 100.0	 1	 100.0	 4.46; % NG
	1184	 200.0	 55.235	 178.02	 -67.55	 1.0	 100.0	 1	 400.0	 0.0; % NG
	1220	 90.0	 28.795	 84.07	 -26.48	 1.0	 100.0	 1	 180.0	 0.0; % NG
	1225	 145.215	 31.6	 118.84	 -55.64	 1.0	 100.0	 1	 290.43	 0.0; % NG
	1237	 1333.335	 293.585	 906.61	 -319.44	 1.0	 100.0	 1	 2000.0	 666.67; % NG
	1241	 32.815	 0.655	 22.29	 -20.98	 1.0	 100.0	 1	 65.63	 0.0; % NG
	1243	 50.0	 13.64	 44.3	 -17.02	 1.0	 100.0	 1	 100.0	 0.0; % COW
	1244	 31.895	 -2.495	 23.86	 -28.85	 1.0	 100.0	 1	 63.79	 0.0; % NG
	1251	 800.0	 182.77	 550.69	 -185.15	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	1258	 40.0	 10.04	 34.91	 -14.83	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	1267	 266.665	 69.24	 191.38	 -52.9	 1.0	 100.0	 1	 400.0	 133.33; % NG
	1271	 -17.0	 0.215	 32.54	 -32.11	 1.0	 100.0	 1	 100.0	 -134.0; % COW
	1295	 -32.735	 12.02	 36.92	 -12.88	 1.0	 100.0	 1	 100.0	 -165.47; % NG
	1307	 -223.4	 10.57	 35.48	 -14.34	 1.0	 100.0	 1	 100.0	 -546.8; % NG
	1313	 20.0	 5.045	 17.51	 -7.42	 1.0	 100.0	 1	 40.0	 0.0; % NG
	1315	 -106.6	 13.355	 38.26	 -11.55	 1.0	 100.0	 1	 100.0	 -313.2; % NG
	1320	 180.0	 50.16	 160.62	 -60.3	 1.0	 100.0	 1	 360.0	 0.0; % COW
	1337	 266.665	 68.235	 190.67	 -54.2	 1.0	 100.0	 1	 400.0	 133.33; % NG
	1341	 60.0	 19.705	 57.03	 -17.62	 1.0	 100.0	 1	 120.0	 0.0; % COW
	1354	 -114.335	 13.175	 38.08	 -11.73	 1.0	 100.0	 1	 100.0	 -328.67; % NG
	1361	 -5.735	 30.375	 91.51	 -30.76	 1.0	 100.0	 1	 100.0	 -111.47; % NG
	1365	 266.665	 56.62	 179.34	 -66.1	 1.0	 100.0	 1	 400.0	 133.33; % COW
	1371	 98.7	 -20.84	 47.16	 -88.84	 1.0	 100.0	 1	 197.4	 0.0; % NG
	1378	 29.86	 -1.255	 4.86	 -7.37	 1.0	 100.0	 1	 100.0	 -40.28; % NG
	1387	 -82.265	 51.435	 174.11	 -71.24	 1.0	 100.0	 1	 100.0	 -264.53; % NG
	1390	 200.675	 34.85	 126.8	 -57.1	 1.0	 100.0	 1	 301.01	 100.34; % NG
	1391	 20.0	 6.285	 18.74	 -6.17	 1.0	 100.0	 1	 40.0	 0.0; % NG
	1399	 -66.4	 0.72	 11.64	 -10.2	 1.0	 100.0	 1	 100.0	 -232.8; % NG
	1402	 200.0	 44.905	 136.48	 -46.67	 1.0	 100.0	 1	 300.0	 100.0; % NG
	1409	 533.335	 93.45	 338.66	 -151.76	 1.0	 100.0	 1	 800.0	 266.67; % COW
	1417	 40.0	 13.19	 38.08	 -11.7	 1.0	 100.0	 1	 80.0	 0.0; % COW
	1420	 526.665	 62.155	 251.08	 -126.77	 1.0	 100.0	 1	 790.0	 263.33; % NUC
	1422	 -17.335	 5.65	 18.09	 -6.79	 1.0	 100.0	 1	 100.0	 -134.67; % NG
	1426	 250.0	 67.05	 220.32	 -86.22	 1.0	 100.0	 1	 500.0	 0.0; % NG
	1433	 30.03	 -7.26	 35.74	 -50.26	 1.0	 100.0	 1	 60.06	 0.0; % PEL
	1436	 40.0	 12.815	 37.72	 -12.09	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1440	 60.375	 -8.17	 41.52	 -57.86	 1.0	 100.0	 1	 120.75	 0.0; % NG
	1444	 135.635	 -65.115	 142.87	 -273.1	 1.0	 100.0	 1	 357.63	 -86.36; % NG
	1458	 1333.335	 282.225	 895.23	 -330.78	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1474	 32.0	 0.43	 1.9	 -1.04	 1.0	 100.0	 1	 100.0	 -36.0; % NG
	1475	 600.0	 118.725	 394.45	 -157.0	 1.0	 100.0	 1	 900.0	 300.0; % COW
	1478	 40.0	 11.48	 36.4	 -13.44	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	1481	 350.0	 172.07	 539.99	 -195.85	 1.0	 100.0	 1	 600.0	 100.0; % COW
	1484	 150.0	 35.68	 127.72	 -56.36	 1.0	 100.0	 1	 300.0	 0.0; % NG
	1487	 200.0	 51.935	 176.62	 -72.75	 1.0	 100.0	 1	 400.0	 0.0; % NG
	1492	 350.0	 131.065	 376.31	 -114.18	 1.0	 100.0	 1	 600.0	 100.0; % COW
	1498	 2.655	 0.595	 2.25	 -1.06	 1.0	 100.0	 1	 5.31	 0.0; % NG
	1507	 -16.13	 6.305	 18.77	 -6.16	 1.0	 100.0	 1	 100.0	 -132.26; % NG
	1508	 100.0	 28.8	 90.09	 -32.49	 1.0	 100.0	 1	 200.0	 0.0; % NG
	1529	 34.865	 0.41	 1.88	 -1.06	 1.0	 100.0	 1	 100.0	 -30.27; % COW
	1546	 266.665	 52.67	 175.3	 -69.96	 1.0	 100.0	 1	 400.0	 133.33; % NG
	1550	 266.665	 51.73	 174.21	 -70.75	 1.0	 100.0	 1	 400.0	 133.33; % COW
	1555	 533.335	 131.14	 376.36	 -114.08	 1.0	 100.0	 1	 800.0	 266.67; % NG
	1557	 733.335	 140.805	 478.45	 -196.84	 1.0	 100.0	 1	 1100.0	 366.67; % COW
	1558	 23.625	 2.045	 7.91	 -3.82	 1.0	 100.0	 1	 47.25	 0.0; % NG
	1570	 133.335	 31.835	 93.16	 -29.49	 1.0	 100.0	 1	 200.0	 66.67; % NG
	1582	 200.0	 55.485	 177.98	 -67.01	 1.0	 100.0	 1	 400.0	 0.0; % NG
	1589	 28.975	 -5.725	 5.55	 -17.0	 1.0	 100.0	 1	 100.0	 -42.05; % COW
	1604	 40.0	 12.745	 37.66	 -12.17	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1606	 266.665	 51.945	 174.6	 -70.71	 1.0	 100.0	 1	 400.0	 133.33; % NG
	1618	 -41.065	 0.6	 21.27	 -20.07	 1.0	 100.0	 1	 100.0	 -182.13; % NG
	1626	 14.175	 1.28	 17.31	 -14.75	 1.0	 100.0	 1	 28.35	 0.0; % NG
	1642	 40.0	 12.815	 37.74	 -12.11	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1680	 1333.335	 316.395	 928.89	 -296.1	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1684	 800.0	 162.315	 530.3	 -205.67	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	1685	 60.0	 20.095	 57.41	 -17.22	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1697	 -76.0	 0.35	 31.94	 -31.24	 1.0	 100.0	 1	 100.0	 -252.0; % COW
	1708	 666.665	 133.035	 439.37	 -173.3	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	1715	 40.0	 10.175	 35.11	 -14.76	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	1717	 20.0	 6.8	 19.25	 -5.65	 1.0	 100.0	 1	 40.0	 0.0; % COW
	1719	 533.335	 133.425	 378.7	 -111.85	 1.0	 100.0	 1	 800.0	 266.67; % NUC
	1720	 800.0	 166.21	 534.24	 -201.82	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	1721	 20.0	 6.065	 18.52	 -6.39	 1.0	 100.0	 1	 40.0	 0.0; % NG
	1726	 60.0	 17.92	 55.28	 -19.44	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1736	 135.055	 23.305	 84.74	 -38.13	 1.0	 100.0	 1	 202.58	 67.53; % NG
	1738	 480.0	 26.11	 267.73	 -215.51	 1.0	 100.0	 1	 720.0	 240.0; % COW
	1743	 62.5	 18.365	 55.21	 -18.48	 1.0	 100.0	 1	 125.0	 0.0; % COW
	1747	 600.0	 111.97	 387.67	 -163.73	 1.0	 100.0	 1	 900.0	 300.0; % COW
	1748	 266.665	 54.12	 176.69	 -68.45	 1.0	 100.0	 1	 400.0	 133.33; % COW
	1754	 20.53	 4.535	 16.99	 -7.92	 1.0	 100.0	 1	 41.06	 0.0; % NG
	1756	 133.335	 26.055	 87.48	 -35.37	 1.0	 100.0	 1	 200.0	 66.67; % NG
	1776	 312.375	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 624.75	 0.0; % COW
	1785	 60.0	 14.405	 51.66	 -22.85	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1786	 800.0	 147.1	 515.09	 -220.89	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	1788	 400.0	 88.665	 272.25	 -94.92	 1.0	 100.0	 1	 600.0	 200.0; % COW
	1793	 -10.2	 9.72	 34.64	 -15.2	 1.0	 100.0	 1	 100.0	 -120.4; % NG
	1794	 1333.335	 314.335	 926.35	 -297.68	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1797	 40.0	 12.07	 36.93	 -12.79	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1808	 49.6	 36.535	 111.23	 -38.16	 1.0	 100.0	 1	 100.0	 -0.8; % COW
	1812	 35.44	 3.615	 12.89	 -5.66	 1.0	 100.0	 1	 70.88	 0.0; % NG
	1814	 266.665	 51.655	 174.22	 -70.91	 1.0	 100.0	 1	 400.0	 133.33; % NG
	1819	 150.0	 40.375	 132.46	 -51.71	 1.0	 100.0	 1	 300.0	 0.0; % COW
	1822	 533.335	 110.79	 356.05	 -134.47	 1.0	 100.0	 1	 800.0	 266.67; % COW
	1823	 40.0	 11.13	 36.04	 -13.78	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1843	 60.0	 20.605	 58.01	 -16.8	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1846	 61.74	 -10.9	 40.94	 -62.74	 1.0	 100.0	 1	 123.48	 0.0; % NG
	1847	 40.0	 13.53	 38.42	 -11.36	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1850	 16.485	 0.715	 11.52	 -10.09	 1.0	 100.0	 1	 32.97	 0.0; % NG
	1851	 15.96	 1.435	 11.76	 -8.89	 1.0	 100.0	 1	 31.92	 0.0; % NG
	1852	 -111.2	 20.82	 58.16	 -16.52	 1.0	 100.0	 1	 100.0	 -322.4; % NG
	1871	 15.535	 8.875	 27.31	 -9.56	 1.0	 100.0	 1	 100.0	 -68.93; % NG
	1877	 120.0	 42.385	 117.14	 -32.37	 1.0	 100.0	 1	 240.0	 0.0; % NG
	1888	 612.78	 120.095	 396.02	 -155.83	 1.0	 100.0	 1	 912.78	 312.78; % COW
	1890	 1066.665	 196.055	 686.73	 -294.62	 1.0	 100.0	 1	 1600.0	 533.33; % NUC
	1892	 41.6	 1.12	 11.03	 -8.79	 1.0	 100.0	 1	 100.0	 -16.8; % NG
	1898	 150.0	 40.93	 133.11	 -51.25	 1.0	 100.0	 1	 300.0	 0.0; % NG
	1900	 300.0	 79.86	 263.49	 -103.77	 1.0	 100.0	 1	 600.0	 0.0; % COW
	1905	 400.0	 99.485	 283.42	 -84.45	 1.0	 100.0	 1	 600.0	 200.0; % COW
	1907	 50.0	 14.215	 44.86	 -16.43	 1.0	 100.0	 1	 100.0	 0.0; % NG
	1909	 29.215	 13.785	 38.67	 -11.1	 1.0	 100.0	 1	 100.0	 -41.57; % NG
	1914	 255.755	 4.705	 160.36	 -150.95	 1.0	 100.0	 1	 472.16	 39.35; % COW
	1919	 400.0	 90.555	 274.12	 -93.01	 1.0	 100.0	 1	 600.0	 200.0; % COW
	1925	 -72.665	 0.215	 5.13	 -4.7	 1.0	 100.0	 1	 100.0	 -245.33; % NG
	1927	 250.0	 67.995	 221.35	 -85.36	 1.0	 100.0	 1	 500.0	 0.0; % COW
	1935	 13.065	 2.13	 31.24	 -26.98	 1.0	 100.0	 1	 100.0	 -73.87; % NG
	1938	 265.78	 -82.74	 314.85	 -480.33	 1.0	 100.0	 1	 531.56	 0.0; % COW
	1947	 38.65	 0.54	 2.05	 -0.97	 1.0	 100.0	 1	 100.0	 -22.7; % NG
	1959	 20.0	 5.695	 18.14	 -6.75	 1.0	 100.0	 1	 40.0	 0.0; % NG
	1970	 60.0	 16.805	 54.24	 -20.63	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1982	 48.535	 -5.34	 20.66	 -31.34	 1.0	 100.0	 1	 100.0	 -2.93; % NG
	1991	 30.0	 8.765	 27.19	 -9.66	 1.0	 100.0	 1	 60.0	 0.0; % NG
	1999	 90.0	 25.22	 80.51	 -30.07	 1.0	 100.0	 1	 180.0	 0.0; % NG
	2017	 333.335	 86.445	 239.75	 -66.86	 1.0	 100.0	 1	 500.0	 166.67; % COW
	2018	 40.0	 13.24	 38.1	 -11.62	 1.0	 100.0	 1	 80.0	 0.0; % COW
	2030	 400.0	 73.075	 257.0	 -110.85	 1.0	 100.0	 1	 600.0	 200.0; % NG
	2035	 666.665	 135.29	 441.85	 -171.27	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	2046	 150.0	 41.615	 133.49	 -50.26	 1.0	 100.0	 1	 300.0	 0.0; % NG
	2050	 1333.335	 349.275	 962.2	 -263.65	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	2051	 145.145	 3.005	 98.71	 -92.7	 1.0	 100.0	 1	 290.29	 0.0; % COW
	2054	 1.85	 0.175	 1.37	 -1.02	 1.0	 100.0	 1	 3.7	 0.0; % NG
	2063	 65.865	 18.1	 67.03	 -30.83	 1.0	 100.0	 1	 100.0	 31.73; % NG
	2082	 -44.975	 -1.52	 4.66	 -7.7	 1.0	 100.0	 1	 100.0	 -189.95; % NG
	2085	 100.0	 26.1	 88.39	 -36.19	 1.0	 100.0	 1	 200.0	 0.0; % NG
	2086	 40.0	 11.4	 36.34	 -13.54	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2091	 20.0	 5.42	 17.88	 -7.04	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	2096	 800.0	 155.185	 522.74	 -212.37	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	2098	 133.335	 24.975	 86.24	 -36.29	 1.0	 100.0	 1	 200.0	 66.67; % NG
	2100	 257.07	 9.86	 160.69	 -140.97	 1.0	 100.0	 1	 462.73	 51.41; % COW
	2104	 36.065	 1.025	 4.45	 -2.4	 1.0	 100.0	 1	 100.0	 -27.87; % COW
	2107	 1000.0	 202.14	 661.9	 -257.62	 1.0	 100.0	 1	 1500.0	 500.0; % COW
	2113	 266.665	 49.39	 172.07	 -73.29	 1.0	 100.0	 1	 400.0	 133.33; % NG
	2150	 400.0	 82.335	 266.17	 -101.5	 1.0	 100.0	 1	 600.0	 200.0; % COW
	2153	 -281.065	 45.47	 137.41	 -46.47	 1.0	 100.0	 1	 100.0	 -662.13; % NG
	2163	 20.0	 4.76	 17.24	 -7.72	 1.0	 100.0	 1	 40.0	 0.0; % NG
	2167	 133.335	 31.12	 92.35	 -30.11	 1.0	 100.0	 1	 200.0	 66.67; % NG
	2176	 1900.0	 13.26	 38.2	 -11.68	 1.0	 100.0	 1	 2900.0	 900.0; % NG
	2177	 -30.865	 21.045	 58.35	 -16.26	 1.0	 100.0	 1	 100.0	 -161.73; % NG
	2181	 356.0	 -37.925	 198.93	 -274.78	 1.0	 100.0	 1	 534.0	 178.0; % NG
	2185	 60.0	 16.555	 53.94	 -20.83	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2187	 600.0	 129.965	 405.25	 -145.32	 1.0	 100.0	 1	 900.0	 300.0; % NUC
	2193	 8.06	 2.455	 7.47	 -2.56	 1.0	 100.0	 1	 16.12	 0.0; % NG
	2197	 14.475	 2.385	 19.51	 -14.74	 1.0	 100.0	 1	 100.0	 -71.05; % NG
	2206	 200.0	 45.355	 137.29	 -46.58	 1.0	 100.0	 1	 300.0	 100.0; % NG
	2207	 40.0	 14.1	 38.96	 -10.76	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2225	 -5.665	 0.615	 2.27	 -1.04	 1.0	 100.0	 1	 100.0	 -111.33; % NG
	2236	 24.37	 0.58	 2.23	 -1.07	 1.0	 100.0	 1	 100.0	 -51.26; % NG
	2237	 100.0	 33.54	 94.84	 -27.76	 1.0	 100.0	 1	 200.0	 0.0; % COW
	2241	 805.335	 -175.96	 216.04	 -567.96	 1.0	 100.0	 1	 1208.0	 402.67; % NUC
	2243	 29.6	 1.305	 4.72	 -2.11	 1.0	 100.0	 1	 100.0	 -40.8; % COW
	2245	 104.235	 -22.81	 85.19	 -130.81	 1.0	 100.0	 1	 208.47	 0.0; % NG
	2250	 -22.335	 7.625	 26.07	 -10.82	 1.0	 100.0	 1	 100.0	 -144.67; % NG
	2253	 533.335	 105.89	 351.3	 -139.52	 1.0	 100.0	 1	 800.0	 266.67; % COW
	2266	 99.75	 -14.155	 101.16	 -129.47	 1.0	 100.0	 1	 199.5	 0.0; % NG
	2267	 333.335	 74.665	 228.16	 -78.83	 1.0	 100.0	 1	 500.0	 166.67; % COW
	2276	 59.65	 2.585	 41.67	 -36.5	 1.0	 100.0	 1	 119.3	 0.0; % NG
	2278	 73.5	 -16.65	 53.35	 -86.65	 1.0	 100.0	 1	 147.0	 0.0; % NG
	2284	 10.335	 13.565	 38.48	 -11.35	 1.0	 100.0	 1	 100.0	 -79.33; % COW
	2287	 84.0	 -19.79	 56.21	 -95.79	 1.0	 100.0	 1	 168.0	 0.0; % NG
	2289	 19.37	 -2.41	 15.59	 -20.41	 1.0	 100.0	 1	 38.74	 0.0; % NG
	2291	 100.0	 33.38	 95.69	 -28.93	 1.0	 100.0	 1	 200.0	 0.0; % NG
	2310	 200.0	 49.51	 141.39	 -42.37	 1.0	 100.0	 1	 300.0	 100.0; % NG
	2320	 60.0	 18.03	 54.86	 -18.8	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2335	 400.0	 89.695	 273.49	 -94.1	 1.0	 100.0	 1	 600.0	 200.0; % COW
	2351	 26.07	 16.685	 47.28	 -13.91	 1.0	 100.0	 1	 100.0	 -47.86; % NG
	2353	 -25.665	 -2.66	 30.35	 -35.67	 1.0	 100.0	 1	 100.0	 -151.33; % COW
	2357	 -72.735	 13.42	 38.31	 -11.47	 1.0	 100.0	 1	 100.0	 -245.47; % COW
	2359	 40.0	 9.425	 34.35	 -15.5	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2362	 533.335	 106.7	 351.42	 -138.02	 1.0	 100.0	 1	 800.0	 266.67; % COW
	2369	 133.335	 31.34	 92.72	 -30.04	 1.0	 100.0	 1	 200.0	 66.67; % NG
	2394	 300.0	 135.115	 380.31	 -110.08	 1.0	 100.0	 1	 500.0	 100.0; % NG
	2398	 533.335	 123.43	 368.84	 -121.98	 1.0	 100.0	 1	 800.0	 266.67; % COW
	2402	 100.0	 26.32	 88.7	 -36.06	 1.0	 100.0	 1	 200.0	 0.0; % NG
	2412	 204.545	 -0.875	 134.54	 -136.29	 1.0	 100.0	 1	 409.09	 0.0; % COW
	2413	 100.0	 29.375	 90.68	 -31.93	 1.0	 100.0	 1	 200.0	 0.0; % COW
	2421	 -163.6	 12.47	 37.39	 -12.45	 1.0	 100.0	 1	 100.0	 -427.2; % NG
	2425	 -17.0	 16.905	 54.3	 -20.49	 1.0	 100.0	 1	 100.0	 -134.0; % NG
	2426	 21.2	 3.16	 105.34	 -99.02	 1.0	 100.0	 1	 100.0	 -57.6; % COW
	2429	 333.335	 60.725	 214.1	 -92.65	 1.0	 100.0	 1	 500.0	 166.67; % NG
	2446	 1333.335	 308.445	 921.62	 -304.73	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	2447	 40.335	 8.365	 49.04	 -32.31	 1.0	 100.0	 1	 100.0	 -19.33; % NG
	2452	 54.075	 -7.18	 47.33	 -61.69	 1.0	 100.0	 1	 108.15	 0.0; % NG
	2460	 40.0	 13.135	 38.01	 -11.74	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2468	 40.0	 13.105	 38.02	 -11.81	 1.0	 100.0	 1	 80.0	 0.0; % COW
	2481	 40.0	 14.205	 39.12	 -10.71	 1.0	 100.0	 1	 80.0	 0.0; % COW
	2489	 180.0	 50.305	 162.4	 -61.79	 1.0	 100.0	 1	 360.0	 0.0; % NG
	2501	 40.0	 9.635	 34.56	 -15.29	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2509	 -11.665	 13.55	 38.46	 -11.36	 1.0	 100.0	 1	 100.0	 -123.33; % NG
	2515	 20.0	 5.995	 18.43	 -6.44	 1.0	 100.0	 1	 40.0	 0.0; % COW
	2517	 117.26	 0.53	 78.13	 -77.07	 1.0	 100.0	 1	 234.52	 0.0; % NG
	2519	 18.0	 8.845	 27.24	 -9.55	 1.0	 100.0	 1	 100.0	 -64.0; % NG
	2534	 133.335	 24.95	 86.23	 -36.33	 1.0	 100.0	 1	 200.0	 66.67; % NG
	2539	 -31.6	 7.545	 25.99	 -10.9	 1.0	 100.0	 1	 100.0	 -163.2; % COW
	2541	 80.0	 23.45	 73.34	 -26.44	 1.0	 100.0	 1	 160.0	 0.0; % NG
	2547	 38.865	 0.14	 2.6	 -2.32	 1.0	 100.0	 1	 100.0	 -22.27; % NG
	2550	 60.0	 20.87	 58.23	 -16.49	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2568	 100.0	 28.865	 91.25	 -33.52	 1.0	 100.0	 1	 200.0	 0.0; % NG
	2569	 38.1	 6.415	 18.86	 -6.03	 1.0	 100.0	 1	 100.0	 -23.8; % NG
	2572	 400.0	 92.28	 276.19	 -91.63	 1.0	 100.0	 1	 600.0	 200.0; % COW
	2588	 -80.735	 4.61	 17.06	 -7.84	 1.0	 100.0	 1	 100.0	 -261.47; % NG
	2589	 400.0	 67.235	 250.66	 -116.19	 1.0	 100.0	 1	 600.0	 200.0; % COW
	2594	 90.0	 26.555	 81.79	 -28.68	 1.0	 100.0	 1	 180.0	 0.0; % COW
	2595	 800.0	 165.9	 533.87	 -202.07	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	2600	 80.0	 26.245	 76.08	 -23.59	 1.0	 100.0	 1	 160.0	 0.0; % NG
	2604	 -81.0	 4.705	 17.14	 -7.73	 1.0	 100.0	 1	 100.0	 -262.0; % NG
	2606	 150.0	 35.895	 128.02	 -56.23	 1.0	 100.0	 1	 300.0	 0.0; % NG
	2620	 120.0	 32.85	 107.62	 -41.92	 1.0	 100.0	 1	 240.0	 0.0; % NG
	2624	 60.0	 20.915	 58.27	 -16.44	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2627	 1333.335	 308.365	 921.52	 -304.79	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2642	 1333.335	 235.545	 848.76	 -377.67	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2649	 200.0	 49.865	 141.85	 -42.12	 1.0	 100.0	 1	 300.0	 100.0; % NG
	2650	 60.0	 13.97	 50.85	 -22.91	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2653	 60.0	 14.57	 51.94	 -22.8	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2658	 450.0	 32.645	 124.68	 -59.39	 1.0	 100.0	 1	 700.0	 200.0; % COW
	2660	 90.0	 24.46	 79.69	 -30.77	 1.0	 100.0	 1	 180.0	 0.0; % COW
	2662	 31.42	 9.59	 27.99	 -8.81	 1.0	 100.0	 1	 100.0	 -37.16; % COW
	2664	 266.665	 49.085	 171.72	 -73.55	 1.0	 100.0	 1	 400.0	 133.33; % NG
	2685	 90.0	 22.855	 78.09	 -32.38	 1.0	 100.0	 1	 180.0	 0.0; % NG
	2686	 1.4	 -0.445	 69.01	 -69.9	 1.0	 100.0	 1	 100.0	 -97.2; % COW
	2710	 806.665	 211.385	 665.77	 -243.0	 1.0	 100.0	 1	 1480.0	 133.33; % COW
	2719	 98.36	 6.025	 70.15	 -58.1	 1.0	 100.0	 1	 196.72	 0.0; % NG
	2725	 80.0	 19.435	 69.22	 -30.35	 1.0	 100.0	 1	 160.0	 0.0; % NG
	2729	 60.0	 20.045	 57.41	 -17.32	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2736	 150.0	 45.135	 137.02	 -46.75	 1.0	 100.0	 1	 300.0	 0.0; % NG
	2743	 40.0	 10.66	 35.58	 -14.26	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2758	 1033.335	 258.475	 748.51	 -231.56	 1.0	 100.0	 1	 1600.0	 466.67; % COW
	2764	 600.0	 141.1	 416.7	 -134.5	 1.0	 100.0	 1	 900.0	 300.0; % PEL
	2775	 496.0	 101.225	 313.82	 -111.37	 1.0	 100.0	 1	 744.0	 248.0; % COW
	2786	 1333.335	 321.67	 934.81	 -291.47	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	2791	 46.865	 -0.095	 11.28	 -11.47	 1.0	 100.0	 1	 100.0	 -6.27; % NG
	2797	 -13.4	 26.0	 88.33	 -36.33	 1.0	 100.0	 1	 100.0	 -126.8; % NG
	2799	 80.0	 28.125	 77.91	 -21.66	 1.0	 100.0	 1	 160.0	 0.0; % COW
	2800	 800.0	 157.75	 525.34	 -209.84	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	2810	 148.84	 -28.18	 90.6	 -146.96	 1.0	 100.0	 1	 297.68	 0.0; % NG
	2816	 1333.335	 314.26	 926.26	 -297.74	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2817	 40.0	 9.93	 34.8	 -14.94	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2822	 60.0	 17.755	 54.62	 -19.11	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2826	 84.0	 -18.26	 57.74	 -94.26	 1.0	 100.0	 1	 168.0	 0.0; % NG
	2835	 800.0	 183.14	 551.02	 -184.74	 1.0	 100.0	 1	 1200.0	 400.0; % NG
	2839	 30.0	 10.0	 28.38	 -8.38	 1.0	 100.0	 1	 60.0	 0.0; % NG
	2841	 60.0	 18.61	 55.98	 -18.76	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2842	 20.0	 5.725	 18.19	 -6.74	 1.0	 100.0	 1	 40.0	 0.0; % NG
	2852	 100.0	 29.925	 91.2	 -31.35	 1.0	 100.0	 1	 200.0	 0.0; % NG
	2853	 80.0	 22.275	 72.02	 -27.47	 1.0	 100.0	 1	 160.0	 0.0; % NG
	2862	 -23.065	 13.025	 37.94	 -11.89	 1.0	 100.0	 1	 100.0	 -146.13; % NG
	2867	 -30.065	 8.58	 110.29	 -93.13	 1.0	 100.0	 1	 100.0	 -160.13; % NG
	2872	 4.525	 0.385	 3.31	 -2.54	 1.0	 100.0	 1	 9.05	 0.0; % NG
	2874	 -46.05	 0.7	 21.01	 -19.61	 1.0	 100.0	 1	 100.0	 -192.1; % NG
	2878	 107.43	 2.12	 72.95	 -68.71	 1.0	 100.0	 1	 214.86	 0.0; % COW
	2881	 93.49	 27.665	 134.18	 -78.85	 1.0	 100.0	 1	 186.98	 0.0; % NG
	2886	 60.0	 20.335	 57.69	 -17.02	 1.0	 100.0	 1	 120.0	 0.0; % COW
	2896	 -98.935	 0.395	 1.52	 -0.73	 1.0	 100.0	 1	 100.0	 -297.87; % NG
	2897	 133.335	 33.405	 94.68	 -27.87	 1.0	 100.0	 1	 200.0	 66.67; % NG
	2902	 20.0	 6.735	 19.19	 -5.72	 1.0	 100.0	 1	 40.0	 0.0; % NG
	2920	 800.0	 196.625	 563.93	 -170.68	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	2923	 800.0	 168.98	 536.84	 -198.88	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	2930	 40.0	 12.35	 37.24	 -12.54	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2934	 3.415	 0.3	 2.51	 -1.91	 1.0	 100.0	 1	 6.83	 0.0; % PEL
	2942	 400.0	 99.485	 283.42	 -84.45	 1.0	 100.0	 1	 600.0	 200.0; % COW
	2946	 -98.065	 0.48	 1.83	 -0.87	 1.0	 100.0	 1	 100.0	 -296.13; % NG
	2956	 266.665	 49.89	 172.53	 -72.75	 1.0	 100.0	 1	 400.0	 133.33; % COW
	2973	 666.665	 125.9	 432.47	 -180.67	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	2975	 34.225	 5.885	 18.35	 -6.58	 1.0	 100.0	 1	 100.0	 -31.55; % COW
	2982	 40.0	 9.13	 34.04	 -15.78	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	2985	 246.675	 25.895	 184.46	 -132.67	 1.0	 100.0	 1	 493.35	 0.0; % COW
	2987	 160.0	 39.945	 139.64	 -59.75	 1.0	 100.0	 1	 320.0	 0.0; % NG
	2989	 -311.335	 17.87	 55.22	 -19.48	 1.0	 100.0	 1	 100.0	 -722.67; % COW
	2992	 266.665	 67.125	 189.58	 -55.33	 1.0	 100.0	 1	 400.0	 133.33; % NG
	2997	 2133.335	 453.315	 1434.05	 -527.42	 1.0	 100.0	 1	 3200.0	 1066.67; % COW
	3002	 38.0	 -2.44	 21.56	 -26.44	 1.0	 100.0	 1	 100.0	 -24.0; % COW
	3003	 250.0	 125.405	 370.58	 -119.77	 1.0	 100.0	 1	 400.0	 100.0; % COW
	3009	 -18.665	 17.11	 47.72	 -13.5	 1.0	 100.0	 1	 100.0	 -137.33; % COW
	3018	 100.0	 27.395	 89.61	 -34.82	 1.0	 100.0	 1	 200.0	 0.0; % NG
	3028	 666.665	 135.29	 441.85	 -171.27	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3029	 40.0	 12.625	 37.49	 -12.24	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3035	 800.0	 196.85	 564.62	 -170.92	 1.0	 100.0	 1	 1200.0	 400.0; % NG
	3038	 150.0	 35.785	 127.91	 -56.34	 1.0	 100.0	 1	 300.0	 0.0; % NG
	3039	 10.46	 4.97	 17.43	 -7.49	 1.0	 100.0	 1	 100.0	 -79.08; % NG
	3045	 11.065	 -1.56	 23.05	 -26.17	 1.0	 100.0	 1	 100.0	 -77.87; % NG
	3054	 266.665	 45.305	 167.72	 -77.11	 1.0	 100.0	 1	 400.0	 133.33; % NG
	3064	 256.0	 -0.6	 137.76	 -138.96	 1.0	 100.0	 1	 384.0	 128.0; % NG
	3078	 333.335	 75.065	 228.19	 -78.06	 1.0	 100.0	 1	 500.0	 166.67; % NG
	3084	 -4.885	 66.305	 188.93	 -56.32	 1.0	 100.0	 1	 100.0	 -109.77; % NG
	3088	 120.0	 32.235	 106.96	 -42.49	 1.0	 100.0	 1	 240.0	 0.0; % NG
	3090	 40.0	 13.13	 38.06	 -11.8	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3091	 16.515	 -5.13	 15.99	 -26.25	 1.0	 100.0	 1	 33.03	 0.0; % NG
	3096	 10.465	 -7.755	 21.04	 -36.55	 1.0	 100.0	 1	 100.0	 -79.07; % NG
	3113	 36.465	 0.7	 22.39	 -20.99	 1.0	 100.0	 1	 100.0	 -27.07; % NG
	3114	 20.0	 4.86	 17.33	 -7.61	 1.0	 100.0	 1	 40.0	 0.0; % NG
	3127	 400.0	 66.65	 250.27	 -116.97	 1.0	 100.0	 1	 600.0	 200.0; % NG
	3130	 400.0	 94.845	 278.16	 -88.47	 1.0	 100.0	 1	 600.0	 200.0; % COW
	3133	 120.0	 39.205	 113.97	 -35.56	 1.0	 100.0	 1	 240.0	 0.0; % NG
	3134	 -40.865	 20.46	 70.25	 -29.33	 1.0	 100.0	 1	 100.0	 -181.73; % NG
	3135	 99.04	 29.29	 161.69	 -103.11	 1.0	 100.0	 1	 198.08	 0.0; % NG
	3147	 128.065	 64.795	 187.35	 -57.76	 1.0	 100.0	 1	 200.0	 56.13; % NG
	3150	 29.105	 0.78	 6.66	 -5.1	 1.0	 100.0	 1	 100.0	 -41.79; % NG
	3152	 60.0	 17.275	 54.68	 -20.13	 1.0	 100.0	 1	 120.0	 0.0; % NG
	3156	 7.865	 -5.425	 21.53	 -32.38	 1.0	 100.0	 1	 100.0	 -84.27; % COW
	3157	 9.205	 0.825	 6.78	 -5.13	 1.0	 100.0	 1	 18.41	 0.0; % NG
	3158	 34.2	 47.155	 138.81	 -44.5	 1.0	 100.0	 1	 100.0	 -31.6; % COW
	3163	 103.43	 -0.55	 67.92	 -69.02	 1.0	 100.0	 1	 206.86	 0.0; % NG
	3183	 60.0	 16.36	 53.7	 -20.98	 1.0	 100.0	 1	 120.0	 0.0; % COW
	3189	 50.0	 14.05	 44.68	 -16.58	 1.0	 100.0	 1	 100.0	 0.0; % COW
	3198	 120.0	 38.845	 113.55	 -35.86	 1.0	 100.0	 1	 240.0	 0.0; % NG
	3205	 270.0	 77.575	 243.61	 -88.46	 1.0	 100.0	 1	 540.0	 0.0; % NG
	3218	 -21.6	 11.895	 36.79	 -13.0	 1.0	 100.0	 1	 100.0	 -143.2; % NG
	3219	 25.665	 57.96	 180.55	 -64.63	 1.0	 100.0	 1	 100.0	 -48.67; % NG
	3227	 266.665	 51.2	 173.96	 -71.56	 1.0	 100.0	 1	 400.0	 133.33; % COW
	3229	 266.665	 54.975	 177.61	 -67.66	 1.0	 100.0	 1	 400.0	 133.33; % NG
	3233	 210.0	 49.68	 178.47	 -79.11	 1.0	 100.0	 1	 420.0	 0.0; % NG
	3234	 60.0	 19.305	 56.14	 -17.53	 1.0	 100.0	 1	 120.0	 0.0; % COW
	3236	 266.665	 51.27	 173.85	 -71.31	 1.0	 100.0	 1	 400.0	 133.33; % NG
	3240	 21.8	 5.43	 62.23	 -51.37	 1.0	 100.0	 1	 100.0	 -56.4; % NG
	3251	 533.335	 133.365	 378.64	 -111.91	 1.0	 100.0	 1	 800.0	 266.67; % COW
	3253	 64.625	 -4.13	 64.47	 -72.73	 1.0	 100.0	 1	 129.25	 0.0; % COW
	3263	 40.0	 13.725	 38.65	 -11.2	 1.0	 100.0	 1	 80.0	 0.0; % COW
	3264	 22.5	 4.9	 17.36	 -7.56	 1.0	 100.0	 1	 45.0	 0.0; % COW
	3278	 60.0	 14.895	 52.31	 -22.52	 1.0	 100.0	 1	 120.0	 0.0; % NG
	3284	 90.0	 26.655	 81.97	 -28.66	 1.0	 100.0	 1	 180.0	 0.0; % NG
	3285	 533.335	 111.175	 356.44	 -134.09	 1.0	 100.0	 1	 800.0	 266.67; % COW
	3290	 90.0	 21.17	 76.54	 -34.2	 1.0	 100.0	 1	 180.0	 0.0; % NG
	3291	 333.335	 75.99	 229.0	 -77.02	 1.0	 100.0	 1	 500.0	 166.67; % COW
	3292	 213.335	 -33.72	 115.17	 -182.61	 1.0	 100.0	 1	 320.0	 106.67; % NG
	3298	 120.0	 28.845	 103.58	 -45.89	 1.0	 100.0	 1	 240.0	 0.0; % NG
	3304	 276.0	 -45.42	 83.58	 -174.42	 1.0	 100.0	 1	 414.0	 138.0; % NG
	3306	 666.665	 132.885	 439.2	 -173.43	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3310	 30.53	 2.82	 22.58	 -16.94	 1.0	 100.0	 1	 61.06	 0.0; % NG
	3322	 32.94	 16.3	 46.86	 -14.26	 1.0	 100.0	 1	 100.0	 -34.12; % NG
	3323	 41.66	 -1.55	 4.45	 -7.55	 1.0	 100.0	 1	 100.0	 -16.68; % NG
	3324	 32.35	 13.245	 38.13	 -11.64	 1.0	 100.0	 1	 100.0	 -35.3; % NG
	3326	 800.0	 196.985	 564.44	 -170.47	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	3330	 100.0	 32.125	 93.36	 -29.11	 1.0	 100.0	 1	 200.0	 0.0; % NG
	3334	 19.665	 9.535	 34.41	 -15.34	 1.0	 100.0	 1	 100.0	 -60.67; % NG
	3335	 0.0	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 630.0	 -630.0; % COW
	3336	 21.8	 0.36	 4.85	 -4.13	 1.0	 100.0	 1	 100.0	 -56.4; % NG
	3340	 -141.8	 17.595	 55.0	 -19.81	 1.0	 100.0	 1	 100.0	 -383.6; % NG
	3345	 -24.6	 -4.16	 39.1	 -47.42	 1.0	 100.0	 1	 100.0	 -149.2; % COW
	3346	 40.0	 12.17	 37.1	 -12.76	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3349	 100.0	 30.185	 91.48	 -31.11	 1.0	 100.0	 1	 200.0	 0.0; % NG
	3353	 40.0	 13.295	 38.2	 -11.61	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3362	 40.0	 11.9	 36.83	 -13.03	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3364	 67.635	 2.875	 47.19	 -41.44	 1.0	 100.0	 1	 135.27	 0.0; % COW
	3371	 40.0	 11.42	 36.31	 -13.47	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3375	 58.535	 53.045	 175.66	 -69.57	 1.0	 100.0	 1	 100.0	 17.07; % COW
	3389	 60.0	 18.955	 56.35	 -18.44	 1.0	 100.0	 1	 120.0	 0.0; % COW
	3390	 60.0	 17.2	 54.59	 -20.19	 1.0	 100.0	 1	 120.0	 0.0; % PEL
	3396	 150.0	 39.855	 131.75	 -52.04	 1.0	 100.0	 1	 300.0	 0.0; % NG
	3411	 -32.465	 7.155	 25.57	 -11.26	 1.0	 100.0	 1	 100.0	 -164.93; % NG
	3416	 90.0	 21.155	 76.43	 -34.12	 1.0	 100.0	 1	 180.0	 0.0; % NG
	3422	 60.0	 20.845	 58.19	 -16.5	 1.0	 100.0	 1	 120.0	 0.0; % NG
	3426	 36.71	 -6.125	 44.78	 -57.03	 1.0	 100.0	 1	 73.42	 0.0; % PEL
	3431	 100.0	 31.0	 92.26	 -30.26	 1.0	 100.0	 1	 200.0	 0.0; % NG
	3436	 800.0	 183.04	 550.97	 -184.89	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	3438	 -8.335	 12.49	 37.4	 -12.42	 1.0	 100.0	 1	 100.0	 -116.67; % COW
	3441	 133.335	 28.085	 89.45	 -33.28	 1.0	 100.0	 1	 200.0	 66.67; % NG
	3480	 266.665	 62.82	 185.19	 -59.55	 1.0	 100.0	 1	 400.0	 133.33; % NG
	3492	 -197.2	 16.335	 53.75	 -21.08	 1.0	 100.0	 1	 100.0	 -494.4; % COW
	3507	 60.0	 14.725	 51.58	 -22.13	 1.0	 100.0	 1	 120.0	 0.0; % COW
	3508	 60.0	 16.725	 54.09	 -20.64	 1.0	 100.0	 1	 120.0	 0.0; % COW
	3511	 533.335	 122.145	 366.74	 -122.45	 1.0	 100.0	 1	 800.0	 266.67; % COW
	3513	 600.0	 112.24	 387.88	 -163.4	 1.0	 100.0	 1	 900.0	 300.0; % COW
	3515	 -6.935	 13.66	 38.54	 -11.22	 1.0	 100.0	 1	 100.0	 -113.87; % NG
	3518	 666.665	 127.965	 433.83	 -177.9	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3547	 133.335	 29.78	 91.06	 -31.5	 1.0	 100.0	 1	 200.0	 66.67; % NG
	3550	 180.0	 44.875	 157.15	 -67.4	 1.0	 100.0	 1	 360.0	 0.0; % NG
	3551	 25.265	 52.875	 175.51	 -69.76	 1.0	 100.0	 1	 100.0	 -49.47; % NG
	3565	 40.0	 13.93	 38.83	 -10.97	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3570	 200.0	 32.47	 124.15	 -59.21	 1.0	 100.0	 1	 300.0	 100.0; % NG
	3571	 120.0	 27.24	 100.91	 -46.43	 1.0	 100.0	 1	 240.0	 0.0; % NG
	3580	 300.0	 77.17	 261.7	 -107.36	 1.0	 100.0	 1	 600.0	 0.0; % COW
	3582	 -164.535	 0.395	 52.83	 -52.04	 1.0	 100.0	 1	 100.0	 -429.07; % NG
	3583	 20.0	 5.225	 17.7	 -7.25	 1.0	 100.0	 1	 40.0	 0.0; % COW
	3584	 -8.935	 2.34	 19.8	 -15.12	 1.0	 100.0	 1	 100.0	 -117.87; % NG
	3585	 40.0	 12.555	 37.43	 -12.32	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3590	 29.335	 0.705	 2.66	 -1.25	 1.0	 100.0	 1	 100.0	 -41.33; % NG
	3599	 -7.065	 13.24	 38.12	 -11.64	 1.0	 100.0	 1	 100.0	 -114.13; % NG
	3605	 90.0	 23.28	 78.6	 -32.04	 1.0	 100.0	 1	 180.0	 0.0; % NG
	3611	 -33.6	 17.235	 54.59	 -20.12	 1.0	 100.0	 1	 100.0	 -167.2; % COW
	3618	 40.0	 11.27	 36.22	 -13.68	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3621	 150.0	 37.985	 130.01	 -54.04	 1.0	 100.0	 1	 300.0	 0.0; % NG
	3625	 78.75	 -8.145	 58.77	 -75.06	 1.0	 100.0	 1	 157.5	 0.0; % NG
	3628	 526.665	 63.89	 253.06	 -125.28	 1.0	 100.0	 1	 790.0	 263.33; % COW
	3629	 80.0	 27.105	 76.85	 -22.64	 1.0	 100.0	 1	 160.0	 0.0; % NG
	3634	 333.335	 64.62	 217.44	 -88.2	 1.0	 100.0	 1	 500.0	 166.67; % COW
	3635	 41.055	 -9.44	 22.56	 -41.44	 1.0	 100.0	 1	 82.11	 0.0; % NG
	3638	 167.79	 22.35	 153.73	 -109.03	 1.0	 100.0	 1	 335.58	 0.0; % COW
	3644	 33.045	 0.565	 22.35	 -21.22	 1.0	 100.0	 1	 66.09	 0.0; % NG
	3656	 32.535	 41.375	 116.07	 -33.32	 1.0	 100.0	 1	 100.0	 -34.93; % PEL
	3659	 1333.335	 330.815	 943.64	 -282.01	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	3660	 -35.69	 -6.485	 35.56	 -48.53	 1.0	 100.0	 1	 100.0	 -171.38; % NG
	3661	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3673	 400.0	 73.59	 257.61	 -110.43	 1.0	 100.0	 1	 600.0	 200.0; % COW
	3689	 3.1	 0.565	 2.18	 -1.05	 1.0	 100.0	 1	 6.2	 0.0; % NG
	3691	 200.0	 41.975	 133.84	 -49.89	 1.0	 100.0	 1	 300.0	 100.0; % NG
	3692	 210.0	 51.135	 180.11	 -77.84	 1.0	 100.0	 1	 420.0	 0.0; % COW
	3696	 533.335	 109.44	 354.58	 -135.7	 1.0	 100.0	 1	 800.0	 266.67; % COW
	3698	 41.61	 11.435	 36.34	 -13.47	 1.0	 100.0	 1	 100.0	 -16.78; % NG
	3711	 40.0	 13.49	 38.36	 -11.38	 1.0	 100.0	 1	 80.0	 0.0; % COW
	3720	 -0.265	 5.955	 18.4	 -6.49	 1.0	 100.0	 1	 100.0	 -100.53; % NG
	3723	 800.0	 146.21	 514.15	 -221.73	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	3724	 50.0	 12.235	 42.94	 -18.47	 1.0	 100.0	 1	 100.0	 0.0; % COW
	3739	 40.0	 14.0	 38.9	 -10.9	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3741	 800.0	 180.705	 548.57	 -187.16	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	3743	 22.345	 9.99	 28.38	 -8.4	 1.0	 100.0	 1	 100.0	 -55.31; % NG
	3746	 40.0	 13.17	 38.06	 -11.72	 1.0	 100.0	 1	 80.0	 0.0; % COW
	3750	 160.0	 48.16	 148.02	 -51.7	 1.0	 100.0	 1	 320.0	 0.0; % NG
	3753	 400.0	 71.73	 255.79	 -112.33	 1.0	 100.0	 1	 600.0	 200.0; % COW
	3755	 -44.465	 -5.2	 32.42	 -42.82	 1.0	 100.0	 1	 100.0	 -188.93; % NG
	3759	 100.0	 29.02	 90.31	 -32.27	 1.0	 100.0	 1	 200.0	 0.0; % NG
	3766	 33.39	 -2.845	 32.06	 -37.75	 1.0	 100.0	 1	 66.78	 0.0; % PEL
	3769	 120.0	 36.61	 110.34	 -37.12	 1.0	 100.0	 1	 240.0	 0.0; % NG
	3782	 -34.6	 5.29	 17.76	 -7.18	 1.0	 100.0	 1	 100.0	 -169.2; % NG
	3791	 60.0	 17.365	 54.7	 -19.97	 1.0	 100.0	 1	 120.0	 0.0; % COW
	3792	 120.0	 33.405	 108.06	 -41.25	 1.0	 100.0	 1	 240.0	 0.0; % NG
	3797	 -86.135	 10.52	 35.41	 -14.37	 1.0	 100.0	 1	 100.0	 -272.27; % NG
	3800	 38.485	 -6.53	 35.4	 -48.46	 1.0	 100.0	 1	 76.97	 0.0; % COW
	3808	 666.665	 160.45	 467.02	 -146.12	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3809	 466.665	 98.14	 313.01	 -116.73	 1.0	 100.0	 1	 700.0	 233.33; % COW
	3810	 133.335	 33.725	 94.81	 -27.36	 1.0	 100.0	 1	 200.0	 66.67; % COW
	3821	 266.665	 43.295	 165.76	 -79.17	 1.0	 100.0	 1	 400.0	 133.33; % NG
	3825	 600.0	 112.385	 388.17	 -163.4	 1.0	 100.0	 1	 900.0	 300.0; % NUC
	3840	 34.7	 0.435	 36.29	 -35.42	 1.0	 100.0	 1	 100.0	 -30.6; % COW
	3841	 90.0	 24.335	 79.52	 -30.85	 1.0	 100.0	 1	 180.0	 0.0; % COW
	3850	 266.665	 62.82	 185.19	 -59.55	 1.0	 100.0	 1	 400.0	 133.33; % NG
	3851	 22.345	 9.84	 28.23	 -8.55	 1.0	 100.0	 1	 100.0	 -55.31; % NG
	3853	 266.665	 60.095	 182.73	 -62.54	 1.0	 100.0	 1	 400.0	 133.33; % COW
	3869	 666.665	 134.275	 440.69	 -172.14	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3870	 77.28	 -24.795	 85.5	 -135.09	 1.0	 100.0	 1	 154.56	 0.0; % NG
	3876	 33.265	 9.375	 34.27	 -15.52	 1.0	 100.0	 1	 100.0	 -33.47; % NG
	3879	 80.0	 21.17	 71.02	 -28.68	 1.0	 100.0	 1	 160.0	 0.0; % NG
	3888	 60.0	 19.5	 56.84	 -17.84	 1.0	 100.0	 1	 120.0	 0.0; % NG
	3900	 60.0	 16.77	 54.19	 -20.65	 1.0	 100.0	 1	 120.0	 0.0; % NG
	3907	 240.0	 21.145	 152.36	 -110.07	 1.0	 100.0	 1	 360.0	 120.0; % NG
	3908	 5.04	 1.115	 4.25	 -2.02	 1.0	 100.0	 1	 10.08	 0.0; % NG
	3910	 266.665	 51.22	 173.84	 -71.4	 1.0	 100.0	 1	 400.0	 133.33; % COW
	3916	 35.815	 13.125	 38.02	 -11.77	 1.0	 100.0	 1	 100.0	 -28.37; % NG
	3920	 266.665	 52.9	 175.53	 -69.73	 1.0	 100.0	 1	 400.0	 133.33; % COW
	3922	 400.0	 72.025	 256.11	 -112.06	 1.0	 100.0	 1	 600.0	 200.0; % COW
	3938	 20.8	 6.97	 25.39	 -11.45	 1.0	 100.0	 1	 100.0	 -58.4; % NG
	3940	 666.665	 144.52	 450.57	 -161.53	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3948	 34.21	 7.895	 26.31	 -10.52	 1.0	 100.0	 1	 100.0	 -31.58; % NG
	3949	 100.0	 31.885	 94.12	 -30.35	 1.0	 100.0	 1	 200.0	 0.0; % NG
	3951	 31.935	 -0.7	 126.16	 -127.56	 1.0	 100.0	 1	 100.0	 -36.13; % NG
	3958	 60.0	 18.45	 55.3	 -18.4	 1.0	 100.0	 1	 120.0	 0.0; % NG
	3959	 29.625	 -4.29	 20.0	 -28.58	 1.0	 100.0	 1	 59.25	 0.0; % COW
	3963	 266.665	 54.34	 177.09	 -68.41	 1.0	 100.0	 1	 400.0	 133.33; % NG
	3971	 -39.665	 18.29	 55.67	 -19.09	 1.0	 100.0	 1	 100.0	 -179.33; % NG
	3979	 159.6	 -43.05	 120.7	 -206.8	 1.0	 100.0	 1	 319.2	 0.0; % COW
	3983	 200.0	 43.115	 134.98	 -48.75	 1.0	 100.0	 1	 300.0	 100.0; % NG
	3987	 40.0	 13.165	 38.05	 -11.72	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3991	 -90.595	 12.705	 37.63	 -12.22	 1.0	 100.0	 1	 100.0	 -281.19; % NG
	3996	 -30.8	 6.155	 18.62	 -6.31	 1.0	 100.0	 1	 100.0	 -161.6; % NG
	4009	 60.0	 17.54	 54.88	 -19.8	 1.0	 100.0	 1	 120.0	 0.0; % NG
	4012	 40.0	 13.0	 37.87	 -11.87	 1.0	 100.0	 1	 80.0	 0.0; % COW
	4016	 60.0	 14.905	 52.25	 -22.44	 1.0	 100.0	 1	 120.0	 0.0; % COW
	4024	 100.0	 34.815	 97.07	 -27.44	 1.0	 100.0	 1	 200.0	 0.0; % NG
	4026	 333.335	 69.685	 223.07	 -83.7	 1.0	 100.0	 1	 500.0	 166.67; % COW
	4028	 7.53	 5.965	 18.44	 -6.51	 1.0	 100.0	 1	 100.0	 -84.94; % NG
	4046	 266.665	 56.055	 178.68	 -66.57	 1.0	 100.0	 1	 400.0	 133.33; % NG
	4052	 40.0	 10.805	 35.73	 -14.12	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4056	 -1.265	 13.14	 38.05	 -11.77	 1.0	 100.0	 1	 100.0	 -102.53; % NG
	4071	 52.5	 -5.875	 38.72	 -50.47	 1.0	 100.0	 1	 105.0	 0.0; % NG
	4075	 60.0	 18.365	 55.21	 -18.48	 1.0	 100.0	 1	 120.0	 0.0; % PEL
	4076	 133.335	 27.215	 88.51	 -34.08	 1.0	 100.0	 1	 200.0	 66.67; % NG
	4084	 300.0	 80.6	 264.94	 -103.74	 1.0	 100.0	 1	 600.0	 0.0; % COW
	4085	 100.0	 24.455	 85.83	 -36.92	 1.0	 100.0	 1	 200.0	 0.0; % NG
	4090	 -21.465	 -10.09	 38.67	 -58.85	 1.0	 100.0	 1	 100.0	 -142.93; % NG
	4094	 250.0	 70.58	 223.91	 -82.75	 1.0	 100.0	 1	 400.0	 100.0; % COW
	4106	 32.13	 -3.01	 30.6	 -36.62	 1.0	 100.0	 1	 64.26	 0.0; % NG
	4118	 40.0	 13.485	 38.37	 -11.4	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4122	 150.0	 42.51	 134.14	 -49.12	 1.0	 100.0	 1	 300.0	 0.0; % COW
	4125	 40.0	 11.945	 36.89	 -13.0	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4128	 60.0	 19.7	 57.03	 -17.63	 1.0	 100.0	 1	 120.0	 0.0; % NG
	4131	 266.665	 61.615	 184.19	 -60.96	 1.0	 100.0	 1	 400.0	 133.33; % NG
	4163	 266.665	 65.625	 188.07	 -56.82	 1.0	 100.0	 1	 400.0	 133.33; % NG
	4172	 20.0	 6.15	 18.58	 -6.28	 1.0	 100.0	 1	 40.0	 0.0; % NG
	4175	 1333.335	 291.53	 904.67	 -321.61	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	4178	 400.0	 80.195	 264.0	 -103.61	 1.0	 100.0	 1	 600.0	 200.0; % COW
	4179	 60.0	 17.19	 54.59	 -20.21	 1.0	 100.0	 1	 120.0	 0.0; % NG
	4182	 533.335	 99.42	 344.9	 -146.06	 1.0	 100.0	 1	 800.0	 266.67; % COW
	4183	 48.3	 13.42	 38.27	 -11.43	 1.0	 100.0	 1	 100.0	 -3.4; % NG
	4192	 600.0	 120.695	 396.38	 -154.99	 1.0	 100.0	 1	 900.0	 300.0; % NUC
	4195	 -275.935	 159.055	 465.42	 -147.31	 1.0	 100.0	 1	 100.0	 -651.87; % NG
	4198	 45.915	 3.97	 64.15	 -56.21	 1.0	 100.0	 1	 91.83	 0.0; % NG
	4200	 200.0	 39.4	 131.25	 -52.45	 1.0	 100.0	 1	 300.0	 100.0; % COW
	4204	 17.895	 0.49	 1.83	 -0.85	 1.0	 100.0	 1	 100.0	 -64.21; % NG
	4207	 500.0	 127.4	 373.46	 -118.66	 1.0	 100.0	 1	 800.0	 200.0; % COW
	4210	 80.0	 21.685	 71.61	 -28.24	 1.0	 100.0	 1	 160.0	 0.0; % NG
	4211	 20.0	 7.095	 19.55	 -5.36	 1.0	 100.0	 1	 40.0	 0.0; % NG
	4221	 101.875	 -2.19	 72.12	 -76.5	 1.0	 100.0	 1	 203.75	 0.0; % NG
	4228	 1.265	 16.995	 47.62	 -13.63	 1.0	 100.0	 1	 100.0	 -97.47; % NG
	4231	 2761.14	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 4188.95	 1333.33; % NG
	4244	 533.335	 109.72	 354.48	 -135.04	 1.0	 100.0	 1	 800.0	 266.67; % COW
	4259	 20.0	 5.98	 18.41	 -6.45	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	4278	 83.68	 -30.21	 75.89	 -136.31	 1.0	 100.0	 1	 167.36	 0.0; % NG
	4279	 400.0	 77.605	 261.6	 -106.39	 1.0	 100.0	 1	 600.0	 200.0; % COW
	4291	 210.0	 67.1	 196.08	 -61.88	 1.0	 100.0	 1	 420.0	 0.0; % COW
	4296	 20.0	 5.545	 18.02	 -6.93	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	4322	 200.0	 49.89	 141.75	 -41.97	 1.0	 100.0	 1	 300.0	 100.0; % NG
	4323	 160.0	 50.255	 149.98	 -49.47	 1.0	 100.0	 1	 320.0	 0.0; % NG
	4330	 1066.665	 233.235	 723.46	 -256.99	 1.0	 100.0	 1	 1600.0	 533.33; % COW
	4331	 40.0	 11.805	 36.73	 -13.12	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4333	 90.0	 23.82	 79.1	 -31.46	 1.0	 100.0	 1	 180.0	 0.0; % NG
	4334	 50.0	 14.46	 45.09	 -16.17	 1.0	 100.0	 1	 100.0	 0.0; % NG
	4337	 800.0	 209.295	 576.78	 -158.19	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	4338	 15.0	 4.48	 16.93	 -7.97	 1.0	 100.0	 1	 100.0	 -70.0; % COW
	4350	 100.0	 26.155	 87.37	 -35.06	 1.0	 100.0	 1	 200.0	 0.0; % NG
	4375	 40.0	 11.99	 36.93	 -12.95	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4376	 200.0	 37.455	 129.29	 -54.38	 1.0	 100.0	 1	 300.0	 100.0; % NG
	4393	 200.0	 50.065	 142.0	 -41.87	 1.0	 100.0	 1	 300.0	 100.0; % COW
	4395	 -36.065	 13.575	 38.48	 -11.33	 1.0	 100.0	 1	 100.0	 -172.13; % NG
	4396	 200.0	 50.9	 142.82	 -41.02	 1.0	 100.0	 1	 300.0	 100.0; % NG
	4398	 150.0	 42.2	 134.39	 -49.99	 1.0	 100.0	 1	 300.0	 0.0; % NG
	4399	 43.905	 5.645	 18.1	 -6.81	 1.0	 100.0	 1	 100.0	 -12.19; % COW
	4400	 266.665	 51.945	 174.6	 -70.71	 1.0	 100.0	 1	 400.0	 133.33; % COW
	4419	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	4420	 44.1	 -2.815	 51.76	 -57.39	 1.0	 100.0	 1	 88.2	 0.0; % NG
	4428	 30.12	 0.625	 20.49	 -19.24	 1.0	 100.0	 1	 60.24	 0.0; % COW
	4429	 23.1	 9.995	 24.74	 -4.75	 1.0	 100.0	 1	 46.2	 0.0; % NG
	4440	 16.265	 33.65	 94.73	 -27.43	 1.0	 100.0	 1	 100.0	 -67.47; % COW
	4442	 42.51	 0.345	 34.61	 -33.92	 1.0	 100.0	 1	 100.0	 -14.98; % COW
	4445	 429.19	 17.18	 269.01	 -234.65	 1.0	 100.0	 1	 772.54	 85.84; % NUC
	4447	 266.665	 60.175	 182.87	 -62.52	 1.0	 100.0	 1	 400.0	 133.33; % NG
	4455	 601.335	 15.245	 204.12	 -173.63	 1.0	 100.0	 1	 902.0	 300.67; % NUC
	4464	 60.0	 21.075	 58.41	 -16.26	 1.0	 100.0	 1	 120.0	 0.0; % NG
	4468	 -1.135	 13.09	 38.01	 -11.83	 1.0	 100.0	 1	 100.0	 -102.27; % NG
	4478	 333.335	 67.405	 220.62	 -85.81	 1.0	 100.0	 1	 500.0	 166.67; % COW
	4480	 666.665	 132.885	 439.2	 -173.43	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	4482	 40.0	 13.95	 38.85	 -10.95	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4486	 20.0	 4.46	 16.9	 -7.98	 1.0	 100.0	 1	 40.0	 0.0; % NG
	4498	 100.0	 28.235	 89.58	 -33.11	 1.0	 100.0	 1	 200.0	 0.0; % COW
	4502	 60.0	 14.265	 51.15	 -22.62	 1.0	 100.0	 1	 120.0	 0.0; % NG
	4506	 -64.535	 12.955	 37.86	 -11.95	 1.0	 100.0	 1	 100.0	 -229.07; % NG
	4516	 266.665	 50.34	 173.07	 -72.39	 1.0	 100.0	 1	 400.0	 133.33; % COW
	4526	 30.0	 8.395	 26.83	 -10.04	 1.0	 100.0	 1	 60.0	 0.0; % NG
	4533	 1600.0	 338.34	 1074.34	 -397.66	 1.0	 100.0	 1	 2400.0	 800.0; % COW
	4552	 -28.495	 -0.425	 3.57	 -4.42	 1.0	 100.0	 1	 100.0	 -156.99; % COW
	4564	 162.5	 30.49	 122.64	 -61.66	 1.0	 100.0	 1	 325.0	 0.0; % NG
	4566	 29.745	 13.035	 37.94	 -11.87	 1.0	 100.0	 1	 100.0	 -40.51; % NG
	4573	 46.745	 2.415	 51.69	 -46.86	 1.0	 100.0	 1	 93.49	 0.0; % NG
	4586	 -313.8	 31.575	 92.96	 -29.81	 1.0	 100.0	 1	 100.0	 -727.6; % NG
	4602	 533.335	 130.385	 375.7	 -114.93	 1.0	 100.0	 1	 800.0	 266.67; % COW
	4608	 13.23	 0.04	 17.31	 -17.23	 1.0	 100.0	 1	 26.46	 0.0; % PEL
	4609	 36.29	 3.39	 45.93	 -39.15	 1.0	 100.0	 1	 72.58	 0.0; % NG
	4613	 514.665	 -56.625	 254.86	 -368.11	 1.0	 100.0	 1	 772.0	 257.33; % NUC
	4620	 100.0	 32.5	 93.85	 -28.85	 1.0	 100.0	 1	 200.0	 0.0; % NG
	4624	 40.0	 10.715	 35.62	 -14.19	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4633	 5.935	 -3.66	 -0.72	 -6.6	 1.0	 100.0	 1	 100.0	 -88.13; % NG
	4638	 -107.535	 13.355	 38.28	 -11.57	 1.0	 100.0	 1	 100.0	 -315.07; % NG
	4647	 50.0	 14.305	 45.01	 -16.4	 1.0	 100.0	 1	 100.0	 0.0; % NG
	4654	 105.0	 8.875	 133.34	 -115.59	 1.0	 100.0	 1	 210.0	 0.0; % NG
	4657	 150.0	 48.835	 140.98	 -43.31	 1.0	 100.0	 1	 300.0	 0.0; % COW
	4661	 -2.6	 6.685	 19.14	 -5.77	 1.0	 100.0	 1	 100.0	 -105.2; % NG
	4662	 1333.335	 284.39	 897.58	 -328.8	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	4663	 -27.335	 17.72	 55.07	 -19.63	 1.0	 100.0	 1	 100.0	 -154.67; % NG
	4666	 333.335	 46.7	 198.84	 -105.44	 1.0	 100.0	 1	 500.0	 166.67; % COW
	4667	 36.15	 12.87	 37.78	 -12.04	 1.0	 100.0	 1	 100.0	 -27.7; % NG
	4670	 333.335	 61.565	 214.71	 -91.58	 1.0	 100.0	 1	 500.0	 166.67; % COW
	4676	 533.335	 97.91	 343.25	 -147.43	 1.0	 100.0	 1	 800.0	 266.67; % COW
	4690	 600.0	 142.755	 417.98	 -132.47	 1.0	 100.0	 1	 900.0	 300.0; % COW
	4695	 -7.265	 13.655	 38.53	 -11.22	 1.0	 100.0	 1	 100.0	 -114.53; % COW
	4701	 140.925	 6.055	 98.4	 -86.29	 1.0	 100.0	 1	 281.85	 0.0; % NG
	4708	 60.0	 18.675	 56.03	 -18.68	 1.0	 100.0	 1	 120.0	 0.0; % COW
	4739	 40.0	 12.58	 37.44	 -12.28	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4749	 276.83	 0.34	 280.0	 -279.32	 1.0	 100.0	 1	 553.66	 0.0; % COW
	4755	 28.98	 -5.52	 30.48	 -41.52	 1.0	 100.0	 1	 57.96	 0.0; % NG
	4758	 400.0	 73.27	 257.49	 -110.95	 1.0	 100.0	 1	 600.0	 200.0; % COW
	4772	 100.0	 27.28	 89.54	 -34.98	 1.0	 100.0	 1	 200.0	 0.0; % NG
	4773	 32.65	 0.625	 22.15	 -20.9	 1.0	 100.0	 1	 65.3	 0.0; % PEL
	4776	 600.0	 114.335	 389.83	 -161.16	 1.0	 100.0	 1	 900.0	 300.0; % COW
	4783	 666.665	 132.885	 439.2	 -173.43	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	4788	 533.335	 134.22	 379.51	 -111.07	 1.0	 100.0	 1	 800.0	 266.67; % COW
	4805	 -72.335	 67.885	 190.29	 -54.52	 1.0	 100.0	 1	 100.0	 -244.67; % NG
	4816	 32.615	 13.465	 38.37	 -11.44	 1.0	 100.0	 1	 100.0	 -34.77; % NG
	4819	 666.665	 134.275	 440.69	 -172.14	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	4823	 5.23	 1.185	 4.44	 -2.07	 1.0	 100.0	 1	 10.46	 0.0; % NG
	4824	 800.0	 191.065	 558.52	 -176.39	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	4834	 5.515	 0.08	 7.0	 -6.84	 1.0	 100.0	 1	 11.03	 0.0; % NG
	4843	 6.815	 0.595	 5.0	 -3.81	 1.0	 100.0	 1	 13.63	 0.0; % COW
	4844	 300.0	 133.03	 377.48	 -111.42	 1.0	 100.0	 1	 500.0	 100.0; % COW
	4845	 45.835	 9.15	 27.54	 -9.24	 1.0	 100.0	 1	 100.0	 -8.33; % NG
	4846	 200.0	 41.975	 133.84	 -49.89	 1.0	 100.0	 1	 300.0	 100.0; % COW
	4847	 -65.8	 69.475	 192.1	 -53.15	 1.0	 100.0	 1	 100.0	 -231.6; % COW
	4848	 266.665	 65.035	 187.31	 -57.24	 1.0	 100.0	 1	 400.0	 133.33; % COW
	4850	 80.0	 26.665	 76.52	 -23.19	 1.0	 100.0	 1	 160.0	 0.0; % NG
	4871	 50.0	 13.17	 43.87	 -17.53	 1.0	 100.0	 1	 100.0	 0.0; % NG
	4880	 23.135	 25.83	 75.62	 -23.96	 1.0	 100.0	 1	 100.0	 -53.73; % NG
	4882	 6.825	 -1.78	 6.22	 -9.78	 1.0	 100.0	 1	 13.65	 0.0; % COW
	4892	 200.0	 51.72	 176.3	 -72.86	 1.0	 100.0	 1	 400.0	 0.0; % NG
	4897	 40.0	 12.675	 37.58	 -12.23	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4900	 12.495	 -2.21	 14.79	 -19.21	 1.0	 100.0	 1	 24.99	 0.0; % NG
	4918	 40.0	 12.35	 37.27	 -12.57	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4931	 51.395	 0.375	 34.39	 -33.64	 1.0	 100.0	 1	 102.79	 0.0; % NG
	4938	 1333.335	 321.275	 933.87	 -291.32	 1.0	 100.0	 1	 2000.0	 666.67; % NG
	4944	 44.105	 6.17	 18.64	 -6.3	 1.0	 100.0	 1	 100.0	 -11.79; % NG
	4945	 333.335	 71.09	 224.4	 -82.22	 1.0	 100.0	 1	 500.0	 166.67; % NG
	4949	 60.0	 20.315	 57.63	 -17.0	 1.0	 100.0	 1	 120.0	 0.0; % NG
	4952	 41.615	 12.31	 37.23	 -12.61	 1.0	 100.0	 1	 100.0	 -16.77; % NG
	4954	 60.0	 17.1	 54.46	 -20.26	 1.0	 100.0	 1	 120.0	 0.0; % NG
	4955	 79.7	 3.89	 73.86	 -66.08	 1.0	 100.0	 1	 159.4	 0.0; % NG
	4957	 800.0	 166.135	 533.39	 -201.12	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	4959	 584.0	 10.17	 460.83	 -440.49	 1.0	 100.0	 1	 876.0	 292.0; % COW
	4967	 210.0	 53.185	 182.2	 -75.83	 1.0	 100.0	 1	 420.0	 0.0; % NG
	4969	 533.335	 130.64	 375.73	 -114.45	 1.0	 100.0	 1	 800.0	 266.67; % COW
	4979	 150.0	 40.375	 132.46	 -51.71	 1.0	 100.0	 1	 300.0	 0.0; % COW
	4994	 266.665	 51.02	 173.76	 -71.72	 1.0	 100.0	 1	 400.0	 133.33; % NG
	4996	 80.0	 22.085	 71.89	 -27.72	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5004	 110.06	 2.16	 74.73	 -70.41	 1.0	 100.0	 1	 220.12	 0.0; % COW
	5005	 333.335	 67.715	 220.88	 -85.45	 1.0	 100.0	 1	 500.0	 166.67; % COW
	5019	 40.0	 12.815	 37.72	 -12.09	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	5020	 40.0	 13.97	 38.87	 -10.93	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5025	 -53.4	 0.675	 5.65	 -4.3	 1.0	 100.0	 1	 100.0	 -206.8; % NG
	5027	 43.135	 32.2	 93.58	 -29.18	 1.0	 100.0	 1	 100.0	 -13.73; % COW
	5036	 40.0	 10.105	 35.06	 -14.85	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5043	 100.0	 26.275	 88.65	 -36.1	 1.0	 100.0	 1	 200.0	 0.0; % NG
	5051	 80.0	 24.79	 74.55	 -24.97	 1.0	 100.0	 1	 160.0	 0.0; % PEL
	5059	 90.0	 26.655	 81.97	 -28.66	 1.0	 100.0	 1	 180.0	 0.0; % NG
	5060	 20.34	 0.895	 14.22	 -12.43	 1.0	 100.0	 1	 40.68	 0.0; % NG
	5065	 800.0	 164.885	 532.96	 -203.19	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	5067	 300.0	 74.665	 258.91	 -109.58	 1.0	 100.0	 1	 600.0	 0.0; % COW
	5075	 -11.735	 7.46	 25.91	 -10.99	 1.0	 100.0	 1	 100.0	 -123.47; % NG
	5091	 180.0	 41.28	 151.81	 -69.25	 1.0	 100.0	 1	 360.0	 0.0; % NG
	5092	 333.335	 68.33	 221.62	 -84.96	 1.0	 100.0	 1	 500.0	 166.67; % PEL
	5097	 14.155	 2.4	 8.91	 -4.11	 1.0	 100.0	 1	 21.23	 7.08; % NG
	5098	 536.0	 -141.735	 278.62	 -562.09	 1.0	 100.0	 1	 804.0	 268.0; % COW
	5110	 14.995	 13.39	 38.28	 -11.5	 1.0	 100.0	 1	 100.0	 -70.01; % COW
	5120	 60.0	 18.965	 56.35	 -18.42	 1.0	 100.0	 1	 120.0	 0.0; % COW
	5134	 110.225	 32.885	 100.9	 -35.13	 1.0	 100.0	 1	 220.45	 0.0; % NG
	5138	 266.665	 57.15	 179.86	 -65.56	 1.0	 100.0	 1	 400.0	 133.33; % NG
	5144	 1333.335	 269.81	 882.86	 -343.24	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	5145	 716.955	 29.645	 450.4	 -391.11	 1.0	 100.0	 1	 1290.52	 143.39; % NG
	5152	 40.0	 12.82	 37.75	 -12.11	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	5154	 13.94	 10.05	 28.42	 -8.32	 1.0	 100.0	 1	 100.0	 -72.12; % NG
	5158	 533.335	 100.475	 345.71	 -144.76	 1.0	 100.0	 1	 800.0	 266.67; % COW
	5164	 466.665	 87.35	 301.89	 -127.19	 1.0	 100.0	 1	 700.0	 233.33; % COW
	5171	 -8.4	 0.3	 32.89	 -32.29	 1.0	 100.0	 1	 100.0	 -116.8; % COW
	5180	 38.335	 1.105	 4.03	 -1.82	 1.0	 100.0	 1	 100.0	 -23.33; % NG
	5192	 90.0	 24.335	 79.52	 -30.85	 1.0	 100.0	 1	 180.0	 0.0; % COW
	5193	 40.0	 12.605	 37.47	 -12.26	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5225	 160.0	 45.565	 145.28	 -54.15	 1.0	 100.0	 1	 320.0	 0.0; % NG
	5226	 160.0	 45.86	 145.53	 -53.81	 1.0	 100.0	 1	 320.0	 0.0; % NG
	5231	 133.335	 30.685	 91.91	 -30.54	 1.0	 100.0	 1	 200.0	 66.67; % NG
	5236	 220.0	 56.365	 193.56	 -80.83	 1.0	 100.0	 1	 440.0	 0.0; % NG
	5237	 80.0	 25.14	 75.02	 -24.74	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5239	 -846.265	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 100.0	 -1792.53; % NG
	5251	 80.0	 21.54	 71.44	 -28.36	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5262	 333.335	 68.055	 221.33	 -85.22	 1.0	 100.0	 1	 500.0	 166.67; % NG
	5264	 63.315	 -17.95	 38.05	 -73.95	 1.0	 100.0	 1	 126.63	 0.0; % NG
	5273	 46.435	 17.31	 47.91	 -13.29	 1.0	 100.0	 1	 100.0	 -7.13; % NG
	5278	 60.0	 13.905	 51.3	 -23.49	 1.0	 100.0	 1	 120.0	 0.0; % COW
	5280	 -79.265	 0.615	 2.29	 -1.06	 1.0	 100.0	 1	 100.0	 -258.53; % NG
	5285	 100.0	 29.405	 91.72	 -32.91	 1.0	 100.0	 1	 200.0	 0.0; % NG
	5290	 180.0	 49.125	 159.67	 -61.42	 1.0	 100.0	 1	 360.0	 0.0; % NG
	5293	 229.335	 26.775	 151.05	 -97.5	 1.0	 100.0	 1	 344.0	 114.67; % COW
	5299	 870.165	 -19.975	 542.73	 -582.68	 1.0	 100.0	 1	 1689.14	 51.19; % COW
	5301	 100.0	 33.355	 94.66	 -27.95	 1.0	 100.0	 1	 200.0	 0.0; % NG
	5305	 125.265	 63.06	 185.68	 -59.56	 1.0	 100.0	 1	 200.0	 50.53; % NG
	5309	 204.545	 -3.695	 132.58	 -139.97	 1.0	 100.0	 1	 409.09	 0.0; % NG
	5323	 40.0	 13.52	 38.42	 -11.38	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5329	 13.475	 0.325	 35.25	 -34.6	 1.0	 100.0	 1	 100.0	 -73.05; % NG
	5340	 -56.0	 11.47	 36.37	 -13.43	 1.0	 100.0	 1	 100.0	 -212.0; % NG
	5348	 16.37	 0.64	 11.36	 -10.08	 1.0	 100.0	 1	 32.74	 0.0; % NG
	5352	 5.25	 -0.71	 4.29	 -5.71	 1.0	 100.0	 1	 10.5	 0.0; % PEL
	5365	 20.0	 5.695	 18.14	 -6.75	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	5368	 200.0	 45.87	 137.65	 -45.91	 1.0	 100.0	 1	 300.0	 100.0; % NG
	5369	 -0.995	 13.445	 38.34	 -11.45	 1.0	 100.0	 1	 100.0	 -101.99; % COW
	5379	 1333.335	 314.42	 926.47	 -297.63	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	5395	 -213.865	 20.7	 58.06	 -16.66	 1.0	 100.0	 1	 100.0	 -527.73; % NG
	5397	 -37.335	 11.96	 36.81	 -12.89	 1.0	 100.0	 1	 100.0	 -174.67; % COW
	5398	 266.665	 54.54	 177.29	 -68.21	 1.0	 100.0	 1	 400.0	 133.33; % NG
	5401	 50.0	 12.055	 42.68	 -18.57	 1.0	 100.0	 1	 100.0	 0.0; % NG
	5403	 333.335	 65.915	 219.43	 -87.6	 1.0	 100.0	 1	 500.0	 166.67; % NG
	5409	 120.0	 28.955	 102.6	 -44.69	 1.0	 100.0	 1	 240.0	 0.0; % NG
	5412	 266.665	 52.07	 174.75	 -70.61	 1.0	 100.0	 1	 400.0	 133.33; % NG
	5425	 120.0	 34.535	 108.27	 -39.2	 1.0	 100.0	 1	 240.0	 0.0; % NG
	5429	 150.0	 35.08	 127.12	 -56.96	 1.0	 100.0	 1	 300.0	 0.0; % NG
	5444	 550.0	 106.75	 382.87	 -169.37	 1.0	 100.0	 1	 900.0	 200.0; % COW
	5457	 40.0	 13.595	 38.49	 -11.3	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5461	 40.0	 13.355	 38.26	 -11.55	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5465	 46.735	 0.165	 31.09	 -30.76	 1.0	 100.0	 1	 93.47	 0.0; % NG
	5471	 400.0	 79.265	 263.39	 -104.86	 1.0	 100.0	 1	 600.0	 200.0; % COW
	5479	 266.665	 66.12	 188.35	 -56.11	 1.0	 100.0	 1	 400.0	 133.33; % NG
	5480	 40.0	 12.98	 37.89	 -11.93	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5481	 1333.335	 307.335	 920.31	 -305.64	 1.0	 100.0	 1	 2000.0	 666.67; % NG
	5482	 124.53	 26.6	 101.32	 -48.12	 1.0	 100.0	 1	 249.06	 0.0; % NG
	5486	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	5487	 200.0	 37.435	 129.3	 -54.43	 1.0	 100.0	 1	 300.0	 100.0; % COW
	5488	 -14.265	 12.58	 37.49	 -12.33	 1.0	 100.0	 1	 100.0	 -128.53; % NG
	5490	 2666.665	 539.345	 1765.36	 -686.67	 1.0	 100.0	 1	 4000.0	 1333.33; % COW
	5504	 40.0	 13.06	 37.98	 -11.86	 1.0	 100.0	 1	 80.0	 0.0; % COW
	5512	 80.0	 19.835	 69.67	 -30.0	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5513	 -80.665	 62.485	 185.06	 -60.09	 1.0	 100.0	 1	 100.0	 -261.33; % NG
	5530	 -13.935	 12.0	 36.94	 -12.94	 1.0	 100.0	 1	 100.0	 -127.87; % NG
	5533	 100.0	 26.58	 88.87	 -35.71	 1.0	 100.0	 1	 200.0	 0.0; % NG
	5546	 20.0	 6.705	 19.16	 -5.75	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	5556	 400.0	 71.865	 255.93	 -112.2	 1.0	 100.0	 1	 600.0	 200.0; % COW
	5564	 40.0	 11.905	 36.8	 -12.99	 1.0	 100.0	 1	 80.0	 0.0; % COW
	5572	 60.0	 18.365	 55.21	 -18.48	 1.0	 100.0	 1	 120.0	 0.0; % COW
	5594	 -108.8	 5.05	 17.52	 -7.42	 1.0	 100.0	 1	 100.0	 -317.6; % NG
	5602	 22.05	 -4.16	 25.84	 -34.16	 1.0	 100.0	 1	 44.1	 0.0; % NG
	5603	 120.015	 9.07	 141.02	 -122.88	 1.0	 100.0	 1	 240.03	 0.0; % NG
	5611	 20.0	 5.52	 17.99	 -6.95	 1.0	 100.0	 1	 40.0	 0.0; % NG
	5620	 -60.065	 25.495	 80.73	 -29.74	 1.0	 100.0	 1	 100.0	 -220.13; % NG
	5645	 60.0	 15.635	 52.51	 -21.24	 1.0	 100.0	 1	 120.0	 0.0; % NG
	5656	 61.895	 64.55	 187.06	 -57.96	 1.0	 100.0	 1	 100.0	 23.79; % NG
	5658	 120.0	 28.465	 103.18	 -46.25	 1.0	 100.0	 1	 240.0	 0.0; % NG
	5664	 80.0	 22.83	 72.71	 -27.05	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5668	 180.0	 54.375	 164.82	 -56.07	 1.0	 100.0	 1	 360.0	 0.0; % NG
	5669	 350.0	 9.565	 34.47	 -15.34	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5670	 33.88	 0.635	 22.97	 -21.7	 1.0	 100.0	 1	 67.76	 0.0; % NG
	5677	 60.0	 15.255	 52.14	 -21.63	 1.0	 100.0	 1	 120.0	 0.0; % COW
	5679	 25.94	 8.85	 27.25	 -9.55	 1.0	 100.0	 1	 100.0	 -48.12; % NG
	5692	 533.335	 111.26	 356.53	 -134.01	 1.0	 100.0	 1	 800.0	 266.67; % COW
	5705	 30.0	 9.76	 28.17	 -8.65	 1.0	 100.0	 1	 60.0	 0.0; % NG
	5709	 800.0	 182.77	 550.69	 -185.15	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	5714	 60.0	 18.675	 55.48	 -18.13	 1.0	 100.0	 1	 120.0	 0.0; % NG
	5717	 50.0	 13.335	 44.0	 -17.33	 1.0	 100.0	 1	 100.0	 0.0; % NG
	5721	 90.0	 27.355	 82.65	 -27.94	 1.0	 100.0	 1	 180.0	 0.0; % COW
	5722	 21.955	 -15.805	 31.42	 -63.03	 1.0	 100.0	 1	 100.0	 -56.09; % COW
	5726	 47.99	 0.22	 31.98	 -31.54	 1.0	 100.0	 1	 95.98	 0.0; % NG
	5737	 40.0	 13.115	 38.01	 -11.78	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5742	 56.76	 9.63	 35.69	 -16.43	 1.0	 100.0	 1	 85.14	 28.38; % NG
	5750	 204.0	 31.905	 123.76	 -59.95	 1.0	 100.0	 1	 306.0	 102.0; % COW
	5759	 533.335	 131.455	 376.65	 -113.74	 1.0	 100.0	 1	 800.0	 266.67; % COW
	5781	 1200.0	 227.25	 779.29	 -324.79	 1.0	 100.0	 1	 1800.0	 600.0; % COW
	5786	 31.92	 2.66	 23.3	 -17.98	 1.0	 100.0	 1	 63.84	 0.0; % NG
	5787	 120.0	 41.055	 114.67	 -32.56	 1.0	 100.0	 1	 240.0	 0.0; % NG
	5809	 266.665	 47.08	 169.19	 -75.03	 1.0	 100.0	 1	 400.0	 133.33; % NG
	5811	 20.0	 5.005	 17.42	 -7.41	 1.0	 100.0	 1	 40.0	 0.0; % NG
	5812	 150.0	 34.95	 126.98	 -57.08	 1.0	 100.0	 1	 300.0	 0.0; % NG
	5814	 293.335	 59.905	 196.98	 -77.17	 1.0	 100.0	 1	 440.0	 146.67; % NG
	5821	 0.53	 -0.235	 45.83	 -46.3	 1.0	 100.0	 1	 100.0	 -98.94; % NG
	5822	 187.235	 62.665	 185.23	 -59.9	 1.0	 100.0	 1	 300.0	 74.47; % NG
	5823	 333.335	 67.605	 220.75	 -85.54	 1.0	 100.0	 1	 500.0	 166.67; % COW
	5824	 800.0	 171.45	 539.22	 -196.32	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	5825	 350.0	 21.225	 76.5	 -34.05	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5828	 19.99	 0.83	 13.93	 -12.27	 1.0	 100.0	 1	 39.98	 0.0; % NG
	5831	 -69.6	 0.42	 1.58	 -0.74	 1.0	 100.0	 1	 100.0	 -239.2; % NG
	5838	 8.455	 -1.97	 13.03	 -16.97	 1.0	 100.0	 1	 16.91	 0.0; % NG
	5839	 60.0	 16.125	 53.01	 -20.76	 1.0	 100.0	 1	 120.0	 0.0; % COW
	5844	 400.0	 105.685	 351.25	 -139.88	 1.0	 100.0	 1	 800.0	 0.0; % COW
	5846	 19.0	 -2.59	 51.99	 -57.17	 1.0	 100.0	 1	 100.0	 -62.0; % NG
	5855	 533.335	 131.165	 376.39	 -114.06	 1.0	 100.0	 1	 800.0	 266.67; % COW
	5856	 320.0	 64.565	 214.13	 -85.0	 1.0	 100.0	 1	 480.0	 160.0; % COW
	5862	 40.0	 10.805	 35.73	 -14.12	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5863	 533.335	 113.18	 358.2	 -131.84	 1.0	 100.0	 1	 800.0	 266.67; % COW
	5864	 24.36	 0.96	 28.39	 -26.47	 1.0	 100.0	 1	 48.72	 0.0; % NG
	5868	 533.335	 124.73	 369.72	 -120.26	 1.0	 100.0	 1	 800.0	 266.67; % COW
	5874	 55.385	 15.97	 46.53	 -14.59	 1.0	 100.0	 1	 100.0	 10.77; % NG
	5881	 40.0	 11.795	 36.72	 -13.13	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5882	 60.0	 15.575	 52.96	 -21.81	 1.0	 100.0	 1	 120.0	 0.0; % COW
	5883	 800.0	 158.73	 526.77	 -209.31	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	5885	 60.0	 15.23	 52.11	 -21.65	 1.0	 100.0	 1	 120.0	 0.0; % NG
	5894	 100.0	 24.955	 86.3	 -36.39	 1.0	 100.0	 1	 200.0	 0.0; % NG
	5896	 40.0	 12.375	 37.32	 -12.57	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5922	 43.18	 7.05	 19.49	 -5.39	 1.0	 100.0	 1	 100.0	 -13.64; % COW
	5930	 82.46	 18.455	 68.33	 -31.42	 1.0	 100.0	 1	 164.92	 0.0; % NG
	5940	 0.065	 4.74	 17.21	 -7.73	 1.0	 100.0	 1	 100.0	 -99.87; % NG
	5941	 40.0	 12.625	 37.53	 -12.28	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	5955	 28.475	 12.895	 37.78	 -11.99	 1.0	 100.0	 1	 100.0	 -43.05; % NG
	5964	 40.0	 12.21	 37.05	 -12.63	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	5970	 180.0	 62.065	 172.47	 -48.34	 1.0	 100.0	 1	 360.0	 0.0; % NG
	5971	 1333.335	 321.45	 934.54	 -291.64	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	5973	 80.0	 25.41	 75.26	 -24.44	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5975	 40.0	 11.09	 35.9	 -13.72	 1.0	 100.0	 1	 80.0	 0.0; % COW
	5977	 266.665	 57.32	 179.91	 -65.27	 1.0	 100.0	 1	 400.0	 133.33; % COW
	5980	 150.0	 37.75	 129.72	 -54.22	 1.0	 100.0	 1	 300.0	 0.0; % NG
	5983	 -18.335	 12.34	 37.27	 -12.59	 1.0	 100.0	 1	 100.0	 -136.67; % NG
	5985	 533.335	 117.04	 362.21	 -128.13	 1.0	 100.0	 1	 800.0	 266.67; % COW
	5986	 1333.335	 271.38	 884.39	 -341.63	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	5988	 533.335	 128.26	 373.58	 -117.06	 1.0	 100.0	 1	 800.0	 266.67; % COW
	5991	 800.0	 150.15	 517.55	 -217.25	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	5994	 -8.2	 -0.285	 60.51	 -61.08	 1.0	 100.0	 1	 100.0	 -116.4; % NG
	5998	 4.6	 -4.29	 27.48	 -36.06	 1.0	 100.0	 1	 100.0	 -90.8; % NG
	6000	 600.0	 136.225	 411.66	 -139.21	 1.0	 100.0	 1	 900.0	 300.0; % COW
	6001	 10.05	 -0.295	 7.11	 -7.7	 1.0	 100.0	 1	 20.1	 0.0; % PEL
	6033	 60.0	 19.465	 56.86	 -17.93	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6036	 600.0	 114.62	 390.4	 -161.16	 1.0	 100.0	 1	 900.0	 300.0; % COW
	6046	 533.335	 106.355	 351.66	 -138.95	 1.0	 100.0	 1	 800.0	 266.67; % NUC
	6086	 46.305	 -7.99	 42.01	 -57.99	 1.0	 100.0	 1	 92.61	 0.0; % NG
	6088	 -135.465	 9.765	 34.67	 -15.14	 1.0	 100.0	 1	 100.0	 -370.93; % NG
	6090	 40.0	 11.675	 36.58	 -13.23	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6092	 600.0	 119.855	 395.59	 -155.88	 1.0	 100.0	 1	 900.0	 300.0; % NUC
	6100	 -43.005	 63.04	 185.63	 -59.55	 1.0	 100.0	 1	 100.0	 -186.01; % NG
	6103	 200.0	 49.51	 141.39	 -42.37	 1.0	 100.0	 1	 300.0	 100.0; % NG
	6105	 60.0	 18.33	 55.73	 -19.07	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6120	 40.0	 11.83	 36.73	 -13.07	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6124	 526.665	 65.33	 254.71	 -124.05	 1.0	 100.0	 1	 790.0	 263.33; % COW
	6129	 266.665	 50.845	 173.49	 -71.8	 1.0	 100.0	 1	 400.0	 133.33; % NG
	6130	 40.0	 12.78	 37.68	 -12.12	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6131	 600.0	 139.465	 415.26	 -136.33	 1.0	 100.0	 1	 900.0	 300.0; % COW
	6138	 -31.265	 4.46	 16.91	 -7.99	 1.0	 100.0	 1	 100.0	 -162.53; % COW
	6144	 5.02	 1.09	 4.21	 -2.03	 1.0	 100.0	 1	 10.04	 0.0; % PEL
	6145	 120.0	 31.08	 104.76	 -42.6	 1.0	 100.0	 1	 240.0	 0.0; % NG
	6153	 401.01	 -6.085	 249.65	 -261.82	 1.0	 100.0	 1	 769.94	 32.08; % COW
	6168	 26.88	 2.465	 19.86	 -14.93	 1.0	 100.0	 1	 53.76	 0.0; % NG
	6169	 -7.2	 13.605	 38.48	 -11.27	 1.0	 100.0	 1	 100.0	 -114.4; % NG
	6175	 213.045	 55.555	 258.8	 -147.69	 1.0	 100.0	 1	 426.09	 0.0; % NG
	6179	 40.0	 10.51	 35.43	 -14.41	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6181	 384.0	 30.475	 194.93	 -133.98	 1.0	 100.0	 1	 576.0	 192.0; % COW
	6182	 60.0	 20.615	 57.93	 -16.7	 1.0	 100.0	 1	 120.0	 0.0; % COW
	6201	 266.665	 56.36	 178.97	 -66.25	 1.0	 100.0	 1	 400.0	 133.33; % NG
	6204	 666.665	 141.285	 447.13	 -164.56	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	6207	 400.0	 90.555	 274.12	 -93.01	 1.0	 100.0	 1	 600.0	 200.0; % NUC
	6233	 800.0	 177.855	 545.68	 -189.97	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	6237	 -5.555	 -0.615	 2.42	 -3.65	 1.0	 100.0	 1	 100.0	 -111.11; % COW
	6239	 2.66	 0.585	 2.24	 -1.07	 1.0	 100.0	 1	 5.32	 0.0; % PEL
	6242	 60.0	 18.22	 55.52	 -19.08	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6249	 266.665	 54.54	 177.29	 -68.21	 1.0	 100.0	 1	 400.0	 133.33; % COW
	6270	 236.46	 38.525	 265.02	 -187.97	 1.0	 100.0	 1	 472.92	 0.0; % NG
	6279	 28.075	 13.2	 38.09	 -11.69	 1.0	 100.0	 1	 100.0	 -43.85; % COW
	6280	 60.0	 13.88	 51.25	 -23.49	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6284	 50.0	 12.055	 42.68	 -18.57	 1.0	 100.0	 1	 100.0	 0.0; % NG
	6291	 60.0	 20.76	 58.12	 -16.6	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6329	 200.0	 42.465	 134.08	 -49.15	 1.0	 100.0	 1	 300.0	 100.0; % NG
	6331	 40.0	 12.855	 37.76	 -12.05	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6332	 100.0	 34.305	 96.56	 -27.95	 1.0	 100.0	 1	 200.0	 0.0; % COW
	6334	 60.0	 19.44	 56.24	 -17.36	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6338	 29.99	 2.53	 21.92	 -16.86	 1.0	 100.0	 1	 59.98	 0.0; % NG
	6351	 40.0	 13.365	 38.29	 -11.56	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6358	 40.0	 12.785	 37.69	 -12.12	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6366	 200.0	 47.225	 139.07	 -44.62	 1.0	 100.0	 1	 300.0	 100.0; % NG
	6368	 -46.865	 13.825	 51.11	 -23.46	 1.0	 100.0	 1	 100.0	 -193.73; % COW
	6370	 358.665	 50.695	 279.2	 -177.81	 1.0	 100.0	 1	 538.0	 179.33; % NG
	6373	 -84.0	 22.72	 72.5	 -27.06	 1.0	 100.0	 1	 100.0	 -268.0; % NG
	6374	 200.0	 54.275	 176.7	 -68.15	 1.0	 100.0	 1	 400.0	 0.0; % COW
	6376	 31.465	 48.96	 148.65	 -50.73	 1.0	 100.0	 1	 100.0	 -37.07; % NG
	6403	 27.72	 -6.87	 32.13	 -45.87	 1.0	 100.0	 1	 55.44	 0.0; % PEL
	6410	 12.0	 -3.135	 23.72	 -29.99	 1.0	 100.0	 1	 100.0	 -76.0; % NG
	6413	 800.0	 169.2	 537.03	 -198.63	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	6415	 450.0	 22.4	 83.58	 -38.78	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	6419	 800.0	 139.69	 507.58	 -228.2	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	6429	 100.0	 26.57	 88.83	 -35.69	 1.0	 100.0	 1	 200.0	 0.0; % NG
	6432	 200.0	 58.365	 180.93	 -64.2	 1.0	 100.0	 1	 400.0	 0.0; % COW
	6434	 800.0	 183.3	 551.33	 -184.73	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	6436	 -7.67	 0.61	 2.26	 -1.04	 1.0	 100.0	 1	 100.0	 -115.34; % COW
	6448	 20.0	 5.865	 18.36	 -6.63	 1.0	 100.0	 1	 40.0	 0.0; % NG
	6458	 50.0	 12.425	 43.09	 -18.24	 1.0	 100.0	 1	 100.0	 0.0; % NG
	6459	 90.0	 30.96	 86.17	 -24.25	 1.0	 100.0	 1	 180.0	 0.0; % COW
	6474	 666.665	 132.285	 438.72	 -174.15	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	6483	 60.0	 17.915	 55.34	 -19.51	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6484	 800.0	 140.36	 508.02	 -227.3	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	6492	 266.665	 57.51	 180.02	 -65.0	 1.0	 100.0	 1	 400.0	 133.33; % NG
	6497	 533.335	 103.49	 348.83	 -141.85	 1.0	 100.0	 1	 800.0	 266.67; % PEL
	6498	 98.595	 -19.35	 52.65	 -91.35	 1.0	 100.0	 1	 197.19	 0.0; % NG
	6502	 40.0	 12.685	 37.56	 -12.19	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6516	 140.0	 39.45	 126.73	 -47.83	 1.0	 100.0	 1	 280.0	 0.0; % NG
	6518	 938.665	 -98.81	 388.92	 -586.54	 1.0	 100.0	 1	 1408.0	 469.33; % COW
	6525	 8.4	 -1.88	 6.12	 -9.88	 1.0	 100.0	 1	 16.8	 0.0; % PEL
	6552	 -86.135	 12.71	 37.58	 -12.16	 1.0	 100.0	 1	 100.0	 -272.27; % NG
	6587	 29.455	 -5.535	 27.23	 -38.3	 1.0	 100.0	 1	 58.91	 0.0; % PEL
	6591	 266.665	 65.92	 188.45	 -56.61	 1.0	 100.0	 1	 400.0	 133.33; % NG
	6594	 600.0	 138.63	 414.32	 -137.06	 1.0	 100.0	 1	 900.0	 300.0; % COW
	6608	 35.285	 17.0	 47.56	 -13.56	 1.0	 100.0	 1	 100.0	 -29.43; % NG
	6621	 150.0	 33.74	 125.6	 -58.12	 1.0	 100.0	 1	 300.0	 0.0; % COW
	6626	 20.0	 5.83	 18.32	 -6.66	 1.0	 100.0	 1	 40.0	 0.0; % NG
	6627	 66.665	 11.455	 42.14	 -19.23	 1.0	 100.0	 1	 100.0	 33.33; % NG
	6632	 2000.0	 459.55	 1378.19	 -459.09	 1.0	 100.0	 1	 3000.0	 1000.0; % PEL
	6641	 40.0	 13.67	 38.53	 -11.19	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6654	 533.335	 91.89	 337.04	 -153.26	 1.0	 100.0	 1	 800.0	 266.67; % NUC
	6656	 150.0	 39.82	 131.88	 -52.24	 1.0	 100.0	 1	 300.0	 0.0; % NG
	6661	 50.0	 13.835	 44.49	 -16.82	 1.0	 100.0	 1	 100.0	 0.0; % COW
	6680	 30.0	 9.745	 28.15	 -8.66	 1.0	 100.0	 1	 60.0	 0.0; % PEL
	6681	 54.19	 0.36	 36.22	 -35.5	 1.0	 100.0	 1	 108.38	 0.0; % NG
	6703	 800.0	 166.055	 533.98	 -201.87	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	6715	 20.0	 5.565	 18.03	 -6.9	 1.0	 100.0	 1	 40.0	 0.0; % NG
	6734	 360.0	 89.715	 311.52	 -132.09	 1.0	 100.0	 1	 720.0	 0.0; % COW
	6736	 600.0	 130.46	 405.88	 -144.96	 1.0	 100.0	 1	 900.0	 300.0; % COW
	6739	 40.0	 11.98	 36.93	 -12.97	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6753	 40.0	 10.925	 35.87	 -14.02	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6756	 30.0	 9.835	 28.24	 -8.57	 1.0	 100.0	 1	 60.0	 0.0; % PEL
	6764	 4.995	 1.105	 4.21	 -2.0	 1.0	 100.0	 1	 9.99	 0.0; % NG
	6778	 266.665	 60.69	 183.4	 -62.02	 1.0	 100.0	 1	 400.0	 133.33; % NG
	6780	 17.025	 1.31	 10.68	 -8.06	 1.0	 100.0	 1	 29.19	 4.86; % PEL
	6793	 30.0	 9.8	 28.21	 -8.61	 1.0	 100.0	 1	 60.0	 0.0; % NG
	6798	 666.665	 123.065	 429.61	 -183.48	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	6807	 80.0	 27.34	 77.14	 -22.46	 1.0	 100.0	 1	 160.0	 0.0; % NG
	6811	 100.0	 31.96	 93.15	 -29.23	 1.0	 100.0	 1	 200.0	 0.0; % NG
	6816	 80.0	 27.545	 77.35	 -22.26	 1.0	 100.0	 1	 160.0	 0.0; % NG
	6820	 16.265	 1.465	 11.99	 -9.06	 1.0	 100.0	 1	 32.53	 0.0; % NG
	6822	 150.0	 39.725	 131.81	 -52.36	 1.0	 100.0	 1	 300.0	 0.0; % NG
	6831	 11.665	 10.685	 35.62	 -14.25	 1.0	 100.0	 1	 100.0	 -76.67; % NG
	6838	 400.0	 71.46	 255.23	 -112.31	 1.0	 100.0	 1	 600.0	 200.0; % NUC
	6843	 60.0	 17.36	 54.68	 -19.96	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6845	 60.0	 15.885	 53.24	 -21.47	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6847	 200.0	 58.835	 181.63	 -63.96	 1.0	 100.0	 1	 400.0	 0.0; % NG
	6850	 15.75	 -0.72	 1.74	 -3.18	 1.0	 100.0	 1	 31.5	 0.0; % PEL
	6852	 -179.935	 6.11	 18.56	 -6.34	 1.0	 100.0	 1	 100.0	 -459.87; % NG
	6857	 2666.665	 639.94	 1865.83	 -585.95	 1.0	 100.0	 1	 4000.0	 1333.33; % COW
	6861	 -0.935	 13.445	 38.34	 -11.45	 1.0	 100.0	 1	 100.0	 -101.87; % NG
	6864	 40.0	 11.165	 36.08	 -13.75	 1.0	 100.0	 1	 80.0	 0.0; % COW
	6868	 25.46	 -6.66	 23.34	 -36.66	 1.0	 100.0	 1	 50.92	 0.0; % NG
	6874	 266.665	 49.785	 172.42	 -72.85	 1.0	 100.0	 1	 400.0	 133.33; % NG
	6877	 50.255	 0.31	 33.57	 -32.95	 1.0	 100.0	 1	 100.51	 0.0; % NG
	6888	 194.335	 64.72	 189.31	 -59.87	 1.0	 100.0	 1	 300.0	 88.67; % NG
	6893	 242.665	 -15.99	 122.24	 -154.22	 1.0	 100.0	 1	 364.0	 121.33; % COW
	6900	 333.335	 65.665	 218.81	 -87.48	 1.0	 100.0	 1	 500.0	 166.67; % COW
	6907	 380.0	 90.29	 327.04	 -146.46	 1.0	 100.0	 1	 760.0	 0.0; % COW
	6910	 147.915	 8.855	 104.8	 -87.09	 1.0	 100.0	 1	 295.83	 0.0; % COW
	6914	 100.0	 25.965	 87.28	 -35.35	 1.0	 100.0	 1	 200.0	 0.0; % NG
	6920	 43.535	 -5.23	 14.77	 -25.23	 1.0	 100.0	 1	 100.0	 -12.93; % NG
	6924	 88.56	 15.31	 56.01	 -25.39	 1.0	 100.0	 1	 132.84	 44.28; % NG
	6930	 116.22	 8.935	 72.88	 -55.01	 1.0	 100.0	 1	 199.23	 33.21; % NG
	6934	 21.545	 9.715	 28.12	 -8.69	 1.0	 100.0	 1	 100.0	 -56.91; % NG
	6936	 600.0	 113.03	 388.7	 -162.64	 1.0	 100.0	 1	 900.0	 300.0; % COW
	6937	 250.0	 65.595	 188.15	 -56.96	 1.0	 100.0	 1	 400.0	 100.0; % NG
	6947	 140.0	 38.9	 126.09	 -48.29	 1.0	 100.0	 1	 280.0	 0.0; % NG
	6948	 200.0	 56.58	 179.39	 -66.23	 1.0	 100.0	 1	 400.0	 0.0; % COW
	6950	 15.75	 -1.15	 11.7	 -14.0	 1.0	 100.0	 1	 31.5	 0.0; % NG
	6967	 266.665	 61.9	 184.53	 -60.73	 1.0	 100.0	 1	 400.0	 133.33; % NG
	6969	 40.0	 13.63	 38.53	 -11.27	 1.0	 100.0	 1	 80.0	 0.0; % COW
	6982	 41.6	 18.89	 56.22	 -18.44	 1.0	 100.0	 1	 100.0	 -16.8; % NG
	6993	 100.0	 28.32	 89.69	 -33.05	 1.0	 100.0	 1	 200.0	 0.0; % NG
	6999	 1333.335	 249.04	 862.05	 -363.97	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7008	 480.0	 107.345	 401.3	 -186.61	 1.0	 100.0	 1	 960.0	 0.0; % COW
	7025	 -83.065	 5.125	 17.59	 -7.34	 1.0	 100.0	 1	 100.0	 -266.13; % NG
	7027	 200.0	 50.905	 175.51	 -73.7	 1.0	 100.0	 1	 400.0	 0.0; % NG
	7028	 333.335	 65.82	 219.32	 -87.68	 1.0	 100.0	 1	 500.0	 166.67; % NG
	7029	 800.0	 140.5	 507.73	 -226.73	 1.0	 100.0	 1	 1200.0	 400.0; % NG
	7032	 107.1	 30.085	 131.74	 -71.57	 1.0	 100.0	 1	 214.2	 0.0; % NG
	7033	 266.665	 67.795	 190.44	 -54.85	 1.0	 100.0	 1	 400.0	 133.33; % NG
	7036	 40.0	 11.22	 36.16	 -13.72	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7049	 60.0	 20.81	 58.18	 -16.56	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7056	 400.0	 83.19	 267.36	 -100.98	 1.0	 100.0	 1	 600.0	 200.0; % COW
	7058	 40.0	 12.695	 37.59	 -12.2	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7063	 333.335	 67.385	 220.66	 -85.89	 1.0	 100.0	 1	 500.0	 166.67; % COW
	7065	 200.0	 45.095	 136.87	 -46.68	 1.0	 100.0	 1	 300.0	 100.0; % NG
	7075	 17.085	 0.76	 13.41	 -11.89	 1.0	 100.0	 1	 100.0	 -65.83; % NG
	7085	 150.0	 34.905	 126.93	 -57.12	 1.0	 100.0	 1	 300.0	 0.0; % NG
	7089	 -69.2	 13.455	 38.35	 -11.44	 1.0	 100.0	 1	 100.0	 -238.4; % NG
	7093	 100.0	 31.86	 93.14	 -29.42	 1.0	 100.0	 1	 200.0	 0.0; % NG
	7104	 200.0	 41.365	 133.02	 -50.29	 1.0	 100.0	 1	 300.0	 100.0; % COW
	7107	 53.165	 54.945	 177.44	 -67.55	 1.0	 100.0	 1	 100.0	 6.33; % COW
	7113	 83.895	 3.665	 71.21	 -63.88	 1.0	 100.0	 1	 167.79	 0.0; % NG
	7114	 -88.065	 17.015	 54.38	 -20.35	 1.0	 100.0	 1	 100.0	 -276.13; % NG
	7115	 136.14	 5.86	 95.06	 -83.34	 1.0	 100.0	 1	 272.28	 0.0; % NG
	7128	 526.665	 62.39	 251.35	 -126.57	 1.0	 100.0	 1	 790.0	 263.33; % NUC
	7134	 47.25	 -6.58	 37.42	 -50.58	 1.0	 100.0	 1	 94.5	 0.0; % NG
	7137	 800.0	 148.43	 516.03	 -219.17	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	7153	 20.0	 5.15	 17.61	 -7.31	 1.0	 100.0	 1	 40.0	 0.0; % NG
	7159	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	7166	 60.0	 17.73	 55.11	 -19.65	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7169	 40.0	 12.145	 37.06	 -12.77	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7183	 1333.335	 314.42	 926.47	 -297.63	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7200	 100.0	 23.785	 86.18	 -38.61	 1.0	 100.0	 1	 200.0	 0.0; % NG
	7207	 100.0	 31.86	 93.14	 -29.42	 1.0	 100.0	 1	 200.0	 0.0; % NG
	7209	 3.675	 0.83	 3.12	 -1.46	 1.0	 100.0	 1	 7.35	 0.0; % PEL
	7212	 101.35	 4.1	 70.22	 -62.02	 1.0	 100.0	 1	 202.7	 0.0; % NG
	7214	 266.665	 52.07	 174.75	 -70.61	 1.0	 100.0	 1	 400.0	 133.33; % COW
	7223	 25.81	 -6.41	 41.59	 -54.41	 1.0	 100.0	 1	 51.62	 0.0; % NG
	7227	 486.665	 22.785	 279.66	 -234.09	 1.0	 100.0	 1	 730.0	 243.33; % COW
	7228	 533.335	 125.015	 370.35	 -120.32	 1.0	 100.0	 1	 800.0	 266.67; % COW
	7238	 38.8	 5.465	 92.99	 -82.06	 1.0	 100.0	 1	 100.0	 -22.4; % NG
	7250	 20.0	 4.78	 17.26	 -7.7	 1.0	 100.0	 1	 40.0	 0.0; % NG
	7257	 53.645	 0.27	 35.77	 -35.23	 1.0	 100.0	 1	 107.29	 0.0; % NG
	7260	 21.8	 3.725	 13.73	 -6.28	 1.0	 100.0	 1	 32.7	 10.9; % PEL
	7267	 23.535	 27.5	 89.84	 -34.84	 1.0	 100.0	 1	 100.0	 -52.93; % COW
	7270	 600.0	 119.37	 394.86	 -156.12	 1.0	 100.0	 1	 900.0	 300.0; % COW
	7278	 266.665	 51.48	 174.01	 -71.05	 1.0	 100.0	 1	 400.0	 133.33; % NG
	7279	 -404.465	 4.07	 14.78	 -6.64	 1.0	 100.0	 1	 100.0	 -908.93; % NG
	7281	 336.86	 -15.21	 318.74	 -349.16	 1.0	 100.0	 1	 673.72	 0.0; % COW
	7282	 2666.665	 637.065	 1862.29	 -588.16	 1.0	 100.0	 1	 4000.0	 1333.33; % COW
	7293	 6.865	 12.795	 37.71	 -12.12	 1.0	 100.0	 1	 100.0	 -86.27; % NG
	7303	 600.0	 108.65	 384.34	 -167.04	 1.0	 100.0	 1	 900.0	 300.0; % COW
	7327	 80.0	 26.245	 76.11	 -23.62	 1.0	 100.0	 1	 160.0	 0.0; % NG
	7328	 40.0	 12.53	 37.45	 -12.39	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7329	 40.0	 11.355	 36.26	 -13.55	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7330	 267.34	 44.65	 167.11	 -77.81	 1.0	 100.0	 1	 401.01	 133.67; % NG
	7331	 20.0	 5.655	 18.12	 -6.81	 1.0	 100.0	 1	 40.0	 0.0; % NG
	7337	 16.065	 9.065	 32.44	 -14.31	 1.0	 100.0	 1	 32.13	 0.0; % NG
	7350	 87.02	 -23.69	 75.31	 -122.69	 1.0	 100.0	 1	 174.04	 0.0; % NG
	7359	 60.0	 14.105	 51.0	 -22.79	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7363	 -39.865	 -2.515	 33.96	 -38.99	 1.0	 100.0	 1	 100.0	 -179.73; % NG
	7370	 35.135	 0.615	 3.56	 -2.33	 1.0	 100.0	 1	 100.0	 -29.73; % NG
	7376	 60.0	 18.78	 56.18	 -18.62	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7383	 67.6	 11.5	 42.54	 -19.54	 1.0	 100.0	 1	 101.4	 33.8; % NG
	7386	 65.1	 -13.39	 42.61	 -69.39	 1.0	 100.0	 1	 130.2	 0.0; % NG
	7393	 44.17	 2.105	 34.08	 -29.87	 1.0	 100.0	 1	 100.0	 -11.66; % NG
	7401	 150.0	 41.93	 134.01	 -50.15	 1.0	 100.0	 1	 300.0	 0.0; % NG
	7408	 1202.665	 30.49	 408.24	 -347.26	 1.0	 100.0	 1	 1804.0	 601.33; % COW
	7427	 1066.665	 263.095	 752.61	 -226.42	 1.0	 100.0	 1	 1600.0	 533.33; % COW
	7429	 120.0	 8.815	 77.0	 -59.37	 1.0	 100.0	 1	 180.0	 60.0; % NG
	7431	 600.0	 124.25	 399.88	 -151.38	 1.0	 100.0	 1	 900.0	 300.0; % NG
	7432	 40.0	 12.755	 37.65	 -12.14	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7446	 20.48	 0.865	 14.28	 -12.55	 1.0	 100.0	 1	 40.96	 0.0; % PEL
	7465	 44.965	 9.29	 27.69	 -9.11	 1.0	 100.0	 1	 100.0	 -10.07; % NG
	7466	 -85.02	 -0.605	 75.85	 -77.06	 1.0	 100.0	 1	 100.0	 -270.04; % NG
	7474	 60.0	 18.93	 56.27	 -18.41	 1.0	 100.0	 1	 120.0	 0.0; % COW
	7490	 48.535	 21.79	 83.0	 -39.42	 1.0	 100.0	 1	 100.0	 -2.93; % NG
	7495	 125.265	 77.23	 214.23	 -59.77	 1.0	 100.0	 1	 200.0	 50.53; % NG
	7498	 -22.6	 -5.205	 17.85	 -28.26	 1.0	 100.0	 1	 100.0	 -145.2; % NG
	7499	 65.935	 29.01	 90.31	 -32.29	 1.0	 100.0	 1	 100.0	 31.87; % NG
	7504	 2.65	 0.595	 2.24	 -1.05	 1.0	 100.0	 1	 5.3	 0.0; % NG
	7508	 600.0	 126.49	 402.15	 -149.17	 1.0	 100.0	 1	 900.0	 300.0; % COW
	7520	 533.335	 104.815	 350.36	 -140.73	 1.0	 100.0	 1	 800.0	 266.67; % NUC
	7522	 533.335	 125.72	 371.11	 -119.67	 1.0	 100.0	 1	 800.0	 266.67; % COW
	7558	 -0.335	 -0.57	 6.35	 -7.49	 1.0	 100.0	 1	 100.0	 -100.67; % COW
	7568	 60.0	 16.07	 53.4	 -21.26	 1.0	 100.0	 1	 120.0	 0.0; % COW
	7607	 140.0	 44.635	 131.89	 -42.62	 1.0	 100.0	 1	 280.0	 0.0; % NG
	7616	 400.0	 93.555	 276.99	 -89.88	 1.0	 100.0	 1	 600.0	 200.0; % NG
	7619	 60.0	 14.2	 51.09	 -22.69	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7627	 266.665	 58.275	 180.61	 -64.06	 1.0	 100.0	 1	 400.0	 133.33; % NG
	7628	 200.0	 41.87	 133.78	 -50.04	 1.0	 100.0	 1	 300.0	 100.0; % COW
	7630	 65.91	 2.675	 45.85	 -40.5	 1.0	 100.0	 1	 131.82	 0.0; % NG
	7639	 1.535	 9.38	 27.79	 -9.03	 1.0	 100.0	 1	 100.0	 -96.93; % NG
	7641	 540.0	 107.93	 378.21	 -162.35	 1.0	 100.0	 1	 880.0	 200.0; % COW
	7645	 -13.865	 -0.575	 5.32	 -6.47	 1.0	 100.0	 1	 100.0	 -127.73; % NG
	7656	 173.52	 6.645	 108.47	 -95.18	 1.0	 100.0	 1	 312.34	 34.7; % NG
	7657	 266.665	 49.71	 172.41	 -72.99	 1.0	 100.0	 1	 400.0	 133.33; % NG
	7659	 23.665	 24.96	 74.7	 -24.78	 1.0	 100.0	 1	 100.0	 -52.67; % NG
	7661	 90.0	 21.48	 76.75	 -33.79	 1.0	 100.0	 1	 180.0	 0.0; % NG
	7670	 29.42	 9.69	 28.05	 -8.67	 1.0	 100.0	 1	 100.0	 -41.16; % NG
	7671	 266.665	 60.31	 182.95	 -62.33	 1.0	 100.0	 1	 400.0	 133.33; % NG
	7676	 40.0	 13.11	 38.03	 -11.81	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7681	 200.0	 51.435	 176.18	 -73.31	 1.0	 100.0	 1	 400.0	 0.0; % NG
	7683	 21.25	 -3.96	 24.04	 -31.96	 1.0	 100.0	 1	 42.5	 0.0; % NG
	7687	 23.2	 13.03	 38.0	 -11.94	 1.0	 100.0	 1	 100.0	 -53.6; % NG
	7697	 140.0	 39.45	 126.73	 -47.83	 1.0	 100.0	 1	 280.0	 0.0; % COW
	7707	 -12.6	 13.78	 38.67	 -11.11	 1.0	 100.0	 1	 100.0	 -125.2; % NG
	7718	 266.665	 51.345	 173.91	 -71.22	 1.0	 100.0	 1	 400.0	 133.33; % NG
	7728	 314.665	 19.975	 193.14	 -153.19	 1.0	 100.0	 1	 472.0	 157.33; % NG
	7737	 40.0	 11.95	 36.9	 -13.0	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	7742	 37.57	 6.68	 19.1	 -5.74	 1.0	 100.0	 1	 100.0	 -24.86; % NG
	7743	 120.0	 24.14	 97.38	 -49.1	 1.0	 100.0	 1	 240.0	 0.0; % NG
	7755	 6.45	 0.605	 4.78	 -3.57	 1.0	 100.0	 1	 12.9	 0.0; % COW
	7758	 220.0	 58.235	 195.3	 -78.83	 1.0	 100.0	 1	 440.0	 0.0; % NG
	7759	 1000.0	 209.285	 700.16	 -281.59	 1.0	 100.0	 1	 1600.0	 400.0; % COW
	7761	 60.0	 15.39	 52.75	 -21.97	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7776	 1333.335	 321.605	 934.73	 -291.52	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7779	 400.0	 98.05	 281.92	 -85.82	 1.0	 100.0	 1	 600.0	 200.0; % NUC
	7785	 120.0	 31.11	 105.85	 -43.63	 1.0	 100.0	 1	 240.0	 0.0; % NG
	7798	 40.0	 12.895	 37.78	 -11.99	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7800	 60.0	 17.715	 55.02	 -19.59	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7808	 1333.335	 314.335	 926.35	 -297.68	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7819	 25.77	 2.23	 18.9	 -14.44	 1.0	 100.0	 1	 51.54	 0.0; % NG
	7833	 120.0	 31.98	 106.77	 -42.81	 1.0	 100.0	 1	 240.0	 0.0; % COW
	7835	 90.0	 26.12	 81.41	 -29.17	 1.0	 100.0	 1	 180.0	 0.0; % NG
	7836	 7.61	 1.66	 6.39	 -3.07	 1.0	 100.0	 1	 15.22	 0.0; % NG
	7842	 100.0	 27.76	 90.08	 -34.56	 1.0	 100.0	 1	 200.0	 0.0; % NG
	7843	 200.0	 47.34	 170.14	 -75.46	 1.0	 100.0	 1	 400.0	 0.0; % NG
	7854	 51.6	 53.17	 175.29	 -68.95	 1.0	 100.0	 1	 100.0	 3.2; % NG
	7860	 533.335	 135.225	 380.36	 -109.91	 1.0	 100.0	 1	 800.0	 266.67; % COW
	7880	 333.335	 63.98	 217.18	 -89.22	 1.0	 100.0	 1	 500.0	 166.67; % COW
	7890	 -16.0	 6.295	 18.76	 -6.17	 1.0	 100.0	 1	 100.0	 -132.0; % NG
	7894	 83.895	 7.805	 73.03	 -57.42	 1.0	 100.0	 1	 167.79	 0.0; % NG
	7896	 160.0	 49.605	 149.3	 -50.09	 1.0	 100.0	 1	 320.0	 0.0; % NG
	7913	 1333.335	 307.415	 920.41	 -305.58	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7926	 -54.8	 -6.265	 35.82	 -48.35	 1.0	 100.0	 1	 100.0	 -209.6; % NG
	7929	 1066.665	 207.95	 698.07	 -282.17	 1.0	 100.0	 1	 1600.0	 533.33; % COW
	7934	 150.0	 44.24	 136.03	 -47.55	 1.0	 100.0	 1	 300.0	 0.0; % NG
	7940	 400.0	 90.555	 274.12	 -93.01	 1.0	 100.0	 1	 600.0	 200.0; % COW
	7949	 39.69	 -5.81	 43.13	 -54.75	 1.0	 100.0	 1	 79.38	 0.0; % COW
	7953	 -67.135	 99.305	 282.78	 -84.17	 1.0	 100.0	 1	 100.0	 -234.27; % NG
	7960	 400.0	 90.49	 274.2	 -93.22	 1.0	 100.0	 1	 600.0	 200.0; % COW
	7964	 75.8	 10.535	 74.88	 -53.81	 1.0	 100.0	 1	 151.6	 0.0; % NG
	7979	 2133.335	 508.205	 1487.06	 -470.65	 1.0	 100.0	 1	 3200.0	 1066.67; % NUC
	7983	 162.435	 -6.7	 186.32	 -199.72	 1.0	 100.0	 1	 324.87	 0.0; % COW
	7995	 31.5	 -6.995	 23.0	 -36.99	 1.0	 100.0	 1	 63.0	 0.0; % NG
	7998	 600.0	 115.31	 391.57	 -160.95	 1.0	 100.0	 1	 900.0	 300.0; % NG
	8036	 46.905	 9.785	 28.2	 -8.63	 1.0	 100.0	 1	 100.0	 -6.19; % NG
	8043	 32.0	 25.855	 75.67	 -23.96	 1.0	 100.0	 1	 100.0	 -36.0; % NG
	8044	 400.0	 97.96	 281.63	 -85.71	 1.0	 100.0	 1	 600.0	 200.0; % NUC
	8045	 5.49	 1.225	 4.64	 -2.19	 1.0	 100.0	 1	 10.98	 0.0; % COW
	8065	 400.0	 93.095	 276.94	 -90.75	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8066	 -75.935	 0.6	 10.73	 -9.53	 1.0	 100.0	 1	 100.0	 -251.87; % NG
	8085	 49.61	 -9.76	 30.24	 -49.76	 1.0	 100.0	 1	 99.22	 0.0; % NG
	8087	 210.0	 48.475	 177.22	 -80.27	 1.0	 100.0	 1	 420.0	 0.0; % NG
	8096	 40.0	 12.76	 37.66	 -12.14	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8101	 230.655	 -1.11	 151.6	 -153.82	 1.0	 100.0	 1	 461.31	 0.0; % COW
	8105	 11.81	 1.165	 4.1	 -1.77	 1.0	 100.0	 1	 23.62	 0.0; % NG
	8109	 520.8	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 1041.6	 0.0; % COW
	8116	 163.325	 0.155	 155.0	 -154.69	 1.0	 100.0	 1	 326.65	 0.0; % NG
	8117	 800.0	 157.36	 525.09	 -210.37	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	8119	 40.0	 9.625	 34.53	 -15.28	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8123	 40.0	 11.935	 36.83	 -12.96	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8134	 40.0	 11.98	 36.87	 -12.91	 1.0	 100.0	 1	 80.0	 0.0; % COW
	8136	 9.6	 -0.14	 4.32	 -4.6	 1.0	 100.0	 1	 100.0	 -80.8; % COW
	8156	 133.335	 26.02	 87.43	 -35.39	 1.0	 100.0	 1	 200.0	 66.67; % NG
	8157	 266.665	 56.62	 179.34	 -66.1	 1.0	 100.0	 1	 400.0	 133.33; % NG
	8158	 100.0	 29.33	 91.67	 -33.01	 1.0	 100.0	 1	 200.0	 0.0; % COW
	8159	 473.245	 77.15	 291.71	 -137.41	 1.0	 100.0	 1	 709.87	 236.62; % COW
	8185	 147.175	 8.725	 104.19	 -86.74	 1.0	 100.0	 1	 294.35	 0.0; % COW
	8187	 333.335	 65.595	 219.1	 -87.91	 1.0	 100.0	 1	 500.0	 166.67; % NG
	8203	 -5.465	 4.475	 105.01	 -96.06	 1.0	 100.0	 1	 100.0	 -110.93; % COW
	8207	 103.635	 1.86	 70.17	 -66.45	 1.0	 100.0	 1	 207.27	 0.0; % NG
	8210	 1066.665	 219.065	 709.44	 -271.31	 1.0	 100.0	 1	 1600.0	 533.33; % COW
	8212	 40.0	 12.61	 37.48	 -12.26	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8215	 60.0	 15.38	 52.21	 -21.45	 1.0	 100.0	 1	 120.0	 0.0; % NG
	8218	 43.05	 1.18	 32.04	 -29.68	 1.0	 100.0	 1	 86.1	 0.0; % PEL
	8222	 40.0	 10.855	 35.76	 -14.05	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8223	 400.0	 92.965	 276.81	 -90.88	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8225	 20.0	 7.035	 19.49	 -5.42	 1.0	 100.0	 1	 40.0	 0.0; % NG
	8227	 372.0	 -56.55	 192.45	 -305.55	 1.0	 100.0	 1	 558.0	 186.0; % COW
	8240	 39.575	 0.375	 36.34	 -35.59	 1.0	 100.0	 1	 100.0	 -20.85; % NG
	8242	 210.0	 48.94	 177.81	 -79.93	 1.0	 100.0	 1	 420.0	 0.0; % COW
	8247	 180.0	 53.725	 164.3	 -56.85	 1.0	 100.0	 1	 360.0	 0.0; % NG
	8252	 266.665	 55.385	 178.09	 -67.32	 1.0	 100.0	 1	 400.0	 133.33; % NG
	8267	 120.0	 32.14	 106.84	 -42.56	 1.0	 100.0	 1	 240.0	 0.0; % NG
	8269	 20.0	 6.47	 18.94	 -6.0	 1.0	 100.0	 1	 40.0	 0.0; % COW
	8278	 60.0	 16.54	 53.88	 -20.8	 1.0	 100.0	 1	 120.0	 0.0; % NG
	8297	 45.78	 -10.1	 41.33	 -61.53	 1.0	 100.0	 1	 91.56	 0.0; % NG
	8304	 400.0	 90.555	 274.12	 -93.01	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8311	 44.17	 5.335	 17.8	 -7.13	 1.0	 100.0	 1	 100.0	 -11.66; % NG
	8312	 1600.0	 360.845	 1096.33	 -374.64	 1.0	 100.0	 1	 2400.0	 800.0; % COW
	8317	 1202.665	 25.08	 402.46	 -352.3	 1.0	 100.0	 1	 1804.0	 601.33; % COW
	8340	 80.0	 22.68	 72.47	 -27.11	 1.0	 100.0	 1	 160.0	 0.0; % NG
	8362	 220.0	 55.555	 192.7	 -81.59	 1.0	 100.0	 1	 440.0	 0.0; % NG
	8371	 266.665	 63.29	 185.66	 -59.08	 1.0	 100.0	 1	 400.0	 133.33; % NG
	8375	 240.0	 55.85	 203.22	 -91.52	 1.0	 100.0	 1	 480.0	 0.0; % NG
	8377	 200.0	 43.97	 136.04	 -48.1	 1.0	 100.0	 1	 300.0	 100.0; % COW
	8378	 20.0	 5.335	 17.78	 -7.11	 1.0	 100.0	 1	 40.0	 0.0; % COW
	8383	 333.335	 72.935	 225.36	 -79.49	 1.0	 100.0	 1	 500.0	 166.67; % COW
	8384	 26.135	 10.015	 24.27	 -4.24	 1.0	 100.0	 1	 100.0	 -47.73; % NG
	8398	 41.16	 9.225	 34.16	 -15.71	 1.0	 100.0	 1	 82.32	 0.0; % NG
	8401	 533.335	 132.32	 377.63	 -112.99	 1.0	 100.0	 1	 800.0	 266.67; % COW
	8413	 266.665	 48.29	 171.01	 -74.43	 1.0	 100.0	 1	 400.0	 133.33; % COW
	8415	 333.335	 64.945	 218.07	 -88.18	 1.0	 100.0	 1	 500.0	 166.67; % NG
	8427	 40.0	 12.71	 37.61	 -12.19	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	8433	 50.4	 135.75	 380.55	 -109.05	 1.0	 100.0	 1	 100.0	 0.8; % NG
	8451	 40.0	 12.21	 37.15	 -12.73	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8458	 666.665	 167.965	 474.42	 -138.49	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	8464	 133.335	 23.265	 84.61	 -38.08	 1.0	 100.0	 1	 200.0	 66.67; % NG
	8473	 -40.0	 27.88	 90.21	 -34.45	 1.0	 100.0	 1	 100.0	 -180.0; % COW
	8474	 533.335	 111.47	 356.66	 -133.72	 1.0	 100.0	 1	 800.0	 266.67; % NG
	8481	 60.0	 18.355	 55.64	 -18.93	 1.0	 100.0	 1	 120.0	 0.0; % NG
	8486	 40.0	 9.245	 34.16	 -15.67	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8515	 100.0	 30.8	 93.03	 -31.43	 1.0	 100.0	 1	 200.0	 0.0; % NG
	8518	 23.52	 -4.41	 28.59	 -37.41	 1.0	 100.0	 1	 47.04	 0.0; % NG
	8522	 -0.46	 0.96	 3.61	 -1.69	 1.0	 100.0	 1	 100.0	 -100.92; % NG
	8531	 133.335	 22.135	 83.35	 -39.08	 1.0	 100.0	 1	 200.0	 66.67; % COW
	8532	 -414.835	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 100.0	 -929.67; % NG
	8553	 2633.335	 627.205	 1851.27	 -596.86	 1.0	 100.0	 1	 4000.0	 1266.67; % COW
	8564	 6.665	 14.525	 51.91	 -22.86	 1.0	 100.0	 1	 100.0	 -86.67; % NG
	8569	 266.665	 58.525	 181.24	 -64.19	 1.0	 100.0	 1	 400.0	 133.33; % NG
	8576	 49.335	 3.39	 12.68	 -5.9	 1.0	 100.0	 1	 100.0	 -1.33; % NG
	8586	 40.0	 12.855	 37.75	 -12.04	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8591	 400.0	 95.435	 278.84	 -87.97	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8603	 120.0	 32.125	 106.87	 -42.62	 1.0	 100.0	 1	 240.0	 0.0; % NG
	8605	 400.0	 90.145	 273.94	 -93.65	 1.0	 100.0	 1	 600.0	 200.0; % NG
	8608	 333.335	 80.53	 233.65	 -72.59	 1.0	 100.0	 1	 500.0	 166.67; % NG
	8610	 -71.39	 77.195	 224.7	 -70.31	 1.0	 100.0	 1	 100.0	 -242.78; % NG
	8611	 35.21	 16.215	 46.84	 -14.41	 1.0	 100.0	 1	 100.0	 -29.58; % NG
	8622	 60.0	 15.425	 52.66	 -21.81	 1.0	 100.0	 1	 120.0	 0.0; % NG
	8623	 120.0	 36.77	 110.42	 -36.88	 1.0	 100.0	 1	 240.0	 0.0; % NG
	8625	 51.515	 0.38	 34.48	 -33.72	 1.0	 100.0	 1	 103.03	 0.0; % COW
	8630	 200.0	 32.685	 124.56	 -59.19	 1.0	 100.0	 1	 300.0	 100.0; % NG
	8640	 150.0	 39.245	 131.33	 -52.84	 1.0	 100.0	 1	 300.0	 0.0; % NG
	8663	 333.335	 55.4	 207.95	 -97.15	 1.0	 100.0	 1	 500.0	 166.67; % NG
	8670	 -42.2	 12.47	 37.4	 -12.46	 1.0	 100.0	 1	 100.0	 -184.4; % NG
	8675	 40.0	 13.095	 38.02	 -11.83	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8676	 -122.735	 9.98	 34.92	 -14.96	 1.0	 100.0	 1	 100.0	 -345.47; % NG
	8683	 25.15	 16.965	 54.32	 -20.39	 1.0	 100.0	 1	 100.0	 -49.7; % NG
	8693	 40.0	 11.475	 36.39	 -13.44	 1.0	 100.0	 1	 80.0	 0.0; % COW
	8702	 180.0	 62.765	 173.2	 -47.67	 1.0	 100.0	 1	 360.0	 0.0; % NG
	8714	 536.0	 73.985	 376.94	 -228.97	 1.0	 100.0	 1	 804.0	 268.0; % NUC
	8721	 1333.335	 319.77	 932.68	 -293.14	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	8729	 50.18	 2.075	 34.95	 -30.8	 1.0	 100.0	 1	 100.36	 0.0; % COW
	8737	 533.335	 134.335	 379.68	 -111.01	 1.0	 100.0	 1	 800.0	 266.67; % COW
	8758	 533.335	 101.17	 346.49	 -144.15	 1.0	 100.0	 1	 800.0	 266.67; % COW
	8762	 266.665	 46.31	 168.92	 -76.3	 1.0	 100.0	 1	 400.0	 133.33; % COW
	8764	 192.87	 55.395	 178.04	 -67.25	 1.0	 100.0	 1	 300.0	 85.74; % NG
	8770	 23.065	 6.785	 61.15	 -47.58	 1.0	 100.0	 1	 100.0	 -53.87; % NG
	8771	 20.0	 6.635	 19.07	 -5.8	 1.0	 100.0	 1	 40.0	 0.0; % NG
	8795	 120.0	 36.925	 111.7	 -37.85	 1.0	 100.0	 1	 240.0	 0.0; % NG
	8797	 30.215	 2.79	 22.35	 -16.77	 1.0	 100.0	 1	 60.43	 0.0; % PEL
	8807	 -152.665	 10.885	 35.84	 -14.07	 1.0	 100.0	 1	 100.0	 -405.33; % NG
	8818	 80.0	 27.06	 76.87	 -22.75	 1.0	 100.0	 1	 160.0	 0.0; % NG
	8820	 133.335	 31.72	 92.95	 -29.51	 1.0	 100.0	 1	 200.0	 66.67; % NG
	8822	 10.185	 70.11	 192.72	 -52.5	 1.0	 100.0	 1	 100.0	 -79.63; % NG
	8851	 50.0	 14.23	 44.89	 -16.43	 1.0	 100.0	 1	 100.0	 0.0; % NG
	8858	 180.0	 53.465	 163.91	 -56.98	 1.0	 100.0	 1	 360.0	 0.0; % NG
	8869	 533.335	 139.235	 384.3	 -105.83	 1.0	 100.0	 1	 800.0	 266.67; % COW
	8871	 -105.865	 32.935	 106.62	 -40.75	 1.0	 100.0	 1	 100.0	 -311.73; % NG
	8872	 1333.335	 319.77	 932.68	 -293.14	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	8875	 400.0	 88.875	 272.77	 -95.02	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8894	 266.665	 57.345	 179.73	 -65.04	 1.0	 100.0	 1	 400.0	 133.33; % NG
	8896	 21.0	 -1.965	 15.33	 -19.26	 1.0	 100.0	 1	 42.0	 0.0; % NG
	8897	 60.0	 19.145	 56.5	 -18.21	 1.0	 100.0	 1	 120.0	 0.0; % NG
	8903	 43.365	 0.29	 28.99	 -28.41	 1.0	 100.0	 1	 86.73	 0.0; % NG
	8914	 40.0	 12.365	 37.19	 -12.46	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8920	 20.0	 4.8	 17.27	 -7.67	 1.0	 100.0	 1	 40.0	 0.0; % NG
	8927	 40.0	 13.76	 38.64	 -11.12	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8944	 50.0	 12.305	 42.9	 -18.29	 1.0	 100.0	 1	 100.0	 0.0; % COW
	8946	 533.335	 93.92	 339.05	 -151.21	 1.0	 100.0	 1	 800.0	 266.67; % COW
	8950	 -120.47	 13.31	 38.23	 -11.61	 1.0	 100.0	 1	 100.0	 -340.94; % COW
	8956	 400.0	 82.335	 266.17	 -101.5	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8961	 8.8	 1.57	 53.52	 -50.38	 1.0	 100.0	 1	 100.0	 -82.4; % NG
	8966	 150.0	 45.105	 136.96	 -46.75	 1.0	 100.0	 1	 300.0	 0.0; % COW
	8971	 -13.6	 66.79	 189.2	 -55.62	 1.0	 100.0	 1	 100.0	 -127.2; % NG
	8972	 20.0	 6.265	 18.7	 -6.17	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	8973	 1333.335	 245.94	 859.0	 -367.12	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	8976	 100.0	 33.35	 95.65	 -28.95	 1.0	 100.0	 1	 200.0	 0.0; % NG
	8978	 533.335	 114.65	 359.96	 -130.66	 1.0	 100.0	 1	 800.0	 266.67; % COW
	8981	 48.99	 0.24	 32.66	 -32.18	 1.0	 100.0	 1	 97.98	 0.0; % NG
	8987	 35.365	 0.88	 31.68	 -29.92	 1.0	 100.0	 1	 100.0	 -29.27; % NG
	8988	 36.75	 -5.2	 27.09	 -37.49	 1.0	 100.0	 1	 73.5	 0.0; % PEL
	8993	 19.21	 14.08	 38.98	 -10.82	 1.0	 100.0	 1	 100.0	 -61.58; % COW
	8997	 158.545	 3.055	 107.59	 -101.48	 1.0	 100.0	 1	 317.09	 0.0; % NG
	9000	 266.665	 52.67	 175.3	 -69.96	 1.0	 100.0	 1	 400.0	 133.33; % COW
	9001	 333.335	 67.175	 220.49	 -86.14	 1.0	 100.0	 1	 500.0	 166.67; % NG
	9013	 30.0	 9.945	 28.36	 -8.47	 1.0	 100.0	 1	 60.0	 0.0; % NG
	9027	 533.335	 130.97	 376.25	 -114.31	 1.0	 100.0	 1	 800.0	 266.67; % COW
	9034	 -42.2	 -7.755	 30.47	 -45.98	 1.0	 100.0	 1	 100.0	 -184.4; % NG
	9035	 40.0	 11.495	 36.35	 -13.36	 1.0	 100.0	 1	 80.0	 0.0; % NG
	9039	 23.435	 0.58	 2.23	 -1.07	 1.0	 100.0	 1	 100.0	 -53.13; % COW
	9043	 42.965	 5.365	 17.82	 -7.09	 1.0	 100.0	 1	 100.0	 -14.07; % NG
	9046	 200.0	 53.42	 176.14	 -69.3	 1.0	 100.0	 1	 400.0	 0.0; % NG
	9047	 266.665	 64.41	 186.96	 -58.14	 1.0	 100.0	 1	 400.0	 133.33; % NG
	9048	 100.0	 30.145	 92.45	 -32.16	 1.0	 100.0	 1	 200.0	 0.0; % NG
	9054	 266.665	 55.18	 177.87	 -67.51	 1.0	 100.0	 1	 400.0	 133.33; % NG
	9055	 -10.0	 0.685	 11.6	 -10.23	 1.0	 100.0	 1	 100.0	 -120.0; % NG
	9058	 51.42	 16.78	 47.34	 -13.78	 1.0	 100.0	 1	 100.0	 2.84; % COW
	9060	 -229.2	 9.89	 34.79	 -15.01	 1.0	 100.0	 1	 100.0	 -558.4; % NG
	9067	 293.335	 60.865	 198.07	 -76.34	 1.0	 100.0	 1	 440.0	 146.67; % COW
	9097	 20.58	 4.565	 17.03	 -7.9	 1.0	 100.0	 1	 41.16	 0.0; % PEL
	9099	 -9.865	 -2.63	 63.31	 -68.57	 1.0	 100.0	 1	 100.0	 -119.73; % NG
	9100	 50.0	 13.335	 44.0	 -17.33	 1.0	 100.0	 1	 100.0	 0.0; % NG
	9101	 666.665	 136.535	 442.99	 -169.92	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	9103	 10.935	 -4.055	 25.09	 -33.2	 1.0	 100.0	 1	 100.0	 -78.13; % COW
	9105	 66.665	 10.05	 40.58	 -20.48	 1.0	 100.0	 1	 100.0	 33.33; % COW
	9108	 27.29	 2.245	 18.65	 -14.16	 1.0	 100.0	 1	 100.0	 -45.42; % NG
	9110	 550.0	 49.84	 172.53	 -72.85	 1.0	 100.0	 1	 900.0	 200.0; % COW
	9113	 62.89	 12.79	 49.65	 -24.07	 1.0	 100.0	 1	 125.78	 0.0; % COW
	9125	 20.0	 4.795	 17.28	 -7.69	 1.0	 100.0	 1	 40.0	 0.0; % NG
	9132	 533.335	 109.925	 355.14	 -135.29	 1.0	 100.0	 1	 800.0	 266.67; % COW
	9137	 64.235	 121.365	 335.96	 -93.23	 1.0	 100.0	 1	 100.0	 28.47; % NG
	9140	 25.2	 23.355	 73.19	 -26.48	 1.0	 100.0	 1	 100.0	 -49.6; % NG
	9150	 666.665	 133.05	 439.38	 -173.28	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	9161	 200.0	 51.225	 175.96	 -73.51	 1.0	 100.0	 1	 400.0	 0.0; % COW
	9167	 90.0	 27.505	 82.76	 -27.75	 1.0	 100.0	 1	 180.0	 0.0; % NG
	9168	 200.675	 34.85	 126.8	 -57.1	 1.0	 100.0	 1	 301.01	 100.34; % NG
	9174	 -170.935	 62.92	 175.0	 -49.16	 1.0	 100.0	 1	 100.0	 -441.87; % NG
	9180	 80.0	 27.86	 77.69	 -21.97	 1.0	 100.0	 1	 160.0	 0.0; % NG
	9187	 30.0	 8.42	 26.85	 -10.01	 1.0	 100.0	 1	 60.0	 0.0; % PEL
	9195	 40.0	 11.21	 36.15	 -13.73	 1.0	 100.0	 1	 80.0	 0.0; % NG
	9197	 47.51	 4.115	 34.65	 -26.42	 1.0	 100.0	 1	 95.02	 0.0; % NG
	9200	 150.0	 34.88	 126.9	 -57.14	 1.0	 100.0	 1	 300.0	 0.0; % NG
	9215	 20.0	 5.79	 18.19	 -6.61	 1.0	 100.0	 1	 40.0	 0.0; % COW
	9230	 -34.465	 36.04	 127.96	 -55.88	 1.0	 100.0	 1	 100.0	 -168.93; % NG
	9235	 200.0	 51.69	 176.33	 -72.95	 1.0	 100.0	 1	 400.0	 0.0; % NG
	9238	 800.0	 184.045	 552.08	 -183.99	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	9239	 400.0	 90.49	 274.2	 -93.22	 1.0	 100.0	 1	 600.0	 200.0; % COW
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	  48.144896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.752152	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.944562	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.963567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.582172	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 102.123377	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.491952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.121938	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.422147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.547479	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.340722	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.847851	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.555469	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.372493	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.375422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.224446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.806983	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.631964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.120319	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.196291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  67.893274	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.690715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.756254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.534667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.107941	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.105459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.472656	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.223030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.538301	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.957222	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.521714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.536720	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.147209	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.161061	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.649135	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.216573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.143579	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.608411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.435671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.722854	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.458323	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  62.457256	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.320554	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.109769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.715930	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.855361	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.046649	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.293749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.344146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.792717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.890752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.737199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.039292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.726025	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.536201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.002594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.286323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.665073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.265444	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.015219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.330953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.386487	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.914927	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.514558	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.294770	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.807489	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.295725	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.589696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.952051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.954064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.191448	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.711424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.804978	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.033588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.152413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.325875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.823998	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.469758	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.593272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.551931	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.129224	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.053251	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.278186	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.651028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  87.617497	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.138695	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.848214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.733565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.482425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.459703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.505085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.670212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.975457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.242647	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.025704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.556910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.356072	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.774912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.390872	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.037941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.179903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.501955	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.316382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.908855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.814239	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.496477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.731813	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.270435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.930525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.378171	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.668034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.359581	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.620093	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.337555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.315011	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.235620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.604601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.363783	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.000500	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.927762	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.734171	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.919716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.633061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.847313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.689607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.095756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.590748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.192791	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.395841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.396239	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.118951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.607693	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.753305	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.033043	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  47.432749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.641911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.601252	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.258328	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.083093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.412766	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.081564	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.329283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.329787	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.754364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.438736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.898489	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.716118	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.551616	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.079880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.053825	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.044824	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.509630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.569503	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.401918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.494446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.511724	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.775384	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.825257	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.230335	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.173886	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.373029	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.096869	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.927221	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.476474	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.075049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.084275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.997549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.161573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.834682	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.715422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.061291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.255410	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.892800	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.899324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.421517	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.958013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.103282	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.866196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.300609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.799906	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.800816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.557401	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.259257	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.557610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.911611	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.014432	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   1.071850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.982049	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.151955	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.162431	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.135441	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.603662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.220193	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.367380	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.103440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.934404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.550650	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.177738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.358057	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.928142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.130811	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.913374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.932051	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	 118.570612	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.260764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.970296	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.722342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.287917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.078334	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.249510	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.480414	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.894484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.659079	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.856730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.758531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.965475	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.279880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.356619	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.856555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.316255	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.371064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.759980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.712076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.499286	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.361834	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.419607	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  43.329464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.057305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.582126	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  55.266202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.120099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.524252	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.039675	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.748303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.589378	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.321663	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.039464	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.278393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.283861	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.139482	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.137273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.837277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.870979	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.254086	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.147587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.165908	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.694015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.953036	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.292778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.793506	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.222375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.219998	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.540861	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.768555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.649531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.363392	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.890257	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.270091	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.024209	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.862233	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.618706	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.323126	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.343575	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.094958	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.494305	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.799553	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.961187	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.976055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.691068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.963897	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.506253	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.532833	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.255779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.948991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.666638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.649459	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.203888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.107884	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.565980	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.254721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.758363	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.697566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.810988	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.319458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.289334	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.454045	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.871727	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.609064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.733934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.859963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.091467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.394698	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.902441	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.248917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.900986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.626322	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.922925	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.986078	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.635003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.509280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.752608	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.402360	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.139299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.041313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.120997	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.305921	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.651453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.732541	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.671395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.305849	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.630495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.466732	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.992192	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.482090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.949394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.516900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.735968	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.187480	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.692039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.264056	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.333830	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.729397	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.229244	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.299358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.542750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.661663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.441348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.846998	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.161975	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.943170	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.281348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.786918	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.256565	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.318247	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.808835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.650904	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.249967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.038824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.537628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.073184	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.824785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.670602	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.996971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.217540	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.067362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.394594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.737712	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.985454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.553288	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.965350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.027280	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.602855	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  16.998832	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.503691	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.677207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.445483	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.353265	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.827773	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.084249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.463243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.552361	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  64.068347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.401378	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.858232	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.347056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.298386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.432912	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.100079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.665198	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.979552	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.083538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.654884	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.321378	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.613214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.751012	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.313191	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.635344	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.274556	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.652036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.388639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.351286	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.115523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.232082	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  38.224510	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.827947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.636987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.119339	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.644179	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.659349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.101417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.871103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.638583	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.700027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.458631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.328398	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.225535	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.740096	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.834852	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.709582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.638741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.784635	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.911969	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.357856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.963408	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.106874	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.311063	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.702619	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.854487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.140027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.065228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.014463	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.885515	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.879528	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.606246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.384634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.617236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.406819	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.735817	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.166303	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.293283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.046489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.039635	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.893845	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.175603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.347202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.131986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.378836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.243907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.490330	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 127.658311	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.737454	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.735630	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  48.235337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.697772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.852194	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.590004	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.170203	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.638055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.423574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.345298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.660833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.457277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.714222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.363538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.414149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.994573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.511632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.734958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.873792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.471806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.038568	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.635729	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.723953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.909648	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.374375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.402662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.907865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.918525	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.296122	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.054174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.800197	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.970753	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.942238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.525317	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.717663	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.253599	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.808574	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.336922	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.291773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.001628	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.973924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.925871	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.308636	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.908608	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.104841	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.685946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.570538	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.110581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.057755	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.294704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.971945	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.337781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.058396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.255894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.373476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.166181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.714396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.927563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.261038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.406945	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.930872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.318611	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.498828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.870957	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.128600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.968419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.013114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.858355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.836127	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.694069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.684152	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.917671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.541021	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.256919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.498363	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.903500	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.159962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.690731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.669559	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.963522	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.089575	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.175712	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.997219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.103507	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.737195	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.348539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.958452	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.798248	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.184065	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.955511	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.573279	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.822416	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.195876	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.028229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.779274	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.161172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.078730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.107917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.767012	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.603226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.102026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.484859	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.287187	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.519936	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.698519	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.979883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.132763	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.479206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.504484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.482055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.654333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.389273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.009128	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.070659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.364857	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.891638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.842955	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.825904	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.046709	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  61.725154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.806893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.968799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.847614	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.029777	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.362785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.777207	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   1.537740	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.275363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.458605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.912891	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.245176	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.145219	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.407998	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.744553	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.206807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.972699	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.023855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.043283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.228708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.060609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.045535	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.504625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.389291	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.702231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.322694	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.029564	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.830975	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.696479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.267996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.347311	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.090056	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.329004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.462532	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.467213	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.698580	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.589051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.019544	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.894351	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.627205	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.214251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.065244	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.532768	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  59.380148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.937542	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.415667	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.256124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.089258	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.351149	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.421940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.289463	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.486979	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.198242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.370007	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.127790	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.168049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.336866	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.445031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.772597	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.563697	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.809285	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.721338	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.658198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.573851	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.774764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.684417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.998654	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.026277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.375409	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.786469	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.009789	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.816477	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.134451	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.923704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.773888	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  17.418593	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.113608	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.220397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.432633	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.681431	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.684350	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.043655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.309571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.958476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.685947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.649509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.432934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.152065	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.017137	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.135417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.651823	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.010727	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.286071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.669339	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.973389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.434993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.813710	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.287272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.357847	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.890626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.689979	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.348814	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.012228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.771720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.296528	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.421253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.381882	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.831599	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.546341	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.349461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.129229	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.737776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.040504	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.320048	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.341106	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.296653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.042006	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.649838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.582030	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.527656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.655037	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.635442	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.739655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.177275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.466737	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.547168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.274707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.422527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.195115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.043029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.163040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.903040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.866454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.398174	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.487552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.844412	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.664259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.305563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.309374	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.385700	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.982200	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.313556	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.842150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.114199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.328024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.817326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   3.608021	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.997397	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.014085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.173040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.392731	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.059029	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.152041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.889417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.286789	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.677155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.369139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.380376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.652938	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.863907	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.620015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.570034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.303926	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.922408	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.855251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.200314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.150423	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.068272	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.966879	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.913241	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  33.098399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.378244	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.431247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.158986	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.001399	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.080448	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.976559	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.533666	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  41.075854	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.661953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.242087	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.797361	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.055036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.851498	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.482918	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.112936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.158159	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.757324	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.464538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.572255	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.058618	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.066607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.229491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.486671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.459931	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.945738	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.960106	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.964478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.562486	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  50.837256	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.047891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.327454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.431112	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.597294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.600672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.223249	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.680220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.637709	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  44.667432	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.397514	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.450727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.330025	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.238986	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.165475	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.896768	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.201921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.739449	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.185318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.930888	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.675260	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.864562	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.897136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.278803	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.161237	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.039035	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.306420	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.103468	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.050218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.172336	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.137214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.532080	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   8.834906	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.063997	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.544768	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.516308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.640319	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.675981	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   4.140264	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.826715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.040829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.442163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.423077	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.942215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.903366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.343260	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.131114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  65.397800	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.094839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.647501	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.049067	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.328954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.993589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.014027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.553502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.368555	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.050709	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.776532	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.189912	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.873221	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.367472	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.106322	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.013667	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.267780	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.743462	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.194640	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.903648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.270782	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.293238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.745359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.012929	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.218235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.524916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.794118	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.675960	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.504055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.763809	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.355888	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.417307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.974757	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.357767	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.658799	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.479967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.566020	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.661162	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.320485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.575825	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.234898	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.563050	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.299343	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.172893	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.617166	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.301364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.417014	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.267572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.728963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.758793	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.380490	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.947432	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.770991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.116816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.847765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.515014	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.082994	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.749023	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.658359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.602203	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.447595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.023770	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.864998	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.533571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.916555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.666412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.768548	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.085930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.562099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.213155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.444025	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.355193	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.284324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.973960	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.097176	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.906808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.990192	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.934433	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.394832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.110470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.724225	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.051883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.441359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.074835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.526206	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.132958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.067610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.829561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.158307	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.051337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.873903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.047970	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.577572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.085410	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.389739	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.061390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.263230	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.736207	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.845055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.147059	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.913788	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.419418	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.924411	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.791467	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.213536	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.444606	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.731253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.968595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.521112	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.283906	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.100709	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.576672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.607430	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.210659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.890316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.247291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.366692	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.331492	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.087229	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.084043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.392973	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.298010	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.748108	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  61.520896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.789736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.081902	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.083858	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.950946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.274884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.454944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.717922	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.009591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.827656	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.161707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.776390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.873382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.924747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.744744	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.976011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.521015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.428312	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.689969	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.721288	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.643284	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.708712	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.258751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.116582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.681768	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.702642	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.237227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.290083	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.533258	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.649355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.641912	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.326739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.475578	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.018558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.527005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.223311	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.230263	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  31.882959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.413190	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.075765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.730659	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.977843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.100481	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.486294	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.782835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.580400	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.819934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.553469	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  39.413841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.647101	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.670433	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.706230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.430718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.178235	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.396996	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  41.689647	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.287885	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  48.756500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.126427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.282394	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 125.290711	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.381751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.858752	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.446820	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.759363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.569397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.069879	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.641345	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.732637	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.717303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.356313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.422851	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.661458	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.569302	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.785597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.771786	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.480520	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.368083	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.703049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.765088	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.463622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.087684	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.729646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.408151	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.761421	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.013303	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.672406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.569971	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   7.680673	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.262289	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.983566	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.888144	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.138694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   3.786782	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.507928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.044829	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.076248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.025545	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.895962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.146429	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.985682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.375985	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.337298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.025389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.402893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.579840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.880507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.029058	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.590686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.343333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.897158	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.216738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.516706	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.256590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.092547	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   5.907459	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  28.130641	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.878373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.233684	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.288650	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.668791	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.254976	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.911006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.797476	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.469758	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.673093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.795935	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  59.554780	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  90.013495	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.697406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.272898	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.182295	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.974025	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.424028	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.398888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.313818	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.091696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.368438	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.742772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.559927	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.455407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.083875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.141198	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.643631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.652114	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.092184	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.042535	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.409748	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.572147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.635184	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.619414	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.278361	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.572572	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.335444	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.892131	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.224110	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.502044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.715111	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.477057	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.243561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.839143	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.726218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.867885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.122900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.575687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.087045	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.532168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.648306	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  33.436849	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.936068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.843899	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.698064	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.957368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.009816	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.686621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.723618	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.773278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.729286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.640918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.778872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.882267	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.066933	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.725353	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.907335	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  61.372980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.209090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.250785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.981961	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.103188	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.436249	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.005824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.111311	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.969642	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.081206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.252608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.624312	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.168242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.033554	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.189152	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.296209	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.595976	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.152029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.200369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.401706	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.456439	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.821834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.707881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.779918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.897554	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.130649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.590703	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.360403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.827172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.763197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.737404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.934747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.883192	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.264309	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.981888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.716156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.267538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.427984	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  31.868611	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.829231	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.317293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.039021	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  34.485075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.646487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.369675	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.641341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.504630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.353961	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   5.614878	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.577407	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.567888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.816110	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.274348	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.169452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.433887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.785341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.794264	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.399675	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.958530	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.697364	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.246703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.459403	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.279058	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.343069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.311330	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.192872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.866455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.825967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.160137	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.608049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.799044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.534953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.229967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.693973	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.265881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.617631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.063566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.959939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.334543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.943200	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.304992	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.038659	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.365102	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.999770	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.940862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.086284	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.654247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.323546	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.249756	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.516610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.539121	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.567961	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.793197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.641789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.279474	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.408803	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  18.431972	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.038982	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.115732	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.576597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.355039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.589204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.809219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.931376	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.704264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.069041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.375713	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.376337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.749953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.498271	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.896078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.926856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.570995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.323123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.762494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.134503	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.053306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.777769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.708037	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.146887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.038240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.311548	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 135.689482	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.528363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.994668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.368728	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.241873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.024236	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.948234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.409506	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.633387	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  21.957447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.758076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.931874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.783281	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.967955	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.448888	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.234116	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.663396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.218493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.770954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.057099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.155626	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.304648	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.880919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.976998	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.066271	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.168919	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.658579	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.843480	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.682484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.147629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.811815	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.941246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.127268	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.333501	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.544766	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.860208	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.977136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.570156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.184601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.432942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.218343	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  34.772463	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.018644	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.684066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.402629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.933806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.387286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.213039	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.867573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.573950	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.384633	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.586117	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.435374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.930722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.437849	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.078237	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.473181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.602774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.049874	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.016723	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.099815	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.577840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.612273	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.311415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.417054	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.659299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.927004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.889352	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.047468	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.755502	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.071572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.863887	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.899664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.704566	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.397987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.213052	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.091965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.879539	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.891778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.941122	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.492358	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.179498	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.514392	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.719370	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.025390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.642254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.929940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.820730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.265734	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.400486	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.848034	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.467943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.822554	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.332109	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.666350	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.211721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.417373	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.075697	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.868375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.949591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  60.006794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.149887	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.882160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.739460	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.726493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.588632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.483492	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.015051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.190601	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.144588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.298496	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.434393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.632615	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.588042	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.171482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.771761	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.726986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.680802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.676495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.285750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.307017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.702193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.932557	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.855459	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.579196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.692324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.248962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.593726	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.773290	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.178659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.081694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.306959	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.579099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.875139	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.712042	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.649065	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.415465	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.144163	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.022867	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.927155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.345732	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.415599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.031345	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.443806	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.579664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.734857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.237649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.213998	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.551108	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.017482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.732674	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.695984	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.142146	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.294288	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.845679	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.544318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.241921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.022856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.729251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.347890	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.630583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.205072	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.005591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.880421	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.071592	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.706985	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.947855	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.619202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.423957	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.229960	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.280965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.916025	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.398181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.373169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.698254	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.080952	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.783323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.316978	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.316592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.817705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.210865	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.046947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.573154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.976634	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.366282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.652877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.957362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.988850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.111467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.462109	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.292932	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.271813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.166082	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.602737	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.062341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.268885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.829634	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.400643	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.252035	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.819493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.729776	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.034510	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.186266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.816826	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.678743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.102515	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.228887	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.300558	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.250371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.932351	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.249059	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.040866	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.850702	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.048389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.223883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.274672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.737718	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.177628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.077973	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.880068	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.329574	   0.000000; % COW
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	5147	 3097	 0.0006	 0.00616	 0.0	 823.0	 5104	 5104	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 8763	 0.0005	 0.0074	 0.0	 921.0	 4259	 4259	 0.0	 0.0	 1	 -30.0	 30.0;
	2169	 3124	 0.00107	 0.00626	 0.0	 476.0	 4974	 4974	 0.0	 0.0	 1	 -30.0	 30.0;
	2169	 3234	 0.000841	 0.0055	 0.0	 476.0	 5678	 5678	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 711	 0.00143	 0.01563	 0.0	 1645.0	 2013	 2013	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 4533	 0.00146	 0.01692	 0.0	 1711.0	 2838	 2838	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 5425	 7e-05	 0.00057	 0.0	 1711.0	 55004	 55004	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 4704	 6e-05	 0.00056	 0.0	 1514.0	 56085	 56085	 0.0	 0.0	 1	 -30.0	 30.0;
	5960	 7431	 0.003349	 0.01656	 0.0	 1870	 1870	 1870	 0.0	 0.0	 1	 -30.0	 30.0;
	5960	 3186	 0.003409	 0.016211	 0.0	 1907	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	4481	 7431	 0.003479	 0.01586	 0.0	 1946	 1946	 1946	 0.0	 0.0	 1	 -30.0	 30.0;
	4481	 3186	 0.003099	 0.017969	 0.0	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	531	 9203	 0.00127	 0.01842	 0.0	 823.0	 1711	 1711	 0.0	 0.0	 1	 -30.0	 30.0;
	531	 835	 0.00126	 0.01847	 0.0	 1547.0	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	1656	 118	 0.0013	 0.01808	 0.0	 1218.0	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	1656	 3449	 0.00131	 0.01765	 0.0	 1744.0	 1785	 1785	 0.0	 0.0	 1	 -30.0	 30.0;
	5084	 1809	 0.00065	 0.01311	 0.0	 2407	 2407	 2407	 0.0	 0.0	 1	 -30.0	 30.0;
	5084	 6398	 0.00067	 0.00974	 0.0	 2598.0	 3236	 3236	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 7833	 0.00236	 0.01418	 0.0	 553.0	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 7770	 0.002169	 0.015909	 0.0	 514.0	 1968	 1968	 0.0	 0.0	 1	 -30.0	 30.0;
	354	 1278	 0.00027	 0.00254	 0.0	 1349.0	 12367	 12367	 0.0	 0.0	 1	 -30.0	 30.0;
	354	 7617	 0.00027	 0.00259	 0.0	 1119.0	 12131	 12131	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 1278	 0.00033	 0.00302	 0.0	 1448.0	 10398	 10398	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 905	 0.00029	 0.00312	 0.0	 1613.0	 10081	 10081	 0.0	 0.0	 1	 -30.0	 30.0;
	1842	 6542	 0.000289	 0.00137	 0.0	 533.0	 22560	 22560	 0.0	 0.0	 1	 -30.0	 30.0;
	1842	 7622	 0.000219	 0.00263	 0.0	 11969	 11969	 11969	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 6542	 0.000289	 0.001341	 0.0	 457.0	 23027	 23027	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 8785	 0.000229	 0.00257	 0.0	 12243	 12243	 12243	 0.0	 0.0	 1	 -30.0	 30.0;
	6613	 6542	 0.000841	 0.00689	 0.0	 514.0	 4551	 4551	 0.0	 0.0	 1	 -30.0	 30.0;
	6613	 1651	 0.000979	 0.00586	 0.0	 495.0	 5317	 5317	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 6542	 0.00014	 0.0012	 0.0	 26146	 26146	 26146	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 7840	 0.000211	 0.001539	 0.0	 20335	 20335	 20335	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 6542	 0.000401	 0.004901	 0.0	 6424	 6424	 6424	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 7840	 0.000219	 0.00151	 0.0	 533.0	 20703	 20703	 0.0	 0.0	 1	 -30.0	 30.0;
	8072	 6542	 0.000729	 0.004539	 0.0	 495.0	 6872	 6872	 0.0	 0.0	 1	 -30.0	 30.0;
	8072	 2759	 0.00062	 0.00482	 0.0	 495.0	 6500	 6500	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 6069	 0.00052	 0.00407	 0.0	 1481.0	 7699	 7699	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 3445	 0.00034	 0.00502	 0.0	 1843.0	 6278	 6278	 0.0	 0.0	 1	 -30.0	 30.0;
	7561	 6069	 0.00065	 0.00698	 0.0	 1711.0	 4506	 4506	 0.0	 0.0	 1	 -30.0	 30.0;
	7561	 8825	 0.00059	 0.00806	 0.0	 1678.0	 3909	 3909	 0.0	 0.0	 1	 -30.0	 30.0;
	6748	 8864	 0.00063	 0.00464	 0.0	 495.0	 6746	 6746	 0.0	 0.0	 1	 -30.0	 30.0;
	6748	 5078	 0.000599	 0.005099	 0.0	 533.0	 6153	 6153	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 4785	 0.00064	 0.00307	 0.0	 10073	 10073	 10073	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 7667	 0.000659	 0.003	 0.0	 10284	 10284	 10284	 0.0	 0.0	 1	 -30.0	 30.0;
	8619	 6775	 0.00053	 0.00528	 0.0	 1086.0	 5953	 5953	 0.0	 0.0	 1	 -30.0	 30.0;
	8619	 8195	 0.00056	 0.0053	 0.0	 1283.0	 5927	 5927	 0.0	 0.0	 1	 -30.0	 30.0;
	3107	 4785	 0.0018	 0.007919	 0.0	 3890	 3890	 3890	 0.0	 0.0	 1	 -30.0	 30.0;
	3107	 7154	 0.001651	 0.00862	 0.0	 3600	 3600	 3600	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 6775	 0.00045	 0.00545	 0.0	 1382.0	 5777	 5777	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 905	 0.00052	 0.00476	 0.0	 1547.0	 6597	 6597	 0.0	 0.0	 1	 -30.0	 30.0;
	2282	 6876	 0.01286	 0.037421	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	2282	 5654	 0.032397	 0.123	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 6876	 0.032851	 0.069727	 0.0	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 8045	 0.059942	 0.112802	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 7472	 0.00011	 0.00109	 0.0	 1086.0	 28833	 28833	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 8899	 0.00011	 0.00107	 0.0	 1185.0	 29367	 29367	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 7681	 0.000461	 0.00395	 0.0	 629.0	 7943	 7943	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 1508	 0.000599	 0.003789	 0.0	 591.0	 8235	 8235	 0.0	 0.0	 1	 -30.0	 30.0;
	7118	 6568	 0.00173	 0.01542	 0.0	 987.0	 2844	 2844	 0.0	 0.0	 1	 -30.0	 30.0;
	7118	 4346	 0.00166	 0.02083	 0.0	 1119.0	 2112	 2112	 0.0	 0.0	 1	 -30.0	 30.0;
	3469	 8850	 0.006314	 0.018488	 0.0	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	3469	 1997	 0.015727	 0.037669	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	7556	 7058	 0.00374	 0.02095	 0.0	 800.0	 1485	 1485	 0.0	 0.0	 1	 -30.0	 30.0;
	7556	 4324	 0.00511	 0.019461	 0.0	 800.0	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 2867	 0.011281	 0.050771	 0.0	 457.0	 608	 608	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 2588	 0.0115	 0.049719	 0.0	 438.0	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 2867	 0.011719	 0.048659	 0.0	 438.0	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 2588	 0.01193	 0.047599	 0.0	 438.0	 644	 644	 0.0	 0.0	 1	 -30.0	 30.0;
	132	 2962	 0.00064	 0.00715	 0.0	 1481.0	 4401	 4401	 0.0	 0.0	 1	 -30.0	 30.0;
	132	 4393	 0.00089	 0.00712	 0.0	 1283.0	 4403	 4403	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 693	 0.00048	 0.00555	 0.0	 987.0	 5671	 5671	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 7860	 0.00047	 0.00566	 0.0	 1086.0	 5562	 5562	 0.0	 0.0	 1	 -30.0	 30.0;
	6883	 693	 0.00046	 0.00524	 0.0	 1053.0	 6006	 6006	 0.0	 0.0	 1	 -30.0	 30.0;
	6883	 7860	 0.00052	 0.00514	 0.0	 1053.0	 6115	 6115	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 4503	 0.00438	 0.010686	 0.0	 2736	 2736	 2736	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 6658	 0.031347	 0.062653	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	6494	 4945	 0.00029	 0.00298	 0.0	 1613.0	 10550	 10550	 0.0	 0.0	 1	 -30.0	 30.0;
	6494	 6080	 0.0003	 0.00291	 0.0	 1514.0	 10798	 10798	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 9010	 0.00155	 0.01529	 0.0	 1185.0	 3137	 3137	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 3146	 0.00148	 0.0152	 0.0	 1283.0	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	8697	 8142	 0.000169	 0.00096	 0.0	 312.0	 32406	 32406	 0.0	 0.0	 1	 -30.0	 30.0;
	8697	 6195	 0.000182	 0.000942	 0.0	 312.0	 32924	 32924	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 424	 0.00016	 0.00184	 0.0	 17103	 17103	 17103	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 7235	 0.00022	 0.00287	 0.0	 10974	 10974	 10974	 0.0	 0.0	 1	 -30.0	 30.0;
	3852	 6497	 0.00015	 0.00187	 0.0	 16838	 16838	 16838	 0.0	 0.0	 1	 -30.0	 30.0;
	3852	 4779	 0.00022	 0.00266	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	674	 8885	 0.00138	 0.0174	 0.0	 1316.0	 2528	 2528	 0.0	 0.0	 1	 -30.0	 30.0;
	674	 3115	 0.00272	 0.0288	 0.0	 1086.0	 1667	 1667	 0.0	 0.0	 1	 -30.0	 30.0;
	8126	 5177	 0.00065	 0.01024	 0.0	 1843.0	 3079	 3079	 0.0	 0.0	 1	 -30.0	 30.0;
	8126	 6007	 0.00073	 0.01004	 0.0	 1876.0	 3138	 3138	 0.0	 0.0	 1	 -30.0	 30.0;
	8935	 5177	 0.00075	 0.00983	 0.0	 1909.0	 3205	 3205	 0.0	 0.0	 1	 -30.0	 30.0;
	8935	 6007	 0.00076	 0.00963	 0.0	 1909.0	 3270	 3270	 0.0	 0.0	 1	 -30.0	 30.0;
	7146	 7388	 0.00042	 0.02666	 0.0	 1185.0	 1185	 1185	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 8855	 0.00029	 0.0026	 0.0	 12075	 12075	 12075	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 5781	 0.00022	 0.00303	 0.0	 1185.0	 10398	 10398	 0.0	 0.0	 1	 -30.0	 30.0;
	6996	 3761	 0.001	 0.006159	 0.0	 5063	 5063	 5063	 0.0	 0.0	 1	 -30.0	 30.0;
	6996	 9108	 0.00113	 0.00657	 0.0	 533.0	 4739	 4739	 0.0	 0.0	 1	 -30.0	 30.0;
	1212	 8258	 0.0013	 0.01277	 0.0	 1316.0	 3438	 3438	 0.0	 0.0	 1	 -30.0	 30.0;
	1212	 7330	 0.00163	 0.01808	 0.0	 1382.0	 2431	 2431	 0.0	 0.0	 1	 -30.0	 30.0;
	8644	 106	 0.00047	 0.00406	 0.0	 1316.0	 10795	 10795	 0.0	 0.0	 1	 -30.0	 30.0;
	8644	 5883	 0.00235	 0.02343	 0.0	 1316.0	 1874	 1874	 0.0	 0.0	 1	 -30.0	 30.0;
	97	 6413	 0.00036	 0.00445	 0.0	 1547.0	 7076	 7076	 0.0	 0.0	 1	 -30.0	 30.0;
	97	 1644	 0.00017	 0.0025	 0.0	 1909.0	 12606	 12606	 0.0	 0.0	 1	 -30.0	 30.0;
	4379	 6413	 0.00036	 0.00436	 0.0	 1580.0	 7221	 7221	 0.0	 0.0	 1	 -30.0	 30.0;
	4379	 3483	 0.00017	 0.00255	 0.0	 1810.0	 12360	 12360	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 3208	 0.00096	 0.00995	 0.0	 1349.0	 3160	 3160	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 6790	 0.00152	 0.01949	 0.0	 1382.0	 1616	 1616	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 3208	 0.00094	 0.01014	 0.0	 1251.0	 3102	 3102	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 6790	 0.00149	 0.01986	 0.0	 1415.0	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	2885	 3208	 0.00107	 0.01243	 0.0	 1152.0	 2532	 2532	 0.0	 0.0	 1	 -30.0	 30.0;
	2885	 2585	 0.00102	 0.01034	 0.0	 1218.0	 4639	 4639	 0.0	 0.0	 1	 -30.0	 30.0;
	3717	 4848	 0.0047	 0.02061	 0.0	 438.0	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	3717	 3688	 0.00739	 0.040531	 0.0	 400.0	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 8640	 0.00049	 0.00611	 0.0	 1942.0	 7198	 7198	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 7330	 0.00035	 0.00431	 0.0	 1547.0	 10203	 10203	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 1029	 0.00261	 0.01344	 0.0	 419.0	 2308	 2308	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 3525	 0.003521	 0.019591	 0.0	 419.0	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	6870	 3431	 0.0025	 0.01419	 0.0	 2193	 2193	 2193	 0.0	 0.0	 1	 -30.0	 30.0;
	6870	 5046	 0.00287	 0.0237	 0.0	 381.0	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	6693	 6743	 0.00088	 0.00956	 0.0	 1547.0	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	6693	 287	 0.00095	 0.00877	 0.0	 1382.0	 3581	 3581	 0.0	 0.0	 1	 -30.0	 30.0;
	2053	 752	 0.00332	 0.020651	 0.0	 457.0	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	2053	 3048	 0.003969	 0.018781	 0.0	 457.0	 1646	 1646	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 2738	 0.002849	 0.014909	 0.0	 438.0	 2082	 2082	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 1575	 0.00439	 0.02451	 0.0	 438.0	 1269	 1269	 0.0	 0.0	 1	 -30.0	 30.0;
	1524	 8687	 0.0002	 0.0018	 0.0	 17442	 17442	 17442	 0.0	 0.0	 1	 -30.0	 30.0;
	1524	 8393	 0.00025	 0.00261	 0.0	 12048	 12048	 12048	 0.0	 0.0	 1	 -30.0	 30.0;
	7369	 8687	 0.0002	 0.00176	 0.0	 17833	 17833	 17833	 0.0	 0.0	 1	 -30.0	 30.0;
	7369	 139	 0.00025	 0.00255	 0.0	 1909.0	 12329	 12329	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 6176	 0.012488	 0.047413	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 7177	 0.010479	 0.027711	 0.0	 1067	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 7458	 0.00044	 0.00428	 0.0	 1810.0	 7342	 7342	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 1337	 0.00036	 0.00475	 0.0	 6631	 6631	 6631	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 5239	 0.00058	 0.00534	 0.0	 1876.0	 5881	 5881	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 3145	 0.00054	 0.00589	 0.0	 1843.0	 5341	 5341	 0.0	 0.0	 1	 -30.0	 30.0;
	2941	 1429	 0.00206	 0.02057	 0.0	 1152.0	 1528	 1528	 0.0	 0.0	 1	 -30.0	 30.0;
	2941	 1542	 0.00077	 0.00872	 0.0	 954.0	 3609	 3609	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 9183	 0.00161	 0.01963	 0.0	 1349.0	 1604	 1604	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 1542	 0.00075	 0.00888	 0.0	 1382.0	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 7261	 0.00016	 0.00152	 0.0	 1645.0	 20667	 20667	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 5479	 0.00019	 0.00163	 0.0	 1711.0	 19249	 19249	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 7261	 0.00015	 0.0016	 0.0	 1547.0	 19656	 19656	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 5479	 0.00015	 0.00183	 0.0	 1645.0	 17204	 17204	 0.0	 0.0	 1	 -30.0	 30.0;
	3648	 3290	 0.00121	 0.01426	 0.0	 1415.0	 2208	 2208	 0.0	 0.0	 1	 -30.0	 30.0;
	3648	 5523	 0.00116	 0.01456	 0.0	 1448.0	 2163	 2163	 0.0	 0.0	 1	 -30.0	 30.0;
	451	 144	 0.00068	 0.00727	 0.0	 1777.0	 4327	 4327	 0.0	 0.0	 1	 -30.0	 30.0;
	451	 1601	 0.0007	 0.00734	 0.0	 1876.0	 4285	 4285	 0.0	 0.0	 1	 -30.0	 30.0;
	7898	 144	 0.00076	 0.00712	 0.0	 1580.0	 4412	 4412	 0.0	 0.0	 1	 -30.0	 30.0;
	7898	 1601	 0.0008	 0.00719	 0.0	 1909.0	 4367	 4367	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 1582	 0.0002	 0.0022	 0.0	 1218.0	 14299	 14299	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 7416	 0.0002	 0.0022	 0.0	 1251.0	 14299	 14299	 0.0	 0.0	 1	 -30.0	 30.0;
	270	 2046	 0.000205	 0.00215	 0.0	 1415.0	 14626	 14626	 0.0	 0.0	 1	 -30.0	 30.0;
	270	 7416	 0.000205	 0.00215	 0.0	 1448.0	 14626	 14626	 0.0	 0.0	 1	 -30.0	 30.0;
	5938	 8433	 0.00053	 0.00589	 0.0	 1316.0	 5342	 5342	 0.0	 0.0	 1	 -30.0	 30.0;
	5938	 816	 0.00046	 0.00675	 0.0	 1119.0	 4669	 4669	 0.0	 0.0	 1	 -30.0	 30.0;
	8539	 8433	 0.00054	 0.00577	 0.0	 1316.0	 5451	 5451	 0.0	 0.0	 1	 -30.0	 30.0;
	8539	 816	 0.00045	 0.00625	 0.0	 1086.0	 5041	 5041	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 1544	 0.00275	 0.02752	 0.0	 1382.0	 1596	 1596	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 7674	 0.00184	 0.01515	 0.0	 1316.0	 2891	 2891	 0.0	 0.0	 1	 -30.0	 30.0;
	2323	 4150	 0.00438	 0.02432	 0.0	 1279	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	2323	 599	 0.0043	 0.01949	 0.0	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	8376	 6999	 0.00033	 0.00269	 0.0	 1218.0	 16279	 16279	 0.0	 0.0	 1	 -30.0	 30.0;
	8376	 4903	 0.00243	 0.01904	 0.0	 1119.0	 2299	 2299	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 6999	 0.00034	 0.00263	 0.0	 1119.0	 16637	 16637	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 4903	 0.00248	 0.01864	 0.0	 1086.0	 2347	 2347	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 6190	 0.00122	 0.01249	 0.0	 987.0	 2518	 2518	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 4055	 0.00106	 0.01031	 0.0	 1053.0	 3048	 3048	 0.0	 0.0	 1	 -30.0	 30.0;
	3313	 6190	 0.00119	 0.01273	 0.0	 987.0	 2471	 2471	 0.0	 0.0	 1	 -30.0	 30.0;
	3313	 4055	 0.00108	 0.01009	 0.0	 1086.0	 3113	 3113	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 4401	 0.001039	 0.013711	 0.0	 2298	 2298	 2298	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 5145	 0.00114	 0.011409	 0.0	 2755	 2755	 2755	 0.0	 0.0	 1	 -30.0	 30.0;
	7851	 5878	 0.001021	 0.013969	 0.0	 2256	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	7851	 5145	 0.001169	 0.011159	 0.0	 2816	 2816	 2816	 0.0	 0.0	 1	 -30.0	 30.0;
	8001	 8201	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	2322	 8201	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	843	 154	 0.009372	 0.035702	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	843	 3598	 0.029157	 0.103686	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	529	 5527	 0.00065	 0.00673	 0.0	 1514.0	 4672	 4672	 0.0	 0.0	 1	 -30.0	 30.0;
	529	 4164	 0.00066	 0.00658	 0.0	 1678.0	 4777	 4777	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 2487	 0.000969	 0.006021	 0.0	 553.0	 5180	 5180	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 4167	 0.00099	 0.005901	 0.0	 381.0	 5280	 5280	 0.0	 0.0	 1	 -30.0	 30.0;
	1162	 8598	 0.00088	 0.006599	 0.0	 4745	 4745	 4745	 0.0	 0.0	 1	 -30.0	 30.0;
	1162	 5325	 0.00086	 0.006729	 0.0	 495.0	 4657	 4657	 0.0	 0.0	 1	 -30.0	 30.0;
	8690	 3277	 9e-05	 0.00077	 0.0	 1711.0	 40746	 40746	 0.0	 0.0	 1	 -30.0	 30.0;
	8690	 4226	 9e-05	 0.00078	 0.0	 1580.0	 40230	 40230	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 3277	 8e-05	 0.00082	 0.0	 1481.0	 38340	 38340	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 7617	 8e-05	 0.00076	 0.0	 1251.0	 41334	 41334	 0.0	 0.0	 1	 -30.0	 30.0;
	6759	 5527	 9e-05	 0.00074	 0.0	 1613.0	 42374	 42374	 0.0	 0.0	 1	 -30.0	 30.0;
	6759	 4226	 9e-05	 0.00073	 0.0	 1251.0	 42946	 42946	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 2487	 0.00062	 0.003781	 0.0	 8245	 8245	 8245	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 782	 0.000599	 0.0035	 0.0	 553.0	 8896	 8896	 0.0	 0.0	 1	 -30.0	 30.0;
	6871	 8598	 0.00064	 0.00274	 0.0	 11227	 11227	 11227	 0.0	 0.0	 1	 -30.0	 30.0;
	6871	 1346	 0.000651	 0.00268	 0.0	 610.0	 11454	 11454	 0.0	 0.0	 1	 -30.0	 30.0;
	6813	 1369	 0.00055	 0.00685	 0.0	 1777.0	 4597	 4597	 0.0	 0.0	 1	 -30.0	 30.0;
	6813	 376	 0.00061	 0.00639	 0.0	 1843.0	 4921	 4921	 0.0	 0.0	 1	 -30.0	 30.0;
	6019	 5527	 0.00042	 0.00523	 0.0	 1514.0	 6021	 6021	 0.0	 0.0	 1	 -30.0	 30.0;
	6019	 8334	 0.00045	 0.00605	 0.0	 1481.0	 5207	 5207	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 3277	 0.0003	 0.00228	 0.0	 1448.0	 13736	 13736	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 8899	 0.00026	 0.00264	 0.0	 1218.0	 11908	 11908	 0.0	 0.0	 1	 -30.0	 30.0;
	3355	 9230	 0.00536	 0.03568	 0.0	 553.0	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	3355	 6287	 0.006091	 0.03549	 0.0	 572.0	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 9230	 0.006419	 0.033271	 0.0	 591.0	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 1481	 0.005789	 0.035901	 0.0	 610.0	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	6968	 1829	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6968	 7774	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7956	 9230	 0.008401	 0.04011	 0.0	 419.0	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	7956	 3197	 0.007831	 0.041531	 0.0	 419.0	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	7550	 667	 0.00575	 0.046461	 0.0	 572.0	 675	 675	 0.0	 0.0	 1	 -30.0	 30.0;
	7550	 1220	 0.006711	 0.04426	 0.0	 591.0	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	3615	 8731	 0.00036	 0.00485	 0.0	 6495	 6495	 6495	 0.0	 0.0	 1	 -30.0	 30.0;
	3615	 6246	 0.00042	 0.00415	 0.0	 7573	 7573	 7573	 0.0	 0.0	 1	 -30.0	 30.0;
	7031	 1679	 9e-05	 0.00069	 0.0	 1316.0	 45395	 45395	 0.0	 0.0	 1	 -30.0	 30.0;
	7031	 7420	 4e-05	 0.00036	 0.0	 1415.0	 87206	 87206	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 2502	 0.00055	 0.00569	 0.0	 1316.0	 5526	 5526	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 8556	 0.0007	 0.00767	 0.0	 1185.0	 4102	 4102	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 3885	 0.0013	 0.01299	 0.0	 1185.0	 2420	 2420	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 8322	 0.00092	 0.01031	 0.0	 1645.0	 4657	 4657	 0.0	 0.0	 1	 -30.0	 30.0;
	1095	 3885	 0.00158	 0.01496	 0.0	 1448.0	 2100	 2100	 0.0	 0.0	 1	 -30.0	 30.0;
	1095	 1132	 0.00123	 0.01309	 0.0	 1909.0	 2403	 2403	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 6639	 0.000599	 0.00274	 0.0	 533.0	 11263	 11263	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 7317	 0.0005	 0.00405	 0.0	 7741	 7741	 7741	 0.0	 0.0	 1	 -30.0	 30.0;
	2549	 7829	 0.003349	 0.02445	 0.0	 553.0	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	2549	 4951	 0.003281	 0.02493	 0.0	 553.0	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 3622	 0.00087	 0.01097	 0.0	 1251.0	 2871	 2871	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 8974	 0.00161	 0.01464	 0.0	 1349.0	 2145	 2145	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 3370	 0.0	 0.00046	 0.0	 757.0	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 3684	 0.00118	 0.01223	 0.0	 987.0	 2571	 2571	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 6710	 0.00045	 0.00364	 0.0	 1251.0	 8613	 8613	 0.0	 0.0	 1	 -30.0	 30.0;
	2380	 1952	 0.00714	 0.03393	 0.0	 912	 912	 912	 0.0	 0.0	 1	 -30.0	 30.0;
	2380	 7679	 0.00655	 0.036849	 0.0	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 7953	 0.00088	 0.00722	 0.0	 1810.0	 4343	 4343	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 6446	 0.00071	 0.00835	 0.0	 1909.0	 3770	 3770	 0.0	 0.0	 1	 -30.0	 30.0;
	6575	 7953	 0.00084	 0.00705	 0.0	 1843.0	 4450	 4450	 0.0	 0.0	 1	 -30.0	 30.0;
	6575	 8401	 0.00102	 0.00799	 0.0	 1613.0	 3922	 3922	 0.0	 0.0	 1	 -30.0	 30.0;
	6387	 5594	 0.003781	 0.029969	 0.0	 533.0	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	6387	 8145	 0.00386	 0.02969	 0.0	 533.0	 1056	 1056	 0.0	 0.0	 1	 -30.0	 30.0;
	6694	 8426	 0.00076	 0.00463	 0.0	 572.0	 6733	 6733	 0.0	 0.0	 1	 -30.0	 30.0;
	6694	 2887	 0.000711	 0.004841	 0.0	 572.0	 6456	 6456	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 9184	 0.00631	 0.034469	 0.0	 400.0	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 7410	 0.006169	 0.03512	 0.0	 419.0	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 5161	 0.002961	 0.017651	 0.0	 610.0	 1765	 1765	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 2887	 0.00299	 0.02462	 0.0	 591.0	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 9184	 0.002789	 0.011659	 0.0	 495.0	 2635	 2635	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 6718	 0.00249	 0.013211	 0.0	 476.0	 2350	 2350	 0.0	 0.0	 1	 -30.0	 30.0;
	4180	 9184	 0.002669	 0.016031	 0.0	 629.0	 1944	 1944	 0.0	 0.0	 1	 -30.0	 30.0;
	4180	 4702	 0.00261	 0.014841	 0.0	 629.0	 2097	 2097	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 9184	 0.00074	 0.004599	 0.0	 381.0	 6782	 6782	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 1971	 0.000719	 0.00468	 0.0	 438.0	 6672	 6672	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 4697	 3.5e-05	 0.000355	 0.0	 1251.0	 123677	 123677	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 4824	 3.5e-05	 0.000355	 0.0	 1251.0	 123677	 123677	 0.0	 0.0	 1	 -30.0	 30.0;
	1434	 246	 0.00511	 0.02949	 0.0	 419.0	 1056	 1056	 0.0	 0.0	 1	 -30.0	 30.0;
	1434	 5733	 0.007719	 0.044271	 0.0	 400.0	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	2936	 246	 0.004281	 0.022469	 0.0	 381.0	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	2936	 3103	 0.005961	 0.03382	 0.0	 457.0	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	4893	 6468	 0.00073	 0.01034	 0.0	 1678.0	 3048	 3048	 0.0	 0.0	 1	 -30.0	 30.0;
	4893	 6848	 0.00076	 0.00889	 0.0	 1843.0	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	2601	 2613	 0.005159	 0.025789	 0.0	 400.0	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	2601	 9073	 0.00549	 0.027711	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 2613	 0.00614	 0.01764	 0.0	 400.0	 1692	 1692	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 3198	 0.003229	 0.01788	 0.0	 1739	 1739	 1739	 0.0	 0.0	 1	 -30.0	 30.0;
	8381	 4795	 0.00053	 0.00587	 0.0	 1777.0	 5360	 5360	 0.0	 0.0	 1	 -30.0	 30.0;
	8381	 5562	 0.00055	 0.00666	 0.0	 1711.0	 4727	 4727	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 6652	 0.00326	 0.01388	 0.0	 2216	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 4064	 0.003081	 0.01488	 0.0	 2079	 2079	 2079	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 1716	 0.00051	 0.00614	 0.0	 5127	 5127	 5127	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 6246	 0.00043	 0.00406	 0.0	 7737	 7737	 7737	 0.0	 0.0	 1	 -30.0	 30.0;
	8028	 5930	 0.00761	 0.046031	 0.0	 438.0	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	8028	 9044	 0.00351	 0.01632	 0.0	 419.0	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 1610	 0.00031	 0.00495	 0.0	 1744.0	 6369	 6369	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 9133	 0.00043	 0.00485	 0.0	 1942.0	 6488	 6488	 0.0	 0.0	 1	 -30.0	 30.0;
	8751	 147	 0.00426	 0.027099	 0.0	 629.0	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	8751	 5885	 0.00437	 0.024969	 0.0	 591.0	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 7896	 0.005	 0.03932	 0.0	 419.0	 797	 797	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 7473	 0.006039	 0.036789	 0.0	 457.0	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 9122	 0.0009	 0.00893	 0.0	 1218.0	 4916	 4916	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 7314	 0.00286	 0.02156	 0.0	 1053.0	 2029	 2029	 0.0	 0.0	 1	 -30.0	 30.0;
	679	 147	 0.00418	 0.022729	 0.0	 629.0	 1367	 1367	 0.0	 0.0	 1	 -30.0	 30.0;
	679	 5677	 0.00405	 0.02231	 0.0	 629.0	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	7291	 4830	 0.00013	 0.00675	 0.0	 1645.0	 4679	 4679	 0.0	 0.0	 1	 -30.0	 30.0;
	7291	 1249	 0.00013	 0.00688	 0.0	 1678.0	 4591	 4591	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 4079	 0.00078	 0.01201	 0.0	 2625	 2625	 2625	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 6529	 0.00075	 0.01254	 0.0	 1777.0	 2515	 2515	 0.0	 0.0	 1	 -30.0	 30.0;
	2329	 5169	 0.00071	 0.00722	 0.0	 4354	 4354	 4354	 0.0	 0.0	 1	 -30.0	 30.0;
	2329	 4337	 0.00084	 0.0074	 0.0	 1876.0	 4242	 4242	 0.0	 0.0	 1	 -30.0	 30.0;
	4142	 8137	 0.00105	 0.0081	 0.0	 1053.0	 3868	 3868	 0.0	 0.0	 1	 -30.0	 30.0;
	4142	 7870	 0.00203	 0.01565	 0.0	 1119.0	 2002	 2002	 0.0	 0.0	 1	 -30.0	 30.0;
	8500	 1586	 0.00035	 0.00581	 0.0	 1876.0	 5427	 5427	 0.0	 0.0	 1	 -30.0	 30.0;
	8500	 2634	 0.00045	 0.00534	 0.0	 5895	 5895	 5895	 0.0	 0.0	 1	 -30.0	 30.0;
	7357	 7529	 8.1e-05	 0.001331	 0.0	 23689	 23689	 23689	 0.0	 0.0	 1	 -30.0	 30.0;
	7357	 6297	 0.00025	 0.001591	 0.0	 19614	 19614	 19614	 0.0	 0.0	 1	 -30.0	 30.0;
	6959	 2290	 0.00401	 0.026219	 0.0	 419.0	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	6959	 7473	 0.004669	 0.027521	 0.0	 419.0	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 8580	 0.00115	 0.01265	 0.0	 1086.0	 2487	 2487	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 1360	 0.00112	 0.0129	 0.0	 1086.0	 2440	 2440	 0.0	 0.0	 1	 -30.0	 30.0;
	7764	 5850	 0.00123	 0.01589	 0.0	 757.0	 1982	 1982	 0.0	 0.0	 1	 -30.0	 30.0;
	7764	 7870	 0.00054	 0.00484	 0.0	 1185.0	 6487	 6487	 0.0	 0.0	 1	 -30.0	 30.0;
	3778	 8172	 0.00401	 0.03961	 0.0	 794	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	3778	 3888	 0.002909	 0.01981	 0.0	 514.0	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 6145	 0.002211	 0.014419	 0.0	 438.0	 2166	 2166	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 3186	 0.002169	 0.013349	 0.0	 457.0	 2336	 2336	 0.0	 0.0	 1	 -30.0	 30.0;
	3651	 8580	 0.00055	 0.00508	 0.0	 1218.0	 6182	 6182	 0.0	 0.0	 1	 -30.0	 30.0;
	3651	 895	 0.00046	 0.00595	 0.0	 1448.0	 5294	 5294	 0.0	 0.0	 1	 -30.0	 30.0;
	6633	 7467	 0.00201	 0.00988	 0.0	 553.0	 3133	 3133	 0.0	 0.0	 1	 -30.0	 30.0;
	6633	 2200	 0.003401	 0.019099	 0.0	 572.0	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	1976	 680	 0.00028	 0.00308	 0.0	 1678.0	 10214	 10214	 0.0	 0.0	 1	 -30.0	 30.0;
	1976	 5674	 0.00038	 0.00307	 0.0	 1843.0	 10212	 10212	 0.0	 0.0	 1	 -30.0	 30.0;
	2435	 4208	 0.00044	 0.00577	 0.0	 757.0	 7624	 7624	 0.0	 0.0	 1	 -30.0	 30.0;
	2435	 2398	 0.00102	 0.01295	 0.0	 757.0	 3397	 3397	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 1653	 0.00085	 0.01005	 0.0	 1711.0	 3132	 3132	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 5498	 0.00073	 0.0097	 0.0	 1843.0	 3248	 3248	 0.0	 0.0	 1	 -30.0	 30.0;
	7646	 1884	 0.00139	 0.0126	 0.0	 1349.0	 2492	 2492	 0.0	 0.0	 1	 -30.0	 30.0;
	7646	 5503	 0.00117	 0.01389	 0.0	 1218.0	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	6574	 1506	 0.00076	 0.00908	 0.0	 1382.0	 3467	 3467	 0.0	 0.0	 1	 -30.0	 30.0;
	6574	 8562	 0.00137	 0.01338	 0.0	 1283.0	 3584	 3584	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 2588	 0.006	 0.0402	 0.0	 438.0	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 689	 0.005719	 0.03906	 0.0	 438.0	 801	 801	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 1884	 0.0007	 0.01065	 0.0	 856.0	 2960	 2960	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 2294	 0.00066	 0.01062	 0.0	 856.0	 2969	 2969	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 3146	 0.00153	 0.01695	 0.0	 1152.0	 2593	 2593	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 6098	 0.00083	 0.00925	 0.0	 1316.0	 4751	 4751	 0.0	 0.0	 1	 -30.0	 30.0;
	6060	 5289	 0.00033	 0.00101	 0.0	 823.0	 29729	 29729	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 5289	 0.00028	 0.00104	 0.0	 757.0	 29329	 29329	 0.0	 0.0	 1	 -30.0	 30.0;
	1049	 603	 0.00139	 0.0125	 0.0	 1283.0	 3508	 3508	 0.0	 0.0	 1	 -30.0	 30.0;
	1049	 8344	 0.00119	 0.01236	 0.0	 1119.0	 3553	 3553	 0.0	 0.0	 1	 -30.0	 30.0;
	2363	 8726	 0.010099	 0.05513	 0.0	 381.0	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	2363	 599	 0.00464	 0.027021	 0.0	 1153	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 3859	 0.002211	 0.012031	 0.0	 591.0	 2583	 2583	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 4064	 0.002479	 0.0115	 0.0	 572.0	 2686	 2686	 0.0	 0.0	 1	 -30.0	 30.0;
	5534	 8577	 0.030281	 0.058314	 0.0	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	5534	 7721	 0.028174	 0.054256	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	2579	 8577	 0.01114	 0.026231	 0.0	 1109	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	2579	 2178	 0.018157	 0.045248	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	6365	 353	 0.00369	 0.017159	 0.0	 1800	 1800	 1800	 0.0	 0.0	 1	 -30.0	 30.0;
	6365	 4810	 0.004909	 0.03018	 0.0	 1034	 1034	 1034	 0.0	 0.0	 1	 -30.0	 30.0;
	8641	 7285	 0.00408	 0.0056	 0.0	 1251.0	 6368	 6368	 0.0	 0.0	 1	 -30.0	 30.0;
	8641	 7674	 0.00301	 0.00925	 0.0	 1283.0	 4536	 4536	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 353	 0.001599	 0.00489	 0.0	 6140	 6140	 6140	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 6182	 0.00031	 0.00175	 0.0	 400.0	 17774	 17774	 0.0	 0.0	 1	 -30.0	 30.0;
	6154	 353	 0.00163	 0.004789	 0.0	 495.0	 6245	 6245	 0.0	 0.0	 1	 -30.0	 30.0;
	6154	 6182	 0.00031	 0.001789	 0.0	 400.0	 17398	 17398	 0.0	 0.0	 1	 -30.0	 30.0;
	3046	 3236	 0.00988	 0.063229	 0.0	 400.0	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	3046	 1575	 0.00114	 0.00638	 0.0	 400.0	 4874	 4874	 0.0	 0.0	 1	 -30.0	 30.0;
	681	 7081	 0.00065	 0.00755	 0.0	 1086.0	 4169	 4169	 0.0	 0.0	 1	 -30.0	 30.0;
	681	 6907	 0.00052	 0.00503	 0.0	 987.0	 6247	 6247	 0.0	 0.0	 1	 -30.0	 30.0;
	567	 7081	 0.00063	 0.0077	 0.0	 1086.0	 4089	 4089	 0.0	 0.0	 1	 -30.0	 30.0;
	567	 6907	 0.00053	 0.00493	 0.0	 921.0	 6371	 6371	 0.0	 0.0	 1	 -30.0	 30.0;
	2371	 3343	 0.00055	 0.00683	 0.0	 1645.0	 4610	 4610	 0.0	 0.0	 1	 -30.0	 30.0;
	2371	 8263	 0.00118	 0.01134	 0.0	 1382.0	 2771	 2771	 0.0	 0.0	 1	 -30.0	 30.0;
	6482	 3343	 0.00056	 0.00668	 0.0	 1942.0	 4713	 4713	 0.0	 0.0	 1	 -30.0	 30.0;
	6482	 8263	 0.0012	 0.0111	 0.0	 1349.0	 2830	 2830	 0.0	 0.0	 1	 -30.0	 30.0;
	6637	 8894	 0.0098	 0.01047	 0.0	 1020.0	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	6637	 3208	 0.00134	 0.01215	 0.0	 1086.0	 2585	 2585	 0.0	 0.0	 1	 -30.0	 30.0;
	6491	 8894	 0.00092	 0.01198	 0.0	 1283.0	 4012	 4012	 0.0	 0.0	 1	 -30.0	 30.0;
	6491	 2585	 0.00057	 0.00616	 0.0	 1283.0	 7132	 7132	 0.0	 0.0	 1	 -30.0	 30.0;
	8282	 7455	 0.00108	 0.01773	 0.0	 1547.0	 2714	 2714	 0.0	 0.0	 1	 -30.0	 30.0;
	8282	 3729	 0.00064	 0.01047	 0.0	 757.0	 3012	 3012	 0.0	 0.0	 1	 -30.0	 30.0;
	359	 9048	 0.002211	 0.013341	 0.0	 572.0	 2336	 2336	 0.0	 0.0	 1	 -30.0	 30.0;
	359	 96	 0.001901	 0.014229	 0.0	 591.0	 2201	 2201	 0.0	 0.0	 1	 -30.0	 30.0;
	6818	 743	 0.00193	 0.011771	 0.0	 400.0	 2649	 2649	 0.0	 0.0	 1	 -30.0	 30.0;
	6818	 8496	 0.00251	 0.014909	 0.0	 438.0	 2090	 2090	 0.0	 0.0	 1	 -30.0	 30.0;
	5038	 611	 6e-05	 0.00084	 0.0	 1448.0	 37509	 37509	 0.0	 0.0	 1	 -30.0	 30.0;
	5038	 1249	 6e-05	 0.00092	 0.0	 1448.0	 34262	 34262	 0.0	 0.0	 1	 -30.0	 30.0;
	8428	 5905	 0.00138	 0.010349	 0.0	 533.0	 3026	 3026	 0.0	 0.0	 1	 -30.0	 30.0;
	8428	 7464	 0.00156	 0.009151	 0.0	 533.0	 3403	 3403	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 5905	 0.001349	 0.010539	 0.0	 553.0	 2973	 2973	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 7464	 0.001591	 0.00895	 0.0	 514.0	 3475	 3475	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 4129	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 4507	 0.00057	 0.0071	 0.0	 1613.0	 4435	 4435	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 6246	 0.00057	 0.00697	 0.0	 1613.0	 4517	 4517	 0.0	 0.0	 1	 -30.0	 30.0;
	8431	 4122	 0.000969	 0.00743	 0.0	 629.0	 4216	 4216	 0.0	 0.0	 1	 -30.0	 30.0;
	8431	 4844	 0.00099	 0.007271	 0.0	 629.0	 4305	 4305	 0.0	 0.0	 1	 -30.0	 30.0;
	170	 4122	 0.00088	 0.00824	 0.0	 629.0	 3812	 3812	 0.0	 0.0	 1	 -30.0	 30.0;
	170	 4844	 0.00086	 0.008401	 0.0	 629.0	 3741	 3741	 0.0	 0.0	 1	 -30.0	 30.0;
	625	 3790	 0.00293	 0.01664	 0.0	 400.0	 1870	 1870	 0.0	 0.0	 1	 -30.0	 30.0;
	625	 7978	 0.008719	 0.05249	 0.0	 381.0	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	3308	 1723	 0.00057	 0.00627	 0.0	 856.0	 5018	 5018	 0.0	 0.0	 1	 -30.0	 30.0;
	3308	 7870	 0.00088	 0.00878	 0.0	 790.0	 3580	 3580	 0.0	 0.0	 1	 -30.0	 30.0;
	9042	 221	 0.00033	 0.00421	 0.0	 1909.0	 7480	 7480	 0.0	 0.0	 1	 -30.0	 30.0;
	9042	 8623	 0.00084	 0.00353	 0.0	 8706	 8706	 8706	 0.0	 0.0	 1	 -30.0	 30.0;
	425	 7526	 0.0001	 0.00119	 0.0	 1810.0	 26451	 26451	 0.0	 0.0	 1	 -30.0	 30.0;
	425	 5674	 0.0001	 0.0013	 0.0	 1613.0	 24227	 24227	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 8581	 9e-05	 0.00121	 0.0	 1514.0	 26034	 26034	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 4337	 0.0001	 0.00134	 0.0	 1251.0	 23508	 23508	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 3025	 0.00063	 0.01067	 0.0	 1514.0	 2956	 2956	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 2420	 0.00073	 0.00959	 0.0	 1514.0	 3285	 3285	 0.0	 0.0	 1	 -30.0	 30.0;
	7276	 3887	 0.002021	 0.030271	 0.0	 1042	 1042	 1042	 0.0	 0.0	 1	 -30.0	 30.0;
	7276	 5088	 0.00218	 0.02786	 0.0	 1131	 1131	 1131	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 3025	 0.00086	 0.00781	 0.0	 1580.0	 4021	 4021	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 4276	 0.00092	 0.00666	 0.0	 1514.0	 4699	 4699	 0.0	 0.0	 1	 -30.0	 30.0;
	5601	 3887	 0.003969	 0.0272	 0.0	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	5601	 5958	 0.00311	 0.029729	 0.0	 1057	 1057	 1057	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 3025	 0.00055	 0.00837	 0.0	 1283.0	 3766	 3766	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 9235	 0.00053	 0.0084	 0.0	 1415.0	 3753	 3753	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 3025	 0.00053	 0.00853	 0.0	 1316.0	 3696	 3696	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 9235	 0.00052	 0.00778	 0.0	 1415.0	 4052	 4052	 0.0	 0.0	 1	 -30.0	 30.0;
	7719	 3887	 0.0017	 0.008159	 0.0	 553.0	 3791	 3791	 0.0	 0.0	 1	 -30.0	 30.0;
	7719	 7843	 0.001729	 0.00799	 0.0	 3864	 3864	 3864	 0.0	 0.0	 1	 -30.0	 30.0;
	2269	 3887	 0.00176	 0.00781	 0.0	 591.0	 3946	 3946	 0.0	 0.0	 1	 -30.0	 30.0;
	2269	 7843	 0.00157	 0.008849	 0.0	 3515	 3515	 3515	 0.0	 0.0	 1	 -30.0	 30.0;
	786	 3887	 0.000219	 0.002229	 0.0	 14104	 14104	 14104	 0.0	 0.0	 1	 -30.0	 30.0;
	786	 5145	 0.000229	 0.00218	 0.0	 14411	 14411	 14411	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 3887	 0.000229	 0.00213	 0.0	 14745	 14745	 14745	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 5145	 0.000211	 0.002419	 0.0	 13009	 13009	 13009	 0.0	 0.0	 1	 -30.0	 30.0;
	4430	 3887	 0.00019	 0.00255	 0.0	 12353	 12353	 12353	 0.0	 0.0	 1	 -30.0	 30.0;
	4430	 5145	 0.000211	 0.0025	 0.0	 12591	 12591	 12591	 0.0	 0.0	 1	 -30.0	 30.0;
	8221	 3887	 0.0	 0.0002	 0.0	 495.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8221	 2175	 0.0	 0.0002	 0.0	 495.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1933	 7992	 0.00067	 0.01058	 0.0	 1316.0	 2980	 2980	 0.0	 0.0	 1	 -30.0	 30.0;
	1933	 7458	 0.00065	 0.01078	 0.0	 1185.0	 2925	 2925	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 265	 0.009281	 0.05299	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 7679	 0.009419	 0.057219	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 2392	 0.00055	 0.00505	 0.0	 6219	 6219	 6219	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 6297	 9.9e-05	 0.00164	 0.0	 19226	 19226	 19226	 0.0	 0.0	 1	 -30.0	 30.0;
	7686	 7992	 0.00064	 0.00998	 0.0	 1152.0	 3159	 3159	 0.0	 0.0	 1	 -30.0	 30.0;
	7686	 2368	 0.00216	 0.02943	 0.0	 1020.0	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 2154	 0.00039	 0.00474	 0.0	 1843.0	 6642	 6642	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 1747	 0.00045	 0.00467	 0.0	 1448.0	 6733	 6733	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 2154	 0.00052	 0.00567	 0.0	 1645.0	 5548	 5548	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 1689	 0.00054	 0.00667	 0.0	 1316.0	 4721	 4721	 0.0	 0.0	 1	 -30.0	 30.0;
	4470	 4417	 0.008909	 0.042349	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	4470	 8325	 0.00713	 0.03293	 0.0	 938	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	8883	 1429	 0.0021	 0.02015	 0.0	 1448.0	 1560	 1560	 0.0	 0.0	 1	 -30.0	 30.0;
	8883	 9183	 0.00177	 0.02084	 0.0	 1448.0	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 7393	 0.001461	 0.00781	 0.0	 3976	 3976	 3976	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 5911	 0.001651	 0.007651	 0.0	 4036	 4036	 4036	 0.0	 0.0	 1	 -30.0	 30.0;
	8674	 7393	 0.00168	 0.0075	 0.0	 4110	 4110	 4110	 0.0	 0.0	 1	 -30.0	 30.0;
	8674	 5911	 0.001719	 0.007341	 0.0	 4190	 4190	 4190	 0.0	 0.0	 1	 -30.0	 30.0;
	7931	 6967	 0.00626	 0.020771	 0.0	 381.0	 1457	 1457	 0.0	 0.0	 1	 -30.0	 30.0;
	7931	 6967	 0.00638	 0.02032	 0.0	 400.0	 1484	 1484	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 6314	 0.047983	 0.076364	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 1567	 0.010868	 0.039083	 0.0	 779	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 3472	 0.021851	 0.032364	 0.0	 809	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 3472	 0.075008	 0.121636	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3472	 5172	 0.049273	 0.084942	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	7150	 7131	 0.058521	 0.110017	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	7517	 6627	 0.012992	 0.052719	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	6627	 7517	 0.012727	 0.053752	 0.0	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 2474	 0.013341	 0.054169	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	4848	 5326	 0.014961	 0.083521	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	7141	 1649	 0.023653	 0.033603	 0.0	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	7141	 1649	 0.024099	 0.032876	 0.0	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	1649	 7517	 0.024934	 0.109579	 0.0	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	1649	 7517	 0.024397	 0.111653	 0.0	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	1649	 6023	 0.03414	 0.051058	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	6314	 5475	 0.018893	 0.029083	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	2474	 5657	 0.000581	 0.003081	 0.0	 476.0	 10075	 10075	 0.0	 0.0	 1	 -30.0	 30.0;
	2474	 5657	 0.0005	 0.002789	 0.0	 495.0	 11148	 11148	 0.0	 0.0	 1	 -30.0	 30.0;
	2474	 6505	 0.009281	 0.03489	 0.0	 381.0	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	5989	 2474	 0.006081	 0.034	 0.0	 438.0	 915	 915	 0.0	 0.0	 1	 -30.0	 30.0;
	5989	 2474	 0.00595	 0.034651	 0.0	 419.0	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	1700	 7141	 0.05019	 0.076339	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	7141	 3806	 0.05724	 0.101868	 0.0	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	8258	 7313	 0.0013	 0.01496	 0.0	 921.0	 2938	 2938	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 8258	 0.00108	 0.01115	 0.0	 1415.0	 3939	 3939	 0.0	 0.0	 1	 -30.0	 30.0;
	8258	 106	 0.00223	 0.02267	 0.0	 1349.0	 1937	 1937	 0.0	 0.0	 1	 -30.0	 30.0;
	7931	 6505	 0.008229	 0.03325	 0.0	 400.0	 923	 923	 0.0	 0.0	 1	 -30.0	 30.0;
	7931	 5976	 0.018159	 0.06526	 0.0	 419.0	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 9171	 0.02257	 0.034777	 0.0	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 2639	 0.032339	 0.103017	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 2639	 0.031678	 0.105041	 0.0	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 833	 0.028331	 0.050182	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 6314	 0.047314	 0.063678	 0.0	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	4848	 7204	 0.0045	 0.02618	 0.0	 419.0	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	4848	 5989	 0.01913	 0.10681	 0.0	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	8295	 7150	 0.059273	 0.08086	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	7981	 4155	 0.008041	 0.014298	 0.0	 1926	 1926	 1926	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 7981	 0.047802	 0.073562	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	3722	 1700	 0.049636	 0.058818	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	9171	 1567	 0.04738	 0.075992	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	6023	 8826	 0.035603	 0.045331	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 5172	 0.024529	 0.031678	 0.0	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	8891	 2897	 0.036851	 0.047521	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	6348	 8339	 0.004058	 0.011041	 0.0	 2686	 2686	 2686	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 6348	 0.012818	 0.022554	 0.0	 1218	 1218	 1218	 0.0	 0.0	 1	 -30.0	 30.0;
	4548	 1652	 0.079256	 0.118479	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 4548	 0.012554	 0.022967	 0.0	 1207	 1207	 1207	 0.0	 0.0	 1	 -30.0	 30.0;
	8339	 8102	 0.007917	 0.029628	 0.0	 1030	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	8339	 8102	 0.007744	 0.027438	 0.0	 1108	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 2500	 0.00039	 0.00461	 0.0	 757.0	 9536	 9536	 0.0	 0.0	 1	 -30.0	 30.0;
	7204	 273	 0.014039	 0.071669	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	7204	 273	 0.01251	 0.081219	 0.0	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	273	 5976	 0.0045	 0.016831	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	5989	 273	 0.00261	 0.009401	 0.0	 381.0	 3238	 3238	 0.0	 0.0	 1	 -30.0	 30.0;
	7205	 2639	 0.08024	 0.135628	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 7205	 0.043587	 0.057314	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	7204	 80	 0.00326	 0.01895	 0.0	 476.0	 1643	 1643	 0.0	 0.0	 1	 -30.0	 30.0;
	743	 80	 0.005409	 0.02675	 0.0	 400.0	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	4155	 3380	 0.083537	 0.116554	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	2546	 3380	 0.012463	 0.054793	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	833	 8826	 0.044992	 0.07586	 0.0	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 1652	 0.032777	 0.050628	 0.0	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	3806	 4649	 0.060314	 0.092818	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	8891	 8295	 0.02462	 0.034967	 0.0	 739	 739	 739	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 3722	 0.026603	 0.03038	 0.0	 783	 783	 783	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 5123	 0.01595	 0.022281	 0.0	 1153	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 5123	 0.018083	 0.021843	 0.0	 1114	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 5989	 0.0132	 0.06293	 0.0	 400.0	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 5989	 0.01345	 0.06162	 0.0	 400.0	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 3722	 0.010612	 0.023017	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 7548	 0.01601	 0.06706	 0.0	 419.0	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 5594	 0.00362	 0.01457	 0.0	 457.0	 2105	 2105	 0.0	 0.0	 1	 -30.0	 30.0;
	8101	 4775	 0.010281	 0.04007	 0.0	 419.0	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	8101	 9184	 0.01549	 0.06756	 0.0	 381.0	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 5177	 0.00073	 0.01141	 0.0	 1876.0	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 7992	 0.00108	 0.01698	 0.0	 1481.0	 1857	 1857	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 515	 0.0022	 0.027409	 0.0	 381.0	 1149	 1149	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 515	 0.002151	 0.02794	 0.0	 381.0	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 7597	 0.00445	 0.02582	 0.0	 629.0	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 265	 0.005099	 0.02426	 0.0	 629.0	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 1726	 0.019539	 0.100021	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 1726	 0.01914	 0.101979	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 2203	 0.00158	 0.02551	 0.0	 1236	 1236	 1236	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 4681	 0.00021	 0.00296	 0.0	 1382.0	 10645	 10645	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 5652	 0.00157	 0.02091	 0.0	 1507	 1507	 1507	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 4681	 0.00162	 0.02163	 0.0	 1457	 1457	 1457	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 4775	 0.008521	 0.03463	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 9184	 0.00463	 0.078531	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 9184	 0.004531	 0.072711	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 111	 0.00575	 0.02876	 0.0	 381.0	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 3152	 0.00411	 0.01826	 0.0	 438.0	 1688	 1688	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 1726	 0.008091	 0.03594	 0.0	 381.0	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	3826	 2026	 0.011031	 0.060581	 0.0	 419.0	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	3826	 5999	 0.01326	 0.07163	 0.0	 419.0	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	5069	 1829	 0.007031	 0.069341	 0.0	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	5069	 5594	 0.00238	 0.031081	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 9184	 0.010831	 0.057479	 0.0	 457.0	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 111	 0.001849	 0.01024	 0.0	 381.0	 3036	 3036	 0.0	 0.0	 1	 -30.0	 30.0;
	7548	 6762	 0.017581	 0.07664	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	7548	 6762	 0.017909	 0.07501	 0.0	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	7548	 5999	 0.01312	 0.05724	 0.0	 381.0	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	7548	 5999	 0.01337	 0.056021	 0.0	 400.0	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	7548	 555	 0.007961	 0.0347	 0.0	 419.0	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 9184	 0.01181	 0.044729	 0.0	 381.0	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 123	 0.00457	 0.018729	 0.0	 1639	 1639	 1639	 0.0	 0.0	 1	 -30.0	 30.0;
	8433	 8228	 0.0012	 0.0141	 0.0	 1283.0	 2233	 2233	 0.0	 0.0	 1	 -30.0	 30.0;
	8433	 8228	 0.00107	 0.01598	 0.0	 1283.0	 1973	 1973	 0.0	 0.0	 1	 -30.0	 30.0;
	8433	 2933	 0.00046	 0.00666	 0.0	 889.0	 4732	 4732	 0.0	 0.0	 1	 -30.0	 30.0;
	8433	 2772	 0.001	 0.0181	 0.0	 757.0	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 3702	 9.1e-05	 0.00139	 0.0	 22677	 22677	 22677	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 3702	 0.00013	 0.00089	 0.0	 35119	 35119	 35119	 0.0	 0.0	 1	 -30.0	 30.0;
	7597	 265	 0.000281	 0.001289	 0.0	 572.0	 23943	 23943	 0.0	 0.0	 1	 -30.0	 30.0;
	6962	 3508	 0.00119	 0.01964	 0.0	 1119.0	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	6962	 3508	 0.00117	 0.02001	 0.0	 1185.0	 1576	 1576	 0.0	 0.0	 1	 -30.0	 30.0;
	1829	 4207	 0.00238	 0.032341	 0.0	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	1829	 4207	 0.002331	 0.02994	 0.0	 1052	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	1829	 4842	 0.005479	 0.07155	 0.0	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 265	 0.008091	 0.036841	 0.0	 381.0	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 4842	 0.003081	 0.03707	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 555	 0.01086	 0.05936	 0.0	 438.0	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	2933	 958	 0.00063	 0.00975	 0.0	 823.0	 3233	 3233	 0.0	 0.0	 1	 -30.0	 30.0;
	9184	 8609	 0.00143	 0.025771	 0.0	 1224	 1224	 1224	 0.0	 0.0	 1	 -30.0	 30.0;
	9184	 8609	 0.001401	 0.026271	 0.0	 1201	 1201	 1201	 0.0	 0.0	 1	 -30.0	 30.0;
	9184	 123	 0.00631	 0.03037	 0.0	 400.0	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	2026	 5999	 0.00325	 0.01388	 0.0	 400.0	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	8609	 3702	 0.015461	 0.0828	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	8609	 3702	 0.017521	 0.08114	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	5652	 7992	 0.00036	 0.00554	 0.0	 1514.0	 5690	 5690	 0.0	 0.0	 1	 -30.0	 30.0;
	2772	 7992	 0.0018	 0.02089	 0.0	 1507	 1507	 1507	 0.0	 0.0	 1	 -30.0	 30.0;
	958	 7992	 0.00183	 0.02045	 0.0	 1539	 1539	 1539	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 458	 0.00052	 0.01489	 0.0	 921.0	 2121	 2121	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 458	 0.00051	 0.01518	 0.0	 757.0	 2080	 2080	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 5999	 0.020669	 0.110081	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 5999	 0.02024	 0.1122	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	298	 265	 0.01089	 0.05145	 0.0	 591.0	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	298	 265	 0.01111	 0.050401	 0.0	 553.0	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 1726	 0.00493	 0.026719	 0.0	 1163	 1163	 1163	 0.0	 0.0	 1	 -30.0	 30.0;
	3887	 7393	 0.005169	 0.067461	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3887	 7393	 0.00506	 0.068729	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 6876	 0.011397	 0.04438	 0.0	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	1926	 8412	 0.022504	 0.082851	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	1926	 3936	 0.015793	 0.061587	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	5718	 2613	 0.012659	 0.05405	 0.0	 381.0	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 4010	 0.016149	 0.057248	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	154	 4010	 0.038612	 0.122471	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	4010	 7187	 0.044273	 0.108959	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	8850	 5942	 0.038876	 0.139587	 0.0	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	8850	 6402	 0.10805	 0.191992	 0.0	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	3093	 8850	 0.035802	 0.084231	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 5168	 0.00614	 0.02205	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 6128	 0.003587	 0.01395	 0.0	 2193	 2193	 2193	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 7768	 0.019554	 0.05981	 0.0	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	6128	 3316	 0.038066	 0.142281	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 4326	 0.007421	 0.02181	 0.0	 1372	 1372	 1372	 0.0	 0.0	 1	 -30.0	 30.0;
	4326	 8176	 0.007562	 0.021339	 0.0	 1396	 1396	 1396	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 7589	 0.007388	 0.026537	 0.0	 1147	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	7589	 1674	 0.00724	 0.02705	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	73	 7086	 0.004893	 0.018273	 0.0	 1670	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	7086	 5551	 0.004777	 0.018612	 0.0	 1644	 1644	 1644	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 6346	 0.015289	 0.041463	 0.0	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 6346	 0.01143	 0.042091	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	73	 2704	 0.006793	 0.014182	 0.0	 2009	 2009	 2009	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 2704	 0.012967	 0.048471	 0.0	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 6346	 0.009281	 0.029554	 0.0	 1020	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6346	 0.041248	 0.116479	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 6346	 0.071479	 0.137678	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	2321	 6346	 0.020612	 0.075893	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 514	 0.05214	 0.100421	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 6346	 0.047942	 0.179157	 0.0	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	7262	 2512	 0.0016	 0.01402	 0.0	 1119.0	 2239	 2239	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 6140	 0.009149	 0.027992	 0.0	 1073	 1073	 1073	 0.0	 0.0	 1	 -30.0	 30.0;
	8622	 5910	 0.031107	 0.116281	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	8622	 5551	 0.026463	 0.091273	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 8622	 0.023562	 0.075017	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	4038	 8622	 0.015702	 0.050017	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 3316	 0.004802	 0.017231	 0.0	 1766	 1766	 1766	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 1219	 0.065579	 0.208826	 0.0	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 3490	 0.049917	 0.112843	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 136	 0.047793	 0.095603	 0.0	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	7390	 3316	 0.043421	 0.168942	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	7768	 3316	 0.029364	 0.093017	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	2911	 3820	 0.023521	 0.086562	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 3820	 0.017909	 0.058463	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	3757	 535	 0.008198	 0.030248	 0.0	 1008	 1008	 1008	 0.0	 0.0	 1	 -30.0	 30.0;
	535	 3105	 0.015579	 0.053744	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	535	 6003	 0.030471	 0.09738	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	2811	 535	 0.017157	 0.066	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1273	 4503	 0.017628	 0.065868	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1273	 5173	 0.022686	 0.072273	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	2219	 4307	 0.010322	 0.03719	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	4307	 7531	 0.010802	 0.038281	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	4982	 7187	 0.019298	 0.073041	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 4982	 0.011678	 0.035273	 0.0	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 4503	 0.019719	 0.057256	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	175	 730	 0.026421	 0.086471	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	8176	 1916	 0.014281	 0.045471	 0.0	 663	 663	 663	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 7038	 0.004529	 0.013686	 0.0	 2192	 2192	 2192	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 7531	 0.014603	 0.058463	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	6722	 5579	 0.007702	 0.020876	 0.0	 1420	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	6722	 3467	 0.010281	 0.03957	 0.0	 773	 773	 773	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 5064	 0.00686	 0.023661	 0.0	 1283	 1283	 1283	 0.0	 0.0	 1	 -30.0	 30.0;
	3757	 5070	 0.02457	 0.09557	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	19	 1219	 0.03024	 0.085372	 0.0	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	19	 7390	 0.04157	 0.14924	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	6029	 19	 0.028132	 0.097008	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	19	 8667	 0.038661	 0.123091	 0.0	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 8718	 0.019364	 0.077413	 0.0	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	8718	 3936	 0.009562	 0.036182	 0.0	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	7262	 5625	 0.00147	 0.01643	 0.0	 1415.0	 1915	 1915	 0.0	 0.0	 1	 -30.0	 30.0;
	701	 6216	 0.005719	 0.016826	 0.0	 1778	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	6216	 9177	 0.007843	 0.027041	 0.0	 1122	 1122	 1122	 0.0	 0.0	 1	 -30.0	 30.0;
	6216	 1290	 0.016826	 0.045628	 0.0	 650	 650	 650	 0.0	 0.0	 1	 -30.0	 30.0;
	6216	 2205	 0.02238	 0.062777	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 701	 0.012959	 0.041248	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	9177	 4387	 0.004702	 0.017562	 0.0	 1738	 1738	 1738	 0.0	 0.0	 1	 -30.0	 30.0;
	7713	 9177	 0.023331	 0.080446	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	1496	 974	 0.00505	 0.018653	 0.0	 1635	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	4356	 1496	 0.008562	 0.025686	 0.0	 1167	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	3491	 2958	 0.026124	 0.083149	 0.0	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	2958	 4767	 0.02038	 0.04605	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	7723	 6602	 0.000169	 0.00106	 0.0	 29428	 29428	 29428	 0.0	 0.0	 1	 -30.0	 30.0;
	963	 7723	 0.00043	 0.003901	 0.0	 8049	 8049	 8049	 0.0	 0.0	 1	 -30.0	 30.0;
	7968	 4636	 0.005298	 0.021	 0.0	 1459	 1459	 1459	 0.0	 0.0	 1	 -30.0	 30.0;
	4636	 7292	 0.001322	 0.004289	 0.0	 7038	 7038	 7038	 0.0	 0.0	 1	 -30.0	 30.0;
	6431	 1112	 0.005471	 0.016554	 0.0	 1812	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	6431	 4878	 0.022198	 0.064653	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	4791	 2761	 0.027653	 0.099256	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	2625	 4791	 0.044099	 0.152107	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 3167	 0.017603	 0.047711	 0.0	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 4356	 0.024198	 0.06562	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	8371	 3622	 0.00165	 0.01428	 0.0	 1283.0	 3353	 3353	 0.0	 0.0	 1	 -30.0	 30.0;
	7285	 8371	 0.00131	 0.01467	 0.0	 1152.0	 2996	 2996	 0.0	 0.0	 1	 -30.0	 30.0;
	5942	 8941	 0.040802	 0.129909	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	945	 2761	 0.005058	 0.019686	 0.0	 1555	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	2761	 1388	 0.075521	 0.145463	 0.0	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	945	 5196	 0.024033	 0.088488	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	7568	 4935	 0.001599	 0.007401	 0.0	 438.0	 4172	 4172	 0.0	 0.0	 1	 -30.0	 30.0;
	1290	 8412	 0.025289	 0.082934	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	8837	 7390	 0.012421	 0.035058	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	3236	 2738	 0.00855	 0.03774	 0.0	 457.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 5207	 0.010686	 0.03019	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 6176	 0.010331	 0.03438	 0.0	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6547	 0.01581	 0.050339	 0.0	 599	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	7968	 4878	 0.005661	 0.022744	 0.0	 1348	 1348	 1348	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 8398	 0.000636	 0.002512	 0.0	 12190	 12190	 12190	 0.0	 0.0	 1	 -30.0	 30.0;
	3936	 5834	 0.005281	 0.017521	 0.0	 1727	 1727	 1727	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 2823	 0.002826	 0.00781	 0.0	 3804	 3804	 3804	 0.0	 0.0	 1	 -30.0	 30.0;
	1112	 4996	 0.018066	 0.056876	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 5173	 0.038537	 0.144033	 0.0	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 1252	 0.049669	 0.141083	 0.0	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 7292	 0.058628	 0.17286	 0.0	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 6054	 0.00043	 0.001273	 0.0	 23509	 23509	 23509	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 6896	 0.025917	 0.093058	 0.0	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	1733	 4172	 0.02295	 0.065	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	5975	 5173	 0.001504	 0.00486	 0.0	 6209	 6209	 6209	 0.0	 0.0	 1	 -30.0	 30.0;
	5975	 5173	 0.002182	 0.006678	 0.0	 4497	 4497	 4497	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 963	 0.002979	 0.02218	 0.0	 1412	 1412	 1412	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 963	 0.003021	 0.022531	 0.0	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 4038	 0.020843	 0.058843	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 406	 0.009331	 0.027413	 0.0	 1091	 1091	 1091	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 6913	 0.009182	 0.024769	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 353	 0.00275	 0.01488	 0.0	 476.0	 2088	 2088	 0.0	 0.0	 1	 -30.0	 30.0;
	6688	 2992	 0.0001	 0.00082	 0.0	 1152.0	 53407	 53407	 0.0	 0.0	 1	 -30.0	 30.0;
	5930	 963	 0.01476	 0.08713	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	5930	 4935	 0.00212	 0.011469	 0.0	 400.0	 2709	 2709	 0.0	 0.0	 1	 -30.0	 30.0;
	7292	 6595	 0.013521	 0.049959	 0.0	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	6595	 974	 0.017793	 0.07124	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	8612	 2613	 0.01481	 0.086021	 0.0	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 8612	 0.01686	 0.07207	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	7531	 5660	 0.012331	 0.034413	 0.0	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 5660	 0.000777	 0.00276	 0.0	 11017	 11017	 11017	 0.0	 0.0	 1	 -30.0	 30.0;
	3222	 154	 0.028421	 0.08657	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	1916	 4618	 0.023521	 0.081132	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	3574	 2620	 0.000901	 0.005	 0.0	 438.0	 6218	 6218	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 3098	 0.00263	 0.01551	 0.0	 419.0	 2008	 2008	 0.0	 0.0	 1	 -30.0	 30.0;
	7176	 3179	 0.017463	 0.071669	 0.0	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	7176	 8805	 0.016826	 0.065512	 0.0	 468	 468	 468	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 3856	 0.019587	 0.076612	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	1382	 1304	 0.022537	 0.071769	 0.0	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 175	 0.013256	 0.04005	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 3222	 0.046397	 0.13586	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 573	 0.026471	 0.105893	 0.0	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	8557	 7241	 0.025504	 0.08119	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	4934	 8557	 0.027603	 0.10738	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	7187	 3801	 0.084843	 0.156942	 0.0	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 3105	 0.030521	 0.115653	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 8031	 0.004	 0.010851	 0.0	 2732	 2732	 2732	 0.0	 0.0	 1	 -30.0	 30.0;
	8031	 5207	 0.016017	 0.043421	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 1904	 0.027091	 0.087488	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	7421	 6938	 0.02243	 0.047793	 0.0	 599	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	7768	 6938	 0.016851	 0.051537	 0.0	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	8398	 8412	 0.01638	 0.053901	 0.0	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	8398	 8412	 0.012298	 0.045521	 0.0	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	8412	 6866	 0.025017	 0.048653	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	3467	 8914	 0.00186	 0.007174	 0.0	 4263	 4263	 4263	 0.0	 0.0	 1	 -30.0	 30.0;
	2969	 8914	 0.001397	 0.005372	 0.0	 5691	 5691	 5691	 0.0	 0.0	 1	 -30.0	 30.0;
	2205	 4387	 0.010777	 0.043479	 0.0	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	6378	 2205	 0.016413	 0.047628	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	1451	 5516	 0.004	 0.011281	 0.0	 2640	 2640	 2640	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 5516	 0.004041	 0.015099	 0.0	 2021	 2021	 2021	 0.0	 0.0	 1	 -30.0	 30.0;
	3467	 8447	 0.004636	 0.017579	 0.0	 1738	 1738	 1738	 0.0	 0.0	 1	 -30.0	 30.0;
	8447	 5173	 0.006529	 0.025091	 0.0	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	6547	 3467	 0.01781	 0.052339	 0.0	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	1451	 2969	 0.003744	 0.010149	 0.0	 2921	 2921	 2921	 0.0	 0.0	 1	 -30.0	 30.0;
	6650	 5173	 0.006248	 0.023702	 0.0	 1289	 1289	 1289	 0.0	 0.0	 1	 -30.0	 30.0;
	6650	 6402	 0.035107	 0.106207	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	6650	 8972	 0.014769	 0.045182	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	6650	 3398	 0.004322	 0.012198	 0.0	 2441	 2441	 2441	 0.0	 0.0	 1	 -30.0	 30.0;
	6650	 6896	 0.015678	 0.054083	 0.0	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 8837	 0.011331	 0.023636	 0.0	 1206	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	963	 6602	 0.000591	 0.002969	 0.0	 400.0	 10435	 10435	 0.0	 0.0	 1	 -30.0	 30.0;
	963	 6602	 0.000281	 0.0025	 0.0	 12556	 12556	 12556	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 6602	 0.00781	 0.039159	 0.0	 792	 792	 792	 0.0	 0.0	 1	 -30.0	 30.0;
	6602	 1125	 0.00419	 0.02431	 0.0	 419.0	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	353	 6602	 0.014479	 0.06989	 0.0	 381.0	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	353	 6602	 0.013419	 0.07594	 0.0	 400.0	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	3622	 4022	 0.00208	 0.02183	 0.0	 1053.0	 1441	 1441	 0.0	 0.0	 1	 -30.0	 30.0;
	7241	 3801	 0.028083	 0.103397	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	6003	 2219	 0.005793	 0.017802	 0.0	 1688	 1688	 1688	 0.0	 0.0	 1	 -30.0	 30.0;
	8941	 8972	 0.016124	 0.049322	 0.0	 609	 609	 609	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 3490	 0.018471	 0.041802	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 1068	 0.031719	 0.066198	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	209	 1733	 0.017554	 0.056124	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	6089	 1252	 0.011207	 0.037917	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	2613	 3574	 0.02261	 0.105521	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 4934	 0.002397	 0.013603	 0.0	 2287	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	4934	 514	 0.021901	 0.055818	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	3491	 3801	 0.007719	 0.030066	 0.0	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 2321	 0.017711	 0.05	 0.0	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 3801	 0.035322	 0.070802	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 6029	 0.017281	 0.050777	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 5235	 0.04324	 0.168223	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	6054	 4596	 0.022678	 0.082017	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 2811	 0.026	 0.079537	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	5404	 6899	 0.027347	 0.080372	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 5404	 0.023364	 0.074372	 0.0	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	8577	 3093	 0.011421	 0.02757	 0.0	 1059	 1059	 1059	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 3574	 0.011039	 0.047169	 0.0	 653	 653	 653	 0.0	 0.0	 1	 -30.0	 30.0;
	1125	 3574	 0.015159	 0.0732	 0.0	 381.0	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	2682	 3574	 0.00119	 0.005729	 0.0	 381.0	 5399	 5399	 0.0	 0.0	 1	 -30.0	 30.0;
	7695	 3574	 0.00182	 0.060349	 0.0	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	7292	 3856	 0.00795	 0.032132	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	855	 7292	 0.006372	 0.021934	 0.0	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	2625	 7292	 0.015992	 0.036041	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	7292	 4356	 0.022843	 0.087157	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	7591	 2911	 0.00495	 0.014942	 0.0	 2007	 2007	 2007	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 7591	 0.000901	 0.00238	 0.0	 12413	 12413	 12413	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 7591	 0.008942	 0.027339	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 2911	 0.00476	 0.017587	 0.0	 1734	 1734	 1734	 0.0	 0.0	 1	 -30.0	 30.0;
	6899	 2911	 0.037339	 0.128802	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 4905	 0.00081	 0.00219	 0.0	 13528	 13528	 13528	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 4439	 0.005132	 0.018438	 0.0	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	4367	 3856	 0.005934	 0.023107	 0.0	 1325	 1325	 1325	 0.0	 0.0	 1	 -30.0	 30.0;
	4367	 3856	 0.005802	 0.021397	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	4367	 226	 0.000463	 0.001421	 0.0	 21136	 21136	 21136	 0.0	 0.0	 1	 -30.0	 30.0;
	4367	 6089	 0.000909	 0.002521	 0.0	 11787	 11787	 11787	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 4439	 0.009347	 0.025364	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	9175	 4905	 0.00062	 0.002017	 0.0	 14970	 14970	 14970	 0.0	 0.0	 1	 -30.0	 30.0;
	226	 9175	 0.000917	 0.002364	 0.0	 12458	 12458	 12458	 0.0	 0.0	 1	 -30.0	 30.0;
	9175	 2625	 0.009248	 0.016446	 0.0	 1675	 1675	 1675	 0.0	 0.0	 1	 -30.0	 30.0;
	6089	 2671	 0.00295	 0.008	 0.0	 3705	 3705	 3705	 0.0	 0.0	 1	 -30.0	 30.0;
	2625	 6089	 0.003339	 0.012612	 0.0	 2422	 2422	 2422	 0.0	 0.0	 1	 -30.0	 30.0;
	2625	 2671	 0.00319	 0.012504	 0.0	 2448	 2448	 2448	 0.0	 0.0	 1	 -30.0	 30.0;
	855	 2625	 0.007826	 0.030521	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	7105	 4022	 0.00063	 0.00702	 0.0	 987.0	 4482	 4482	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 5625	 0.00184	 0.02018	 0.0	 1086.0	 1559	 1559	 0.0	 0.0	 1	 -30.0	 30.0;
	1453	 6074	 0.003818	 0.010661	 0.0	 2790	 2790	 2790	 0.0	 0.0	 1	 -30.0	 30.0;
	7531	 1453	 0.008678	 0.025198	 0.0	 1186	 1186	 1186	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 1453	 0.008843	 0.024661	 0.0	 1206	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	136	 6866	 0.023347	 0.041909	 0.0	 659	 659	 659	 0.0	 0.0	 1	 -30.0	 30.0;
	8667	 5207	 0.018091	 0.055347	 0.0	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	7258	 1382	 0.03443	 0.093347	 0.0	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	7258	 8805	 0.041033	 0.111248	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	8205	 7713	 0.015843	 0.05686	 0.0	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 8205	 0.020397	 0.064959	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	209	 5235	 0.017893	 0.054959	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 6074	 0.029496	 0.09295	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	9229	 8398	 0.011579	 0.046397	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	7695	 3236	 0.00099	 0.0042	 0.0	 381.0	 7321	 7321	 0.0	 0.0	 1	 -30.0	 30.0;
	7695	 3236	 0.00076	 0.00449	 0.0	 381.0	 6937	 6937	 0.0	 0.0	 1	 -30.0	 30.0;
	8841	 1428	 0.006587	 0.016868	 0.0	 1745	 1745	 1745	 0.0	 0.0	 1	 -30.0	 30.0;
	1428	 6074	 0.016876	 0.064909	 0.0	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	8841	 5070	 0.036612	 0.115372	 0.0	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 3936	 0.009421	 0.030826	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	9229	 3936	 0.008041	 0.030438	 0.0	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 6913	 0.000744	 0.002182	 0.0	 13702	 13702	 13702	 0.0	 0.0	 1	 -30.0	 30.0;
	7695	 4354	 0.000901	 0.003979	 0.0	 7743	 7743	 7743	 0.0	 0.0	 1	 -30.0	 30.0;
	7695	 3098	 0.01212	 0.05176	 0.0	 381.0	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	6688	 5625	 0.00256	 0.02765	 0.0	 1316.0	 1736	 1736	 0.0	 0.0	 1	 -30.0	 30.0;
	2823	 7421	 0.00224	 0.007256	 0.0	 4160	 4160	 4160	 0.0	 0.0	 1	 -30.0	 30.0;
	8894	 5625	 0.0009	 0.00943	 0.0	 1316.0	 3335	 3335	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 9229	 0.007744	 0.024273	 0.0	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	7421	 9229	 0.006372	 0.017992	 0.0	 1655	 1655	 1655	 0.0	 0.0	 1	 -30.0	 30.0;
	8805	 7768	 0.048554	 0.142669	 0.0	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	3398	 8972	 0.010802	 0.030488	 0.0	 977	 977	 977	 0.0	 0.0	 1	 -30.0	 30.0;
	6378	 4575	 0.015496	 0.047397	 0.0	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	7531	 6074	 0.010207	 0.030826	 0.0	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	6074	 4575	 0.026504	 0.077876	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	3097	 659	 0.00073	 0.00905	 0.0	 1185.0	 3480	 3480	 0.0	 0.0	 1	 -30.0	 30.0;
	9024	 4929	 0.00192	 0.02296	 0.0	 889.0	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 6542	 0.01431	 0.05899	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	6542	 1445	 0.02607	 0.07168	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6833	 0.00054	 0.00465	 0.0	 1580.0	 6748	 6748	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 2268	 0.00126	 0.01124	 0.0	 1613.0	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 7180	 0.00048	 0.00527	 0.0	 1547.0	 5970	 5970	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6293	 0.00082	 0.00938	 0.0	 1580.0	 3355	 3355	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 9192	 0.00028	 0.003502	 0.0	 8992	 8992	 8992	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 3493	 0.691467	 4.414711	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 955	 0.02004	 0.0916	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 228	 0.841911	 4.768444	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 6826	 0.026	 0.08948	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 8964	 0.002631	 0.011889	 0.0	 299.0	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 5776	 0.7232	 1.944	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	9192	 955	 0.156169	 0.546756	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	9192	 6826	 0.168809	 0.580622	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	9192	 8964	 0.019222	 0.068209	 0.0	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 1616	 0.00039	 0.00386	 0.0	 1415.0	 8142	 8142	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 1163	 0.00096	 0.01138	 0.0	 1448.0	 2766	 2766	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 9064	 0.00037	 0.00325	 0.0	 1415.0	 9657	 9657	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 8921	 0.00029	 0.00339	 0.0	 1580.0	 9284	 9284	 0.0	 0.0	 1	 -30.0	 30.0;
	3493	 2299	 0.009458	 0.158871	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	2299	 4423	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6826	 2299	 0.312951	 7.130667	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 2299	 0.247649	 1.075911	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 2299	 0.06056	 0.18612	 0.0	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 2299	 2.142489	 4.347733	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 2299	 0.07132	 1.068889	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 2299	 0.02268	 0.08652	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 2299	 2.007778	 4.494222	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 2299	 0.006178	 0.028938	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 2299	 0.027711	 0.260951	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	3493	 5587	 0.0	 0.000222	 0.0	 299.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4586	 3493	 0.00692	 0.337378	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 3493	 0.025991	 0.10048	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	6826	 3493	 0.083711	 0.8648	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 3493	 0.447378	 1.862089	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 3493	 0.062169	 0.153191	 0.0	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 3493	 2.492533	 4.725778	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 3493	 0.020271	 0.08244	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 3493	 0.11416	 1.777556	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 3493	 0.574978	 2.992578	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 3493	 1.887067	 4.964444	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 3493	 0.250778	 0.817422	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 3493	 0.007049	 0.029609	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 4586	 0.003049	 0.020218	 0.0	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 4586	 0.002911	 0.020262	 0.0	 1544	 1544	 1544	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 2870	 4e-05	 0.00041	 0.0	 757.0	 76679	 76679	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 659	 0.00087	 0.01087	 0.0	 1283.0	 2897	 2897	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 1037	 4e-05	 0.00046	 0.0	 757.0	 68410	 68410	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 659	 0.00095	 0.00924	 0.0	 1481.0	 3401	 3401	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 5210	 0.528017	 2.636157	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 1445	 0.032031	 0.128659	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 7762	 0.00044	 0.0032	 0.0	 1645.0	 9780	 9780	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 2520	 0.00046	 0.00489	 0.0	 1711.0	 6432	 6432	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 7762	 0.0003	 0.00352	 0.0	 1580.0	 8942	 8942	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 89	 0.00051	 0.00454	 0.0	 1645.0	 6915	 6915	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 659	 0.00068	 0.00746	 0.0	 1613.0	 4217	 4217	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 8605	 0.00093	 0.01022	 0.0	 1744.0	 3079	 3079	 0.0	 0.0	 1	 -30.0	 30.0;
	8605	 1367	 4e-05	 0.0004	 0.0	 1481.0	 78577	 78577	 0.0	 0.0	 1	 -30.0	 30.0;
	8605	 8921	 0.00078	 0.00698	 0.0	 1744.0	 4498	 4498	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 1676	 4e-05	 0.00043	 0.0	 1580.0	 73144	 73144	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 7051	 0.00025	 0.00309	 0.0	 1678.0	 10190	 10190	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 7762	 0.00047	 0.00538	 0.0	 1613.0	 5849	 5849	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 7762	 0.00046	 0.00548	 0.0	 1744.0	 5744	 5744	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 5996	 0.00016	 0.00173	 0.0	 1843.0	 18181	 18181	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 6293	 0.00166	 0.01471	 0.0	 1744.0	 2134	 2134	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 7762	 0.00051	 0.00512	 0.0	 1777.0	 6140	 6140	 0.0	 0.0	 1	 -30.0	 30.0;
	6704	 8921	 0.00021	 0.00248	 0.0	 1514.0	 12692	 12692	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 4586	 0.004391	 0.021689	 0.0	 286.0	 1428	 1428	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 6293	 0.00024	 0.00289	 0.0	 1645.0	 10893	 10893	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 3506	 0.0	 0.000222	 0.0	 338.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 8964	 0.01788	 0.100471	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	3506	 2908	 0.006458	 0.039982	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 6826	 0.106151	 0.993333	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 5776	 0.699778	 3.232311	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	8964	 6826	 0.257058	 0.43592	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 6826	 0.002769	 0.011449	 0.0	 2682	 2682	 2682	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 8329	 0.00034	 0.00305	 0.0	 1580.0	 10293	 10293	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 7051	 0.00123	 0.01255	 0.0	 1843.0	 2505	 2505	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 9239	 6e-05	 0.00065	 0.0	 1415.0	 48391	 48391	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 7960	 6e-05	 0.00063	 0.0	 1514.0	 49913	 49913	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 6233	 6e-05	 0.00055	 0.0	 1744.0	 57093	 57093	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 5416	 0.00079	 0.00968	 0.0	 1349.0	 3253	 3253	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 6798	 7e-05	 0.00079	 0.0	 39828	 39828	 39828	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 3279	 0.0	 0.000222	 0.0	 377.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 792	 2.064178	 7.545333	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	7279	 792	 0.153711	 0.482489	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 792	 0.015809	 0.12368	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 792	 0.057978	 0.363422	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 792	 0.6932	 2.196889	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 792	 0.560356	 2.395867	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 2267	 0.00024	 0.00213	 0.0	 757.0	 14737	 14737	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 7637	 0.00093	 0.00884	 0.0	 1283.0	 3554	 3554	 0.0	 0.0	 1	 -30.0	 30.0;
	8964	 2168	 0.0	 0.000222	 0.0	 312.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3659	 5996	 0.00018	 0.00204	 0.0	 1777.0	 15425	 15425	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 5996	 0.00018	 0.00208	 0.0	 757.0	 15130	 15130	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 5097	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 3242	 0.02068	 0.093391	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 3242	 0.777778	 7.408	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 7279	 0.00884	 0.07292	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 3242	 0.131671	 8.295556	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 1611	 0.082462	 0.568222	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 1611	 0.0042	 0.02624	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 8179	 0.00031	 0.00317	 0.0	 1251.0	 9918	 9918	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 7762	 0.00043	 0.00498	 0.0	 1481.0	 6320	 6320	 0.0	 0.0	 1	 -30.0	 30.0;
	9025	 7762	 0.00042	 0.00508	 0.0	 1711.0	 6197	 6197	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 4427	 0.110671	 0.773067	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 7279	 0.00912	 0.037609	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 8335	 0.098049	 0.598711	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 5155	 0.019031	 1.160356	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 271	 0.024071	 0.915733	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 7563	 1.484267	 4.479111	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 7563	 0.011578	 0.063271	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 7563	 0.654889	 1.839111	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 1611	 0.022049	 0.10076	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 7279	 0.459867	 2.604711	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 8335	 2.320222	 6.088	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 5155	 0.006369	 0.048089	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 271	 0.006631	 0.0432	 0.0	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 4427	 2.567244	 6.767111	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 4427	 0.309889	 1.214178	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 4427	 0.009191	 0.043289	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 1611	 0.691022	 5.239556	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 1445	 0.002669	 0.01718	 0.0	 1817	 1817	 1817	 0.0	 0.0	 1	 -30.0	 30.0;
	8179	 5509	 0.00074	 0.00694	 0.0	 1251.0	 4526	 4526	 0.0	 0.0	 1	 -30.0	 30.0;
	8179	 7762	 0.00068	 0.008	 0.0	 1547.0	 3935	 3935	 0.0	 0.0	 1	 -30.0	 30.0;
	7279	 4014	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 7279	 0.00524	 0.030631	 0.0	 1017	 1017	 1017	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 7279	 0.33932	 3.814667	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 7279	 0.22696	 2.614933	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 7279	 0.190671	 0.719378	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 7279	 1.050222	 2.105556	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 7279	 1.431644	 4.294578	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 7279	 0.022618	 0.161089	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 1579	 0.00088	 0.00895	 0.0	 1810.0	 3513	 3513	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 1531	 0.0	 0.000222	 0.0	 299.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 8335	 1.827778	 7.768	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 8335	 0.020849	 0.153382	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 8335	 0.156231	 0.656267	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 8335	 0.176498	 0.891556	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	7762	 2268	 0.00067	 0.00777	 0.0	 1613.0	 4051	 4051	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 271	 0.004578	 0.061889	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 2908	 0.01348	 0.05932	 0.0	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 5155	 0.066391	 2.802622	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 5155	 0.194258	 2.220444	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 1611	 0.008151	 0.072822	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 2908	 0.016502	 0.055382	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 271	 0.0806	 4.633778	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 271	 0.831556	 3.729644	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 1611	 0.007951	 0.074151	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	1579	 5848	 0.0004	 0.00362	 0.0	 1613.0	 8673	 8673	 0.0	 0.0	 1	 -30.0	 30.0;
	7051	 8847	 0.00015	 0.00177	 0.0	 1580.0	 17783	 17783	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 8229	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	317	 6233	 2e-05	 0.00022	 0.0	 1678.0	 142990	 142990	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 2449	 0.02864	 0.172902	 0.0	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 4495	 0.017591	 0.1404	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 4495	 0.00752	 0.031711	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 8420	 0.0	 0.000222	 0.0	 546.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 2283	 0.032587	 0.058388	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	636	 2283	 0.029752	 0.070686	 0.0	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 4008	 0.00699	 0.04244	 0.0	 476.0	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 7532	 0.0008	 0.006081	 0.0	 5151	 5151	 5151	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 6006	 0.004669	 0.041919	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 6006	 0.00476	 0.04106	 0.0	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	6999	 2041	 0.00146	 0.0163	 0.0	 1316.0	 2946	 2946	 0.0	 0.0	 1	 -30.0	 30.0;
	6999	 2041	 0.00098	 0.01485	 0.0	 1218.0	 3239	 3239	 0.0	 0.0	 1	 -30.0	 30.0;
	6999	 2041	 0.00143	 0.01661	 0.0	 1119.0	 2891	 2891	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 6999	 0.00209	 0.0241	 0.0	 1909.0	 1993	 1993	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 6999	 0.00273	 0.02677	 0.0	 1448.0	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 6999	 0.00279	 0.02623	 0.0	 1251.0	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 815	 0.007479	 0.032207	 0.0	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 2127	 0.04319	 0.16186	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	1617	 3294	 0.007256	 0.029702	 0.0	 1034	 1034	 1034	 0.0	 0.0	 1	 -30.0	 30.0;
	3294	 6055	 0.006488	 0.036041	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	3788	 4558	 0.028653	 0.066364	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	7112	 3788	 0.010463	 0.027446	 0.0	 1076	 1076	 1076	 0.0	 0.0	 1	 -30.0	 30.0;
	1438	 3173	 0.012409	 0.071919	 0.0	 400.0	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	1438	 3173	 0.012659	 0.07045	 0.0	 438.0	 442	 442	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 9125	 0.003419	 0.02344	 0.0	 419.0	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 7432	 0.002469	 0.01486	 0.0	 2097	 2097	 2097	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 5497	 0.00682	 0.03368	 0.0	 457.0	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 921	 0.02036	 0.09743	 0.0	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 3765	 0.048	 0.080331	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 3420	 0.00262	 0.008083	 0.0	 3718	 3718	 3718	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 6537	 0.004107	 0.023083	 0.0	 1348	 1348	 1348	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 7991	 0.003207	 0.015719	 0.0	 1969	 1969	 1969	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 716	 0.004727	 0.02143	 0.0	 1440	 1440	 1440	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 3861	 0.004041	 0.012702	 0.0	 2370	 2370	 2370	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 2559	 0.017802	 0.037777	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 5424	 0.002934	 0.014273	 0.0	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	3641	 2922	 0.006231	 0.032174	 0.0	 964	 964	 964	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 2937	 0.026876	 0.085248	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 6367	 0.050636	 0.099223	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 3329	 0.045347	 0.092	 0.0	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 3329	 0.005231	 0.013504	 0.0	 2182	 2182	 2182	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 8659	 0.024752	 0.057446	 0.0	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 7932	 0.015083	 0.065182	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 8925	 0.03986	 0.070686	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 1499	 0.036231	 0.064248	 0.0	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 4684	 0.004537	 0.022041	 0.0	 1404	 1404	 1404	 0.0	 0.0	 1	 -30.0	 30.0;
	9111	 7560	 0.052603	 0.157802	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	8925	 7560	 0.005562	 0.024083	 0.0	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	8925	 7560	 0.005446	 0.024554	 0.0	 1256	 1256	 1256	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 7560	 0.009107	 0.051661	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	7560	 761	 0.00419	 0.009868	 0.0	 2947	 2947	 2947	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 7560	 0.024281	 0.13338	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 7560	 0.02376	 0.123496	 0.0	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 7560	 0.005331	 0.020752	 0.0	 1475	 1475	 1475	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 7068	 0.001107	 0.004603	 0.0	 6673	 6673	 6673	 0.0	 0.0	 1	 -30.0	 30.0;
	7068	 7823	 0.005628	 0.030702	 0.0	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	716	 8108	 0.024628	 0.130893	 0.0	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	716	 8108	 0.024132	 0.133463	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 8108	 0.01419	 0.07062	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 8108	 0.014471	 0.069182	 0.0	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	6761	 8408	 0.008372	 0.045231	 0.0	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	6942	 6761	 0.024628	 0.097983	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	6761	 7087	 0.002471	 0.009331	 0.0	 3273	 3273	 3273	 0.0	 0.0	 1	 -30.0	 30.0;
	337	 1873	 0.025702	 0.144587	 0.0	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	4184	 337	 0.003421	 0.019752	 0.0	 1576	 1576	 1576	 0.0	 0.0	 1	 -30.0	 30.0;
	3534	 45	 0.004562	 0.017174	 0.0	 1778	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	45	 915	 0.018868	 0.083661	 0.0	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	45	 4877	 0.01019	 0.027917	 0.0	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	8830	 3534	 0.019471	 0.064058	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	6258	 1681	 0.053446	 0.118207	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	1681	 5539	 0.049521	 0.123438	 0.0	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 5055	 0.00914	 0.042039	 0.0	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 921	 0.004711	 0.021591	 0.0	 1430	 1430	 1430	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 9237	 0.0	 0.000893	 0.0	 35373	 35373	 35373	 0.0	 0.0	 1	 -30.0	 30.0;
	4693	 1450	 0.00405	 0.021132	 0.0	 1469	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	4693	 1450	 0.004587	 0.020711	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	9237	 3683	 0.044182	 0.091041	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	9237	 4536	 0.022653	 0.047421	 0.0	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	9237	 7484	 0.058876	 0.108463	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	457	 3572	 0.013174	 0.026992	 0.0	 1052	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 457	 0.001273	 0.002818	 0.0	 10216	 10216	 10216	 0.0	 0.0	 1	 -30.0	 30.0;
	1698	 1617	 0.009471	 0.048769	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	5966	 3474	 0.017388	 0.04138	 0.0	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	3474	 8897	 0.017339	 0.054661	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 4605	 0.025033	 0.137942	 0.0	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 4605	 0.024521	 0.140653	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4605	 7181	 0.021198	 0.056041	 0.0	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	4605	 8174	 0.007174	 0.035	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	2678	 4605	 0.010826	 0.029992	 0.0	 991	 991	 991	 0.0	 0.0	 1	 -30.0	 30.0;
	2678	 4605	 0.012876	 0.028058	 0.0	 1024	 1024	 1024	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 7744	 0.034248	 0.143124	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	6033	 7744	 0.015421	 0.066364	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 8659	 0.014512	 0.035901	 0.0	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 1438	 0.00863	 0.054419	 0.0	 533.0	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 1438	 0.008461	 0.055479	 0.0	 514.0	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 4280	 0.013256	 0.073248	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	8978	 4280	 0.004033	 0.018174	 0.0	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	636	 3765	 0.016008	 0.027066	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 3614	 0.013537	 0.070083	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	7793	 5223	 0.004744	 0.024876	 0.0	 1248	 1248	 1248	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 2776	 0.014364	 0.037438	 0.0	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	8319	 2249	 0.010364	 0.020314	 0.0	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	2249	 3669	 0.007289	 0.018207	 0.0	 1611	 1611	 1611	 0.0	 0.0	 1	 -30.0	 30.0;
	8360	 1500	 0.011744	 0.052446	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	7456	 8360	 0.015438	 0.062876	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	9010	 6568	 0.00157	 0.01612	 0.0	 1020.0	 2976	 2976	 0.0	 0.0	 1	 -30.0	 30.0;
	9010	 6568	 0.00154	 0.01643	 0.0	 1020.0	 2921	 2921	 0.0	 0.0	 1	 -30.0	 30.0;
	3641	 5424	 0.001967	 0.008438	 0.0	 3646	 3646	 3646	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 8272	 0.01162	 0.033653	 0.0	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 888	 0.006901	 0.04661	 0.0	 419.0	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 888	 0.00782	 0.04568	 0.0	 438.0	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	2865	 888	 0.005401	 0.0343	 0.0	 381.0	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 888	 0.011419	 0.07275	 0.0	 381.0	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 6006	 0.01044	 0.05919	 0.0	 476.0	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	8923	 1073	 0.050314	 0.112132	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	8923	 1073	 0.057017	 0.109893	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 4275	 0.007	 0.028231	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 8446	 0.010719	 0.040868	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 4668	 0.04443	 0.10976	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 568	 0.021372	 0.121033	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 884	 0.020579	 0.095331	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	2914	 8923	 0.02386	 0.06986	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	8852	 2914	 0.062901	 0.105628	 0.0	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	2914	 2127	 0.035686	 0.149314	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	6502	 2914	 0.00181	 0.006876	 0.0	 4443	 4443	 4443	 0.0	 0.0	 1	 -30.0	 30.0;
	6501	 2914	 0.002628	 0.01462	 0.0	 2127	 2127	 2127	 0.0	 0.0	 1	 -30.0	 30.0;
	6501	 2914	 0.002983	 0.014331	 0.0	 2158	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 2914	 0.006157	 0.03114	 0.0	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 7461	 0.022	 0.043066	 0.0	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 2022	 0.013438	 0.033479	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 8549	 0.013488	 0.028893	 0.0	 991	 991	 991	 0.0	 0.0	 1	 -30.0	 30.0;
	3421	 9178	 0.114058	 0.230033	 0.0	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	9178	 944	 0.062901	 0.133777	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	9178	 1981	 0.041868	 0.106554	 0.0	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	3415	 8315	 0.052347	 0.07786	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	8315	 5570	 0.003099	 0.006174	 0.0	 4573	 4573	 4573	 0.0	 0.0	 1	 -30.0	 30.0;
	889	 7340	 0.04357	 0.108678	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	889	 8173	 0.020893	 0.043289	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 8897	 0.035289	 0.072058	 0.0	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 8923	 0.050579	 0.074298	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	4069	 8923	 0.042934	 0.087917	 0.0	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	815	 7121	 0.036711	 0.086397	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	7121	 8319	 0.053124	 0.100066	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	7121	 4065	 0.022959	 0.041727	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	3967	 1641	 0.00476	 0.023868	 0.0	 1298	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	7737	 3967	 0.005529	 0.011182	 0.0	 2533	 2533	 2533	 0.0	 0.0	 1	 -30.0	 30.0;
	7572	 727	 0.00183	 0.02821	 0.0	 1678.0	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	7455	 7572	 0.00198	 0.02074	 0.0	 1218.0	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	8880	 5954	 0.022917	 0.094893	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	8880	 5954	 0.023347	 0.092868	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 2998	 0.030364	 0.073256	 0.0	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 6453	 0.004562	 0.020132	 0.0	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 6453	 0.010562	 0.020686	 0.0	 1360	 1360	 1360	 0.0	 0.0	 1	 -30.0	 30.0;
	944	 5954	 0.01838	 0.07314	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 5027	 0.005628	 0.029702	 0.0	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 5027	 0.005777	 0.029273	 0.0	 1059	 1059	 1059	 0.0	 0.0	 1	 -30.0	 30.0;
	2813	 5954	 0.014529	 0.236802	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	2582	 1737	 0.005818	 0.032182	 0.0	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	2582	 4693	 0.003636	 0.021843	 0.0	 1427	 1427	 1427	 0.0	 0.0	 1	 -30.0	 30.0;
	3440	 2041	 0.00318	 0.02624	 0.0	 1119.0	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	3440	 7455	 0.00442	 0.03649	 0.0	 1251.0	 1312	 1312	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 1647	 0.005099	 0.027868	 0.0	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 1737	 0.00995	 0.049397	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 1737	 0.01014	 0.048397	 0.0	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 1682	 0.007917	 0.04757	 0.0	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 93	 0.004008	 0.022182	 0.0	 1402	 1402	 1402	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 206	 0.006603	 0.039124	 0.0	 797	 797	 797	 0.0	 0.0	 1	 -30.0	 30.0;
	8319	 5637	 0.00657	 0.028281	 0.0	 1088	 1088	 1088	 0.0	 0.0	 1	 -30.0	 30.0;
	7340	 8319	 0.071471	 0.124661	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	7340	 8319	 0.069983	 0.127058	 0.0	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	8319	 3669	 0.00743	 0.018182	 0.0	 1609	 1609	 1609	 0.0	 0.0	 1	 -30.0	 30.0;
	8830	 7796	 0.004653	 0.024339	 0.0	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	8897	 8830	 0.007157	 0.03462	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	8897	 8830	 0.007298	 0.033909	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	6780	 7777	 0.00024	 0.00281	 0.0	 1218.0	 11201	 11201	 0.0	 0.0	 1	 -30.0	 30.0;
	5408	 7246	 0.010711	 0.056603	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	3746	 5408	 0.064273	 0.068058	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	8168	 5583	 0.013917	 0.06676	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	8168	 8599	 0.034298	 0.076091	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 3151	 0.00676	 0.044942	 0.0	 696	 696	 696	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 4184	 0.025579	 0.109438	 0.0	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 4184	 0.026091	 0.107198	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	3309	 3387	 0.00319	 0.01543	 0.0	 2005	 2005	 2005	 0.0	 0.0	 1	 -30.0	 30.0;
	3387	 2763	 0.003669	 0.014628	 0.0	 2095	 2095	 2095	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 1585	 0.001653	 0.007331	 0.0	 4204	 4204	 4204	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 2879	 0.009661	 0.04095	 0.0	 751	 751	 751	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 9010	 0.00089	 0.00981	 0.0	 1152.0	 3207	 3207	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 9010	 0.00087	 0.01	 0.0	 1316.0	 3147	 3147	 0.0	 0.0	 1	 -30.0	 30.0;
	9010	 7777	 0.00114	 0.01867	 0.0	 1448.0	 1689	 1689	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 2892	 0.034661	 0.089231	 0.0	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	1098	 4894	 0.009463	 0.018603	 0.0	 2114	 2114	 2114	 0.0	 0.0	 1	 -30.0	 30.0;
	2831	 7101	 0.032777	 0.061248	 0.0	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	6867	 2831	 0.029182	 0.043207	 0.0	 606	 606	 606	 0.0	 0.0	 1	 -30.0	 30.0;
	6758	 5966	 0.012826	 0.022587	 0.0	 1217	 1217	 1217	 0.0	 0.0	 1	 -30.0	 30.0;
	1967	 9111	 0.01519	 0.065017	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	390	 9111	 0.002107	 0.009	 0.0	 3418	 3418	 3418	 0.0	 0.0	 1	 -30.0	 30.0;
	9111	 4518	 0.010099	 0.046587	 0.0	 663	 663	 663	 0.0	 0.0	 1	 -30.0	 30.0;
	206	 1647	 0.001934	 0.009008	 0.0	 3429	 3429	 3429	 0.0	 0.0	 1	 -30.0	 30.0;
	6258	 7461	 0.041537	 0.116843	 0.0	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	6942	 7932	 0.013091	 0.050041	 0.0	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 7101	 0.003058	 0.005579	 0.0	 4965	 4965	 4965	 0.0	 0.0	 1	 -30.0	 30.0;
	1677	 8880	 0.008554	 0.035397	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	9210	 5456	 0.020314	 0.102727	 0.0	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5081	 5456	 0.005008	 0.025364	 0.0	 1222	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 5456	 0.042182	 0.161132	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	7790	 1314	 0.00014	 0.000581	 0.0	 52855	 52855	 52855	 0.0	 0.0	 1	 -30.0	 30.0;
	3437	 2163	 0.001339	 0.007438	 0.0	 4180	 4180	 4180	 0.0	 0.0	 1	 -30.0	 30.0;
	2461	 1585	 0.004223	 0.009347	 0.0	 3080	 3080	 3080	 0.0	 0.0	 1	 -30.0	 30.0;
	1585	 5565	 0.016314	 0.034562	 0.0	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	8978	 1585	 0.009331	 0.045339	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	2461	 4009	 0.00038	 0.002769	 0.0	 11302	 11302	 11302	 0.0	 0.0	 1	 -30.0	 30.0;
	8978	 2461	 0.007066	 0.043107	 0.0	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	1843	 1967	 0.003124	 0.017231	 0.0	 1804	 1804	 1804	 0.0	 0.0	 1	 -30.0	 30.0;
	2561	 5467	 0.020512	 0.048562	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	4069	 5467	 0.016934	 0.03314	 0.0	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	9026	 3641	 0.011083	 0.030769	 0.0	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 6599	 0.024314	 0.099174	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 6599	 0.024769	 0.097058	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 6599	 0.025231	 0.09495	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 5159	 0.012917	 0.049612	 0.0	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 3281	 0.048058	 0.135157	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 4009	 0.009372	 0.048876	 0.0	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 5457	 0.00538	 0.031752	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 5457	 0.005273	 0.029397	 0.0	 1058	 1058	 1058	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 8910	 0.044562	 0.09762	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	6599	 3844	 0.017876	 0.097091	 0.0	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	6599	 3547	 0.037207	 0.166008	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	7455	 8885	 0.00018	 0.00154	 0.0	 987.0	 28455	 28455	 0.0	 0.0	 1	 -30.0	 30.0;
	7455	 8885	 0.00023	 0.00194	 0.0	 889.0	 22584	 22584	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 2419	 0.005669	 0.040521	 0.0	 514.0	 773	 773	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 4788	 0.001581	 0.012159	 0.0	 381.0	 2577	 2577	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 4788	 0.001409	 0.013781	 0.0	 400.0	 2281	 2281	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 3505	 0.00111	 0.0075	 0.0	 438.0	 4167	 4167	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 557	 0.0115	 0.07662	 0.0	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	2211	 2937	 0.002661	 0.01286	 0.0	 2406	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	1737	 4693	 0.010793	 0.046942	 0.0	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 9210	 0.023826	 0.100992	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	9210	 7608	 0.014603	 0.07986	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	9210	 5081	 0.026132	 0.099818	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 3883	 0.002289	 0.012554	 0.0	 2476	 2476	 2476	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 6258	 0.00743	 0.030719	 0.0	 1000	 1000	 1000	 0.0	 0.0	 1	 -30.0	 30.0;
	7554	 3415	 0.014653	 0.029174	 0.0	 968	 968	 968	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 7554	 0.016388	 0.04286	 0.0	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	4536	 8983	 0.056248	 0.122041	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	343	 8983	 0.024901	 0.049099	 0.0	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 7181	 0.026554	 0.061851	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	3421	 6739	 0.073678	 0.305793	 0.0	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	3094	 3421	 0.029083	 0.060017	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	3421	 66	 0.021893	 0.134521	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	1324	 5552	 0.018983	 0.03914	 0.0	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	5552	 5676	 0.024529	 0.041612	 0.0	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	7077	 5443	 0.039421	 0.085686	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	7340	 5443	 0.039421	 0.085769	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 7077	 0.00876	 0.016901	 0.0	 1660	 1660	 1660	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 7242	 0.006967	 0.018248	 0.0	 1618	 1618	 1618	 0.0	 0.0	 1	 -30.0	 30.0;
	8372	 2763	 0.025099	 0.107901	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	3683	 8372	 0.02605	 0.103438	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 2263	 0.012719	 0.033719	 0.0	 877	 877	 877	 0.0	 0.0	 1	 -30.0	 30.0;
	2263	 7793	 0.022273	 0.043661	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	8046	 5219	 0.00124	 0.006653	 0.0	 4668	 4668	 4668	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 5219	 0.001587	 0.007636	 0.0	 4051	 4051	 4051	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 3781	 0.006207	 0.032331	 0.0	 960	 960	 960	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 3781	 0.006083	 0.032942	 0.0	 943	 943	 943	 0.0	 0.0	 1	 -30.0	 30.0;
	3781	 3746	 0.001314	 0.005446	 0.0	 5639	 5639	 5639	 0.0	 0.0	 1	 -30.0	 30.0;
	4275	 435	 0.003851	 0.01662	 0.0	 1852	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 8029	 0.005124	 0.031934	 0.0	 977	 977	 977	 0.0	 0.0	 1	 -30.0	 30.0;
	8978	 8029	 0.005008	 0.029562	 0.0	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	589	 8174	 0.048331	 0.094372	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	589	 2602	 0.015678	 0.073826	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2679	 868	 0.005579	 0.019174	 0.0	 1582	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	343	 2679	 0.029397	 0.077132	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 868	 0.002901	 0.006802	 0.0	 4272	 4272	 4272	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 93	 0.004769	 0.020826	 0.0	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 8709	 0.031388	 0.06305	 0.0	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 3890	 0.032587	 0.068752	 0.0	 416	 416	 416	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 1353	 0.042802	 0.083983	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	3844	 3547	 0.01214	 0.069124	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	2892	 1873	 0.008388	 0.017033	 0.0	 2324	 2324	 2324	 0.0	 0.0	 1	 -30.0	 30.0;
	8925	 8746	 0.008521	 0.046653	 0.0	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	8925	 8505	 0.003331	 0.013818	 0.0	 2223	 2223	 2223	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 2419	 0.016729	 0.090401	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 6046	 0.01526	 0.081479	 0.0	 495.0	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 8551	 0.00905	 0.068219	 0.0	 457.0	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 1922	 0.01205	 0.08575	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 6971	 0.007841	 0.04113	 0.0	 495.0	 755	 755	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 239	 0.002413	 0.010686	 0.0	 2884	 2884	 2884	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 84	 0.005041	 0.022769	 0.0	 1355	 1355	 1355	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 36	 0.00126	 0.007531	 0.0	 419.0	 4137	 4137	 0.0	 0.0	 1	 -30.0	 30.0;
	7737	 2068	 0.00176	 0.007603	 0.0	 4048	 4048	 4048	 0.0	 0.0	 1	 -30.0	 30.0;
	7737	 2068	 0.00157	 0.00862	 0.0	 3606	 3606	 3606	 0.0	 0.0	 1	 -30.0	 30.0;
	8852	 2561	 0.02743	 0.059157	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	1677	 1447	 0.028992	 0.060893	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 2415	 0.012942	 0.051851	 0.0	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 3531	 0.071157	 0.104149	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 6695	 0.002017	 0.010686	 0.0	 2905	 2905	 2905	 0.0	 0.0	 1	 -30.0	 30.0;
	3141	 6695	 0.00195	 0.009364	 0.0	 3303	 3303	 3303	 0.0	 0.0	 1	 -30.0	 30.0;
	3141	 6695	 0.001992	 0.009174	 0.0	 3365	 3365	 3365	 0.0	 0.0	 1	 -30.0	 30.0;
	1324	 574	 0.027017	 0.074521	 0.0	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	574	 7077	 0.025107	 0.072339	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	4341	 3730	 0.002942	 0.006248	 0.0	 4574	 4574	 4574	 0.0	 0.0	 1	 -30.0	 30.0;
	3730	 3828	 0.006983	 0.028678	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 5563	 0.049636	 0.077364	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	8797	 5563	 0.071752	 0.121198	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	390	 5515	 0.00219	 0.009174	 0.0	 3350	 3350	 3350	 0.0	 0.0	 1	 -30.0	 30.0;
	6076	 390	 0.018719	 0.067983	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	8978	 5159	 0.006339	 0.025397	 0.0	 1207	 1207	 1207	 0.0	 0.0	 1	 -30.0	 30.0;
	7246	 23	 0.011876	 0.064967	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	6739	 4372	 0.004603	 0.024603	 0.0	 1262	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	1782	 6739	 0.037934	 0.102868	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	2998	 7296	 0.020818	 0.067711	 0.0	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	2776	 1171	 0.020223	 0.048471	 0.0	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 3746	 0.00705	 0.034314	 0.0	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 7250	 0.015388	 0.074008	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 7250	 0.015066	 0.075463	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	1324	 34	 0.060331	 0.128752	 0.0	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	34	 7022	 0.037752	 0.085843	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	34	 636	 0.060471	 0.109992	 0.0	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 34	 0.021959	 0.050058	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	7077	 2130	 0.005347	 0.026198	 0.0	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 2130	 0.005058	 0.015769	 0.0	 1908	 1908	 1908	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 1107	 0.010256	 0.053223	 0.0	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	3576	 4372	 0.01476	 0.082157	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 1247	 0.047843	 0.112033	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	7882	 4161	 0.013909	 0.036793	 0.0	 804	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	4161	 3094	 0.030289	 0.064818	 0.0	 442	 442	 442	 0.0	 0.0	 1	 -30.0	 30.0;
	4161	 1098	 0.026132	 0.123132	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	4161	 1098	 0.026628	 0.120562	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	8269	 4161	 0.016727	 0.063959	 0.0	 478	 478	 478	 0.0	 0.0	 1	 -30.0	 30.0;
	6651	 5275	 0.002413	 0.010248	 0.0	 3001	 3001	 3001	 0.0	 0.0	 1	 -30.0	 30.0;
	6651	 4184	 0.009	 0.040843	 0.0	 756	 756	 756	 0.0	 0.0	 1	 -30.0	 30.0;
	435	 8446	 0.008421	 0.018488	 0.0	 1555	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	8514	 8219	 0.014917	 0.034322	 0.0	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	8514	 2790	 0.00743	 0.035942	 0.0	 861	 861	 861	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 8514	 0.003851	 0.016	 0.0	 1920	 1920	 1920	 0.0	 0.0	 1	 -30.0	 30.0;
	1590	 8514	 0.00162	 0.008008	 0.0	 3867	 3867	 3867	 0.0	 0.0	 1	 -30.0	 30.0;
	3477	 7882	 0.014372	 0.045793	 0.0	 659	 659	 659	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 3477	 0.038678	 0.089967	 0.0	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	7796	 4655	 0.009504	 0.021727	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	4655	 4877	 0.018364	 0.096521	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 6453	 0.00195	 0.010669	 0.0	 2913	 2913	 2913	 0.0	 0.0	 1	 -30.0	 30.0;
	6453	 6196	 0.021182	 0.046826	 0.0	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 7608	 0.031752	 0.131826	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 4518	 0.002917	 0.01238	 0.0	 2484	 2484	 2484	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 1779	 0.016157	 0.035826	 0.0	 804	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 3144	 0.003727	 0.020529	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 6002	 0.019992	 0.079231	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	3151	 1779	 0.023653	 0.094587	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	3144	 1517	 0.009322	 0.049058	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 1517	 0.026727	 0.146752	 0.0	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 557	 0.000531	 0.002919	 0.0	 10647	 10647	 10647	 0.0	 0.0	 1	 -30.0	 30.0;
	572	 6196	 0.021992	 0.059397	 0.0	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	572	 5086	 0.044413	 0.10176	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	4044	 572	 0.043223	 0.088562	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 3281	 0.006992	 0.014066	 0.0	 2011	 2011	 2011	 0.0	 0.0	 1	 -30.0	 30.0;
	1698	 5368	 0.007256	 0.028802	 0.0	 1064	 1064	 1064	 0.0	 0.0	 1	 -30.0	 30.0;
	1698	 5368	 0.006471	 0.032636	 0.0	 950	 950	 950	 0.0	 0.0	 1	 -30.0	 30.0;
	1698	 8910	 0.043198	 0.156397	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	7823	 5024	 0.016248	 0.04014	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	1438	 1143	 0.00206	 0.01393	 0.0	 457.0	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	1438	 1143	 0.002021	 0.01419	 0.0	 495.0	 2204	 2204	 0.0	 0.0	 1	 -30.0	 30.0;
	1438	 36	 0.00324	 0.02076	 0.0	 438.0	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	1438	 36	 0.00318	 0.021159	 0.0	 457.0	 1477	 1477	 0.0	 0.0	 1	 -30.0	 30.0;
	1324	 7077	 0.031603	 0.070331	 0.0	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 1324	 0.003132	 0.014554	 0.0	 2122	 2122	 2122	 0.0	 0.0	 1	 -30.0	 30.0;
	1509	 1324	 0.006669	 0.032091	 0.0	 964	 964	 964	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 8746	 0.008934	 0.046298	 0.0	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	915	 5319	 0.002942	 0.012008	 0.0	 2555	 2555	 2555	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 4065	 0.010942	 0.062207	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 5917	 0.002529	 0.011777	 0.0	 2623	 2623	 2623	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 507	 0.015107	 0.042769	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	8646	 9026	 0.00705	 0.022099	 0.0	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 3842	 0.038231	 0.105893	 0.0	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 6065	 0.005901	 0.021289	 0.0	 1430	 1430	 1430	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 5198	 0.013636	 0.022686	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	7022	 636	 0.023826	 0.059364	 0.0	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	7077	 3524	 0.016091	 0.045967	 0.0	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	3524	 4304	 0.017033	 0.053008	 0.0	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	7384	 3842	 0.017744	 0.09686	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	5917	 5082	 0.003636	 0.018818	 0.0	 1649	 1649	 1649	 0.0	 0.0	 1	 -30.0	 30.0;
	5917	 5082	 0.003562	 0.019174	 0.0	 1620	 1620	 1620	 0.0	 0.0	 1	 -30.0	 30.0;
	6557	 5607	 0.008256	 0.021909	 0.0	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 7796	 0.026917	 0.061636	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 4438	 0.022702	 0.057149	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 8272	 0.023983	 0.070124	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 2626	 0.035231	 0.078314	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 8797	 0.02462	 0.053603	 0.0	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 4944	 0.008091	 0.03214	 0.0	 954	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	419	 3381	 0.016793	 0.081388	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	3381	 1107	 0.008636	 0.047388	 0.0	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	5176	 7077	 0.009364	 0.018207	 0.0	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	7077	 8173	 0.023331	 0.063727	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	7077	 498	 0.014983	 0.033579	 0.0	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	3141	 6133	 0.004636	 0.019678	 0.0	 1563	 1563	 1563	 0.0	 0.0	 1	 -30.0	 30.0;
	3141	 6133	 0.004727	 0.019273	 0.0	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 157	 0.018446	 0.089686	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	8978	 3006	 0.011529	 0.056587	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	8091	 6258	 0.00862	 0.021587	 0.0	 1359	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	8091	 3171	 0.005702	 0.013017	 0.0	 2223	 2223	 2223	 0.0	 0.0	 1	 -30.0	 30.0;
	7130	 645	 0.048256	 0.078099	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	645	 4297	 0.065529	 0.159802	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	6033	 645	 0.02681	 0.110702	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	66	 1782	 0.04538	 0.142983	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 3309	 0.024992	 0.097777	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	8782	 3309	 0.020256	 0.109372	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	3309	 521	 0.024636	 0.095653	 0.0	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	2211	 5081	 0.003364	 0.017669	 0.0	 1757	 1757	 1757	 0.0	 0.0	 1	 -30.0	 30.0;
	3669	 8821	 0.018463	 0.039124	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	8821	 1229	 0.021636	 0.060793	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	7280	 116	 0.01786	 0.039711	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	2419	 3505	 0.00588	 0.03186	 0.0	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 7336	 0.045058	 0.177512	 0.0	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 2733	 0.003686	 0.017711	 0.0	 1747	 1747	 1747	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 2733	 0.003612	 0.018058	 0.0	 1716	 1716	 1716	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 2733	 0.007876	 0.021066	 0.0	 1405	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 7336	 0.03186	 0.159347	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	8797	 3576	 0.034901	 0.071347	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	1856	 5368	 0.006339	 0.033281	 0.0	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	1856	 5368	 0.006207	 0.033917	 0.0	 917	 917	 917	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 5368	 0.006207	 0.034983	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	6523	 8978	 0.006289	 0.024661	 0.0	 1242	 1242	 1242	 0.0	 0.0	 1	 -30.0	 30.0;
	6523	 7594	 0.002554	 0.01376	 0.0	 2258	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	944	 1447	 0.003579	 0.01486	 0.0	 2067	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 1843	 0.01495	 0.02843	 0.0	 984	 984	 984	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 7375	 0.011727	 0.028934	 0.0	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	7375	 8646	 0.013843	 0.048909	 0.0	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 1843	 0.032388	 0.080711	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 1843	 0.011719	 0.074793	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	1843	 6076	 0.00057	 0.002612	 0.0	 11816	 11816	 11816	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 1270	 0.012554	 0.026314	 0.0	 1084	 1084	 1084	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 5119	 0.022554	 0.049397	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	944	 2813	 0.005438	 0.021669	 0.0	 1414	 1414	 1414	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 1506	 0.00079	 0.00721	 0.0	 1119.0	 4355	 4355	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 3981	 0.00023	 0.00228	 0.0	 1119.0	 13785	 13785	 0.0	 0.0	 1	 -30.0	 30.0;
	7737	 9145	 0.002248	 0.012083	 0.0	 2571	 2571	 2571	 0.0	 0.0	 1	 -30.0	 30.0;
	7737	 9145	 0.002198	 0.012314	 0.0	 2526	 2526	 2526	 0.0	 0.0	 1	 -30.0	 30.0;
	7340	 7782	 0.014727	 0.064099	 0.0	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	239	 7340	 0.016364	 0.040901	 0.0	 718	 718	 718	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 7340	 0.024471	 0.063686	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	8322	 3885	 0.00037	 0.00429	 0.0	 1185.0	 7336	 7336	 0.0	 0.0	 1	 -30.0	 30.0;
	9194	 3885	 0.00201	 0.02375	 0.0	 1283.0	 1326	 1326	 0.0	 0.0	 1	 -30.0	 30.0;
	3885	 2942	 9e-05	 0.00093	 0.0	 1415.0	 33807	 33807	 0.0	 0.0	 1	 -30.0	 30.0;
	3885	 1905	 9e-05	 0.00095	 0.0	 1415.0	 33102	 33102	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 9144	 0.004969	 0.034979	 0.0	 438.0	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 9144	 0.00468	 0.033031	 0.0	 419.0	 1323	 1323	 0.0	 0.0	 1	 -30.0	 30.0;
	9144	 6434	 0.00076	 0.007909	 0.0	 629.0	 5553	 5553	 0.0	 0.0	 1	 -30.0	 30.0;
	9144	 5497	 0.020539	 0.080461	 0.0	 476.0	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 2790	 0.024562	 0.099231	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 8797	 0.103397	 0.231174	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 66	 0.063843	 0.141661	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	8322	 727	 0.00059	 0.00906	 0.0	 1810.0	 5309	 5309	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 6434	 0.001979	 0.02175	 0.0	 2021	 2021	 2021	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 2110	 0.005281	 0.040039	 0.0	 495.0	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 557	 0.012281	 0.069219	 0.0	 495.0	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 6971	 0.00668	 0.04144	 0.0	 533.0	 1149	 1149	 0.0	 0.0	 1	 -30.0	 30.0;
	6434	 6158	 0.00725	 0.03801	 0.0	 553.0	 1141	 1141	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 2041	 0.00225	 0.02188	 0.0	 1415.0	 1437	 1437	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 1922	 0.00525	 0.03749	 0.0	 514.0	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 1922	 0.00605	 0.03069	 0.0	 514.0	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	3669	 3263	 0.054793	 0.13405	 0.0	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	7782	 3669	 0.019099	 0.076488	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	3669	 6867	 0.035686	 0.057678	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	6758	 7054	 0.00481	 0.020579	 0.0	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	6758	 7054	 0.004909	 0.020149	 0.0	 1524	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	6758	 4304	 0.010843	 0.055512	 0.0	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	6758	 4304	 0.012289	 0.054397	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	498	 6758	 0.003562	 0.018124	 0.0	 1711	 1711	 1711	 0.0	 0.0	 1	 -30.0	 30.0;
	8717	 8219	 0.038017	 0.081934	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	8717	 1098	 0.020149	 0.083124	 0.0	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	8717	 6732	 0.009554	 0.040959	 0.0	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	2813	 8232	 0.008331	 0.043322	 0.0	 717	 717	 717	 0.0	 0.0	 1	 -30.0	 30.0;
	8232	 1981	 0.02114	 0.114479	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 3263	 0.017488	 0.03838	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	7054	 4232	 0.00381	 0.019256	 0.0	 1610	 1610	 1610	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 4232	 0.001397	 0.005802	 0.0	 5293	 5293	 5293	 0.0	 0.0	 1	 -30.0	 30.0;
	2279	 6258	 0.004719	 0.024603	 0.0	 1261	 1261	 1261	 0.0	 0.0	 1	 -30.0	 30.0;
	2279	 6258	 0.00462	 0.025058	 0.0	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	3171	 6258	 0.005413	 0.027876	 0.0	 1113	 1113	 1113	 0.0	 0.0	 1	 -30.0	 30.0;
	6258	 5804	 0.032041	 0.196413	 0.0	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	1970	 6258	 0.002198	 0.022248	 0.0	 1413	 1413	 1413	 0.0	 0.0	 1	 -30.0	 30.0;
	6258	 190	 0.00262	 0.018463	 0.0	 1694	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	6258	 419	 0.030347	 0.112149	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3828	 7384	 0.014512	 0.05981	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	1270	 8274	 0.005438	 0.009124	 0.0	 2974	 2974	 2974	 0.0	 0.0	 1	 -30.0	 30.0;
	9125	 1314	 0.005169	 0.022219	 0.0	 1385	 1385	 1385	 0.0	 0.0	 1	 -30.0	 30.0;
	716	 6537	 0.007793	 0.029769	 0.0	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	716	 7991	 0.006091	 0.028653	 0.0	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	4184	 5024	 0.02876	 0.060388	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1641	 1911	 0.02443	 0.09576	 0.0	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 1911	 0.009083	 0.03857	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	8797	 761	 0.048157	 0.08462	 0.0	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	4944	 2279	 0.002512	 0.013826	 0.0	 2248	 2248	 2248	 0.0	 0.0	 1	 -30.0	 30.0;
	8274	 6304	 0.012298	 0.026826	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	8408	 8599	 0.022744	 0.133521	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5319	 4877	 0.022554	 0.088876	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	7130	 8709	 0.019231	 0.033802	 0.0	 813	 813	 813	 0.0	 0.0	 1	 -30.0	 30.0;
	8897	 6557	 0.010017	 0.022711	 0.0	 1273	 1273	 1273	 0.0	 0.0	 1	 -30.0	 30.0;
	8897	 507	 0.00219	 0.011843	 0.0	 2623	 2623	 2623	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 5706	 0.019281	 0.064488	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 5706	 0.02119	 0.091727	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	4297	 8803	 0.003099	 0.013893	 0.0	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 8803	 0.004132	 0.021959	 0.0	 1414	 1414	 1414	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 8803	 0.004041	 0.02238	 0.0	 1389	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 8782	 0.002471	 0.010901	 0.0	 2826	 2826	 2826	 0.0	 0.0	 1	 -30.0	 30.0;
	7777	 9194	 0.002	 0.017	 0.0	 1283.0	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 9194	 0.0016	 0.01758	 0.0	 1119.0	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	8408	 332	 0.027397	 0.111917	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	8408	 7087	 0.008752	 0.044802	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	716	 6304	 0.045727	 0.07386	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 8527	 0.044281	 0.119579	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 8527	 0.057612	 0.11224	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	4341	 8527	 0.063314	 0.107273	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 5176	 0.006769	 0.017909	 0.0	 1650	 1650	 1650	 0.0	 0.0	 1	 -30.0	 30.0;
	7000	 4184	 0.003273	 0.01157	 0.0	 2628	 2628	 2628	 0.0	 0.0	 1	 -30.0	 30.0;
	7000	 542	 0.000248	 0.001331	 0.0	 23331	 23331	 23331	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 2713	 0.010603	 0.045727	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	2713	 4341	 0.016273	 0.089678	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 7496	 0.008397	 0.022777	 0.0	 1302	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	7496	 1416	 0.013421	 0.036314	 0.0	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	8978	 4009	 0.009628	 0.050752	 0.0	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	6002	 332	 0.011777	 0.046843	 0.0	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	3746	 332	 0.014446	 0.059967	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 2256	 0.005174	 0.029562	 0.0	 1053	 1053	 1053	 0.0	 0.0	 1	 -30.0	 30.0;
	8272	 2678	 0.069256	 0.110017	 0.0	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	1500	 1963	 0.00524	 0.022124	 0.0	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 8954	 0.005083	 0.019421	 0.0	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	8954	 1325	 0.004099	 0.013868	 0.0	 2185	 2185	 2185	 0.0	 0.0	 1	 -30.0	 30.0;
	8890	 7280	 0.04181	 0.081397	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	8890	 6942	 0.041446	 0.067174	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 2369	 0.008841	 0.0587	 0.0	 476.0	 533	 533	 0.0	 0.0	 1	 -30.0	 30.0;
	1856	 3547	 0.011876	 0.064	 0.0	 486	 486	 486	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 2211	 0.037579	 0.182612	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 7296	 0.025752	 0.129421	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 8269	 0.00543	 0.011421	 0.0	 2498	 2498	 2498	 0.0	 0.0	 1	 -30.0	 30.0;
	8269	 3923	 0.003727	 0.010066	 0.0	 2943	 2943	 2943	 0.0	 0.0	 1	 -30.0	 30.0;
	4304	 7112	 0.015868	 0.053702	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	2163	 8890	 0.026388	 0.120603	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	8046	 2167	 0.002372	 0.010669	 0.0	 2891	 2891	 2891	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 1325	 0.001289	 0.005041	 0.0	 6071	 6071	 6071	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 3646	 0.001438	 0.006421	 0.0	 4801	 4801	 4801	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 6933	 0.001471	 0.006289	 0.0	 4891	 4891	 4891	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 1199	 0.00105	 0.01056	 0.0	 1086.0	 2977	 2977	 0.0	 0.0	 1	 -30.0	 30.0;
	2865	 36	 0.01137	 0.056789	 0.0	 381.0	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 36	 0.00519	 0.028151	 0.0	 476.0	 1104	 1104	 0.0	 0.0	 1	 -30.0	 30.0;
	1641	 5962	 0.030091	 0.150033	 0.0	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	6033	 94	 0.011207	 0.023851	 0.0	 1199	 1199	 1199	 0.0	 0.0	 1	 -30.0	 30.0;
	94	 8549	 0.073347	 0.103488	 0.0	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 6367	 0.064149	 0.131041	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 1314	 0.002341	 0.009719	 0.0	 3160	 3160	 3160	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 279	 0.051231	 0.126554	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 279	 0.031967	 0.079413	 0.0	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	1590	 542	 0.00024	 0.001	 0.0	 30716	 30716	 30716	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 3062	 0.034008	 0.069388	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	521	 1028	 0.003	 0.01243	 0.0	 2471	 2471	 2471	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 7484	 0.036281	 0.073678	 0.0	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 3237	 0.003587	 0.017231	 0.0	 1795	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 6971	 0.00012	 0.00062	 0.0	 50020	 50020	 50020	 0.0	 0.0	 1	 -30.0	 30.0;
	7456	 6732	 0.006909	 0.039231	 0.0	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	6501	 6502	 0.003314	 0.007017	 0.0	 4071	 4071	 4071	 0.0	 0.0	 1	 -30.0	 30.0;
	8910	 8978	 0.011289	 0.063661	 0.0	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	8910	 8978	 0.01105	 0.058942	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	7594	 8978	 0.007711	 0.039413	 0.0	 787	 787	 787	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 239	 0.004017	 0.013669	 0.0	 2218	 2218	 2218	 0.0	 0.0	 1	 -30.0	 30.0;
	3861	 1247	 0.040521	 0.08386	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	2559	 2672	 0.024579	 0.061231	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	3062	 4044	 0.067992	 0.151463	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 8505	 0.003579	 0.011942	 0.0	 2534	 2534	 2534	 0.0	 0.0	 1	 -30.0	 30.0;
	6501	 422	 0.00776	 0.021587	 0.0	 1377	 1377	 1377	 0.0	 0.0	 1	 -30.0	 30.0;
	8910	 8093	 0.003298	 0.009463	 0.0	 3153	 3153	 3153	 0.0	 0.0	 1	 -30.0	 30.0;
	8144	 8093	 0.005157	 0.01376	 0.0	 2150	 2150	 2150	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 8144	 0.009934	 0.034479	 0.0	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	3646	 1509	 0.002008	 0.010802	 0.0	 2875	 2875	 2875	 0.0	 0.0	 1	 -30.0	 30.0;
	6933	 3237	 0.001967	 0.011008	 0.0	 2825	 2825	 2825	 0.0	 0.0	 1	 -30.0	 30.0;
	654	 5807	 0.003219	 0.01439	 0.0	 2143	 2143	 2143	 0.0	 0.0	 1	 -30.0	 30.0;
	654	 1924	 0.00239	 0.01426	 0.0	 2185	 2185	 2185	 0.0	 0.0	 1	 -30.0	 30.0;
	8675	 6520	 0.00143	 0.013591	 0.0	 591.0	 2312	 2312	 0.0	 0.0	 1	 -30.0	 30.0;
	8675	 7219	 0.004669	 0.05795	 0.0	 544	 544	 544	 0.0	 0.0	 1	 -30.0	 30.0;
	8675	 1553	 0.00412	 0.043151	 0.0	 610.0	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	8675	 3124	 0.000521	 0.00612	 0.0	 5143	 5143	 5143	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 4808	 0.005849	 0.02768	 0.0	 273.0	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	4762	 5448	 0.012742	 0.049311	 0.0	 273.0	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	6411	 7219	 0.00206	 0.01061	 0.0	 2923	 2923	 2923	 0.0	 0.0	 1	 -30.0	 30.0;
	6411	 2005	 0.001591	 0.01	 0.0	 3120	 3120	 3120	 0.0	 0.0	 1	 -30.0	 30.0;
	1278	 1557	 0.00098	 0.00874	 0.0	 1547.0	 3592	 3592	 0.0	 0.0	 1	 -30.0	 30.0;
	1278	 5527	 0.00045	 0.00548	 0.0	 856.0	 5745	 5745	 0.0	 0.0	 1	 -30.0	 30.0;
	4761	 5992	 0.000719	 0.003349	 0.0	 9222	 9222	 9222	 0.0	 0.0	 1	 -30.0	 30.0;
	4761	 2257	 0.000919	 0.00687	 0.0	 4558	 4558	 4558	 0.0	 0.0	 1	 -30.0	 30.0;
	4761	 6335	 0.000219	 0.0015	 0.0	 20838	 20838	 20838	 0.0	 0.0	 1	 -30.0	 30.0;
	3278	 2624	 0.00355	 0.019669	 0.0	 591.0	 1581	 1581	 0.0	 0.0	 1	 -30.0	 30.0;
	3278	 752	 0.00389	 0.02201	 0.0	 495.0	 1414	 1414	 0.0	 0.0	 1	 -30.0	 30.0;
	3278	 7239	 0.00251	 0.01455	 0.0	 629.0	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	4416	 4553	 0.00825	 0.036781	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	4416	 4176	 0.000581	 0.00412	 0.0	 591.0	 7592	 7592	 0.0	 0.0	 1	 -30.0	 30.0;
	6775	 8905	 0.00103	 0.01236	 0.0	 1481.0	 2547	 2547	 0.0	 0.0	 1	 -30.0	 30.0;
	6775	 5527	 0.0014	 0.01768	 0.0	 1349.0	 1782	 1782	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 356	 0.00088	 0.01169	 0.0	 2695	 2695	 2695	 0.0	 0.0	 1	 -30.0	 30.0;
	3949	 147	 0.001711	 0.01164	 0.0	 629.0	 2685	 2685	 0.0	 0.0	 1	 -30.0	 30.0;
	3949	 4453	 0.00268	 0.015031	 0.0	 553.0	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	3949	 9048	 0.0018	 0.01132	 0.0	 572.0	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	1122	 4211	 0.00051	 0.00268	 0.0	 476.0	 11579	 11579	 0.0	 0.0	 1	 -30.0	 30.0;
	1122	 2501	 0.000651	 0.003289	 0.0	 419.0	 9422	 9422	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 4201	 0.0012	 0.01137	 0.0	 1744.0	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 6666	 0.00168	 0.02275	 0.0	 1385	 1385	 1385	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 5992	 0.002331	 0.0225	 0.0	 1397	 1397	 1397	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 5992	 0.002081	 0.0255	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 688	 0.000781	 0.004979	 0.0	 6268	 6268	 6268	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 2191	 0.00514	 0.06699	 0.0	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	7472	 3494	 0.00088	 0.00804	 0.0	 1942.0	 3906	 3906	 0.0	 0.0	 1	 -30.0	 30.0;
	7472	 3277	 0.00032	 0.00311	 0.0	 1678.0	 10104	 10104	 0.0	 0.0	 1	 -30.0	 30.0;
	7472	 219	 0.00015	 0.00197	 0.0	 1020.0	 15988	 15988	 0.0	 0.0	 1	 -30.0	 30.0;
	7681	 5807	 0.004719	 0.023831	 0.0	 438.0	 1301	 1301	 0.0	 0.0	 1	 -30.0	 30.0;
	7681	 2257	 0.00669	 0.029979	 0.0	 457.0	 1029	 1029	 0.0	 0.0	 1	 -30.0	 30.0;
	9161	 8395	 0.001031	 0.01225	 0.0	 2570	 2570	 2570	 0.0	 0.0	 1	 -30.0	 30.0;
	9161	 8598	 0.00105	 0.00937	 0.0	 553.0	 3351	 3351	 0.0	 0.0	 1	 -30.0	 30.0;
	9161	 943	 0.00201	 0.01293	 0.0	 400.0	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 752	 0.002	 0.012229	 0.0	 553.0	 2550	 2550	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 1915	 8.1e-05	 0.000521	 0.0	 400.0	 59909	 59909	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 6520	 0.00113	 0.010969	 0.0	 2865	 2865	 2865	 0.0	 0.0	 1	 -30.0	 30.0;
	8905	 8742	 0.00195	 0.02538	 0.0	 1241	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	8905	 3277	 0.00164	 0.01684	 0.0	 1514.0	 1867	 1867	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 5898	 0.006289	 0.06895	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 8986	 0.001169	 0.010229	 0.0	 3069	 3069	 3069	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 5844	 0.00805	 0.060409	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 5844	 0.00789	 0.061581	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 7219	 0.007159	 0.04164	 0.0	 533.0	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 7219	 0.007289	 0.040729	 0.0	 533.0	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 7027	 0.004531	 0.02731	 0.0	 1142	 1142	 1142	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 1062	 0.004521	 0.033581	 0.0	 533.0	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	8395	 3407	 0.0005	 0.005081	 0.0	 6187	 6187	 6187	 0.0	 0.0	 1	 -30.0	 30.0;
	8395	 811	 0.00132	 0.006521	 0.0	 4748	 4748	 4748	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 5898	 0.004401	 0.030531	 0.0	 1025	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 1553	 0.000469	 0.003409	 0.0	 629.0	 9180	 9180	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 3494	 0.00239	 0.02364	 0.0	 1330	 1330	 1330	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 4323	 0.00034	 0.0041	 0.0	 1777.0	 7678	 7678	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 6666	 0.00027	 0.00327	 0.0	 1645.0	 9627	 9627	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 6666	 0.00026	 0.00333	 0.0	 1777.0	 9457	 9457	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 2716	 0.00059	 0.00574	 0.0	 1547.0	 5475	 5475	 0.0	 0.0	 1	 -30.0	 30.0;
	1017	 7785	 0.000789	 0.003711	 0.0	 8326	 8326	 8326	 0.0	 0.0	 1	 -30.0	 30.0;
	1017	 7529	 0.00419	 0.04988	 0.0	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	1017	 5242	 0.001651	 0.010919	 0.0	 2861	 2861	 2861	 0.0	 0.0	 1	 -30.0	 30.0;
	2498	 7027	 0.007281	 0.03162	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	2498	 2290	 0.006831	 0.03505	 0.0	 572.0	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	3494	 5527	 0.00108	 0.01258	 0.0	 1645.0	 2502	 2502	 0.0	 0.0	 1	 -30.0	 30.0;
	3494	 4323	 0.00174	 0.0229	 0.0	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	3494	 2716	 0.00223	 0.02125	 0.0	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 5992	 0.0023	 0.014081	 0.0	 2214	 2214	 2214	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 1924	 0.00213	 0.026831	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 5795	 0.001039	 0.00549	 0.0	 5654	 5654	 5654	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 8276	 0.00301	 0.016711	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 1406	 0.000849	 0.005229	 0.0	 5963	 5963	 5963	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 1603	 0.002781	 0.020281	 0.0	 591.0	 1544	 1544	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 943	 0.002159	 0.01389	 0.0	 2248	 2248	 2248	 0.0	 0.0	 1	 -30.0	 30.0;
	153	 8142	 0.003502	 0.031631	 0.0	 325.0	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	4808	 7005	 0.003929	 0.024729	 0.0	 260.0	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	7005	 153	 0.00076	 0.005609	 0.0	 260.0	 5581	 5581	 0.0	 0.0	 1	 -30.0	 30.0;
	2624	 4211	 0.002039	 0.01249	 0.0	 533.0	 2496	 2496	 0.0	 0.0	 1	 -30.0	 30.0;
	4938	 8742	 0.00036	 0.00572	 0.0	 1942.0	 5512	 5512	 0.0	 0.0	 1	 -30.0	 30.0;
	4938	 1141	 0.00028	 0.00448	 0.0	 1876.0	 7038	 7038	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 5898	 0.001091	 0.01663	 0.0	 457.0	 1896	 1896	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 7027	 0.011909	 0.080909	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 147	 0.000401	 0.00232	 0.0	 381.0	 13417	 13417	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 147	 0.000349	 0.00263	 0.0	 11907	 11907	 11907	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 5973	 0.000531	 0.0063	 0.0	 4997	 4997	 4997	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 464	 0.005531	 0.02938	 0.0	 533.0	 1057	 1057	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 7896	 0.00019	 0.002521	 0.0	 12495	 12495	 12495	 0.0	 0.0	 1	 -30.0	 30.0;
	5973	 5898	 0.00075	 0.010909	 0.0	 495.0	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	8362	 4176	 0.007	 0.03088	 0.0	 629.0	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	8362	 4453	 0.002349	 0.009281	 0.0	 553.0	 3300	 3300	 0.0	 0.0	 1	 -30.0	 30.0;
	5898	 5225	 0.003219	 0.02125	 0.0	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	5898	 5225	 0.004461	 0.027961	 0.0	 514.0	 1116	 1116	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 4284	 0.00105	 0.007901	 0.0	 629.0	 3964	 3964	 0.0	 0.0	 1	 -30.0	 30.0;
	6719	 4553	 0.002461	 0.01019	 0.0	 3014	 3014	 3014	 0.0	 0.0	 1	 -30.0	 30.0;
	6719	 4176	 0.00605	 0.028409	 0.0	 533.0	 1088	 1088	 0.0	 0.0	 1	 -30.0	 30.0;
	2097	 943	 7e-05	 0.00039	 0.0	 79720	 79720	 79720	 0.0	 0.0	 1	 -30.0	 30.0;
	5992	 1924	 0.0047	 0.02175	 0.0	 495.0	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	7459	 4342	 0.00118	 0.00719	 0.0	 591.0	 4336	 4336	 0.0	 0.0	 1	 -30.0	 30.0;
	7459	 227	 0.002349	 0.01887	 0.0	 1662	 1662	 1662	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 1586	 0.00104	 0.01314	 0.0	 1876.0	 2397	 2397	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 6666	 0.0004	 0.004	 0.0	 7858	 7858	 7858	 0.0	 0.0	 1	 -30.0	 30.0;
	8986	 6683	 0.001289	 0.006229	 0.0	 476.0	 4966	 4966	 0.0	 0.0	 1	 -30.0	 30.0;
	8986	 3569	 0.00555	 0.035419	 0.0	 438.0	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	8986	 3569	 0.00381	 0.0328	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	4553	 5905	 0.00093	 0.006841	 0.0	 4576	 4576	 4576	 0.0	 0.0	 1	 -30.0	 30.0;
	4553	 5905	 0.000909	 0.006979	 0.0	 4489	 4489	 4489	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 5576	 0.001091	 0.0082	 0.0	 514.0	 3819	 3819	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 4745	 0.002081	 0.020419	 0.0	 495.0	 1539	 1539	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 3432	 0.00082	 0.00276	 0.0	 10971	 10971	 10971	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 7027	 0.00162	 0.007021	 0.0	 4384	 4384	 4384	 0.0	 0.0	 1	 -30.0	 30.0;
	7872	 5844	 0.002831	 0.015021	 0.0	 572.0	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	7872	 135	 0.006781	 0.03026	 0.0	 514.0	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	1557	 3277	 0.00041	 0.00523	 0.0	 1777.0	 6022	 6022	 0.0	 0.0	 1	 -30.0	 30.0;
	1557	 4201	 0.00062	 0.0098	 0.0	 1810.0	 3217	 3217	 0.0	 0.0	 1	 -30.0	 30.0;
	1557	 4201	 0.00083	 0.00975	 0.0	 1843.0	 3229	 3229	 0.0	 0.0	 1	 -30.0	 30.0;
	3569	 8598	 0.00131	 0.01564	 0.0	 2013	 2013	 2013	 0.0	 0.0	 1	 -30.0	 30.0;
	3569	 7219	 0.002039	 0.026831	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	3569	 4745	 0.001031	 0.00945	 0.0	 3323	 3323	 3323	 0.0	 0.0	 1	 -30.0	 30.0;
	3569	 3742	 0.001789	 0.015211	 0.0	 2063	 2063	 2063	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 7219	 0.003021	 0.03739	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 382	 0.004211	 0.04031	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 3550	 0.004979	 0.029409	 0.0	 610.0	 1060	 1060	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 3550	 0.00488	 0.029979	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 2392	 0.002211	 0.02399	 0.0	 1312	 1312	 1312	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 2392	 0.00231	 0.023021	 0.0	 1366	 1366	 1366	 0.0	 0.0	 1	 -30.0	 30.0;
	464	 7027	 0.00719	 0.046841	 0.0	 553.0	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 5844	 0.00155	 0.00968	 0.0	 476.0	 3223	 3223	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 5844	 0.0015	 0.01051	 0.0	 2976	 2976	 2976	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 3041	 0.00169	 0.013401	 0.0	 2339	 2339	 2339	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 2556	 0.001659	 0.012409	 0.0	 629.0	 2524	 2524	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 7027	 0.005091	 0.0167	 0.0	 1810	 1810	 1810	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 2290	 0.009919	 0.04649	 0.0	 553.0	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 5242	 9.1e-05	 0.000531	 0.0	 58632	 58632	 58632	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 7219	 0.00982	 0.045331	 0.0	 553.0	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 9169	 0.003039	 0.02964	 0.0	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	1915	 3973	 0.004159	 0.02051	 0.0	 381.0	 1510	 1510	 0.0	 0.0	 1	 -30.0	 30.0;
	3432	 7027	 0.00087	 0.00469	 0.0	 6623	 6623	 6623	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 582	 0.0017	 0.021039	 0.0	 400.0	 1497	 1497	 0.0	 0.0	 1	 -30.0	 30.0;
	3277	 219	 0.00019	 0.0032	 0.0	 889.0	 9854	 9854	 0.0	 0.0	 1	 -30.0	 30.0;
	2487	 2926	 0.006979	 0.03975	 0.0	 495.0	 783	 783	 0.0	 0.0	 1	 -30.0	 30.0;
	2487	 582	 0.000521	 0.004081	 0.0	 7678	 7678	 7678	 0.0	 0.0	 1	 -30.0	 30.0;
	2487	 1062	 0.00382	 0.02214	 0.0	 553.0	 1406	 1406	 0.0	 0.0	 1	 -30.0	 30.0;
	1369	 4201	 0.00204	 0.02487	 0.0	 1266	 1266	 1266	 0.0	 0.0	 1	 -30.0	 30.0;
	6520	 4211	 0.00312	 0.018469	 0.0	 572.0	 1687	 1687	 0.0	 0.0	 1	 -30.0	 30.0;
	2926	 7027	 0.005479	 0.038841	 0.0	 553.0	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	135	 7219	 0.000789	 0.007729	 0.0	 4066	 4066	 4066	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 7239	 0.001789	 0.01618	 0.0	 572.0	 1941	 1941	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 7239	 0.00175	 0.016479	 0.0	 553.0	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	7239	 3973	 0.00375	 0.025099	 0.0	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 6433	 0.010778	 0.035609	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	6433	 1615	 0.0096	 0.04036	 0.0	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	7936	 4176	 0.001031	 0.016919	 0.0	 1864	 1864	 1864	 0.0	 0.0	 1	 -30.0	 30.0;
	7936	 4176	 0.00101	 0.01725	 0.0	 1829	 1829	 1829	 0.0	 0.0	 1	 -30.0	 30.0;
	7219	 4876	 0.00124	 0.013169	 0.0	 2389	 2389	 2389	 0.0	 0.0	 1	 -30.0	 30.0;
	7219	 4876	 0.00119	 0.01356	 0.0	 591.0	 2321	 2321	 0.0	 0.0	 1	 -30.0	 30.0;
	7219	 3742	 0.00119	 0.013281	 0.0	 2369	 2369	 2369	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 7467	 0.00306	 0.02405	 0.0	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 5225	 0.002469	 0.018081	 0.0	 629.0	 1731	 1731	 0.0	 0.0	 1	 -30.0	 30.0;
	7732	 6259	 0.0018	 0.014651	 0.0	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	7732	 2392	 0.001081	 0.010219	 0.0	 3074	 3074	 3074	 0.0	 0.0	 1	 -30.0	 30.0;
	6259	 7529	 0.000669	 0.003521	 0.0	 8814	 8814	 8814	 0.0	 0.0	 1	 -30.0	 30.0;
	7027	 356	 0.001039	 0.0142	 0.0	 2219	 2219	 2219	 0.0	 0.0	 1	 -30.0	 30.0;
	7027	 1789	 0.002771	 0.019919	 0.0	 1571	 1571	 1571	 0.0	 0.0	 1	 -30.0	 30.0;
	3407	 4876	 0.00295	 0.013401	 0.0	 2302	 2302	 2302	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 2257	 0.00411	 0.02488	 0.0	 1253	 1253	 1253	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 8488	 0.00061	 0.007211	 0.0	 4365	 4365	 4365	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 811	 0.002219	 0.011081	 0.0	 2796	 2796	 2796	 0.0	 0.0	 1	 -30.0	 30.0;
	7153	 2963	 6e-05	 0.00066	 0.0	 757.0	 47664	 47664	 0.0	 0.0	 1	 -30.0	 30.0;
	4211	 2556	 0.00411	 0.026081	 0.0	 629.0	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	9235	 6666	 0.00168	 0.02222	 0.0	 1418	 1418	 1418	 0.0	 0.0	 1	 -30.0	 30.0;
	9235	 2963	 0.00049	 0.0061	 0.0	 1843.0	 5162	 5162	 0.0	 0.0	 1	 -30.0	 30.0;
	2257	 6335	 0.00082	 0.00575	 0.0	 5439	 5439	 5439	 0.0	 0.0	 1	 -30.0	 30.0;
	7896	 2290	 0.001409	 0.01918	 0.0	 1643	 1643	 1643	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 8276	 0.001841	 0.011159	 0.0	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 2963	 0.00109	 0.01044	 0.0	 3010	 3010	 3010	 0.0	 0.0	 1	 -30.0	 30.0;
	4830	 1141	 0.00088	 0.01608	 0.0	 1909.0	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	4176	 4369	 0.000591	 0.007781	 0.0	 4048	 4048	 4048	 0.0	 0.0	 1	 -30.0	 30.0;
	4176	 3088	 0.001901	 0.0247	 0.0	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	7785	 6817	 0.00382	 0.018401	 0.0	 1681	 1681	 1681	 0.0	 0.0	 1	 -30.0	 30.0;
	7529	 6817	 0.004169	 0.02775	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	7529	 2392	 0.001849	 0.01889	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	2290	 3088	 0.00076	 0.01036	 0.0	 3041	 3041	 3041	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 688	 0.00207	 0.009849	 0.0	 3139	 3139	 3139	 0.0	 0.0	 1	 -30.0	 30.0;
	7817	 382	 0.001849	 0.013841	 0.0	 2263	 2263	 2263	 0.0	 0.0	 1	 -30.0	 30.0;
	7817	 382	 0.00243	 0.015771	 0.0	 1980	 1980	 1980	 0.0	 0.0	 1	 -30.0	 30.0;
	6666	 1653	 0.00128	 0.01149	 0.0	 1678.0	 2733	 2733	 0.0	 0.0	 1	 -30.0	 30.0;
	2191	 721	 0.00057	 0.005961	 0.0	 5275	 5275	 5275	 0.0	 0.0	 1	 -30.0	 30.0;
	2191	 6375	 0.00218	 0.015099	 0.0	 2071	 2071	 2071	 0.0	 0.0	 1	 -30.0	 30.0;
	382	 5242	 0.00131	 0.008771	 0.0	 553.0	 3562	 3562	 0.0	 0.0	 1	 -30.0	 30.0;
	721	 6375	 0.00163	 0.008729	 0.0	 3558	 3558	 3558	 0.0	 0.0	 1	 -30.0	 30.0;
	1406	 4700	 0.004831	 0.02588	 0.0	 533.0	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	227	 3124	 0.00062	 0.00857	 0.0	 3677	 3677	 3677	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 5905	 0.002281	 0.0362	 0.0	 871	 871	 871	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 9169	 0.00132	 0.01036	 0.0	 3025	 3025	 3025	 0.0	 0.0	 1	 -30.0	 30.0;
	4700	 2392	 0.00281	 0.017099	 0.0	 1823	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	2392	 1603	 0.00424	 0.0258	 0.0	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	711	 7953	 0.00036	 0.00313	 0.0	 1744.0	 10026	 10026	 0.0	 0.0	 1	 -30.0	 30.0;
	6088	 9060	 0.00112	 0.0114	 0.0	 1678.0	 2758	 2758	 0.0	 0.0	 1	 -30.0	 30.0;
	6088	 5988	 0.00046	 0.007	 0.0	 1053.0	 4503	 4503	 0.0	 0.0	 1	 -30.0	 30.0;
	6088	 372	 0.00113	 0.01516	 0.0	 1448.0	 2078	 2078	 0.0	 0.0	 1	 -30.0	 30.0;
	9060	 2153	 0.00138	 0.01478	 0.0	 1185.0	 2128	 2128	 0.0	 0.0	 1	 -30.0	 30.0;
	9060	 518	 0.00107	 0.01447	 0.0	 1448.0	 2178	 2178	 0.0	 0.0	 1	 -30.0	 30.0;
	6099	 1387	 0.012651	 0.08939	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	6099	 6014	 0.00957	 0.05424	 0.0	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 3446	 0.0017	 0.01823	 0.0	 987.0	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 6007	 0.00092	 0.00892	 0.0	 1283.0	 3523	 3523	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 1884	 0.00063	 0.00829	 0.0	 1251.0	 3800	 3800	 0.0	 0.0	 1	 -30.0	 30.0;
	2153	 8728	 0.00052	 0.00757	 0.0	 921.0	 4163	 4163	 0.0	 0.0	 1	 -30.0	 30.0;
	8728	 6569	 0.00189	 0.02546	 0.0	 987.0	 1238	 1238	 0.0	 0.0	 1	 -30.0	 30.0;
	8728	 4195	 0.00044	 0.00602	 0.0	 987.0	 5234	 5234	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 5620	 0.00138	 0.01477	 0.0	 1777.0	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 6468	 0.00055	 0.00597	 0.0	 1645.0	 5269	 5269	 0.0	 0.0	 1	 -30.0	 30.0;
	372	 3808	 0.00047	 0.00684	 0.0	 1613.0	 4608	 4608	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 3375	 0.0038	 0.026331	 0.0	 476.0	 1188	 1188	 0.0	 0.0	 1	 -30.0	 30.0;
	2153	 2465	 0.001	 0.00937	 0.0	 823.0	 3353	 3353	 0.0	 0.0	 1	 -30.0	 30.0;
	2153	 372	 0.00203	 0.01819	 0.0	 1613.0	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 6373	 0.002419	 0.015021	 0.0	 419.0	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 6373	 0.00274	 0.014719	 0.0	 2110	 2110	 2110	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 3599	 0.014599	 0.077461	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 7107	 0.012461	 0.05613	 0.0	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 3375	 0.014581	 0.083849	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	7114	 6569	 0.0006	 0.00665	 0.0	 1547.0	 4731	 4731	 0.0	 0.0	 1	 -30.0	 30.0;
	7114	 6569	 0.00057	 0.00856	 0.0	 1316.0	 3682	 3682	 0.0	 0.0	 1	 -30.0	 30.0;
	7114	 6007	 0.00234	 0.02648	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	2465	 3920	 0.00019	 0.00167	 0.0	 889.0	 18794	 18794	 0.0	 0.0	 1	 -30.0	 30.0;
	2465	 2098	 0.00019	 0.00164	 0.0	 823.0	 19133	 19133	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 8279	 3e-05	 0.00047	 0.0	 757.0	 67071	 67071	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 844	 3e-05	 0.00048	 0.0	 757.0	 65679	 65679	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 4046	 0.00097	 0.01084	 0.0	 954.0	 2903	 2903	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 5855	 8e-05	 0.00073	 0.0	 1086.0	 43013	 43013	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 4969	 8e-05	 0.0006	 0.0	 1020.0	 52184	 52184	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 1555	 7e-05	 0.00067	 0.0	 1020.0	 46891	 46891	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 714	 7e-05	 0.00066	 0.0	 1053.0	 47593	 47593	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 562	 0.00145	 0.00707	 0.0	 4377	 4377	 4377	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 3389	 0.00164	 0.00693	 0.0	 4436	 4436	 4436	 0.0	 0.0	 1	 -30.0	 30.0;
	372	 7214	 8e-05	 0.00084	 0.0	 1119.0	 37435	 37435	 0.0	 0.0	 1	 -30.0	 30.0;
	372	 5412	 0.0001	 0.00083	 0.0	 1152.0	 37784	 37784	 0.0	 0.0	 1	 -30.0	 30.0;
	372	 8156	 0.0001	 0.00081	 0.0	 1119.0	 38703	 38703	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 6366	 0.00019	 0.00215	 0.0	 757.0	 14635	 14635	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 3910	 0.00037	 0.00292	 0.0	 1119.0	 10732	 10732	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 2084	 0.00033	 0.00332	 0.0	 757.0	 9468	 9468	 0.0	 0.0	 1	 -30.0	 30.0;
	3551	 4076	 0.002031	 0.01382	 0.0	 457.0	 2262	 2262	 0.0	 0.0	 1	 -30.0	 30.0;
	3551	 2590	 0.001979	 0.014091	 0.0	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	6569	 2973	 4e-05	 0.00052	 0.0	 1843.0	 60566	 60566	 0.0	 0.0	 1	 -30.0	 30.0;
	6569	 1138	 4e-05	 0.00054	 0.0	 1678.0	 58336	 58336	 0.0	 0.0	 1	 -30.0	 30.0;
	3551	 7376	 0.00136	 0.0067	 0.0	 4621	 4621	 4621	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 4400	 0.0001	 0.00078	 0.0	 1119.0	 40168	 40168	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 1606	 0.00011	 0.00076	 0.0	 1086.0	 41134	 41134	 0.0	 0.0	 1	 -30.0	 30.0;
	3446	 3290	 0.00376	 0.04872	 0.0	 647	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 5882	 0.0002	 0.00258	 0.0	 1185.0	 12207	 12207	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 372	 0.00089	 0.0087	 0.0	 1086.0	 3612	 3612	 0.0	 0.0	 1	 -30.0	 30.0;
	291	 3551	 0.01282	 0.053159	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	291	 6995	 0.002219	 0.01038	 0.0	 457.0	 2976	 2976	 0.0	 0.0	 1	 -30.0	 30.0;
	291	 3551	 0.01307	 0.05205	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	291	 3375	 0.00449	 0.01863	 0.0	 457.0	 1649	 1649	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 4195	 0.00215	 0.0248	 0.0	 1269	 1269	 1269	 0.0	 0.0	 1	 -30.0	 30.0;
	2357	 6251	 0.00192	 0.02113	 0.0	 1053.0	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	2357	 7953	 0.00165	 0.01704	 0.0	 757.0	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	6569	 6468	 0.00168	 0.02469	 0.0	 1053.0	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	6569	 4195	 0.00222	 0.02324	 0.0	 1283.0	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 518	 0.00173	 0.01682	 0.0	 1119.0	 1869	 1869	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 5343	 0.00174	 0.01872	 0.0	 1349.0	 1681	 1681	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 2465	 0.00194	 0.02194	 0.0	 1218.0	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	9230	 3340	 0.013831	 0.056841	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	9230	 3340	 0.014091	 0.055599	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 202	 0.009081	 0.05263	 0.0	 400.0	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 5468	 0.007401	 0.05661	 0.0	 419.0	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	7953	 5343	 0.00164	 0.01627	 0.0	 1382.0	 1932	 1932	 0.0	 0.0	 1	 -30.0	 30.0;
	7107	 2588	 0.022909	 0.124591	 0.0	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 5343	 0.00074	 0.00791	 0.0	 1448.0	 3976	 3976	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 1884	 0.00136	 0.01726	 0.0	 1152.0	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	202	 3551	 0.011211	 0.07026	 0.0	 381.0	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	202	 3551	 0.01143	 0.06882	 0.0	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	5343	 4195	 0.00544	 0.06455	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	3340	 2588	 0.016289	 0.066719	 0.0	 381.0	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3340	 2588	 0.016591	 0.065271	 0.0	 381.0	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 1884	 0.00077	 0.0096	 0.0	 1349.0	 3280	 3280	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 1884	 0.00093	 0.00905	 0.0	 1316.0	 3473	 3473	 0.0	 0.0	 1	 -30.0	 30.0;
	2588	 5468	 0.021729	 0.15268	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 6995	 0.00064	 0.002919	 0.0	 10571	 10571	 10571	 0.0	 0.0	 1	 -30.0	 30.0;
	6995	 3375	 0.002211	 0.009169	 0.0	 457.0	 3350	 3350	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 9090	 0.00014	 0.001729	 0.0	 18210	 18210	 18210	 0.0	 0.0	 1	 -30.0	 30.0;
	5021	 9090	 0.0002	 0.00281	 0.0	 11213	 11213	 11213	 0.0	 0.0	 1	 -30.0	 30.0;
	2657	 5514	 0.000711	 0.004289	 0.0	 629.0	 7266	 7266	 0.0	 0.0	 1	 -30.0	 30.0;
	2657	 6986	 0.0007	 0.00438	 0.0	 610.0	 7122	 7122	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 2657	 0.00032	 0.00437	 0.0	 629.0	 7209	 7209	 0.0	 0.0	 1	 -30.0	 30.0;
	5514	 5784	 7e-05	 0.000401	 0.0	 610.0	 77598	 77598	 0.0	 0.0	 1	 -30.0	 30.0;
	6986	 8528	 7e-05	 0.000401	 0.0	 572.0	 77598	 77598	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 5784	 0.00189	 0.0083	 0.0	 629.0	 3711	 3711	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 8528	 0.00168	 0.009401	 0.0	 572.0	 3308	 3308	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 7194	 0.000151	 0.00169	 0.0	 629.0	 18617	 18617	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 7410	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 7410	 0.001	 0.120531	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 6234	 4.583678	 10.16446	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 5680	 8.430371	 11.9126	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 2895	 8.911157	 11.64008	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 6234	 7.455785	 17.24773	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 6234	 9.746074	 17.22748	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 6234	 0.796777	 2.654959	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 6234	 0.960248	 2.559091	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 6234	 5.215909	 9.009917	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 6234	 5.097107	 9.164256	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 6234	 19.22748	 20.93388	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 6234	 17.18905	 24.75	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 2955	 17.2064	 22.05785	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 6234	 0.227459	 1.377252	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 6234	 0.13382	 0.643926	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 6234	 0.211219	 1.206674	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 6234	 0.230165	 1.120413	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 6234	 29.19835	 48.54959	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 6234	 0.13231	 0.939504	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 6234	 0.842851	 2.338843	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 6234	 0.820764	 2.471488	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 6234	 0.553244	 1.973719	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 6234	 0.01405	 0.0548	 0.0	 419.0	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 1581	 1.071157	 2.739256	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 1581	 0.00774	 0.04075	 0.0	 438.0	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 6234	 16.64566	 21.19835	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 6234	 16.22913	 16.64318	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 7410	 10.87128	 19.07149	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7410	 5680	 15.62583	 25.67355	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7410	 2895	 16.95331	 27.19835	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 7410	 16.6593	 34.37603	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 7410	 19.6814	 37.93595	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 7410	 1.881012	 4.967975	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 7410	 1.902851	 5.765909	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 7410	 10.14587	 20.68595	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 7410	 10.93058	 18.98595	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 7410	 36.07851	 50.20248	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 7410	 40.72727	 46.32438	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7410	 2955	 36.24587	 46.68595	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 7410	 0.444855	 2.8	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 7410	 0.273946	 1.391054	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 7410	 0.514545	 2.160744	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 7410	 0.450992	 2.507851	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 7410	 0.292665	 1.871012	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 7410	 1.795062	 4.826033	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 7410	 1.551219	 5.755991	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 7410	 1.089959	 4.426653	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	7410	 1581	 0.00757	 0.037729	 0.0	 495.0	 821	 821	 0.0	 0.0	 1	 -30.0	 30.0;
	7410	 1581	 2.158264	 6.029752	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 7410	 35.04132	 44.83471	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 7410	 30.36983	 39.79132	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 4334	 0.00058	 0.00554	 0.0	 1316.0	 5671	 5671	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 5941	 0.00116	 0.01169	 0.0	 1382.0	 2689	 2689	 0.0	 0.0	 1	 -30.0	 30.0;
	6284	 4334	 0.00052	 0.00627	 0.0	 1448.0	 5021	 5021	 0.0	 0.0	 1	 -30.0	 30.0;
	6284	 5941	 0.00118	 0.01144	 0.0	 1448.0	 2747	 2747	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 6284	 0.001	 0.223012	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 4334	 0.05072	 0.617493	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 5941	 0.05373	 0.600208	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	324	 5401	 0.381143	 1.437258	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	6284	 4334	 0.04991	 0.630229	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	6284	 5941	 0.05131	 0.624993	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	324	 6284	 0.389938	 1.410526	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 5178	 0.00059	 0.00463	 0.0	 6768	 6768	 6768	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 1596	 0.00047	 0.0038	 0.0	 8250	 8250	 8250	 0.0	 0.0	 1	 -30.0	 30.0;
	6272	 7643	 0.0006	 0.00453	 0.0	 6913	 6913	 6913	 0.0	 0.0	 1	 -30.0	 30.0;
	6272	 5178	 0.03442	 0.298892	 0.0	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	6272	 7643	 0.03377	 0.305229	 0.0	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	6272	 6615	 0.00047	 0.00372	 0.0	 8425	 8425	 8425	 0.0	 0.0	 1	 -30.0	 30.0;
	4472	 600	 0.00036	 0.00341	 0.0	 1185.0	 9212	 9212	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 4472	 0.00164	 0.01639	 0.0	 1185.0	 1918	 1918	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 6212	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 6212	 0.001	 0.13669	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 7711	 2.103099	 5.086777	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 7198	 0.004781	 0.02089	 0.0	 495.0	 1474	 1474	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 4789	 46.67975	 63.95455	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 7592	 45.98967	 55.45455	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 6421	 1.337128	 3.255992	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 1085	 0.09056	 0.365041	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 3913	 0.085081	 0.477665	 0.0	 66	 66	 66	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 3913	 0.008	 0.040669	 0.0	 419.0	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 7711	 2.446281	 4.115289	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 98	 0.00488	 0.020469	 0.0	 591.0	 1502	 1502	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 4789	 44.43595	 63.26653	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 7592	 47.34298	 50.52893	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6421	 1.382355	 2.978719	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 1085	 0.07226	 0.393864	 0.0	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 1085	 0.007831	 0.04144	 0.0	 419.0	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 3913	 0.08989	 0.428161	 0.0	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	3727	 7971	 0.00055	 0.00435	 0.0	 1810.0	 7205	 7205	 0.0	 0.0	 1	 -30.0	 30.0;
	2260	 7971	 0.00128	 0.00706	 0.0	 1909.0	 4403	 4403	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 5555	 0.00053	 0.00407	 0.0	 1283.0	 7697	 7697	 0.0	 0.0	 1	 -30.0	 30.0;
	6965	 5555	 0.00056	 0.00478	 0.0	 1711.0	 6564	 6564	 0.0	 0.0	 1	 -30.0	 30.0;
	8342	 3727	 0.208393	 1.089612	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 3727	 0.199571	 1.1759	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 3727	 0.02232	 0.346918	 0.0	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	3102	 3727	 0.858172	 1.866898	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 3727	 0.00031	 0.00216	 0.0	 1547.0	 14476	 14476	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 3727	 0.001	 0.274529	 0.0	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 3727	 4.431302	 8.136427	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 8553	 0.36115	 2.404917	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 192	 0.319377	 2.230125	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 3349	 0.325519	 2.183657	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 8851	 1.726316	 5.458795	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 6894	 2.428047	 7.275623	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 9100	 0.00056	 0.00716	 0.0	 1349.0	 4399	 4399	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 9100	 0.527043	 3.451801	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 5717	 0.515582	 3.196122	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 6222	 1.334072	 5.856163	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 8465	 0.0011	 0.01318	 0.0	 1547.0	 2389	 2389	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 8802	 0.00108	 0.01344	 0.0	 1580.0	 2343	 2343	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 5717	 0.00063	 0.00702	 0.0	 1613.0	 4482	 4482	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 1029	 0.246612	 1.335723	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 1029	 0.008229	 0.04962	 0.0	 476.0	 629	 629	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 3431	 0.219628	 1.572521	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 4033	 4.089256	 11.14855	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 1238	 0.00943	 0.04726	 0.0	 514.0	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 1238	 3.689876	 10.15083	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 438	 0.202581	 1.497417	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 1907	 0.1973	 1.490124	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 276	 0.0028	 0.013271	 0.0	 457.0	 2329	 2329	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 3330	 0.12369	 1.125744	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 1587	 1.335496	 4.761364	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 8938	 1.15	 4.888636	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 1177	 1.052913	 5.261983	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 3431	 0.00932	 0.04863	 0.0	 476.0	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 4033	 0.00961	 0.046281	 0.0	 514.0	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 5929	 0.0025	 0.015031	 0.0	 419.0	 2074	 2074	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 7601	 0.0008	 0.00519	 0.0	 438.0	 6016	 6016	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 1238	 0.00612	 0.03036	 0.0	 495.0	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	7601	 1854	 0.00038	 0.00243	 0.0	 457.0	 12843	 12843	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 6221	 0.000909	 0.005091	 0.0	 438.0	 6108	 6108	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 438	 0.00187	 0.00944	 0.0	 438.0	 3283	 3283	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 1854	 0.00043	 0.00238	 0.0	 457.0	 13061	 13061	 0.0	 0.0	 1	 -30.0	 30.0;
	8693	 4214	 0.00013	 0.00176	 0.0	 1415.0	 17899	 17899	 0.0	 0.0	 1	 -30.0	 30.0;
	8693	 4214	 0.00013	 0.00179	 0.0	 1580.0	 17601	 17601	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 1066	 0.00018	 0.00189	 0.0	 16638	 16638	 16638	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 7175	 0.0002	 0.00185	 0.0	 16976	 16976	 16976	 0.0	 0.0	 1	 -30.0	 30.0;
	1066	 1522	 0.00039	 0.00344	 0.0	 1876.0	 9124	 9124	 0.0	 0.0	 1	 -30.0	 30.0;
	7175	 5716	 0.0004	 0.00337	 0.0	 1942.0	 9308	 9308	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 8421	 0.00027	 0.00274	 0.0	 11473	 11473	 11473	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 1253	 0.00056	 0.00437	 0.0	 7170	 7170	 7170	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 6657	 0.00026	 0.00279	 0.0	 11273	 11273	 11273	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 2788	 0.001349	 0.00763	 0.0	 4077	 4077	 4077	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 2608	 0.00374	 0.02218	 0.0	 1405	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 7321	 0.000349	 0.00186	 0.0	 16692	 16692	 16692	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 2608	 0.004651	 0.02025	 0.0	 1521	 1521	 1521	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 7321	 0.00037	 0.00182	 0.0	 17008	 17008	 17008	 0.0	 0.0	 1	 -30.0	 30.0;
	7502	 4101	 0.001	 0.209093	 0.0	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	7502	 8342	 0.00062	 0.00513	 0.0	 6113	 6113	 6113	 0.0	 0.0	 1	 -30.0	 30.0;
	7502	 2511	 0.04427	 0.493158	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	7502	 1522	 2.319321	 5.378532	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 7502	 2.762188	 4.809072	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 7502	 24.69598	 23.43698	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7502	 8429	 1.383864	 4.675693	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 7502	 0.470817	 2.500277	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	1150	 7502	 0.00099	 0.00946	 0.0	 3321	 3321	 3321	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 7502	 0.05862	 0.781925	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 2511	 0.04335	 0.502652	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 2511	 0.00063	 0.00502	 0.0	 1678.0	 6244	 6244	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 1522	 2.364751	 5.268767	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 4101	 2.814266	 4.706787	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 4101	 25.15305	 22.92729	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 9084	 0.00032	 0.00223	 0.0	 14022	 14022	 14022	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 8429	 1.353809	 4.329363	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 4101	 0.460582	 2.315097	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 4101	 0.0574	 0.796953	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 2102	 0.00439	 0.016341	 0.0	 1867	 1867	 1867	 0.0	 0.0	 1	 -30.0	 30.0;
	252	 5719	 0.004039	 0.019031	 0.0	 533.0	 1624	 1624	 0.0	 0.0	 1	 -30.0	 30.0;
	252	 8498	 0.001331	 0.007669	 0.0	 514.0	 4059	 4059	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 7240	 0.001091	 0.005159	 0.0	 533.0	 5991	 5991	 0.0	 0.0	 1	 -30.0	 30.0;
	8498	 2071	 0.00131	 0.00782	 0.0	 457.0	 3984	 3984	 0.0	 0.0	 1	 -30.0	 30.0;
	2071	 2743	 0.00449	 0.022021	 0.0	 457.0	 1406	 1406	 0.0	 0.0	 1	 -30.0	 30.0;
	8342	 2511	 0.0	 0.0002	 0.0	 1448.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8342	 2511	 0.001	 0.229342	 0.0	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 8342	 0.159093	 0.880956	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	3102	 8342	 0.11009	 0.785942	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 8342	 0.00133	 0.01275	 0.0	 2465	 2465	 2465	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 8342	 0.08106	 0.897645	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 8342	 0.0009	 0.00658	 0.0	 1514.0	 4757	 4757	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 8342	 1.066967	 3.005956	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 8342	 0.00037	 0.00335	 0.0	 1678.0	 9373	 9373	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 2511	 0.14919	 0.968975	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	3102	 2511	 0.107472	 0.83054	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 1522	 6.591066	 12.31994	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 2511	 0.089861	 0.931163	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 2511	 0.00151	 0.0125	 0.0	 2509	 2509	 2509	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 2511	 7.50831	 11.99515	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 2511	 57.05332	 52.93698	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 2511	 1.218213	 2.697091	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 2511	 0.00091	 0.00644	 0.0	 1481.0	 4857	 4857	 0.0	 0.0	 1	 -30.0	 30.0;
	8429	 2511	 5.391066	 9.229224	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 2511	 1.899723	 5.672438	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	1165	 2511	 0.00034	 0.00341	 0.0	 1810.0	 9218	 9218	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 2511	 0.372853	 1.916066	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 2912	 0.001	 0.398657	 0.0	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 2196	 0.00157	 0.00875	 0.0	 400.0	 3554	 3554	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 2912	 0.013419	 0.18632	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 2196	 0.001771	 0.00857	 0.0	 3610	 3610	 3610	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 7102	 3e-05	 0.00035	 0.0	 1316.0	 89920	 89920	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 4645	 4e-05	 0.00047	 0.0	 1283.0	 66966	 66966	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 7711	 6.406818	 19.24731	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 7711	 5.408471	 18.64401	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 7711	 4.777893	 12.85021	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7711	 1067	 7.316529	 22.04545	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7711	 1067	 0.00518	 0.053229	 0.0	 400.0	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 7711	 1.28	 5.819421	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 7711	 1.306178	 5.47314	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	7711	 6421	 0.001	 0.244421	 0.0	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 7711	 0.326384	 2.031736	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	3913	 7711	 0.34876	 2.295661	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	7711	 6421	 0.000401	 0.00324	 0.0	 419.0	 9676	 9676	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 8553	 1.103116	 4.165166	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 8553	 0.982756	 4.720568	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 8553	 17.77701	 32.87327	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8553	 6894	 11.94321	 24.78324	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	9100	 8553	 0.13187	 1.326939	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 8553	 0.129169	 1.352909	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 8553	 15.47438	 32.5367	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8693	 8553	 0.00019	 0.00211	 0.0	 1251.0	 14910	 14910	 0.0	 0.0	 1	 -30.0	 30.0;
	8693	 8553	 0.0002	 0.00206	 0.0	 1218.0	 15262	 15262	 0.0	 0.0	 1	 -30.0	 30.0;
	7684	 3860	 0.00013	 0.001771	 0.0	 17789	 17789	 17789	 0.0	 0.0	 1	 -30.0	 30.0;
	6715	 5323	 0.008081	 0.041651	 0.0	 400.0	 745	 745	 0.0	 0.0	 1	 -30.0	 30.0;
	6715	 5323	 0.168091	 0.83657	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	6715	 5323	 0.008229	 0.040771	 0.0	 438.0	 760	 760	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 5323	 2.293802	 5.98719	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	2237	 5323	 2.825	 5.516736	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 4350	 0.731178	 1.985165	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	7811	 6715	 0.001349	 0.01345	 0.0	 2337	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	648	 7811	 0.00051	 0.00643	 0.0	 400.0	 4898	 4898	 0.0	 0.0	 1	 -30.0	 30.0;
	7445	 6715	 0.00137	 0.013159	 0.0	 2388	 2388	 2388	 0.0	 0.0	 1	 -30.0	 30.0;
	648	 7445	 0.0005	 0.00655	 0.0	 381.0	 4809	 4809	 0.0	 0.0	 1	 -30.0	 30.0;
	9037	 6584	 0.001	 0.425381	 0.0	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	6497	 6584	 4.659141	 9.407202	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 6584	 1.022853	 3.286357	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	6584	 4296	 1.18795	 4.384626	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	6584	 5611	 1.213781	 4.303324	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 6584	 8.581024	 12.40582	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7483	 6584	 0.203857	 1.400623	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	6584	 4296	 0.00082	 0.0099	 0.0	 3180	 3180	 3180	 0.0	 0.0	 1	 -30.0	 30.0;
	7483	 6584	 0.00056	 0.0066	 0.0	 1777.0	 4769	 4769	 0.0	 0.0	 1	 -30.0	 30.0;
	4478	 6584	 0.00031	 0.00634	 0.0	 1020.0	 4977	 4977	 0.0	 0.0	 1	 -30.0	 30.0;
	6497	 9037	 4.02687	 9.790858	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 9037	 1.000554	 3.350416	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	9037	 5611	 0.00081	 0.0101	 0.0	 1514.0	 3118	 3118	 0.0	 0.0	 1	 -30.0	 30.0;
	9037	 4296	 1.418213	 3.650623	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	9037	 5611	 1.263504	 4.137327	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 9037	 8.415512	 12.67105	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7483	 9037	 0.172188	 1.486496	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 6715	 0.008531	 0.04201	 0.0	 457.0	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 6715	 0.19088	 1.317025	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	2237	 6715	 0.20351	 1.242748	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	6715	 7240	 0.003419	 0.02226	 0.0	 514.0	 1403	 1403	 0.0	 0.0	 1	 -30.0	 30.0;
	6715	 4350	 0.05611	 0.44343	 0.0	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	2237	 6715	 0.00869	 0.041091	 0.0	 457.0	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	6715	 4153	 0.003349	 0.02268	 0.0	 495.0	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	6978	 6715	 0.00176	 0.018651	 0.0	 800.0	 1687	 1687	 0.0	 0.0	 1	 -30.0	 30.0;
	7505	 1918	 0.00019	 0.00245	 0.0	 757.0	 12855	 12855	 0.0	 0.0	 1	 -30.0	 30.0;
	7505	 1918	 0.00019	 0.00227	 0.0	 757.0	 13867	 13867	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 4296	 0.00018	 0.00209	 0.0	 15058	 15058	 15058	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 5611	 0.00017	 0.00213	 0.0	 1744.0	 14783	 14783	 0.0	 0.0	 1	 -30.0	 30.0;
	6753	 424	 0.00024	 0.0025	 0.0	 1382.0	 12578	 12578	 0.0	 0.0	 1	 -30.0	 30.0;
	6497	 4766	 0.897576	 2.903878	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 6497	 0.01432	 0.301302	 0.0	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 6497	 0.00025	 0.00245	 0.0	 1382.0	 12827	 12827	 0.0	 0.0	 1	 -30.0	 30.0;
	6497	 7483	 3.381094	 7.270776	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	4709	 3102	 0.00142	 0.01435	 0.0	 1777.0	 2191	 2191	 0.0	 0.0	 1	 -30.0	 30.0;
	4709	 1079	 0.00023	 0.00181	 0.0	 1810.0	 17313	 17313	 0.0	 0.0	 1	 -30.0	 30.0;
	7954	 3102	 0.00139	 0.01463	 0.0	 1843.0	 2150	 2150	 0.0	 0.0	 1	 -30.0	 30.0;
	7954	 6847	 0.00023	 0.00178	 0.0	 1843.0	 17600	 17600	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 6160	 0.00047	 0.00384	 0.0	 1218.0	 8165	 8165	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 2990	 0.0005	 0.00403	 0.0	 1645.0	 7779	 7779	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 2990	 0.00025	 0.00236	 0.0	 1251.0	 13310	 13310	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 3102	 0.838573	 2.37223	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 1161	 0.078193	 0.509841	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 1161	 5.654848	 7.590028	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	7346	 3102	 0.0009	 0.0069	 0.0	 1810.0	 4540	 4540	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 7346	 0.0002	 0.00149	 0.0	 21012	 21012	 21012	 0.0	 0.0	 1	 -30.0	 30.0;
	9152	 3102	 0.00092	 0.00675	 0.0	 1876.0	 4637	 4637	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 9152	 0.0002	 0.00145	 0.0	 21581	 21581	 21581	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 3102	 0.413608	 1.666759	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 3102	 0.03562	 0.272507	 0.0	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	4886	 622	 0.0001	 0.00144	 0.0	 1744.0	 21883	 21883	 0.0	 0.0	 1	 -30.0	 30.0;
	8693	 4886	 9e-05	 0.00129	 0.0	 24427	 24427	 24427	 0.0	 0.0	 1	 -30.0	 30.0;
	1593	 6611	 0.0001	 0.00133	 0.0	 23684	 23684	 23684	 0.0	 0.0	 1	 -30.0	 30.0;
	8693	 1593	 9e-05	 0.00132	 0.0	 23875	 23875	 23875	 0.0	 0.0	 1	 -30.0	 30.0;
	622	 8404	 0.00063	 0.00676	 0.0	 1942.0	 4653	 4653	 0.0	 0.0	 1	 -30.0	 30.0;
	6611	 2342	 0.00065	 0.00662	 0.0	 1777.0	 4749	 4749	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 8404	 0.00017	 0.00236	 0.0	 1645.0	 13350	 13350	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 2342	 0.00017	 0.00219	 0.0	 1744.0	 14381	 14381	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 8929	 0.0017	 0.007469	 0.0	 4124	 4124	 4124	 0.0	 0.0	 1	 -30.0	 30.0;
	8929	 7198	 0.001039	 0.005599	 0.0	 514.0	 5547	 5547	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 7457	 0.001729	 0.00731	 0.0	 495.0	 4206	 4206	 0.0	 0.0	 1	 -30.0	 30.0;
	7457	 98	 0.001021	 0.0057	 0.0	 495.0	 5455	 5455	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 1790	 0.00168	 0.007159	 0.0	 419.0	 4296	 4296	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 7198	 0.00112	 0.00495	 0.0	 419.0	 6224	 6224	 0.0	 0.0	 1	 -30.0	 30.0;
	8929	 7457	 0.001	 0.364917	 0.0	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 8929	 0.106669	 0.821178	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	8929	 7198	 0.0977	 0.935248	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	8929	 98	 0.10481	 0.756446	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 7457	 0.094539	 0.895083	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	7457	 7198	 0.09563	 0.921384	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	7457	 98	 0.085479	 0.810062	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 3631	 0.0002	 0.0021	 0.0	 1481.0	 14974	 14974	 0.0	 0.0	 1	 -30.0	 30.0;
	3631	 6538	 0.00051	 0.00613	 0.0	 1678.0	 5136	 5136	 0.0	 0.0	 1	 -30.0	 30.0;
	7299	 6152	 0.00062	 0.006331	 0.0	 4966	 4966	 4966	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 1587	 0.00075	 0.00981	 0.0	 3211	 3211	 3211	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 8614	 0.00105	 0.01369	 0.0	 2301	 2301	 2301	 0.0	 0.0	 1	 -30.0	 30.0;
	8614	 491	 0.00132	 0.01291	 0.0	 1645.0	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 6137	 0.00103	 0.01395	 0.0	 1777.0	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 7545	 0.00134	 0.01263	 0.0	 2488	 2488	 2488	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 5941	 0.269647	 1.156579	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	324	 4334	 0.06211	 0.718075	 0.0	 44	 44	 44	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 590	 0.00062	 0.005	 0.0	 1580.0	 6270	 6270	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 4334	 0.00031	 0.00248	 0.0	 1744.0	 12639	 12639	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 2394	 0.0006	 0.0051	 0.0	 1678.0	 6152	 6152	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 2743	 0.007331	 0.044461	 0.0	 457.0	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 2743	 0.00718	 0.0453	 0.0	 457.0	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	7299	 375	 0.0002	 0.00211	 0.0	 629.0	 14904	 14904	 0.0	 0.0	 1	 -30.0	 30.0;
	5021	 375	 0.000659	 0.002909	 0.0	 629.0	 10591	 10591	 0.0	 0.0	 1	 -30.0	 30.0;
	6657	 7440	 0.00088	 0.0079	 0.0	 3974	 3974	 3974	 0.0	 0.0	 1	 -30.0	 30.0;
	8421	 8006	 0.00089	 0.00774	 0.0	 4055	 4055	 4055	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 4345	 0.00089	 0.00706	 0.0	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1861	 0.0009	 0.0069	 0.0	 4540	 4540	 4540	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 1522	 0.527957	 1.890097	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 1522	 6.434972	 8.855956	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8429	 1522	 0.02292	 0.469398	 0.0	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 1522	 0.03034	 0.81482	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 1522	 0.225173	 1.343006	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	4298	 3361	 0.0001	 0.00122	 0.0	 1349.0	 25805	 25805	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 3361	 0.00025	 0.00221	 0.0	 1876.0	 14203	 14203	 0.0	 0.0	 1	 -30.0	 30.0;
	92	 6848	 2.696676	 13.13573	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	92	 5523	 3.125	 11.9903	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 92	 0.00054	 0.00664	 0.0	 1678.0	 4742	 4742	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 92	 0.899169	 5.002355	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 92	 0.06172	 1.437119	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 92	 0.521247	 2.927216	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 92	 0.00397	 0.614771	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 92	 0.956579	 5.569321	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 92	 0.071011	 1.246122	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 92	 22.47576	 40.81994	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	630	 92	 0.00141	 0.00778	 0.0	 3995	 3995	 3995	 0.0	 0.0	 1	 -30.0	 30.0;
	6369	 1861	 0.00021	 0.00179	 0.0	 17527	 17527	 17527	 0.0	 0.0	 1	 -30.0	 30.0;
	8429	 4345	 0.00021	 0.00175	 0.0	 17922	 17922	 17922	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 5178	 0.00051	 0.00411	 0.0	 7627	 7627	 7627	 0.0	 0.0	 1	 -30.0	 30.0;
	1811	 7643	 0.00052	 0.00402	 0.0	 7793	 7793	 7793	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 7643	 0.00439	 0.248677	 0.0	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 2237	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 2237	 0.001	 0.289959	 0.0	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 3739	 9.9e-05	 0.000789	 0.0	 39724	 39724	 39724	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 4350	 0.13343	 0.727438	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	2237	 4350	 0.11368	 0.773802	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 7512	 0.0001	 0.0011	 0.0	 28598	 28598	 28598	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 4714	 0.00069	 0.00512	 0.0	 6115	 6115	 6115	 0.0	 0.0	 1	 -30.0	 30.0;
	8099	 1452	 0.0001	 0.00102	 0.0	 30821	 30821	 30821	 0.0	 0.0	 1	 -30.0	 30.0;
	2444	 8099	 0.0007	 0.005	 0.0	 6257	 6257	 6257	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 3862	 0.00031	 0.00399	 0.0	 1580.0	 7893	 7893	 0.0	 0.0	 1	 -30.0	 30.0;
	6848	 5682	 9e-05	 0.00103	 0.0	 1547.0	 30551	 30551	 0.0	 0.0	 1	 -30.0	 30.0;
	3862	 3976	 0.00021	 0.00231	 0.0	 1547.0	 13619	 13619	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 2157	 8e-05	 0.00082	 0.0	 1415.0	 38340	 38340	 0.0	 0.0	 1	 -30.0	 30.0;
	2157	 8948	 0.00016	 0.00203	 0.0	 1448.0	 15513	 15513	 0.0	 0.0	 1	 -30.0	 30.0;
	8948	 7160	 3e-05	 0.00036	 0.0	 1382.0	 87440	 87440	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 7160	 0.00061	 0.00766	 0.0	 1547.0	 4111	 4111	 0.0	 0.0	 1	 -30.0	 30.0;
	6848	 5523	 0.0	 0.0002	 0.0	 1909.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6848	 5523	 0.01257	 0.43678	 0.0	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 6848	 22.73892	 49.0	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 6848	 4.844044	 19.18698	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 6848	 0.001	 1.752701	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 6848	 0.908172	 6.096537	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	7082	 6848	 4.358657	 9.756232	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 6848	 25.29224	 66.18213	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 6848	 1.071399	 5.397922	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 6848	 0.155789	 0.985526	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 5523	 23.51524	 49.62604	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 5523	 5.179155	 18.97368	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 5523	 0.0144	 1.921053	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 5523	 0.997091	 6.027978	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	7082	 5523	 4.636704	 9.781162	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 5523	 29.33518	 59.12049	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 5523	 1.098269	 5.695983	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 5523	 0.00085	 0.00853	 0.0	 1777.0	 3685	 3685	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 5523	 0.15653	 1.070014	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 5941	 0.00015	 0.00148	 0.0	 21235	 21235	 21235	 0.0	 0.0	 1	 -30.0	 30.0;
	475	 5941	 0.00014	 0.00167	 0.0	 1349.0	 18849	 18849	 0.0	 0.0	 1	 -30.0	 30.0;
	324	 5941	 0.525672	 1.551039	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	6469	 7941	 0.00411	 0.01861	 0.0	 495.0	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	4153	 6469	 0.000969	 0.005841	 0.0	 476.0	 5335	 5335	 0.0	 0.0	 1	 -30.0	 30.0;
	7941	 2743	 0.004581	 0.02156	 0.0	 495.0	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	2632	 6485	 0.00026	 0.00323	 0.0	 954.0	 9748	 9748	 0.0	 0.0	 1	 -30.0	 30.0;
	2632	 6485	 0.00026	 0.00329	 0.0	 987.0	 9572	 9572	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 8465	 6e-05	 0.00065	 0.0	 1185.0	 48391	 48391	 0.0	 0.0	 1	 -30.0	 30.0;
	8465	 1582	 0.00038	 0.00377	 0.0	 1316.0	 8337	 8337	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 8802	 6e-05	 0.00066	 0.0	 1349.0	 47664	 47664	 0.0	 0.0	 1	 -30.0	 30.0;
	8802	 2046	 0.00038	 0.00369	 0.0	 1481.0	 8516	 8516	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 3349	 0.01122	 0.71669	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 192	 25.10803	 39.16205	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 6894	 32.07964	 43.87258	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 9100	 0.427673	 3.90554	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 5717	 0.418573	 3.979224	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 192	 23.26662	 36.54363	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 3349	 25.59141	 38.34626	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 6894	 32.6849	 42.93906	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 9100	 0.409481	 3.684488	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 5717	 0.464072	 3.610803	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 3349	 23.70568	 35.76593	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 3431	 0.0	 0.0002	 0.0	 400.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 3431	 0.001	 0.19151	 0.0	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 4033	 17.56446	 20.66736	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 1238	 13.87645	 21.76446	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 438	 1.145248	 3.637603	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 1907	 1.372004	 3.186983	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 1029	 0.119159	 0.998905	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 1587	 6.052479	 9.575826	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 1029	 4.474793	 10.74483	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 1029	 4.534711	 10.47087	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 4033	 18.49236	 22.54545	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 1238	 13.69401	 22.82645	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 438	 1.333636	 3.866942	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 1907	 1.179442	 4.148554	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 3431	 0.114281	 1.035289	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 1587	 5.617769	 11.75372	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 3431	 4.939669	 11.00083	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 3431	 4.903306	 10.93058	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7690	 1452	 2e-05	 0.00021	 0.0	 149739	 149739	 149739	 0.0	 0.0	 1	 -30.0	 30.0;
	7690	 2074	 0.00028	 0.00263	 0.0	 11943	 11943	 11943	 0.0	 0.0	 1	 -30.0	 30.0;
	3270	 7512	 2e-05	 0.00023	 0.0	 136820	 136820	 136820	 0.0	 0.0	 1	 -30.0	 30.0;
	3270	 8868	 0.00027	 0.00268	 0.0	 11727	 11727	 11727	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 7198	 0.02601	 0.665517	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 98	 0.028591	 0.528326	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	7924	 6554	 0.01088	 0.212832	 0.0	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	2440	 6554	 0.00032	 0.00331	 0.0	 1580.0	 9499	 9499	 0.0	 0.0	 1	 -30.0	 30.0;
	4261	 6554	 0.00031	 0.00306	 0.0	 1218.0	 10271	 10271	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 237	 0.00057	 0.01002	 0.0	 3148	 3148	 3148	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 2277	 0.00053	 0.00558	 0.0	 1942.0	 5636	 5636	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 4296	 22.58241	 30.56787	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 5611	 22.12119	 31.16759	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 4766	 1.627632	 4.119529	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	8762	 4766	 0.0003	 0.00319	 0.0	 1580.0	 9859	 9859	 0.0	 0.0	 1	 -30.0	 30.0;
	7483	 4766	 0.00232	 0.519501	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 9003	 0.00058	 0.00981	 0.0	 3215	 3215	 3215	 0.0	 0.0	 1	 -30.0	 30.0;
	9088	 9003	 0.00065	 0.00643	 0.0	 4888	 4888	 4888	 0.0	 0.0	 1	 -30.0	 30.0;
	4501	 237	 0.00063	 0.00655	 0.0	 4801	 4801	 4801	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 8517	 0.001	 0.215229	 0.0	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 7924	 0.00102	 0.00911	 0.0	 1481.0	 3446	 3446	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 6558	 0.00094	 0.00901	 0.0	 1744.0	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 8517	 3.359072	 5.253809	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 4723	 0.00019	 0.00221	 0.0	 1481.0	 14241	 14241	 0.0	 0.0	 1	 -30.0	 30.0;
	7924	 1079	 0.00039	 0.00355	 0.0	 1547.0	 8845	 8845	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 1148	 0.0001	 0.00073	 0.0	 42870	 42870	 42870	 0.0	 0.0	 1	 -30.0	 30.0;
	6847	 600	 0.00018	 0.00226	 0.0	 1547.0	 13933	 13933	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 6847	 0.00038	 0.00368	 0.0	 987.0	 8539	 8539	 0.0	 0.0	 1	 -30.0	 30.0;
	6847	 7116	 0.00047	 0.00386	 0.0	 1843.0	 8124	 8124	 0.0	 0.0	 1	 -30.0	 30.0;
	7198	 98	 0.001	 0.309525	 0.0	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	2912	 2196	 0.000711	 0.00393	 0.0	 553.0	 7910	 7910	 0.0	 0.0	 1	 -30.0	 30.0;
	2912	 7631	 0.001219	 0.00569	 0.0	 5429	 5429	 5429	 0.0	 0.0	 1	 -30.0	 30.0;
	8349	 6286	 0.00125	 0.005581	 0.0	 457.0	 5523	 5523	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 6286	 0.0007	 0.00401	 0.0	 7760	 7760	 7760	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 4866	 0.0599	 0.313109	 0.0	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 3267	 0.00051	 0.00517	 0.0	 1744.0	 6081	 6081	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 8429	 0.92403	 2.090097	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 7816	 0.05633	 0.587403	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 5428	 0.333109	 1.178601	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	5021	 7194	 0.0002	 0.002599	 0.0	 381.0	 12118	 12118	 0.0	 0.0	 1	 -30.0	 30.0;
	6508	 4023	 6e-05	 0.00066	 0.0	 1843.0	 47664	 47664	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 4723	 0.00203	 0.01921	 0.0	 1415.0	 1636	 1636	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 8336	 0.00132	 0.01562	 0.0	 1645.0	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 1918	 0.00039	 0.00541	 0.0	 5824	 5824	 5824	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 8336	 0.0013	 0.01592	 0.0	 1678.0	 1978	 1978	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 6667	 0.00084	 0.00852	 0.0	 3690	 3690	 3690	 0.0	 0.0	 1	 -30.0	 30.0;
	6508	 3052	 0.00016	 0.0017	 0.0	 1547.0	 18500	 18500	 0.0	 0.0	 1	 -30.0	 30.0;
	1807	 5102	 0.00092	 0.00761	 0.0	 1678.0	 4121	 4121	 0.0	 0.0	 1	 -30.0	 30.0;
	1807	 491	 0.00062	 0.00468	 0.0	 1711.0	 6691	 6691	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 1811	 0.00094	 0.00746	 0.0	 1580.0	 4202	 4202	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 7545	 0.00063	 0.00458	 0.0	 1645.0	 6833	 6833	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 1811	 0.0	 0.0002	 0.0	 1547.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 1811	 0.001	 0.227327	 0.0	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 3647	 3e-05	 0.00034	 0.0	 92545	 92545	 92545	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 5102	 0.00052	 0.00501	 0.0	 6272	 6272	 6272	 0.0	 0.0	 1	 -30.0	 30.0;
	4041	 1811	 0.00059	 0.00491	 0.0	 6388	 6388	 6388	 0.0	 0.0	 1	 -30.0	 30.0;
	241	 1238	 0.006229	 0.029719	 0.0	 495.0	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	241	 438	 0.00194	 0.00924	 0.0	 476.0	 3346	 3346	 0.0	 0.0	 1	 -30.0	 30.0;
	3118	 2631	 0.00189	 0.00769	 0.0	 3989	 3989	 3989	 0.0	 0.0	 1	 -30.0	 30.0;
	3118	 8934	 0.0037	 0.017021	 0.0	 476.0	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	4597	 1144	 0.00168	 0.008719	 0.0	 438.0	 3558	 3558	 0.0	 0.0	 1	 -30.0	 30.0;
	4597	 6173	 0.003771	 0.016669	 0.0	 514.0	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	6440	 7631	 0.004669	 0.024729	 0.0	 438.0	 1256	 1256	 0.0	 0.0	 1	 -30.0	 30.0;
	1189	 8349	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1189	 8349	 0.00099	 0.00607	 0.0	 5136	 5136	 5136	 0.0	 0.0	 1	 -30.0	 30.0;
	6440	 1189	 0.00476	 0.02624	 0.0	 381.0	 1185	 1185	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 5820	 0.00051	 0.00286	 0.0	 457.0	 10874	 10874	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 5820	 0.0005	 0.002909	 0.0	 476.0	 10702	 10702	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 1238	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 1238	 0.001	 0.18874	 0.0	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 438	 0.704421	 2.986983	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 1907	 0.680207	 2.970661	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 4033	 4.389256	 10.44091	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 1587	 0.00861	 0.432252	 0.0	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 4033	 0.006521	 0.039849	 0.0	 457.0	 783	 783	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 4033	 0.450599	 2.525826	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 4033	 0.51345	 2.178099	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 1962	 0.000159	 0.002091	 0.0	 15063	 15063	 15063	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 438	 0.547603	 3.122934	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 1907	 0.63281	 2.590496	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 1238	 4.541736	 8.227686	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 1587	 0.00687	 0.424525	 0.0	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 1238	 0.394752	 2.341736	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 1238	 0.00638	 0.04063	 0.0	 457.0	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 1238	 0.459607	 1.981798	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 1944	 0.000159	 0.00213	 0.0	 14789	 14789	 14789	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 1144	 0.001	 0.319917	 0.0	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 2631	 0.074539	 0.567996	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 1144	 0.054219	 0.438326	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 4119	 0.00049	 0.0046	 0.0	 1744.0	 6829	 6829	 0.0	 0.0	 1	 -30.0	 30.0;
	8193	 4119	 0.00063	 0.00676	 0.0	 1547.0	 4653	 4653	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 2306	 0.02777	 0.440042	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	3514	 2306	 0.02704	 0.444668	 0.0	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	3514	 2306	 0.00048	 0.00469	 0.0	 1777.0	 6701	 6701	 0.0	 0.0	 1	 -30.0	 30.0;
	8193	 2306	 0.00062	 0.00626	 0.0	 1514.0	 5022	 5022	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 3514	 0.0	 0.0002	 0.0	 1415.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 3514	 0.001	 0.247292	 0.0	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 5963	 3e-05	 0.00035	 0.0	 1514.0	 89920	 89920	 0.0	 0.0	 1	 -30.0	 30.0;
	9046	 1667	 0.00014	 0.00118	 0.0	 1251.0	 26583	 26583	 0.0	 0.0	 1	 -30.0	 30.0;
	3514	 7771	 3e-05	 0.00034	 0.0	 1514.0	 92545	 92545	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 5963	 0.00072	 0.00903	 0.0	 1514.0	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 7771	 0.00082	 0.00885	 0.0	 1678.0	 3554	 3554	 0.0	 0.0	 1	 -30.0	 30.0;
	7440	 969	 0.00012	 0.00093	 0.0	 757.0	 33686	 33686	 0.0	 0.0	 1	 -30.0	 30.0;
	6946	 7240	 0.000831	 0.004229	 0.0	 7330	 7330	 7330	 0.0	 0.0	 1	 -30.0	 30.0;
	9053	 4153	 0.000841	 0.00414	 0.0	 7478	 7478	 7478	 0.0	 0.0	 1	 -30.0	 30.0;
	8762	 6095	 0.00049	 0.00607	 0.0	 1876.0	 5187	 5187	 0.0	 0.0	 1	 -30.0	 30.0;
	7483	 2277	 0.00048	 0.00567	 0.0	 1547.0	 5552	 5552	 0.0	 0.0	 1	 -30.0	 30.0;
	7483	 475	 0.00047	 0.00578	 0.0	 1349.0	 5447	 5447	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 6222	 6e-05	 0.00069	 0.0	 1613.0	 45607	 45607	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 6894	 0.198269	 1.245429	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 9100	 28.23615	 48.46122	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 5717	 32.00069	 47.49169	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 6222	 0.001	 0.339079	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	4296	 5611	 0.001	 0.23876	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	7483	 4296	 7.242382	 14.44598	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7483	 5611	 7.08795	 14.71814	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 5598	 0.00493	 0.059419	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 5598	 0.01006	 0.07863	 0.0	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 5680	 0.001	 0.434587	 0.0	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 2895	 0.001	 0.434132	 0.0	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 4488	 9.525206	 20.12748	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 8022	 0.490393	 3.121901	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 260	 0.324483	 3.440909	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 5909	 7.110331	 13.27211	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 2828	 8.147314	 13.64236	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 5596	 1.873657	 4.730165	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 4099	 1.953223	 4.544628	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 629	 0.893533	 3.267562	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 3423	 0.947417	 3.197521	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 2955	 1.735227	 5.478926	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 6451	 49.21281	 47.44215	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 6451	 21.70248	 30.12603	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 4702	 9.99835	 24.78719	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 7500	 10.26198	 26.88017	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 1067	 0.625785	 4.196281	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 6451	 0.531426	 3.034091	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 6451	 3.245868	 10.84669	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 6451	 3.282025	 10.98388	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 1581	 0.002919	 0.01451	 0.0	 553.0	 2135	 2135	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 1581	 0.001	 0.67564	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 6655	 0.227169	 1.409215	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 6307	 0.192229	 1.194917	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 1581	 0.002979	 0.0142	 0.0	 553.0	 2178	 2178	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 5531	 0.000151	 0.0015	 0.0	 20953	 20953	 20953	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 4350	 0.000151	 0.001461	 0.0	 21506	 21506	 21506	 0.0	 0.0	 1	 -30.0	 30.0;
	6485	 1493	 0.00136	 0.0167	 0.0	 1415.0	 1886	 1886	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 2895	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 2895	 0.001	 0.256632	 0.0	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 5680	 6.78595	 11.8655	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 5680	 1.097169	 5.085744	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 5680	 0.904029	 5.181818	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 5680	 4.170248	 8.645247	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 5680	 4.773967	 8.884503	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 5680	 0.874421	 3.172727	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 5680	 1.05436	 2.929339	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 5680	 0.513368	 2.495455	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 5680	 0.604525	 2.218802	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	2955	 5680	 1.308616	 3.033264	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 5680	 39.69008	 38.26033	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 5680	 17.11942	 22.4938	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 5680	 20.47789	 32.19835	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 5680	 21.35331	 30.98554	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 5680	 1.604091	 6.167149	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 5680	 1.137851	 5.037397	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 5680	 6.625413	 15.09483	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 5680	 6.196074	 16.5874	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 5680	 59.24587	 56.3595	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 1581	 0.086409	 1.077231	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 5680	 0.080841	 0.916612	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 5680	 0.07195	 0.701488	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 2895	 5.952479	 12.55207	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 2895	 1.208636	 4.790289	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 2895	 0.897293	 4.88781	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 2895	 4.399793	 8.436157	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 2895	 4.466736	 9.775413	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 2895	 0.924855	 3.415083	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 2895	 1.008368	 3.168595	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 2895	 0.519401	 2.533471	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 2895	 0.611653	 2.252893	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	2955	 2895	 1.180868	 3.490496	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 2895	 38.08471	 41.4876	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 2895	 19.69132	 22.41116	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 2895	 21.63017	 31.43802	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 2895	 20.91529	 32.94215	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 2895	 1.695537	 6.03657	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 2895	 1.302851	 4.551033	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 2895	 5.718182	 16.36116	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 2895	 6.683678	 15.9062	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 1581	 0.10661	 0.987583	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 2895	 0.079729	 0.948512	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 2895	 0.06449	 0.807169	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 2895	 0.002151	 0.02656	 0.0	 1186	 1186	 1186	 0.0	 0.0	 1	 -30.0	 30.0;
	6485	 4811	 0.00094	 0.01246	 0.0	 1711.0	 2528	 2528	 0.0	 0.0	 1	 -30.0	 30.0;
	4811	 4849	 0.00109	 0.00971	 0.0	 1942.0	 3233	 3233	 0.0	 0.0	 1	 -30.0	 30.0;
	6485	 3012	 0.00099	 0.01086	 0.0	 1678.0	 2897	 2897	 0.0	 0.0	 1	 -30.0	 30.0;
	6485	 3012	 0.00092	 0.0127	 0.0	 1613.0	 2481	 2481	 0.0	 0.0	 1	 -30.0	 30.0;
	3012	 4849	 0.00097	 0.01101	 0.0	 1909.0	 2858	 2858	 0.0	 0.0	 1	 -30.0	 30.0;
	438	 1907	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	438	 1907	 0.001	 0.236901	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 438	 1.033202	 3.18595	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	1587	 438	 0.07336	 0.952996	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 438	 4.823554	 9.755785	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 438	 4.344835	 10.74711	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7684	 438	 0.000789	 0.01039	 0.0	 3032	 3032	 3032	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 1907	 0.877293	 3.230992	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	1587	 1907	 0.08095	 0.839008	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 1907	 4.635744	 9.702067	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 1907	 4.775207	 9.229752	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	6558	 2440	 0.00017	 0.0018	 0.0	 1942.0	 17471	 17471	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 4261	 0.00017	 0.00184	 0.0	 1251.0	 17095	 17095	 0.0	 0.0	 1	 -30.0	 30.0;
	8647	 2074	 6e-05	 0.00055	 0.0	 57093	 57093	 57093	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 8868	 5e-05	 0.00051	 0.0	 61641	 61641	 61641	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 7207	 4.9e-05	 0.000194	 0.0	 1645.0	 157864	 157864	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 7207	 0.001	 0.502417	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 491	 0.11597	 1.150069	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 4332	 0.00027	 0.00201	 0.0	 1645.0	 15576	 15576	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 324	 12.69044	 26.69945	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 7093	 5.039543	 12.54224	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 7093	 4.861565	 13.04917	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7207	 491	 0.131427	 1.127078	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	7207	 2513	 0.00034	 0.00324	 0.0	 1777.0	 9696	 9696	 0.0	 0.0	 1	 -30.0	 30.0;
	7207	 324	 14.34765	 23.73407	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 7207	 4.937535	 12.78878	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 7207	 4.758934	 13.29571	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 276	 0.00189	 0.01011	 0.0	 495.0	 3072	 3072	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 7412	 0.00193	 0.009901	 0.0	 495.0	 3132	 3132	 0.0	 0.0	 1	 -30.0	 30.0;
	321	 7412	 0.00095	 0.004461	 0.0	 495.0	 6926	 6926	 0.0	 0.0	 1	 -30.0	 30.0;
	321	 5929	 0.000841	 0.00505	 0.0	 457.0	 6170	 6170	 0.0	 0.0	 1	 -30.0	 30.0;
	6432	 3330	 0.00074	 0.00837	 0.0	 419.0	 3760	 3760	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 1587	 3.807645	 6.613017	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 3330	 0.512211	 2.208058	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 3330	 0.432727	 2.575207	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 321	 0.00551	 0.13675	 0.0	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	8193	 6615	 0.00018	 0.00165	 0.0	 19031	 19031	 19031	 0.0	 0.0	 1	 -30.0	 30.0;
	8193	 1596	 0.00017	 0.00168	 0.0	 18707	 18707	 18707	 0.0	 0.0	 1	 -30.0	 30.0;
	3052	 4298	 0.00022	 0.00207	 0.0	 1415.0	 15175	 15175	 0.0	 0.0	 1	 -30.0	 30.0;
	7254	 5878	 6e-05	 0.000531	 0.0	 59111	 59111	 59111	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 4401	 6e-05	 0.000521	 0.0	 495.0	 60231	 60231	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 5909	 2.538636	 7.69814	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 2828	 2.881818	 7.882025	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 5596	 0.648822	 3.687603	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 4099	 0.662004	 3.615496	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 629	 0.347417	 1.771488	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 3423	 0.302727	 2.122521	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 2955	 0.13874	 1.055682	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 4488	 32.21488	 46.94215	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 4488	 16.64897	 25.36157	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 1581	 31.40496	 45.72727	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 6655	 1.96531	 5.971488	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 6307	 1.628843	 5.349793	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5878	 2955	 0.003831	 0.04362	 0.0	 722	 722	 722	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 2955	 0.003901	 0.042711	 0.0	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 4737	 0.0	 0.0002	 0.0	 1448.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 4737	 0.03143	 0.812673	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	7352	 2891	 6e-05	 0.00062	 0.0	 1613.0	 50711	 50711	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 2891	 5.540582	 14.44598	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 2891	 0.171863	 2.799169	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	7082	 2891	 31.73753	 62.63988	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 2891	 0.0037	 0.670762	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 2891	 4.69723	 16.67659	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 2891	 13.8608	 37.26524	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 4737	 6e-05	 0.00063	 0.0	 49913	 49913	 49913	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 4737	 0.842036	 5.10651	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 4737	 0.001	 0.767382	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 4737	 0.0122	 0.920499	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 4737	 0.831094	 4.707341	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 4737	 13.1392	 39.18767	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7910	 7352	 0.00022	 0.0023	 0.0	 1777.0	 13672	 13672	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 8647	 0.00022	 0.00213	 0.0	 14752	 14752	 14752	 0.0	 0.0	 1	 -30.0	 30.0;
	8332	 6894	 0.00034	 0.003	 0.0	 10463	 10463	 10463	 0.0	 0.0	 1	 -30.0	 30.0;
	324	 8332	 0.00022	 0.00172	 0.0	 18217	 18217	 18217	 0.0	 0.0	 1	 -30.0	 30.0;
	5048	 6894	 0.00034	 0.00294	 0.0	 10673	 10673	 10673	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 5048	 0.00022	 0.00168	 0.0	 18643	 18643	 18643	 0.0	 0.0	 1	 -30.0	 30.0;
	9100	 6894	 25.47853	 44.51731	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 6894	 24.93629	 45.35734	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6894	 0.138622	 1.351247	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 1587	 1.420021	 4.04938	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 1587	 1.226446	 4.635537	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	1587	 5820	 0.000771	 0.0083	 0.0	 3790	 3790	 3790	 0.0	 0.0	 1	 -30.0	 30.0;
	2788	 9077	 0.00449	 0.023349	 0.0	 1329	 1329	 1329	 0.0	 0.0	 1	 -30.0	 30.0;
	640	 7099	 0.001	 0.313037	 0.0	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	640	 6440	 0.025331	 0.364938	 0.0	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	640	 6440	 0.004219	 0.018211	 0.0	 1690	 1690	 1690	 0.0	 0.0	 1	 -30.0	 30.0;
	7099	 6440	 0.02581	 0.357169	 0.0	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	7099	 6440	 0.00413	 0.01686	 0.0	 553.0	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	491	 3476	 0.00018	 0.00157	 0.0	 19989	 19989	 19989	 0.0	 0.0	 1	 -30.0	 30.0;
	324	 491	 4.622922	 11.33102	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 491	 1.337465	 6.217936	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 491	 1.319252	 5.765305	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	7545	 5272	 0.00017	 0.0016	 0.0	 19632	 19632	 19632	 0.0	 0.0	 1	 -30.0	 30.0;
	7545	 4332	 0.00017	 0.00163	 0.0	 1777.0	 19275	 19275	 0.0	 0.0	 1	 -30.0	 30.0;
	7545	 3950	 2e-05	 0.00022	 0.0	 757.0	 142990	 142990	 0.0	 0.0	 1	 -30.0	 30.0;
	8934	 6173	 0.0	 0.0002	 0.0	 533.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8934	 6173	 0.01018	 0.46657	 0.0	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 8934	 0.00887	 0.046021	 0.0	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	3780	 8934	 0.007479	 0.02551	 0.0	 553.0	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	1623	 6173	 0.00762	 0.024979	 0.0	 572.0	 1210	 1210	 0.0	 0.0	 1	 -30.0	 30.0;
	7440	 3476	 0.00034	 0.00277	 0.0	 11319	 11319	 11319	 0.0	 0.0	 1	 -30.0	 30.0;
	8006	 5272	 0.00035	 0.00271	 0.0	 1777.0	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	4501	 2513	 0.00146	 0.01134	 0.0	 1547.0	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 1177	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 1177	 0.001	 0.250041	 0.0	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 5142	 0.00031	 0.00232	 0.0	 438.0	 13496	 13496	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 6130	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 6130	 0.001	 0.319463	 0.0	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 6440	 0.002479	 0.011479	 0.0	 438.0	 2690	 2690	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 1258	 1.778616	 5.164256	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 3332	 0.00644	 0.026229	 0.0	 419.0	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	4085	 3332	 0.342769	 1.509876	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 6440	 0.002521	 0.01124	 0.0	 438.0	 2743	 2743	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 1258	 1.29219	 4.678099	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4085	 6130	 0.236529	 1.420661	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 260	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 260	 0.05505	 0.67124	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 8022	 4.467975	 11.21446	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 5596	 34.72521	 52.45248	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 4099	 36.34711	 50.63223	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 629	 22.76033	 33.1281	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 3423	 21.48554	 36.70661	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 2955	 39.50826	 49.23967	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 8022	 17.04917	 42.27893	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 8022	 16.04855	 40.82025	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 1067	 0.053771	 1.208946	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 1067	 0.003281	 0.016341	 0.0	 514.0	 1896	 1896	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 8022	 0.825227	 5.014463	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 4789	 4.278926	 11.33285	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 7592	 3.46157	 11.98905	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 8022	 4.532025	 17.77417	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 8022	 0.009169	 0.03831	 0.0	 514.0	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 8022	 4.582645	 17.99917	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 6421	 4.507231	 15.28285	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 1581	 0.001	 1.211157	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 6655	 7.098967	 16.7219	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 6307	 6.249587	 14.57107	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 260	 3.945041	 12.27665	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 5596	 34.19215	 51.58471	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 4099	 31.52686	 50.73347	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 629	 18.00289	 35.73554	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 3423	 21.65083	 34.30165	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 2955	 35.85331	 52.29959	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 260	 18.05847	 51.41322	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 260	 21.28512	 43.97521	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 1067	 0.036771	 0.970744	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 260	 0.78843	 6.091736	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 4789	 3.228512	 12.74483	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 7592	 3.551653	 11.03347	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 260	 5.941736	 18.63595	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 260	 4.915083	 20.96901	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 260	 0.01039	 0.037539	 0.0	 495.0	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 6421	 4.096281	 15.0905	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 1581	 0.001	 1.352211	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 6655	 6.635537	 16.54979	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 6307	 5.82438	 14.40847	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 2133	 0.00046	 0.00466	 0.0	 6746	 6746	 6746	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 324	 0.03625	 0.46376	 0.0	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 324	 0.00045	 0.00475	 0.0	 6621	 6621	 6621	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 324	 0.04062	 0.4091	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 1581	 0.006271	 0.0373	 0.0	 836	 836	 836	 0.0	 0.0	 1	 -30.0	 30.0;
	648	 5531	 0.000331	 0.00331	 0.0	 9496	 9496	 9496	 0.0	 0.0	 1	 -30.0	 30.0;
	648	 4350	 0.000341	 0.00324	 0.0	 9696	 9696	 9696	 0.0	 0.0	 1	 -30.0	 30.0;
	648	 1484	 0.00013	 0.00132	 0.0	 381.0	 23815	 23815	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 2828	 0.001	 0.1802	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 5596	 0.04812	 0.726715	 0.0	 44	 44	 44	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 5596	 0.005169	 0.036401	 0.0	 495.0	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 4099	 0.04006	 0.78624	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 5909	 0.559318	 2.376033	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 5909	 0.574607	 2.433264	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 2955	 0.449463	 2.310744	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 5909	 0.18062	 1.392789	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 5909	 0.092211	 0.750041	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 5909	 6.405372	 12.55372	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 5909	 5.734504	 14.28161	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 5909	 15.87066	 21.82231	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 5909	 45.78719	 60.88223	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 5909	 52.13017	 54.55165	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 5909	 0.615	 2.63781	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 1581	 16.26798	 23.5124	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 6655	 0.818636	 3.652686	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 6307	 0.670434	 2.968182	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 5596	 0.041711	 0.912376	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 4099	 0.04611	 0.822479	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 4099	 0.005271	 0.03561	 0.0	 533.0	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 2828	 0.605434	 2.534091	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 2828	 0.542851	 2.99876	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 2955	 0.520909	 2.569628	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 2828	 0.177789	 1.458264	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 2828	 0.09881	 0.801281	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 2828	 6.124793	 15.47397	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 2828	 5.91157	 16.17149	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 2828	 14.54876	 25.34091	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 2828	 54.67355	 60.11777	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 2828	 0.802355	 2.58657	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 1581	 19.94897	 25.18388	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 6655	 1.027479	 3.393802	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 6307	 0.843471	 3.042975	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 7492	 0.00078	 0.00782	 0.0	 1909.0	 4020	 4020	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 8429	 7.575485	 11.77562	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 7816	 1.23705	 3.353947	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 5428	 3.429501	 6.941136	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 1525	 0.00076	 0.00797	 0.0	 1810.0	 3946	 3946	 0.0	 0.0	 1	 -30.0	 30.0;
	8256	 1525	 0.00025	 0.00233	 0.0	 1942.0	 13480	 13480	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 7492	 0.00179	 0.01397	 0.0	 1613.0	 2243	 2243	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 63	 0.173643	 1.472438	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 8336	 5.182133	 18.94529	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 2724	 0.188989	 1.114889	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 63	 1.860596	 8.193906	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 316	 0.00424	 0.029211	 0.0	 572.0	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 1067	 6.176859	 17.47149	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 242	 10.52665	 27.33264	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 4789	 0.202	 1.377087	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 7592	 0.19876	 1.343988	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 7592	 0.00545	 0.042341	 0.0	 553.0	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 242	 7.300207	 16.26798	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 242	 6.816736	 17.84773	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 6421	 3.997727	 8.729958	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 1581	 15.84711	 34.44008	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 1085	 30.61777	 53.27893	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 3913	 36.28512	 62.88017	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 2724	 0.00082	 0.01007	 0.0	 1580.0	 3127	 3127	 0.0	 0.0	 1	 -30.0	 30.0;
	7454	 7706	 0.0005	 0.004169	 0.0	 572.0	 7523	 7523	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 7454	 0.00525	 0.033151	 0.0	 495.0	 942	 942	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 4646	 0.001969	 0.01718	 0.0	 495.0	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 4288	 0.001289	 0.009229	 0.0	 553.0	 3390	 3390	 0.0	 0.0	 1	 -30.0	 30.0;
	4288	 3935	 0.00043	 0.00349	 0.0	 553.0	 8983	 8983	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 6716	 0.000979	 0.008901	 0.0	 495.0	 3528	 3528	 0.0	 0.0	 1	 -30.0	 30.0;
	6716	 316	 0.000219	 0.00155	 0.0	 514.0	 20179	 20179	 0.0	 0.0	 1	 -30.0	 30.0;
	7039	 7135	 0.00025	 0.00319	 0.0	 889.0	 9872	 9872	 0.0	 0.0	 1	 -30.0	 30.0;
	7039	 7135	 0.00024	 0.00295	 0.0	 856.0	 10673	 10673	 0.0	 0.0	 1	 -30.0	 30.0;
	8429	 732	 0.00022	 0.00171	 0.0	 1448.0	 18322	 18322	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 732	 0.0005	 0.00382	 0.0	 1514.0	 8200	 8200	 0.0	 0.0	 1	 -30.0	 30.0;
	6369	 2545	 0.0002	 0.00192	 0.0	 1251.0	 16364	 16364	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 2545	 0.0005	 0.00383	 0.0	 1580.0	 8178	 8178	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 4099	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 4099	 0.001	 0.268678	 0.0	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 5596	 0.042159	 0.956198	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 5596	 0.002341	 0.022341	 0.0	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 5596	 0.04555	 0.93969	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 2955	 0.077909	 1.08686	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	4424	 5596	 0.0003	 0.003289	 0.0	 629.0	 9565	 9565	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 5596	 1.527831	 6.098554	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 5596	 0.958926	 2.68595	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 5596	 28.84298	 48.1157	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 5596	 33.55372	 46.46901	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 5596	 47.90702	 63.74587	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 5596	 28.68802	 30.77066	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 5596	 4.526653	 11.10372	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 1581	 6.754959	 11.13905	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 6655	 0.105229	 1.236012	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 6307	 0.085781	 1.020186	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 4099	 0.044289	 0.919483	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 4099	 0.047781	 0.901963	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 2955	 0.076341	 1.006446	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 4099	 0.0003	 0.00336	 0.0	 610.0	 9364	 9364	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 4099	 1.621322	 5.733678	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 4099	 0.903202	 2.852273	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 4099	 30.65289	 49.86157	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 4099	 32.78719	 47.26653	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 4099	 44.17355	 62.70041	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 4099	 25.07438	 35.58471	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 4099	 5.060744	 9.753098	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 1581	 6.015083	 12.60103	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 6655	 0.099409	 1.193017	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 6655	 0.002021	 0.01812	 0.0	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 6307	 0.09157	 0.961405	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 5774	 0.00032	 0.00387	 0.0	 1349.0	 8135	 8135	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 3583	 0.00038	 0.00378	 0.0	 1448.0	 8315	 8315	 0.0	 0.0	 1	 -30.0	 30.0;
	3578	 6753	 0.00032	 0.00394	 0.0	 1481.0	 7991	 7991	 0.0	 0.0	 1	 -30.0	 30.0;
	3578	 606	 0.00038	 0.0037	 0.0	 1382.0	 8493	 8493	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 7483	 6.036911	 10.78324	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6485	 7135	 0.0008	 0.00945	 0.0	 1481.0	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	7135	 624	 0.00079	 0.00828	 0.0	 1349.0	 3798	 3798	 0.0	 0.0	 1	 -30.0	 30.0;
	6485	 7135	 0.00078	 0.00964	 0.0	 1415.0	 3267	 3267	 0.0	 0.0	 1	 -30.0	 30.0;
	7135	 624	 0.00081	 0.00811	 0.0	 1316.0	 3876	 3876	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 3423	 0.0	 0.0002	 0.0	 419.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 3423	 0.001	 0.26281	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 2955	 0.001	 0.461798	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 2955	 0.00164	 0.020729	 0.0	 533.0	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 629	 7.774793	 17.76901	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 629	 3.756405	 9.209917	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 1067	 27.82645	 45.00826	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 629	 20.96901	 31.09711	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 629	 18.12293	 35.08471	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 1581	 3.360124	 8.657025	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 6655	 0.14569	 1.294938	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 6307	 0.125919	 1.049607	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 2955	 0.001	 0.471508	 0.0	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 2955	 0.001599	 0.02112	 0.0	 1492	 1492	 1492	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 3423	 8.624174	 16.76653	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 3423	 4.365909	 9.241321	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 1067	 29.57231	 44.15909	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 3423	 22.67562	 29.81818	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 3423	 22.21281	 29.92975	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 1581	 3.288017	 9.179959	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 6655	 0.15644	 1.276653	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 6307	 0.124669	 1.119298	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 2955	 6.748554	 16.31901	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 2955	 3.853099	 7.976446	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 2955	 53.92562	 59.04132	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 2955	 37.32851	 39.04752	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 2955	 16.76198	 30.60331	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2955	 1581	 6.070868	 12.11942	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 2955	 0.29624	 1.60312	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 2955	 0.293884	 1.293946	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 8336	 0.15633	 3.578947	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 2724	 0.242957	 1.518213	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 1268	 8.069251	 24.53047	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 3522	 0.00029	 0.00357	 0.0	 8819	 8819	 8819	 0.0	 0.0	 1	 -30.0	 30.0;
	2440	 5380	 0.00012	 0.00131	 0.0	 1777.0	 24012	 24012	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 6718	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 6718	 0.001	 0.168909	 0.0	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 4702	 0.837231	 3.56405	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 7500	 0.690682	 3.987397	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 7500	 0.00988	 0.05469	 0.0	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 8182	 5.606818	 11.56529	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 8182	 15.6624	 27.83058	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 8182	 16.76116	 26.42355	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 1971	 0.039521	 0.57	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 1581	 25.64463	 32.3843	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 6655	 12.49401	 21.31612	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 6307	 10.90826	 18.38058	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 4702	 0.367355	 2.263636	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 7500	 0.394566	 2.152479	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 6718	 2.95062	 6.117354	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 6718	 8.41281	 14.42025	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 6718	 8.672314	 14.29339	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 1971	 0.0192	 0.321384	 0.0	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 1581	 12.78037	 18.27831	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 6655	 6.830371	 10.80145	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 6307	 5.092149	 10.9593	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 7082	 0.00043	 0.00522	 0.0	 1218.0	 6031	 6031	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 7082	 0.00184	 0.01667	 0.0	 1580.0	 1884	 1884	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 7082	 0.248089	 2.761427	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 4884	 0.00037	 0.00464	 0.0	 1481.0	 6787	 6787	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 5768	 0.00059	 0.00694	 0.0	 1547.0	 4536	 4536	 0.0	 0.0	 1	 -30.0	 30.0;
	9100	 8693	 0.00027	 0.00348	 0.0	 1481.0	 9050	 9050	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 8693	 0.00027	 0.00354	 0.0	 1547.0	 8898	 8898	 0.0	 0.0	 1	 -30.0	 30.0;
	9100	 5717	 0.02114	 0.839889	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 9100	 30.32756	 43.46053	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 5717	 30.89958	 42.53601	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 7500	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 7500	 0.001	 0.238595	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 4702	 0.256632	 1.964752	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 4702	 0.63343	 3.574793	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 4702	 0.709752	 3.284711	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 4702	 0.01324	 0.090909	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 4702	 0.000591	 1.201426	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 1581	 1.821963	 7.541736	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 7500	 0.210826	 2.191942	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 7500	 0.746074	 3.056198	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 7500	 0.740041	 3.16219	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 7500	 0.000841	 1.29095	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	7500	 1581	 2.154545	 7.118182	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 1950	 8e-05	 0.00105	 0.0	 1481.0	 29997	 29997	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 8336	 0.00025	 0.00186	 0.0	 16832	 16832	 16832	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 5598	 9.1e-05	 0.000581	 0.0	 572.0	 53713	 53713	 0.0	 0.0	 1	 -30.0	 30.0;
	7910	 8336	 0.00023	 0.00211	 0.0	 1876.0	 14883	 14883	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 8027	 8e-05	 0.00107	 0.0	 1613.0	 29439	 29439	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 8336	 2e-05	 0.0002	 0.0	 1415.0	 157153	 157153	 0.0	 0.0	 1	 -30.0	 30.0;
	7717	 1739	 0.00063	 0.00406	 0.0	 553.0	 7689	 7689	 0.0	 0.0	 1	 -30.0	 30.0;
	7717	 1067	 9.1e-05	 0.00056	 0.0	 533.0	 55676	 55676	 0.0	 0.0	 1	 -30.0	 30.0;
	8866	 2066	 0.00064	 0.003969	 0.0	 553.0	 7858	 7858	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 8866	 9.1e-05	 0.00055	 0.0	 476.0	 56662	 56662	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 1950	 2e-05	 0.0002	 0.0	 1580.0	 157153	 157153	 0.0	 0.0	 1	 -30.0	 30.0;
	8027	 4860	 0.00091	 0.01097	 0.0	 1448.0	 2870	 2870	 0.0	 0.0	 1	 -30.0	 30.0;
	1739	 2516	 0.00711	 0.045841	 0.0	 514.0	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	2066	 8696	 0.00724	 0.044849	 0.0	 553.0	 696	 696	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 8336	 5.952838	 17.29294	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 8336	 20.08726	 50.82479	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 1067	 4.890702	 15.41012	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 1067	 5.639256	 15.40868	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 1067	 4.76281	 15.7	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 1067	 21.2624	 53.66529	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 1067	 25.16942	 46.14463	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 6421	 5.023554	 17.83409	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 1581	 0.483492	 3.46095	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 1067	 0.000211	 0.0012	 0.0	 419.0	 25926	 25926	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 6655	 9.888017	 20.17066	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 6307	 9.581818	 15.8126	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1493	 1058	 0.00015	 0.00151	 0.0	 1580.0	 20817	 20817	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 1893	 0.00044	 0.00443	 0.0	 1547.0	 7096	 7096	 0.0	 0.0	 1	 -30.0	 30.0;
	2516	 6451	 0.00301	 0.01868	 0.0	 495.0	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	8696	 6451	 0.00268	 0.02118	 0.0	 476.0	 1480	 1480	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 1058	 0.00044	 0.00433	 0.0	 1481.0	 7258	 7258	 0.0	 0.0	 1	 -30.0	 30.0;
	1893	 1493	 0.00015	 0.00148	 0.0	 1448.0	 21235	 21235	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 4789	 36.67975	 64.23967	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 7592	 34.68595	 57.82851	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 3533	 0.001	 0.997107	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 3533	 0.001	 0.990558	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 3533	 0.00389	 0.03206	 0.0	 476.0	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 1971	 2.394421	 10.2281	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 1581	 0.001	 0.942996	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 6655	 7.162397	 16.07149	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 6307	 6.970248	 12.65785	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 6180	 0.00041	 0.00489	 0.0	 6437	 6437	 6437	 0.0	 0.0	 1	 -30.0	 30.0;
	8779	 6180	 0.00035	 0.00415	 0.0	 7585	 7585	 7585	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 4389	 0.00041	 0.00478	 0.0	 6585	 6585	 6585	 0.0	 0.0	 1	 -30.0	 30.0;
	8779	 4389	 0.00036	 0.00406	 0.0	 1711.0	 7750	 7750	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 7443	 0.00069	 0.00736	 0.0	 1810.0	 4274	 4274	 0.0	 0.0	 1	 -30.0	 30.0;
	3522	 4535	 0.00035	 0.00355	 0.0	 8855	 8855	 8855	 0.0	 0.0	 1	 -30.0	 30.0;
	2444	 4535	 0.0003	 0.0037	 0.0	 8510	 8510	 8510	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 5650	 0.00079	 0.00639	 0.0	 4906	 4906	 4906	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 2724	 10.65028	 23.35249	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 2724	 0.00035	 0.00375	 0.0	 8387	 8387	 8387	 0.0	 0.0	 1	 -30.0	 30.0;
	630	 2724	 0.00035	 0.00368	 0.0	 8545	 8545	 8545	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 7592	 0.0	 0.0002	 0.0	 476.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 7592	 0.001	 0.307397	 0.0	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 4789	 30.07851	 44.4938	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 4789	 28.13843	 48.89876	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 6421	 1.021095	 4.339256	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 1581	 19.04773	 44.46694	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 1085	 11.71198	 25.83058	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 3913	 13.4062	 28.03306	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 7592	 25.77686	 44.3843	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 7592	 29.27686	 39.66322	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 6421	 0.90343	 4.251446	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 1581	 15.67913	 46.04752	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 1085	 10.06777	 25.78512	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 3913	 11.7936	 27.51653	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	4732	 5650	 0.00037	 0.00319	 0.0	 1744.0	 9837	 9837	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 7443	 0.00037	 0.0032	 0.0	 1678.0	 9806	 9806	 0.0	 0.0	 1	 -30.0	 30.0;
	3267	 9084	 6e-05	 0.00057	 0.0	 55112	 55112	 55112	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 3267	 0.00081	 0.00793	 0.0	 3963	 3963	 3963	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 2605	 0.0	 0.0002	 0.0	 533.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 2605	 0.001	 0.218595	 0.0	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 1971	 5.508884	 16.92169	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 1581	 0.417335	 3.096901	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 6655	 35.56405	 45.20868	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 6307	 26.29545	 47.22107	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 1971	 5.134091	 18.53492	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 1581	 0.373512	 3.536364	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 6655	 31.99174	 51.7624	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2605	 6307	 26.61157	 47.82645	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6421	 1581	 22.02479	 61.94007	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 6421	 0.20395	 1.135248	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	3913	 6421	 0.207314	 1.339256	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 1581	 15.82955	 28.76446	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 6655	 27.39876	 40.44215	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 6307	 23.59711	 35.69835	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 1581	 1.210248	 3.369008	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 1581	 0.914421	 3.375826	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	3780	 1258	 0.005729	 0.02032	 0.0	 400.0	 1497	 1497	 0.0	 0.0	 1	 -30.0	 30.0;
	1623	 1258	 0.005841	 0.019909	 0.0	 438.0	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	4085	 1258	 0.084781	 0.493471	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 4052	 0.0	 0.0002	 0.0	 1349.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 4052	 0.001	 0.19356	 0.0	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 8193	 0.00192	 0.01356	 0.0	 2307	 2307	 2307	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 8193	 0.00172	 0.01537	 0.0	 2043	 2043	 2043	 0.0	 0.0	 1	 -30.0	 30.0;
	1918	 4206	 0.00035	 0.00346	 0.0	 1909.0	 9083	 9083	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 3913	 0.0	 0.0002	 0.0	 533.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 3913	 0.001	 0.159719	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 6049	 0.000341	 0.00199	 0.0	 591.0	 15646	 15646	 0.0	 0.0	 1	 -30.0	 30.0;
	6049	 7524	 0.00219	 0.012901	 0.0	 2414	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	7524	 4411	 0.002531	 0.013539	 0.0	 2294	 2294	 2294	 0.0	 0.0	 1	 -30.0	 30.0;
	4411	 7218	 0.002281	 0.01263	 0.0	 2462	 2462	 2462	 0.0	 0.0	 1	 -30.0	 30.0;
	7218	 112	 0.00232	 0.01393	 0.0	 2237	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	6369	 2038	 0.00043	 0.00418	 0.0	 1810.0	 7518	 7518	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 8429	 0.113102	 0.936981	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	8429	 1165	 0.00043	 0.00419	 0.0	 7500	 7500	 7500	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 8429	 0.124889	 1.006302	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	2608	 9077	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2608	 9077	 0.003651	 0.01288	 0.0	 2360	 2360	 2360	 0.0	 0.0	 1	 -30.0	 30.0;
	9077	 7321	 0.004021	 0.01951	 0.0	 1586	 1586	 1586	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 1150	 0.00057	 0.00402	 0.0	 7780	 7780	 7780	 0.0	 0.0	 1	 -30.0	 30.0;
	4041	 5428	 0.00064	 0.00448	 0.0	 6980	 6980	 6980	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 5428	 0.00646	 0.473407	 0.0	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	3264	 2038	 8e-05	 0.00061	 0.0	 889.0	 51343	 51343	 0.0	 0.0	 1	 -30.0	 30.0;
	779	 1165	 6e-05	 0.00065	 0.0	 1086.0	 48391	 48391	 0.0	 0.0	 1	 -30.0	 30.0;
	4085	 3780	 0.00012	 0.000461	 0.0	 400.0	 66310	 66310	 0.0	 0.0	 1	 -30.0	 30.0;
	4085	 1623	 0.00013	 0.00045	 0.0	 67437	 67437	 67437	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 6307	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 6307	 0.001	 0.249814	 0.0	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	8593	 7650	 0.0001	 0.00075	 0.0	 1218.0	 41748	 41748	 0.0	 0.0	 1	 -30.0	 30.0;
	8593	 7490	 0.0038	 0.11597	 0.0	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	8593	 7490	 0.0001	 0.00081	 0.0	 1283.0	 38703	 38703	 0.0	 0.0	 1	 -30.0	 30.0;
	6811	 7650	 0.0001	 0.00094	 0.0	 1283.0	 33415	 33415	 0.0	 0.0	 1	 -30.0	 30.0;
	6811	 7650	 9e-05	 0.00107	 0.0	 1152.0	 29418	 29418	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 6811	 7e-05	 0.00085	 0.0	 1119.0	 37037	 37037	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 6811	 8e-05	 0.00081	 0.0	 1283.0	 38808	 38808	 0.0	 0.0	 1	 -30.0	 30.0;
	7650	 7490	 0.00018	 0.00171	 0.0	 1086.0	 18371	 18371	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 2532	 0.00017	 0.00191	 0.0	 1415.0	 16473	 16473	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 2532	 0.00016	 0.00194	 0.0	 1349.0	 16228	 16228	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 7934	 0.0005	 0.00317	 0.0	 1514.0	 9843	 9843	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 7934	 0.00048	 0.00322	 0.0	 1547.0	 9703	 9703	 0.0	 0.0	 1	 -30.0	 30.0;
	7490	 4349	 0.00427	 0.19732	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	7490	 4349	 0.0001	 0.00122	 0.0	 1152.0	 25805	 25805	 0.0	 0.0	 1	 -30.0	 30.0;
	7490	 4349	 0.0001	 0.00119	 0.0	 1251.0	 26451	 26451	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 4498	 0.0024	 0.02048	 0.0	 1532	 1532	 1532	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 197	 0.00042	 0.00474	 0.0	 1876.0	 6638	 6638	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 2094	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 2094	 0.003409	 0.129831	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 7741	 0.00605	 0.024031	 0.0	 457.0	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 7741	 0.005919	 0.0245	 0.0	 419.0	 1254	 1254	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 6197	 0.406364	 1.478988	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 397	 0.12912	 0.95312	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 4971	 0.23062	 0.90281	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 2883	 0.05107	 0.366901	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 397	 0.00207	 0.0168	 0.0	 1867	 1867	 1867	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 1627	 0.00119	 0.009659	 0.0	 514.0	 3246	 3246	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 2883	 0.120151	 0.700041	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 5869	 0.032581	 0.326756	 0.0	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	3716	 5543	 2e-05	 0.0002	 0.0	 757.0	 157153	 157153	 0.0	 0.0	 1	 -30.0	 30.0;
	3716	 959	 0.00025	 0.00344	 0.0	 757.0	 9159	 9159	 0.0	 0.0	 1	 -30.0	 30.0;
	3716	 959	 0.01671	 0.288767	 0.0	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	3716	 2583	 0.01954	 0.281191	 0.0	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	6274	 3716	 0.00356	 0.222701	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	6274	 3716	 0.00271	 0.199571	 0.0	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	4637	 5543	 0.00016	 0.00253	 0.0	 921.0	 12461	 12461	 0.0	 0.0	 1	 -30.0	 30.0;
	6274	 5543	 0.00018	 0.00214	 0.0	 1251.0	 14709	 14709	 0.0	 0.0	 1	 -30.0	 30.0;
	6197	 397	 0.002091	 0.0138	 0.0	 2264	 2264	 2264	 0.0	 0.0	 1	 -30.0	 30.0;
	6197	 397	 0.291467	 1.202521	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 6197	 0.204719	 0.794277	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 6197	 0.026401	 0.214814	 0.0	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 6197	 0.00295	 0.01256	 0.0	 438.0	 2449	 2449	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 7815	 0.359525	 1.423657	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	4167	 7815	 0.32907	 1.339607	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	4167	 7815	 0.00469	 0.03913	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 7815	 0.000841	 0.00544	 0.0	 5739	 5739	 5739	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 7815	 0.014581	 0.16557	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 7815	 1.038884	 1.650227	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	7602	 7815	 0.863926	 1.96155	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 397	 0.005081	 0.02426	 0.0	 419.0	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 56	 0.470062	 1.363636	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 7127	 0.035969	 0.35219	 0.0	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 9165	 0.0033	 0.01864	 0.0	 476.0	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 9165	 0.018021	 0.1825	 0.0	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	5088	 6296	 0.002651	 0.027659	 0.0	 1137	 1137	 1137	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 5088	 0.00226	 0.04061	 0.0	 514.0	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	5088	 8287	 0.000711	 0.0098	 0.0	 3215	 3215	 3215	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 5088	 0.002211	 0.037599	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4113	 2420	 0.0016	 0.01356	 0.0	 1316.0	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	4113	 2420	 0.00165	 0.01328	 0.0	 1283.0	 2361	 2361	 0.0	 0.0	 1	 -30.0	 30.0;
	6274	 959	 0.01336	 0.25865	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	6274	 959	 0.00015	 0.00253	 0.0	 757.0	 12464	 12464	 0.0	 0.0	 1	 -30.0	 30.0;
	8855	 1663	 0.00225	 0.02106	 0.0	 1492	 1492	 1492	 0.0	 0.0	 1	 -30.0	 30.0;
	4226	 1663	 0.00426	 0.03506	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	6777	 1663	 0.00043	 0.00581	 0.0	 5422	 5422	 5422	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 3944	 0.001151	 0.009909	 0.0	 419.0	 3167	 3167	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 3944	 0.000961	 0.00751	 0.0	 610.0	 4173	 4173	 0.0	 0.0	 1	 -30.0	 30.0;
	853	 3944	 0.00032	 0.00324	 0.0	 438.0	 9702	 9702	 0.0	 0.0	 1	 -30.0	 30.0;
	8855	 1663	 0.00245	 0.02191	 0.0	 1053.0	 1433	 1433	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 1663	 0.00037	 0.00606	 0.0	 921.0	 5203	 5203	 0.0	 0.0	 1	 -30.0	 30.0;
	6977	 1663	 0.0029	 0.0289	 0.0	 1088	 1088	 1088	 0.0	 0.0	 1	 -30.0	 30.0;
	7055	 397	 0.000151	 0.00156	 0.0	 20155	 20155	 20155	 0.0	 0.0	 1	 -30.0	 30.0;
	9086	 397	 0.00014	 0.00144	 0.0	 21833	 21833	 21833	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 397	 0.026841	 0.406942	 0.0	 78	 78	 78	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 397	 0.025909	 0.304649	 0.0	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 827	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 827	 0.001	 0.18678	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	8454	 2630	 0.989958	 2.675	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	8292	 2630	 0.994529	 2.704017	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 2630	 0.154938	 0.902078	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 2630	 0.141247	 1.002008	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	9116	 2630	 0.01709	 0.303539	 0.0	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 7424	 0.00081	 0.00826	 0.0	 1547.0	 3806	 3806	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 4113	 0.00174	 0.01199	 0.0	 1481.0	 2608	 2608	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 6193	 0.00136	 0.012	 0.0	 1020.0	 2616	 2616	 0.0	 0.0	 1	 -30.0	 30.0;
	8454	 827	 1.135249	 2.306648	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	8292	 827	 1.077147	 2.483726	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 827	 0.140319	 0.988089	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 827	 0.15108	 0.940582	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	9116	 827	 0.00045	 0.00442	 0.0	 1382.0	 7110	 7110	 0.0	 0.0	 1	 -30.0	 30.0;
	9116	 827	 0.01578	 0.332528	 0.0	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 827	 0.00032	 0.00308	 0.0	 10201	 10201	 10201	 0.0	 0.0	 1	 -30.0	 30.0;
	327	 4637	 0.00018	 0.0025	 0.0	 1942.0	 12603	 12603	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 4637	 0.03152	 0.366053	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 3761	 0.00251	 0.13469	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 5325	 0.00943	 0.04787	 0.0	 419.0	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 7127	 0.002781	 0.02494	 0.0	 1259	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 7127	 0.22876	 0.857376	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 9165	 0.113521	 0.454752	 0.0	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	8855	 7617	 0.00159	 0.01603	 0.0	 1415.0	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 4167	 0.00924	 0.04881	 0.0	 495.0	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 9165	 0.00643	 0.027271	 0.0	 533.0	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	8855	 4226	 0.00183	 0.01368	 0.0	 1810.0	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	8199	 5360	 0.0	 0.0002	 0.0	 954.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8199	 5360	 0.001	 0.191392	 0.0	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3254	 8199	 0.00081	 0.00981	 0.0	 1547.0	 3209	 3209	 0.0	 0.0	 1	 -30.0	 30.0;
	8199	 4946	 0.090907	 0.571413	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	8199	 4946	 0.00058	 0.00647	 0.0	 1547.0	 4863	 4863	 0.0	 0.0	 1	 -30.0	 30.0;
	8199	 8968	 0.441572	 1.595429	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	8199	 4840	 0.0463	 0.493158	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	8199	 5972	 0.053	 0.456427	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	5972	 5360	 0.00048	 0.00707	 0.0	 1514.0	 4458	 4458	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 4946	 0.0007	 0.00626	 0.0	 1777.0	 5015	 5015	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 4946	 0.099273	 0.491122	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 8968	 0.411558	 1.466205	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 4840	 0.05226	 0.428179	 0.0	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 5972	 0.04979	 0.473137	 0.0	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	7170	 1425	 0.00018	 0.00218	 0.0	 14441	 14441	 14441	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 4366	 0.344619	 1.353116	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 2385	 0.581787	 1.764958	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 7920	 0.075831	 0.835526	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 7920	 0.00095	 0.0105	 0.0	 1481.0	 2997	 2997	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 2080	 0.081281	 0.782202	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 7424	 0.06719	 0.554377	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 6193	 0.00409	 0.271641	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 6193	 0.00041	 0.00351	 0.0	 1448.0	 8939	 8939	 0.0	 0.0	 1	 -30.0	 30.0;
	7957	 652	 0.00138	 0.008789	 0.0	 533.0	 3551	 3551	 0.0	 0.0	 1	 -30.0	 30.0;
	7957	 3303	 0.002331	 0.01832	 0.0	 1711	 1711	 1711	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 2385	 0.0	 0.0002	 0.0	 1876.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 2385	 0.001	 0.311717	 0.0	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	1588	 4366	 0.00043	 0.00408	 0.0	 1843.0	 7700	 7700	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 7920	 0.083899	 0.525478	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 2080	 0.07124	 0.605921	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 1425	 0.00013	 0.00147	 0.0	 21405	 21405	 21405	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 7424	 2.055194	 4.798753	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	8968	 4366	 0.00048	 0.00587	 0.0	 1744.0	 5364	 5364	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 4366	 0.81115	 2.560526	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 7957	 0.00095	 0.004169	 0.0	 7388	 7388	 7388	 0.0	 0.0	 1	 -30.0	 30.0;
	8113	 7957	 0.01012	 0.04631	 0.0	 495.0	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	3005	 2385	 0.00013	 0.0014	 0.0	 757.0	 22466	 22466	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 2385	 0.00013	 0.00143	 0.0	 1415.0	 21999	 21999	 0.0	 0.0	 1	 -30.0	 30.0;
	2385	 7920	 0.091447	 0.726385	 0.0	 44	 44	 44	 0.0	 0.0	 1	 -30.0	 30.0;
	2385	 7920	 0.00093	 0.00869	 0.0	 987.0	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	2385	 2080	 0.089307	 0.727078	 0.0	 44	 44	 44	 0.0	 0.0	 1	 -30.0	 30.0;
	2385	 7424	 3.590651	 5.504778	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 2385	 0.00047	 0.00544	 0.0	 1580.0	 5785	 5785	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 2385	 1.2741	 3.747645	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	7966	 4206	 0.00142	 0.01566	 0.0	 1415.0	 2009	 2009	 0.0	 0.0	 1	 -30.0	 30.0;
	2080	 6667	 0.00082	 0.00794	 0.0	 3958	 3958	 3958	 0.0	 0.0	 1	 -30.0	 30.0;
	8454	 8292	 0.0	 0.0002	 0.0	 1415.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8454	 8292	 0.001	 0.149882	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 8454	 0.088033	 0.626579	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 8454	 0.001	 0.00866	 0.0	 1283.0	 3624	 3624	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 8454	 0.090852	 0.619418	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	9116	 8454	 0.87133	 2.390028	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 8292	 0.087632	 0.633012	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 8292	 0.097832	 0.57669	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	9116	 8292	 0.857064	 2.463089	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	8292	 4113	 0.0004	 0.0039	 0.0	 1086.0	 8058	 8058	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 4167	 0.001	 0.486508	 0.0	 65	 65	 65	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 5325	 0.003909	 0.034711	 0.0	 591.0	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 5325	 0.497789	 2.055971	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 4804	 0.357087	 1.677376	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 7602	 0.349194	 1.694876	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 4167	 0.438409	 2.013802	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	4167	 4804	 0.307107	 1.517831	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	4167	 7602	 0.354174	 1.443988	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	8620	 2493	 0.00274	 0.144159	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	8620	 6586	 0.00039	 0.00175	 0.0	 17618	 17618	 17618	 0.0	 0.0	 1	 -30.0	 30.0;
	2493	 8916	 0.000401	 0.001711	 0.0	 457.0	 17975	 17975	 0.0	 0.0	 1	 -30.0	 30.0;
	7966	 5100	 0.06537	 0.54912	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	7966	 1588	 0.00098	 0.00852	 0.0	 1086.0	 3684	 3684	 0.0	 0.0	 1	 -30.0	 30.0;
	7966	 1588	 0.076039	 0.582729	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	7966	 1994	 0.00185	 0.01418	 0.0	 1053.0	 2209	 2209	 0.0	 0.0	 1	 -30.0	 30.0;
	2890	 7966	 0.790374	 2.170014	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	1675	 652	 0.00188	 0.0087	 0.0	 495.0	 3549	 3549	 0.0	 0.0	 1	 -30.0	 30.0;
	1675	 3539	 0.042461	 0.437066	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	417	 3539	 0.00068	 0.008531	 0.0	 476.0	 3691	 3691	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 7920	 0.00107	 0.01108	 0.0	 1942.0	 2838	 2838	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 7424	 0.00092	 0.00947	 0.0	 1711.0	 3320	 3320	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 3319	 0.0	 0.0002	 0.0	 1678.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 3319	 0.001	 0.196378	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 9116	 0.102652	 0.915512	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 9116	 0.110602	 0.871537	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	6066	 3319	 0.00153	 0.01371	 0.0	 1316.0	 2290	 2290	 0.0	 0.0	 1	 -30.0	 30.0;
	8899	 3319	 0.00296	 0.02271	 0.0	 1053.0	 1380	 1380	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 1588	 0.0	 0.0002	 0.0	 757.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 1588	 0.001	 0.229661	 0.0	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 1994	 0.00076	 0.0066	 0.0	 1086.0	 4755	 4755	 0.0	 0.0	 1	 -30.0	 30.0;
	2890	 5100	 0.134051	 0.802355	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	2890	 1588	 0.136413	 0.960942	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	8520	 8916	 0.0027	 0.02195	 0.0	 495.0	 1429	 1429	 0.0	 0.0	 1	 -30.0	 30.0;
	8520	 3303	 0.001211	 0.004961	 0.0	 6186	 6186	 6186	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 7055	 0.010091	 0.211612	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 9086	 0.008349	 0.215682	 0.0	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 2145	 0.000401	 0.001781	 0.0	 17303	 17303	 17303	 0.0	 0.0	 1	 -30.0	 30.0;
	7055	 9086	 0.00076	 0.205461	 0.0	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	8968	 6777	 0.00086	 0.0138	 0.0	 1711.0	 2285	 2285	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 1128	 0.00101	 0.01174	 0.0	 1613.0	 2681	 2681	 0.0	 0.0	 1	 -30.0	 30.0;
	7920	 2080	 0.0	 0.0002	 0.0	 1481.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7920	 2080	 0.001	 0.17286	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	7920	 7424	 0.917036	 2.770706	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 7920	 0.299162	 1.508587	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	2080	 7424	 0.973546	 2.445291	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 2080	 0.335817	 1.383795	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	782	 4804	 0.00114	 0.00625	 0.0	 553.0	 4972	 4972	 0.0	 0.0	 1	 -30.0	 30.0;
	5017	 782	 0.00069	 0.00343	 0.0	 9029	 9029	 9029	 0.0	 0.0	 1	 -30.0	 30.0;
	7171	 782	 0.000669	 0.00349	 0.0	 8889	 8889	 8889	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 782	 0.00264	 0.01612	 0.0	 533.0	 1934	 1934	 0.0	 0.0	 1	 -30.0	 30.0;
	3254	 4226	 0.001	 0.01303	 0.0	 1744.0	 2418	 2418	 0.0	 0.0	 1	 -30.0	 30.0;
	951	 4226	 0.00018	 0.00112	 0.0	 823.0	 27846	 27846	 0.0	 0.0	 1	 -30.0	 30.0;
	6020	 1346	 0.000771	 0.0027	 0.0	 419.0	 11250	 11250	 0.0	 0.0	 1	 -30.0	 30.0;
	1181	 1346	 0.000719	 0.003039	 0.0	 10115	 10115	 10115	 0.0	 0.0	 1	 -30.0	 30.0;
	1346	 7602	 0.00138	 0.005409	 0.0	 495.0	 5659	 5659	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 7617	 0.00017	 0.0011	 0.0	 1744.0	 28379	 28379	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 4971	 0.01424	 0.207211	 0.0	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	7127	 4971	 0.00288	 0.023031	 0.0	 1361	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	9116	 6274	 0.00059	 0.00738	 0.0	 1218.0	 4267	 4267	 0.0	 0.0	 1	 -30.0	 30.0;
	4164	 4840	 2e-05	 0.0002	 0.0	 1251.0	 157153	 157153	 0.0	 0.0	 1	 -30.0	 30.0;
	3254	 6605	 0.00034	 0.00243	 0.0	 757.0	 12874	 12874	 0.0	 0.0	 1	 -30.0	 30.0;
	6274	 2583	 0.00939	 0.239481	 0.0	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	6274	 2583	 0.0003	 0.00385	 0.0	 757.0	 8180	 8180	 0.0	 0.0	 1	 -30.0	 30.0;
	6297	 8287	 0.00082	 0.0117	 0.0	 2694	 2694	 2694	 0.0	 0.0	 1	 -30.0	 30.0;
	6297	 6296	 0.000831	 0.010711	 0.0	 2941	 2941	 2941	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 2138	 0.0	 0.0002	 0.0	 1152.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 2138	 0.001	 0.424958	 0.0	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 2906	 0.00035	 0.00315	 0.0	 9967	 9967	 9967	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 2906	 0.01362	 0.396288	 0.0	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 6274	 0.088213	 0.739543	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	2138	 2906	 0.01388	 0.388199	 0.0	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	2138	 6274	 0.0012	 0.01148	 0.0	 1843.0	 2737	 2737	 0.0	 0.0	 1	 -30.0	 30.0;
	2138	 6274	 0.086413	 0.754086	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	327	 8968	 0.00049	 0.00475	 0.0	 1547.0	 6615	 6615	 0.0	 0.0	 1	 -30.0	 30.0;
	2901	 5622	 0.002669	 0.01443	 0.0	 419.0	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 652	 0.00338	 0.01488	 0.0	 572.0	 2071	 2071	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 8916	 0.00101	 0.005841	 0.0	 5329	 5329	 5329	 0.0	 0.0	 1	 -30.0	 30.0;
	6777	 1994	 0.00034	 0.00381	 0.0	 1744.0	 8258	 8258	 0.0	 0.0	 1	 -30.0	 30.0;
	2890	 1994	 0.00017	 0.00223	 0.0	 1678.0	 14124	 14124	 0.0	 0.0	 1	 -30.0	 30.0;
	5869	 6586	 0.00161	 0.013789	 0.0	 553.0	 2276	 2276	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 7914	 0.00032	 0.00234	 0.0	 1777.0	 13375	 13375	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 7424	 0.01246	 0.249882	 0.0	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 2906	 0.00073	 0.00838	 0.0	 1514.0	 3756	 3756	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 8968	 0.01019	 0.13124	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 8968	 0.00078	 0.00873	 0.0	 1580.0	 3604	 3604	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 4840	 0.463179	 1.173823	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 5972	 0.428629	 1.321537	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	6274	 2906	 0.099591	 0.647687	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	7731	 2906	 0.00019	 0.00245	 0.0	 1547.0	 12855	 12855	 0.0	 0.0	 1	 -30.0	 30.0;
	8968	 4840	 1.591828	 3.383587	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	8968	 5972	 1.558587	 3.254017	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 4804	 1.410971	 2.609298	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 7602	 1.456178	 2.474793	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 7602	 0.0	 0.0002	 0.0	 495.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 7602	 0.001	 0.139341	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	4840	 5972	 0.0	 0.0002	 0.0	 1119.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4840	 5972	 0.001	 0.196801	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	7767	 1627	 0.00025	 0.00232	 0.0	 13537	 13537	 13537	 0.0	 0.0	 1	 -30.0	 30.0;
	5869	 7767	 0.000719	 0.005461	 0.0	 5735	 5735	 5735	 0.0	 0.0	 1	 -30.0	 30.0;
	1627	 8753	 0.00012	 0.00069	 0.0	 45102	 45102	 45102	 0.0	 0.0	 1	 -30.0	 30.0;
	6541	 1627	 0.003099	 0.11999	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	7127	 9165	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7127	 9165	 0.001	 0.13145	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 5869	 0.10799	 0.554256	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 8553	 0.00077	 0.00927	 0.0	 1744.0	 3396	 3396	 0.0	 0.0	 1	 -30.0	 30.0;
	6538	 8553	 0.00078	 0.00908	 0.0	 3467	 3467	 3467	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 6894	 0.00038	 0.0045	 0.0	 790.0	 6995	 6995	 0.0	 0.0	 1	 -30.0	 30.0;
	6894	 6458	 0.00147	 0.0125	 0.0	 1777.0	 2510	 2510	 0.0	 0.0	 1	 -30.0	 30.0;
	6668	 6894	 0.00039	 0.00441	 0.0	 757.0	 7135	 7135	 0.0	 0.0	 1	 -30.0	 30.0;
	6894	 1243	 0.00202	 0.01654	 0.0	 1613.0	 1896	 1896	 0.0	 0.0	 1	 -30.0	 30.0;
	6538	 8333	 0.0	 0.0002	 0.0	 1448.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6538	 8333	 0.00147	 0.112341	 0.0	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	6538	 4859	 0.00069	 0.00564	 0.0	 1613.0	 5560	 5560	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 6668	 0.00068	 0.00574	 0.0	 1580.0	 5465	 5465	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 6668	 0.0	 0.0002	 0.0	 757.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 6668	 0.00088	 0.07777	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	590	 4859	 0.00062	 0.00515	 0.0	 1185.0	 6090	 6090	 0.0	 0.0	 1	 -30.0	 30.0;
	2394	 6668	 0.0007	 0.00505	 0.0	 1185.0	 6196	 6196	 0.0	 0.0	 1	 -30.0	 30.0;
	590	 2394	 0.0	 0.0002	 0.0	 1086.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	590	 2394	 0.00076	 0.06481	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	3090	 459	 0.00011	 0.00149	 0.0	 21143	 21143	 21143	 0.0	 0.0	 1	 -30.0	 30.0;
	5894	 1927	 9.9e-05	 0.000979	 0.0	 32102	 32102	 32102	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 3934	 0.01788	 0.227831	 0.0	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 3934	 0.004669	 0.015969	 0.0	 419.0	 1899	 1899	 0.0	 0.0	 1	 -30.0	 30.0;
	6830	 5433	 0.011229	 0.03868	 0.0	 381.0	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	388	 5433	 0.01001	 0.043841	 0.0	 381.0	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 476	 0.002151	 0.01032	 0.0	 2997	 2997	 2997	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 5896	 0.003281	 0.017901	 0.0	 629.0	 1736	 1736	 0.0	 0.0	 1	 -30.0	 30.0;
	2439	 4256	 0.005271	 0.026909	 0.0	 457.0	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 8451	 0.00044	 0.002169	 0.0	 495.0	 14273	 14273	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 8451	 0.00045	 0.00213	 0.0	 495.0	 14510	 14510	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 6227	 0.452251	 2.097438	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	6227	 1214	 0.247659	 1.380679	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 6227	 0.436378	 1.290097	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 6227	 0.218089	 1.220914	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	4786	 6227	 0.0612	 1.024169	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 6227	 0.06168	 0.959765	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 6227	 0.0011	 0.00838	 0.0	 1613.0	 3738	 3738	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 6227	 0.05459	 0.962258	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 6227	 0.00126	 0.01278	 0.0	 1514.0	 2460	 2460	 0.0	 0.0	 1	 -30.0	 30.0;
	8541	 1614	 5e-05	 0.000229	 0.0	 134762	 134762	 134762	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 8541	 0.001331	 0.009331	 0.0	 629.0	 3352	 3352	 0.0	 0.0	 1	 -30.0	 30.0;
	8541	 9200	 6e-05	 0.00031	 0.0	 457.0	 100039	 100039	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 6418	 0.00155	 0.00805	 0.0	 3854	 3854	 3854	 0.0	 0.0	 1	 -30.0	 30.0;
	6418	 158	 0.351674	 1.414483	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 6418	 0.239545	 1.416095	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	5228	 1927	 0.00011	 0.00088	 0.0	 381.0	 35618	 35618	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 459	 0.00012	 0.00064	 0.0	 48510	 48510	 48510	 0.0	 0.0	 1	 -30.0	 30.0;
	8216	 459	 0.002349	 0.01088	 0.0	 438.0	 2838	 2838	 0.0	 0.0	 1	 -30.0	 30.0;
	8216	 459	 0.0023	 0.011099	 0.0	 419.0	 2787	 2787	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 853	 0.004771	 0.03713	 0.0	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 1927	 0.00056	 0.0013	 0.0	 22316	 22316	 22316	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 1927	 0.001091	 0.007409	 0.0	 438.0	 4218	 4218	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 1927	 0.00168	 0.007479	 0.0	 4121	 4121	 4121	 0.0	 0.0	 1	 -30.0	 30.0;
	1432	 1927	 0.003151	 0.01876	 0.0	 514.0	 1661	 1661	 0.0	 0.0	 1	 -30.0	 30.0;
	1160	 2647	 0.005719	 0.255764	 0.0	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 1160	 0.000599	 0.00294	 0.0	 10528	 10528	 10528	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 2647	 0.00062	 0.00288	 0.0	 553.0	 10723	 10723	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 4785	 0.001169	 0.012591	 0.0	 2498	 2498	 2498	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 4785	 0.00131	 0.01119	 0.0	 2804	 2804	 2804	 0.0	 0.0	 1	 -30.0	 30.0;
	6407	 4785	 0.000159	 0.00137	 0.0	 22903	 22903	 22903	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 4785	 0.000159	 0.001341	 0.0	 23392	 23392	 23392	 0.0	 0.0	 1	 -30.0	 30.0;
	8516	 1293	 0.00051	 0.0025	 0.0	 12380	 12380	 12380	 0.0	 0.0	 1	 -30.0	 30.0;
	4471	 7097	 0.00031	 0.001289	 0.0	 457.0	 23826	 23826	 0.0	 0.0	 1	 -30.0	 30.0;
	8516	 7097	 0.05163	 0.55124	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	7655	 7097	 0.201229	 1.043864	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	7748	 5779	 1.027128	 2.385331	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	7748	 167	 0.288306	 1.382335	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	6997	 7748	 0.05949	 0.340661	 0.0	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	7748	 2614	 0.007211	 0.030409	 0.0	 1011	 1011	 1011	 0.0	 0.0	 1	 -30.0	 30.0;
	8639	 7748	 0.899153	 2.660744	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 7748	 0.809979	 2.92686	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	7748	 5324	 0.00251	 0.011211	 0.0	 419.0	 2750	 2750	 0.0	 0.0	 1	 -30.0	 30.0;
	8113	 4793	 0.08695	 0.512231	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	8113	 8798	 0.006289	 0.693946	 0.0	 46	 46	 46	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 8113	 0.140669	 0.495269	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 8113	 0.00882	 0.041831	 0.0	 476.0	 739	 739	 0.0	 0.0	 1	 -30.0	 30.0;
	6977	 1825	 2e-05	 0.00025	 0.0	 757.0	 125947	 125947	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 4434	 0.000159	 0.00074	 0.0	 41734	 41734	 41734	 0.0	 0.0	 1	 -30.0	 30.0;
	1004	 6661	 0.004469	 0.139591	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	1004	 2413	 0.001039	 0.006211	 0.0	 438.0	 5017	 5017	 0.0	 0.0	 1	 -30.0	 30.0;
	7430	 9095	 0.00813	 0.186659	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	7430	 2413	 0.00101	 0.00625	 0.0	 400.0	 4990	 4990	 0.0	 0.0	 1	 -30.0	 30.0;
	5943	 571	 8.1e-05	 0.000781	 0.0	 438.0	 40229	 40229	 0.0	 0.0	 1	 -30.0	 30.0;
	5943	 6948	 0.0003	 0.002031	 0.0	 476.0	 15386	 15386	 0.0	 0.0	 1	 -30.0	 30.0;
	7125	 571	 9.1e-05	 0.000719	 0.0	 629.0	 43585	 43585	 0.0	 0.0	 1	 -30.0	 30.0;
	7125	 8123	 0.00086	 0.005581	 0.0	 629.0	 5594	 5594	 0.0	 0.0	 1	 -30.0	 30.0;
	4474	 1214	 0.00062	 0.00605	 0.0	 856.0	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 571	 0.00181	 0.009599	 0.0	 3234	 3234	 3234	 0.0	 0.0	 1	 -30.0	 30.0;
	6321	 571	 0.00099	 0.00481	 0.0	 629.0	 6433	 6433	 0.0	 0.0	 1	 -30.0	 30.0;
	571	 4496	 0.00038	 0.00218	 0.0	 14275	 14275	 14275	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 1400	 0.00031	 0.00342	 0.0	 1777.0	 9199	 9199	 0.0	 0.0	 1	 -30.0	 30.0;
	7116	 1400	 0.00083	 0.00929	 0.0	 1415.0	 3387	 3387	 0.0	 0.0	 1	 -30.0	 30.0;
	3249	 1400	 0.00074	 0.00793	 0.0	 3967	 3967	 3967	 0.0	 0.0	 1	 -30.0	 30.0;
	3116	 3249	 0.00016	 0.00166	 0.0	 1843.0	 18941	 18941	 0.0	 0.0	 1	 -30.0	 30.0;
	1400	 8187	 0.0	 0.0002	 0.0	 1119.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1400	 8187	 0.01471	 0.443012	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	1323	 8187	 0.00037	 0.00337	 0.0	 1843.0	 9318	 9318	 0.0	 0.0	 1	 -30.0	 30.0;
	6830	 2903	 0.001461	 0.006711	 0.0	 4600	 4600	 4600	 0.0	 0.0	 1	 -30.0	 30.0;
	1855	 2903	 0.001479	 0.00656	 0.0	 591.0	 4698	 4698	 0.0	 0.0	 1	 -30.0	 30.0;
	7220	 4793	 0.00068	 0.0113	 0.0	 2791	 2791	 2791	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 3116	 0.00019	 0.00196	 0.0	 757.0	 16041	 16041	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 3116	 0.00019	 0.00198	 0.0	 757.0	 15881	 15881	 0.0	 0.0	 1	 -30.0	 30.0;
	1323	 5380	 0.00886	 0.294079	 0.0	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	1323	 5380	 0.00028	 0.00275	 0.0	 1711.0	 11428	 11428	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 5380	 0.01321	 0.296717	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 8816	 0.001	 0.169901	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 158	 0.03111	 0.255	 0.0	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 8346	 0.00057	 0.002849	 0.0	 10872	 10872	 10872	 0.0	 0.0	 1	 -30.0	 30.0;
	8816	 158	 0.03143	 0.234731	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 8816	 0.000581	 0.002789	 0.0	 553.0	 11088	 11088	 0.0	 0.0	 1	 -30.0	 30.0;
	8602	 3905	 0.00157	 0.007	 0.0	 572.0	 4404	 4404	 0.0	 0.0	 1	 -30.0	 30.0;
	8602	 683	 0.00131	 0.00636	 0.0	 591.0	 4865	 4865	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 3905	 0.001669	 0.00724	 0.0	 514.0	 4252	 4252	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 4146	 0.00663	 0.249339	 0.0	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 1147	 0.000169	 0.00032	 0.0	 87286	 87286	 87286	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 3947	 0.000151	 0.00038	 0.0	 77250	 77250	 77250	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 2655	 0.000841	 0.009581	 0.0	 3285	 3285	 3285	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 540	 0.0355	 0.360558	 0.0	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 683	 0.027539	 0.325145	 0.0	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 3854	 0.025271	 0.339442	 0.0	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 8624	 0.000169	 0.000219	 0.0	 114188	 114188	 114188	 0.0	 0.0	 1	 -30.0	 30.0;
	2433	 158	 0.000401	 0.0018	 0.0	 17129	 17129	 17129	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 2433	 0.00205	 0.01162	 0.0	 2678	 2678	 2678	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 2433	 0.000651	 0.0045	 0.0	 6948	 6948	 6948	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 158	 0.00038	 0.00187	 0.0	 16554	 16554	 16554	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 2944	 0.002091	 0.01139	 0.0	 438.0	 2728	 2728	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 2944	 0.00064	 0.004169	 0.0	 7489	 7489	 7489	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 158	 0.03551	 0.421116	 0.0	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 886	 0.090159	 0.624236	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 7997	 0.025919	 0.457603	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 2610	 0.140581	 0.992087	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 8033	 0.00082	 0.007331	 0.0	 629.0	 4283	 4283	 0.0	 0.0	 1	 -30.0	 30.0;
	8216	 822	 0.008469	 0.038599	 0.0	 800	 800	 800	 0.0	 0.0	 1	 -30.0	 30.0;
	8216	 6452	 0.003729	 0.012081	 0.0	 457.0	 2499	 2499	 0.0	 0.0	 1	 -30.0	 30.0;
	6997	 5779	 0.071281	 0.33186	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	6997	 5779	 0.011919	 0.055651	 0.0	 419.0	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 9225	 0.0038	 0.01182	 0.0	 457.0	 2545	 2545	 0.0	 0.0	 1	 -30.0	 30.0;
	3116	 7731	 0.00233	 0.0191	 0.0	 1642	 1642	 1642	 0.0	 0.0	 1	 -30.0	 30.0;
	3116	 6343	 0.00258	 0.02125	 0.0	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	3116	 7731	 0.00246	 0.01795	 0.0	 1744	 1744	 1744	 0.0	 0.0	 1	 -30.0	 30.0;
	3116	 9160	 0.00231	 0.02199	 0.0	 1429	 1429	 1429	 0.0	 0.0	 1	 -30.0	 30.0;
	7116	 3116	 0.00105	 0.0114	 0.0	 1909.0	 2760	 2760	 0.0	 0.0	 1	 -30.0	 30.0;
	3116	 873	 0.00268	 0.02035	 0.0	 1539	 1539	 1539	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 1993	 0.00124	 0.005711	 0.0	 5406	 5406	 5406	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 9198	 0.0002	 0.0022	 0.0	 572.0	 14299	 14299	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 2784	 0.00019	 0.00225	 0.0	 13990	 13990	 13990	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 6886	 0.001169	 0.005159	 0.0	 553.0	 5972	 5972	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 8479	 0.001271	 0.005591	 0.0	 5510	 5510	 5510	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 3321	 0.00182	 0.01218	 0.0	 476.0	 2565	 2565	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 7161	 0.00107	 0.005789	 0.0	 5366	 5366	 5366	 0.0	 0.0	 1	 -30.0	 30.0;
	6470	 79	 0.00026	 0.00275	 0.0	 1613.0	 11436	 11436	 0.0	 0.0	 1	 -30.0	 30.0;
	6470	 798	 0.0001	 0.00093	 0.0	 1909.0	 33771	 33771	 0.0	 0.0	 1	 -30.0	 30.0;
	9154	 8270	 0.00019	 0.00166	 0.0	 1876.0	 18906	 18906	 0.0	 0.0	 1	 -30.0	 30.0;
	9154	 8270	 0.00019	 0.00163	 0.0	 1909.0	 19249	 19249	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 5491	 0.00126	 0.00953	 0.0	 1810.0	 3286	 3286	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 7725	 0.00131	 0.00994	 0.0	 1942.0	 3151	 3151	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 5491	 0.00128	 0.00933	 0.0	 1777.0	 3355	 3355	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 9143	 0.00134	 0.00972	 0.0	 1777.0	 3220	 3220	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 1943	 0.001	 0.180201	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 7725	 1.365928	 3.472299	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 9143	 0.186177	 1.029224	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 3772	 0.98608	 2.33608	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 7715	 0.487888	 1.618975	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 5387	 0.850277	 2.290235	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 7725	 1.29162	 3.486565	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 9143	 0.201801	 0.8991	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 1943	 0.842729	 2.35651	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 7715	 0.415547	 1.630194	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 5387	 0.830956	 1.995914	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	476	 8955	 0.005729	 0.021281	 0.0	 400.0	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	476	 8955	 0.005081	 0.029331	 0.0	 1062	 1062	 1062	 0.0	 0.0	 1	 -30.0	 30.0;
	6981	 8955	 0.00576	 0.035781	 0.0	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 8955	 0.002021	 0.00976	 0.0	 533.0	 3170	 3170	 0.0	 0.0	 1	 -30.0	 30.0;
	3176	 8955	 0.00563	 0.03313	 0.0	 457.0	 940	 940	 0.0	 0.0	 1	 -30.0	 30.0;
	8725	 6965	 0.001	 0.260568	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	6906	 8725	 0.127098	 1.298546	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 8725	 0.04182	 0.986219	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 8725	 0.00129	 0.01393	 0.0	 1909.0	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	2260	 8725	 0.00082	 0.00915	 0.0	 1876.0	 3439	 3439	 0.0	 0.0	 1	 -30.0	 30.0;
	330	 8725	 0.00119	 0.01287	 0.0	 1777.0	 2444	 2444	 0.0	 0.0	 1	 -30.0	 30.0;
	6906	 6965	 0.118677	 1.418975	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	6906	 6965	 0.00148	 0.01585	 0.0	 1909.0	 1985	 1985	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 6965	 0.04574	 0.913504	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	7781	 6965	 0.00116	 0.01192	 0.0	 1448.0	 2638	 2638	 0.0	 0.0	 1	 -30.0	 30.0;
	7116	 1148	 0.06698	 0.909972	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	7116	 1148	 0.00042	 0.00331	 0.0	 9468	 9468	 9468	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 4140	 0.002591	 0.01299	 0.0	 2385	 2385	 2385	 0.0	 0.0	 1	 -30.0	 30.0;
	4140	 2300	 0.01169	 0.067849	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	7324	 3709	 0.00074	 0.00368	 0.0	 438.0	 8416	 8416	 0.0	 0.0	 1	 -30.0	 30.0;
	7324	 167	 0.00064	 0.0042	 0.0	 7435	 7435	 7435	 0.0	 0.0	 1	 -30.0	 30.0;
	7324	 5324	 0.0018	 0.01139	 0.0	 591.0	 2740	 2740	 0.0	 0.0	 1	 -30.0	 30.0;
	842	 3709	 0.00082	 0.003401	 0.0	 476.0	 9029	 9029	 0.0	 0.0	 1	 -30.0	 30.0;
	842	 167	 0.00069	 0.00381	 0.0	 8158	 8158	 8158	 0.0	 0.0	 1	 -30.0	 30.0;
	842	 5324	 0.00189	 0.01094	 0.0	 591.0	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 5184	 0.000151	 0.000711	 0.0	 43458	 43458	 43458	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 1359	 0.00013	 0.000789	 0.0	 39503	 39503	 39503	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 7335	 5e-05	 0.00024	 0.0	 128848	 128848	 128848	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 867	 5e-05	 0.00025	 0.0	 123896	 123896	 123896	 0.0	 0.0	 1	 -30.0	 30.0;
	8639	 3709	 0.00012	 0.000711	 0.0	 43808	 43808	 43808	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 3709	 0.00011	 0.000719	 0.0	 43428	 43428	 43428	 0.0	 0.0	 1	 -30.0	 30.0;
	657	 4154	 0.003091	 0.015719	 0.0	 1972	 1972	 1972	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 8638	 0.018159	 0.39124	 0.0	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 6336	 0.169419	 0.883946	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 3479	 0.656054	 1.65126	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 5232	 0.452913	 1.939091	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 8699	 0.055969	 0.74907	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 4154	 0.549483	 1.897438	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 4154	 0.483574	 1.959731	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 7620	 0.279731	 1.818967	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 7620	 0.006521	 0.02749	 0.0	 381.0	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	7444	 6083	 0.07687	 1.255956	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	7444	 6083	 0.00068	 0.00577	 0.0	 1678.0	 5437	 5437	 0.0	 0.0	 1	 -30.0	 30.0;
	4471	 6973	 0.00812	 0.12314	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	17	 4471	 0.00157	 0.007031	 0.0	 514.0	 4385	 4385	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 4471	 0.001599	 0.00688	 0.0	 495.0	 4472	 4472	 0.0	 0.0	 1	 -30.0	 30.0;
	4471	 8516	 0.00113	 0.00724	 0.0	 629.0	 4311	 4311	 0.0	 0.0	 1	 -30.0	 30.0;
	4471	 8516	 0.001271	 0.007091	 0.0	 591.0	 4385	 4385	 0.0	 0.0	 1	 -30.0	 30.0;
	657	 8699	 0.000919	 0.005211	 0.0	 572.0	 5970	 5970	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 6321	 0.00199	 0.010219	 0.0	 514.0	 3035	 3035	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 8544	 0.005409	 0.02475	 0.0	 514.0	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 4854	 0.00482	 0.02805	 0.0	 572.0	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 3261	 0.028479	 0.302273	 0.0	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 6336	 0.11506	 0.606198	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 6321	 0.025271	 0.321983	 0.0	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 8915	 0.00194	 0.010091	 0.0	 3074	 3074	 3074	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 3261	 0.00314	 0.019719	 0.0	 1582	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	4121	 7028	 0.00042	 0.00384	 0.0	 1909.0	 8178	 8178	 0.0	 0.0	 1	 -30.0	 30.0;
	4121	 798	 0.00031	 0.00229	 0.0	 1744.0	 13669	 13669	 0.0	 0.0	 1	 -30.0	 30.0;
	4121	 1116	 0.00024	 0.00235	 0.0	 1645.0	 13372	 13372	 0.0	 0.0	 1	 -30.0	 30.0;
	4121	 2429	 0.00103	 0.01072	 0.0	 1678.0	 2934	 2934	 0.0	 0.0	 1	 -30.0	 30.0;
	2443	 8516	 0.00275	 0.01311	 0.0	 495.0	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	2443	 8552	 0.001771	 0.01225	 0.0	 476.0	 2553	 2553	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 5896	 0.001	 0.385207	 0.0	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 5896	 0.003349	 0.022711	 0.0	 438.0	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 5149	 0.00032	 0.001531	 0.0	 20196	 20196	 20196	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 6120	 0.359525	 1.472438	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 5152	 1.632355	 4.693388	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 8134	 0.08494	 0.651364	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 8123	 0.052581	 0.671529	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	8451	 309	 0.12794	 1.157789	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 309	 0.002461	 0.014531	 0.0	 629.0	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	7652	 6808	 0.002659	 0.013271	 0.0	 591.0	 2334	 2334	 0.0	 0.0	 1	 -30.0	 30.0;
	7652	 6808	 0.002711	 0.01299	 0.0	 2381	 2381	 2381	 0.0	 0.0	 1	 -30.0	 30.0;
	4675	 5152	 3.9e-05	 0.0002	 0.0	 155017	 155017	 155017	 0.0	 0.0	 1	 -30.0	 30.0;
	3202	 5152	 5e-05	 0.00031	 0.0	 100595	 100595	 100595	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 6864	 0.00089	 0.00698	 0.0	 4490	 4490	 4490	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 5528	 0.00028	 0.00271	 0.0	 11595	 11595	 11595	 0.0	 0.0	 1	 -30.0	 30.0;
	1706	 3149	 0.00025	 0.00273	 0.0	 1349.0	 11523	 11523	 0.0	 0.0	 1	 -30.0	 30.0;
	1706	 1214	 0.00027	 0.00238	 0.0	 1613.0	 13188	 13188	 0.0	 0.0	 1	 -30.0	 30.0;
	1706	 5528	 0.00027	 0.00277	 0.0	 1942.0	 11350	 11350	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 1214	 0.00808	 0.60428	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 3149	 0.01086	 0.386371	 0.0	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 5528	 0.03494	 0.767659	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 4786	 0.0265	 0.810665	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 3149	 0.524993	 2.841898	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 3149	 0.475568	 2.62313	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	8639	 167	 0.02113	 0.408595	 0.0	 78	 78	 78	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 167	 0.022469	 0.384442	 0.0	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	9160	 6413	 0.00045	 0.0038	 0.0	 8255	 8255	 8255	 0.0	 0.0	 1	 -30.0	 30.0;
	9160	 6413	 0.00047	 0.00374	 0.0	 1843.0	 8380	 8380	 0.0	 0.0	 1	 -30.0	 30.0;
	8638	 7714	 0.00019	 0.00086	 0.0	 400.0	 35865	 35865	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 8638	 0.542397	 1.40281	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	3479	 8638	 1.299236	 2.713017	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	8638	 5232	 1.066591	 3.481612	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	8638	 8699	 0.276529	 1.159153	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 8638	 1.192211	 3.154339	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 8638	 1.210785	 2.840289	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	7620	 8638	 0.804979	 2.837397	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	886	 9190	 9.1e-05	 0.00055	 0.0	 56662	 56662	 56662	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 886	 0.009909	 0.377748	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	886	 2610	 0.914793	 3.247727	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	3038	 9190	 0.000349	 0.002159	 0.0	 629.0	 14444	 14444	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 7714	 0.00132	 0.00624	 0.0	 533.0	 4953	 4953	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 9190	 0.00088	 0.005159	 0.0	 514.0	 6036	 6036	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 2610	 0.001349	 0.01051	 0.0	 476.0	 2982	 2982	 0.0	 0.0	 1	 -30.0	 30.0;
	532	 2029	 0.000539	 0.003099	 0.0	 610.0	 10042	 10042	 0.0	 0.0	 1	 -30.0	 30.0;
	532	 8033	 0.00207	 0.01182	 0.0	 572.0	 2633	 2633	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 8516	 0.000539	 0.003159	 0.0	 9857	 9857	 9857	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 8552	 0.004081	 0.0247	 0.0	 1262	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	7609	 4151	 0.000531	 0.003521	 0.0	 495.0	 8871	 8871	 0.0	 0.0	 1	 -30.0	 30.0;
	7944	 1992	 0.000539	 0.00345	 0.0	 9047	 9047	 9047	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 7944	 0.005169	 0.02325	 0.0	 1327	 1327	 1327	 0.0	 0.0	 1	 -30.0	 30.0;
	7652	 4854	 0.000669	 0.004099	 0.0	 572.0	 7606	 7606	 0.0	 0.0	 1	 -30.0	 30.0;
	7652	 6438	 0.000599	 0.00344	 0.0	 9047	 9047	 9047	 0.0	 0.0	 1	 -30.0	 30.0;
	388	 7652	 0.00139	 0.008919	 0.0	 3500	 3500	 3500	 0.0	 0.0	 1	 -30.0	 30.0;
	7652	 8544	 0.00069	 0.00419	 0.0	 572.0	 7439	 7439	 0.0	 0.0	 1	 -30.0	 30.0;
	1855	 7652	 0.001539	 0.008099	 0.0	 3832	 3832	 3832	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 2705	 0.00062	 0.00356	 0.0	 495.0	 8742	 8742	 0.0	 0.0	 1	 -30.0	 30.0;
	2705	 8699	 0.001091	 0.006479	 0.0	 438.0	 4808	 4808	 0.0	 0.0	 1	 -30.0	 30.0;
	8960	 7318	 6e-05	 0.00052	 0.0	 1942.0	 60345	 60345	 0.0	 0.0	 1	 -30.0	 30.0;
	8960	 7942	 0.00023	 0.00485	 0.0	 1876.0	 6506	 6506	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 7318	 7e-05	 0.00051	 0.0	 1909.0	 61361	 61361	 0.0	 0.0	 1	 -30.0	 30.0;
	7488	 5896	 5e-05	 0.000229	 0.0	 134762	 134762	 134762	 0.0	 0.0	 1	 -30.0	 30.0;
	1318	 5896	 8.1e-05	 0.0003	 0.0	 101652	 101652	 101652	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 5896	 6e-05	 0.000341	 0.0	 91231	 91231	 91231	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 5896	 0.339112	 2.39938	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 5896	 0.982252	 4.492975	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5896	 8134	 0.299979	 2.042583	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	5896	 8123	 0.216508	 1.7125	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 5896	 0.002841	 0.01551	 0.0	 2004	 2004	 2004	 0.0	 0.0	 1	 -30.0	 30.0;
	8451	 5896	 0.00326	 1.128223	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 5896	 0.00232	 0.016961	 0.0	 1846	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 5896	 0.003979	 0.02513	 0.0	 495.0	 1242	 1242	 0.0	 0.0	 1	 -30.0	 30.0;
	7360	 5896	 0.002281	 0.017289	 0.0	 591.0	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 1214	 0.111143	 0.652313	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	18	 1214	 0.00045	 0.00399	 0.0	 1711.0	 7867	 7867	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 1214	 0.01009	 0.588213	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	4786	 1214	 0.0029	 0.60196	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 1214	 0.468573	 2.303532	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 1214	 0.401032	 2.262812	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 1214	 0.00054	 0.00451	 0.0	 1777.0	 6955	 6955	 0.0	 0.0	 1	 -30.0	 30.0;
	18	 1214	 0.0004	 0.00439	 0.0	 1645.0	 7166	 7166	 0.0	 0.0	 1	 -30.0	 30.0;
	2364	 2610	 0.00132	 0.0077	 0.0	 4044	 4044	 4044	 0.0	 0.0	 1	 -30.0	 30.0;
	2364	 8699	 0.002289	 0.013909	 0.0	 457.0	 2241	 2241	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 3160	 0.00015	 0.00153	 0.0	 1448.0	 20547	 20547	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 6164	 0.00022	 0.00174	 0.0	 1777.0	 18011	 18011	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 9221	 0.00031	 0.00276	 0.0	 1514.0	 11374	 11374	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 2610	 0.498802	 2.231818	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 8699	 0.00243	 0.01461	 0.0	 533.0	 2133	 2133	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 8033	 0.0013	 0.005919	 0.0	 553.0	 5213	 5213	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 6120	 2.422314	 7.164876	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 6120	 0.005271	 0.03874	 0.0	 572.0	 808	 808	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 8134	 0.157781	 1.324793	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 8134	 0.00695	 0.055591	 0.0	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 8123	 0.211777	 1.52969	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	8451	 6120	 0.1823	 1.686529	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 8427	 2.525346	 8.326177	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 8427	 0.00086	 0.00871	 0.0	 3610	 3610	 3610	 0.0	 0.0	 1	 -30.0	 30.0;
	8427	 1823	 0.13018	 1.288158	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	8427	 3583	 5.25734	 15.96122	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8427	 6864	 0.196787	 1.606648	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	8687	 1823	 0.00124	 0.01282	 0.0	 1645.0	 2453	 2453	 0.0	 0.0	 1	 -30.0	 30.0;
	17	 2112	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	17	 2112	 0.227149	 1.244607	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	17	 2029	 0.024581	 0.402459	 0.0	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 17	 0.04388	 0.657934	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	6981	 17	 0.12525	 0.756384	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	3176	 17	 0.18987	 0.937128	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	17	 8775	 0.00163	 0.007031	 0.0	 4377	 4377	 4377	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 2029	 0.456736	 1.546157	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 2112	 0.03062	 0.528388	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	6981	 2112	 0.192099	 0.773678	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	3176	 2112	 0.027081	 0.45345	 0.0	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	3176	 2112	 0.002211	 0.01299	 0.0	 2398	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	2102	 6155	 0.00344	 0.015909	 0.0	 1941	 1941	 1941	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 5528	 0.123539	 0.685277	 0.0	 46	 46	 46	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 4786	 0.096593	 0.575748	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 6027	 0.225512	 1.104709	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 4294	 0.17135	 1.111427	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 5528	 0.00117	 0.00907	 0.0	 1810.0	 3454	 3454	 0.0	 0.0	 1	 -30.0	 30.0;
	3714	 1765	 3e-05	 0.00039	 0.0	 1777.0	 80755	 80755	 0.0	 0.0	 1	 -30.0	 30.0;
	624	 3714	 0.00079	 0.0065	 0.0	 1744.0	 4825	 4825	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 3714	 0.00091	 0.00755	 0.0	 4154	 4154	 4154	 0.0	 0.0	 1	 -30.0	 30.0;
	624	 3714	 0.00081	 0.00636	 0.0	 1843.0	 4927	 4927	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 3714	 0.00086	 0.00818	 0.0	 1843.0	 3841	 3841	 0.0	 0.0	 1	 -30.0	 30.0;
	2439	 5152	 0.003979	 0.02364	 0.0	 591.0	 1318	 1318	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 8134	 6.941322	 16.0093	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 8123	 6.73657	 15.66095	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8451	 5152	 0.185229	 2.220661	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 1823	 5.786496	 13.8054	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 3583	 0.04375	 0.648878	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 606	 0.0008	 0.00847	 0.0	 1711.0	 3713	 3713	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 6864	 0.19205	 1.80741	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 6864	 0.00157	 0.01084	 0.0	 2884	 2884	 2884	 0.0	 0.0	 1	 -30.0	 30.0;
	4501	 2176	 0.00155	 0.01203	 0.0	 2605	 2605	 2605	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 4117	 0.00062	 0.00656	 0.0	 1777.0	 4794	 4794	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 1823	 0.00203	 0.0219	 0.0	 1437	 1437	 1437	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 7849	 0.00017	 0.00135	 0.0	 1876.0	 23215	 23215	 0.0	 0.0	 1	 -30.0	 30.0;
	4875	 8479	 0.000341	 0.001729	 0.0	 419.0	 17924	 17924	 0.0	 0.0	 1	 -30.0	 30.0;
	3479	 4875	 0.00101	 0.00926	 0.0	 553.0	 3392	 3392	 0.0	 0.0	 1	 -30.0	 30.0;
	2413	 4875	 0.00055	 0.00262	 0.0	 11800	 11800	 11800	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 8479	 0.018781	 0.265517	 0.0	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 1993	 0.0298	 0.392211	 0.0	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 2390	 0.00057	 0.002841	 0.0	 533.0	 10902	 10902	 0.0	 0.0	 1	 -30.0	 30.0;
	2413	 1993	 0.00943	 0.27814	 0.0	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 8479	 0.027961	 0.338967	 0.0	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	8479	 3542	 0.000581	 0.002781	 0.0	 11119	 11119	 11119	 0.0	 0.0	 1	 -30.0	 30.0;
	2413	 8479	 0.010831	 0.239876	 0.0	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 5644	 0.00261	 0.01243	 0.0	 381.0	 2487	 2487	 0.0	 0.0	 1	 -30.0	 30.0;
	2665	 4146	 0.00214	 0.01187	 0.0	 533.0	 2619	 2619	 0.0	 0.0	 1	 -30.0	 30.0;
	540	 4146	 0.04931	 0.648058	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	540	 4146	 0.001711	 0.010781	 0.0	 572.0	 2894	 2894	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 4425	 0.00068	 0.003271	 0.0	 9455	 9455	 9455	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 4146	 0.07599	 0.788884	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	3854	 4146	 0.05989	 0.967314	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	7245	 4146	 0.00036	 0.002719	 0.0	 11517	 11517	 11517	 0.0	 0.0	 1	 -30.0	 30.0;
	829	 1116	 0.00022	 0.00201	 0.0	 1711.0	 15622	 15622	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 829	 0.04617	 0.493712	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	829	 7399	 0.00031	 0.00302	 0.0	 1810.0	 10405	 10405	 0.0	 0.0	 1	 -30.0	 30.0;
	6906	 5754	 0.001	 0.254681	 0.0	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	6906	 2429	 0.00034	 0.00288	 0.0	 1777.0	 10893	 10893	 0.0	 0.0	 1	 -30.0	 30.0;
	5061	 9143	 8e-05	 0.00085	 0.0	 1283.0	 36999	 36999	 0.0	 0.0	 1	 -30.0	 30.0;
	5061	 9143	 8e-05	 0.00087	 0.0	 1316.0	 36155	 36155	 0.0	 0.0	 1	 -30.0	 30.0;
	5061	 9143	 7e-05	 0.00089	 0.0	 1316.0	 35383	 35383	 0.0	 0.0	 1	 -30.0	 30.0;
	3617	 6155	 0.808079	 2.998967	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	296	 6155	 0.11606	 0.766157	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 6155	 0.044669	 0.42969	 0.0	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 6155	 0.0045	 0.023841	 0.0	 438.0	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	4047	 417	 0.009969	 0.07739	 0.0	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 4047	 0.01431	 0.10638	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4047	 5104	 0.00774	 0.06957	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	129	 417	 0.016669	 0.26188	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	8798	 417	 0.009969	 0.061409	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	129	 417	 0.001729	 0.00995	 0.0	 400.0	 3128	 3128	 0.0	 0.0	 1	 -30.0	 30.0;
	7731	 6066	 0.0015	 0.01398	 0.0	 1251.0	 2247	 2247	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 7731	 0.00243	 0.01942	 0.0	 1415.0	 1614	 1614	 0.0	 0.0	 1	 -30.0	 30.0;
	8503	 822	 0.00455	 0.02705	 0.0	 495.0	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 8503	 0.004331	 0.01676	 0.0	 591.0	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	8503	 1949	 0.24907	 0.891963	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	8503	 822	 0.033831	 0.228099	 0.0	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	296	 3617	 0.344318	 0.959132	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	3617	 4268	 0.087211	 0.561364	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	3617	 1497	 0.003909	 0.019531	 0.0	 1586	 1586	 1586	 0.0	 0.0	 1	 -30.0	 30.0;
	6589	 798	 0.01509	 0.413102	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	6589	 1955	 9e-05	 0.001	 0.0	 31461	 31461	 31461	 0.0	 0.0	 1	 -30.0	 30.0;
	6589	 6524	 0.00094	 0.00943	 0.0	 1711.0	 3334	 3334	 0.0	 0.0	 1	 -30.0	 30.0;
	6589	 4500	 0.03361	 0.58162	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 2260	 0.0001	 0.00107	 0.0	 1580.0	 29393	 29393	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 873	 0.00084	 0.00882	 0.0	 1580.0	 3566	 3566	 0.0	 0.0	 1	 -30.0	 30.0;
	2439	 296	 0.00501	 0.021599	 0.0	 572.0	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	296	 4268	 0.04149	 0.219607	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	296	 1773	 0.000781	 0.00744	 0.0	 629.0	 4223	 4223	 0.0	 0.0	 1	 -30.0	 30.0;
	5958	 8059	 0.011789	 0.277645	 0.0	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	5958	 8059	 0.0052	 0.02574	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	8059	 6603	 0.031669	 0.507603	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	8059	 6603	 0.00438	 0.025461	 0.0	 1223	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 8059	 0.27186	 0.993388	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	79	 798	 0.0037	 0.327618	 0.0	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	798	 4500	 0.01026	 0.269931	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 592	 0.000281	 0.0023	 0.0	 13633	 13633	 13633	 0.0	 0.0	 1	 -30.0	 30.0;
	7609	 7332	 0.000539	 0.005021	 0.0	 6256	 6256	 6256	 0.0	 0.0	 1	 -30.0	 30.0;
	7609	 4793	 0.251054	 1.054483	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 7609	 0.00539	 0.022409	 0.0	 381.0	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 853	 0.18813	 0.545888	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 1432	 0.02382	 0.200979	 0.0	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 1432	 0.00375	 0.019289	 0.0	 476.0	 1608	 1608	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 2614	 0.003151	 0.01874	 0.0	 1663	 1663	 1663	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 822	 0.02419	 0.20719	 0.0	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	4754	 5958	 0.005479	 0.022531	 0.0	 553.0	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	4754	 6172	 0.008581	 0.133581	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5806	 3854	 0.000849	 0.00436	 0.0	 7112	 7112	 7112	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 5169	 0.0004	 0.00418	 0.0	 1843.0	 7523	 7523	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 330	 0.00023	 0.00253	 0.0	 1909.0	 12434	 12434	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 2712	 0.000659	 0.006909	 0.0	 4552	 4552	 4552	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 2409	 0.14356	 0.922161	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 4578	 0.05061	 0.949861	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	2472	 8479	 0.001669	 0.19101	 0.0	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 2472	 0.008901	 0.19594	 0.0	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 8479	 0.008849	 0.207376	 0.0	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	584	 2260	 0.04068	 0.314813	 0.0	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	584	 873	 0.001	 0.358151	 0.0	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	584	 873	 0.00029	 0.00339	 0.0	 1481.0	 9284	 9284	 0.0	 0.0	 1	 -30.0	 30.0;
	584	 6343	 0.001	 0.381247	 0.0	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 1323	 0.0	 0.0002	 0.0	 757.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 1323	 0.001	 0.261032	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 2387	 5e-05	 0.000409	 0.0	 76660	 76660	 76660	 0.0	 0.0	 1	 -30.0	 30.0;
	7245	 3905	 0.00036	 0.00411	 0.0	 553.0	 7657	 7657	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 1707	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 1707	 0.06963	 0.647459	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	540	 4522	 0.00138	 0.00794	 0.0	 553.0	 3920	 3920	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 4522	 0.04905	 0.618285	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	7360	 4522	 0.01481	 0.65845	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 4522	 0.057229	 0.834525	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 1707	 0.00276	 0.034271	 0.0	 919	 919	 919	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 1707	 0.045901	 0.629938	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	7360	 1707	 0.05236	 0.804298	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 1707	 0.010979	 0.705971	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 2260	 0.00111	 0.00985	 0.0	 1942.0	 3187	 3187	 0.0	 0.0	 1	 -30.0	 30.0;
	3583	 1823	 12.66967	 25.61427	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1823	 6864	 0.7509	 2.64626	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	8134	 8123	 0.001	 0.522603	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	8134	 8123	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8451	 8134	 1.015517	 3.518182	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	3854	 8134	 0.00274	 0.01674	 0.0	 610.0	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	8982	 8134	 0.001031	 0.006669	 0.0	 4681	 4681	 4681	 0.0	 0.0	 1	 -30.0	 30.0;
	8451	 8123	 0.827397	 3.941942	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	3636	 1823	 0.00018	 0.00147	 0.0	 21329	 21329	 21329	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 1823	 0.00025	 0.00253	 0.0	 757.0	 12425	 12425	 0.0	 0.0	 1	 -30.0	 30.0;
	3789	 1823	 0.00045	 0.00372	 0.0	 1613.0	 8430	 8430	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 1823	 0.00019	 0.00142	 0.0	 1744.0	 22049	 22049	 0.0	 0.0	 1	 -30.0	 30.0;
	6097	 1823	 0.00017	 0.00161	 0.0	 757.0	 19511	 19511	 0.0	 0.0	 1	 -30.0	 30.0;
	4622	 1773	 0.00031	 0.00387	 0.0	 8137	 8137	 8137	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 7401	 0.00057	 0.00261	 0.0	 11824	 11824	 11824	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 1901	 0.000591	 0.002591	 0.0	 11886	 11886	 11886	 0.0	 0.0	 1	 -30.0	 30.0;
	2665	 683	 0.001599	 0.00775	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	540	 683	 0.014031	 0.614215	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	540	 3854	 0.012341	 0.556384	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	540	 3854	 0.001599	 0.00738	 0.0	 4184	 4184	 4184	 0.0	 0.0	 1	 -30.0	 30.0;
	9080	 1765	 0.077687	 1.036288	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	9080	 624	 0.00057	 0.00542	 0.0	 5796	 5796	 5796	 0.0	 0.0	 1	 -30.0	 30.0;
	9080	 624	 0.001	 0.513781	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	9080	 1485	 0.01036	 0.396828	 0.0	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	9080	 1485	 0.00067	 0.00594	 0.0	 5285	 5285	 5285	 0.0	 0.0	 1	 -30.0	 30.0;
	9080	 4718	 0.897853	 2.161981	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 4276	 0.0015	 0.01442	 0.0	 1514.0	 2179	 2179	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 4276	 0.00139	 0.01387	 0.0	 1843.0	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	624	 1765	 0.001	 0.795637	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 1765	 0.230298	 1.27597	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 1765	 0.05565	 0.673331	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	9154	 18	 0.00019	 0.00214	 0.0	 1744.0	 14703	 14703	 0.0	 0.0	 1	 -30.0	 30.0;
	9154	 18	 0.00019	 0.00198	 0.0	 1744.0	 15881	 15881	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 4786	 0.07358	 0.966343	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 5528	 0.06384	 1.43054	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 5528	 0.076281	 1.166136	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 4786	 0.210457	 1.788158	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 4786	 0.185533	 1.718213	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 4786	 2e-05	 0.00024	 0.0	 1547.0	 131160	 131160	 0.0	 0.0	 1	 -30.0	 30.0;
	330	 5116	 0.01408	 0.37133	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	7781	 5116	 0.01647	 0.363712	 0.0	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	7781	 5116	 0.00068	 0.00621	 0.0	 1810.0	 5057	 5057	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 873	 0.00079	 0.00807	 0.0	 1810.0	 3896	 3896	 0.0	 0.0	 1	 -30.0	 30.0;
	2429	 5754	 0.00052	 0.00514	 0.0	 1843.0	 6115	 6115	 0.0	 0.0	 1	 -30.0	 30.0;
	873	 2260	 0.111198	 0.57367	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	6343	 2260	 0.126101	 0.495623	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 1497	 0.0032	 0.016281	 0.0	 476.0	 1904	 1904	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 1497	 0.003659	 0.01407	 0.0	 514.0	 2173	 2173	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 1773	 0.002281	 0.010039	 0.0	 3069	 3069	 3069	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 1773	 0.001919	 0.011669	 0.0	 2672	 2672	 2672	 0.0	 0.0	 1	 -30.0	 30.0;
	7332	 4793	 0.00236	 0.02263	 0.0	 1389	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 7332	 0.009849	 0.054531	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	1432	 853	 0.02949	 0.13405	 0.0	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	1432	 853	 0.005021	 0.030341	 0.0	 1028	 1028	 1028	 0.0	 0.0	 1	 -30.0	 30.0;
	3583	 7849	 0.00076	 0.00675	 0.0	 4651	 4651	 4651	 0.0	 0.0	 1	 -30.0	 30.0;
	3583	 6864	 0.568047	 3.572576	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	635	 4425	 0.003419	 0.014531	 0.0	 2117	 2117	 2117	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 635	 0.002979	 0.016461	 0.0	 1889	 1889	 1889	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 3261	 0.09382	 0.44438	 0.0	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	7655	 3261	 0.003789	 0.02306	 0.0	 381.0	 1352	 1352	 0.0	 0.0	 1	 -30.0	 30.0;
	2726	 3789	 0.00014	 0.00108	 0.0	 1810.0	 29005	 29005	 0.0	 0.0	 1	 -30.0	 30.0;
	2726	 9154	 0.00015	 0.00119	 0.0	 1810.0	 26336	 26336	 0.0	 0.0	 1	 -30.0	 30.0;
	1955	 9154	 0.00031	 0.00232	 0.0	 13496	 13496	 13496	 0.0	 0.0	 1	 -30.0	 30.0;
	1792	 1955	 0.00025	 0.00193	 0.0	 1415.0	 16231	 16231	 0.0	 0.0	 1	 -30.0	 30.0;
	9154	 7942	 0.137791	 1.05367	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	9154	 7399	 0.00054	 0.00395	 0.0	 1876.0	 7924	 7924	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 2712	 0.00113	 0.012581	 0.0	 2501	 2501	 2501	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 3155	 0.00238	 0.02086	 0.0	 1505	 1505	 1505	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 6981	 0.127331	 1.369545	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 2223	 0.699669	 2.452893	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	9023	 6603	 0.00331	 0.025159	 0.0	 533.0	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	624	 1485	 0.01975	 0.825554	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 624	 0.507639	 2.270152	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	5958	 6603	 0.20336	 0.874897	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	5958	 6172	 0.00732	 0.030659	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 5958	 0.075401	 0.292748	 0.0	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 5958	 0.00314	 0.02136	 0.0	 1464	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	9160	 6977	 0.00044	 0.00325	 0.0	 1876.0	 9632	 9632	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 2413	 0.00076	 0.00364	 0.0	 8495	 8495	 8495	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 5965	 0.00075	 0.00474	 0.0	 6583	 6583	 6583	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 3479	 3.557851	 5.439876	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 5232	 4.011157	 6.327273	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 8699	 0.006	 0.327025	 0.0	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 6336	 3.78905	 6.419628	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 6336	 3.833471	 5.760331	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 6336	 0.000841	 0.00362	 0.0	 8500	 8500	 8500	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 2003	 0.03	 0.279855	 0.0	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 2003	 0.00107	 0.004849	 0.0	 6362	 6362	 6362	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 7620	 3.092975	 5.176033	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 7620	 0.02688	 0.291116	 0.0	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 7620	 0.00188	 0.0132	 0.0	 553.0	 2370	 2370	 0.0	 0.0	 1	 -30.0	 30.0;
	6541	 1432	 0.001469	 0.00724	 0.0	 4276	 4276	 4276	 0.0	 0.0	 1	 -30.0	 30.0;
	6541	 1432	 0.0015	 0.007081	 0.0	 4365	 4365	 4365	 0.0	 0.0	 1	 -30.0	 30.0;
	8033	 5429	 0.0017	 0.00806	 0.0	 591.0	 3835	 3835	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 2606	 0.00369	 0.016091	 0.0	 533.0	 1914	 1914	 0.0	 0.0	 1	 -30.0	 30.0;
	8516	 7085	 0.00301	 0.0177	 0.0	 591.0	 1760	 1760	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 4758	 5e-05	 0.00053	 0.0	 1415.0	 59336	 59336	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 3922	 6e-05	 0.0005	 0.0	 1481.0	 62725	 62725	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 5749	 4e-05	 0.00047	 0.0	 66966	 66966	 66966	 0.0	 0.0	 1	 -30.0	 30.0;
	8699	 166	 0.00174	 0.016521	 0.0	 400.0	 1902	 1902	 0.0	 0.0	 1	 -30.0	 30.0;
	1576	 5556	 0.00019	 0.00196	 0.0	 1810.0	 16041	 16041	 0.0	 0.0	 1	 -30.0	 30.0;
	2429	 6419	 0.00074	 0.00584	 0.0	 5366	 5366	 5366	 0.0	 0.0	 1	 -30.0	 30.0;
	1576	 1720	 0.00019	 0.00183	 0.0	 17169	 17169	 17169	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 2595	 0.00018	 0.00186	 0.0	 16904	 16904	 16904	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 4294	 0.0	 0.0002	 0.0	 757.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 4294	 0.001	 0.413968	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 5528	 0.00215	 0.02177	 0.0	 1444	 1444	 1444	 0.0	 0.0	 1	 -30.0	 30.0;
	6997	 822	 0.008659	 0.0422	 0.0	 381.0	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	79	 6983	 0.00029	 0.00252	 0.0	 1415.0	 12453	 12453	 0.0	 0.0	 1	 -30.0	 30.0;
	79	 4500	 0.0343	 0.612763	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	2610	 8552	 0.00036	 0.00195	 0.0	 15930	 15930	 15930	 0.0	 0.0	 1	 -30.0	 30.0;
	2610	 8552	 0.000409	 0.00213	 0.0	 14564	 14564	 14564	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 2787	 0.00118	 0.008719	 0.0	 476.0	 3591	 3591	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 4941	 0.0053	 0.023409	 0.0	 1317	 1317	 1317	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 4941	 0.005401	 0.022909	 0.0	 610.0	 1343	 1343	 0.0	 0.0	 1	 -30.0	 30.0;
	5965	 4941	 0.000901	 0.00412	 0.0	 610.0	 7490	 7490	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 2413	 0.05139	 0.435785	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	3479	 5232	 0.01661	 0.339194	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	3479	 8699	 2.441736	 4.517975	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 3479	 0.03336	 0.374174	 0.0	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 3479	 0.033219	 0.37814	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	3479	 4496	 0.003151	 0.017599	 0.0	 1767	 1767	 1767	 0.0	 0.0	 1	 -30.0	 30.0;
	7620	 3479	 0.02231	 0.393079	 0.0	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	8759	 3636	 0.0005	 0.00519	 0.0	 6059	 6059	 6059	 0.0	 0.0	 1	 -30.0	 30.0;
	8759	 8585	 0.00024	 0.00227	 0.0	 1777.0	 13839	 13839	 0.0	 0.0	 1	 -30.0	 30.0;
	8759	 6983	 0.00049	 0.00529	 0.0	 1448.0	 5946	 5946	 0.0	 0.0	 1	 -30.0	 30.0;
	8759	 5403	 0.00036	 0.00305	 0.0	 1448.0	 10286	 10286	 0.0	 0.0	 1	 -30.0	 30.0;
	3859	 5673	 0.00264	 0.014781	 0.0	 2104	 2104	 2104	 0.0	 0.0	 1	 -30.0	 30.0;
	6902	 5673	 0.002539	 0.01357	 0.0	 2289	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 5673	 0.0053	 0.021599	 0.0	 553.0	 1421	 1421	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 5673	 0.003091	 0.01568	 0.0	 1977	 1977	 1977	 0.0	 0.0	 1	 -30.0	 30.0;
	9208	 5673	 0.00274	 0.0127	 0.0	 2432	 2432	 2432	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 5673	 0.04224	 0.3325	 0.0	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	5914	 5491	 0.00086	 0.00873	 0.0	 1777.0	 3601	 3601	 0.0	 0.0	 1	 -30.0	 30.0;
	9160	 5491	 0.00206	 0.01561	 0.0	 1678.0	 2007	 2007	 0.0	 0.0	 1	 -30.0	 30.0;
	3668	 9143	 0.00032	 0.00271	 0.0	 1514.0	 11576	 11576	 0.0	 0.0	 1	 -30.0	 30.0;
	7781	 3668	 0.00051	 0.00524	 0.0	 1744.0	 6000	 6000	 0.0	 0.0	 1	 -30.0	 30.0;
	250	 7725	 0.00032	 0.00265	 0.0	 1810.0	 11834	 11834	 0.0	 0.0	 1	 -30.0	 30.0;
	330	 250	 0.0005	 0.00534	 0.0	 1645.0	 5890	 5890	 0.0	 0.0	 1	 -30.0	 30.0;
	7725	 9143	 0.0	 0.0002	 0.0	 1580.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7725	 9143	 0.163629	 1.021814	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 7725	 0.001	 0.350312	 0.0	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	7715	 7725	 0.0571	 0.699515	 0.0	 46	 46	 46	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 7725	 0.00022	 0.00214	 0.0	 1415.0	 14684	 14684	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 7725	 0.05584	 0.597071	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	4578	 9143	 0.00044	 0.00329	 0.0	 1942.0	 9517	 9517	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 9143	 0.0684	 0.765166	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 9143	 0.0005	 0.00377	 0.0	 1744.0	 8306	 8306	 0.0	 0.0	 1	 -30.0	 30.0;
	7715	 9143	 0.02916	 0.635783	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 9143	 0.00021	 0.00218	 0.0	 1744.0	 14423	 14423	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 9143	 0.076648	 0.893421	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	6830	 7859	 0.003581	 0.01713	 0.0	 1805	 1805	 1805	 0.0	 0.0	 1	 -30.0	 30.0;
	388	 122	 0.003651	 0.01676	 0.0	 1842	 1842	 1842	 0.0	 0.0	 1	 -30.0	 30.0;
	6524	 5969	 0.0	 0.0002	 0.0	 889.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6524	 5969	 0.001	 0.363179	 0.0	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	6524	 2429	 0.03201	 0.610942	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	5969	 2429	 0.03493	 0.703809	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	5969	 3160	 0.00038	 0.00378	 0.0	 1711.0	 8315	 8315	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 6603	 0.662562	 1.966736	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 6603	 0.007461	 0.03539	 0.0	 553.0	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 1485	 1.057548	 2.384834	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 7859	 0.00313	 0.015591	 0.0	 1987	 1987	 1987	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 122	 0.00325	 0.01495	 0.0	 2065	 2065	 2065	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 2029	 0.174211	 0.885269	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	6981	 2029	 0.05432	 0.507293	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	3176	 2029	 0.315744	 1.143306	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	7655	 8516	 0.106531	 0.728988	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 2429	 0.00046	 0.00355	 0.0	 1909.0	 8825	 8825	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 2429	 0.00046	 0.00356	 0.0	 1481.0	 8800	 8800	 0.0	 0.0	 1	 -30.0	 30.0;
	2787	 5232	 0.00056	 0.00351	 0.0	 457.0	 8887	 8887	 0.0	 0.0	 1	 -30.0	 30.0;
	7620	 2787	 0.001271	 0.00699	 0.0	 476.0	 4447	 4447	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 8699	 2.229752	 5.528926	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 5232	 0.186169	 1.134959	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 5232	 0.191419	 0.99374	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	7620	 5232	 0.001	 0.342025	 0.0	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	9221	 6083	 8e-05	 0.00071	 0.0	 1843.0	 44210	 44210	 0.0	 0.0	 1	 -30.0	 30.0;
	1576	 6083	 0.00047	 0.00487	 0.0	 1283.0	 6457	 6457	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 8699	 2.630992	 4.595455	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 8699	 2.602893	 4.194835	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 8699	 0.002849	 0.0122	 0.0	 400.0	 2522	 2522	 0.0	 0.0	 1	 -30.0	 30.0;
	7620	 8699	 1.630455	 4.689463	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	3160	 6083	 0.136641	 1.051662	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	673	 6083	 0.00035	 0.00282	 0.0	 1514.0	 11116	 11116	 0.0	 0.0	 1	 -30.0	 30.0;
	5914	 9160	 0.00092	 0.0092	 0.0	 1810.0	 3417	 3417	 0.0	 0.0	 1	 -30.0	 30.0;
	2409	 4578	 0.0	 0.0002	 0.0	 1020.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2409	 4578	 0.02074	 0.459238	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	2409	 1576	 0.00025	 0.00224	 0.0	 1876.0	 14015	 14015	 0.0	 0.0	 1	 -30.0	 30.0;
	7655	 8552	 0.000651	 0.0037	 0.0	 8408	 8408	 8408	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 5261	 0.001	 0.238182	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 7620	 0.168469	 0.943719	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 7620	 0.1577	 0.919711	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	6452	 4793	 0.0033	 0.023531	 0.0	 1330	 1330	 1330	 0.0	 0.0	 1	 -30.0	 30.0;
	9225	 4793	 0.00336	 0.023031	 0.0	 553.0	 1358	 1358	 0.0	 0.0	 1	 -30.0	 30.0;
	8798	 4793	 0.050961	 0.353843	 0.0	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 4793	 0.07906	 0.386591	 0.0	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 4793	 0.00224	 0.02005	 0.0	 1566	 1566	 1566	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 4793	 0.001979	 0.018841	 0.0	 1668	 1668	 1668	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 25	 0.0003	 0.002669	 0.0	 533.0	 11761	 11761	 0.0	 0.0	 1	 -30.0	 30.0;
	1823	 1792	 0.00017	 0.00166	 0.0	 1415.0	 18930	 18930	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 4500	 0.00057	 0.00619	 0.0	 1744.0	 5082	 5082	 0.0	 0.0	 1	 -30.0	 30.0;
	6097	 8713	 8e-05	 0.00082	 0.0	 757.0	 38340	 38340	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 3854	 0.001	 0.452087	 0.0	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 7360	 0.028289	 0.776901	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 4557	 0.027469	 0.75064	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	3854	 2212	 0.001409	 0.00714	 0.0	 476.0	 4341	 4341	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 6652	 0.00776	 0.04488	 0.0	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	673	 2486	 0.00028	 0.0023	 0.0	 1448.0	 13633	 13633	 0.0	 0.0	 1	 -30.0	 30.0;
	3225	 673	 0.00015	 0.00155	 0.0	 1580.0	 20285	 20285	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 525	 0.000229	 0.00113	 0.0	 27397	 27397	 27397	 0.0	 0.0	 1	 -30.0	 30.0;
	7360	 3357	 0.00024	 0.001099	 0.0	 514.0	 28081	 28081	 0.0	 0.0	 1	 -30.0	 30.0;
	6452	 8798	 0.000651	 0.005031	 0.0	 6227	 6227	 6227	 0.0	 0.0	 1	 -30.0	 30.0;
	9225	 8798	 0.000581	 0.0057	 0.0	 553.0	 5514	 5514	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 8798	 0.395351	 1.062603	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	7781	 1576	 0.00073	 0.00574	 0.0	 1942.0	 5460	 5460	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 6164	 0.00074	 0.00562	 0.0	 5573	 5573	 5573	 0.0	 0.0	 1	 -30.0	 30.0;
	798	 4500	 0.00021	 0.00217	 0.0	 1580.0	 14489	 14489	 0.0	 0.0	 1	 -30.0	 30.0;
	8639	 5580	 0.001	 0.253636	 0.0	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	7803	 3225	 0.00078	 0.00691	 0.0	 1645.0	 4543	 4543	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 6343	 0.00135	 0.01007	 0.0	 3109	 3109	 3109	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 6981	 0.048271	 0.517335	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 6981	 0.001901	 0.01187	 0.0	 2628	 2628	 2628	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 3176	 0.02499	 0.413099	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 3176	 0.00186	 0.01099	 0.0	 533.0	 2834	 2834	 0.0	 0.0	 1	 -30.0	 30.0;
	330	 7781	 0.00351	 0.296032	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	2390	 9095	 0.000169	 0.000789	 0.0	 39147	 39147	 39147	 0.0	 0.0	 1	 -30.0	 30.0;
	2413	 2390	 0.000211	 0.001031	 0.0	 30016	 30016	 30016	 0.0	 0.0	 1	 -30.0	 30.0;
	3542	 6661	 0.00038	 0.001909	 0.0	 16229	 16229	 16229	 0.0	 0.0	 1	 -30.0	 30.0;
	2413	 3542	 0.000219	 0.001	 0.0	 30857	 30857	 30857	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 7715	 0.0114	 0.491198	 0.0	 65	 65	 65	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 5387	 0.0111	 0.44741	 0.0	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	6981	 3176	 0.065849	 0.525558	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	6981	 8775	 0.00095	 0.0053	 0.0	 514.0	 5867	 5867	 0.0	 0.0	 1	 -30.0	 30.0;
	5965	 2413	 0.00139	 0.008281	 0.0	 3762	 3762	 3762	 0.0	 0.0	 1	 -30.0	 30.0;
	6886	 7161	 0.001	 0.26688	 0.0	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 2033	 0.00036	 0.00286	 0.0	 10959	 10959	 10959	 0.0	 0.0	 1	 -30.0	 30.0;
	7620	 2003	 0.02231	 0.26281	 0.0	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	7620	 2003	 0.001669	 0.01064	 0.0	 572.0	 2933	 2933	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 7880	 3e-05	 0.00031	 0.0	 101421	 101421	 101421	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 433	 3e-05	 0.0003	 0.0	 1942.0	 104769	 104769	 0.0	 0.0	 1	 -30.0	 30.0;
	7942	 7399	 0.0004	 0.00637	 0.0	 1645.0	 4950	 4950	 0.0	 0.0	 1	 -30.0	 30.0;
	7803	 5403	 0.00018	 0.0019	 0.0	 1711.0	 16551	 16551	 0.0	 0.0	 1	 -30.0	 30.0;
	7803	 8585	 0.00032	 0.00267	 0.0	 1711.0	 11747	 11747	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 7715	 0.00023	 0.00202	 0.0	 1613.0	 15537	 15537	 0.0	 0.0	 1	 -30.0	 30.0;
	7715	 5387	 0.001	 0.382043	 0.0	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	7878	 9208	 0.00011	 0.00075	 0.0	 533.0	 41671	 41671	 0.0	 0.0	 1	 -30.0	 30.0;
	8810	 9208	 0.00013	 0.000531	 0.0	 57781	 57781	 57781	 0.0	 0.0	 1	 -30.0	 30.0;
	7360	 4557	 0.010909	 0.62314	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	1497	 1773	 0.005969	 0.037081	 0.0	 842	 842	 842	 0.0	 0.0	 1	 -30.0	 30.0;
	4501	 9088	 0.0	 0.0002	 0.0	 1514.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4501	 9088	 0.001	 0.39696	 0.0	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	4501	 8388	 0.192888	 1.242729	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	9088	 1630	 0.00078	 0.00629	 0.0	 1876.0	 4984	 4984	 0.0	 0.0	 1	 -30.0	 30.0;
	9088	 8388	 0.215693	 1.63338	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	1630	 8388	 0.00048	 0.00397	 0.0	 7899	 7899	 7899	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 8388	 0.00049	 0.00388	 0.0	 8077	 8077	 8077	 0.0	 0.0	 1	 -30.0	 30.0;
	7245	 8698	 0.000211	 0.00113	 0.0	 27479	 27479	 27479	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 5387	 3e-05	 0.00035	 0.0	 1316.0	 89920	 89920	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 2223	 0.007409	 0.042281	 0.0	 736	 736	 736	 0.0	 0.0	 1	 -30.0	 30.0;
	3724	 6541	 0.00012	 0.0007	 0.0	 44476	 44476	 44476	 0.0	 0.0	 1	 -30.0	 30.0;
	873	 6343	 0.0	 0.0002	 0.0	 856.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	873	 6343	 0.001	 0.284017	 0.0	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	8779	 8256	 1.997645	 4.178116	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	8779	 3110	 0.00015	 0.00152	 0.0	 1349.0	 20681	 20681	 0.0	 0.0	 1	 -30.0	 30.0;
	8779	 1287	 0.00014	 0.00141	 0.0	 1316.0	 22293	 22293	 0.0	 0.0	 1	 -30.0	 30.0;
	8779	 4732	 0.00103	 0.00914	 0.0	 1645.0	 3435	 3435	 0.0	 0.0	 1	 -30.0	 30.0;
	8779	 2932	 0.00105	 0.00896	 0.0	 1514.0	 3502	 3502	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 8779	 0.334702	 1.492936	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 8779	 0.00142	 0.01428	 0.0	 1711.0	 2202	 2202	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 8779	 0.340893	 1.460526	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 8779	 0.00139	 0.01455	 0.0	 2162	 2162	 2162	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 4662	 0.0004	 0.00376	 0.0	 8354	 8354	 8354	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 5316	 0.00101	 0.01129	 0.0	 1711.0	 2787	 2787	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 4571	 0.00076	 0.0089	 0.0	 3537	 3537	 3537	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 4662	 0.0004	 0.00368	 0.0	 8534	 8534	 8534	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 2681	 0.00099	 0.01151	 0.0	 1810.0	 2735	 2735	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 938	 0.00075	 0.00824	 0.0	 3818	 3818	 3818	 0.0	 0.0	 1	 -30.0	 30.0;
	7934	 4670	 0.00156	 0.01568	 0.0	 1744.0	 2005	 2005	 0.0	 0.0	 1	 -30.0	 30.0;
	7934	 4670	 0.00152	 0.01599	 0.0	 1711.0	 1967	 1967	 0.0	 0.0	 1	 -30.0	 30.0;
	484	 7006	 0.00539	 0.01612	 0.0	 591.0	 1859	 1859	 0.0	 0.0	 1	 -30.0	 30.0;
	484	 7006	 0.0048	 0.018271	 0.0	 572.0	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	8188	 866	 0.008729	 0.034159	 0.0	 419.0	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	8188	 866	 0.00855	 0.03482	 0.0	 419.0	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	4156	 1900	 0.00146	 0.00651	 0.0	 1152.0	 4735	 4735	 0.0	 0.0	 1	 -30.0	 30.0;
	511	 1900	 0.134252	 0.771745	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	511	 1900	 0.00072	 0.00587	 0.0	 1810.0	 5342	 5342	 0.0	 0.0	 1	 -30.0	 30.0;
	511	 1900	 0.00071	 0.006	 0.0	 1876.0	 5229	 5229	 0.0	 0.0	 1	 -30.0	 30.0;
	6374	 1900	 0.00013	 0.00132	 0.0	 1810.0	 23815	 23815	 0.0	 0.0	 1	 -30.0	 30.0;
	3396	 1900	 0.322853	 1.362742	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 8944	 0.161841	 1.112975	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 8944	 0.00356	 0.022409	 0.0	 591.0	 1393	 1393	 0.0	 0.0	 1	 -30.0	 30.0;
	439	 8944	 0.211508	 1.021529	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	439	 8944	 0.00838	 0.038479	 0.0	 803	 803	 803	 0.0	 0.0	 1	 -30.0	 30.0;
	484	 8944	 0.912748	 1.922025	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 8198	 0.005211	 0.016901	 0.0	 457.0	 1786	 1786	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 8198	 0.219566	 0.646591	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 8198	 0.00531	 0.016539	 0.0	 476.0	 1819	 1819	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 7261	 0.140519	 0.391918	 0.0	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 5234	 0.00131	 0.01484	 0.0	 1810.0	 2121	 2121	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 4571	 0.05123	 0.434093	 0.0	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 4571	 0.0006	 0.00673	 0.0	 1876.0	 4675	 4675	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 8370	 0.05191	 0.445222	 0.0	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 5234	 0.736704	 3.325	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 5234	 2.622299	 8.981301	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	7680	 6466	 0.0	 0.0002	 0.0	 757.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7680	 6466	 0.001	 0.291627	 0.0	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	2463	 7680	 0.00016	 0.00138	 0.0	 1415.0	 22738	 22738	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 7680	 0.00017	 0.00135	 0.0	 1448.0	 23215	 23215	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 6466	 0.00017	 0.00133	 0.0	 1251.0	 23559	 23559	 0.0	 0.0	 1	 -30.0	 30.0;
	7919	 6466	 0.00017	 0.0013	 0.0	 1316.0	 24093	 24093	 0.0	 0.0	 1	 -30.0	 30.0;
	7934	 2463	 0.00189	 0.01446	 0.0	 1316.0	 2167	 2167	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 983	 0.00074	 0.00698	 0.0	 1382.0	 4501	 4501	 0.0	 0.0	 1	 -30.0	 30.0;
	7934	 478	 0.00193	 0.01416	 0.0	 1349.0	 2211	 2211	 0.0	 0.0	 1	 -30.0	 30.0;
	7919	 4175	 0.00073	 0.00711	 0.0	 1349.0	 4420	 4420	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 8256	 0.136731	 0.910873	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 8256	 0.00128	 0.0134	 0.0	 1876.0	 2347	 2347	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 8256	 0.13394	 0.92874	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 2192	 0.271641	 0.707964	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 2192	 0.00037	 0.0037	 0.0	 1645.0	 12962	 12962	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 2192	 0.00038	 0.00363	 0.0	 1876.0	 13206	 13206	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 2192	 0.00156	 0.01473	 0.0	 1810.0	 2133	 2133	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 2192	 0.00159	 0.01442	 0.0	 1678.0	 2178	 2178	 0.0	 0.0	 1	 -30.0	 30.0;
	8300	 4218	 0.01049	 0.04336	 0.0	 438.0	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 4218	 0.010271	 0.04418	 0.0	 457.0	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 4218	 0.00881	 0.037021	 0.0	 457.0	 831	 831	 0.0	 0.0	 1	 -30.0	 30.0;
	2418	 4218	 0.004409	 0.01682	 0.0	 476.0	 1817	 1817	 0.0	 0.0	 1	 -30.0	 30.0;
	2418	 4218	 0.00432	 0.017151	 0.0	 533.0	 1786	 1786	 0.0	 0.0	 1	 -30.0	 30.0;
	7514	 4218	 0.01025	 0.042341	 0.0	 553.0	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 2736	 0.05386	 0.203789	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 2736	 0.005	 0.017849	 0.0	 1705	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 2736	 0.004909	 0.01824	 0.0	 1673	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	2736	 3189	 0.442645	 0.98938	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	2736	 3189	 0.00789	 0.025831	 0.0	 514.0	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	2736	 3189	 0.00774	 0.02638	 0.0	 476.0	 1149	 1149	 0.0	 0.0	 1	 -30.0	 30.0;
	6458	 511	 0.00141	 0.01209	 0.0	 1744.0	 2596	 2596	 0.0	 0.0	 1	 -30.0	 30.0;
	6458	 8415	 0.104079	 0.42973	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	983	 4662	 0.00139	 0.01016	 0.0	 1349.0	 3081	 3081	 0.0	 0.0	 1	 -30.0	 30.0;
	4175	 4662	 0.00142	 0.00994	 0.0	 1415.0	 3146	 3146	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 386	 9e-05	 0.00064	 0.0	 757.0	 48875	 48875	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 4732	 0.195942	 0.820914	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 2932	 0.199778	 0.804155	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 2190	 0.02836	 0.37876	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	386	 4732	 0.00109	 0.00814	 0.0	 3847	 3847	 3847	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 386	 0.00054	 0.00424	 0.0	 7391	 7391	 7391	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 511	 0.00263	 0.02613	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	511	 6914	 0.00166	 0.01885	 0.0	 1547.0	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	511	 3396	 0.847576	 2.035042	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 511	 0.00094	 0.00794	 0.0	 1645.0	 3951	 3951	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 1403	 0.014081	 0.055831	 0.0	 457.0	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 439	 2.006198	 3.572314	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 439	 0.0122	 0.05982	 0.0	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 484	 0.30564	 1.254566	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 484	 0.0235	 0.076229	 0.0	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 3189	 0.029969	 0.12889	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 3189	 0.02932	 0.119341	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	6621	 4499	 0.00699	 0.02886	 0.0	 629.0	 1064	 1064	 0.0	 0.0	 1	 -30.0	 30.0;
	4499	 866	 0.004909	 0.014719	 0.0	 553.0	 2036	 2036	 0.0	 0.0	 1	 -30.0	 30.0;
	8952	 7514	 0.005591	 0.01814	 0.0	 457.0	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	8952	 7514	 0.00569	 0.01776	 0.0	 514.0	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	7261	 4571	 0.03624	 0.415741	 0.0	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	7261	 8370	 0.03359	 0.482777	 0.0	 66	 66	 66	 0.0	 0.0	 1	 -30.0	 30.0;
	7261	 8370	 0.00088	 0.01001	 0.0	 1711.0	 3144	 3144	 0.0	 0.0	 1	 -30.0	 30.0;
	7261	 938	 0.001	 0.00981	 0.0	 3204	 3204	 3204	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 7261	 0.706579	 3.541136	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 7261	 2.102562	 10.3982	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	484	 1403	 0.00962	 0.03813	 0.0	 533.0	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	7676	 5164	 0.04235	 0.255499	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	7676	 6993	 0.03604	 0.287562	 0.0	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	7676	 6993	 0.00069	 0.00676	 0.0	 1942.0	 4649	 4649	 0.0	 0.0	 1	 -30.0	 30.0;
	7676	 4620	 0.02303	 0.242479	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 7676	 0.002	 0.02189	 0.0	 1438	 1438	 1438	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 5054	 0.00063	 0.00569	 0.0	 1843.0	 5518	 5518	 0.0	 0.0	 1	 -30.0	 30.0;
	2681	 5194	 0.00064	 0.00557	 0.0	 1909.0	 5634	 5634	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 6993	 0.001	 0.193123	 0.0	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 4620	 0.01778	 0.156988	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 4620	 0.00104	 0.00843	 0.0	 1613.0	 5675	 5675	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 5164	 0.00096	 0.01465	 0.0	 2152	 2152	 2152	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 5164	 0.003	 0.02517	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	6993	 4620	 0.462929	 1.374931	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	107	 6993	 0.00244	 0.01729	 0.0	 2761	 2761	 2761	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 6993	 0.00094	 0.01356	 0.0	 2324	 2324	 2324	 0.0	 0.0	 1	 -30.0	 30.0;
	8300	 6794	 0.01526	 0.05118	 0.0	 400.0	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 6794	 0.01555	 0.05011	 0.0	 419.0	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	439	 484	 0.26188	 0.583802	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 7934	 0.0036	 0.04	 0.0	 787	 787	 787	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 495	 0.00363	 0.03446	 0.0	 912	 912	 912	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 3396	 0.00099	 0.01049	 0.0	 1218.0	 2998	 2998	 0.0	 0.0	 1	 -30.0	 30.0;
	8966	 4620	 0.00332	 0.03036	 0.0	 1579	 1579	 1579	 0.0	 0.0	 1	 -30.0	 30.0;
	8716	 1426	 0.00027	 0.00309	 0.0	 1744.0	 10184	 10184	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 1426	 0.00031	 0.00303	 0.0	 1415.0	 10371	 10371	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 3189	 0.027099	 0.21312	 0.0	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 3189	 0.00357	 0.011021	 0.0	 553.0	 2727	 2727	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 3189	 0.00351	 0.01126	 0.0	 495.0	 2679	 2679	 0.0	 0.0	 1	 -30.0	 30.0;
	7934	 495	 0.00037	 0.00418	 0.0	 1251.0	 7528	 7528	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 6621	 0.04124	 0.192349	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 6621	 0.015669	 0.064711	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 6621	 0.016	 0.06349	 0.0	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	6621	 866	 0.012281	 0.03676	 0.0	 610.0	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 193	 0.02043	 0.19226	 0.0	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 193	 0.00287	 0.01095	 0.0	 495.0	 2791	 2791	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 193	 0.00281	 0.011169	 0.0	 495.0	 2743	 2743	 0.0	 0.0	 1	 -30.0	 30.0;
	8415	 6914	 0.00054	 0.00596	 0.0	 1580.0	 5279	 5279	 0.0	 0.0	 1	 -30.0	 30.0;
	6900	 8415	 0.00134	 0.01244	 0.0	 1876.0	 2525	 2525	 0.0	 0.0	 1	 -30.0	 30.0;
	983	 4175	 0.001	 0.265693	 0.0	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	8966	 983	 0.15358	 0.524508	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	7169	 983	 0.613823	 2.118352	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	7169	 983	 0.00081	 0.0077	 0.0	 1349.0	 4080	 4080	 0.0	 0.0	 1	 -30.0	 30.0;
	983	 5194	 0.00228	 0.02083	 0.0	 1508	 1508	 1508	 0.0	 0.0	 1	 -30.0	 30.0;
	8966	 4175	 0.168047	 0.592382	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	8966	 4175	 0.0008	 0.00785	 0.0	 1547.0	 4004	 4004	 0.0	 0.0	 1	 -30.0	 30.0;
	7169	 4175	 0.698199	 2.371468	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	4175	 5054	 0.00232	 0.02039	 0.0	 1540	 1540	 1540	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 5986	 0.00177	 0.01939	 0.0	 2476	 2476	 2476	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 5986	 0.00173	 0.01976	 0.0	 2430	 2430	 2430	 0.0	 0.0	 1	 -30.0	 30.0;
	8966	 7169	 0.0	 0.0002	 0.0	 1613.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8966	 7169	 0.001	 0.213047	 0.0	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	8966	 5054	 0.00194	 0.01469	 0.0	 1547.0	 2132	 2132	 0.0	 0.0	 1	 -30.0	 30.0;
	107	 8966	 0.00123	 0.00838	 0.0	 1514.0	 5691	 5691	 0.0	 0.0	 1	 -30.0	 30.0;
	8966	 3057	 0.00121	 0.0116	 0.0	 1678.0	 4133	 4133	 0.0	 0.0	 1	 -30.0	 30.0;
	8966	 4498	 0.00346	 0.03846	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	7169	 5194	 0.00198	 0.01438	 0.0	 1678.0	 2177	 2177	 0.0	 0.0	 1	 -30.0	 30.0;
	7169	 4498	 0.00338	 0.0392	 0.0	 803	 803	 803	 0.0	 0.0	 1	 -30.0	 30.0;
	7169	 197	 0.00248	 0.02446	 0.0	 889.0	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	4732	 2932	 0.001	 0.26367	 0.0	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 4732	 0.580512	 1.382895	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	6457	 4732	 0.00094	 0.00807	 0.0	 3888	 3888	 3888	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 2932	 0.00232	 0.01638	 0.0	 1910	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 2932	 0.00217	 0.0131	 0.0	 1876.0	 2379	 2379	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 2932	 0.568421	 1.409488	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	1757	 5584	 0.005331	 0.017341	 0.0	 1742	 1742	 1742	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 8370	 0.00199	 0.02218	 0.0	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 5194	 0.00163	 0.01513	 0.0	 2076	 2076	 2076	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 5054	 0.00159	 0.01541	 0.0	 2039	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 6457	 0.00136	 0.00959	 0.0	 3262	 3262	 3262	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 8716	 0.00042	 0.00496	 0.0	 1580.0	 6346	 6346	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 5258	 0.00041	 0.00505	 0.0	 954.0	 6235	 6235	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 7514	 0.016591	 0.06199	 0.0	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 8370	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 8370	 0.001	 0.404868	 0.0	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 4571	 0.130547	 2.317729	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 4571	 0.431627	 6.284488	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 8370	 0.127403	 2.421884	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 8370	 0.397583	 6.979917	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	3396	 6900	 0.00356	 0.03374	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 5054	 0.00164	 0.14108	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 6900	 0.00058	 0.00658	 0.0	 1909.0	 4782	 4782	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 6900	 0.00065	 0.00645	 0.0	 1909.0	 4873	 4873	 0.0	 0.0	 1	 -30.0	 30.0;
	3057	 197	 0.079079	 0.405817	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	3057	 197	 0.00139	 0.01268	 0.0	 1481.0	 3779	 3779	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 503	 0.0	 0.0002	 0.0	 987.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 503	 0.001	 0.270111	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	8414	 6794	 0.185091	 0.839215	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	8414	 6794	 0.004651	 0.039669	 0.0	 495.0	 1207	 1207	 0.0	 0.0	 1	 -30.0	 30.0;
	8414	 6794	 0.00476	 0.042841	 0.0	 495.0	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 197	 0.0018	 0.02033	 0.0	 1185.0	 1548	 1548	 0.0	 0.0	 1	 -30.0	 30.0;
	7799	 6956	 0.001	 0.335748	 0.0	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	8716	 7799	 0.0001	 0.00068	 0.0	 1580.0	 45958	 45958	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 6956	 0.0001	 0.00067	 0.0	 1580.0	 46629	 46629	 0.0	 0.0	 1	 -30.0	 30.0;
	4901	 9195	 0.026107	 0.07605	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	8040	 4901	 0.019727	 0.062124	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	7007	 9195	 0.026603	 0.074438	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	8040	 7007	 0.020107	 0.060851	 0.0	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	8143	 6682	 0.014017	 0.040471	 0.0	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	6682	 1395	 0.012488	 0.045289	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	7210	 5541	 0.014281	 0.039612	 0.0	 751	 751	 751	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 7315	 0.010826	 0.032686	 0.0	 918	 918	 918	 0.0	 0.0	 1	 -30.0	 30.0;
	4462	 6720	 0.012554	 0.049893	 0.0	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	6720	 8118	 0.00705	 0.023174	 0.0	 1305	 1305	 1305	 0.0	 0.0	 1	 -30.0	 30.0;
	4384	 4937	 0.018818	 0.054132	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	1395	 4937	 0.032769	 0.043661	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 4462	 0.015322	 0.049653	 0.0	 608	 608	 608	 0.0	 0.0	 1	 -30.0	 30.0;
	2530	 664	 0.002413	 0.006917	 0.0	 4312	 4312	 4312	 0.0	 0.0	 1	 -30.0	 30.0;
	664	 5353	 0.010537	 0.025917	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	4384	 8143	 0.009124	 0.032314	 0.0	 941	 941	 941	 0.0	 0.0	 1	 -30.0	 30.0;
	4384	 7210	 0.008934	 0.032934	 0.0	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	9195	 4074	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	8410	 4074	 0.015562	 0.044669	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	6585	 4074	 0.013	 0.049983	 0.0	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	9195	 5445	 0.014347	 0.041182	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	9195	 5445	 0.014628	 0.040322	 0.0	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	1715	 690	 0.017446	 0.029752	 0.0	 916	 916	 916	 0.0	 0.0	 1	 -30.0	 30.0;
	1715	 6576	 0.031579	 0.070992	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	3419	 1715	 0.007843	 0.018793	 0.0	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 1715	 0.007992	 0.018413	 0.0	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	5911	 7692	 0.001271	 0.016781	 0.0	 553.0	 1877	 1877	 0.0	 0.0	 1	 -30.0	 30.0;
	5911	 7692	 0.00124	 0.015539	 0.0	 610.0	 2027	 2027	 0.0	 0.0	 1	 -30.0	 30.0;
	690	 4384	 0.033777	 0.06419	 0.0	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4384	 1180	 0.014347	 0.028397	 0.0	 993	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	6576	 4384	 0.023331	 0.052182	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	4384	 6925	 0.009446	 0.022636	 0.0	 1288	 1288	 1288	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 1395	 0.006992	 0.025488	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	6925	 1180	 0.003339	 0.008851	 0.0	 3340	 3340	 3340	 0.0	 0.0	 1	 -30.0	 30.0;
	8410	 4871	 0.016471	 0.06081	 0.0	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	7405	 6585	 0.020149	 0.058727	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 612	 0.013992	 0.054	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 3988	 0.013686	 0.05	 0.0	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 4515	 0.000223	 0.000826	 0.0	 36920	 36920	 36920	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 3358	 0.000248	 0.00081	 0.0	 37289	 37289	 37289	 0.0	 0.0	 1	 -30.0	 30.0;
	9212	 4871	 0.036512	 0.098843	 0.0	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	612	 208	 0.012876	 0.037438	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 208	 0.013124	 0.036636	 0.0	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 3419	 0.013909	 0.033041	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 4403	 0.014182	 0.032372	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 8324	 0.00474	 0.027521	 0.0	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 6865	 0.00538	 0.026969	 0.0	 1149	 1149	 1149	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 8118	 0.020372	 0.06276	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	9212	 7405	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 5911	 0.0053	 0.02831	 0.0	 419.0	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 5911	 0.00601	 0.02774	 0.0	 438.0	 1113	 1113	 0.0	 0.0	 1	 -30.0	 30.0;
	8324	 6159	 0.00113	 0.006229	 0.0	 4990	 4990	 4990	 0.0	 0.0	 1	 -30.0	 30.0;
	6865	 6159	 0.001151	 0.00611	 0.0	 5081	 5081	 5081	 0.0	 0.0	 1	 -30.0	 30.0;
	2530	 2307	 0.014364	 0.029529	 0.0	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 2530	 0.009017	 0.019727	 0.0	 1457	 1457	 1457	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 2530	 0.00919	 0.019314	 0.0	 1477	 1477	 1477	 0.0	 0.0	 1	 -30.0	 30.0;
	6865	 4569	 9.1e-05	 0.000219	 0.0	 133194	 133194	 133194	 0.0	 0.0	 1	 -30.0	 30.0;
	8324	 4569	 9.1e-05	 0.000229	 0.0	 128186	 128186	 128186	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 4857	 0.00205	 0.00562	 0.0	 295.0	 5281	 5281	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 5702	 0.016	 0.049818	 0.0	 604	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 5702	 0.014331	 0.054347	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	8799	 4857	 0.00738	 0.021149	 0.0	 1411	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 8799	 0.011256	 0.027769	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	501	 4857	 0.007207	 0.019587	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 501	 0.01195	 0.024826	 0.0	 1147	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 3158	 0.00796	 0.04504	 0.0	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 6934	 0.00844	 0.068649	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 5874	 0.021551	 0.0842	 0.0	 260.0	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 8761	 0.002809	 0.01632	 0.0	 299.0	 1908	 1908	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 362	 0.00028	 0.00084	 0.0	 35675	 35675	 35675	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 362	 0.00032	 0.000822	 0.0	 35810	 35810	 35810	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 2836	 0.007711	 0.054271	 0.0	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 4508	 0.002298	 0.017129	 0.0	 299.0	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	8026	 8919	 0.004711	 0.026049	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	8026	 5453	 0.008462	 0.03792	 0.0	 814	 814	 814	 0.0	 0.0	 1	 -30.0	 30.0;
	7876	 1776	 0.00095	 0.01117	 0.0	 1086.0	 2818	 2818	 0.0	 0.0	 1	 -30.0	 30.0;
	7876	 5101	 0.00142	 0.01429	 0.0	 1152.0	 2200	 2200	 0.0	 0.0	 1	 -30.0	 30.0;
	5794	 7887	 0.000569	 0.005382	 0.0	 260.0	 5837	 5837	 0.0	 0.0	 1	 -30.0	 30.0;
	3322	 2069	 0.00984	 0.04424	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	3322	 4286	 0.0166	 0.105449	 0.0	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	848	 7465	 0.007209	 0.034969	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	848	 1673	 0.023951	 0.07004	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	8919	 2285	 0.002258	 0.01644	 0.0	 1904	 1904	 1904	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 1385	 0.00948	 0.02892	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 2569	 0.01224	 0.04384	 0.0	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	2351	 2569	 0.016	 0.062369	 0.0	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	2351	 2247	 0.020422	 0.082729	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	2351	 2247	 0.020009	 0.08436	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	4440	 2247	 0.010702	 0.030338	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	4440	 2247	 0.010902	 0.02968	 0.0	 1000	 1000	 1000	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 2662	 0.00848	 0.040809	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 4129	 0.012862	 0.05772	 0.0	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 1776	 0.00047	 0.00546	 0.0	 889.0	 5764	 5764	 0.0	 0.0	 1	 -30.0	 30.0;
	7708	 7670	 0.002871	 0.02108	 0.0	 1485	 1485	 1485	 0.0	 0.0	 1	 -30.0	 30.0;
	7708	 4286	 0.004849	 0.02916	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	7708	 4286	 0.004751	 0.029711	 0.0	 1050	 1050	 1050	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 4286	 0.001569	 0.005489	 0.0	 5534	 5534	 5534	 0.0	 0.0	 1	 -30.0	 30.0;
	6653	 6492	 0.0003	 0.00316	 0.0	 1218.0	 9952	 9952	 0.0	 0.0	 1	 -30.0	 30.0;
	6653	 5101	 0.00114	 0.01207	 0.0	 1152.0	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	6653	 6084	 0.00147	 0.01724	 0.0	 1086.0	 1826	 1826	 0.0	 0.0	 1	 -30.0	 30.0;
	6653	 9228	 0.00039	 0.00552	 0.0	 1251.0	 5709	 5709	 0.0	 0.0	 1	 -30.0	 30.0;
	8761	 2836	 0.004991	 0.036511	 0.0	 858	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	8761	 8095	 0.007302	 0.041071	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	1636	 5977	 0.00022	 0.00305	 0.0	 889.0	 10330	 10330	 0.0	 0.0	 1	 -30.0	 30.0;
	1636	 285	 0.00074	 0.00834	 0.0	 954.0	 3773	 3773	 0.0	 0.0	 1	 -30.0	 30.0;
	1636	 4217	 0.00126	 0.0174	 0.0	 856.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	4228	 3158	 0.00216	 0.012578	 0.0	 2476	 2476	 2476	 0.0	 0.0	 1	 -30.0	 30.0;
	4228	 647	 0.001329	 0.0106	 0.0	 2957	 2957	 2957	 0.0	 0.0	 1	 -30.0	 30.0;
	4228	 6934	 0.006049	 0.063742	 0.0	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 8456	 0.006769	 0.02648	 0.0	 1156	 1156	 1156	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 8129	 0.016022	 0.047791	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 2836	 0.02884	 0.096209	 0.0	 260.0	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	7449	 8129	 0.00656	 0.024578	 0.0	 1242	 1242	 1242	 0.0	 0.0	 1	 -30.0	 30.0;
	7449	 1385	 0.00388	 0.017342	 0.0	 1778	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	7449	 7742	 0.01772	 0.064978	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 651	 0.01312	 0.052809	 0.0	 299.0	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 647	 0.001738	 0.002889	 0.0	 9369	 9369	 9369	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 8032	 0.001169	 0.003489	 0.0	 299.0	 8585	 8585	 0.0	 0.0	 1	 -30.0	 30.0;
	4145	 7559	 0.00368	 0.035022	 0.0	 897	 897	 897	 0.0	 0.0	 1	 -30.0	 30.0;
	4145	 6839	 0.001391	 0.010338	 0.0	 3029	 3029	 3029	 0.0	 0.0	 1	 -30.0	 30.0;
	4145	 4601	 0.004222	 0.030831	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 5715	 0.004271	 0.036089	 0.0	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 7559	 0.00596	 0.04024	 0.0	 777	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 5115	 0.011529	 0.046698	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 2569	 0.02252	 0.087338	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	6608	 3675	 0.004071	 0.035591	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	6608	 4601	 0.004138	 0.0386	 0.0	 814	 814	 814	 0.0	 0.0	 1	 -30.0	 30.0;
	2839	 2519	 0.010911	 0.027231	 0.0	 1077	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	81	 6506	 0.00256	 0.024622	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	81	 4601	 0.005129	 0.040671	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	8456	 7465	 0.005462	 0.032671	 0.0	 954	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	8456	 1673	 0.002871	 0.014209	 0.0	 2180	 2180	 2180	 0.0	 0.0	 1	 -30.0	 30.0;
	8456	 1673	 0.002929	 0.013911	 0.0	 2222	 2222	 2222	 0.0	 0.0	 1	 -30.0	 30.0;
	8456	 200	 0.003422	 0.011009	 0.0	 2740	 2740	 2740	 0.0	 0.0	 1	 -30.0	 30.0;
	6506	 7559	 0.00212	 0.016769	 0.0	 1869	 1869	 1869	 0.0	 0.0	 1	 -30.0	 30.0;
	1953	 5101	 0.00125	 0.01387	 0.0	 1711.0	 2269	 2269	 0.0	 0.0	 1	 -30.0	 30.0;
	8611	 2569	 0.004289	 0.017071	 0.0	 260.0	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	8611	 5273	 0.0084	 0.024738	 0.0	 1210	 1210	 1210	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 4286	 0.01044	 0.039671	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 4286	 0.010218	 0.040418	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 3743	 0.008351	 0.02432	 0.0	 1229	 1229	 1229	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 2411	 0.00188	 0.006711	 0.0	 4533	 4533	 4533	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 8095	 0.00132	 0.00352	 0.0	 8403	 8403	 8403	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 4217	 0.00113	 0.01322	 0.0	 1415.0	 2381	 2381	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 1776	 0.00098	 0.01301	 0.0	 1053.0	 2422	 2422	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 5453	 0.005271	 0.05104	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 7544	 0.017458	 0.109631	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 222	 0.002831	 0.01016	 0.0	 2995	 2995	 2995	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 222	 0.001978	 0.010902	 0.0	 2851	 2851	 2851	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 4217	 0.00059	 0.00764	 0.0	 790.0	 4123	 4123	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 8129	 0.000231	 0.000769	 0.0	 39340	 39340	 39340	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 2285	 0.002809	 0.02468	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 7887	 0.009942	 0.050222	 0.0	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 8206	 0.00117	 0.01756	 0.0	 1547.0	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 9047	 9e-05	 0.0017	 0.0	 856.0	 18555	 18555	 0.0	 0.0	 1	 -30.0	 30.0;
	2285	 6391	 0.002569	 0.02344	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	2285	 4720	 0.00144	 0.011369	 0.0	 2757	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	9058	 8201	 0.002129	 0.019689	 0.0	 1596	 1596	 1596	 0.0	 0.0	 1	 -30.0	 30.0;
	4286	 7544	 0.00756	 0.048378	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	4286	 5115	 0.031138	 0.104969	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	8206	 6084	 0.00043	 0.00623	 0.0	 1185.0	 5059	 5059	 0.0	 0.0	 1	 -30.0	 30.0;
	7559	 2544	 0.000769	 0.005769	 0.0	 5428	 5428	 5428	 0.0	 0.0	 1	 -30.0	 30.0;
	736	 4601	 0.01464	 0.043018	 0.0	 696	 696	 696	 0.0	 0.0	 1	 -30.0	 30.0;
	736	 137	 0.006609	 0.014329	 0.0	 2002	 2002	 2002	 0.0	 0.0	 1	 -30.0	 30.0;
	4200	 6084	 0.00021	 0.00252	 0.0	 856.0	 12492	 12492	 0.0	 0.0	 1	 -30.0	 30.0;
	4376	 4601	 0.002689	 0.019791	 0.0	 1582	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	4376	 4601	 0.002738	 0.01936	 0.0	 1616	 1616	 1616	 0.0	 0.0	 1	 -30.0	 30.0;
	4376	 4601	 0.001338	 0.010018	 0.0	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	6839	 4601	 0.001698	 0.012871	 0.0	 2434	 2434	 2434	 0.0	 0.0	 1	 -30.0	 30.0;
	1646	 4601	 0.00384	 0.028342	 0.0	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	2836	 8201	 0.00616	 0.033618	 0.0	 925	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	2836	 7742	 0.01488	 0.045698	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	6492	 9228	 4e-05	 0.00051	 0.0	 1218.0	 61747	 61747	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 2662	 0.028751	 0.090409	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 4129	 0.00092	 0.004609	 0.0	 6721	 6721	 6721	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 2569	 0.005151	 0.012329	 0.0	 2365	 2365	 2365	 0.0	 0.0	 1	 -30.0	 30.0;
	6391	 4720	 0.002129	 0.018	 0.0	 1743	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	222	 5874	 0.008929	 0.041471	 0.0	 745	 745	 745	 0.0	 0.0	 1	 -30.0	 30.0;
	222	 2124	 0.0222	 0.091822	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 5273	 0.005671	 0.021169	 0.0	 1442	 1442	 1442	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 2124	 0.00956	 0.035551	 0.0	 273.0	 859	 859	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 8201	 0.003169	 0.021911	 0.0	 1427	 1427	 1427	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 8201	 0.00324	 0.021471	 0.0	 1455	 1455	 1455	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 4601	 0.01168	 0.055391	 0.0	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 4601	 0.011902	 0.054209	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 137	 0.01908	 0.062769	 0.0	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 4508	 0.001591	 0.011098	 0.0	 299.0	 2818	 2818	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 1294	 0.003289	 0.019091	 0.0	 457.0	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 1666	 0.004169	 0.025349	 0.0	 476.0	 1230	 1230	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 4096	 0.00439	 0.023909	 0.0	 457.0	 1300	 1300	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 4241	 0.00156	 0.01956	 0.0	 1316.0	 1610	 1610	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 7395	 0.00029	 0.00391	 0.0	 1843.0	 8057	 8057	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 5873	 0.00179	 0.02522	 0.0	 1250	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 4241	 0.00079	 0.00756	 0.0	 1843.0	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 1475	 0.00027	 0.00281	 0.0	 1645.0	 11190	 11190	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 1475	 0.00026	 0.00286	 0.0	 1547.0	 11000	 11000	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 264	 0.000281	 0.00213	 0.0	 14703	 14703	 14703	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 8530	 0.000419	 0.00299	 0.0	 10463	 10463	 10463	 0.0	 0.0	 1	 -30.0	 30.0;
	3744	 4806	 0.001659	 0.009091	 0.0	 3419	 3419	 3419	 0.0	 0.0	 1	 -30.0	 30.0;
	3744	 6239	 0.00439	 0.03324	 0.0	 381.0	 943	 943	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 8671	 0.000841	 0.00612	 0.0	 400.0	 5114	 5114	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 201	 0.003341	 0.022841	 0.0	 533.0	 1369	 1369	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 3512	 0.00581	 0.04232	 0.0	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 1430	 0.00495	 0.02919	 0.0	 438.0	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 5592	 0.01789	 0.07795	 0.0	 381.0	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 4953	 0.00186	 0.014289	 0.0	 381.0	 2193	 2193	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 2355	 0.002281	 0.014401	 0.0	 2167	 2167	 2167	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 2957	 0.00031	 0.00132	 0.0	 23296	 23296	 23296	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 6936	 0.001349	 0.0077	 0.0	 381.0	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 5933	 0.00586	 0.02574	 0.0	 476.0	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 6040	 0.00556	 0.020211	 0.0	 591.0	 1507	 1507	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 2917	 0.00026	 0.001159	 0.0	 553.0	 26594	 26594	 0.0	 0.0	 1	 -30.0	 30.0;
	2917	 6654	 0.000599	 0.002419	 0.0	 591.0	 12676	 12676	 0.0	 0.0	 1	 -30.0	 30.0;
	6679	 7139	 0.0005	 0.00386	 0.0	 8116	 8116	 8116	 0.0	 0.0	 1	 -30.0	 30.0;
	6679	 6134	 0.00107	 0.008289	 0.0	 533.0	 3780	 3780	 0.0	 0.0	 1	 -30.0	 30.0;
	6679	 6134	 0.001091	 0.00811	 0.0	 3861	 3861	 3861	 0.0	 0.0	 1	 -30.0	 30.0;
	7413	 6679	 0.00038	 0.00255	 0.0	 533.0	 12252	 12252	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 6456	 0.000271	 0.000979	 0.0	 31096	 31096	 31096	 0.0	 0.0	 1	 -30.0	 30.0;
	2358	 1638	 7e-05	 0.00076	 0.0	 41388	 41388	 41388	 0.0	 0.0	 1	 -30.0	 30.0;
	2358	 8571	 0.000521	 0.003901	 0.0	 8026	 8026	 8026	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 8247	 0.0016	 0.01839	 0.0	 1251.0	 1712	 1712	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 1393	 0.007651	 0.058781	 0.0	 476.0	 533	 533	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 6243	 0.00394	 0.02182	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 8338	 0.003461	 0.03005	 0.0	 553.0	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 751	 0.00337	 0.01831	 0.0	 438.0	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	8285	 4293	 0.000581	 0.00194	 0.0	 495.0	 15598	 15598	 0.0	 0.0	 1	 -30.0	 30.0;
	7392	 4293	 0.000539	 0.001719	 0.0	 17534	 17534	 17534	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 930	 0.00249	 0.03075	 0.0	 1024	 1024	 1024	 0.0	 0.0	 1	 -30.0	 30.0;
	930	 4407	 0.0014	 0.01409	 0.0	 1678.0	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	7834	 6596	 0.008	 0.050031	 0.0	 381.0	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	7834	 5592	 0.002211	 0.01562	 0.0	 572.0	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	1418	 3633	 0.00281	 0.021831	 0.0	 476.0	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	1418	 7820	 0.000711	 0.004919	 0.0	 6356	 6356	 6356	 0.0	 0.0	 1	 -30.0	 30.0;
	2921	 6093	 0.001841	 0.00738	 0.0	 4153	 4153	 4153	 0.0	 0.0	 1	 -30.0	 30.0;
	2921	 3487	 0.002849	 0.008979	 0.0	 3354	 3354	 3354	 0.0	 0.0	 1	 -30.0	 30.0;
	8353	 3633	 0.00232	 0.014099	 0.0	 2211	 2211	 2211	 0.0	 0.0	 1	 -30.0	 30.0;
	8353	 3633	 0.00237	 0.0138	 0.0	 2256	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	8353	 6904	 0.00081	 0.004591	 0.0	 476.0	 6776	 6776	 0.0	 0.0	 1	 -30.0	 30.0;
	8353	 6625	 0.002219	 0.010469	 0.0	 2952	 2952	 2952	 0.0	 0.0	 1	 -30.0	 30.0;
	6261	 1872	 0.001081	 0.00851	 0.0	 3683	 3683	 3683	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 7973	 0.00087	 0.006969	 0.0	 4498	 4498	 4498	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 7973	 0.00088	 0.006831	 0.0	 4587	 4587	 4587	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 4651	 0.000349	 0.00237	 0.0	 13186	 13186	 13186	 0.0	 0.0	 1	 -30.0	 30.0;
	710	 6499	 0.00232	 0.00924	 0.0	 381.0	 3316	 3316	 0.0	 0.0	 1	 -30.0	 30.0;
	710	 3792	 0.00812	 0.03669	 0.0	 400.0	 841	 841	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 6717	 0.003521	 0.02825	 0.0	 476.0	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 4752	 0.00264	 0.017651	 0.0	 1770	 1770	 1770	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 6499	 0.00486	 0.02149	 0.0	 457.0	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 6769	 0.006831	 0.034669	 0.0	 419.0	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 7075	 0.017211	 0.108151	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 8213	 0.00063	 0.00475	 0.0	 419.0	 6593	 6593	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 8213	 0.00062	 0.004841	 0.0	 6473	 6473	 6473	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 2507	 0.0009	 0.01092	 0.0	 1843.0	 2883	 2883	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 6917	 0.00124	 0.01096	 0.0	 1777.0	 2864	 2864	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 2951	 0.003211	 0.00176	 0.0	 8627	 8627	 8627	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 7820	 0.001521	 0.008031	 0.0	 3865	 3865	 3865	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 1898	 0.0005	 0.00441	 0.0	 1415.0	 7118	 7118	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 1498	 0.00247	 0.02573	 0.0	 1223	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 1280	 0.00042	 0.00367	 0.0	 1283.0	 8552	 8552	 0.0	 0.0	 1	 -30.0	 30.0;
	7431	 4279	 0.0023	 0.01644	 0.0	 457.0	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	7431	 4279	 0.00226	 0.01676	 0.0	 457.0	 1868	 1868	 0.0	 0.0	 1	 -30.0	 30.0;
	7431	 4279	 0.0023	 0.0162	 0.0	 476.0	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	7431	 4279	 0.00225	 0.015	 0.0	 419.0	 2083	 2083	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 5946	 0.007281	 0.035729	 0.0	 438.0	 867	 867	 0.0	 0.0	 1	 -30.0	 30.0;
	2236	 5946	 0.001919	 0.00945	 0.0	 438.0	 3276	 3276	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 1173	 0.005211	 0.02981	 0.0	 514.0	 1044	 1044	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 6936	 0.000659	 0.00586	 0.0	 5357	 5357	 5357	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 6936	 0.000591	 0.00664	 0.0	 4739	 4739	 4739	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 2946	 0.011969	 0.07424	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	6261	 3065	 0.000531	 0.003919	 0.0	 7988	 7988	 7988	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 3378	 0.001521	 0.00718	 0.0	 438.0	 4304	 4304	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 3378	 0.001211	 0.00613	 0.0	 476.0	 5056	 5056	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 4809	 0.00676	 0.03725	 0.0	 419.0	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 4750	 0.00399	 0.018091	 0.0	 381.0	 1706	 1706	 0.0	 0.0	 1	 -30.0	 30.0;
	6663	 5217	 0.000341	 0.00339	 0.0	 9272	 9272	 9272	 0.0	 0.0	 1	 -30.0	 30.0;
	6663	 4096	 0.001271	 0.0102	 0.0	 3074	 3074	 3074	 0.0	 0.0	 1	 -30.0	 30.0;
	6663	 4096	 0.00125	 0.010401	 0.0	 3016	 3016	 3016	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 509	 0.00261	 0.016651	 0.0	 1875	 1875	 1875	 0.0	 0.0	 1	 -30.0	 30.0;
	9162	 509	 0.000219	 0.002409	 0.0	 514.0	 13059	 13059	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 6964	 0.00601	 0.02814	 0.0	 438.0	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 7002	 0.008969	 0.03787	 0.0	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 6879	 0.00232	 0.01094	 0.0	 438.0	 2825	 2825	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 6917	 0.00196	 0.02382	 0.0	 1322	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 8870	 0.00422	 0.03598	 0.0	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 8870	 0.0043	 0.03522	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	8504	 6632	 0.00208	 0.01691	 0.0	 1547.0	 1854	 1854	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 2730	 0.00544	 0.05439	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 7508	 0.00239	 0.02598	 0.0	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 385	 0.00396	 0.03096	 0.0	 1013	 1013	 1013	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 385	 0.00353	 0.03509	 0.0	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 8858	 0.000531	 0.003729	 0.0	 514.0	 8387	 8387	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 8858	 0.00038	 0.0025	 0.0	 12492	 12492	 12492	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 8858	 0.00039	 0.00244	 0.0	 12784	 12784	 12784	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 4856	 0.00836	 0.044521	 0.0	 400.0	 698	 698	 0.0	 0.0	 1	 -30.0	 30.0;
	1618	 1060	 0.00264	 0.03029	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	1618	 8806	 0.00396	 0.04589	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	8547	 6669	 0.00411	 0.021729	 0.0	 400.0	 1429	 1429	 0.0	 0.0	 1	 -30.0	 30.0;
	8547	 7398	 0.00607	 0.0285	 0.0	 457.0	 1085	 1085	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 2496	 0.00075	 0.0047	 0.0	 6637	 6637	 6637	 0.0	 0.0	 1	 -30.0	 30.0;
	8419	 2496	 0.00114	 0.007969	 0.0	 553.0	 3924	 3924	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 2916	 0.00036	 0.00324	 0.0	 1316.0	 9690	 9690	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 8973	 0.00094	 0.00874	 0.0	 1218.0	 3594	 3594	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 8888	 0.00949	 0.05145	 0.0	 476.0	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 4906	 0.011719	 0.0337	 0.0	 400.0	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 2471	 0.0022	 0.012331	 0.0	 419.0	 2522	 2522	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 2235	 0.00038	 0.00448	 0.0	 1382.0	 7026	 7026	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 5873	 0.00098	 0.01126	 0.0	 987.0	 2795	 2795	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 5919	 0.00055	 0.00621	 0.0	 1777.0	 5067	 5067	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 2096	 0.00163	 0.01287	 0.0	 1711.0	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 6127	 0.0018	 0.01886	 0.0	 1668	 1668	 1668	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 6127	 0.0047	 0.024969	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 2658	 0.009711	 0.059669	 0.0	 400.0	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 5191	 0.005271	 0.03451	 0.0	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 1175	 0.016169	 0.11936	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 1344	 0.00226	 0.014789	 0.0	 419.0	 2112	 2112	 0.0	 0.0	 1	 -30.0	 30.0;
	8671	 1421	 0.00151	 0.01081	 0.0	 591.0	 2894	 2894	 0.0	 0.0	 1	 -30.0	 30.0;
	709	 4652	 0.00228	 0.0217	 0.0	 1448	 1448	 1448	 0.0	 0.0	 1	 -30.0	 30.0;
	709	 3587	 0.00137	 0.01593	 0.0	 1711.0	 1976	 1976	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 3798	 0.00099	 0.0121	 0.0	 1086.0	 2602	 2602	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 2261	 0.0	 0.01881	 0.0	 1119.0	 1680	 1680	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 7755	 0.00143	 0.0163	 0.0	 1185.0	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 7287	 0.00057	 0.00562	 0.0	 1119.0	 5592	 5592	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 7287	 0.00055	 0.00572	 0.0	 1185.0	 5497	 5497	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 6496	 0.00057	 0.00658	 0.0	 1448.0	 4783	 4783	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 5372	 0.00075	 0.0082	 0.0	 1251.0	 3837	 3837	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 807	 0.00253	 0.02153	 0.0	 1316.0	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	201	 8582	 0.00236	 0.011219	 0.0	 533.0	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 7053	 0.00173	 0.0154	 0.0	 1415.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 2764	 0.00385	 0.04172	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 2764	 0.00377	 0.04251	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1498	 0.00199	 0.02121	 0.0	 1483	 1483	 1483	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1133	 0.00236	 0.01933	 0.0	 1185.0	 1623	 1623	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1133	 0.00241	 0.01891	 0.0	 1119.0	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	2301	 3427	 0.000521	 0.004729	 0.0	 6640	 6640	 6640	 0.0	 0.0	 1	 -30.0	 30.0;
	2301	 8575	 0.00094	 0.005581	 0.0	 5582	 5582	 5582	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 1086	 0.00134	 0.01324	 0.0	 1218.0	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 2849	 0.00073	 0.00638	 0.0	 1283.0	 4919	 4919	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 2459	 0.00248	 0.02774	 0.0	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 477	 0.00152	 0.013	 0.0	 1580.0	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 477	 0.00155	 0.01272	 0.0	 1678.0	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 8210	 0.00117	 0.01301	 0.0	 1349.0	 2419	 2419	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 3113	 0.00197	 0.02054	 0.0	 1119.0	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 8987	 0.00157	 0.01909	 0.0	 1613.0	 1650	 1650	 0.0	 0.0	 1	 -30.0	 30.0;
	3065	 4450	 0.00107	 0.008669	 0.0	 3617	 3617	 3617	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 1501	 0.000469	 0.00314	 0.0	 9950	 9950	 9950	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 706	 0.000409	 0.00305	 0.0	 10265	 10265	 10265	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 706	 0.00569	 0.032979	 0.0	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	3500	 8871	 0.00087	 0.006771	 0.0	 514.0	 4628	 4628	 0.0	 0.0	 1	 -30.0	 30.0;
	3500	 8582	 0.002151	 0.014039	 0.0	 533.0	 2225	 2225	 0.0	 0.0	 1	 -30.0	 30.0;
	6359	 6783	 9.9e-05	 0.00043	 0.0	 553.0	 71587	 71587	 0.0	 0.0	 1	 -30.0	 30.0;
	6454	 6359	 0.000151	 0.0005	 0.0	 60477	 60477	 60477	 0.0	 0.0	 1	 -30.0	 30.0;
	7833	 8438	 0.001531	 0.00812	 0.0	 3823	 3823	 3823	 0.0	 0.0	 1	 -30.0	 30.0;
	7833	 8438	 0.00113	 0.00857	 0.0	 3655	 3655	 3655	 0.0	 0.0	 1	 -30.0	 30.0;
	4253	 7196	 0.00226	 0.01868	 0.0	 514.0	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	4253	 4651	 0.000401	 0.00239	 0.0	 13035	 13035	 13035	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 1912	 0.001169	 0.008349	 0.0	 514.0	 3747	 3747	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 6315	 0.00324	 0.02312	 0.0	 533.0	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	621	 4360	 0.006031	 0.034789	 0.0	 495.0	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	621	 808	 0.0103	 0.05269	 0.0	 438.0	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 6917	 0.00129	 0.01494	 0.0	 1481.0	 2107	 2107	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 6917	 0.00126	 0.01523	 0.0	 1349.0	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	4958	 4906	 0.001031	 0.00601	 0.0	 5181	 5181	 5181	 0.0	 0.0	 1	 -30.0	 30.0;
	4958	 4906	 0.00105	 0.00588	 0.0	 5289	 5289	 5289	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 5823	 0.00197	 0.01719	 0.0	 1119.0	 1826	 1826	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 1947	 0.00114	 0.01237	 0.0	 1382.0	 2543	 2543	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 3966	 0.00314	 0.02868	 0.0	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 1074	 0.00294	 0.03326	 0.0	 947	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 1074	 0.00288	 0.0308	 0.0	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 807	 0.00088	 0.02821	 0.0	 1086.0	 1120	 1120	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 6659	 0.00152	 0.01702	 0.0	 889.0	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 7303	 0.00022	 0.00209	 0.0	 1481.0	 15031	 15031	 0.0	 0.0	 1	 -30.0	 30.0;
	1793	 2668	 0.00087	 0.005	 0.0	 6224	 6224	 6224	 0.0	 0.0	 1	 -30.0	 30.0;
	1793	 8338	 0.000711	 0.00439	 0.0	 381.0	 7103	 7103	 0.0	 0.0	 1	 -30.0	 30.0;
	1793	 8338	 0.000729	 0.004289	 0.0	 419.0	 7261	 7261	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 6443	 0.001031	 0.00549	 0.0	 5655	 5655	 5655	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 519	 0.003219	 0.01512	 0.0	 2044	 2044	 2044	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 595	 0.007271	 0.031419	 0.0	 381.0	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 3291	 0.02145	 0.085781	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 7504	 0.002841	 0.017771	 0.0	 1756	 1756	 1756	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 2896	 0.003331	 0.017289	 0.0	 400.0	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 2343	 0.01524	 0.064091	 0.0	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	8534	 5121	 0.000831	 0.0052	 0.0	 514.0	 5999	 5999	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 9039	 0.00164	 0.0103	 0.0	 495.0	 3029	 3029	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 4238	 0.00139	 0.00864	 0.0	 381.0	 3610	 3610	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 1411	 0.00143	 0.00764	 0.0	 438.0	 4064	 4064	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 5793	 0.000229	 0.00126	 0.0	 24666	 24666	 24666	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 5793	 0.000211	 0.00143	 0.0	 21853	 21853	 21853	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 1549	 0.0008	 0.01072	 0.0	 1547.0	 2939	 2939	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 4600	 0.00067	 0.00661	 0.0	 1119.0	 4755	 4755	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 2800	 0.0003	 0.00427	 0.0	 1382.0	 7380	 7380	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 2800	 0.00068	 0.00648	 0.0	 1349.0	 4848	 4848	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 8186	 0.0002	 0.001289	 0.0	 24216	 24216	 24216	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 4011	 0.00013	 0.000961	 0.0	 533.0	 32573	 32573	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 2235	 0.00118	 0.01285	 0.0	 1613.0	 2448	 2448	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 5239	 0.00062	 0.00577	 0.0	 1086.0	 5444	 5444	 0.0	 0.0	 1	 -30.0	 30.0;
	9216	 1409	 9.1e-05	 0.000289	 0.0	 104253	 104253	 104253	 0.0	 0.0	 1	 -30.0	 30.0;
	9216	 1409	 9.1e-05	 0.000271	 0.0	 110496	 110496	 110496	 0.0	 0.0	 1	 -30.0	 30.0;
	9216	 6597	 0.0003	 0.002719	 0.0	 476.0	 11548	 11548	 0.0	 0.0	 1	 -30.0	 30.0;
	9216	 6836	 0.00049	 0.002091	 0.0	 14708	 14708	 14708	 0.0	 0.0	 1	 -30.0	 30.0;
	9216	 15	 0.000159	 0.001461	 0.0	 572.0	 21494	 21494	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 6132	 0.00301	 0.02281	 0.0	 1373	 1373	 1373	 0.0	 0.0	 1	 -30.0	 30.0;
	6660	 6132	 0.0027	 0.019979	 0.0	 1567	 1567	 1567	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 649	 0.00019	 0.000539	 0.0	 55271	 55271	 55271	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 6836	 0.000169	 0.00061	 0.0	 514.0	 49903	 49903	 0.0	 0.0	 1	 -30.0	 30.0;
	8417	 5435	 0.00163	 0.00939	 0.0	 533.0	 3315	 3315	 0.0	 0.0	 1	 -30.0	 30.0;
	8417	 5435	 0.001159	 0.009031	 0.0	 514.0	 3470	 3470	 0.0	 0.0	 1	 -30.0	 30.0;
	8417	 4058	 9.9e-05	 0.00037	 0.0	 457.0	 82471	 82471	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 9055	 0.003789	 0.01805	 0.0	 1713	 1713	 1713	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 1471	 0.00069	 0.00389	 0.0	 7996	 7996	 7996	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 7925	 0.00201	 0.01845	 0.0	 1283.0	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 7925	 0.00121	 0.00902	 0.0	 1283.0	 3471	 3471	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 1947	 0.00155	 0.01573	 0.0	 1283.0	 1999	 1999	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 8337	 0.00031	 0.00274	 0.0	 1316.0	 11456	 11456	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 3966	 0.00047	 0.00563	 0.0	 1185.0	 5592	 5592	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 3544	 0.00066	 0.00721	 0.0	 1152.0	 4363	 4363	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 4806	 0.00326	 0.016711	 0.0	 1856	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 2907	 0.002479	 0.01262	 0.0	 629.0	 2457	 2457	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 2907	 0.00243	 0.01286	 0.0	 610.0	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 4338	 0.004521	 0.02306	 0.0	 476.0	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 1282	 0.00211	 0.00899	 0.0	 3421	 3421	 3421	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 7795	 0.001289	 0.005651	 0.0	 553.0	 5450	 5450	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 3382	 0.002479	 0.009021	 0.0	 3377	 3377	 3377	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 6456	 0.00151	 0.010521	 0.0	 419.0	 2972	 2972	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 8352	 0.00101	 0.004151	 0.0	 438.0	 7394	 7394	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 797	 0.015599	 0.079	 0.0	 381.0	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 8207	 0.013961	 0.067591	 0.0	 457.0	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 1241	 0.007099	 0.043169	 0.0	 514.0	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 5042	 0.00317	 0.02987	 0.0	 987.0	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 2764	 0.00081	 0.0088	 0.0	 1119.0	 3575	 3575	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 2764	 0.00098	 0.00961	 0.0	 987.0	 3270	 3270	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 179	 0.00194	 0.02225	 0.0	 921.0	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	9001	 5463	 0.001031	 0.006349	 0.0	 4911	 4911	 4911	 0.0	 0.0	 1	 -30.0	 30.0;
	9001	 445	 0.00668	 0.0297	 0.0	 553.0	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	4809	 2538	 0.00439	 0.02236	 0.0	 533.0	 1387	 1387	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 6397	 0.00249	 0.01349	 0.0	 591.0	 2303	 2303	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 4556	 0.001969	 0.01205	 0.0	 495.0	 2588	 2588	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 4592	 0.000461	 0.003031	 0.0	 572.0	 10303	 10303	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 267	 0.00444	 0.023479	 0.0	 438.0	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 4632	 0.00175	 0.01288	 0.0	 2431	 2431	 2431	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 4632	 0.001711	 0.01312	 0.0	 2388	 2388	 2388	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 579	 0.0008	 0.00784	 0.0	 1481.0	 4009	 4009	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 9117	 0.00051	 0.00612	 0.0	 1382.0	 5144	 5144	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 7145	 0.00137	 0.00905	 0.0	 3451	 3451	 3451	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 4855	 0.002771	 0.021409	 0.0	 381.0	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 4855	 0.00314	 0.020979	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 4095	 0.002	 0.01118	 0.0	 2782	 2782	 2782	 0.0	 0.0	 1	 -30.0	 30.0;
	8285	 699	 0.00119	 0.00875	 0.0	 3578	 3578	 3578	 0.0	 0.0	 1	 -30.0	 30.0;
	8285	 6882	 0.00031	 0.00236	 0.0	 13271	 13271	 13271	 0.0	 0.0	 1	 -30.0	 30.0;
	8285	 7820	 0.000831	 0.00539	 0.0	 5792	 5792	 5792	 0.0	 0.0	 1	 -30.0	 30.0;
	267	 7349	 0.004349	 0.02394	 0.0	 419.0	 1299	 1299	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 8731	 0.0007	 0.00782	 0.0	 1678.0	 4024	 4024	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 1716	 0.00046	 0.00432	 0.0	 1843.0	 7271	 7271	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 3067	 0.00049	 0.00617	 0.0	 1678.0	 5104	 5104	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 1074	 0.00127	 0.01514	 0.0	 1777.0	 2080	 2080	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 6544	 0.00232	 0.01843	 0.0	 1701	 1701	 1701	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 1503	 0.00488	 0.032151	 0.0	 553.0	 972	 972	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 3715	 0.000229	 0.00136	 0.0	 533.0	 22904	 22904	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 6836	 0.0003	 0.001531	 0.0	 476.0	 20247	 20247	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 5892	 0.00026	 0.00126	 0.0	 400.0	 24553	 24553	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 5948	 0.00056	 0.002091	 0.0	 553.0	 14593	 14593	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 2962	 0.00103	 0.0093	 0.0	 1711.0	 3376	 3376	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 2437	 0.00183	 0.01689	 0.0	 1316.0	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	7058	 5163	 0.00324	 0.01095	 0.0	 857.0	 2767	 2767	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 8236	 0.001419	 0.008539	 0.0	 3650	 3650	 3650	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 3427	 0.00068	 0.00438	 0.0	 495.0	 7127	 7127	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 5884	 0.00178	 0.01651	 0.0	 1283.0	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 4315	 0.00151	 0.01827	 0.0	 1251.0	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 4315	 0.00148	 0.01862	 0.0	 1316.0	 1692	 1692	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 2437	 0.00201	 0.02546	 0.0	 1237	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 2437	 0.00197	 0.02357	 0.0	 1336	 1336	 1336	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 3427	 0.001091	 0.00775	 0.0	 4036	 4036	 4036	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 988	 0.000841	 0.006669	 0.0	 4700	 4700	 4700	 0.0	 0.0	 1	 -30.0	 30.0;
	932	 3728	 0.00151	 0.012081	 0.0	 514.0	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	932	 7463	 0.00032	 0.002521	 0.0	 438.0	 12430	 12430	 0.0	 0.0	 1	 -30.0	 30.0;
	8087	 3342	 0.006091	 0.03019	 0.0	 514.0	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	8087	 7659	 0.003651	 0.016461	 0.0	 553.0	 1874	 1874	 0.0	 0.0	 1	 -30.0	 30.0;
	8087	 3334	 0.00076	 0.00425	 0.0	 381.0	 7317	 7317	 0.0	 0.0	 1	 -30.0	 30.0;
	8087	 3334	 0.00087	 0.004031	 0.0	 7660	 7660	 7660	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 3728	 0.000651	 0.004729	 0.0	 591.0	 6618	 6618	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 8936	 0.00045	 0.00337	 0.0	 514.0	 9291	 9291	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 481	 0.001539	 0.00839	 0.0	 438.0	 3704	 3704	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 481	 0.001919	 0.010479	 0.0	 514.0	 2966	 2966	 0.0	 0.0	 1	 -30.0	 30.0;
	481	 9057	 0.001169	 0.007031	 0.0	 438.0	 4432	 4432	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 481	 0.00739	 0.034081	 0.0	 906	 906	 906	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 481	 0.00164	 0.00964	 0.0	 419.0	 3231	 3231	 0.0	 0.0	 1	 -30.0	 30.0;
	5890	 481	 0.00206	 0.012	 0.0	 457.0	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 481	 0.000961	 0.00531	 0.0	 457.0	 5854	 5854	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 6771	 6e-05	 0.00029	 0.0	 987.0	 106663	 106663	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 4806	 0.001919	 0.013151	 0.0	 381.0	 2377	 2377	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 4806	 0.00019	 0.00107	 0.0	 400.0	 29067	 29067	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 4806	 0.00018	 0.001091	 0.0	 438.0	 28567	 28567	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 2459	 0.00147	 0.01714	 0.0	 1514.0	 1837	 1837	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 2459	 0.00143	 0.01632	 0.0	 1283.0	 1929	 1929	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 2459	 0.00142	 0.01416	 0.0	 1580.0	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 2459	 0.00145	 0.01386	 0.0	 1744.0	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 8987	 0.00073	 0.00732	 0.0	 1613.0	 4294	 4294	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 1240	 0.009039	 0.05989	 0.0	 476.0	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 4016	 0.007919	 0.04975	 0.0	 457.0	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 981	 0.000521	 0.005841	 0.0	 457.0	 5387	 5387	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 6344	 0.000521	 0.0028	 0.0	 11091	 11091	 11091	 0.0	 0.0	 1	 -30.0	 30.0;
	6564	 1074	 0.0007	 0.00744	 0.0	 889.0	 4227	 4227	 0.0	 0.0	 1	 -30.0	 30.0;
	6564	 4026	 0.00159	 0.0148	 0.0	 921.0	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	4336	 4249	 0.000659	 0.005151	 0.0	 553.0	 6083	 6083	 0.0	 0.0	 1	 -30.0	 30.0;
	7196	 4249	 0.000729	 0.004901	 0.0	 419.0	 6375	 6375	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 642	 0.00064	 0.00772	 0.0	 1119.0	 4078	 4078	 0.0	 0.0	 1	 -30.0	 30.0;
	7573	 6186	 0.00018	 0.00093	 0.0	 591.0	 33347	 33347	 0.0	 0.0	 1	 -30.0	 30.0;
	7573	 8186	 0.00019	 0.00118	 0.0	 495.0	 26429	 26429	 0.0	 0.0	 1	 -30.0	 30.0;
	7413	 7573	 0.000409	 0.002341	 0.0	 514.0	 13292	 13292	 0.0	 0.0	 1	 -30.0	 30.0;
	8719	 1023	 0.00087	 0.006591	 0.0	 381.0	 4752	 4752	 0.0	 0.0	 1	 -30.0	 30.0;
	8719	 3063	 0.00162	 0.0098	 0.0	 3181	 3181	 3181	 0.0	 0.0	 1	 -30.0	 30.0;
	7508	 7053	 0.00096	 0.00849	 0.0	 1547.0	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6932	 0.000341	 0.001081	 0.0	 495.0	 27867	 27867	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6932	 0.0003	 0.001219	 0.0	 514.0	 25162	 25162	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 8068	 9.9e-05	 0.00076	 0.0	 533.0	 41215	 41215	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 8068	 0.00011	 0.00074	 0.0	 553.0	 42222	 42222	 0.0	 0.0	 1	 -30.0	 30.0;
	1602	 4855	 0.00151	 0.009039	 0.0	 3447	 3447	 3447	 0.0	 0.0	 1	 -30.0	 30.0;
	1602	 2551	 0.00356	 0.02331	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 1439	 0.000281	 0.00169	 0.0	 18438	 18438	 18438	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 6597	 0.000169	 0.001531	 0.0	 495.0	 20508	 20508	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 8661	 0.00038	 0.00326	 0.0	 9625	 9625	 9625	 0.0	 0.0	 1	 -30.0	 30.0;
	1086	 7257	 0.00136	 0.01738	 0.0	 1481.0	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 519	 0.00186	 0.0133	 0.0	 2353	 2353	 2353	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 519	 0.00182	 0.01356	 0.0	 2309	 2309	 2309	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 6443	 0.002531	 0.015919	 0.0	 533.0	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 6749	 0.00289	 0.015969	 0.0	 419.0	 1947	 1947	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 4947	 0.001771	 0.01107	 0.0	 400.0	 2818	 2818	 0.0	 0.0	 1	 -30.0	 30.0;
	4204	 4947	 0.007969	 0.04238	 0.0	 733	 733	 733	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 7191	 0.00013	 0.00062	 0.0	 495.0	 49864	 49864	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 284	 0.0002	 0.00201	 0.0	 572.0	 15638	 15638	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 9159	 0.00095	 0.01024	 0.0	 1349.0	 3072	 3072	 0.0	 0.0	 1	 -30.0	 30.0;
	1133	 9159	 0.00553	 0.04909	 0.0	 640	 640	 640	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 6499	 0.009229	 0.03693	 0.0	 438.0	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 6499	 0.00451	 0.028469	 0.0	 438.0	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 6038	 0.003591	 0.01906	 0.0	 400.0	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 7398	 0.010159	 0.05169	 0.0	 495.0	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	75	 2126	 0.00039	 0.003099	 0.0	 10113	 10113	 10113	 0.0	 0.0	 1	 -30.0	 30.0;
	75	 6869	 0.000729	 0.0048	 0.0	 6507	 6507	 6507	 0.0	 0.0	 1	 -30.0	 30.0;
	7137	 6659	 0.00141	 0.01296	 0.0	 921.0	 2423	 2423	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 6745	 0.001969	 0.019229	 0.0	 1635	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 8953	 0.001081	 0.0105	 0.0	 2993	 2993	 2993	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 8953	 0.00105	 0.010711	 0.0	 2935	 2935	 2935	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 2849	 0.00052	 0.00449	 0.0	 1415.0	 6989	 6989	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 6397	 0.01024	 0.056349	 0.0	 476.0	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 1520	 0.004599	 0.023659	 0.0	 419.0	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 3233	 0.010021	 0.057409	 0.0	 438.0	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 3291	 0.00275	 0.01525	 0.0	 457.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 8240	 0.00107	 0.01122	 0.0	 1547.0	 2803	 2803	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 5884	 0.00242	 0.02336	 0.0	 1218.0	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 3587	 0.00165	 0.01303	 0.0	 823.0	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 3587	 0.00155	 0.01332	 0.0	 856.0	 2356	 2356	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 5970	 0.00087	 0.005469	 0.0	 5704	 5704	 5704	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 5970	 0.002281	 0.011909	 0.0	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 970	 0.00106	 0.01076	 0.0	 2922	 2922	 2922	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 5348	 0.001409	 0.01618	 0.0	 381.0	 1945	 1945	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 1909	 0.00306	 0.015521	 0.0	 457.0	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	3843	 8534	 0.000969	 0.006831	 0.0	 438.0	 4579	 4579	 0.0	 0.0	 1	 -30.0	 30.0;
	3843	 9039	 0.002531	 0.016961	 0.0	 533.0	 1842	 1842	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 257	 0.01207	 0.077901	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 6936	 0.014091	 0.080581	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 2946	 0.003289	 0.01481	 0.0	 2083	 2083	 2083	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 172	 0.003349	 0.0145	 0.0	 2123	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	8138	 3792	 0.005651	 0.026479	 0.0	 419.0	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	8138	 7659	 0.01193	 0.064669	 0.0	 457.0	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	6669	 5111	 0.004151	 0.017281	 0.0	 419.0	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 7145	 0.00213	 0.014091	 0.0	 2217	 2217	 2217	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 1894	 0.00113	 0.00651	 0.0	 419.0	 4781	 4781	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 1894	 0.001159	 0.00637	 0.0	 419.0	 4879	 4879	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 6456	 0.00611	 0.03288	 0.0	 457.0	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	8946	 849	 0.00012	 0.00156	 0.0	 1744.0	 20189	 20189	 0.0	 0.0	 1	 -30.0	 30.0;
	8946	 849	 0.00013	 0.00153	 0.0	 1645.0	 20572	 20572	 0.0	 0.0	 1	 -30.0	 30.0;
	8946	 6768	 0.00285	 0.03071	 0.0	 1025	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	5970	 2896	 0.00676	 0.03787	 0.0	 495.0	 822	 822	 0.0	 0.0	 1	 -30.0	 30.0;
	5970	 9049	 0.004461	 0.023521	 0.0	 438.0	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 618	 0.00064	 0.0078	 0.0	 1514.0	 4037	 4037	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 618	 0.00065	 0.00764	 0.0	 1514.0	 4120	 4120	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 579	 0.00066	 0.00602	 0.0	 1481.0	 5216	 5216	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 4442	 0.00149	 0.01224	 0.0	 889.0	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 814	 0.00061	 0.00582	 0.0	 1020.0	 5398	 5398	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 6904	 0.001461	 0.00744	 0.0	 4167	 4167	 4167	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 7820	 0.00386	 0.02406	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 7632	 0.00306	 0.01555	 0.0	 1994	 1994	 1994	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 7632	 0.003	 0.01586	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	3629	 4112	 0.003271	 0.020651	 0.0	 1511	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 7630	 0.000849	 0.00657	 0.0	 4769	 4769	 4769	 0.0	 0.0	 1	 -30.0	 30.0;
	1645	 3066	 0.000211	 0.001169	 0.0	 476.0	 26592	 26592	 0.0	 0.0	 1	 -30.0	 30.0;
	1645	 7973	 0.000469	 0.00345	 0.0	 495.0	 9073	 9073	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 7508	 0.00126	 0.0145	 0.0	 1382.0	 2171	 2171	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 5933	 0.008219	 0.04925	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 1769	 0.006771	 0.04132	 0.0	 438.0	 755	 755	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 7600	 0.000841	 0.004539	 0.0	 591.0	 6843	 6843	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 3792	 0.00701	 0.03161	 0.0	 476.0	 976	 976	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 6879	 0.000781	 0.004271	 0.0	 572.0	 7276	 7276	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 962	 0.00049	 0.0032	 0.0	 533.0	 9758	 9758	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 3813	 0.000331	 0.00199	 0.0	 629.0	 15658	 15658	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 3813	 0.00032	 0.002031	 0.0	 629.0	 15364	 15364	 0.0	 0.0	 1	 -30.0	 30.0;
	3813	 5500	 9.1e-05	 0.00057	 0.0	 476.0	 54724	 54724	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 869	 0.001651	 0.006789	 0.0	 533.0	 4521	 4521	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 3382	 0.001461	 0.007229	 0.0	 4283	 4283	 4283	 0.0	 0.0	 1	 -30.0	 30.0;
	8352	 9049	 0.00437	 0.023979	 0.0	 438.0	 1296	 1296	 0.0	 0.0	 1	 -30.0	 30.0;
	1869	 473	 0.00781	 0.04595	 0.0	 419.0	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	1869	 6243	 0.0015	 0.006531	 0.0	 457.0	 4714	 4714	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 9057	 0.001031	 0.006469	 0.0	 4823	 4823	 4823	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 3061	 0.00183	 0.01686	 0.0	 1119.0	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 618	 0.0002	 0.00294	 0.0	 1514.0	 10720	 10720	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 618	 0.00021	 0.00288	 0.0	 1316.0	 10939	 10939	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 5042	 0.00171	 0.01889	 0.0	 1283.0	 1666	 1666	 0.0	 0.0	 1	 -30.0	 30.0;
	8870	 2764	 0.00069	 0.00565	 0.0	 1185.0	 5550	 5550	 0.0	 0.0	 1	 -30.0	 30.0;
	8870	 2764	 0.0007	 0.00553	 0.0	 1382.0	 5667	 5667	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 4290	 0.00011	 0.00115	 0.0	 1119.0	 27343	 27343	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 6681	 0.00012	 0.00126	 0.0	 1316.0	 24957	 24957	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 8973	 0.00326	 0.02919	 0.0	 1076	 1076	 1076	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 5060	 0.00092	 0.00876	 0.0	 823.0	 3587	 3587	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 6932	 0.00087	 0.005409	 0.0	 457.0	 5766	 5766	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 6869	 0.00131	 0.00701	 0.0	 438.0	 4430	 4430	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 6656	 0.002531	 0.018781	 0.0	 1667	 1667	 1667	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 8729	 0.00894	 0.056909	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 5463	 0.00187	 0.010659	 0.0	 553.0	 2919	 2919	 0.0	 0.0	 1	 -30.0	 30.0;
	7685	 5463	 0.00286	 0.01538	 0.0	 610.0	 2020	 2020	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 4967	 0.0008	 0.00444	 0.0	 419.0	 7002	 7002	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 7875	 0.00545	 0.03936	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 7875	 0.00119	 0.009031	 0.0	 3468	 3468	 3468	 0.0	 0.0	 1	 -30.0	 30.0;
	51	 5670	 0.00295	 0.0162	 0.0	 419.0	 1919	 1919	 0.0	 0.0	 1	 -30.0	 30.0;
	51	 6174	 0.001581	 0.0087	 0.0	 514.0	 3573	 3573	 0.0	 0.0	 1	 -30.0	 30.0;
	51	 2517	 0.007729	 0.025401	 0.0	 591.0	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 3425	 0.00013	 0.001461	 0.0	 457.0	 21536	 21536	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 8658	 0.000341	 0.02219	 0.0	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 4011	 0.00018	 0.001211	 0.0	 591.0	 25801	 25801	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 9028	 0.003099	 0.0147	 0.0	 591.0	 2103	 2103	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 9028	 0.003159	 0.014401	 0.0	 533.0	 2143	 2143	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 4274	 0.00281	 0.01305	 0.0	 2367	 2367	 2367	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 8871	 0.002281	 0.01075	 0.0	 495.0	 2875	 2875	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 8871	 0.00232	 0.010521	 0.0	 457.0	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 3442	 0.000151	 0.000841	 0.0	 36969	 36969	 36969	 0.0	 0.0	 1	 -30.0	 30.0;
	6953	 2658	 0.002771	 0.012091	 0.0	 572.0	 2547	 2547	 0.0	 0.0	 1	 -30.0	 30.0;
	6953	 5592	 0.00613	 0.03005	 0.0	 457.0	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 7659	 0.003219	 0.02486	 0.0	 1261	 1261	 1261	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 8068	 0.000211	 0.001331	 0.0	 572.0	 23440	 23440	 0.0	 0.0	 1	 -30.0	 30.0;
	8504	 1898	 0.00185	 0.01917	 0.0	 1613.0	 1641	 1641	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 869	 0.00082	 0.00381	 0.0	 572.0	 8106	 8106	 0.0	 0.0	 1	 -30.0	 30.0;
	9043	 7819	 0.00075	 0.004531	 0.0	 381.0	 6878	 6878	 0.0	 0.0	 1	 -30.0	 30.0;
	9043	 7819	 0.000729	 0.00419	 0.0	 419.0	 7428	 7428	 0.0	 0.0	 1	 -30.0	 30.0;
	9043	 32	 0.02626	 0.15576	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	9043	 7423	 0.011469	 0.03937	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	7139	 8186	 0.00011	 0.00061	 0.0	 514.0	 50961	 50961	 0.0	 0.0	 1	 -30.0	 30.0;
	7139	 1065	 0.000531	 0.00313	 0.0	 381.0	 9950	 9950	 0.0	 0.0	 1	 -30.0	 30.0;
	7139	 6134	 0.001211	 0.00864	 0.0	 3621	 3621	 3621	 0.0	 0.0	 1	 -30.0	 30.0;
	4336	 4651	 0.00094	 0.006289	 0.0	 4968	 4968	 4968	 0.0	 0.0	 1	 -30.0	 30.0;
	731	 4020	 0.001	 0.00886	 0.0	 823.0	 3543	 3543	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 3178	 0.001979	 0.010469	 0.0	 514.0	 2965	 2965	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 3178	 0.0017	 0.00855	 0.0	 553.0	 3624	 3624	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 2116	 0.00757	 0.04624	 0.0	 419.0	 675	 675	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 7283	 0.001719	 0.00794	 0.0	 495.0	 3889	 3889	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 7283	 0.00176	 0.007781	 0.0	 3960	 3960	 3960	 0.0	 0.0	 1	 -30.0	 30.0;
	3157	 916	 0.00126	 0.0053	 0.0	 400.0	 5799	 5799	 0.0	 0.0	 1	 -30.0	 30.0;
	3157	 1241	 0.00444	 0.022789	 0.0	 419.0	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 2437	 0.00163	 0.0145	 0.0	 1086.0	 2165	 2165	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 257	 0.003281	 0.02124	 0.0	 495.0	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 7283	 0.004979	 0.025271	 0.0	 476.0	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	8858	 2403	 0.0072	 0.055289	 0.0	 495.0	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	8858	 4772	 0.00787	 0.04582	 0.0	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	8858	 4016	 0.003961	 0.017711	 0.0	 1741	 1741	 1741	 0.0	 0.0	 1	 -30.0	 30.0;
	2403	 6797	 0.00756	 0.04826	 0.0	 457.0	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	6192	 8207	 0.003401	 0.02086	 0.0	 457.0	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	6192	 3937	 0.001341	 0.00669	 0.0	 419.0	 4630	 4630	 0.0	 0.0	 1	 -30.0	 30.0;
	7669	 8867	 6e-05	 0.000581	 0.0	 438.0	 54080	 54080	 0.0	 0.0	 1	 -30.0	 30.0;
	7669	 5948	 9.1e-05	 0.00074	 0.0	 514.0	 42367	 42367	 0.0	 0.0	 1	 -30.0	 30.0;
	7392	 8939	 0.000531	 0.00175	 0.0	 17273	 17273	 17273	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 5096	 0.00116	 0.01159	 0.0	 1382.0	 2712	 2712	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 4315	 0.00038	 0.00457	 0.0	 1613.0	 6889	 6889	 0.0	 0.0	 1	 -30.0	 30.0;
	3066	 7973	 0.000729	 0.00405	 0.0	 553.0	 7676	 7676	 0.0	 0.0	 1	 -30.0	 30.0;
	264	 7064	 0.000331	 0.001919	 0.0	 16221	 16221	 16221	 0.0	 0.0	 1	 -30.0	 30.0;
	2188	 4706	 0.00086	 0.01029	 0.0	 1909.0	 3060	 3060	 0.0	 0.0	 1	 -30.0	 30.0;
	7428	 2188	 0.00027	 0.00332	 0.0	 1711.0	 9483	 9483	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 5681	 0.00012	 0.00156	 0.0	 20189	 20189	 20189	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 5681	 0.00012	 0.001531	 0.0	 20569	 20569	 20569	 0.0	 0.0	 1	 -30.0	 30.0;
	8756	 2060	 0.00256	 0.014211	 0.0	 2188	 2188	 2188	 0.0	 0.0	 1	 -30.0	 30.0;
	8756	 8419	 0.00049	 0.00338	 0.0	 9249	 9249	 9249	 0.0	 0.0	 1	 -30.0	 30.0;
	6009	 1430	 0.007531	 0.04444	 0.0	 400.0	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	6009	 5592	 0.007409	 0.03226	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	3150	 8147	 0.001789	 0.012841	 0.0	 2437	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	3150	 4096	 0.001831	 0.01257	 0.0	 2487	 2487	 2487	 0.0	 0.0	 1	 -30.0	 30.0;
	1632	 3621	 0.000169	 0.00143	 0.0	 21937	 21937	 21937	 0.0	 0.0	 1	 -30.0	 30.0;
	1632	 6869	 0.00088	 0.005099	 0.0	 610.0	 6105	 6105	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 7460	 0.0004	 0.00479	 0.0	 1678.0	 6572	 6572	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 7460	 0.00052	 0.00481	 0.0	 1744.0	 6529	 6529	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 7929	 0.00135	 0.01431	 0.0	 1744.0	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 814	 0.00051	 0.00549	 0.0	 1481.0	 5729	 5729	 0.0	 0.0	 1	 -30.0	 30.0;
	699	 6882	 0.00105	 0.007969	 0.0	 476.0	 3930	 3930	 0.0	 0.0	 1	 -30.0	 30.0;
	699	 947	 0.00339	 0.020531	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	699	 2951	 0.00169	 0.009331	 0.0	 3332	 3332	 3332	 0.0	 0.0	 1	 -30.0	 30.0;
	3584	 4177	 0.00374	 0.01905	 0.0	 438.0	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	3584	 5276	 0.00487	 0.026341	 0.0	 533.0	 1180	 1180	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 8301	 0.00057	 0.004581	 0.0	 6843	 6843	 6843	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 8582	 0.000409	 0.00301	 0.0	 10399	 10399	 10399	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 3754	 9.1e-05	 0.00076	 0.0	 419.0	 41268	 41268	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 6179	 0.003919	 0.01682	 0.0	 476.0	 1829	 1829	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 1060	 0.00117	 0.0131	 0.0	 1514.0	 2402	 2402	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 4954	 0.008271	 0.02787	 0.0	 495.0	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 1121	 0.016599	 0.0572	 0.0	 419.0	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 7861	 0.00999	 0.057	 0.0	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 7861	 0.01132	 0.05586	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	7303	 4690	 4e-05	 0.00045	 0.0	 921.0	 69919	 69919	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 8534	 0.003281	 0.01038	 0.0	 495.0	 2902	 2902	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 72	 0.003711	 0.01725	 0.0	 457.0	 1791	 1791	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 6333	 0.00069	 0.00232	 0.0	 457.0	 13051	 13051	 0.0	 0.0	 1	 -30.0	 30.0;
	8702	 4948	 0.004151	 0.02436	 0.0	 514.0	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 4948	 0.006781	 0.028729	 0.0	 476.0	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 6869	 0.000331	 0.00151	 0.0	 438.0	 20434	 20434	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 6869	 0.000331	 0.001479	 0.0	 629.0	 20842	 20842	 0.0	 0.0	 1	 -30.0	 30.0;
	3687	 5877	 0.0001	 0.00144	 0.0	 1514.0	 21883	 21883	 0.0	 0.0	 1	 -30.0	 30.0;
	3687	 5919	 0.00027	 0.00221	 0.0	 1053.0	 14188	 14188	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 4588	 0.0001	 0.00141	 0.0	 1711.0	 22347	 22347	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 2764	 0.00054	 0.00546	 0.0	 1448.0	 5758	 5758	 0.0	 0.0	 1	 -30.0	 30.0;
	7428	 5877	 7e-05	 0.00053	 0.0	 1382.0	 59086	 59086	 0.0	 0.0	 1	 -30.0	 30.0;
	4588	 7428	 6e-05	 0.0006	 0.0	 1481.0	 52385	 52385	 0.0	 0.0	 1	 -30.0	 30.0;
	8939	 4371	 0.000341	 0.00245	 0.0	 12770	 12770	 12770	 0.0	 0.0	 1	 -30.0	 30.0;
	8939	 7820	 0.000841	 0.006719	 0.0	 4665	 4665	 4665	 0.0	 0.0	 1	 -30.0	 30.0;
	6209	 7191	 0.000401	 0.00164	 0.0	 476.0	 18710	 18710	 0.0	 0.0	 1	 -30.0	 30.0;
	519	 7349	 0.004409	 0.032531	 0.0	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 7877	 0.001961	 0.013581	 0.0	 381.0	 2302	 2302	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 4890	 0.006659	 0.03437	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	4062	 1599	 9.1e-05	 0.0007	 0.0	 44749	 44749	 44749	 0.0	 0.0	 1	 -30.0	 30.0;
	4062	 8079	 0.00051	 0.004211	 0.0	 7447	 7447	 7447	 0.0	 0.0	 1	 -30.0	 30.0;
	6841	 8936	 0.00043	 0.0027	 0.0	 11554	 11554	 11554	 0.0	 0.0	 1	 -30.0	 30.0;
	6841	 2564	 0.00038	 0.00306	 0.0	 10244	 10244	 10244	 0.0	 0.0	 1	 -30.0	 30.0;
	8710	 1491	 0.001461	 0.009479	 0.0	 3294	 3294	 3294	 0.0	 0.0	 1	 -30.0	 30.0;
	8710	 7406	 0.001841	 0.011081	 0.0	 514.0	 2813	 2813	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 7504	 0.00094	 0.007169	 0.0	 553.0	 4369	 4369	 0.0	 0.0	 1	 -30.0	 30.0;
	6039	 8034	 0.00082	 0.00846	 0.0	 1415.0	 3717	 3717	 0.0	 0.0	 1	 -30.0	 30.0;
	6039	 7428	 0.00029	 0.00325	 0.0	 1711.0	 9681	 9681	 0.0	 0.0	 1	 -30.0	 30.0;
	7973	 7475	 0.000781	 0.0062	 0.0	 5055	 5055	 5055	 0.0	 0.0	 1	 -30.0	 30.0;
	7973	 2740	 8.1e-05	 0.00187	 0.0	 495.0	 16876	 16876	 0.0	 0.0	 1	 -30.0	 30.0;
	7973	 2297	 8.1e-05	 0.001909	 0.0	 419.0	 16532	 16532	 0.0	 0.0	 1	 -30.0	 30.0;
	6877	 1060	 0.00113	 0.00956	 0.0	 1185.0	 3282	 3282	 0.0	 0.0	 1	 -30.0	 30.0;
	6877	 1060	 0.00115	 0.00935	 0.0	 1218.0	 3354	 3354	 0.0	 0.0	 1	 -30.0	 30.0;
	8981	 4428	 0.00161	 0.02036	 0.0	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	8981	 4428	 0.00157	 0.02075	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 3728	 0.00101	 0.007401	 0.0	 533.0	 4229	 4229	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 7463	 0.00087	 0.00711	 0.0	 476.0	 4410	 4410	 0.0	 0.0	 1	 -30.0	 30.0;
	3582	 5919	 0.00135	 0.01442	 0.0	 1349.0	 2181	 2181	 0.0	 0.0	 1	 -30.0	 30.0;
	3582	 2096	 0.00176	 0.01441	 0.0	 1777.0	 2176	 2176	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 7349	 0.00682	 0.03187	 0.0	 419.0	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	8034	 1399	 0.00109	 0.00987	 0.0	 1185.0	 3181	 3181	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 8034	 0.00273	 0.02829	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 7845	 0.001581	 0.011289	 0.0	 400.0	 2772	 2772	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 3427	 0.001669	 0.013099	 0.0	 2393	 2393	 2393	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 1599	 9.9e-05	 0.00069	 0.0	 495.0	 45315	 45315	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 8079	 9.9e-05	 0.000669	 0.0	 514.0	 46708	 46708	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 3736	 0.000591	 0.00382	 0.0	 8172	 8172	 8172	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 7632	 0.00524	 0.02276	 0.0	 1353	 1353	 1353	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 6625	 0.002719	 0.01143	 0.0	 2689	 2689	 2689	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 8561	 0.00294	 0.02744	 0.0	 954.0	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 7395	 0.0011	 0.01339	 0.0	 1020.0	 2352	 2352	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 5873	 0.00193	 0.01695	 0.0	 1349.0	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 4843	 0.00134	 0.01054	 0.0	 1020.0	 2973	 2973	 0.0	 0.0	 1	 -30.0	 30.0;
	6092	 739	 0.00245	 0.02064	 0.0	 1382.0	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 6717	 0.001841	 0.00901	 0.0	 457.0	 3435	 3435	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 6717	 0.00187	 0.00882	 0.0	 495.0	 3504	 3504	 0.0	 0.0	 1	 -30.0	 30.0;
	8337	 807	 0.00197	 0.02312	 0.0	 1283.0	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	2235	 7395	 0.00078	 0.00887	 0.0	 1382.0	 3548	 3548	 0.0	 0.0	 1	 -30.0	 30.0;
	8512	 5435	 0.003771	 0.0288	 0.0	 438.0	 1088	 1088	 0.0	 0.0	 1	 -30.0	 30.0;
	8512	 4658	 0.000909	 0.00737	 0.0	 457.0	 4254	 4254	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 7460	 0.00086	 0.00783	 0.0	 1744.0	 4011	 4011	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 7460	 0.00095	 0.00855	 0.0	 1547.0	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	299	 7460	 0.00012	 0.00157	 0.0	 1843.0	 20061	 20061	 0.0	 0.0	 1	 -30.0	 30.0;
	299	 7460	 0.00013	 0.00154	 0.0	 757.0	 20439	 20439	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 6456	 0.00089	 0.004771	 0.0	 533.0	 6509	 6509	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 6394	 0.002	 0.00881	 0.0	 553.0	 3497	 3497	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 7075	 0.007711	 0.035331	 0.0	 874	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 6936	 0.005919	 0.030419	 0.0	 495.0	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 2946	 0.0053	 0.031719	 0.0	 591.0	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 1969	 0.00025	 0.001289	 0.0	 24058	 24058	 24058	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 2116	 0.0062	 0.040039	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 5464	 0.0008	 0.00707	 0.0	 1514.0	 4440	 4440	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 4957	 0.0002	 0.00207	 0.0	 954.0	 15189	 15189	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 4446	 0.00036	 0.00322	 0.0	 1053.0	 9749	 9749	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 6090	 0.0023	 0.0157	 0.0	 381.0	 1991	 1991	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 4204	 0.003479	 0.021159	 0.0	 419.0	 1474	 1474	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 3428	 0.00107	 0.01013	 0.0	 1382.0	 3101	 3101	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 6836	 0.00025	 0.000909	 0.0	 514.0	 33506	 33506	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 5892	 0.00037	 0.00188	 0.0	 438.0	 16486	 16486	 0.0	 0.0	 1	 -30.0	 30.0;
	9201	 3937	 0.0003	 0.00145	 0.0	 419.0	 21333	 21333	 0.0	 0.0	 1	 -30.0	 30.0;
	9201	 3692	 0.001419	 0.007539	 0.0	 476.0	 4118	 4118	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 266	 0.0012	 0.0122	 0.0	 1251.0	 2577	 2577	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 2566	 0.00397	 0.02936	 0.0	 1067	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 8806	 0.00092	 0.01112	 0.0	 1185.0	 2831	 2831	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 7428	 0.00387	 0.0452	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 1280	 0.00432	 0.03156	 0.0	 992	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 1133	 0.00407	 0.03937	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 1133	 0.00415	 0.03856	 0.0	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 5111	 0.00869	 0.05343	 0.0	 572.0	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 2172	 0.0068	 0.036961	 0.0	 457.0	 841	 841	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 2658	 0.01805	 0.095469	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	7600	 7283	 0.00045	 0.00206	 0.0	 533.0	 14981	 14981	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 7193	 0.0095	 0.037159	 0.0	 419.0	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 5025	 0.02106	 0.0885	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	7395	 5873	 0.00157	 0.02318	 0.0	 1360	 1360	 1360	 0.0	 0.0	 1	 -30.0	 30.0;
	7395	 3662	 0.00032	 0.00282	 0.0	 1711.0	 11130	 11130	 0.0	 0.0	 1	 -30.0	 30.0;
	7395	 4931	 0.00165	 0.01605	 0.0	 889.0	 1958	 1958	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 489	 0.00107	 0.00714	 0.0	 400.0	 4376	 4376	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 489	 0.000961	 0.00555	 0.0	 400.0	 5608	 5608	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 8529	 0.00074	 0.00461	 0.0	 6766	 6766	 6766	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 7064	 0.00076	 0.00451	 0.0	 6907	 6907	 6907	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 4058	 0.001419	 0.01093	 0.0	 533.0	 2866	 2866	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 4658	 0.003729	 0.024599	 0.0	 476.0	 1270	 1270	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 7029	 0.00233	 0.01992	 0.0	 1575	 1575	 1575	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 7029	 0.00238	 0.01949	 0.0	 1609	 1609	 1609	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 4795	 0.00217	 0.0253	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 4795	 0.00212	 0.02579	 0.0	 1221	 1221	 1221	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 1133	 0.00458	 0.04138	 0.0	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 550	 0.01555	 0.089841	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	6299	 3792	 0.00274	 0.0168	 0.0	 476.0	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 6879	 0.005831	 0.032211	 0.0	 438.0	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 4181	 0.006669	 0.031341	 0.0	 476.0	 986	 986	 0.0	 0.0	 1	 -30.0	 30.0;
	8702	 5163	 0.01081	 0.0538	 0.0	 476.0	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	8702	 7861	 0.005581	 0.02457	 0.0	 495.0	 1254	 1254	 0.0	 0.0	 1	 -30.0	 30.0;
	8702	 7861	 0.00569	 0.024039	 0.0	 533.0	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 7446	 0.002081	 0.01294	 0.0	 457.0	 2411	 2411	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 4897	 0.001599	 0.00919	 0.0	 3387	 3387	 3387	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 5873	 0.00083	 0.00768	 0.0	 1744.0	 4090	 4090	 0.0	 0.0	 1	 -30.0	 30.0;
	8438	 8147	 0.004979	 0.024099	 0.0	 1284	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	8438	 8147	 0.005081	 0.023591	 0.0	 476.0	 1309	 1309	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 266	 0.00412	 0.03917	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	266	 4843	 0.00086	 0.00798	 0.0	 1119.0	 3936	 3936	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 266	 0.00087	 0.00961	 0.0	 1218.0	 3274	 3274	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 266	 0.00095	 0.01034	 0.0	 1251.0	 3043	 3043	 0.0	 0.0	 1	 -30.0	 30.0;
	8374	 266	 0.00211	 0.0196	 0.0	 1119.0	 1603	 1603	 0.0	 0.0	 1	 -30.0	 30.0;
	7193	 5025	 0.00963	 0.05281	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 3734	 0.00018	 0.001349	 0.0	 553.0	 23210	 23210	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 6456	 0.000961	 0.006021	 0.0	 381.0	 5181	 5181	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 6456	 0.000979	 0.00589	 0.0	 381.0	 5291	 5291	 0.0	 0.0	 1	 -30.0	 30.0;
	7877	 3063	 0.000461	 0.002729	 0.0	 610.0	 11413	 11413	 0.0	 0.0	 1	 -30.0	 30.0;
	986	 3367	 0.005039	 0.01901	 0.0	 381.0	 1607	 1607	 0.0	 0.0	 1	 -30.0	 30.0;
	986	 4603	 0.00812	 0.028919	 0.0	 419.0	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	7257	 6970	 0.00106	 0.01005	 0.0	 954.0	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	5873	 6768	 0.00074	 0.0081	 0.0	 1218.0	 3884	 3884	 0.0	 0.0	 1	 -30.0	 30.0;
	8147	 6174	 0.012961	 0.03605	 0.0	 825	 825	 825	 0.0	 0.0	 1	 -30.0	 30.0;
	8147	 6174	 0.00844	 0.0378	 0.0	 400.0	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	8147	 5162	 0.000591	 0.004169	 0.0	 553.0	 7502	 7502	 0.0	 0.0	 1	 -30.0	 30.0;
	6879	 6038	 0.003091	 0.012289	 0.0	 457.0	 2493	 2493	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 4592	 0.000969	 0.0053	 0.0	 553.0	 5863	 5863	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 2686	 0.00161	 0.012919	 0.0	 2427	 2427	 2427	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 2686	 0.003219	 0.01795	 0.0	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 3644	 0.004331	 0.025	 0.0	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 3644	 0.004409	 0.02445	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 2551	 0.00425	 0.02014	 0.0	 1535	 1535	 1535	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 6904	 0.009531	 0.060979	 0.0	 495.0	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 1897	 0.002409	 0.0135	 0.0	 2304	 2304	 2304	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 8210	 0.0006	 0.00662	 0.0	 1678.0	 4753	 4753	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 2849	 0.00173	 0.01701	 0.0	 1678.0	 1848	 1848	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 1173	 0.004289	 0.018531	 0.0	 438.0	 1661	 1661	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 6936	 0.006919	 0.039789	 0.0	 419.0	 783	 783	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 6936	 0.007591	 0.035539	 0.0	 495.0	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 4750	 0.00961	 0.05225	 0.0	 419.0	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 6544	 0.000581	 0.004599	 0.0	 6815	 6815	 6815	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 6544	 0.00057	 0.00469	 0.0	 6686	 6686	 6686	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 6544	 0.00087	 0.003159	 0.0	 591.0	 9641	 9641	 0.0	 0.0	 1	 -30.0	 30.0;
	6436	 5217	 0.00018	 0.001419	 0.0	 22084	 22084	 22084	 0.0	 0.0	 1	 -30.0	 30.0;
	6436	 6717	 0.00195	 0.018841	 0.0	 1668	 1668	 1668	 0.0	 0.0	 1	 -30.0	 30.0;
	72	 6093	 0.00293	 0.01293	 0.0	 400.0	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 3233	 0.001969	 0.010599	 0.0	 438.0	 2931	 2931	 0.0	 0.0	 1	 -30.0	 30.0;
	6985	 854	 3.9e-05	 0.000591	 0.0	 53332	 53332	 53332	 0.0	 0.0	 1	 -30.0	 30.0;
	6985	 415	 0.00364	 0.02431	 0.0	 1286	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	6985	 1501	 0.00114	 0.007211	 0.0	 4327	 4327	 4327	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 4238	 0.001271	 0.008659	 0.0	 381.0	 3610	 3610	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 1411	 0.00105	 0.00668	 0.0	 4672	 4672	 4672	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 6681	 0.00011	 0.00122	 0.0	 987.0	 25787	 25787	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 3587	 0.00117	 0.0124	 0.0	 1349.0	 2537	 2537	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 8374	 0.00168	 0.01891	 0.0	 1185.0	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 7819	 0.00132	 0.008281	 0.0	 572.0	 3767	 3767	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 8378	 0.004531	 0.01924	 0.0	 1599	 1599	 1599	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 1241	 0.007841	 0.041909	 0.0	 419.0	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 7755	 0.00113	 0.01235	 0.0	 1777.0	 2548	 2548	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 7755	 0.00128	 0.0121	 0.0	 1744.0	 2597	 2597	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 8625	 0.0015	 0.01792	 0.0	 1415.0	 1757	 1757	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 1471	 0.00111	 0.005281	 0.0	 5854	 5854	 5854	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 1471	 0.00113	 0.005169	 0.0	 5970	 5970	 5970	 0.0	 0.0	 1	 -30.0	 30.0;
	6040	 3111	 0.00563	 0.03255	 0.0	 476.0	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	1175	 3111	 0.005289	 0.022539	 0.0	 1365	 1365	 1365	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 6239	 0.007159	 0.05086	 0.0	 400.0	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 3689	 0.009669	 0.05649	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 6179	 0.0092	 0.052169	 0.0	 553.0	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 5091	 0.00197	 0.01594	 0.0	 1316.0	 1967	 1967	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 8806	 0.00343	 0.02573	 0.0	 1217	 1217	 1217	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 8247	 0.00151	 0.01485	 0.0	 1185.0	 2117	 2117	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 5060	 0.00092	 0.01042	 0.0	 1020.0	 3020	 3020	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 8012	 0.00029	 0.00336	 0.0	 1547.0	 9367	 9367	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 4489	 0.001711	 0.01255	 0.0	 2494	 2494	 2494	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 1503	 0.005	 0.03962	 0.0	 553.0	 791	 791	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 1168	 0.0014	 0.01687	 0.0	 1251.0	 1866	 1866	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 1168	 0.00067	 0.00678	 0.0	 1942.0	 4637	 4637	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 1168	 0.00065	 0.00692	 0.0	 1678.0	 4545	 4545	 0.0	 0.0	 1	 -30.0	 30.0;
	6092	 849	 0.00137	 0.01524	 0.0	 1218.0	 2065	 2065	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 686	 0.00424	 0.02376	 0.0	 1309	 1309	 1309	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 5821	 0.005591	 0.031711	 0.0	 476.0	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 2225	 0.00138	 0.00649	 0.0	 419.0	 4761	 4761	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 2225	 0.00107	 0.00544	 0.0	 514.0	 5698	 5698	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 4390	 3e-05	 0.00041	 0.0	 1777.0	 76837	 76837	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 4390	 3e-05	 0.00041	 0.0	 1613.0	 76837	 76837	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 4957	 0.00044	 0.00342	 0.0	 1316.0	 9161	 9161	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 2504	 0.003841	 0.01737	 0.0	 438.0	 1776	 1776	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 1912	 0.001771	 0.01337	 0.0	 495.0	 2343	 2343	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 2658	 0.00139	 0.007349	 0.0	 533.0	 4224	 4224	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 5592	 0.00625	 0.03463	 0.0	 533.0	 898	 898	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 4360	 0.00055	 0.00255	 0.0	 12109	 12109	 12109	 0.0	 0.0	 1	 -30.0	 30.0;
	6596	 3512	 0.00489	 0.043331	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	8701	 8207	 0.00145	 0.013099	 0.0	 381.0	 2397	 2397	 0.0	 0.0	 1	 -30.0	 30.0;
	8701	 1271	 0.004039	 0.02881	 0.0	 1086	 1086	 1086	 0.0	 0.0	 1	 -30.0	 30.0;
	2236	 4967	 0.002219	 0.00988	 0.0	 438.0	 3120	 3120	 0.0	 0.0	 1	 -30.0	 30.0;
	8575	 7845	 0.001919	 0.0153	 0.0	 400.0	 2049	 2049	 0.0	 0.0	 1	 -30.0	 30.0;
	8664	 1399	 0.00189	 0.01319	 0.0	 1382.0	 2371	 2371	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 8936	 0.00011	 0.000659	 0.0	 495.0	 47279	 47279	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 2564	 0.00011	 0.00064	 0.0	 457.0	 48642	 48642	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 3027	 0.000211	 0.00111	 0.0	 27957	 27957	 27957	 0.0	 0.0	 1	 -30.0	 30.0;
	6836	 6209	 0.000469	 0.001669	 0.0	 400.0	 18221	 18221	 0.0	 0.0	 1	 -30.0	 30.0;
	5923	 854	 6e-05	 0.000849	 0.0	 37113	 37113	 37113	 0.0	 0.0	 1	 -30.0	 30.0;
	7137	 7310	 0.00051	 0.00597	 0.0	 1580.0	 5272	 5272	 0.0	 0.0	 1	 -30.0	 30.0;
	7137	 6970	 0.00119	 0.01087	 0.0	 1218.0	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 7137	 0.00219	 0.01922	 0.0	 1382.0	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	5919	 2764	 0.00051	 0.00465	 0.0	 1580.0	 6753	 6753	 0.0	 0.0	 1	 -30.0	 30.0;
	8871	 8819	 0.00055	 0.0067	 0.0	 4699	 4699	 4699	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 5329	 0.005099	 0.027349	 0.0	 553.0	 1136	 1136	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 2844	 0.000599	 0.003961	 0.0	 476.0	 7885	 7885	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 3291	 0.005461	 0.032719	 0.0	 476.0	 953	 953	 0.0	 0.0	 1	 -30.0	 30.0;
	8149	 2896	 0.00349	 0.02256	 0.0	 476.0	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	8149	 1802	 0.00132	 0.00861	 0.0	 400.0	 3627	 3627	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 440	 0.0045	 0.01838	 0.0	 1670	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 1391	 0.004289	 0.019719	 0.0	 400.0	 1566	 1566	 0.0	 0.0	 1	 -30.0	 30.0;
	8236	 3027	 0.001409	 0.00881	 0.0	 495.0	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 6607	 0.00212	 0.01857	 0.0	 1415.0	 1691	 1691	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 7673	 0.00049	 0.00574	 0.0	 1613.0	 5484	 5484	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 754	 0.00184	 0.021	 0.0	 1499	 1499	 1499	 0.0	 0.0	 1	 -30.0	 30.0;
	2686	 4773	 0.00593	 0.037409	 0.0	 419.0	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	2225	 4177	 0.00514	 0.024169	 0.0	 438.0	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	3798	 2913	 0.00041	 0.00492	 0.0	 1251.0	 6399	 6399	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 2913	 0.00296	 0.02677	 0.0	 1173	 1173	 1173	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 550	 0.0072	 0.03406	 0.0	 381.0	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 6949	 0.00043	 0.00276	 0.0	 419.0	 11309	 11309	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 9028	 0.001789	 0.013469	 0.0	 533.0	 2325	 2325	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 7406	 0.00163	 0.011091	 0.0	 457.0	 2818	 2818	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 6349	 0.00036	 0.002651	 0.0	 11807	 11807	 11807	 0.0	 0.0	 1	 -30.0	 30.0;
	8867	 15	 0.00013	 0.00132	 0.0	 514.0	 23815	 23815	 0.0	 0.0	 1	 -30.0	 30.0;
	8867	 284	 0.000169	 0.001659	 0.0	 457.0	 18942	 18942	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 8534	 0.00136	 0.012831	 0.0	 2449	 2449	 2449	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 8534	 0.00139	 0.01256	 0.0	 2500	 2500	 2500	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 5276	 0.00126	 0.009521	 0.0	 3289	 3289	 3289	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 5276	 0.00143	 0.009331	 0.0	 3347	 3347	 3347	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 4428	 0.00164	 0.012961	 0.0	 2418	 2418	 2418	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 4428	 0.001599	 0.012	 0.0	 2610	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	6936	 2957	 0.001271	 0.00524	 0.0	 438.0	 5859	 5859	 0.0	 0.0	 1	 -30.0	 30.0;
	8240	 8973	 0.00226	 0.02465	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	6543	 3715	 0.00032	 0.0015	 0.0	 514.0	 20595	 20595	 0.0	 0.0	 1	 -30.0	 30.0;
	6543	 5948	 0.00032	 0.00112	 0.0	 419.0	 27118	 27118	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 4931	 0.00075	 0.00817	 0.0	 1053.0	 3851	 3851	 0.0	 0.0	 1	 -30.0	 30.0;
	8163	 3425	 0.00037	 0.0027	 0.0	 553.0	 11591	 11591	 0.0	 0.0	 1	 -30.0	 30.0;
	3425	 6783	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	2172	 595	 0.012781	 0.05762	 0.0	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	8658	 1065	 0.00036	 0.001289	 0.0	 23603	 23603	 23603	 0.0	 0.0	 1	 -30.0	 30.0;
	6090	 1175	 0.006771	 0.039349	 0.0	 792	 792	 792	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 7673	 0.00292	 0.02831	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 2096	 0.00134	 0.01229	 0.0	 1514.0	 2556	 2556	 0.0	 0.0	 1	 -30.0	 30.0;
	8163	 5500	 0.00011	 0.00063	 0.0	 572.0	 49392	 49392	 0.0	 0.0	 1	 -30.0	 30.0;
	7249	 8207	 0.0003	 0.003331	 0.0	 9445	 9445	 9445	 0.0	 0.0	 1	 -30.0	 30.0;
	7249	 3692	 0.001289	 0.01555	 0.0	 2025	 2025	 2025	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 5923	 0.00011	 0.0017	 0.0	 553.0	 18543	 18543	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 8575	 0.00043	 0.00249	 0.0	 533.0	 12501	 12501	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 4657	 0.002651	 0.016771	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	3487	 1121	 0.0082	 0.025081	 0.0	 400.0	 1198	 1198	 0.0	 0.0	 1	 -30.0	 30.0;
	3442	 8819	 0.00037	 0.002781	 0.0	 591.0	 11260	 11260	 0.0	 0.0	 1	 -30.0	 30.0;
	4856	 4906	 0.010719	 0.054719	 0.0	 400.0	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 4906	 0.006469	 0.04074	 0.0	 400.0	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	5884	 8973	 0.00101	 0.01274	 0.0	 1283.0	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 5961	 9.1e-05	 0.05076	 0.0	 419.0	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 3629	 0.00588	 0.03938	 0.0	 457.0	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 3692	 0.003591	 0.022099	 0.0	 438.0	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 7630	 0.00555	 0.032521	 0.0	 958	 958	 958	 0.0	 0.0	 1	 -30.0	 30.0;
	6877	 7755	 0.00116	 0.01347	 0.0	 1514.0	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	6877	 7755	 0.00113	 0.01247	 0.0	 1547.0	 2523	 2523	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 179	 0.00107	 0.00871	 0.0	 954.0	 3600	 3600	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 4442	 0.00078	 0.00609	 0.0	 1382.0	 5145	 5145	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 6768	 0.00075	 0.00604	 0.0	 1119.0	 5190	 5190	 0.0	 0.0	 1	 -30.0	 30.0;
	4897	 6717	 0.00224	 0.011091	 0.0	 2792	 2792	 2792	 0.0	 0.0	 1	 -30.0	 30.0;
	7475	 6949	 0.001961	 0.013969	 0.0	 400.0	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 5162	 0.001271	 0.00761	 0.0	 476.0	 4095	 4095	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 8806	 0.00374	 0.03581	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 8806	 0.00385	 0.03284	 0.0	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 8806	 0.00392	 0.03216	 0.0	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 8973	 0.00307	 0.03131	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	7819	 32	 0.027	 0.131289	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	6333	 5512	 0.005539	 0.0195	 0.0	 1559	 1559	 1559	 0.0	 0.0	 1	 -30.0	 30.0;
	8534	 9039	 0.003099	 0.017849	 0.0	 495.0	 1744	 1744	 0.0	 0.0	 1	 -30.0	 30.0;
	8534	 5276	 0.002831	 0.014099	 0.0	 533.0	 2197	 2197	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 2261	 0.0	 0.01368	 0.0	 1580.0	 2310	 2310	 0.0	 0.0	 1	 -30.0	 30.0;
	4204	 4657	 0.01082	 0.079719	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	731	 2764	 0.00102	 0.00941	 0.0	 1251.0	 3338	 3338	 0.0	 0.0	 1	 -30.0	 30.0;
	731	 597	 0.00183	 0.01819	 0.0	 1728	 1728	 1728	 0.0	 0.0	 1	 -30.0	 30.0;
	731	 385	 0.00028	 0.00346	 0.0	 1251.0	 9100	 9100	 0.0	 0.0	 1	 -30.0	 30.0;
	3728	 2564	 0.0012	 0.00982	 0.0	 3193	 3193	 3193	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 2622	 0.00027	 0.0032	 0.0	 1810.0	 9837	 9837	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 7688	 0.00064	 0.00679	 0.0	 1152.0	 4632	 4632	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 8260	 0.00047	 0.00442	 0.0	 1711.0	 7107	 7107	 0.0	 0.0	 1	 -30.0	 30.0;
	415	 3367	 0.00493	 0.017599	 0.0	 495.0	 1729	 1729	 0.0	 0.0	 1	 -30.0	 30.0;
	415	 4081	 0.00207	 0.0153	 0.0	 2046	 2046	 2046	 0.0	 0.0	 1	 -30.0	 30.0;
	7287	 7755	 0.00094	 0.0092	 0.0	 1909.0	 3416	 3416	 0.0	 0.0	 1	 -30.0	 30.0;
	7287	 7755	 0.00095	 0.00901	 0.0	 1711.0	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	947	 2785	 0.00101	 0.00719	 0.0	 4351	 4351	 4351	 0.0	 0.0	 1	 -30.0	 30.0;
	3734	 6654	 0.000419	 0.00331	 0.0	 572.0	 9468	 9468	 0.0	 0.0	 1	 -30.0	 30.0;
	2551	 1897	 0.002099	 0.015599	 0.0	 2007	 2007	 2007	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 8664	 0.00163	 0.01283	 0.0	 1283.0	 2443	 2443	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 7428	 0.00445	 0.03788	 0.0	 829	 829	 829	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 4652	 0.00092	 0.00703	 0.0	 1218.0	 4456	 4456	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 32	 9.1e-05	 0.000961	 0.0	 32723	 32723	 32723	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 249	 0.00387	 0.028599	 0.0	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 5290	 0.00949	 0.06625	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 4467	 0.00414	 0.035331	 0.0	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 5290	 0.009781	 0.065581	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	1391	 32	 0.02818	 0.116099	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 2143	 0.00324	 0.01912	 0.0	 381.0	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 6768	 0.00135	 0.01609	 0.0	 1613.0	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 5670	 0.00294	 0.0182	 0.0	 438.0	 1714	 1714	 0.0	 0.0	 1	 -30.0	 30.0;
	8066	 5961	 0.000711	 0.00649	 0.0	 457.0	 4839	 4839	 0.0	 0.0	 1	 -30.0	 30.0;
	442	 8066	 0.002651	 0.01375	 0.0	 2256	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 5961	 0.00105	 0.008469	 0.0	 419.0	 3702	 3702	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 4489	 0.002229	 0.016461	 0.0	 495.0	 1902	 1902	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 4489	 0.002281	 0.01613	 0.0	 495.0	 1940	 1940	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 4489	 0.003341	 0.012651	 0.0	 2415	 2415	 2415	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 4489	 0.003271	 0.012901	 0.0	 2374	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	6484	 7918	 0.00101	 0.01218	 0.0	 1843.0	 2585	 2585	 0.0	 0.0	 1	 -30.0	 30.0;
	6484	 7436	 0.0009	 0.0095	 0.0	 3311	 3311	 3311	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 4690	 0.00098	 0.01241	 0.0	 2538	 2538	 2538	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 1942	 0.001219	 0.00951	 0.0	 3295	 3295	 3295	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 8419	 0.001789	 0.01382	 0.0	 2267	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 8419	 0.00175	 0.014081	 0.0	 2227	 2227	 2227	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 3382	 9.1e-05	 0.00087	 0.0	 36111	 36111	 36111	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 3382	 9.1e-05	 0.00086	 0.0	 36526	 36526	 36526	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 7869	 0.000229	 0.00236	 0.0	 400.0	 13322	 13322	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 5171	 0.00125	 0.00557	 0.0	 591.0	 5534	 5534	 0.0	 0.0	 1	 -30.0	 30.0;
	2172	 5191	 0.00757	 0.04013	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 179	 0.00157	 0.01604	 0.0	 1382.0	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 179	 0.00154	 0.01634	 0.0	 1283.0	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 2096	 0.00169	 0.02383	 0.0	 1323	 1323	 1323	 0.0	 0.0	 1	 -30.0	 30.0;
	1728	 179	 0.00068	 0.0089	 0.0	 1547.0	 3539	 3539	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 4603	 0.010289	 0.036651	 0.0	 476.0	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 4603	 0.00563	 0.03395	 0.0	 918	 918	 918	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 5726	 0.003591	 0.02763	 0.0	 1134	 1134	 1134	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 5726	 0.00351	 0.028159	 0.0	 1114	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 4773	 0.00143	 0.00838	 0.0	 3716	 3716	 3716	 0.0	 0.0	 1	 -30.0	 30.0;
	7659	 6879	 0.01213	 0.06156	 0.0	 476.0	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 5171	 0.004789	 0.022849	 0.0	 553.0	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 8242	 0.00019	 0.00211	 0.0	 457.0	 14910	 14910	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 8529	 0.000331	 0.002349	 0.0	 13316	 13316	 13316	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 8530	 9.1e-05	 0.000539	 0.0	 381.0	 57786	 57786	 0.0	 0.0	 1	 -30.0	 30.0;
	6496	 6607	 0.00088	 0.00776	 0.0	 1382.0	 4045	 4045	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 4706	 0.00039	 0.00368	 0.0	 8536	 8536	 8536	 0.0	 0.0	 1	 -30.0	 30.0;
	6656	 2091	 0.00275	 0.01268	 0.0	 400.0	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	6656	 8993	 0.00205	 0.00874	 0.0	 3519	 3519	 3519	 0.0	 0.0	 1	 -30.0	 30.0;
	6656	 1241	 0.00082	 0.00519	 0.0	 591.0	 6012	 6012	 0.0	 0.0	 1	 -30.0	 30.0;
	2658	 808	 0.00519	 0.02355	 0.0	 457.0	 1310	 1310	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 6749	 0.016711	 0.08874	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	7406	 4397	 0.005099	 0.022659	 0.0	 476.0	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	7406	 1769	 0.001469	 0.01213	 0.0	 591.0	 2586	 2586	 0.0	 0.0	 1	 -30.0	 30.0;
	7406	 1769	 0.001659	 0.01189	 0.0	 533.0	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 4467	 0.000521	 0.00374	 0.0	 419.0	 8366	 8366	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 5025	 0.006461	 0.048349	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 7310	 0.00293	 0.0257	 0.0	 1222	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 5608	 0.00178	 0.0157	 0.0	 1415.0	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 7918	 0.00115	 0.01332	 0.0	 1086.0	 2363	 2363	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 2202	 0.00078	 0.00752	 0.0	 1678.0	 4179	 4179	 0.0	 0.0	 1	 -30.0	 30.0;
	77	 6660	 3.9e-05	 0.00037	 0.0	 84901	 84901	 84901	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 8419	 0.0012	 0.006729	 0.0	 533.0	 4622	 4622	 0.0	 0.0	 1	 -30.0	 30.0;
	33	 3334	 0.000211	 0.001659	 0.0	 18888	 18888	 18888	 0.0	 0.0	 1	 -30.0	 30.0;
	6490	 8301	 0.001659	 0.011919	 0.0	 495.0	 2625	 2625	 0.0	 0.0	 1	 -30.0	 30.0;
	6490	 6869	 0.002	 0.0133	 0.0	 438.0	 2349	 2349	 0.0	 0.0	 1	 -30.0	 30.0;
	4371	 7820	 0.00105	 0.00837	 0.0	 3745	 3745	 3745	 0.0	 0.0	 1	 -30.0	 30.0;
	2896	 5348	 0.00138	 0.014979	 0.0	 2100	 2100	 2100	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 6836	 0.0	 0.0003	 0.0	 105292	 105292	 105292	 0.0	 0.0	 1	 -30.0	 30.0;
	2978	 6836	 0.0	 0.0003	 0.0	 419.0	 105292	 105292	 0.0	 0.0	 1	 -30.0	 30.0;
	2978	 5391	 0.00164	 0.00782	 0.0	 400.0	 3954	 3954	 0.0	 0.0	 1	 -30.0	 30.0;
	3629	 230	 0.007099	 0.04044	 0.0	 514.0	 770	 770	 0.0	 0.0	 1	 -30.0	 30.0;
	9039	 7861	 0.00181	 0.00914	 0.0	 572.0	 3391	 3391	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 7343	 0.00027	 0.00247	 0.0	 1942.0	 12713	 12713	 0.0	 0.0	 1	 -30.0	 30.0;
	7343	 4957	 0.00266	 0.03206	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 981	 0.000591	 0.005081	 0.0	 400.0	 6176	 6176	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 751	 0.002229	 0.016099	 0.0	 419.0	 1944	 1944	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 5372	 0.00205	 0.02585	 0.0	 1086.0	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	7821	 642	 0.00101	 0.0091	 0.0	 1316.0	 3450	 3450	 0.0	 0.0	 1	 -30.0	 30.0;
	7821	 5608	 0.001	 0.00871	 0.0	 1316.0	 3603	 3603	 0.0	 0.0	 1	 -30.0	 30.0;
	9097	 1513	 0.00112	 0.00895	 0.0	 3502	 3502	 3502	 0.0	 0.0	 1	 -30.0	 30.0;
	9097	 1513	 0.001099	 0.008289	 0.0	 3778	 3778	 3778	 0.0	 0.0	 1	 -30.0	 30.0;
	9097	 3125	 0.001289	 0.0095	 0.0	 3295	 3295	 3295	 0.0	 0.0	 1	 -30.0	 30.0;
	9097	 3125	 0.00126	 0.00968	 0.0	 3236	 3236	 3236	 0.0	 0.0	 1	 -30.0	 30.0;
	4315	 5464	 0.00065	 0.00723	 0.0	 1547.0	 4352	 4352	 0.0	 0.0	 1	 -30.0	 30.0;
	1942	 4095	 0.001781	 0.012669	 0.0	 2470	 2470	 2470	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 1074	 0.00086	 0.00956	 0.0	 1053.0	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 807	 0.00248	 0.02429	 0.0	 1283.0	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 4507	 0.00151	 0.01699	 0.0	 1316.0	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	5890	 3689	 0.003159	 0.01537	 0.0	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	8210	 3113	 0.00075	 0.00683	 0.0	 1349.0	 4598	 4598	 0.0	 0.0	 1	 -30.0	 30.0;
	8210	 2849	 0.00223	 0.02524	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	642	 5608	 0.00191	 0.0208	 0.0	 987.0	 1513	 1513	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 642	 0.00074	 0.00784	 0.0	 921.0	 4012	 4012	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 642	 0.00073	 0.00799	 0.0	 1086.0	 3937	 3937	 0.0	 0.0	 1	 -30.0	 30.0;
	1421	 3621	 0.000789	 0.00482	 0.0	 514.0	 6468	 6468	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 1421	 0.000789	 0.004409	 0.0	 381.0	 7053	 7053	 0.0	 0.0	 1	 -30.0	 30.0;
	2844	 3291	 0.005461	 0.03161	 0.0	 533.0	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	1638	 8575	 6e-05	 0.00087	 0.0	 36222	 36222	 36222	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 1411	 0.00593	 0.040961	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 5025	 0.003771	 0.030841	 0.0	 1017	 1017	 1017	 0.0	 0.0	 1	 -30.0	 30.0;
	6454	 8571	 0.00038	 0.001461	 0.0	 533.0	 20925	 20925	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 4081	 0.00149	 0.00938	 0.0	 3326	 3326	 3326	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 4081	 0.001521	 0.00918	 0.0	 3395	 3395	 3395	 0.0	 0.0	 1	 -30.0	 30.0;
	2091	 440	 0.00407	 0.015469	 0.0	 1975	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 1421	 0.00082	 0.006219	 0.0	 5036	 5036	 5036	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 1969	 0.00161	 0.00888	 0.0	 438.0	 3501	 3501	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 9028	 0.00118	 0.006461	 0.0	 514.0	 4810	 4810	 0.0	 0.0	 1	 -30.0	 30.0;
	8819	 6134	 0.00082	 0.009091	 0.0	 3461	 3461	 3461	 0.0	 0.0	 1	 -30.0	 30.0;
	751	 4493	 0.01893	 0.0848	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	751	 4493	 0.01313	 0.082409	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	751	 6344	 0.000281	 0.00149	 0.0	 20833	 20833	 20833	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 3113	 0.00019	 0.00199	 0.0	 1349.0	 15802	 15802	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 5289	 0.0002	 0.00188	 0.0	 1382.0	 16708	 16708	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 2946	 0.003159	 0.025331	 0.0	 1238	 1238	 1238	 0.0	 0.0	 1	 -30.0	 30.0;
	7685	 6394	 0.00445	 0.01886	 0.0	 610.0	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	5821	 5329	 0.00461	 0.02205	 0.0	 514.0	 1403	 1403	 0.0	 0.0	 1	 -30.0	 30.0;
	7283	 8213	 0.00061	 0.00494	 0.0	 6347	 6347	 6347	 0.0	 0.0	 1	 -30.0	 30.0;
	7283	 962	 0.00082	 0.00462	 0.0	 6732	 6732	 6732	 0.0	 0.0	 1	 -30.0	 30.0;
	3468	 8661	 0.000331	 0.003271	 0.0	 553.0	 9608	 9608	 0.0	 0.0	 1	 -30.0	 30.0;
	3468	 1769	 0.00056	 0.004081	 0.0	 591.0	 7669	 7669	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 9055	 0.00163	 0.007521	 0.0	 4105	 4105	 4105	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 1471	 0.001659	 0.00736	 0.0	 4187	 4187	 4187	 0.0	 0.0	 1	 -30.0	 30.0;
	6544	 1503	 0.00719	 0.049211	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	7463	 1969	 6e-05	 0.00039	 0.0	 438.0	 80052	 80052	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 6022	 0.00288	 0.018	 0.0	 533.0	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 8776	 0.00288	 0.0182	 0.0	 495.0	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 5290	 0.00111	 0.008531	 0.0	 438.0	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 4279	 0.00307	 0.022289	 0.0	 514.0	 1404	 1404	 0.0	 0.0	 1	 -30.0	 30.0;
	3067	 4507	 0.00091	 0.00868	 0.0	 1547.0	 3620	 3620	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 9117	 0.00098	 0.0118	 0.0	 1481.0	 2668	 2668	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 7436	 0.00053	 0.00591	 0.0	 1645.0	 5324	 5324	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 2202	 0.00086	 0.00991	 0.0	 1349.0	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	7002	 3334	 0.00545	 0.034099	 0.0	 495.0	 915	 915	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 3495	 0.00095	 0.006091	 0.0	 553.0	 5124	 5124	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 807	 0.00305	 0.0272	 0.0	 1155	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 4910	 0.000281	 0.001841	 0.0	 438.0	 16962	 16962	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 6456	 0.004531	 0.02451	 0.0	 1268	 1268	 1268	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 1503	 0.00618	 0.02961	 0.0	 533.0	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 6745	 0.00064	 0.004461	 0.0	 7010	 7010	 7010	 0.0	 0.0	 1	 -30.0	 30.0;
	916	 4224	 0.00143	 0.00513	 0.0	 553.0	 5932	 5932	 0.0	 0.0	 1	 -30.0	 30.0;
	916	 1241	 0.0052	 0.021841	 0.0	 457.0	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 4910	 0.00138	 0.008669	 0.0	 438.0	 3599	 3599	 0.0	 0.0	 1	 -30.0	 30.0;
	6456	 602	 0.00314	 0.013169	 0.0	 2334	 2334	 2334	 0.0	 0.0	 1	 -30.0	 30.0;
	4224	 1909	 0.002479	 0.01331	 0.0	 476.0	 2334	 2334	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 2740	 7e-05	 0.00194	 0.0	 16272	 16272	 16272	 0.0	 0.0	 1	 -30.0	 30.0;
	9162	 8419	 0.001159	 0.00931	 0.0	 3367	 3367	 3367	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 6349	 0.00062	 0.003669	 0.0	 8489	 8489	 8489	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 5163	 0.015969	 0.056711	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 3754	 0.0085	 0.03719	 0.0	 419.0	 828	 828	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 9055	 0.001531	 0.00732	 0.0	 4224	 4224	 4224	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 9055	 0.00205	 0.01062	 0.0	 2921	 2921	 2921	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 5464	 0.00091	 0.01056	 0.0	 757.0	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	807	 8625	 0.00167	 0.02069	 0.0	 1522	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	6299	 6879	 0.002719	 0.016219	 0.0	 514.0	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 4390	 0.002	 0.02376	 0.0	 1325	 1325	 1325	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 4390	 0.00226	 0.02328	 0.0	 1351	 1351	 1351	 0.0	 0.0	 1	 -30.0	 30.0;
	7630	 442	 0.004151	 0.02119	 0.0	 533.0	 1463	 1463	 0.0	 0.0	 1	 -30.0	 30.0;
	8993	 8378	 0.001841	 0.010909	 0.0	 2856	 2856	 2856	 0.0	 0.0	 1	 -30.0	 30.0;
	6879	 4181	 0.000669	 0.00399	 0.0	 476.0	 7808	 7808	 0.0	 0.0	 1	 -30.0	 30.0;
	3662	 1475	 8e-05	 0.00098	 0.0	 1613.0	 32126	 32126	 0.0	 0.0	 1	 -30.0	 30.0;
	8242	 8530	 0.0002	 0.0025	 0.0	 12595	 12595	 12595	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 5290	 0.006219	 0.031599	 0.0	 533.0	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 1437	 0.00438	 0.023169	 0.0	 533.0	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 4279	 0.00581	 0.03088	 0.0	 514.0	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 4279	 0.0065	 0.02637	 0.0	 438.0	 1164	 1164	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 597	 0.00198	 0.02208	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 5329	 0.00093	 0.006659	 0.0	 4698	 4698	 4698	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 5329	 0.000909	 0.006789	 0.0	 4612	 4612	 4612	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 1074	 0.00244	 0.01919	 0.0	 856.0	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 8582	 0.00194	 0.01549	 0.0	 2024	 2024	 2024	 0.0	 0.0	 1	 -30.0	 30.0;
	1666	 4058	 0.0002	 0.001479	 0.0	 514.0	 21165	 21165	 0.0	 0.0	 1	 -30.0	 30.0;
	4493	 1513	 0.001091	 0.009461	 0.0	 610.0	 3317	 3317	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 6604	 0.003081	 0.00899	 0.0	 495.0	 3324	 3324	 0.0	 0.0	 1	 -30.0	 30.0;
	6604	 1457	 0.00357	 0.0138	 0.0	 457.0	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	3495	 7629	 0.001229	 0.00986	 0.0	 476.0	 3179	 3179	 0.0	 0.0	 1	 -30.0	 30.0;
	1985	 9106	 0.001211	 0.00913	 0.0	 572.0	 3430	 3430	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 8012	 0.00116	 0.01053	 0.0	 1580.0	 2982	 2982	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 5681	 0.0017	 0.009781	 0.0	 3182	 3182	 3182	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 5681	 0.001521	 0.011091	 0.0	 2822	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	7795	 445	 0.0043	 0.0233	 0.0	 572.0	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	2700	 4446	 0.00019	 0.0016	 0.0	 987.0	 19605	 19605	 0.0	 0.0	 1	 -30.0	 30.0;
	4772	 8301	 0.00838	 0.072479	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	4772	 988	 0.00787	 0.049211	 0.0	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	442	 230	 0.00557	 0.03376	 0.0	 924	 924	 924	 0.0	 0.0	 1	 -30.0	 30.0;
	4238	 7312	 0.01213	 0.06564	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	7366	 3125	 0.003531	 0.01086	 0.0	 400.0	 2767	 2767	 0.0	 0.0	 1	 -30.0	 30.0;
	7366	 7423	 0.0158	 0.057031	 0.0	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	754	 2096	 0.00289	 0.0244	 0.0	 1283.0	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	1599	 4096	 0.000521	 0.00413	 0.0	 553.0	 7589	 7589	 0.0	 0.0	 1	 -30.0	 30.0;
	8079	 4096	 0.000531	 0.004039	 0.0	 495.0	 7754	 7754	 0.0	 0.0	 1	 -30.0	 30.0;
	230	 1802	 0.00431	 0.02226	 0.0	 419.0	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	3027	 4081	 0.00163	 0.00899	 0.0	 553.0	 3458	 3458	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 1280	 0.00274	 0.02428	 0.0	 1293	 1293	 1293	 0.0	 0.0	 1	 -30.0	 30.0;
	6315	 6022	 0.0093	 0.056979	 0.0	 514.0	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	6315	 8729	 0.011281	 0.080039	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	6315	 5631	 0.00449	 0.02376	 0.0	 438.0	 1307	 1307	 0.0	 0.0	 1	 -30.0	 30.0;
	2622	 8260	 0.00014	 0.00148	 0.0	 1744.0	 21248	 21248	 0.0	 0.0	 1	 -30.0	 30.0;
	6797	 8301	 0.0055	 0.033659	 0.0	 419.0	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 5465	 0.00249	 0.02082	 0.0	 457.0	 1507	 1507	 0.0	 0.0	 1	 -30.0	 30.0;
	1728	 2096	 0.00164	 0.02252	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 2147	 0.000961	 0.0047	 0.0	 6585	 6585	 6585	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 2147	 0.000979	 0.004599	 0.0	 6718	 6718	 6718	 0.0	 0.0	 1	 -30.0	 30.0;
	7688	 385	 0.00057	 0.00515	 0.0	 1251.0	 6097	 6097	 0.0	 0.0	 1	 -30.0	 30.0;
	8301	 6869	 0.00143	 0.011651	 0.0	 381.0	 2691	 2691	 0.0	 0.0	 1	 -30.0	 30.0;
	1501	 4081	 0.00126	 0.009211	 0.0	 3398	 3398	 3398	 0.0	 0.0	 1	 -30.0	 30.0;
	6022	 695	 9.1e-05	 0.000211	 0.0	 381.0	 137464	 137464	 0.0	 0.0	 1	 -30.0	 30.0;
	8776	 695	 0.000211	 0.000711	 0.0	 42591	 42591	 42591	 0.0	 0.0	 1	 -30.0	 30.0;
	8776	 5631	 0.01095	 0.07062	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 5631	 0.00125	 0.007281	 0.0	 4276	 4276	 4276	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 5631	 0.001	 0.0045	 0.0	 6853	 6853	 6853	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 5025	 0.00282	 0.026419	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	7632	 6625	 0.003479	 0.01456	 0.0	 2111	 2111	 2111	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 4279	 0.005521	 0.03418	 0.0	 457.0	 913	 913	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 4279	 0.00563	 0.033461	 0.0	 476.0	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 4752	 0.00095	 0.0072	 0.0	 419.0	 4350	 4350	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 7312	 0.00093	 0.007159	 0.0	 514.0	 4376	 4376	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 4279	 0.00988	 0.058651	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	6654	 7869	 3.9e-05	 0.00044	 0.0	 591.0	 71510	 71510	 0.0	 0.0	 1	 -30.0	 30.0;
	6654	 7869	 3.9e-05	 0.00043	 0.0	 533.0	 73159	 73159	 0.0	 0.0	 1	 -30.0	 30.0;
	7351	 5441	 0.00018	 0.000781	 0.0	 39412	 39412	 39412	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 7571	 0.002961	 0.01669	 0.0	 419.0	 1864	 1864	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 3916	 0.00056	 0.00432	 0.0	 7252	 7252	 7252	 0.0	 0.0	 1	 -30.0	 30.0;
	6757	 6036	 0.0002	 0.00246	 0.0	 757.0	 12799	 12799	 0.0	 0.0	 1	 -30.0	 30.0;
	6757	 6921	 0.0003	 0.00377	 0.0	 1415.0	 8353	 8353	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 9112	 0.00014	 0.00057	 0.0	 53817	 53817	 53817	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 9112	 0.00013	 0.000729	 0.0	 42657	 42657	 42657	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 9112	 0.00012	 0.000581	 0.0	 53244	 53244	 53244	 0.0	 0.0	 1	 -30.0	 30.0;
	1851	 9112	 0.00011	 0.00064	 0.0	 48642	 48642	 48642	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 9112	 0.00019	 0.00056	 0.0	 53416	 53416	 53416	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 8791	 0.00062	 0.004909	 0.0	 629.0	 6384	 6384	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 7842	 7e-05	 0.00076	 0.0	 987.0	 41388	 41388	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 8997	 0.00066	 0.00622	 0.0	 1711.0	 5051	 5051	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 2129	 0.00054	 0.00752	 0.0	 4190	 4190	 4190	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 29	 0.00105	 0.00877	 0.0	 1415.0	 3577	 3577	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 8903	 8e-05	 0.00091	 0.0	 757.0	 34578	 34578	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 4598	 0.00056	 0.00719	 0.0	 1053.0	 4380	 4380	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 5533	 0.000531	 0.002039	 0.0	 419.0	 14992	 14992	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 4831	 0.008659	 0.03769	 0.0	 400.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 8961	 0.003849	 0.021099	 0.0	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 8522	 0.00688	 0.035969	 0.0	 400.0	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 6888	 0.006729	 0.03713	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 3401	 0.00111	 0.006651	 0.0	 514.0	 4685	 4685	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 641	 0.0023	 0.008909	 0.0	 3433	 3433	 3433	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 2600	 0.000841	 0.00313	 0.0	 9747	 9747	 9747	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 5351	 0.003521	 0.017479	 0.0	 400.0	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 718	 3.9e-05	 0.00025	 0.0	 610.0	 124840	 124840	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 2327	 0.000159	 0.000729	 0.0	 457.0	 42335	 42335	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 7473	 0.005281	 0.032099	 0.0	 495.0	 972	 972	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 7473	 0.005651	 0.029419	 0.0	 476.0	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	903	 3654	 0.000271	 0.00036	 0.0	 70101	 70101	 70101	 0.0	 0.0	 1	 -30.0	 30.0;
	8732	 7050	 0.00044	 0.00143	 0.0	 572.0	 21113	 21113	 0.0	 0.0	 1	 -30.0	 30.0;
	8732	 3912	 0.000159	 0.00074	 0.0	 553.0	 41734	 41734	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 1973	 0.00019	 0.000591	 0.0	 438.0	 50883	 50883	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 2928	 0.00019	 0.00087	 0.0	 35472	 35472	 35472	 0.0	 0.0	 1	 -30.0	 30.0;
	6629	 4918	 0.002591	 0.013659	 0.0	 419.0	 2273	 2273	 0.0	 0.0	 1	 -30.0	 30.0;
	6629	 7309	 0.00305	 0.01168	 0.0	 2617	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	413	 1102	 0.000159	 0.000599	 0.0	 533.0	 50969	 50969	 0.0	 0.0	 1	 -30.0	 30.0;
	413	 1102	 0.000159	 0.00062	 0.0	 495.0	 49351	 49351	 0.0	 0.0	 1	 -30.0	 30.0;
	3248	 4918	 0.00101	 0.004229	 0.0	 572.0	 7265	 7265	 0.0	 0.0	 1	 -30.0	 30.0;
	3248	 4281	 0.00319	 0.018651	 0.0	 553.0	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	3248	 7309	 0.000729	 0.00337	 0.0	 9162	 9162	 9162	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 1187	 0.002961	 0.012831	 0.0	 381.0	 2399	 2399	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 7945	 0.000591	 0.00339	 0.0	 9180	 9180	 9180	 0.0	 0.0	 1	 -30.0	 30.0;
	8900	 2421	 0.00024	 0.001219	 0.0	 25425	 25425	 25425	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 2972	 0.006219	 0.036341	 0.0	 476.0	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 6031	 0.001841	 0.01193	 0.0	 572.0	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 7264	 0.001409	 0.01113	 0.0	 514.0	 2816	 2816	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 283	 0.00151	 0.00768	 0.0	 476.0	 4036	 4036	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 3069	 0.00599	 0.03313	 0.0	 495.0	 939	 939	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 3390	 0.001771	 0.010151	 0.0	 457.0	 3066	 3066	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 4936	 0.00074	 0.00311	 0.0	 9881	 9881	 9881	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 4936	 0.000729	 0.003159	 0.0	 9744	 9744	 9744	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 7809	 0.005271	 0.01906	 0.0	 381.0	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 5455	 0.00906	 0.053151	 0.0	 419.0	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 1857	 0.00405	 0.0153	 0.0	 1996	 1996	 1996	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 5410	 0.00055	 0.003961	 0.0	 495.0	 7899	 7899	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 5410	 0.00055	 0.003729	 0.0	 438.0	 8381	 8381	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1609	 0.00107	 0.007789	 0.0	 514.0	 4018	 4018	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1609	 0.00112	 0.00775	 0.0	 572.0	 4034	 4034	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1609	 0.001031	 0.00775	 0.0	 4041	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 2438	 0.00062	 0.003219	 0.0	 9636	 9636	 9636	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 954	 0.00068	 0.002659	 0.0	 514.0	 11510	 11510	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 502	 0.00193	 0.012479	 0.0	 591.0	 2502	 2502	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 3013	 0.001159	 0.007229	 0.0	 4315	 4315	 4315	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 2949	 0.00137	 0.008729	 0.0	 495.0	 3575	 3575	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 2949	 0.001401	 0.00855	 0.0	 533.0	 3646	 3646	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 2949	 0.001331	 0.008521	 0.0	 533.0	 3663	 3663	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 2208	 0.00031	 0.00081	 0.0	 381.0	 36421	 36421	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 8060	 0.000341	 0.00119	 0.0	 381.0	 25518	 25518	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 4484	 0.00031	 0.001281	 0.0	 476.0	 23967	 23967	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 4239	 0.00094	 0.0035	 0.0	 533.0	 8717	 8717	 0.0	 0.0	 1	 -30.0	 30.0;
	8535	 7047	 7e-05	 0.000651	 0.0	 48244	 48244	 48244	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 3657	 0.00019	 0.00124	 0.0	 591.0	 25180	 25180	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 2928	 0.000331	 0.002539	 0.0	 533.0	 12337	 12337	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 2918	 0.0016	 0.02113	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	7770	 5317	 0.000909	 0.004711	 0.0	 457.0	 6584	 6584	 0.0	 0.0	 1	 -30.0	 30.0;
	7770	 5317	 0.00088	 0.004969	 0.0	 419.0	 6260	 6260	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 8676	 0.001841	 0.0088	 0.0	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 8189	 0.01013	 0.04238	 0.0	 495.0	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 2938	 0.00059	 0.00802	 0.0	 823.0	 3928	 3928	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 2938	 0.00054	 0.0079	 0.0	 757.0	 3990	 3990	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 3918	 0.00171	 0.02128	 0.0	 1086.0	 1480	 1480	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 3918	 0.00174	 0.02084	 0.0	 954.0	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 6581	 0.00086	 0.01433	 0.0	 1251.0	 2201	 2201	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 6581	 0.00087	 0.01404	 0.0	 823.0	 2246	 2246	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 3830	 0.00126	 0.01447	 0.0	 1218.0	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 5648	 0.00122	 0.01509	 0.0	 1152.0	 2087	 2087	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 5648	 0.00154	 0.019	 0.0	 1382.0	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 4907	 0.00474	 0.03564	 0.0	 572.0	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 5957	 0.006	 0.047849	 0.0	 533.0	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 5233	 0.008039	 0.03375	 0.0	 381.0	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	6854	 7309	 2.1e-05	 0.000211	 0.0	 610.0	 148968	 148968	 0.0	 0.0	 1	 -30.0	 30.0;
	8311	 3680	 0.00045	 0.002341	 0.0	 13251	 13251	 13251	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 8804	 0.000669	 0.004281	 0.0	 533.0	 7291	 7291	 0.0	 0.0	 1	 -30.0	 30.0;
	9241	 8804	 0.00068	 0.00419	 0.0	 7442	 7442	 7442	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 7124	 0.000729	 0.00431	 0.0	 610.0	 7227	 7227	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 7124	 0.000591	 0.004651	 0.0	 553.0	 6738	 6738	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 8873	 0.00099	 0.005081	 0.0	 438.0	 6103	 6103	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 7582	 0.00212	 0.013031	 0.0	 2393	 2393	 2393	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 3541	 0.002159	 0.01275	 0.0	 2443	 2443	 2443	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 3698	 0.00025	 0.00095	 0.0	 32156	 32156	 32156	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 3698	 0.000271	 0.00089	 0.0	 33953	 33953	 33953	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 2801	 0.001961	 0.012409	 0.0	 381.0	 2515	 2515	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8328	 0.00044	 0.00207	 0.0	 572.0	 14927	 14927	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8511	 0.000469	 0.00143	 0.0	 629.0	 20990	 20990	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 6570	 0.001271	 0.01406	 0.0	 629.0	 2238	 2238	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 6570	 0.00124	 0.013021	 0.0	 629.0	 2415	 2415	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8975	 0.000409	 0.00239	 0.0	 13028	 13028	 13028	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 216	 0.00094	 0.005	 0.0	 438.0	 6209	 6209	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 2961	 0.000219	 0.0007	 0.0	 629.0	 43067	 43067	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 6773	 6e-05	 0.00025	 0.0	 122861	 122861	 122861	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 5278	 5e-05	 0.000229	 0.0	 134762	 134762	 134762	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 2751	 0.00019	 0.000909	 0.0	 34015	 34015	 34015	 0.0	 0.0	 1	 -30.0	 30.0;
	2276	 5546	 0.001711	 0.00782	 0.0	 3946	 3946	 3946	 0.0	 0.0	 1	 -30.0	 30.0;
	2276	 6816	 0.002651	 0.01176	 0.0	 419.0	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	7766	 444	 0.001409	 0.010599	 0.0	 2955	 2955	 2955	 0.0	 0.0	 1	 -30.0	 30.0;
	7766	 5334	 0.001419	 0.010219	 0.0	 3062	 3062	 3062	 0.0	 0.0	 1	 -30.0	 30.0;
	839	 3918	 0.00013	 0.00212	 0.0	 856.0	 14872	 14872	 0.0	 0.0	 1	 -30.0	 30.0;
	839	 809	 0.00026	 0.00313	 0.0	 1382.0	 10058	 10058	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 2286	 0.0047	 0.0318	 0.0	 476.0	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 6802	 0.00136	 0.00768	 0.0	 438.0	 4050	 4050	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 3520	 0.005669	 0.027789	 0.0	 400.0	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 6271	 0.004409	 0.033091	 0.0	 381.0	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 1435	 0.01056	 0.044469	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7148	 0.01963	 0.07736	 0.0	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7437	 0.01157	 0.04694	 0.0	 457.0	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 871	 0.000479	 0.00255	 0.0	 457.0	 12175	 12175	 0.0	 0.0	 1	 -30.0	 30.0;
	7580	 871	 0.000469	 0.00236	 0.0	 13128	 13128	 13128	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 1539	 0.01237	 0.067039	 0.0	 381.0	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 8515	 0.0132	 0.056229	 0.0	 381.0	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 4084	 0.00026	 0.001711	 0.0	 18252	 18252	 18252	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 4084	 0.000271	 0.001669	 0.0	 18682	 18682	 18682	 0.0	 0.0	 1	 -30.0	 30.0;
	6845	 5340	 0.000211	 0.000401	 0.0	 69711	 69711	 69711	 0.0	 0.0	 1	 -30.0	 30.0;
	8294	 5814	 0.00105	 0.005159	 0.0	 6000	 6000	 6000	 0.0	 0.0	 1	 -30.0	 30.0;
	7115	 6807	 0.00212	 0.00931	 0.0	 419.0	 3309	 3309	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 6791	 0.000151	 0.00068	 0.0	 45348	 45348	 45348	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 4908	 0.00019	 0.00082	 0.0	 37527	 37527	 37527	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 6816	 0.003219	 0.01405	 0.0	 400.0	 2192	 2192	 0.0	 0.0	 1	 -30.0	 30.0;
	6692	 9158	 0.007271	 0.033159	 0.0	 381.0	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	6692	 8035	 0.006659	 0.03132	 0.0	 400.0	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 2848	 0.00057	 0.00668	 0.0	 1580.0	 4712	 4712	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 7056	 0.00057	 0.00758	 0.0	 1514.0	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 7056	 0.00039	 0.00607	 0.0	 921.0	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 1642	 0.00155	 0.0179	 0.0	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 4594	 0.00036	 0.00485	 0.0	 1645.0	 6495	 6495	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 1692	 0.000581	 0.004229	 0.0	 438.0	 7400	 7400	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 8190	 0.00056	 0.00431	 0.0	 7268	 7268	 7268	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 5836	 0.003099	 0.020531	 0.0	 572.0	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 3191	 0.00118	 0.016919	 0.0	 610.0	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 5300	 0.00188	 0.01407	 0.0	 2226	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 4889	 0.00545	 0.04082	 0.0	 457.0	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 444	 0.00214	 0.01639	 0.0	 553.0	 1912	 1912	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 4747	 0.002479	 0.01549	 0.0	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 9011	 0.000159	 0.001229	 0.0	 572.0	 25490	 25490	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 6675	 0.00026	 0.00162	 0.0	 553.0	 19252	 19252	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 6909	 0.000159	 0.00113	 0.0	 476.0	 27681	 27681	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 8835	 0.000461	 0.003219	 0.0	 572.0	 9714	 9714	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 4186	 0.000159	 0.001229	 0.0	 25490	 25490	 25490	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 502	 0.000229	 0.00139	 0.0	 476.0	 22423	 22423	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 502	 0.0002	 0.00156	 0.0	 438.0	 20084	 20084	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 513	 0.00145	 0.00824	 0.0	 381.0	 3776	 3776	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 502	 0.00069	 0.005	 0.0	 591.0	 6259	 6259	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 3697	 0.00036	 0.00455	 0.0	 1909.0	 6921	 6921	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 3697	 0.00036	 0.00453	 0.0	 1876.0	 6952	 6952	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 7541	 0.00066	 0.00997	 0.0	 1448.0	 3162	 3162	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 7541	 0.00064	 0.01016	 0.0	 1086.0	 3103	 3103	 0.0	 0.0	 1	 -30.0	 30.0;
	6306	 4826	 9.9e-05	 0.00044	 0.0	 629.0	 70039	 70039	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 4418	 6e-05	 0.000469	 0.0	 66806	 66806	 66806	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 1605	 3.9e-05	 0.000341	 0.0	 92032	 92032	 92032	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 6952	 0.002531	 0.01943	 0.0	 533.0	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 7124	 0.00945	 0.06418	 0.0	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	9128	 217	 0.000591	 0.002831	 0.0	 457.0	 10923	 10923	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 217	 0.00087	 0.00387	 0.0	 7964	 7964	 7964	 0.0	 0.0	 1	 -30.0	 30.0;
	720	 5350	 0.0015	 0.01785	 0.0	 1283.0	 1764	 1764	 0.0	 0.0	 1	 -30.0	 30.0;
	720	 5350	 0.00147	 0.0182	 0.0	 1251.0	 1730	 1730	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 639	 0.00151	 0.0113	 0.0	 476.0	 2771	 2771	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 639	 0.001479	 0.011521	 0.0	 495.0	 2720	 2720	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 9130	 0.00174	 0.010341	 0.0	 514.0	 3013	 3013	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 9130	 0.001659	 0.01206	 0.0	 553.0	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 1998	 0.00069	 0.000479	 0.0	 37606	 37606	 37606	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 7974	 0.00044	 0.00139	 0.0	 21666	 21666	 21666	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 8180	 0.002039	 0.01601	 0.0	 1958	 1958	 1958	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 7466	 0.01349	 0.05662	 0.0	 457.0	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 305	 0.00082	 0.00438	 0.0	 400.0	 7089	 7089	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 305	 0.0008	 0.004461	 0.0	 381.0	 6970	 6970	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 5106	 0.001091	 0.00888	 0.0	 553.0	 3531	 3531	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 5106	 0.00111	 0.007039	 0.0	 591.0	 4433	 4433	 0.0	 0.0	 1	 -30.0	 30.0;
	2527	 8466	 0.000849	 0.00537	 0.0	 533.0	 5811	 5811	 0.0	 0.0	 1	 -30.0	 30.0;
	8669	 8893	 0.00061	 0.00275	 0.0	 457.0	 11214	 11214	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 7691	 0.00141	 0.0188	 0.0	 1415.0	 1676	 1676	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 6624	 0.00121	 0.01427	 0.0	 1645.0	 2206	 2206	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 8158	 0.001711	 0.007159	 0.0	 438.0	 4292	 4292	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 8795	 0.00545	 0.02381	 0.0	 400.0	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 4143	 0.000771	 0.004331	 0.0	 7181	 7181	 7181	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 2797	 0.00414	 0.03282	 0.0	 553.0	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 6331	 0.00264	 0.011521	 0.0	 438.0	 2673	 2673	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 6384	 0.00261	 0.011	 0.0	 476.0	 2795	 2795	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 7523	 0.00239	 0.00919	 0.0	 419.0	 3327	 3327	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 2889	 0.000539	 0.00226	 0.0	 13596	 13596	 13596	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 6887	 0.00325	 0.017979	 0.0	 572.0	 1729	 1729	 0.0	 0.0	 1	 -30.0	 30.0;
	1249	 4541	 0.00076	 0.0071	 0.0	 1316.0	 4424	 4424	 0.0	 0.0	 1	 -30.0	 30.0;
	819	 7523	 0.000651	 0.00343	 0.0	 9048	 9048	 9048	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 4353	 0.001219	 0.00812	 0.0	 438.0	 3847	 3847	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 4816	 0.00243	 0.01439	 0.0	 591.0	 2165	 2165	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 6246	 0.0006	 0.00839	 0.0	 1251.0	 3756	 3756	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 6246	 0.00059	 0.00856	 0.0	 1185.0	 3682	 3682	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 5658	 0.00087	 0.01328	 0.0	 1777.0	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 5658	 0.00073	 0.01595	 0.0	 1349.0	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 3645	 0.00163	 0.002039	 0.0	 12101	 12101	 12101	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 3645	 0.001659	 0.002	 0.0	 12156	 12156	 12156	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 5764	 0.00339	 0.019669	 0.0	 572.0	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 2360	 0.00239	 0.017281	 0.0	 629.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 9033	 0.00032	 0.00112	 0.0	 495.0	 27118	 27118	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 5918	 0.0018	 0.01401	 0.0	 495.0	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 5918	 0.00212	 0.012469	 0.0	 533.0	 2498	 2498	 0.0	 0.0	 1	 -30.0	 30.0;
	1275	 2850	 0.00063	 0.00411	 0.0	 7597	 7597	 7597	 0.0	 0.0	 1	 -30.0	 30.0;
	6426	 4110	 0.009729	 0.03505	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	6426	 3558	 0.01007	 0.03056	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 2816	 0.00042	 0.00623	 0.0	 5059	 5059	 5059	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 352	 0.00036	 0.00722	 0.0	 1843.0	 4370	 4370	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 6581	 0.00053	 0.0078	 0.0	 954.0	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 1923	 0.00109	 0.0173	 0.0	 823.0	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 5837	 0.00071	 0.01144	 0.0	 2756	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 3830	 0.00157	 0.01884	 0.0	 1251.0	 1671	 1671	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 3577	 0.00032	 0.00384	 0.0	 856.0	 8198	 8198	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 1794	 0.00041	 0.00649	 0.0	 1547.0	 4858	 4858	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 7808	 0.0004	 0.00658	 0.0	 4792	 4792	 4792	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 6581	 0.00054	 0.00763	 0.0	 954.0	 4130	 4130	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 1923	 0.00107	 0.01602	 0.0	 921.0	 1968	 1968	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 5837	 0.0007	 0.01165	 0.0	 2707	 2707	 2707	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 5648	 0.0016	 0.01844	 0.0	 1349.0	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 3577	 0.00032	 0.00376	 0.0	 954.0	 8371	 8371	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 171	 0.00212	 0.01207	 0.0	 495.0	 2578	 2578	 0.0	 0.0	 1	 -30.0	 30.0;
	3137	 2341	 5e-05	 0.00037	 0.0	 84603	 84603	 84603	 0.0	 0.0	 1	 -30.0	 30.0;
	6271	 8787	 0.00355	 0.024651	 0.0	 419.0	 1269	 1269	 0.0	 0.0	 1	 -30.0	 30.0;
	6252	 9137	 0.00675	 0.04145	 0.0	 533.0	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 7133	 0.00195	 0.014341	 0.0	 438.0	 2183	 2183	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 4355	 0.00018	 0.00043	 0.0	 381.0	 67762	 67762	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 2928	 0.00037	 0.000969	 0.0	 457.0	 30454	 30454	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 1341	 0.00257	 0.017169	 0.0	 476.0	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 5419	 0.00076	 0.00399	 0.0	 495.0	 7777	 7777	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 5419	 0.00075	 0.00406	 0.0	 495.0	 7651	 7651	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 2079	 0.003901	 0.023961	 0.0	 572.0	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 772	 0.00249	 0.019211	 0.0	 457.0	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 2928	 0.00025	 0.001159	 0.0	 476.0	 26642	 26642	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 7282	 0.00195	 0.02924	 0.0	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 2197	 0.00152	 0.01527	 0.0	 1481.0	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 7640	 0.00149	 0.01558	 0.0	 1613.0	 2019	 2019	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 1081	 0.00253	 0.0276	 0.0	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 1081	 0.00263	 0.02648	 0.0	 1188	 1188	 1188	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 2359	 0.00077	 0.0092	 0.0	 1415.0	 3422	 3422	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 4196	 0.00112	 0.01705	 0.0	 757.0	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 8546	 0.00226	 0.01101	 0.0	 2811	 2811	 2811	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 5987	 0.004531	 0.029039	 0.0	 495.0	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 8005	 0.002081	 0.030409	 0.0	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 3925	 0.0053	 0.03257	 0.0	 438.0	 958	 958	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 3324	 0.00513	 0.041901	 0.0	 553.0	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 4748	 0.001461	 0.01056	 0.0	 457.0	 2964	 2964	 0.0	 0.0	 1	 -30.0	 30.0;
	8265	 4816	 0.0005	 0.002591	 0.0	 11971	 11971	 11971	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6313	 0.00055	 0.0033	 0.0	 457.0	 9442	 9442	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 6532	 0.002289	 0.01763	 0.0	 476.0	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 2177	 0.0075	 0.043531	 0.0	 457.0	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 2079	 0.00138	 0.019961	 0.0	 1579	 1579	 1579	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 789	 0.00126	 0.018729	 0.0	 591.0	 1683	 1683	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 9189	 0.00038	 0.001331	 0.0	 495.0	 22821	 22821	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 3400	 0.00019	 0.001461	 0.0	 21440	 21440	 21440	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 4747	 0.002151	 0.013401	 0.0	 476.0	 2328	 2328	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 7791	 0.000789	 0.005669	 0.0	 572.0	 5519	 5519	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 6735	 3e-05	 0.00042	 0.0	 757.0	 75017	 75017	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 666	 0.00079	 0.00899	 0.0	 1382.0	 3501	 3501	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 666	 0.0008	 0.00879	 0.0	 1547.0	 3579	 3579	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 4435	 0.00334	 0.03393	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 1644	 0.00063	 0.00789	 0.0	 3991	 3991	 3991	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 3483	 0.0006	 0.00842	 0.0	 1316.0	 3742	 3742	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 7989	 0.00011	 0.00125	 0.0	 25173	 25173	 25173	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 6516	 0.00012	 0.001091	 0.0	 28780	 28780	 28780	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 7697	 9.9e-05	 0.00125	 0.0	 25191	 25191	 25191	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 416	 0.00294	 0.02443	 0.0	 629.0	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2847	 0.00144	 0.011151	 0.0	 495.0	 2810	 2810	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2563	 0.001831	 0.010849	 0.0	 591.0	 2871	 2871	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2563	 0.001599	 0.01055	 0.0	 572.0	 2961	 2961	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2995	 0.00144	 0.019591	 0.0	 381.0	 1609	 1609	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 1001	 0.0133	 0.09551	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 4426	 0.009591	 0.073961	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 2721	 0.0007	 0.00671	 0.0	 1547.0	 4683	 4683	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 2721	 0.00072	 0.00658	 0.0	 1580.0	 4773	 4773	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 4936	 0.001901	 0.00964	 0.0	 629.0	 3215	 3215	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 5179	 0.001711	 0.01189	 0.0	 610.0	 2630	 2630	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 4748	 0.00025	 0.00187	 0.0	 16743	 16743	 16743	 0.0	 0.0	 1	 -30.0	 30.0;
	4197	 5522	 0.00043	 0.002211	 0.0	 14024	 14024	 14024	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 8670	 0.000401	 0.00243	 0.0	 12826	 12826	 12826	 0.0	 0.0	 1	 -30.0	 30.0;
	7809	 5110	 0.00336	 0.017	 0.0	 457.0	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	7222	 4816	 0.005521	 0.031031	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 3817	 9.9e-05	 0.00026	 0.0	 113538	 113538	 113538	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 2732	 0.00045	 0.00718	 0.0	 1086.0	 4391	 4391	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 4550	 0.00044	 0.00665	 0.0	 921.0	 4740	 4740	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 4339	 0.00103	 0.01516	 0.0	 1283.0	 2079	 2079	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 7513	 0.00101	 0.01546	 0.0	 954.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 26	 0.00045	 0.00608	 0.0	 1514.0	 5182	 5182	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 9213	 0.0004	 0.00501	 0.0	 1349.0	 6285	 6285	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 9002	 0.001729	 0.01337	 0.0	 591.0	 2344	 2344	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 6231	 0.00264	 0.01489	 0.0	 514.0	 2089	 2089	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 883	 0.002341	 0.018961	 0.0	 514.0	 1654	 1654	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 5738	 0.001841	 0.01363	 0.0	 476.0	 2297	 2297	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 7700	 0.001219	 0.00949	 0.0	 495.0	 3302	 3302	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 9002	 0.002271	 0.01151	 0.0	 495.0	 2693	 2693	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 5990	 0.010781	 0.05775	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 6450	 0.00251	 0.013919	 0.0	 400.0	 2234	 2234	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 7726	 0.00101	 0.007331	 0.0	 514.0	 4269	 4269	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 4110	 0.00061	 0.003909	 0.0	 629.0	 7985	 7985	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 6376	 0.004289	 0.019331	 0.0	 1596	 1596	 1596	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 4110	 0.0008	 0.004401	 0.0	 629.0	 7062	 7062	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 4829	 0.008099	 0.03519	 0.0	 610.0	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 7857	 0.00063	 0.004591	 0.0	 514.0	 6817	 6817	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 7857	 0.000651	 0.00456	 0.0	 6858	 6858	 6858	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 9012	 0.00114	 0.00581	 0.0	 5335	 5335	 5335	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 2231	 0.001211	 0.00538	 0.0	 5728	 5728	 5728	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 3793	 0.00418	 0.030159	 0.0	 572.0	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 8497	 0.00324	 0.02413	 0.0	 610.0	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 8497	 0.003169	 0.024591	 0.0	 629.0	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 9002	 0.000219	 0.00088	 0.0	 495.0	 34833	 34833	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 9002	 0.000289	 0.00095	 0.0	 514.0	 31811	 31811	 0.0	 0.0	 1	 -30.0	 30.0;
	6313	 44	 0.0035	 0.022211	 0.0	 553.0	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	6313	 7582	 0.00313	 0.02256	 0.0	 1387	 1387	 1387	 0.0	 0.0	 1	 -30.0	 30.0;
	5944	 8808	 0.000831	 0.00162	 0.0	 17349	 17349	 17349	 0.0	 0.0	 1	 -30.0	 30.0;
	3183	 8515	 0.002099	 0.01068	 0.0	 400.0	 2903	 2903	 0.0	 0.0	 1	 -30.0	 30.0;
	1005	 8515	 0.00224	 0.00976	 0.0	 3155	 3155	 3155	 0.0	 0.0	 1	 -30.0	 30.0;
	8787	 1448	 0.00169	 0.01231	 0.0	 629.0	 2543	 2543	 0.0	 0.0	 1	 -30.0	 30.0;
	6636	 9051	 0.00011	 0.00076	 0.0	 41134	 41134	 41134	 0.0	 0.0	 1	 -30.0	 30.0;
	9109	 9051	 0.00011	 0.00068	 0.0	 45856	 45856	 45856	 0.0	 0.0	 1	 -30.0	 30.0;
	6961	 6376	 0.005479	 0.021909	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	6961	 8818	 0.003331	 0.017039	 0.0	 438.0	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	5077	 4353	 0.000479	 0.001271	 0.0	 23256	 23256	 23256	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 5241	 0.00109	 0.01629	 0.0	 823.0	 1935	 1935	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 8200	 4e-05	 0.00063	 0.0	 1810.0	 50038	 50038	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 6290	 0.0053	 0.024531	 0.0	 572.0	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 2291	 0.004659	 0.021919	 0.0	 419.0	 1410	 1410	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 3656	 0.001659	 0.01043	 0.0	 572.0	 2991	 2991	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 4144	 0.006961	 0.053539	 0.0	 495.0	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	1888	 5441	 0.00036	 0.00288	 0.0	 629.0	 10884	 10884	 0.0	 0.0	 1	 -30.0	 30.0;
	1888	 5441	 0.00038	 0.003	 0.0	 629.0	 10446	 10446	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4970	 0.00048	 0.00643	 0.0	 4899	 4899	 4899	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4970	 0.00051	 0.0066	 0.0	 4772	 4772	 4772	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4970	 0.00046	 0.00729	 0.0	 1876.0	 4325	 4325	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 5461	 0.0006	 0.00868	 0.0	 1810.0	 3631	 3631	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 7778	 0.00068	 0.01076	 0.0	 1942.0	 2930	 2930	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 6897	 0.00066	 0.01096	 0.0	 1909.0	 2877	 2877	 0.0	 0.0	 1	 -30.0	 30.0;
	3075	 4562	 0.00101	 0.005099	 0.0	 400.0	 6077	 6077	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 8475	 0.003901	 0.02437	 0.0	 1280	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 2252	 0.00276	 0.016461	 0.0	 553.0	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 7903	 0.00588	 0.047081	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 1857	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	2877	 3674	 0.00131	 0.00538	 0.0	 5705	 5705	 5705	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 1081	 0.00679	 0.04679	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 8267	 0.00138	 0.01466	 0.0	 1086.0	 2146	 2146	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 9176	 0.003531	 0.01724	 0.0	 1795	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1422	 0.01324	 0.06936	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 8515	 0.00363	 0.01743	 0.0	 438.0	 1775	 1775	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 8515	 0.00257	 0.01662	 0.0	 533.0	 1879	 1879	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 5051	 0.01399	 0.056289	 0.0	 419.0	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1051	 0.00343	 0.01751	 0.0	 457.0	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1397	 0.00301	 0.015409	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1584	 0.00857	 0.033091	 0.0	 476.0	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 6888	 0.003341	 0.01689	 0.0	 1835	 1835	 1835	 0.0	 0.0	 1	 -30.0	 30.0;
	7653	 3019	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	7341	 7098	 0.00087	 0.00714	 0.0	 457.0	 4392	 4392	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 8267	 0.00011	 0.001	 0.0	 757.0	 31398	 31398	 0.0	 0.0	 1	 -30.0	 30.0;
	1672	 5365	 0.000219	 0.00101	 0.0	 30565	 30565	 30565	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 5365	 0.000219	 0.001031	 0.0	 29969	 29969	 29969	 0.0	 0.0	 1	 -30.0	 30.0;
	6648	 5365	 0.000271	 0.00101	 0.0	 30207	 30207	 30207	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 5365	 0.000271	 0.000979	 0.0	 31096	 31096	 31096	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 5365	 0.000289	 0.00107	 0.0	 28500	 28500	 28500	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 5365	 0.000289	 0.00105	 0.0	 29005	 29005	 29005	 0.0	 0.0	 1	 -30.0	 30.0;
	4353	 6053	 0.001591	 0.012289	 0.0	 381.0	 2550	 2550	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 5237	 0.000271	 0.001901	 0.0	 495.0	 16450	 16450	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 2886	 0.00186	 0.010711	 0.0	 514.0	 2906	 2906	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 3513	 1e-05	 0.0002	 0.0	 157740	 157740	 157740	 0.0	 0.0	 1	 -30.0	 30.0;
	4049	 883	 0.000169	 0.000271	 0.0	 98903	 98903	 98903	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 883	 0.000169	 0.00031	 0.0	 89464	 89464	 89464	 0.0	 0.0	 1	 -30.0	 30.0;
	1704	 5814	 0.00526	 0.03787	 0.0	 553.0	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	8107	 1486	 0.000229	 0.000599	 0.0	 49257	 49257	 49257	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 5522	 0.00089	 0.004091	 0.0	 438.0	 7545	 7545	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 8670	 0.00093	 0.004	 0.0	 400.0	 7692	 7692	 0.0	 0.0	 1	 -30.0	 30.0;
	8795	 7523	 0.00289	 0.013099	 0.0	 400.0	 2355	 2355	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 6430	 0.002599	 0.016479	 0.0	 533.0	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 7775	 0.00369	 0.02712	 0.0	 553.0	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 3857	 0.0062	 0.04864	 0.0	 629.0	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 333	 0.008021	 0.059031	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 6940	 0.004979	 0.0295	 0.0	 572.0	 1056	 1056	 0.0	 0.0	 1	 -30.0	 30.0;
	8225	 3656	 0.001159	 0.005281	 0.0	 5843	 5843	 5843	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 7752	 0.00361	 0.01824	 0.0	 1699	 1699	 1699	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 1940	 0.001521	 0.01075	 0.0	 2910	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 4234	 0.00868	 0.041711	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 6828	 0.01118	 0.05986	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7571	 0.003229	 0.02543	 0.0	 591.0	 1233	 1233	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7571	 0.00218	 0.01869	 0.0	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7571	 0.001901	 0.021909	 0.0	 572.0	 1437	 1437	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7994	 0.00974	 0.043969	 0.0	 400.0	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7226	 0.003461	 0.01814	 0.0	 457.0	 1711	 1711	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 1554	 0.00487	 0.027669	 0.0	 419.0	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	9011	 1156	 0.000651	 0.003961	 0.0	 610.0	 7870	 7870	 0.0	 0.0	 1	 -30.0	 30.0;
	8689	 5502	 0.00169	 0.00887	 0.0	 400.0	 3499	 3499	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 8873	 0.001711	 0.01336	 0.0	 514.0	 2346	 2346	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 980	 0.00031	 0.000539	 0.0	 400.0	 50801	 50801	 0.0	 0.0	 1	 -30.0	 30.0;
	3204	 3331	 0.0027	 0.01157	 0.0	 2659	 2659	 2659	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 639	 0.000909	 0.006901	 0.0	 514.0	 4539	 4539	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 4936	 0.001729	 0.01214	 0.0	 514.0	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 3492	 0.00614	 0.03106	 0.0	 438.0	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 7937	 0.00418	 0.02388	 0.0	 514.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	3255	 1262	 0.00238	 0.017771	 0.0	 1762	 1762	 1762	 0.0	 0.0	 1	 -30.0	 30.0;
	3255	 1803	 8.1e-05	 0.00063	 0.0	 49730	 49730	 49730	 0.0	 0.0	 1	 -30.0	 30.0;
	7373	 367	 0.001599	 0.01618	 0.0	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 2132	 0.00532	 0.026961	 0.0	 419.0	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 2132	 0.00361	 0.02814	 0.0	 553.0	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 5567	 0.002469	 0.01025	 0.0	 533.0	 2996	 2996	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 1808	 0.005229	 0.02675	 0.0	 400.0	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 1808	 0.00512	 0.02726	 0.0	 419.0	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 7857	 0.00355	 0.01694	 0.0	 400.0	 1826	 1826	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 7289	 0.00139	 0.007659	 0.0	 457.0	 4058	 4058	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 3999	 0.000169	 0.000669	 0.0	 514.0	 45778	 45778	 0.0	 0.0	 1	 -30.0	 30.0;
	8653	 2303	 0.00111	 0.00712	 0.0	 476.0	 4384	 4384	 0.0	 0.0	 1	 -30.0	 30.0;
	908	 6474	 0.00031	 0.001901	 0.0	 533.0	 16400	 16400	 0.0	 0.0	 1	 -30.0	 30.0;
	7030	 6474	 0.000281	 0.002091	 0.0	 14972	 14972	 14972	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 6556	 0.000281	 0.001651	 0.0	 18862	 18862	 18862	 0.0	 0.0	 1	 -30.0	 30.0;
	7325	 6556	 0.000271	 0.00169	 0.0	 18455	 18455	 18455	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 3391	 0.001521	 0.00843	 0.0	 381.0	 3688	 3688	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 3760	 0.000841	 0.0062	 0.0	 533.0	 5049	 5049	 0.0	 0.0	 1	 -30.0	 30.0;
	3707	 8765	 0.00019	 0.00126	 0.0	 514.0	 24790	 24790	 0.0	 0.0	 1	 -30.0	 30.0;
	900	 6619	 0.000219	 0.00143	 0.0	 21835	 21835	 21835	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 8109	 0.00121	 0.01796	 0.0	 1755	 1755	 1755	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 8109	 0.0014	 0.01512	 0.0	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 2177	 0.008409	 0.063651	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 5317	 0.00918	 0.07344	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 608	 0.004219	 0.0345	 0.0	 514.0	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 608	 0.0042	 0.031651	 0.0	 457.0	 990	 990	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 8763	 0.00121	 0.01381	 0.0	 1547.0	 2279	 2279	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 7056	 0.00107	 0.01326	 0.0	 1580.0	 2375	 2375	 0.0	 0.0	 1	 -30.0	 30.0;
	6828	 5814	 0.003401	 0.02607	 0.0	 1202	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 21	 0.000289	 0.00138	 0.0	 419.0	 22404	 22404	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 7702	 0.001031	 0.006039	 0.0	 5156	 5156	 5156	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 7702	 0.00105	 0.005909	 0.0	 5264	 5264	 5264	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 7624	 0.001091	 0.007901	 0.0	 419.0	 3961	 3961	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 1129	 0.00332	 0.024021	 0.0	 553.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 3070	 0.00344	 0.021419	 0.0	 400.0	 1457	 1457	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 306	 0.00095	 0.010419	 0.0	 514.0	 3020	 3020	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 306	 0.00093	 0.01062	 0.0	 476.0	 2963	 2963	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 7491	 0.00474	 0.025409	 0.0	 1223	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 2089	 0.000271	 0.000841	 0.0	 381.0	 35750	 35750	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 6253	 0.000271	 0.00119	 0.0	 381.0	 25882	 25882	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 1562	 0.000289	 0.00076	 0.0	 38849	 38849	 38849	 0.0	 0.0	 1	 -30.0	 30.0;
	7776	 1644	 0.00031	 0.00454	 0.0	 1942.0	 10592	 10592	 0.0	 0.0	 1	 -30.0	 30.0;
	5971	 3483	 0.00032	 0.0044	 0.0	 10925	 10925	 10925	 0.0	 0.0	 1	 -30.0	 30.0;
	2786	 1644	 0.00028	 0.00494	 0.0	 9741	 9741	 9741	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 3483	 0.00028	 0.00508	 0.0	 9474	 9474	 9474	 0.0	 0.0	 1	 -30.0	 30.0;
	8906	 923	 0.000531	 0.00093	 0.0	 29496	 29496	 29496	 0.0	 0.0	 1	 -30.0	 30.0;
	8906	 4914	 0.0003	 0.001031	 0.0	 495.0	 29418	 29418	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 9101	 0.00139	 0.02163	 0.0	 757.0	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 7164	 0.00164	 0.02321	 0.0	 1358	 1358	 1358	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 9101	 0.00136	 0.02205	 0.0	 757.0	 1430	 1430	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 7164	 0.0016	 0.02367	 0.0	 757.0	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 9137	 0.002091	 0.01174	 0.0	 381.0	 2649	 2649	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 9137	 0.001719	 0.00961	 0.0	 553.0	 3236	 3236	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 1026	 0.012341	 0.076781	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 9137	 0.00176	 0.009419	 0.0	 591.0	 3297	 3297	 0.0	 0.0	 1	 -30.0	 30.0;
	1096	 2889	 0.00031	 0.00182	 0.0	 17110	 17110	 17110	 0.0	 0.0	 1	 -30.0	 30.0;
	7380	 2732	 0.00386	 0.02348	 0.0	 1283.0	 1328	 1328	 0.0	 0.0	 1	 -30.0	 30.0;
	7380	 4787	 0.00017	 0.00104	 0.0	 1152.0	 29975	 29975	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 5308	 0.00061	 0.00808	 0.0	 1613.0	 3899	 3899	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 3830	 0.00059	 0.0067	 0.0	 4697	 4697	 4697	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 1027	 0.00059	 0.00748	 0.0	 1481.0	 4210	 4210	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 5648	 0.00061	 0.0063	 0.0	 4991	 4991	 4991	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 1172	 0.001031	 0.008789	 0.0	 629.0	 3570	 3570	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 9191	 0.00051	 0.006169	 0.0	 629.0	 5103	 5103	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 8722	 0.0005	 0.00619	 0.0	 629.0	 5087	 5087	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 3610	 0.00049	 0.00376	 0.0	 572.0	 8331	 8331	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 3610	 0.000539	 0.003229	 0.0	 533.0	 9649	 9649	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 3962	 0.001031	 0.00882	 0.0	 3558	 3558	 3558	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 1838	 0.000711	 0.00463	 0.0	 457.0	 6744	 6744	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 2230	 0.000711	 0.004539	 0.0	 6876	 6876	 6876	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 2467	 0.00206	 0.015341	 0.0	 514.0	 2041	 2041	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 2467	 0.002021	 0.01564	 0.0	 514.0	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 8853	 0.00094	 0.005781	 0.0	 610.0	 5394	 5394	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 1001	 0.002219	 0.016969	 0.0	 629.0	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	7583	 1808	 0.00238	 0.01187	 0.0	 381.0	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	7583	 2889	 0.00707	 0.03095	 0.0	 381.0	 995	 995	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 6624	 0.00256	 0.03401	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 2479	 0.00203	 0.02416	 0.0	 1152.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 4598	 0.001	 0.01459	 0.0	 2160	 2160	 2160	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 4231	 0.00103	 0.00987	 0.0	 1613.0	 3184	 3184	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 5144	 0.00038	 0.00483	 0.0	 1448.0	 6520	 6520	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 5144	 0.00041	 0.00398	 0.0	 1316.0	 7895	 7895	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 2479	 0.00167	 0.01721	 0.0	 1382.0	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 2129	 0.00098	 0.01487	 0.0	 987.0	 2120	 2120	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 9213	 0.00042	 0.00342	 0.0	 1349.0	 9168	 9168	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 9213	 0.00019	 0.00248	 0.0	 1580.0	 12700	 12700	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 4231	 0.00105	 0.00966	 0.0	 1909.0	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 3513	 0.00043	 0.00473	 0.0	 1382.0	 6651	 6651	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 3513	 0.00041	 0.00397	 0.0	 1316.0	 7915	 7915	 0.0	 0.0	 1	 -30.0	 30.0;
	1876	 3906	 0.00051	 0.00514	 0.0	 1218.0	 6116	 6116	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 3906	 0.00053	 0.00503	 0.0	 1415.0	 6246	 6246	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 3758	 0.00455	 0.022771	 0.0	 400.0	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 3758	 0.00557	 0.02055	 0.0	 381.0	 1484	 1484	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 3758	 0.00339	 0.02026	 0.0	 1538	 1538	 1538	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 8976	 0.00237	 0.01068	 0.0	 438.0	 2888	 2888	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 8189	 0.0037	 0.019479	 0.0	 381.0	 1594	 1594	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 7886	 0.01407	 0.056849	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 4544	 0.001669	 0.015409	 0.0	 610.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 4544	 0.001711	 0.015091	 0.0	 2080	 2080	 2080	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 3697	 0.00172	 0.01619	 0.0	 1678.0	 1941	 1941	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 7541	 0.00029	 0.00447	 0.0	 987.0	 7052	 7052	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 7541	 0.00033	 0.00387	 0.0	 1119.0	 8133	 8133	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 4141	 0.00079	 0.01154	 0.0	 987.0	 2731	 2731	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 4141	 0.00077	 0.01177	 0.0	 987.0	 2678	 2678	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 3022	 0.00127	 0.01498	 0.0	 1547.0	 2102	 2102	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 163	 0.00214	 0.012599	 0.0	 495.0	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	4245	 2425	 0.000159	 0.00125	 0.0	 457.0	 25068	 25068	 0.0	 0.0	 1	 -30.0	 30.0;
	3698	 5297	 0.000211	 0.000669	 0.0	 457.0	 45030	 45030	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 8328	 0.000341	 0.001169	 0.0	 514.0	 25940	 25940	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 870	 0.00024	 0.001469	 0.0	 572.0	 21222	 21222	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 2961	 0.00018	 0.000669	 0.0	 533.0	 45595	 45595	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 7988	 0.00033	 0.00683	 0.0	 921.0	 4620	 4620	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 2197	 0.00121	 0.01211	 0.0	 1415.0	 2596	 2596	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 7640	 0.00123	 0.01185	 0.0	 1448.0	 2652	 2652	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 4231	 0.00058	 0.0097	 0.0	 1185.0	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 5144	 0.00103	 0.01292	 0.0	 1251.0	 2438	 2438	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 3513	 0.00116	 0.01266	 0.0	 921.0	 2485	 2485	 0.0	 0.0	 1	 -30.0	 30.0;
	7289	 3999	 0.0013	 0.006841	 0.0	 457.0	 4537	 4537	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 1051	 6e-05	 0.000349	 0.0	 438.0	 89200	 89200	 0.0	 0.0	 1	 -30.0	 30.0;
	2702	 3435	 0.000169	 0.0007	 0.0	 400.0	 43865	 43865	 0.0	 0.0	 1	 -30.0	 30.0;
	9131	 2020	 0.000169	 0.000719	 0.0	 42767	 42767	 42767	 0.0	 0.0	 1	 -30.0	 30.0;
	6308	 6684	 0.000271	 0.001031	 0.0	 29632	 29632	 29632	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 3680	 0.008271	 0.036841	 0.0	 837	 837	 837	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 2751	 0.002969	 0.02299	 0.0	 419.0	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 4623	 0.00124	 0.01273	 0.0	 1218.0	 2470	 2470	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 4339	 0.00106	 0.00989	 0.0	 1481.0	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 5288	 7e-05	 0.00029	 0.0	 757.0	 105881	 105881	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 5421	 9e-05	 0.00079	 0.0	 757.0	 39728	 39728	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 6475	 0.00196	 0.02049	 0.0	 1535	 1535	 1535	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 8468	 0.00158	 0.01519	 0.0	 1283.0	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 2732	 0.00172	 0.01811	 0.0	 1613.0	 1737	 1737	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 7513	 0.00096	 0.01121	 0.0	 1744.0	 2808	 2808	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 6475	 0.00147	 0.01707	 0.0	 1844	 1844	 1844	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 4623	 0.00129	 0.0129	 0.0	 1316.0	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 4550	 0.00179	 0.01737	 0.0	 1645.0	 1809	 1809	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 6475	 0.00131	 0.01935	 0.0	 1629	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 9231	 0.003901	 0.01614	 0.0	 419.0	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 9231	 0.002591	 0.014771	 0.0	 553.0	 2107	 2107	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 9231	 0.00224	 0.0173	 0.0	 476.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 4054	 0.00012	 0.000849	 0.0	 36840	 36840	 36840	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 3481	 0.00394	 0.03039	 0.0	 495.0	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 3602	 0.00189	 0.01	 0.0	 3104	 3104	 3104	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 2794	 0.00032	 0.00257	 0.0	 12197	 12197	 12197	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 2794	 0.00038	 0.00224	 0.0	 13903	 13903	 13903	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 8467	 0.00751	 0.03955	 0.0	 495.0	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 1136	 0.00086	 0.006531	 0.0	 4796	 4796	 4796	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 22	 0.00087	 0.006591	 0.0	 4752	 4752	 4752	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 1001	 0.003031	 0.02276	 0.0	 629.0	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 4950	 0.006331	 0.03911	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 4410	 0.00605	 0.02986	 0.0	 381.0	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 6697	 0.003919	 0.01612	 0.0	 438.0	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 1159	 0.002039	 0.0108	 0.0	 438.0	 2874	 2874	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 7165	 0.006289	 0.026271	 0.0	 514.0	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 2848	 0.00042	 0.00547	 0.0	 856.0	 5758	 5758	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 2848	 0.00043	 0.00536	 0.0	 757.0	 5875	 5875	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 7522	 0.00147	 0.01373	 0.0	 1777.0	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 7522	 0.00131	 0.01555	 0.0	 1547.0	 2025	 2025	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 1642	 0.00221	 0.02217	 0.0	 1418	 1418	 1418	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 809	 0.00224	 0.0217	 0.0	 1448	 1448	 1448	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 6791	 0.00095	 0.003289	 0.0	 400.0	 9227	 9227	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 3400	 0.000229	 0.00082	 0.0	 37102	 37102	 37102	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7092	 0.00068	 0.00306	 0.0	 10077	 10077	 10077	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 3718	 0.00049	 0.00256	 0.0	 419.0	 12119	 12119	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 3701	 0.000531	 0.0022	 0.0	 13958	 13958	 13958	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7507	 0.00136	 0.00956	 0.0	 514.0	 3272	 3272	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7507	 0.0012	 0.010729	 0.0	 476.0	 2926	 2926	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7507	 0.00105	 0.00861	 0.0	 3642	 3642	 3642	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 2406	 0.000591	 0.006969	 0.0	 4517	 4517	 4517	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 8511	 0.00025	 0.0008	 0.0	 37687	 37687	 37687	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 216	 0.00113	 0.00632	 0.0	 400.0	 4920	 4920	 0.0	 0.0	 1	 -30.0	 30.0;
	453	 2129	 0.0003	 0.00275	 0.0	 954.0	 11419	 11419	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 6952	 0.00836	 0.051659	 0.0	 604	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 6952	 0.01338	 0.073469	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 1183	 0.0027	 0.02089	 0.0	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 4410	 0.003419	 0.02636	 0.0	 610.0	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 8743	 0.009531	 0.033711	 0.0	 457.0	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	2446	 8763	 0.0004	 0.00707	 0.0	 4461	 4461	 4461	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 8763	 0.00035	 0.00701	 0.0	 4501	 4501	 4501	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 6785	 0.00194	 0.01751	 0.0	 533.0	 1793	 1793	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 6785	 0.00156	 0.01936	 0.0	 514.0	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 964	 0.00078	 0.00941	 0.0	 1349.0	 3346	 3346	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 964	 0.00074	 0.00969	 0.0	 1580.0	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 8347	 0.00042	 0.00532	 0.0	 1678.0	 5920	 5920	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 8347	 0.0004	 0.00473	 0.0	 1843.0	 6655	 6655	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 8347	 0.0006	 0.00499	 0.0	 1547.0	 6285	 6285	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 6552	 0.00086	 0.00638	 0.0	 610.0	 4907	 4907	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 6552	 0.000969	 0.00625	 0.0	 610.0	 4995	 4995	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 8999	 0.002781	 0.01725	 0.0	 457.0	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 4816	 0.005031	 0.028081	 0.0	 553.0	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 960	 1e-05	 0.00021	 0.0	 150246	 150246	 150246	 0.0	 0.0	 1	 -30.0	 30.0;
	7913	 960	 1e-05	 0.00025	 0.0	 126249	 126249	 126249	 0.0	 0.0	 1	 -30.0	 30.0;
	506	 960	 2e-05	 0.00031	 0.0	 757.0	 101684	 101684	 0.0	 0.0	 1	 -30.0	 30.0;
	2980	 960	 3e-05	 0.0004	 0.0	 757.0	 78748	 78748	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 6382	 0.000841	 0.00474	 0.0	 533.0	 6562	 6562	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 6382	 0.00082	 0.00487	 0.0	 533.0	 6397	 6397	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 1595	 0.00186	 0.011979	 0.0	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 5334	 0.00056	 0.003021	 0.0	 381.0	 10281	 10281	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 5334	 0.00055	 0.003081	 0.0	 10093	 10093	 10093	 0.0	 0.0	 1	 -30.0	 30.0;
	8997	 6153	 0.00114	 0.01063	 0.0	 2955	 2955	 2955	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 5935	 0.003719	 0.02295	 0.0	 629.0	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 5695	 0.006669	 0.04288	 0.0	 514.0	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 5799	 0.00243	 0.0198	 0.0	 1584	 1584	 1584	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 7124	 0.00845	 0.04339	 0.0	 533.0	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 3674	 0.00219	 0.015169	 0.0	 381.0	 2061	 2061	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 2132	 0.00357	 0.0302	 0.0	 419.0	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	2558	 7571	 0.005849	 0.032419	 0.0	 419.0	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	8834	 1129	 0.00406	 0.01688	 0.0	 1820	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	7377	 3324	 0.00113	 0.0065	 0.0	 4788	 4788	 4788	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 4426	 0.0068	 0.04613	 0.0	 514.0	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 1965	 0.00337	 0.02011	 0.0	 419.0	 1550	 1550	 0.0	 0.0	 1	 -30.0	 30.0;
	8060	 7162	 0.00011	 0.0005	 0.0	 61700	 61700	 61700	 0.0	 0.0	 1	 -30.0	 30.0;
	6922	 5482	 0.003711	 0.018521	 0.0	 438.0	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	6922	 1295	 0.000271	 0.00145	 0.0	 457.0	 21414	 21414	 0.0	 0.0	 1	 -30.0	 30.0;
	8369	 4710	 0.00326	 0.01824	 0.0	 1705	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	8961	 7133	 0.00118	 0.00712	 0.0	 419.0	 4377	 4377	 0.0	 0.0	 1	 -30.0	 30.0;
	8961	 6888	 0.00482	 0.02232	 0.0	 381.0	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 7019	 0.00013	 0.000469	 0.0	 381.0	 64904	 64904	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 6253	 0.000229	 0.00075	 0.0	 419.0	 40281	 40281	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 3391	 0.004591	 0.035021	 0.0	 533.0	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 1448	 0.005469	 0.03924	 0.0	 610.0	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 1448	 0.00536	 0.0403	 0.0	 777	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 115	 0.00424	 0.033031	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 4306	 2e-05	 0.00024	 0.0	 757.0	 131160	 131160	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 1763	 1e-05	 0.00021	 0.0	 757.0	 150246	 150246	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3697	 0.00286	 0.03653	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3794	 0.00117	 0.01183	 0.0	 1744.0	 2658	 2658	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3613	 0.00103	 0.01336	 0.0	 1481.0	 2358	 2358	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 1502	 0.00156	 0.01969	 0.0	 1547.0	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 6555	 0.00449	 0.05772	 0.0	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3608	 0.00259	 0.03469	 0.0	 909	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 4134	 0.000219	 0.00118	 0.0	 26320	 26320	 26320	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 1979	 6e-05	 0.00095	 0.0	 33184	 33184	 33184	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 516	 6e-05	 0.000651	 0.0	 629.0	 48317	 48317	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 3580	 8.1e-05	 0.000841	 0.0	 629.0	 37387	 37387	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 3809	 0.00274	 0.020831	 0.0	 514.0	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 5616	 0.004781	 0.027729	 0.0	 553.0	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 5616	 0.002849	 0.02093	 0.0	 572.0	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 6697	 0.00513	 0.03014	 0.0	 514.0	 1034	 1034	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 7165	 0.00113	 0.00651	 0.0	 4781	 4781	 4781	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 892	 0.00125	 0.00707	 0.0	 572.0	 4400	 4400	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 5334	 0.003349	 0.01463	 0.0	 2105	 2105	 2105	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 1526	 0.00245	 0.0122	 0.0	 495.0	 2539	 2539	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6952	 0.00587	 0.036521	 0.0	 400.0	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6952	 0.00569	 0.03774	 0.0	 828	 828	 828	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6952	 0.006031	 0.03545	 0.0	 629.0	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 7883	 0.000531	 0.00301	 0.0	 10335	 10335	 10335	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6430	 0.00076	 0.006099	 0.0	 514.0	 5140	 5140	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 7209	 0.008841	 0.028919	 0.0	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 1910	 0.00169	 0.007091	 0.0	 4334	 4334	 4334	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 6820	 0.001031	 0.00361	 0.0	 8414	 8414	 8414	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 3071	 0.00813	 0.030961	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 6267	 0.00013	 0.00068	 0.0	 533.0	 45626	 45626	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 3855	 0.000211	 0.000729	 0.0	 629.0	 41622	 41622	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 3855	 0.000169	 0.000669	 0.0	 591.0	 45778	 45778	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2928	 0.000669	 0.00251	 0.0	 495.0	 12161	 12161	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2928	 0.000711	 0.00238	 0.0	 476.0	 12717	 12717	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 1172	 0.000229	 0.00238	 0.0	 591.0	 13211	 13211	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 9191	 0.0007	 0.0065	 0.0	 553.0	 4832	 4832	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 8722	 0.00061	 0.006031	 0.0	 514.0	 5211	 5211	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 5362	 0.000281	 0.0018	 0.0	 629.0	 17339	 17339	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 3962	 0.000211	 0.002409	 0.0	 13063	 13063	 13063	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 1343	 0.00056	 0.00773	 0.0	 757.0	 4076	 4076	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 29	 0.0023	 0.01581	 0.0	 1218.0	 1978	 1978	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 3680	 0.005039	 0.032151	 0.0	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 96	 0.00364	 0.01713	 0.0	 457.0	 1804	 1804	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 1868	 0.002169	 0.012409	 0.0	 2508	 2508	 2508	 0.0	 0.0	 1	 -30.0	 30.0;
	346	 3184	 0.00113	 0.004719	 0.0	 6510	 6510	 6510	 0.0	 0.0	 1	 -30.0	 30.0;
	346	 6570	 0.00113	 0.004979	 0.0	 476.0	 6187	 6187	 0.0	 0.0	 1	 -30.0	 30.0;
	3184	 4728	 0.00264	 0.01174	 0.0	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 7886	 0.00494	 0.03181	 0.0	 476.0	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 2132	 0.003711	 0.023961	 0.0	 610.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 8874	 0.001409	 0.01101	 0.0	 457.0	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 1625	 0.001169	 0.00593	 0.0	 381.0	 5227	 5227	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 1625	 0.00118	 0.00587	 0.0	 5276	 5276	 5276	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 3786	 0.00264	 0.012469	 0.0	 533.0	 2479	 2479	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 3786	 0.002349	 0.01414	 0.0	 495.0	 2204	 2204	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 4100	 0.00014	 0.0007	 0.0	 44249	 44249	 44249	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 4419	 3e-05	 0.00054	 0.0	 1876.0	 58406	 58406	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 7159	 3e-05	 0.00055	 0.0	 1810.0	 57347	 57347	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 3661	 4e-05	 0.00058	 0.0	 1777.0	 54332	 54332	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 5486	 4e-05	 0.00054	 0.0	 1876.0	 58336	 58336	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 4231	 0.00171	 0.02197	 0.0	 1382.0	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 4231	 0.00164	 0.02064	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 6921	 0.00136	 0.01756	 0.0	 1711.0	 1794	 1794	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 432	 0.00097	 0.00942	 0.0	 1481.0	 3336	 3336	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 432	 0.00086	 0.01109	 0.0	 1481.0	 2840	 2840	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 432	 0.00085	 0.0113	 0.0	 1448.0	 2788	 2788	 0.0	 0.0	 1	 -30.0	 30.0;
	3353	 6887	 0.000979	 0.0058	 0.0	 400.0	 5371	 5371	 0.0	 0.0	 1	 -30.0	 30.0;
	2479	 2050	 0.00052	 0.00593	 0.0	 1909.0	 5307	 5307	 0.0	 0.0	 1	 -30.0	 30.0;
	2479	 2050	 0.00046	 0.00672	 0.0	 1909.0	 4690	 4690	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 8704	 0.001151	 0.00636	 0.0	 572.0	 4888	 4888	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 8704	 0.001031	 0.007211	 0.0	 591.0	 4337	 4337	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 4710	 0.002341	 0.02286	 0.0	 533.0	 1375	 1375	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 1295	 0.002281	 0.02518	 0.0	 400.0	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 1910	 0.005479	 0.02114	 0.0	 381.0	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 2985	 0.011159	 0.08856	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 5853	 0.000669	 0.00249	 0.0	 400.0	 12252	 12252	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 7824	 0.00193	 0.01643	 0.0	 572.0	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 3071	 0.00024	 0.0017	 0.0	 438.0	 18399	 18399	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 195	 0.010159	 0.065849	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 7367	 0.00294	 0.02131	 0.0	 514.0	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 9155	 0.018841	 0.07469	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 6357	 0.015599	 0.052169	 0.0	 400.0	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 3126	 0.005831	 0.03969	 0.0	 495.0	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 8564	 0.00087	 0.00661	 0.0	 457.0	 4738	 4738	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 5567	 0.00637	 0.024659	 0.0	 381.0	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 3069	 0.0027	 0.020419	 0.0	 553.0	 1534	 1534	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 3876	 0.000409	 0.00314	 0.0	 438.0	 9976	 9976	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 8804	 0.001669	 0.01301	 0.0	 476.0	 2409	 2409	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 8804	 0.00164	 0.01325	 0.0	 495.0	 2366	 2366	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 4550	 0.00089	 0.00556	 0.0	 1283.0	 5610	 5610	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 4125	 0.00186	 0.01809	 0.0	 1613.0	 1737	 1737	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 3346	 0.00381	 0.02853	 0.0	 1020.0	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2377	 0.012419	 0.072151	 0.0	 400.0	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 1401	 0.0042	 0.02556	 0.0	 400.0	 1220	 1220	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2850	 0.010771	 0.0493	 0.0	 476.0	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2430	 0.010159	 0.04995	 0.0	 400.0	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 9164	 0.013169	 0.05113	 0.0	 495.0	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	8511	 1033	 0.000469	 0.001159	 0.0	 400.0	 25264	 25264	 0.0	 0.0	 1	 -30.0	 30.0;
	8511	 6178	 0.000229	 0.00105	 0.0	 457.0	 29393	 29393	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 980	 0.000271	 0.001271	 0.0	 533.0	 24306	 24306	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 4598	 0.00099	 0.01194	 0.0	 1645.0	 2637	 2637	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 4541	 0.00077	 0.01184	 0.0	 2663	 2663	 2663	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 5144	 0.00034	 0.00426	 0.0	 7392	 7392	 7392	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 2129	 0.00101	 0.01168	 0.0	 1744.0	 2695	 2695	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 4541	 0.00086	 0.01046	 0.0	 1810.0	 3010	 3010	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 3513	 0.00035	 0.00417	 0.0	 7549	 7549	 7549	 0.0	 0.0	 1	 -30.0	 30.0;
	6675	 1486	 0.000159	 0.00069	 0.0	 533.0	 44610	 44610	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 5836	 0.000781	 0.00488	 0.0	 629.0	 6392	 6392	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 575	 0.000781	 0.00511	 0.0	 533.0	 6111	 6111	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 8214	 0.00064	 0.003539	 0.0	 457.0	 8784	 8784	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 8214	 0.00057	 0.003781	 0.0	 438.0	 8261	 8261	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 3021	 0.000531	 0.00111	 0.0	 25671	 25671	 25671	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 7967	 0.000521	 0.00113	 0.0	 25386	 25386	 25386	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 5993	 0.00176	 0.00843	 0.0	 438.0	 3668	 3668	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 8804	 0.002461	 0.01975	 0.0	 572.0	 1588	 1588	 0.0	 0.0	 1	 -30.0	 30.0;
	4513	 6831	 0.000591	 0.00105	 0.0	 26216	 26216	 26216	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 1422	 0.00012	 0.00064	 0.0	 48510	 48510	 48510	 0.0	 0.0	 1	 -30.0	 30.0;
	6714	 1808	 0.000581	 0.004419	 0.0	 7088	 7088	 7088	 0.0	 0.0	 1	 -30.0	 30.0;
	6371	 1808	 0.000651	 0.004331	 0.0	 7213	 7213	 7213	 0.0	 0.0	 1	 -30.0	 30.0;
	513	 2866	 0.001289	 0.008289	 0.0	 495.0	 3766	 3766	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 9222	 0.00233	 0.03502	 0.0	 757.0	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 9222	 0.00238	 0.03781	 0.0	 757.0	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 2072	 0.00052	 0.00605	 0.0	 1382.0	 5202	 5202	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 5461	 0.00023	 0.00275	 0.0	 1514.0	 11447	 11447	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 8109	 0.00134	 0.01343	 0.0	 1711.0	 2341	 2341	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 8109	 0.00116	 0.01552	 0.0	 1481.0	 2030	 2030	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 707	 0.004169	 0.027919	 0.0	 514.0	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 4816	 0.00063	 0.008	 0.0	 3937	 3937	 3937	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 1866	 0.004841	 0.028581	 0.0	 629.0	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 5488	 0.007419	 0.05787	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 2467	 0.002719	 0.020331	 0.0	 495.0	 1540	 1540	 0.0	 0.0	 1	 -30.0	 30.0;
	2328	 7178	 0.000789	 0.005	 0.0	 6241	 6241	 6241	 0.0	 0.0	 1	 -30.0	 30.0;
	9180	 195	 0.00238	 0.013219	 0.0	 457.0	 2352	 2352	 0.0	 0.0	 1	 -30.0	 30.0;
	9180	 3133	 0.003771	 0.02701	 0.0	 495.0	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 4544	 0.001271	 0.00939	 0.0	 3334	 3334	 3334	 0.0	 0.0	 1	 -30.0	 30.0;
	9002	 6737	 0.000841	 0.00131	 0.0	 20291	 20291	 20291	 0.0	 0.0	 1	 -30.0	 30.0;
	8439	 3758	 0.005711	 0.043039	 0.0	 591.0	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	8439	 3758	 0.00562	 0.041901	 0.0	 495.0	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 2940	 0.00356	 0.019781	 0.0	 533.0	 1572	 1572	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 163	 0.004841	 0.03149	 0.0	 533.0	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	747	 8507	 0.00057	 0.00107	 0.0	 26055	 26055	 26055	 0.0	 0.0	 1	 -30.0	 30.0;
	6909	 4914	 0.000539	 0.00213	 0.0	 514.0	 14377	 14377	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 4747	 0.0007	 0.00425	 0.0	 7334	 7334	 7334	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 6495	 0.0012	 0.009531	 0.0	 3289	 3289	 3289	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 2751	 0.00206	 0.015901	 0.0	 1971	 1971	 1971	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 4728	 0.00063	 0.00312	 0.0	 9924	 9924	 9924	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 6475	 3e-05	 0.00041	 0.0	 1481.0	 76837	 76837	 0.0	 0.0	 1	 -30.0	 30.0;
	1093	 6475	 2e-05	 0.00043	 0.0	 73380	 73380	 73380	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 6475	 3e-05	 0.00039	 0.0	 1283.0	 80755	 80755	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 6475	 3e-05	 0.00038	 0.0	 82867	 82867	 82867	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 3503	 0.0008	 0.004151	 0.0	 7473	 7473	 7473	 0.0	 0.0	 1	 -30.0	 30.0;
	4549	 3503	 0.000901	 0.00381	 0.0	 8069	 8069	 8069	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 639	 0.000591	 0.004341	 0.0	 476.0	 7210	 7210	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 639	 0.000591	 0.00405	 0.0	 495.0	 7718	 7718	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 4541	 0.00218	 0.0275	 0.0	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 8195	 0.00184	 0.01677	 0.0	 1086.0	 1873	 1873	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 964	 0.00058	 0.00807	 0.0	 1086.0	 3905	 3905	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 964	 0.00056	 0.00823	 0.0	 921.0	 3830	 3830	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 3906	 0.00123	 0.01146	 0.0	 1415.0	 2741	 2741	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 3906	 0.0011	 0.01298	 0.0	 1481.0	 2425	 2425	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 8347	 0.00156	 0.01585	 0.0	 1777.0	 1984	 1984	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 2919	 0.00226	 0.02781	 0.0	 1133	 1133	 1133	 0.0	 0.0	 1	 -30.0	 30.0;
	3758	 188	 0.00614	 0.02831	 0.0	 400.0	 1091	 1091	 0.0	 0.0	 1	 -30.0	 30.0;
	3758	 2242	 0.00513	 0.03401	 0.0	 919	 919	 919	 0.0	 0.0	 1	 -30.0	 30.0;
	3903	 4114	 0.013219	 0.0597	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 6990	 0.012969	 0.06087	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	8626	 8930	 0.00437	 0.032831	 0.0	 553.0	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	8626	 2467	 0.005651	 0.033229	 0.0	 591.0	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 5488	 0.008969	 0.03625	 0.0	 438.0	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 7772	 0.012409	 0.05645	 0.0	 419.0	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 6382	 0.00038	 0.002271	 0.0	 400.0	 13719	 13719	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 4084	 0.00138	 0.01089	 0.0	 572.0	 2878	 2878	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 4084	 0.001539	 0.012521	 0.0	 591.0	 2504	 2504	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 53	 0.00205	 0.014229	 0.0	 533.0	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 7259	 0.00026	 0.00164	 0.0	 495.0	 19023	 19023	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 2475	 0.000289	 0.00169	 0.0	 18424	 18424	 18424	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 7577	 0.003349	 0.051211	 0.0	 457.0	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	7961	 2288	 0.00038	 0.001479	 0.0	 20686	 20686	 20686	 0.0	 0.0	 1	 -30.0	 30.0;
	1592	 7098	 0.00082	 0.00625	 0.0	 553.0	 5012	 5012	 0.0	 0.0	 1	 -30.0	 30.0;
	3187	 2079	 0.00275	 0.015581	 0.0	 572.0	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	6041	 5926	 0.000909	 0.00739	 0.0	 4243	 4243	 4243	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 8486	 0.00082	 0.01038	 0.0	 1547.0	 3034	 3034	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 7530	 0.00093	 0.01017	 0.0	 1382.0	 3094	 3094	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 1502	 0.00137	 0.01431	 0.0	 1876.0	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 1552	 0.00215	 0.02021	 0.0	 1555	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	6952	 3793	 0.01189	 0.058841	 0.0	 457.0	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2526	 0.00104	 0.01241	 0.0	 1251.0	 2537	 2537	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2526	 0.00092	 0.014	 0.0	 1251.0	 2252	 2252	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2365	 0.00055	 0.00845	 0.0	 1152.0	 3731	 3731	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2365	 0.00054	 0.00861	 0.0	 987.0	 3662	 3662	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 3794	 0.00105	 0.01057	 0.0	 1810.0	 2974	 2974	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 3613	 0.00089	 0.01122	 0.0	 1613.0	 2807	 2807	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 6901	 0.00223	 0.02584	 0.0	 1218	 1218	 1218	 0.0	 0.0	 1	 -30.0	 30.0;
	8180	 5106	 0.00101	 0.007841	 0.0	 553.0	 3996	 3996	 0.0	 0.0	 1	 -30.0	 30.0;
	8180	 5106	 0.001081	 0.008099	 0.0	 572.0	 3866	 3866	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 7165	 0.011081	 0.068479	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 8721	 2e-05	 0.00033	 0.0	 95544	 95544	 95544	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 8872	 1e-05	 0.00029	 0.0	 1777.0	 108858	 108858	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 8672	 0.00071	 0.00892	 0.0	 1580.0	 3531	 3531	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 7164	 0.00136	 0.01526	 0.0	 1448.0	 2062	 2062	 0.0	 0.0	 1	 -30.0	 30.0;
	5935	 7772	 0.005401	 0.036021	 0.0	 591.0	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 3430	 0.00437	 0.033719	 0.0	 457.0	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 1051	 0.005151	 0.034919	 0.0	 514.0	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 800	 0.00038	 0.00139	 0.0	 21921	 21921	 21921	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 1077	 0.00037	 0.0015	 0.0	 20446	 20446	 20446	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 4747	 0.00069	 0.004461	 0.0	 533.0	 6998	 6998	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 5213	 0.00688	 0.040591	 0.0	 381.0	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 115	 0.001341	 0.008349	 0.0	 476.0	 3736	 3736	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 115	 0.001229	 0.009669	 0.0	 629.0	 3241	 3241	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 5753	 0.00137	 0.006039	 0.0	 419.0	 5101	 5101	 0.0	 0.0	 1	 -30.0	 30.0;
	7539	 6556	 0.001919	 0.01261	 0.0	 476.0	 2477	 2477	 0.0	 0.0	 1	 -30.0	 30.0;
	7539	 871	 0.00163	 0.0095	 0.0	 533.0	 3278	 3278	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 8874	 0.00488	 0.0497	 0.0	 572.0	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 4505	 0.001289	 0.0087	 0.0	 553.0	 3592	 3592	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 3436	 0.00211	 0.01524	 0.0	 572.0	 2054	 2054	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 3436	 0.00206	 0.015539	 0.0	 591.0	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 3436	 0.00276	 0.01631	 0.0	 514.0	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 6556	 0.00305	 0.019521	 0.0	 610.0	 1599	 1599	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 8765	 0.000409	 0.0023	 0.0	 495.0	 13522	 13522	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 6619	 0.00036	 0.00268	 0.0	 514.0	 11682	 11682	 0.0	 0.0	 1	 -30.0	 30.0;
	8165	 6734	 0.00032	 0.00049	 0.0	 53974	 53974	 53974	 0.0	 0.0	 1	 -30.0	 30.0;
	1078	 6734	 0.00013	 0.000349	 0.0	 84816	 84816	 84816	 0.0	 0.0	 1	 -30.0	 30.0;
	7988	 4231	 0.0002	 0.00327	 0.0	 9642	 9642	 9642	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 2142	 0.000919	 0.00561	 0.0	 533.0	 5557	 5557	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 2142	 0.00094	 0.00549	 0.0	 533.0	 5672	 5672	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 7519	 0.00175	 0.01976	 0.0	 533.0	 1593	 1593	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 6744	 0.001729	 0.019331	 0.0	 476.0	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 6802	 0.00406	 0.02581	 0.0	 572.0	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 769	 0.00526	 0.025961	 0.0	 514.0	 1193	 1193	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 1081	 0.00179	 0.02098	 0.0	 1349.0	 1501	 1501	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 5983	 0.00162	 0.02148	 0.0	 1382.0	 1467	 1467	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 8267	 0.00492	 0.04991	 0.0	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 960	 0.00109	 0.01361	 0.0	 1086.0	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 960	 0.00097	 0.0153	 0.0	 889.0	 2061	 2061	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 3906	 0.00322	 0.03022	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 7361	 0.032831	 0.074151	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 6852	 0.01411	 0.058711	 0.0	 514.0	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 8515	 0.02725	 0.102979	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 3166	 0.012229	 0.04049	 0.0	 400.0	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 2676	 0.01994	 0.066719	 0.0	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 3793	 0.018591	 0.07462	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 4529	 0.008979	 0.03251	 0.0	 937	 937	 937	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 4234	 0.016531	 0.086031	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 44	 0.003591	 0.02137	 0.0	 591.0	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 6630	 0.00124	 0.008	 0.0	 400.0	 3902	 3902	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 6630	 0.001271	 0.007831	 0.0	 438.0	 3982	 3982	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 1545	 0.000469	 0.00294	 0.0	 495.0	 10610	 10610	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 4215	 0.000841	 0.003289	 0.0	 495.0	 9305	 9305	 0.0	 0.0	 1	 -30.0	 30.0;
	7163	 1917	 0.00219	 0.016539	 0.0	 400.0	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	7163	 5519	 0.002901	 0.020901	 0.0	 400.0	 1497	 1497	 0.0	 0.0	 1	 -30.0	 30.0;
	7647	 225	 0.0002	 0.001211	 0.0	 25736	 25736	 25736	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 1397	 9.1e-05	 0.000479	 0.0	 64786	 64786	 64786	 0.0	 0.0	 1	 -30.0	 30.0;
	7021	 7119	 0.005461	 0.029469	 0.0	 419.0	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	7021	 3324	 0.001979	 0.011289	 0.0	 591.0	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	1248	 163	 0.0023	 0.01289	 0.0	 2413	 2413	 2413	 0.0	 0.0	 1	 -30.0	 30.0;
	9045	 2457	 0.000159	 0.00037	 0.0	 78436	 78436	 78436	 0.0	 0.0	 1	 -30.0	 30.0;
	8874	 3786	 0.002789	 0.01562	 0.0	 533.0	 1991	 1991	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 5574	 0.002531	 0.012331	 0.0	 381.0	 2510	 2510	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 7663	 0.00357	 0.023289	 0.0	 400.0	 1341	 1341	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 4889	 0.00076	 0.006039	 0.0	 514.0	 5190	 5190	 0.0	 0.0	 1	 -30.0	 30.0;
	3997	 1526	 0.000469	 0.00075	 0.0	 35710	 35710	 35710	 0.0	 0.0	 1	 -30.0	 30.0;
	184	 1526	 0.00044	 0.00069	 0.0	 38599	 38599	 38599	 0.0	 0.0	 1	 -30.0	 30.0;
	2972	 2088	 0.00561	 0.035521	 0.0	 591.0	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	8676	 933	 0.004539	 0.03468	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	8676	 933	 0.00175	 0.0067	 0.0	 419.0	 4562	 4562	 0.0	 0.0	 1	 -30.0	 30.0;
	8676	 3643	 0.007461	 0.031419	 0.0	 400.0	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	8704	 6723	 0.00224	 0.012909	 0.0	 610.0	 2411	 2411	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 21	 0.0003	 0.000961	 0.0	 419.0	 31376	 31376	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 21	 0.00032	 0.001409	 0.0	 21862	 21862	 21862	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 1551	 0.002031	 0.0157	 0.0	 553.0	 1996	 1996	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 4103	 0.00038	 0.00306	 0.0	 514.0	 10244	 10244	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 7862	 0.00118	 0.0083	 0.0	 553.0	 3768	 3768	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 5458	 0.001229	 0.00787	 0.0	 572.0	 3966	 3966	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 5666	 0.00301	 0.01538	 0.0	 514.0	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 5458	 0.00063	 0.00114	 0.0	 381.0	 24252	 24252	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 7862	 0.00064	 0.00111	 0.0	 24653	 24653	 24653	 0.0	 0.0	 1	 -30.0	 30.0;
	7775	 3857	 0.004919	 0.03837	 0.0	 629.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 3436	 0.001831	 0.008349	 0.0	 438.0	 3696	 3696	 0.0	 0.0	 1	 -30.0	 30.0;
	3430	 401	 0.00536	 0.03188	 0.0	 533.0	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	2967	 8976	 0.00038	 0.001461	 0.0	 20925	 20925	 20925	 0.0	 0.0	 1	 -30.0	 30.0;
	2967	 8976	 0.000289	 0.001521	 0.0	 20403	 20403	 20403	 0.0	 0.0	 1	 -30.0	 30.0;
	8976	 2481	 0.00305	 0.016841	 0.0	 476.0	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	8976	 9108	 0.001781	 0.012729	 0.0	 457.0	 2458	 2458	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 7520	 0.00041	 0.00461	 0.0	 954.0	 6825	 6825	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 7520	 0.0004	 0.0047	 0.0	 1020.0	 6697	 6697	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 5340	 0.00213	 0.01401	 0.0	 629.0	 2230	 2230	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 2319	 0.001271	 0.00887	 0.0	 438.0	 3526	 3526	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 2878	 0.00462	 0.02743	 0.0	 533.0	 1136	 1136	 0.0	 0.0	 1	 -30.0	 30.0;
	2597	 7422	 0.001539	 0.00776	 0.0	 3993	 3993	 3993	 0.0	 0.0	 1	 -30.0	 30.0;
	7183	 8931	 0.00025	 0.00478	 0.0	 10070	 10070	 10070	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 8931	 0.00025	 0.00487	 0.0	 9884	 9884	 9884	 0.0	 0.0	 1	 -30.0	 30.0;
	8128	 8931	 0.00025	 0.00435	 0.0	 823.0	 7250	 7250	 0.0	 0.0	 1	 -30.0	 30.0;
	6337	 8931	 0.00026	 0.00426	 0.0	 757.0	 7402	 7402	 0.0	 0.0	 1	 -30.0	 30.0;
	1237	 8931	 0.00025	 0.00479	 0.0	 10049	 10049	 10049	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 9173	 0.000169	 0.00076	 0.0	 438.0	 40572	 40572	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 7974	 0.00039	 0.00126	 0.0	 495.0	 23949	 23949	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 4816	 0.011229	 0.074659	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 1866	 0.014521	 0.058081	 0.0	 400.0	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 8809	 0.00064	 0.003919	 0.0	 533.0	 7955	 7955	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 5146	 0.014789	 0.07768	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 6940	 0.00938	 0.05355	 0.0	 572.0	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 1742	 0.00124	 0.004289	 0.0	 419.0	 7075	 7075	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 8627	 0.00968	 0.04388	 0.0	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 174	 0.008531	 0.067151	 0.0	 457.0	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 7437	 0.00731	 0.04106	 0.0	 438.0	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 5940	 0.004349	 0.02555	 0.0	 533.0	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 7495	 0.00599	 0.03462	 0.0	 476.0	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 4816	 0.002961	 0.021591	 0.0	 553.0	 1450	 1450	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 4816	 0.002901	 0.02206	 0.0	 572.0	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 6053	 0.002979	 0.016969	 0.0	 476.0	 1834	 1834	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 4189	 0.00312	 0.020021	 0.0	 476.0	 1559	 1559	 0.0	 0.0	 1	 -30.0	 30.0;
	8507	 1973	 0.000219	 0.000909	 0.0	 33783	 33783	 33783	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 1973	 0.000219	 0.00093	 0.0	 457.0	 33061	 33061	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 2128	 0.000151	 0.000289	 0.0	 96873	 96873	 96873	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 8255	 0.00563	 0.043599	 0.0	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 4748	 0.000969	 0.00612	 0.0	 514.0	 5098	 5098	 0.0	 0.0	 1	 -30.0	 30.0;
	3486	 3594	 0.005021	 0.020719	 0.0	 438.0	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	3486	 4679	 0.00988	 0.041039	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 4235	 0.003159	 0.02011	 0.0	 476.0	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 4235	 0.003219	 0.01969	 0.0	 476.0	 1584	 1584	 0.0	 0.0	 1	 -30.0	 30.0;
	7129	 5441	 0.00049	 0.00238	 0.0	 13000	 13000	 13000	 0.0	 0.0	 1	 -30.0	 30.0;
	7129	 5441	 0.000479	 0.002419	 0.0	 12810	 12810	 12810	 0.0	 0.0	 1	 -30.0	 30.0;
	8250	 5720	 0.00264	 0.019729	 0.0	 533.0	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	8250	 5720	 0.002581	 0.02011	 0.0	 495.0	 1558	 1558	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 6723	 0.00037	 0.002831	 0.0	 553.0	 11064	 11064	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 5686	 0.00213	 0.012789	 0.0	 514.0	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	2377	 805	 0.018669	 0.092281	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	907	 9091	 3.9e-05	 0.000401	 0.0	 78402	 78402	 78402	 0.0	 0.0	 1	 -30.0	 30.0;
	4056	 9091	 6e-05	 0.00044	 0.0	 381.0	 71132	 71132	 0.0	 0.0	 1	 -30.0	 30.0;
	6837	 2142	 6e-05	 0.0005	 0.0	 514.0	 62725	 62725	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 2641	 0.001271	 0.007031	 0.0	 476.0	 4421	 4421	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 7577	 0.00055	 0.003159	 0.0	 610.0	 9851	 9851	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 7577	 0.00055	 0.00338	 0.0	 591.0	 9225	 9225	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 7577	 0.00105	 0.004771	 0.0	 495.0	 6466	 6466	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 1629	 0.003289	 0.015039	 0.0	 381.0	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 687	 0.00036	 0.004349	 0.0	 610.0	 7239	 7239	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 687	 0.00038	 0.003669	 0.0	 8564	 8564	 8564	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 2425	 0.00118	 0.00701	 0.0	 4444	 4444	 4444	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 2425	 0.001229	 0.00686	 0.0	 533.0	 4533	 4533	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 5907	 0.00301	 0.0217	 0.0	 1442	 1442	 1442	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 5907	 0.003409	 0.01924	 0.0	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 5907	 0.003409	 0.01938	 0.0	 572.0	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	7847	 9217	 0.002719	 0.02131	 0.0	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	2981	 1448	 0.00295	 0.01956	 0.0	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 5686	 0.001091	 0.00831	 0.0	 476.0	 3769	 3769	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 5907	 0.00111	 0.008211	 0.0	 553.0	 3813	 3813	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 2155	 0.002469	 0.015271	 0.0	 629.0	 2042	 2042	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 8112	 0.00212	 0.01601	 0.0	 1956	 1956	 1956	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 2535	 0.00037	 0.0028	 0.0	 533.0	 11184	 11184	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 7098	 0.00162	 0.01238	 0.0	 2530	 2530	 2530	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 7098	 0.001909	 0.01162	 0.0	 2683	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 7098	 0.001909	 0.010729	 0.0	 553.0	 2899	 2899	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 3737	 0.00089	 0.00526	 0.0	 419.0	 5922	 5922	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 5529	 0.00087	 0.00536	 0.0	 5818	 5818	 5818	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 5753	 0.001521	 0.01176	 0.0	 533.0	 2664	 2664	 0.0	 0.0	 1	 -30.0	 30.0;
	9019	 6563	 0.00014	 0.000591	 0.0	 476.0	 52008	 52008	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 1101	 0.003531	 0.028781	 0.0	 1090	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 8291	 0.004599	 0.03657	 0.0	 553.0	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 8367	 0.00307	 0.019159	 0.0	 591.0	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 1100	 0.000581	 0.004461	 0.0	 514.0	 7022	 7022	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 6887	 0.00164	 0.01161	 0.0	 591.0	 2694	 2694	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 6880	 0.00057	 0.003281	 0.0	 533.0	 9486	 9486	 0.0	 0.0	 1	 -30.0	 30.0;
	7738	 6982	 0.020419	 0.063669	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	6565	 3121	 0.01424	 0.04751	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	8707	 280	 0.00157	 0.008849	 0.0	 553.0	 3515	 3515	 0.0	 0.0	 1	 -30.0	 30.0;
	8707	 2510	 0.01218	 0.07524	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 766	 0.00037	 0.00151	 0.0	 20318	 20318	 20318	 0.0	 0.0	 1	 -30.0	 30.0;
	8411	 6232	 0.000219	 0.000531	 0.0	 54993	 54993	 54993	 0.0	 0.0	 1	 -30.0	 30.0;
	3951	 1397	 0.002849	 0.0137	 0.0	 2258	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 7282	 0.00116	 0.01692	 0.0	 1283.0	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 7282	 0.00133	 0.01462	 0.0	 1415.0	 2152	 2152	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 6475	 0.00063	 0.00821	 0.0	 987.0	 3837	 3837	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 6475	 0.00064	 0.00804	 0.0	 1283.0	 3917	 3917	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 5420	 0.00126	 0.01272	 0.0	 1382.0	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 8267	 0.00337	 0.0494	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 7328	 0.0014	 0.0214	 0.0	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 7328	 0.00137	 0.02182	 0.0	 1445	 1445	 1445	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 7164	 0.00212	 0.02063	 0.0	 1218.0	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 410	 0.00186	 0.01045	 0.0	 610.0	 2976	 2976	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 7579	 0.00426	 0.021771	 0.0	 438.0	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 7579	 0.002659	 0.020539	 0.0	 495.0	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 4189	 0.00606	 0.049919	 0.0	 457.0	 629	 629	 0.0	 0.0	 1	 -30.0	 30.0;
	7282	 4196	 0.00109	 0.01192	 0.0	 889.0	 2639	 2639	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 3916	 0.013021	 0.049219	 0.0	 438.0	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 4747	 0.00236	 0.01239	 0.0	 438.0	 2505	 2505	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 4747	 0.0027	 0.015169	 0.0	 419.0	 2051	 2051	 0.0	 0.0	 1	 -30.0	 30.0;
	4541	 3346	 0.00285	 0.03283	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	4541	 3346	 0.00529	 0.03969	 0.0	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 3346	 0.00254	 0.03721	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2719	 0.000159	 0.00069	 0.0	 44610	 44610	 44610	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2719	 0.000229	 0.000979	 0.0	 31417	 31417	 31417	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2719	 0.00024	 0.00082	 0.0	 36971	 36971	 36971	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 795	 0.000169	 0.00075	 0.0	 41087	 41087	 41087	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 4880	 0.00368	 0.01756	 0.0	 1761	 1761	 1761	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 1868	 0.002599	 0.020659	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 5564	 0.00018	 0.00064	 0.0	 47512	 47512	 47512	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 7036	 0.000159	 0.000771	 0.0	 381.0	 40125	 40125	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 5940	 0.00357	 0.01981	 0.0	 476.0	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 7495	 0.006021	 0.03205	 0.0	 533.0	 969	 969	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 2886	 0.001781	 0.01164	 0.0	 533.0	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 7049	 0.002781	 0.018831	 0.0	 514.0	 1660	 1660	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 6146	 0.000349	 0.00281	 0.0	 11156	 11156	 11156	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 1860	 0.00313	 0.02444	 0.0	 610.0	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 1860	 0.00368	 0.02074	 0.0	 591.0	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 3276	 9.1e-05	 0.001539	 0.0	 20489	 20489	 20489	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 3545	 0.00251	 0.01111	 0.0	 2774	 2774	 2774	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 6842	 0.003081	 0.017961	 0.0	 419.0	 1734	 1734	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 6744	 0.005341	 0.030419	 0.0	 438.0	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 7635	 9.9e-05	 0.00126	 0.0	 514.0	 24993	 24993	 0.0	 0.0	 1	 -30.0	 30.0;
	9091	 1040	 0.002169	 0.017901	 0.0	 419.0	 1752	 1752	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 6178	 0.00011	 0.00038	 0.0	 79847	 79847	 79847	 0.0	 0.0	 1	 -30.0	 30.0;
	1422	 1462	 0.00212	 0.00494	 0.0	 5876	 5876	 5876	 0.0	 0.0	 1	 -30.0	 30.0;
	1422	 7772	 0.018901	 0.077349	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	7881	 5365	 0.00957	 0.0395	 0.0	 457.0	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	7881	 6982	 0.02324	 0.063469	 0.0	 400.0	 468	 468	 0.0	 0.0	 1	 -30.0	 30.0;
	6926	 3327	 0.000531	 0.004331	 0.0	 610.0	 7240	 7240	 0.0	 0.0	 1	 -30.0	 30.0;
	1959	 615	 0.002581	 0.006229	 0.0	 4685	 4685	 4685	 0.0	 0.0	 1	 -30.0	 30.0;
	6455	 1262	 0.00031	 0.002211	 0.0	 419.0	 14149	 14149	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 6982	 0.01087	 0.06114	 0.0	 438.0	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 5918	 0.011581	 0.061099	 0.0	 419.0	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	7624	 3070	 0.002099	 0.016271	 0.0	 400.0	 1926	 1926	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 1547	 0.00093	 0.005461	 0.0	 5703	 5703	 5703	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 5237	 0.009591	 0.037039	 0.0	 419.0	 826	 826	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 772	 0.002591	 0.017211	 0.0	 553.0	 1815	 1815	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 8950	 0.00164	 0.013651	 0.0	 495.0	 2298	 2298	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 2079	 0.003219	 0.014719	 0.0	 457.0	 2097	 2097	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 2229	 0.00401	 0.022229	 0.0	 457.0	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 7049	 0.00126	 0.010211	 0.0	 591.0	 3071	 3071	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 7873	 0.009169	 0.03993	 0.0	 772	 772	 772	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 3865	 0.001349	 0.006081	 0.0	 5072	 5072	 5072	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 8486	 0.00156	 0.01931	 0.0	 1580.0	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 7530	 0.00152	 0.01968	 0.0	 1481.0	 1601	 1601	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 7778	 0.00094	 0.01433	 0.0	 1678.0	 2200	 2200	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 6897	 0.00092	 0.01461	 0.0	 1448.0	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 960	 0.00137	 0.02012	 0.0	 1119.0	 1567	 1567	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 960	 0.00134	 0.02051	 0.0	 921.0	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 4491	 0.00314	 0.042151	 0.0	 572.0	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 6010	 0.000651	 0.00494	 0.0	 6340	 6340	 6340	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 6940	 0.003961	 0.02426	 0.0	 591.0	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	858	 1642	 0.00013	 0.0015	 0.0	 20980	 20980	 20980	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 809	 0.00013	 0.00147	 0.0	 1876.0	 21405	 21405	 0.0	 0.0	 1	 -30.0	 30.0;
	4819	 1642	 0.00011	 0.00172	 0.0	 1876.0	 18328	 18328	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 809	 0.00012	 0.00166	 0.0	 18979	 18979	 18979	 0.0	 0.0	 1	 -30.0	 30.0;
	3869	 1642	 0.00012	 0.00168	 0.0	 1909.0	 18755	 18755	 0.0	 0.0	 1	 -30.0	 30.0;
	3741	 809	 0.00012	 0.00172	 0.0	 1909.0	 18321	 18321	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 687	 0.00093	 0.005669	 0.0	 5499	 5499	 5499	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 7098	 0.00105	 0.00506	 0.0	 6113	 6113	 6113	 0.0	 0.0	 1	 -30.0	 30.0;
	5688	 6231	 0.00113	 0.006539	 0.0	 4761	 4761	 4761	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 5455	 0.00037	 0.002919	 0.0	 10736	 10736	 10736	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 5695	 0.005169	 0.03738	 0.0	 476.0	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	3814	 954	 0.00125	 0.006669	 0.0	 457.0	 4656	 4656	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 2438	 0.001281	 0.00661	 0.0	 4692	 4692	 4692	 0.0	 0.0	 1	 -30.0	 30.0;
	195	 2985	 0.00226	 0.0138	 0.0	 457.0	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 3513	 0.00213	 0.02677	 0.0	 1177	 1177	 1177	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 3346	 0.00154	 0.01919	 0.0	 1349.0	 1641	 1641	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 601	 0.00687	 0.04413	 0.0	 708	 708	 708	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 3241	 0.0045	 0.04725	 0.0	 457.0	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 7338	 0.00138	 0.00837	 0.0	 3724	 3724	 3724	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 1538	 0.000419	 0.001901	 0.0	 16227	 16227	 16227	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 1538	 0.00043	 0.00186	 0.0	 16547	 16547	 16547	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 4729	 0.003331	 0.015099	 0.0	 591.0	 2043	 2043	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 6616	 0.002099	 0.01631	 0.0	 533.0	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 5616	 0.001331	 0.01082	 0.0	 591.0	 2898	 2898	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 6691	 0.00199	 0.00818	 0.0	 381.0	 3753	 3753	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 6691	 0.00169	 0.008831	 0.0	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 892	 0.001771	 0.014281	 0.0	 2196	 2196	 2196	 0.0	 0.0	 1	 -30.0	 30.0;
	601	 616	 0.003099	 0.01844	 0.0	 495.0	 1690	 1690	 0.0	 0.0	 1	 -30.0	 30.0;
	3496	 1551	 0.003409	 0.01819	 0.0	 438.0	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 2230	 0.00057	 0.00369	 0.0	 8460	 8460	 8460	 0.0	 0.0	 1	 -30.0	 30.0;
	8057	 5907	 0.001081	 0.00468	 0.0	 6577	 6577	 6577	 0.0	 0.0	 1	 -30.0	 30.0;
	5354	 5907	 0.00105	 0.004771	 0.0	 6466	 6466	 6466	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 616	 0.001979	 0.01549	 0.0	 591.0	 2023	 2023	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 7338	 0.001469	 0.015151	 0.0	 2076	 2076	 2076	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 5083	 0.000711	 0.003969	 0.0	 419.0	 7834	 7834	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 7576	 0.00051	 0.00274	 0.0	 11334	 11334	 11334	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 3191	 0.000521	 0.00306	 0.0	 495.0	 10177	 10177	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 3488	 0.00188	 0.011841	 0.0	 2635	 2635	 2635	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 1578	 0.002469	 0.010539	 0.0	 2919	 2919	 2919	 0.0	 0.0	 1	 -30.0	 30.0;
	575	 5300	 0.00045	 0.00351	 0.0	 514.0	 8927	 8927	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 9173	 0.00037	 0.000659	 0.0	 41796	 41796	 41796	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 3818	 0.000401	 0.0007	 0.0	 39156	 39156	 39156	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 6232	 0.00014	 0.000531	 0.0	 57521	 57521	 57521	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 1643	 0.000289	 0.0013	 0.0	 495.0	 23719	 23719	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 6253	 7e-05	 0.000289	 0.0	 106228	 106228	 106228	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 6684	 0.00051	 0.002151	 0.0	 381.0	 14289	 14289	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 8151	 0.00037	 0.00157	 0.0	 533.0	 19583	 19583	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 449	 0.00022	 0.00277	 0.0	 1448.0	 11368	 11368	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 449	 0.00025	 0.00271	 0.0	 1547.0	 11607	 11607	 0.0	 0.0	 1	 -30.0	 30.0;
	7641	 3037	 0.000271	 0.002081	 0.0	 572.0	 15052	 15052	 0.0	 0.0	 1	 -30.0	 30.0;
	7641	 3037	 0.00025	 0.00231	 0.0	 533.0	 13595	 13595	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 2340	 0.00095	 0.00331	 0.0	 9173	 9173	 9173	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 8711	 0.00093	 0.00336	 0.0	 9061	 9061	 9061	 0.0	 0.0	 1	 -30.0	 30.0;
	8104	 8722	 0.000341	 0.002211	 0.0	 591.0	 14120	 14120	 0.0	 0.0	 1	 -30.0	 30.0;
	2644	 9191	 0.00032	 0.00232	 0.0	 13488	 13488	 13488	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 8522	 3.9e-05	 0.000271	 0.0	 514.0	 115370	 115370	 0.0	 0.0	 1	 -30.0	 30.0;
	604	 7522	 0.00075	 0.0101	 0.0	 1613.0	 3119	 3119	 0.0	 0.0	 1	 -30.0	 30.0;
	604	 4000	 0.00118	 0.01455	 0.0	 1547.0	 2164	 2164	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 9021	 0.0017	 0.0098	 0.0	 514.0	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 9021	 0.001521	 0.01111	 0.0	 2817	 2817	 2817	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 2042	 0.000169	 0.001401	 0.0	 22385	 22385	 22385	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 687	 0.002591	 0.01725	 0.0	 610.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 3520	 0.000169	 0.001159	 0.0	 438.0	 26969	 26969	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 4729	 0.00307	 0.01339	 0.0	 533.0	 2300	 2300	 0.0	 0.0	 1	 -30.0	 30.0;
	2641	 4889	 0.002591	 0.013521	 0.0	 514.0	 2295	 2295	 0.0	 0.0	 1	 -30.0	 30.0;
	9067	 9051	 0.000581	 0.005031	 0.0	 553.0	 6238	 6238	 0.0	 0.0	 1	 -30.0	 30.0;
	6969	 5573	 0.001419	 0.00595	 0.0	 381.0	 5164	 5164	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 1494	 0.00205	 0.02664	 0.0	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 2732	 0.00295	 0.03721	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 4550	 0.00335	 0.03648	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 1607	 0.00022	 0.00251	 0.0	 1251.0	 12537	 12537	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 2093	 0.00059	 0.00651	 0.0	 1645.0	 4833	 4833	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 2177	 0.008539	 0.041979	 0.0	 381.0	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 2841	 0.001349	 0.0052	 0.0	 400.0	 5880	 5880	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 7972	 0.00245	 0.013909	 0.0	 514.0	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 2481	 0.001469	 0.008419	 0.0	 553.0	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 7164	 0.00084	 0.00836	 0.0	 1349.0	 3760	 3760	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 2078	 0.002591	 0.017789	 0.0	 514.0	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 7873	 0.009651	 0.05968	 0.0	 419.0	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	7422	 7519	 0.00143	 0.00799	 0.0	 381.0	 3892	 3892	 0.0	 0.0	 1	 -30.0	 30.0;
	7422	 6744	 0.001969	 0.014909	 0.0	 572.0	 2101	 2101	 0.0	 0.0	 1	 -30.0	 30.0;
	1026	 1860	 0.01039	 0.06406	 0.0	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 3327	 0.000719	 0.005331	 0.0	 438.0	 5873	 5873	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 6921	 0.00052	 0.00565	 0.0	 1415.0	 5568	 5568	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 7069	 0.002409	 0.019479	 0.0	 495.0	 1610	 1610	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 7069	 0.00256	 0.019151	 0.0	 419.0	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 2866	 0.00656	 0.02288	 0.0	 381.0	 1328	 1328	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 6450	 0.0027	 0.014901	 0.0	 400.0	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 5738	 0.003591	 0.01362	 0.0	 400.0	 2243	 2243	 0.0	 0.0	 1	 -30.0	 30.0;
	7327	 2481	 0.002211	 0.01188	 0.0	 2614	 2614	 2614	 0.0	 0.0	 1	 -30.0	 30.0;
	7327	 8189	 0.00068	 0.00357	 0.0	 400.0	 8692	 8692	 0.0	 0.0	 1	 -30.0	 30.0;
	7474	 1584	 0.000211	 0.000969	 0.0	 400.0	 31852	 31852	 0.0	 0.0	 1	 -30.0	 30.0;
	8947	 3390	 9.9e-05	 0.000539	 0.0	 57640	 57640	 57640	 0.0	 0.0	 1	 -30.0	 30.0;
	1808	 6384	 0.00645	 0.0263	 0.0	 419.0	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	4624	 6031	 0.00063	 0.001901	 0.0	 15773	 15773	 15773	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 3558	 0.000281	 0.000669	 0.0	 43532	 43532	 43532	 0.0	 0.0	 1	 -30.0	 30.0;
	7694	 3865	 0.000219	 0.00064	 0.0	 46697	 46697	 46697	 0.0	 0.0	 1	 -30.0	 30.0;
	9181	 6723	 0.00014	 0.00105	 0.0	 29820	 29820	 29820	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 8748	 0.003219	 0.020729	 0.0	 533.0	 1506	 1506	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 8475	 0.00051	 0.003151	 0.0	 572.0	 9896	 9896	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 8475	 0.000409	 0.00331	 0.0	 514.0	 9471	 9471	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 6639	 0.002289	 0.017479	 0.0	 591.0	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 1187	 0.002831	 0.01895	 0.0	 533.0	 1649	 1649	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 7274	 0.006289	 0.036521	 0.0	 853	 853	 853	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 8992	 0.005651	 0.032169	 0.0	 438.0	 968	 968	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 7266	 0.00414	 0.02262	 0.0	 476.0	 1374	 1374	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 6734	 0.01095	 0.05814	 0.0	 457.0	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 1015	 0.009	 0.0368	 0.0	 495.0	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 8310	 0.000229	 0.00181	 0.0	 553.0	 17314	 17314	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 6570	 0.00119	 0.00726	 0.0	 610.0	 4294	 4294	 0.0	 0.0	 1	 -30.0	 30.0;
	9137	 749	 0.011771	 0.051669	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	7522	 2183	 0.00209	 0.02279	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 3916	 0.002031	 0.01443	 0.0	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 6891	 0.00145	 0.008479	 0.0	 553.0	 3673	 3673	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 6199	 0.00124	 0.01433	 0.0	 1514.0	 2197	 2197	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 6199	 0.00127	 0.01402	 0.0	 1876.0	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	1483	 3649	 0.013039	 0.052841	 0.0	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 6199	 0.00235	 0.02739	 0.0	 954.0	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 6199	 0.0024	 0.02681	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 4141	 0.00135	 0.02056	 0.0	 757.0	 1534	 1534	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 1311	 0.00087	 0.01124	 0.0	 954.0	 2802	 2802	 0.0	 0.0	 1	 -30.0	 30.0;
	8316	 174	 0.0012	 0.00818	 0.0	 629.0	 3821	 3821	 0.0	 0.0	 1	 -30.0	 30.0;
	174	 6430	 0.006961	 0.05561	 0.0	 495.0	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 7892	 0.00105	 0.00763	 0.0	 476.0	 4102	 4102	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 561	 0.000219	 0.00182	 0.0	 17232	 17232	 17232	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 8843	 3.9e-05	 0.0002	 0.0	 155017	 155017	 155017	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 8843	 4.5e-05	 0.000195	 0.0	 157839	 157839	 157839	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 4239	 0.0035	 0.022651	 0.0	 533.0	 1379	 1379	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 1860	 0.004281	 0.02319	 0.0	 457.0	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 5395	 0.003729	 0.014021	 0.0	 419.0	 2178	 2178	 0.0	 0.0	 1	 -30.0	 30.0;
	7042	 2177	 0.00212	 0.01582	 0.0	 572.0	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	8672	 7164	 0.00056	 0.00784	 0.0	 757.0	 4019	 4019	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 7772	 0.004401	 0.01813	 0.0	 1694	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 7772	 0.005021	 0.02144	 0.0	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	4885	 2928	 0.00018	 0.000219	 0.0	 381.0	 111427	 111427	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 2928	 0.000151	 0.000211	 0.0	 121741	 121741	 121741	 0.0	 0.0	 1	 -30.0	 30.0;
	4432	 2928	 0.000151	 0.000211	 0.0	 121741	 121741	 121741	 0.0	 0.0	 1	 -30.0	 30.0;
	2072	 5983	 0.00282	 0.02591	 0.0	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	3450	 6552	 0.00131	 0.008539	 0.0	 533.0	 3657	 3657	 0.0	 0.0	 1	 -30.0	 30.0;
	3956	 7507	 0.002159	 0.015969	 0.0	 1961	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 1838	 0.00019	 0.000281	 0.0	 93122	 93122	 93122	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 2230	 0.0002	 0.000281	 0.0	 91583	 91583	 91583	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 8005	 0.00139	 0.00774	 0.0	 572.0	 4017	 4017	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 6351	 0.01101	 0.06739	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 2749	 0.00063	 0.00463	 0.0	 438.0	 6761	 6761	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 9130	 0.002341	 0.009599	 0.0	 476.0	 3197	 3197	 0.0	 0.0	 1	 -30.0	 30.0;
	410	 4189	 0.00375	 0.021659	 0.0	 476.0	 1438	 1438	 0.0	 0.0	 1	 -30.0	 30.0;
	1494	 5781	 0.00056	 0.00749	 0.0	 1283.0	 4206	 4206	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 6616	 0.00118	 0.00926	 0.0	 533.0	 3384	 3384	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 6031	 0.002039	 0.013081	 0.0	 514.0	 2386	 2386	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 7507	 0.00155	 0.010961	 0.0	 2854	 2854	 2854	 0.0	 0.0	 1	 -30.0	 30.0;
	3276	 7635	 3.9e-05	 0.00036	 0.0	 419.0	 87233	 87233	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 196	 0.00024	 0.000409	 0.0	 381.0	 66610	 66610	 0.0	 0.0	 1	 -30.0	 30.0;
	8522	 7132	 0.000341	 0.001659	 0.0	 553.0	 18651	 18651	 0.0	 0.0	 1	 -30.0	 30.0;
	8522	 5351	 0.005461	 0.024919	 0.0	 457.0	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 7056	 0.00158	 0.02413	 0.0	 954.0	 1307	 1307	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8825	 0.00155	 0.02458	 0.0	 856.0	 1283	 1283	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 6889	 0.00021	 0.00256	 0.0	 1415.0	 12298	 12298	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 6889	 0.00024	 0.00243	 0.0	 1514.0	 12936	 12936	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8887	 0.00144	 0.02266	 0.0	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8887	 0.0014	 0.02098	 0.0	 1503	 1503	 1503	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8487	 0.00086	 0.01074	 0.0	 2932	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	8748	 8475	 0.003341	 0.02611	 0.0	 553.0	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 6785	 0.00387	 0.02063	 0.0	 514.0	 1505	 1505	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 6785	 0.00405	 0.018271	 0.0	 514.0	 1688	 1688	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 1179	 0.00101	 0.00462	 0.0	 400.0	 6680	 6680	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 2575	 0.00088	 0.00389	 0.0	 419.0	 7921	 7921	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 7274	 0.005081	 0.039	 0.0	 514.0	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 8189	 0.00257	 0.0208	 0.0	 553.0	 1508	 1508	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 8189	 0.00251	 0.01926	 0.0	 514.0	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 1039	 0.002531	 0.01314	 0.0	 2361	 2361	 2361	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 7840	 0.00132	 0.00869	 0.0	 3594	 3594	 3594	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 8913	 0.00082	 0.004021	 0.0	 419.0	 7698	 7698	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 4852	 0.00143	 0.007479	 0.0	 438.0	 4149	 4149	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 1183	 0.000659	 0.005771	 0.0	 5439	 5439	 5439	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 1183	 0.000591	 0.006539	 0.0	 4811	 4811	 4811	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 6291	 0.00589	 0.025599	 0.0	 476.0	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 6982	 0.00614	 0.02343	 0.0	 438.0	 1305	 1305	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 1798	 0.00155	 0.01994	 0.0	 1481.0	 1580	 1580	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 3346	 0.00205	 0.03218	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 3346	 0.00233	 0.03154	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	4725	 5738	 0.002341	 0.01982	 0.0	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 8310	 8.1e-05	 0.000521	 0.0	 533.0	 59909	 59909	 0.0	 0.0	 1	 -30.0	 30.0;
	1398	 5567	 9.9e-05	 0.00069	 0.0	 591.0	 45315	 45315	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 4580	 0.00276	 0.016419	 0.0	 553.0	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 4908	 0.00036	 0.001229	 0.0	 457.0	 24666	 24666	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 3740	 0.000229	 0.000711	 0.0	 514.0	 42288	 42288	 0.0	 0.0	 1	 -30.0	 30.0;
	6563	 870	 0.00013	 0.00099	 0.0	 514.0	 31635	 31635	 0.0	 0.0	 1	 -30.0	 30.0;
	8999	 6495	 0.001159	 0.00689	 0.0	 419.0	 4522	 4522	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 5994	 0.008531	 0.03045	 0.0	 381.0	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 8005	 0.000781	 0.004531	 0.0	 514.0	 6871	 6871	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 8005	 0.00075	 0.00474	 0.0	 533.0	 6583	 6583	 0.0	 0.0	 1	 -30.0	 30.0;
	5881	 4031	 0.002159	 0.008349	 0.0	 3663	 3663	 3663	 0.0	 0.0	 1	 -30.0	 30.0;
	8195	 8334	 0.00162	 0.01651	 0.0	 1547.0	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 6357	 0.01236	 0.044211	 0.0	 400.0	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 6357	 0.00825	 0.03989	 0.0	 419.0	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 3775	 0.02187	 0.066961	 0.0	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 3975	 0.01212	 0.06661	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 1642	 0.00036	 0.00534	 0.0	 889.0	 5902	 5902	 0.0	 0.0	 1	 -30.0	 30.0;
	6802	 1153	 0.000229	 0.00063	 0.0	 47123	 47123	 47123	 0.0	 0.0	 1	 -30.0	 30.0;
	6802	 7599	 0.000219	 0.000581	 0.0	 50874	 50874	 50874	 0.0	 0.0	 1	 -30.0	 30.0;
	4025	 3994	 0.000281	 0.00063	 0.0	 45791	 45791	 45791	 0.0	 0.0	 1	 -30.0	 30.0;
	1595	 1414	 0.005021	 0.035659	 0.0	 419.0	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	3114	 3656	 0.00174	 0.007901	 0.0	 3905	 3905	 3905	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 2229	 0.003919	 0.020581	 0.0	 495.0	 1508	 1508	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 9108	 0.003341	 0.016349	 0.0	 495.0	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 1478	 0.003271	 0.016669	 0.0	 457.0	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 8515	 0.000151	 0.000659	 0.0	 419.0	 46722	 46722	 0.0	 0.0	 1	 -30.0	 30.0;
	6405	 7873	 0.00736	 0.035659	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	6405	 3894	 0.00944	 0.042169	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 4734	 0.00068	 0.00652	 0.0	 856.0	 4819	 4819	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 3483	 0.00188	 0.02281	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 7052	 0.00168	 0.00956	 0.0	 533.0	 3255	 3255	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 7052	 0.001669	 0.00981	 0.0	 514.0	 3175	 3175	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 772	 0.002229	 0.01599	 0.0	 591.0	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 772	 0.00218	 0.01631	 0.0	 610.0	 1920	 1920	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 6475	 0.00238	 0.02124	 0.0	 1053.0	 1478	 1478	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 6475	 0.00194	 0.02023	 0.0	 1251.0	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	7361	 3166	 0.013831	 0.05955	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	7361	 426	 0.00876	 0.04875	 0.0	 419.0	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 1857	 0.0002	 0.00099	 0.0	 400.0	 31275	 31275	 0.0	 0.0	 1	 -30.0	 30.0;
	1364	 2430	 0.00105	 0.00826	 0.0	 476.0	 3794	 3794	 0.0	 0.0	 1	 -30.0	 30.0;
	2177	 749	 0.0172	 0.06637	 0.0	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 2850	 0.00305	 0.015781	 0.0	 476.0	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	6555	 3608	 0.00208	 0.02105	 0.0	 1481.0	 1494	 1494	 0.0	 0.0	 1	 -30.0	 30.0;
	8475	 1965	 0.00614	 0.043729	 0.0	 476.0	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	8475	 5926	 0.000229	 0.001849	 0.0	 553.0	 16954	 16954	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 6053	 0.00386	 0.025789	 0.0	 438.0	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 2341	 0.002031	 0.012	 0.0	 591.0	 2596	 2596	 0.0	 0.0	 1	 -30.0	 30.0;
	2629	 7507	 0.000591	 0.004	 0.0	 495.0	 7813	 7813	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 2406	 9.1e-05	 0.00051	 0.0	 60973	 60973	 60973	 0.0	 0.0	 1	 -30.0	 30.0;
	7577	 5814	 0.00732	 0.039969	 0.0	 419.0	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	7577	 3231	 0.004581	 0.02031	 0.0	 629.0	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	7663	 5814	 0.00132	 0.00537	 0.0	 457.0	 5713	 5713	 0.0	 0.0	 1	 -30.0	 30.0;
	1183	 1159	 0.007521	 0.0387	 0.0	 476.0	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	6852	 5051	 0.005159	 0.031281	 0.0	 533.0	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	8307	 8807	 9.9e-05	 0.001159	 0.0	 27156	 27156	 27156	 0.0	 0.0	 1	 -30.0	 30.0;
	6947	 8807	 9.9e-05	 0.00113	 0.0	 27847	 27847	 27847	 0.0	 0.0	 1	 -30.0	 30.0;
	4505	 4357	 0.00019	 0.000909	 0.0	 381.0	 34015	 34015	 0.0	 0.0	 1	 -30.0	 30.0;
	7144	 7791	 0.00107	 0.00413	 0.0	 7404	 7404	 7404	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 2085	 9e-05	 0.00058	 0.0	 1251.0	 53817	 53817	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 4024	 9e-05	 0.00059	 0.0	 1152.0	 52926	 52926	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 9065	 8e-05	 0.00053	 0.0	 757.0	 58932	 58932	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 661	 8e-05	 0.00052	 0.0	 757.0	 60039	 60039	 0.0	 0.0	 1	 -30.0	 30.0;
	6612	 8864	 0.000271	 0.00151	 0.0	 495.0	 20590	 20590	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00053	 0.00585	 0.0	 1909.0	 5378	 5378	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00047	 0.00663	 0.0	 1448.0	 4753	 4753	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00046	 0.00676	 0.0	 1251.0	 4662	 4662	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00045	 0.00689	 0.0	 1251.0	 4575	 4575	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 8494	 0.00028	 0.00338	 0.0	 1580.0	 9314	 9314	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 8494	 0.0003	 0.00319	 0.0	 1349.0	 9859	 9859	 0.0	 0.0	 1	 -30.0	 30.0;
	1643	 4511	 0.00025	 0.00101	 0.0	 476.0	 30359	 30359	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 1973	 0.000281	 0.00119	 0.0	 25834	 25834	 25834	 0.0	 0.0	 1	 -30.0	 30.0;
	2902	 5573	 0.00018	 0.00063	 0.0	 48210	 48210	 48210	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 4410	 0.00382	 0.02868	 0.0	 1092	 1092	 1092	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 333	 0.00361	 0.0235	 0.0	 572.0	 1329	 1329	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 6908	 0.00538	 0.03569	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 7726	 6e-05	 0.000409	 0.0	 514.0	 76413	 76413	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 3243	 9e-05	 0.00102	 0.0	 757.0	 30849	 30849	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 2458	 0.0014	 0.01649	 0.0	 1711.0	 1909	 1909	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 2919	 0.00034	 0.00427	 0.0	 1119.0	 7375	 7375	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 8560	 0.0001	 0.00109	 0.0	 757.0	 28859	 28859	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 6427	 0.00137	 0.01682	 0.0	 1777.0	 1872	 1872	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 8347	 0.00131	 0.01262	 0.0	 1514.0	 2490	 2490	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 5610	 0.00262	 0.019669	 0.0	 533.0	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 2421	 0.00082	 0.00526	 0.0	 476.0	 5934	 5934	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 2421	 0.000841	 0.005151	 0.0	 457.0	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 2421	 0.000669	 0.005081	 0.0	 476.0	 6164	 6164	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 6989	 0.001919	 0.012669	 0.0	 476.0	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 1545	 0.002659	 0.02	 0.0	 1566	 1566	 1566	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 3541	 0.003031	 0.02343	 0.0	 572.0	 1338	 1338	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 4710	 0.01176	 0.059159	 0.0	 400.0	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 8367	 0.002469	 0.017531	 0.0	 495.0	 1785	 1785	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 2288	 0.000669	 0.005729	 0.0	 5477	 5477	 5477	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 8473	 0.000781	 0.00876	 0.0	 381.0	 3592	 3592	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 5455	 0.00062	 0.00482	 0.0	 553.0	 6500	 6500	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 7635	 0.001349	 0.012599	 0.0	 533.0	 2493	 2493	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 8473	 0.000979	 0.0082	 0.0	 3825	 3825	 3825	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 883	 0.008091	 0.028831	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 2288	 0.000711	 0.005969	 0.0	 514.0	 5255	 5255	 0.0	 0.0	 1	 -30.0	 30.0;
	3969	 7726	 0.00145	 0.00857	 0.0	 3635	 3635	 3635	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 1129	 0.00869	 0.03768	 0.0	 400.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 3070	 0.001719	 0.00837	 0.0	 457.0	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 5365	 0.01582	 0.067349	 0.0	 438.0	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 5365	 0.01457	 0.06469	 0.0	 400.0	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 4529	 0.021711	 0.090539	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 3364	 0.00019	 0.000729	 0.0	 400.0	 41929	 41929	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 5383	 0.001271	 0.00638	 0.0	 400.0	 4856	 4856	 0.0	 0.0	 1	 -30.0	 30.0;
	920	 6570	 3.9e-05	 0.0002	 0.0	 400.0	 155017	 155017	 0.0	 0.0	 1	 -30.0	 30.0;
	6664	 4426	 0.000281	 0.00236	 0.0	 629.0	 13291	 13291	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 2183	 0.00019	 0.00329	 0.0	 1744.0	 9586	 9586	 0.0	 0.0	 1	 -30.0	 30.0;
	7513	 4000	 0.00035	 0.00324	 0.0	 9693	 9693	 9693	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 8542	 0.00049	 0.00349	 0.0	 419.0	 8963	 8963	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 8542	 0.000469	 0.00331	 0.0	 419.0	 9449	 9449	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 1662	 0.00313	 0.01324	 0.0	 2322	 2322	 2322	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 9119	 0.001031	 0.006719	 0.0	 476.0	 4647	 4647	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 1151	 0.00038	 0.00401	 0.0	 7843	 7843	 7843	 0.0	 0.0	 1	 -30.0	 30.0;
	502	 3589	 0.00037	 0.002849	 0.0	 495.0	 10995	 10995	 0.0	 0.0	 1	 -30.0	 30.0;
	8473	 1040	 0.00032	 0.00256	 0.0	 476.0	 12244	 12244	 0.0	 0.0	 1	 -30.0	 30.0;
	8473	 145	 0.00037	 0.00118	 0.0	 381.0	 25543	 25543	 0.0	 0.0	 1	 -30.0	 30.0;
	8473	 4267	 0.00068	 0.001151	 0.0	 23628	 23628	 23628	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 5179	 0.00168	 0.009841	 0.0	 495.0	 3164	 3164	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 8854	 0.000599	 0.002401	 0.0	 400.0	 12765	 12765	 0.0	 0.0	 1	 -30.0	 30.0;
	9018	 4	 0.002169	 0.00911	 0.0	 400.0	 3374	 3374	 0.0	 0.0	 1	 -30.0	 30.0;
	9018	 4829	 0.002849	 0.01282	 0.0	 457.0	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 5383	 0.001229	 0.01207	 0.0	 553.0	 2604	 2604	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 7507	 0.001289	 0.01089	 0.0	 610.0	 2881	 2881	 0.0	 0.0	 1	 -30.0	 30.0;
	8887	 1644	 0.00093	 0.01036	 0.0	 856.0	 3037	 3037	 0.0	 0.0	 1	 -30.0	 30.0;
	8887	 3483	 0.00083	 0.01174	 0.0	 823.0	 2684	 2684	 0.0	 0.0	 1	 -30.0	 30.0;
	6639	 7840	 0.00118	 0.009469	 0.0	 3311	 3311	 3311	 0.0	 0.0	 1	 -30.0	 30.0;
	6639	 7840	 0.001151	 0.009651	 0.0	 3250	 3250	 3250	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 8109	 0.00101	 0.01327	 0.0	 1580.0	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	6291	 4189	 0.00364	 0.02486	 0.0	 572.0	 1258	 1258	 0.0	 0.0	 1	 -30.0	 30.0;
	8405	 4747	 0.00056	 0.00425	 0.0	 533.0	 7369	 7369	 0.0	 0.0	 1	 -30.0	 30.0;
	8405	 4580	 0.00369	 0.02681	 0.0	 533.0	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	338	 7824	 0.000531	 0.00276	 0.0	 400.0	 11239	 11239	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 7824	 0.000521	 0.00281	 0.0	 381.0	 11053	 11053	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 7824	 0.000419	 0.00232	 0.0	 13399	 13399	 13399	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 7824	 0.000409	 0.00237	 0.0	 13134	 13134	 13134	 0.0	 0.0	 1	 -30.0	 30.0;
	8458	 8267	 0.00014	 0.00193	 0.0	 1514.0	 16324	 16324	 0.0	 0.0	 1	 -30.0	 30.0;
	2676	 5987	 0.003211	 0.01481	 0.0	 419.0	 2085	 2085	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 5712	 0.00381	 0.01175	 0.0	 2558	 2558	 2558	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 6521	 0.003781	 0.02676	 0.0	 419.0	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 8636	 0.000919	 0.005461	 0.0	 553.0	 5704	 5704	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 8829	 0.000271	 0.001211	 0.0	 381.0	 25455	 25455	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 4235	 0.002229	 0.017401	 0.0	 572.0	 1801	 1801	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 4235	 0.00243	 0.017659	 0.0	 610.0	 1773	 1773	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 4235	 0.002531	 0.01705	 0.0	 591.0	 1833	 1833	 0.0	 0.0	 1	 -30.0	 30.0;
	8818	 5099	 0.012531	 0.05451	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 4734	 0.00087	 0.01212	 0.0	 1349.0	 2600	 2600	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 905	 0.0006	 0.00802	 0.0	 1711.0	 3928	 3928	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 8334	 0.00072	 0.00667	 0.0	 1843.0	 4709	 4709	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 2093	 0.00234	 0.02626	 0.0	 1199	 1199	 1199	 0.0	 0.0	 1	 -30.0	 30.0;
	6772	 6989	 0.00038	 0.002969	 0.0	 514.0	 10553	 10553	 0.0	 0.0	 1	 -30.0	 30.0;
	7885	 3912	 0.00024	 0.00045	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	6730	 3912	 0.000229	 0.000409	 0.0	 67388	 67388	 67388	 0.0	 0.0	 1	 -30.0	 30.0;
	4301	 3912	 0.000281	 0.000401	 0.0	 64510	 64510	 64510	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 5610	 0.001211	 0.005271	 0.0	 5841	 5841	 5841	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 350	 0.000281	 0.00107	 0.0	 438.0	 28553	 28553	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 6763	 0.00025	 0.001091	 0.0	 28222	 28222	 28222	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 1973	 0.00019	 0.00081	 0.0	 629.0	 37967	 37967	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 1973	 0.00045	 0.00136	 0.0	 591.0	 22051	 22051	 0.0	 0.0	 1	 -30.0	 30.0;
	3481	 554	 0.003461	 0.023289	 0.0	 1342	 1342	 1342	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 8222	 0.0013	 0.01609	 0.0	 1843.0	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 8222	 0.00128	 0.0164	 0.0	 1711.0	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 2721	 0.00089	 0.01082	 0.0	 1580.0	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 2721	 0.00087	 0.01102	 0.0	 1645.0	 2858	 2858	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 8578	 0.003349	 0.02514	 0.0	 533.0	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 2653	 0.0003	 0.00061	 0.0	 46468	 46468	 46468	 0.0	 0.0	 1	 -30.0	 30.0;
	148	 7069	 0.000289	 0.001211	 0.0	 514.0	 25372	 25372	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 8743	 0.01301	 0.044091	 0.0	 438.0	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 1742	 0.02162	 0.065969	 0.0	 400.0	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	8930	 314	 0.006461	 0.05275	 0.0	 514.0	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	6954	 7974	 0.0002	 0.000271	 0.0	 93784	 93784	 93784	 0.0	 0.0	 1	 -30.0	 30.0;
	3325	 7974	 0.00018	 0.00026	 0.0	 99888	 99888	 99888	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 1742	 0.00032	 0.00188	 0.0	 16564	 16564	 16564	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 6989	 0.00105	 0.006591	 0.0	 476.0	 4733	 4733	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 6163	 0.00013	 0.00055	 0.0	 55892	 55892	 55892	 0.0	 0.0	 1	 -30.0	 30.0;
	3749	 5365	 0.006151	 0.04013	 0.0	 629.0	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	3749	 6982	 0.007159	 0.040591	 0.0	 533.0	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 3133	 0.00874	 0.048461	 0.0	 400.0	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 4738	 0.004159	 0.01606	 0.0	 1905	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 3656	 0.002919	 0.01912	 0.0	 533.0	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 4300	 0.00094	 0.00394	 0.0	 419.0	 7799	 7799	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 5789	 0.000901	 0.00395	 0.0	 7797	 7797	 7797	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 2467	 0.003159	 0.017789	 0.0	 572.0	 1749	 1749	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 2467	 0.002419	 0.018331	 0.0	 1709	 1709	 1709	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 5256	 0.00375	 0.018281	 0.0	 419.0	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 2653	 0.00025	 0.001031	 0.0	 419.0	 29775	 29775	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 4852	 0.00264	 0.01238	 0.0	 419.0	 2496	 2496	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 4852	 0.001289	 0.00795	 0.0	 457.0	 3923	 3923	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 1151	 0.00087	 0.003081	 0.0	 476.0	 9867	 9867	 0.0	 0.0	 1	 -30.0	 30.0;
	8568	 5215	 0.000401	 0.00224	 0.0	 419.0	 13881	 13881	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 221	 0.0003	 0.00385	 0.0	 8180	 8180	 8180	 0.0	 0.0	 1	 -30.0	 30.0;
	6807	 851	 0.00126	 0.008219	 0.0	 533.0	 3799	 3799	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 5099	 0.01905	 0.055729	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 3558	 0.00201	 0.00444	 0.0	 6482	 6482	 6482	 0.0	 0.0	 1	 -30.0	 30.0;
	7209	 2934	 0.00101	 0.00324	 0.0	 9308	 9308	 9308	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 4787	 0.00105	 0.00677	 0.0	 1218.0	 4611	 4611	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 3830	 0.00039	 0.00502	 0.0	 1152.0	 6274	 6274	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 5648	 0.0004	 0.00492	 0.0	 954.0	 6400	 6400	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 4000	 0.00051	 0.00617	 0.0	 1349.0	 5103	 5103	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 3485	 0.0003	 0.00314	 0.0	 1580.0	 10015	 10015	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 3830	 0.00051	 0.00668	 0.0	 1645.0	 4715	 4715	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 5648	 0.0005	 0.00678	 0.0	 1777.0	 4647	 4647	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 2424	 0.002909	 0.017	 0.0	 1832	 1832	 1832	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 1156	 0.00245	 0.011281	 0.0	 476.0	 2737	 2737	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 4914	 0.0027	 0.01532	 0.0	 457.0	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 4914	 0.00105	 0.011151	 0.0	 2821	 2821	 2821	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 3834	 0.00036	 0.002669	 0.0	 11729	 11729	 11729	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 556	 0.0018	 0.011169	 0.0	 457.0	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 3019	 0.000711	 0.007771	 0.0	 4048	 4048	 4048	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 7923	 0.00036	 0.00257	 0.0	 12172	 12172	 12172	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 4103	 0.00201	 0.01195	 0.0	 610.0	 2607	 2607	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 7862	 0.001091	 0.00731	 0.0	 572.0	 4274	 4274	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 5458	 0.00105	 0.007591	 0.0	 629.0	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 1838	 0.00299	 0.02256	 0.0	 476.0	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	3070	 2888	 0.00036	 0.00288	 0.0	 10884	 10884	 10884	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 4504	 0.00589	 0.045599	 0.0	 553.0	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 3579	 0.00157	 0.0127	 0.0	 476.0	 2469	 2469	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 3579	 0.00168	 0.011969	 0.0	 2614	 2614	 2614	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 7903	 0.00289	 0.021031	 0.0	 438.0	 1488	 1488	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 1102	 0.00395	 0.025211	 0.0	 572.0	 1238	 1238	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 9217	 0.002771	 0.021659	 0.0	 476.0	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 5653	 0.002979	 0.016901	 0.0	 553.0	 1841	 1841	 0.0	 0.0	 1	 -30.0	 30.0;
	8478	 5907	 0.007419	 0.034021	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 6921	 0.00056	 0.00813	 0.0	 889.0	 3877	 3877	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 1813	 0.00361	 0.015211	 0.0	 438.0	 2021	 2021	 0.0	 0.0	 1	 -30.0	 30.0;
	8950	 7049	 0.000409	 0.003331	 0.0	 629.0	 9413	 9413	 0.0	 0.0	 1	 -30.0	 30.0;
	6846	 8788	 0.004091	 0.019599	 0.0	 476.0	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	6846	 6734	 0.00294	 0.012841	 0.0	 495.0	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 5616	 0.020771	 0.080479	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 1965	 0.00662	 0.0513	 0.0	 553.0	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 1767	 0.00607	 0.04581	 0.0	 533.0	 684	 684	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 1102	 0.000669	 0.0042	 0.0	 476.0	 7428	 7428	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 8485	 0.001271	 0.007419	 0.0	 476.0	 4197	 4197	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 5653	 0.001599	 0.012271	 0.0	 572.0	 2553	 2553	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 4661	 0.009599	 0.05024	 0.0	 419.0	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 520	 0.00149	 0.009219	 0.0	 438.0	 3383	 3383	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 6816	 0.01488	 0.06724	 0.0	 400.0	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 5918	 0.003599	 0.024031	 0.0	 419.0	 1300	 1300	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 5918	 0.00519	 0.024	 0.0	 438.0	 1287	 1287	 0.0	 0.0	 1	 -30.0	 30.0;
	8636	 1380	 0.003461	 0.013349	 0.0	 400.0	 2291	 2291	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 4239	 0.00105	 0.01236	 0.0	 2547	 2547	 2547	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 4239	 0.00199	 0.012331	 0.0	 495.0	 2529	 2529	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 3656	 0.00711	 0.044711	 0.0	 438.0	 698	 698	 0.0	 0.0	 1	 -30.0	 30.0;
	6203	 7124	 0.006729	 0.02543	 0.0	 1201	 1201	 1201	 0.0	 0.0	 1	 -30.0	 30.0;
	9059	 7124	 0.005771	 0.02999	 0.0	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	5994	 96	 0.0048	 0.021771	 0.0	 1417	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	5049	 306	 0.00286	 0.02212	 0.0	 533.0	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 8397	 0.00351	 0.02175	 0.0	 514.0	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 6982	 0.008401	 0.0448	 0.0	 572.0	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	7202	 8807	 0.0018	 0.01187	 0.0	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	7202	 8807	 0.001831	 0.01163	 0.0	 2683	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	8592	 2995	 0.00075	 0.00538	 0.0	 5816	 5816	 5816	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 823	 2e-05	 0.00033	 0.0	 95544	 95544	 95544	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 1680	 1e-05	 0.00034	 0.0	 1810.0	 92864	 92864	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 953	 0.00023	 0.00258	 0.0	 823.0	 12195	 12195	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 1817	 0.00023	 0.00252	 0.0	 757.0	 12483	 12483	 0.0	 0.0	 1	 -30.0	 30.0;
	3231	 1504	 0.002031	 0.008531	 0.0	 3602	 3602	 3602	 0.0	 0.0	 1	 -30.0	 30.0;
	3231	 7226	 0.005349	 0.020789	 0.0	 419.0	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	2928	 7865	 0.0002	 0.00082	 0.0	 495.0	 37425	 37425	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 6891	 0.002091	 0.011219	 0.0	 2768	 2768	 2768	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 171	 0.00262	 0.016979	 0.0	 533.0	 1839	 1839	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 171	 0.002669	 0.01663	 0.0	 591.0	 1876	 1876	 0.0	 0.0	 1	 -30.0	 30.0;
	8829	 3044	 0.00025	 0.00118	 0.0	 514.0	 26188	 26188	 0.0	 0.0	 1	 -30.0	 30.0;
	1552	 1194	 0.00056	 0.00715	 0.0	 1645.0	 4405	 4405	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 3740	 0.0007	 0.00455	 0.0	 438.0	 6862	 6862	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 2695	 0.000331	 0.001711	 0.0	 381.0	 18126	 18126	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 2695	 0.00011	 0.000781	 0.0	 553.0	 40050	 40050	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 8877	 0.00111	 0.00664	 0.0	 438.0	 4693	 4693	 0.0	 0.0	 1	 -30.0	 30.0;
	7520	 8222	 0.00066	 0.00838	 0.0	 1547.0	 3758	 3758	 0.0	 0.0	 1	 -30.0	 30.0;
	7520	 8222	 0.00064	 0.00854	 0.0	 1547.0	 3689	 3689	 0.0	 0.0	 1	 -30.0	 30.0;
	2421	 3610	 0.003091	 0.017091	 0.0	 572.0	 1819	 1819	 0.0	 0.0	 1	 -30.0	 30.0;
	2421	 1414	 0.00643	 0.03687	 0.0	 629.0	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	8879	 3610	 0.00275	 0.01937	 0.0	 1615	 1615	 1615	 0.0	 0.0	 1	 -30.0	 30.0;
	8397	 5918	 0.00357	 0.021289	 0.0	 514.0	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	1914	 6982	 0.000289	 0.002789	 0.0	 11266	 11266	 11266	 0.0	 0.0	 1	 -30.0	 30.0;
	7873	 6638	 0.002531	 0.01345	 0.0	 381.0	 2308	 2308	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 7702	 0.00162	 0.012159	 0.0	 514.0	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 7702	 0.00262	 0.01168	 0.0	 419.0	 2639	 2639	 0.0	 0.0	 1	 -30.0	 30.0;
	8835	 1156	 0.00099	 0.006081	 0.0	 5127	 5127	 5127	 0.0	 0.0	 1	 -30.0	 30.0;
	8835	 1233	 0.000909	 0.005979	 0.0	 5224	 5224	 5224	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 408	 0.00011	 0.0008	 0.0	 39117	 39117	 39117	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 7231	 0.00011	 0.00068	 0.0	 45856	 45856	 45856	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 5993	 0.00207	 0.008341	 0.0	 495.0	 3676	 3676	 0.0	 0.0	 1	 -30.0	 30.0;
	1910	 2550	 0.00019	 0.001031	 0.0	 30131	 30131	 30131	 0.0	 0.0	 1	 -30.0	 30.0;
	3975	 7353	 0.014039	 0.0667	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	3126	 7495	 0.004961	 0.03043	 0.0	 438.0	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	2689	 5753	 0.00056	 0.003531	 0.0	 8836	 8836	 8836	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 4235	 0.001461	 0.00889	 0.0	 514.0	 3507	 3507	 0.0	 0.0	 1	 -30.0	 30.0;
	7626	 7076	 6e-05	 0.000419	 0.0	 495.0	 74627	 74627	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 4060	 0.00139	 0.005169	 0.0	 5902	 5902	 5902	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 1311	 0.00069	 0.00825	 0.0	 757.0	 3816	 3816	 0.0	 0.0	 1	 -30.0	 30.0;
	7124	 4566	 0.004969	 0.030781	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	7124	 8873	 0.00012	 0.000969	 0.0	 591.0	 32351	 32351	 0.0	 0.0	 1	 -30.0	 30.0;
	6684	 5383	 0.001091	 0.010159	 0.0	 572.0	 3092	 3092	 0.0	 0.0	 1	 -30.0	 30.0;
	8151	 5383	 0.000969	 0.00887	 0.0	 553.0	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	4357	 6619	 0.00099	 0.006789	 0.0	 514.0	 4605	 4605	 0.0	 0.0	 1	 -30.0	 30.0;
	8191	 8765	 0.001031	 0.00586	 0.0	 381.0	 5309	 5309	 0.0	 0.0	 1	 -30.0	 30.0;
	7466	 5469	 0.00401	 0.03345	 0.0	 629.0	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	3401	 5351	 9.1e-05	 0.000349	 0.0	 87580	 87580	 87580	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 225	 0.00125	 0.00745	 0.0	 591.0	 4182	 4182	 0.0	 0.0	 1	 -30.0	 30.0;
	53	 4031	 0.003711	 0.024219	 0.0	 514.0	 1290	 1290	 0.0	 0.0	 1	 -30.0	 30.0;
	8222	 6921	 0.00169	 0.02156	 0.0	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	8222	 6921	 0.00171	 0.02114	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	6556	 4239	 0.00088	 0.00562	 0.0	 533.0	 5553	 5553	 0.0	 0.0	 1	 -30.0	 30.0;
	6556	 4239	 0.0008	 0.00618	 0.0	 572.0	 5069	 5069	 0.0	 0.0	 1	 -30.0	 30.0;
	2940	 7178	 0.00161	 0.01014	 0.0	 3077	 3077	 3077	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 2563	 0.00032	 0.002031	 0.0	 533.0	 15364	 15364	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 6521	 0.00011	 0.000659	 0.0	 495.0	 47279	 47279	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 3830	 0.00042	 0.00505	 0.0	 1086.0	 6234	 6234	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 5648	 0.00043	 0.00494	 0.0	 1251.0	 6371	 6371	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 4914	 0.00038	 0.000711	 0.0	 39182	 39182	 39182	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 4914	 0.00037	 0.000659	 0.0	 41796	 41796	 41796	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 1644	 0.00248	 0.03096	 0.0	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	163	 3498	 0.00375	 0.019729	 0.0	 495.0	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	163	 2430	 0.00518	 0.020021	 0.0	 438.0	 1528	 1528	 0.0	 0.0	 1	 -30.0	 30.0;
	7943	 9108	 0.000771	 0.003711	 0.0	 495.0	 8334	 8334	 0.0	 0.0	 1	 -30.0	 30.0;
	7943	 1478	 0.00076	 0.003789	 0.0	 457.0	 8174	 8174	 0.0	 0.0	 1	 -30.0	 30.0;
	2308	 3541	 0.000781	 0.00574	 0.0	 5453	 5453	 5453	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 7582	 0.00089	 0.00562	 0.0	 5552	 5552	 5552	 0.0	 0.0	 1	 -30.0	 30.0;
	2019	 8542	 0.000331	 0.001401	 0.0	 21943	 21943	 21943	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 8542	 0.000401	 0.00137	 0.0	 22129	 22129	 22129	 0.0	 0.0	 1	 -30.0	 30.0;
	7945	 5215	 0.00051	 0.003349	 0.0	 9325	 9325	 9325	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 9130	 0.000461	 0.00168	 0.0	 18132	 18132	 18132	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 9130	 0.000469	 0.00164	 0.0	 18519	 18519	 18519	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 6816	 0.006081	 0.03114	 0.0	 457.0	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	7519	 776	 0.005831	 0.02218	 0.0	 495.0	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	8989	 3435	 0.00013	 0.000461	 0.0	 65948	 65948	 65948	 0.0	 0.0	 1	 -30.0	 30.0;
	7797	 2020	 0.00013	 0.000461	 0.0	 65948	 65948	 65948	 0.0	 0.0	 1	 -30.0	 30.0;
	871	 4031	 0.00262	 0.020289	 0.0	 514.0	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	871	 2878	 0.00164	 0.01194	 0.0	 553.0	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	7353	 9164	 0.006479	 0.02845	 0.0	 514.0	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 2012	 0.00294	 0.014419	 0.0	 495.0	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 2012	 0.00238	 0.01463	 0.0	 495.0	 2132	 2132	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 1750	 0.002219	 0.00993	 0.0	 476.0	 3105	 3105	 0.0	 0.0	 1	 -30.0	 30.0;
	1401	 2303	 0.008651	 0.04886	 0.0	 400.0	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 7903	 0.00464	 0.030979	 0.0	 1009	 1009	 1009	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 449	 0.00092	 0.00889	 0.0	 1547.0	 3535	 3535	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 449	 0.00093	 0.00869	 0.0	 1448.0	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 1817	 0.0022	 0.03485	 0.0	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 2458	 0.00074	 0.00941	 0.0	 1843.0	 3347	 3347	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 6427	 0.00087	 0.00884	 0.0	 1678.0	 3557	 3557	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 1730	 0.00139	 0.01662	 0.0	 1894	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	9217	 594	 0.002781	 0.022979	 0.0	 400.0	 1365	 1365	 0.0	 0.0	 1	 -30.0	 30.0;
	6351	 5393	 0.000521	 0.00407	 0.0	 629.0	 7699	 7699	 0.0	 0.0	 1	 -30.0	 30.0;
	6194	 7702	 0.008479	 0.032841	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	2503	 7491	 0.005669	 0.02901	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 2872	 0.001031	 0.004099	 0.0	 7474	 7474	 7474	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 8043	 0.00301	 0.018719	 0.0	 476.0	 1667	 1667	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 2866	 0.00257	 0.01713	 0.0	 438.0	 1824	 1824	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 5417	 0.010461	 0.03836	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 4100	 0.001719	 0.011531	 0.0	 514.0	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 1556	 9.1e-05	 0.00056	 0.0	 400.0	 55676	 55676	 0.0	 0.0	 1	 -30.0	 30.0;
	3894	 3865	 0.00476	 0.025289	 0.0	 1228	 1228	 1228	 0.0	 0.0	 1	 -30.0	 30.0;
	128	 1554	 0.000219	 0.00164	 0.0	 419.0	 19092	 19092	 0.0	 0.0	 1	 -30.0	 30.0;
	198	 7994	 0.002159	 0.01163	 0.0	 2671	 2671	 2671	 0.0	 0.0	 1	 -30.0	 30.0;
	198	 1554	 0.00295	 0.01539	 0.0	 400.0	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 3133	 0.007789	 0.033039	 0.0	 400.0	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 3071	 0.00026	 0.0013	 0.0	 23827	 23827	 23827	 0.0	 0.0	 1	 -30.0	 30.0;
	6486	 8992	 0.00162	 0.013229	 0.0	 438.0	 2371	 2371	 0.0	 0.0	 1	 -30.0	 30.0;
	8485	 594	 0.007919	 0.04194	 0.0	 438.0	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	682	 8477	 0.001229	 0.00401	 0.0	 400.0	 7532	 7532	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 5488	 0.008021	 0.042831	 0.0	 438.0	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	6638	 776	 0.007711	 0.03006	 0.0	 438.0	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	8788	 789	 0.00261	 0.015469	 0.0	 419.0	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 1556	 0.00139	 0.00536	 0.0	 5705	 5705	 5705	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 1556	 0.001419	 0.00525	 0.0	 5809	 5809	 5809	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 7702	 0.006289	 0.032271	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 2132	 0.011031	 0.05625	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	171	 2341	 0.001841	 0.01324	 0.0	 572.0	 2364	 2364	 0.0	 0.0	 1	 -30.0	 30.0;
	6630	 10	 0.000599	 0.00186	 0.0	 553.0	 16165	 16165	 0.0	 0.0	 1	 -30.0	 30.0;
	4484	 4239	 0.00036	 0.001591	 0.0	 533.0	 19365	 19365	 0.0	 0.0	 1	 -30.0	 30.0;
	3044	 4235	 0.003849	 0.027651	 0.0	 553.0	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 4454	 0.00186	 0.00874	 0.0	 591.0	 3535	 3535	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 2183	 0.00025	 0.00285	 0.0	 1580.0	 11041	 11041	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 7923	 0.00207	 0.008841	 0.0	 419.0	 3479	 3479	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 1233	 6e-05	 0.00039	 0.0	 553.0	 80052	 80052	 0.0	 0.0	 1	 -30.0	 30.0;
	8913	 4852	 0.002159	 0.008909	 0.0	 457.0	 3446	 3446	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 1233	 0.000219	 0.00039	 0.0	 70621	 70621	 70621	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 2653	 0.00011	 0.000521	 0.0	 400.0	 59321	 59321	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 2653	 0.00011	 0.00049	 0.0	 400.0	 62899	 62899	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 556	 0.000771	 0.003789	 0.0	 438.0	 8170	 8170	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 3019	 0.000229	 0.002849	 0.0	 11052	 11052	 11052	 0.0	 0.0	 1	 -30.0	 30.0;
	7994	 5256	 0.00445	 0.027599	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 3346	 0.00218	 0.02	 0.0	 1481.0	 1571	 1571	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 8468	 0.00074	 0.00865	 0.0	 1218.0	 3639	 3639	 0.0	 0.0	 1	 -30.0	 30.0;
	7702	 1234	 0.002531	 0.019419	 0.0	 400.0	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	7702	 8035	 0.003	 0.01631	 0.0	 1905	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	8677	 3331	 0.008461	 0.025081	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	8189	 3643	 0.00382	 0.013669	 0.0	 495.0	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 8477	 0.002581	 0.01814	 0.0	 514.0	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	6744	 6101	 0.00201	 0.012219	 0.0	 533.0	 2551	 2551	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 4313	 0.00087	 0.001599	 0.0	 17353	 17353	 17353	 0.0	 0.0	 1	 -30.0	 30.0;
	769	 5233	 0.00455	 0.02394	 0.0	 419.0	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	1965	 5926	 0.005651	 0.041771	 0.0	 457.0	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	9014	 3999	 0.00069	 0.001271	 0.0	 21842	 21842	 21842	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 8406	 0.00068	 0.00269	 0.0	 400.0	 11385	 11385	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 2021	 0.00036	 0.00261	 0.0	 476.0	 11989	 11989	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 8293	 0.001669	 0.012031	 0.0	 419.0	 2601	 2601	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 3656	 0.009669	 0.03513	 0.0	 867	 867	 867	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 8477	 0.001099	 0.00862	 0.0	 3636	 3636	 3636	 0.0	 0.0	 1	 -30.0	 30.0;
	7998	 1644	 0.0005	 0.00711	 0.0	 757.0	 4432	 4432	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 1015	 0.003919	 0.017781	 0.0	 495.0	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 8992	 0.00161	 0.019781	 0.0	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 789	 0.0007	 0.01256	 0.0	 610.0	 2512	 2512	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 5393	 0.000409	 0.0018	 0.0	 17113	 17113	 17113	 0.0	 0.0	 1	 -30.0	 30.0;
	1708	 3906	 2e-05	 0.00043	 0.0	 73380	 73380	 73380	 0.0	 0.0	 1	 -30.0	 30.0;
	9150	 3906	 3e-05	 0.0004	 0.0	 1810.0	 78748	 78748	 0.0	 0.0	 1	 -30.0	 30.0;
	280	 9158	 0.00968	 0.056659	 0.0	 457.0	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	8043	 3656	 0.003969	 0.02925	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 8992	 0.00219	 0.01468	 0.0	 514.0	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 8466	 0.000401	 0.003159	 0.0	 476.0	 9920	 9920	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 6880	 0.000531	 0.003	 0.0	 476.0	 10368	 10368	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 7266	 0.00136	 0.00576	 0.0	 476.0	 5338	 5338	 0.0	 0.0	 1	 -30.0	 30.0;
	8807	 8992	 0.000849	 0.006289	 0.0	 457.0	 4978	 4978	 0.0	 0.0	 1	 -30.0	 30.0;
	8807	 8992	 0.000841	 0.006409	 0.0	 457.0	 4887	 4887	 0.0	 0.0	 1	 -30.0	 30.0;
	8807	 8992	 0.00045	 0.00506	 0.0	 6219	 6219	 6219	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 2088	 0.003669	 0.02988	 0.0	 495.0	 1050	 1050	 0.0	 0.0	 1	 -30.0	 30.0;
	520	 5918	 0.002	 0.01568	 0.0	 514.0	 1999	 1999	 0.0	 0.0	 1	 -30.0	 30.0;
	2653	 2128	 0.00031	 0.0008	 0.0	 419.0	 36817	 36817	 0.0	 0.0	 1	 -30.0	 30.0;
	1216	 5233	 0.00043	 0.00038	 0.0	 55045	 55045	 55045	 0.0	 0.0	 1	 -30.0	 30.0;
	8980	 5993	 0.00043	 0.002229	 0.0	 13915	 13915	 13915	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 5993	 0.00049	 0.00218	 0.0	 14137	 14137	 14137	 0.0	 0.0	 1	 -30.0	 30.0;
	3656	 4060	 0.00282	 0.01844	 0.0	 629.0	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	883	 3331	 0.00462	 0.014849	 0.0	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 3346	 0.00263	 0.04076	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	3498	 2563	 0.01062	 0.056719	 0.0	 457.0	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	1896	 8200	 0.0001	 0.00105	 0.0	 757.0	 29948	 29948	 0.0	 0.0	 1	 -30.0	 30.0;
	9130	 8864	 0.00239	 0.017341	 0.0	 476.0	 1805	 1805	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 2510	 0.001341	 0.010581	 0.0	 533.0	 2962	 2962	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 6146	 0.00101	 0.007599	 0.0	 572.0	 4121	 4121	 0.0	 0.0	 1	 -30.0	 30.0;
	401	 1584	 0.00011	 0.000289	 0.0	 495.0	 102150	 102150	 0.0	 0.0	 1	 -30.0	 30.0;
	7328	 6921	 0.00146	 0.01769	 0.0	 1780	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	7328	 6921	 0.0013	 0.02004	 0.0	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	6816	 5573	 0.007909	 0.028349	 0.0	 419.0	 1074	 1074	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 8564	 0.00012	 0.00049	 0.0	 62614	 62614	 62614	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 8564	 0.00012	 0.000479	 0.0	 63968	 63968	 63968	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.00076	 0.01018	 0.0	 1613.0	 3095	 3095	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.0009	 0.00865	 0.0	 1777.0	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.00096	 0.01294	 0.0	 1645.0	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.0004	 0.00756	 0.0	 1711.0	 4173	 4173	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.00039	 0.00771	 0.0	 1547.0	 4092	 4092	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 8200	 0.00163	 0.02291	 0.0	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 3121	 0.00636	 0.03855	 0.0	 495.0	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 3121	 0.00639	 0.03863	 0.0	 514.0	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 1730	 0.00113	 0.01362	 0.0	 790.0	 2312	 2312	 0.0	 0.0	 1	 -30.0	 30.0;
	1767	 892	 0.00861	 0.05318	 0.0	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 4889	 0.0012	 0.004669	 0.0	 438.0	 6553	 6553	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 7076	 0.00018	 0.001091	 0.0	 514.0	 28567	 28567	 0.0	 0.0	 1	 -30.0	 30.0;
	1234	 8035	 0.001401	 0.00612	 0.0	 457.0	 5032	 5032	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 225	 0.00068	 0.00387	 0.0	 591.0	 8039	 8039	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 8578	 0.0043	 0.033591	 0.0	 514.0	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	3579	 5469	 0.003039	 0.01911	 0.0	 591.0	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	3246	 124	 6e-05	 0.00111	 0.0	 953.0	 28416	 28416	 0.0	 0.0	 1	 -30.0	 30.0;
	8846	 4783	 5e-05	 0.001091	 0.0	 953.0	 28923	 28923	 0.0	 0.0	 1	 -30.0	 30.0;
	2393	 3306	 3.9e-05	 0.00089	 0.0	 953.0	 35458	 35458	 0.0	 0.0	 1	 -30.0	 30.0;
	1895	 4480	 3.9e-05	 0.000901	 0.0	 953.0	 35026	 35026	 0.0	 0.0	 1	 -30.0	 30.0;
	678	 4454	 0.000169	 0.00111	 0.0	 610.0	 28133	 28133	 0.0	 0.0	 1	 -30.0	 30.0;
	1002	 4852	 0.000331	 0.0027	 0.0	 11613	 11613	 11613	 0.0	 0.0	 1	 -30.0	 30.0;
	6429	 2012	 0.00026	 0.00369	 0.0	 8540	 8540	 8540	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 7076	 0.000341	 0.00274	 0.0	 11440	 11440	 11440	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 7491	 0.00038	 0.00506	 0.0	 514.0	 6226	 6226	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 6521	 0.00012	 0.000831	 0.0	 476.0	 37622	 37622	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 594	 0.003031	 0.0123	 0.0	 2494	 2494	 2494	 0.0	 0.0	 1	 -30.0	 30.0;
	4747	 7791	 0.001521	 0.00774	 0.0	 495.0	 4005	 4005	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 3022	 0.00059	 0.00552	 0.0	 1711.0	 5690	 5690	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 1194	 0.00053	 0.00625	 0.0	 1645.0	 5036	 5036	 0.0	 0.0	 1	 -30.0	 30.0;
	5993	 8804	 0.00143	 0.01076	 0.0	 629.0	 2911	 2911	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 8487	 0.00056	 0.00593	 0.0	 5304	 5304	 5304	 0.0	 0.0	 1	 -30.0	 30.0;
	2467	 7178	 0.00205	 0.01461	 0.0	 514.0	 2142	 2142	 0.0	 0.0	 1	 -30.0	 30.0;
	2132	 2303	 0.01068	 0.054521	 0.0	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 8466	 0.00194	 0.011039	 0.0	 533.0	 2819	 2819	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 6880	 0.00131	 0.010099	 0.0	 533.0	 3102	 3102	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 2995	 0.001289	 0.014229	 0.0	 419.0	 2211	 2211	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 3221	 0.00455	 0.027031	 0.0	 495.0	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 3327	 0.00239	 0.01414	 0.0	 610.0	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 8310	 0.004039	 0.029669	 0.0	 591.0	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 2088	 0.001099	 0.007771	 0.0	 629.0	 4025	 4025	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 2021	 0.00082	 0.00762	 0.0	 514.0	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 4114	 0.000719	 0.0033	 0.0	 9353	 9353	 9353	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 5519	 0.000599	 0.00361	 0.0	 400.0	 8632	 8632	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 8293	 0.000521	 0.004039	 0.0	 476.0	 7757	 7757	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 3435	 0.000901	 0.0088	 0.0	 533.0	 3571	 3571	 0.0	 0.0	 1	 -30.0	 30.0;
	7507	 6990	 0.000781	 0.00306	 0.0	 10003	 10003	 10003	 0.0	 0.0	 1	 -30.0	 30.0;
	7507	 2406	 0.000419	 0.00399	 0.0	 7874	 7874	 7874	 0.0	 0.0	 1	 -30.0	 30.0;
	7507	 2020	 0.000841	 0.009841	 0.0	 381.0	 3199	 3199	 0.0	 0.0	 1	 -30.0	 30.0;
	6478	 6146	 0.004021	 0.03064	 0.0	 514.0	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 2695	 0.0023	 0.009031	 0.0	 438.0	 3390	 3390	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 2695	 0.002081	 0.009469	 0.0	 476.0	 3259	 3259	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 5502	 0.00164	 0.008831	 0.0	 3517	 3517	 3517	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 8877	 0.00094	 0.00488	 0.0	 419.0	 6356	 6356	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 9119	 0.000901	 0.00551	 0.0	 553.0	 5658	 5658	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 1151	 0.00051	 0.005961	 0.0	 5280	 5280	 5280	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 1750	 0.00113	 0.004349	 0.0	 533.0	 7030	 7030	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 6616	 0.002081	 0.013031	 0.0	 495.0	 2394	 2394	 0.0	 0.0	 1	 -30.0	 30.0;
	809	 4594	 0.00116	 0.01438	 0.0	 2190	 2190	 2190	 0.0	 0.0	 1	 -30.0	 30.0;
	8656	 4729	 0.00013	 0.001031	 0.0	 30397	 30397	 30397	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 615	 0.00036	 0.002659	 0.0	 514.0	 11773	 11773	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 5393	 0.000771	 0.004539	 0.0	 629.0	 6861	 6861	 0.0	 0.0	 1	 -30.0	 30.0;
	3296	 4080	 0.011902	 0.04088	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	176	 3296	 0.002231	 0.010138	 0.0	 3043	 3043	 3043	 0.0	 0.0	 1	 -30.0	 30.0;
	1142	 165	 0.00023	 0.0025	 0.0	 1448.0	 12582	 12582	 0.0	 0.0	 1	 -30.0	 30.0;
	1142	 165	 0.00023	 0.00254	 0.0	 1283.0	 12386	 12386	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 1142	 0.00179	 0.01478	 0.0	 1415.0	 3238	 3238	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 1142	 0.00183	 0.01446	 0.0	 1316.0	 3307	 3307	 0.0	 0.0	 1	 -30.0	 30.0;
	1142	 1533	 0.00031	 0.00312	 0.0	 1185.0	 10075	 10075	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 1142	 0.00031	 0.00289	 0.0	 1415.0	 10868	 10868	 0.0	 0.0	 1	 -30.0	 30.0;
	914	 1142	 0.00021	 0.00194	 0.0	 1218.0	 16188	 16188	 0.0	 0.0	 1	 -30.0	 30.0;
	6577	 7621	 0.001489	 0.006249	 0.0	 4918	 4918	 4918	 0.0	 0.0	 1	 -30.0	 30.0;
	7740	 7621	 0.010209	 0.042502	 0.0	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	6577	 2382	 0.001462	 0.006369	 0.0	 4834	 4834	 4834	 0.0	 0.0	 1	 -30.0	 30.0;
	2382	 8839	 0.0048	 0.01772	 0.0	 1721	 1721	 1721	 0.0	 0.0	 1	 -30.0	 30.0;
	6577	 5758	 0.00328	 0.01472	 0.0	 2095	 2095	 2095	 0.0	 0.0	 1	 -30.0	 30.0;
	461	 6577	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	8839	 6577	 0.002031	 0.007591	 0.0	 4020	 4020	 4020	 0.0	 0.0	 1	 -30.0	 30.0;
	4137	 6905	 0.00372	 0.014431	 0.0	 2120	 2120	 2120	 0.0	 0.0	 1	 -30.0	 30.0;
	3849	 4137	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	4137	 4568	 0.00108	 0.003698	 0.0	 8200	 8200	 8200	 0.0	 0.0	 1	 -30.0	 30.0;
	4137	 9008	 0.000431	 0.001658	 0.0	 18439	 18439	 18439	 0.0	 0.0	 1	 -30.0	 30.0;
	6905	 3247	 0.000782	 0.002662	 0.0	 11385	 11385	 11385	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 627	 0.001729	 0.005498	 0.0	 5481	 5481	 5481	 0.0	 0.0	 1	 -30.0	 30.0;
	7959	 1930	 0.00221	 0.01891	 0.0	 1119.0	 2318	 2318	 0.0	 0.0	 1	 -30.0	 30.0;
	8171	 1930	 0.00335	 0.03107	 0.0	 1086.0	 1412	 1412	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 436	 0.00109	 0.01324	 0.0	 1777.0	 3321	 3321	 0.0	 0.0	 1	 -30.0	 30.0;
	3448	 2876	 0.027218	 0.118858	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	6355	 3448	 0.002782	 0.010778	 0.0	 2838	 2838	 2838	 0.0	 0.0	 1	 -30.0	 30.0;
	3448	 2576	 0.03336	 0.110049	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	3448	 2576	 0.02972	 0.124729	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	3448	 3653	 0.00244	 0.009351	 0.0	 3269	 3269	 3269	 0.0	 0.0	 1	 -30.0	 30.0;
	3448	 3653	 0.002151	 0.009649	 0.0	 3196	 3196	 3196	 0.0	 0.0	 1	 -30.0	 30.0;
	3448	 3653	 0.00244	 0.009458	 0.0	 3234	 3234	 3234	 0.0	 0.0	 1	 -30.0	 30.0;
	6445	 5808	 0.017102	 0.080911	 0.0	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 6445	 0.030871	 0.129529	 0.0	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	6445	 1877	 0.008778	 0.041551	 0.0	 744	 744	 744	 0.0	 0.0	 1	 -30.0	 30.0;
	6445	 1877	 0.008591	 0.038471	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	6445	 1877	 0.01032	 0.038049	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	6445	 696	 0.004151	 0.017409	 0.0	 1765	 1765	 1765	 0.0	 0.0	 1	 -30.0	 30.0;
	6445	 696	 0.004062	 0.017751	 0.0	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	2838	 6117	 0.000338	 0.00156	 0.0	 19790	 19790	 19790	 0.0	 0.0	 1	 -30.0	 30.0;
	8550	 6117	 0.002689	 0.010018	 0.0	 3046	 3046	 3046	 0.0	 0.0	 1	 -30.0	 30.0;
	6117	 4328	 0.020471	 0.070289	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 2943	 4e-05	 0.000271	 0.0	 115310	 115310	 115310	 0.0	 0.0	 1	 -30.0	 30.0;
	8536	 3995	 0.023289	 0.097751	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 2943	 0.005969	 0.02292	 0.0	 1334	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 2943	 0.00428	 0.019138	 0.0	 1611	 1611	 1611	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 8550	 0.01588	 0.054529	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	6328	 4258	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	4258	 3100	 0.00368	 0.007311	 0.0	 3860	 3860	 3860	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 4258	 0.006369	 0.0324	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	1014	 4258	 0.000791	 0.003569	 0.0	 8641	 8641	 8641	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 4258	 0.000809	 0.003431	 0.0	 8961	 8961	 8961	 0.0	 0.0	 1	 -30.0	 30.0;
	3100	 5915	 0.008871	 0.004431	 0.0	 3186	 3186	 3186	 0.0	 0.0	 1	 -30.0	 30.0;
	9149	 7074	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	6699	 3461	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	7773	 3763	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	6606	 156	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	626	 4475	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 7904	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	8744	 4476	 0.00096	 0.003391	 0.0	 8963	 8963	 8963	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 4476	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	4476	 6404	 0.004471	 0.021831	 0.0	 1418	 1418	 1418	 0.0	 0.0	 1	 -30.0	 30.0;
	4476	 3482	 0.00624	 0.03	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 2434	 0.0008	 0.0038	 0.0	 8135	 8135	 8135	 0.0	 0.0	 1	 -30.0	 30.0;
	176	 3320	 0.010058	 0.035969	 0.0	 846	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	8908	 2434	 0.000782	 0.00352	 0.0	 8761	 8761	 8761	 0.0	 0.0	 1	 -30.0	 30.0;
	5939	 8908	 0.008471	 0.040089	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	7759	 5883	 0.00038	 0.00312	 0.0	 1448.0	 14037	 14037	 0.0	 0.0	 1	 -30.0	 30.0;
	7759	 5883	 0.00038	 0.00305	 0.0	 1185.0	 14354	 14354	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 7759	 0.00255	 0.02375	 0.0	 1349.0	 1847	 1847	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 7759	 0.0026	 0.02326	 0.0	 1514.0	 1885	 1885	 0.0	 0.0	 1	 -30.0	 30.0;
	7759	 6072	 0.00268	 0.03039	 0.0	 1349.0	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	7759	 6072	 0.00262	 0.02814	 0.0	 1185.0	 1562	 1562	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 8184	 0.000258	 0.000929	 0.0	 32762	 32762	 32762	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 8184	 0.003049	 0.013911	 0.0	 2219	 2219	 2219	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 5769	 0.000258	 0.000911	 0.0	 33362	 33362	 33362	 0.0	 0.0	 1	 -30.0	 30.0;
	7868	 5769	 0.000871	 0.003991	 0.0	 7733	 7733	 7733	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 3307	 0.024218	 0.1016	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 6875	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 4527	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 2125	 0.02372	 0.103591	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 7034	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	7605	 4527	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	165	 2522	 0.00038	 0.00396	 0.0	 889.0	 7941	 7941	 0.0	 0.0	 1	 -30.0	 30.0;
	165	 2522	 0.00038	 0.00404	 0.0	 921.0	 7785	 7785	 0.0	 0.0	 1	 -30.0	 30.0;
	165	 2522	 0.00042	 0.0036	 0.0	 987.0	 8716	 8716	 0.0	 0.0	 1	 -30.0	 30.0;
	165	 2522	 0.00043	 0.00352	 0.0	 954.0	 8908	 8908	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 165	 0.00177	 0.01845	 0.0	 1382.0	 2601	 2601	 0.0	 0.0	 1	 -30.0	 30.0;
	7904	 8904	 0.007831	 0.035089	 0.0	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	7904	 7339	 0.002089	 0.007182	 0.0	 260.0	 4224	 4224	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 8904	 0.008871	 0.034391	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 4853	 0.002129	 0.007031	 0.0	 4300	 4300	 4300	 0.0	 0.0	 1	 -30.0	 30.0;
	7501	 5140	 0.007222	 0.032831	 0.0	 940	 940	 940	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 7693	 0.006049	 0.021431	 0.0	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	2837	 8744	 0.0114	 0.005622	 0.0	 2486	 2486	 2486	 0.0	 0.0	 1	 -30.0	 30.0;
	2860	 2536	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2536	 8901	 0.00976	 0.043991	 0.0	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 1379	 0.017658	 0.0684	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 1379	 0.018	 0.067	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 7756	 0.003378	 0.009631	 0.0	 3095	 3095	 3095	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 5267	 0.016409	 0.07168	 0.0	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 1370	 0.0182	 0.04612	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 3108	 0.004818	 0.017231	 0.0	 1766	 1766	 1766	 0.0	 0.0	 1	 -30.0	 30.0;
	7482	 5496	 0.000209	 0.000911	 0.0	 33796	 33796	 33796	 0.0	 0.0	 1	 -30.0	 30.0;
	7482	 2674	 0.000249	 0.000831	 0.0	 36412	 36412	 36412	 0.0	 0.0	 1	 -30.0	 30.0;
	8637	 4978	 0.00136	 0.006458	 0.0	 4787	 4787	 4787	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 4781	 0.002782	 0.013129	 0.0	 2354	 2354	 2354	 0.0	 0.0	 1	 -30.0	 30.0;
	6260	 1818	 0.008049	 0.036031	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	1818	 2664	 0.022311	 0.0864	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	671	 1519	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6260	 1519	 0.00912	 0.035311	 0.0	 867	 867	 867	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 1210	 0.001471	 0.005489	 0.0	 5559	 5559	 5559	 0.0	 0.0	 1	 -30.0	 30.0;
	7228	 8640	 0.00058	 0.00639	 0.0	 1053.0	 6876	 6876	 0.0	 0.0	 1	 -30.0	 30.0;
	7228	 8640	 0.00057	 0.00651	 0.0	 987.0	 6752	 6752	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 3993	 0.002111	 0.007542	 0.0	 4034	 4034	 4034	 0.0	 0.0	 1	 -30.0	 30.0;
	1204	 3993	 0.014049	 0.037031	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	259	 2725	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	259	 6779	 0.002071	 0.005609	 0.0	 5283	 5283	 5283	 0.0	 0.0	 1	 -30.0	 30.0;
	1966	 259	 0.00368	 0.016711	 0.0	 1846	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	1966	 259	 0.0036	 0.017018	 0.0	 1816	 1816	 1816	 0.0	 0.0	 1	 -30.0	 30.0;
	259	 8111	 0.00012	 0.000431	 0.0	 70604	 70604	 70604	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 7389	 0.00012	 0.000431	 0.0	 70604	 70604	 70604	 0.0	 0.0	 1	 -30.0	 30.0;
	7074	 5915	 0.01328	 0.031071	 0.0	 935	 935	 935	 0.0	 0.0	 1	 -30.0	 30.0;
	8436	 7074	 0.031911	 0.071711	 0.0	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	6215	 3461	 0.000382	 0.001289	 0.0	 23496	 23496	 23496	 0.0	 0.0	 1	 -30.0	 30.0;
	1966	 6215	 0.002582	 0.00988	 0.0	 3094	 3094	 3094	 0.0	 0.0	 1	 -30.0	 30.0;
	2596	 3763	 0.00036	 0.001218	 0.0	 24871	 24871	 24871	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 2596	 0.002458	 0.00908	 0.0	 3358	 3358	 3358	 0.0	 0.0	 1	 -30.0	 30.0;
	6928	 6102	 0.000911	 0.003271	 0.0	 9303	 9303	 9303	 0.0	 0.0	 1	 -30.0	 30.0;
	176	 6928	 0.01436	 0.05344	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	159	 6635	 0.000462	 0.001631	 0.0	 18634	 18634	 18634	 0.0	 0.0	 1	 -30.0	 30.0;
	159	 6102	 0.000929	 0.0032	 0.0	 9480	 9480	 9480	 0.0	 0.0	 1	 -30.0	 30.0;
	9079	 6635	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 6635	 0.013391	 0.060849	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 5013	 0.010631	 0.048342	 0.0	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 3312	 0.005498	 0.021302	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	3312	 1490	 0.001449	 0.006329	 0.0	 4866	 4866	 4866	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 8912	 0.007951	 0.029329	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 1877	 0.02072	 0.086938	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	232	 840	 0.007182	 0.02672	 0.0	 1142	 1142	 1142	 0.0	 0.0	 1	 -30.0	 30.0;
	7247	 2367	 0.00424	 0.019129	 0.0	 1613	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	2876	 7247	 0.010542	 0.047938	 0.0	 644	 644	 644	 0.0	 0.0	 1	 -30.0	 30.0;
	7247	 3653	 0.016751	 0.06488	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 3581	 0.016671	 0.059071	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 6223	 0.00536	 0.024151	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 2876	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2876	 5304	 0.007089	 0.017938	 0.0	 260.0	 1638	 1638	 0.0	 0.0	 1	 -30.0	 30.0;
	5606	 2876	 0.020849	 0.052831	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	5755	 5304	 0.010609	 0.005209	 0.0	 2673	 2673	 2673	 0.0	 0.0	 1	 -30.0	 30.0;
	2454	 5143	 0.020898	 0.098071	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	6511	 5143	 0.002258	 0.008409	 0.0	 3628	 3628	 3628	 0.0	 0.0	 1	 -30.0	 30.0;
	421	 6318	 0.00056	 0.00236	 0.0	 13023	 13023	 13023	 0.0	 0.0	 1	 -30.0	 30.0;
	6318	 1014	 0.014258	 0.064311	 0.0	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 1987	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6645	 1987	 0.040249	 0.143902	 0.0	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	8737	 1987	 0.021778	 0.071862	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	1987	 3831	 0.022742	 0.09932	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 1987	 0.021511	 0.07092	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 4254	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4254	 8863	 0.010818	 0.0454	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	2293	 4254	 0.013671	 0.059698	 0.0	 516	 516	 516	 0.0	 0.0	 1	 -30.0	 30.0;
	6005	 7807	 0.00011	 0.00059	 0.0	 987.0	 73510	 73510	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 7807	 0.00093	 0.00993	 0.0	 1415.0	 4833	 4833	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 6005	 0.00037	 0.00305	 0.0	 1481.0	 14360	 14360	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 1006	 0.0001	 0.00066	 0.0	 1152.0	 47320	 47320	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 2814	 0.00105	 0.00973	 0.0	 1382.0	 3228	 3228	 0.0	 0.0	 1	 -30.0	 30.0;
	1006	 1650	 0.00037	 0.00298	 0.0	 1613.0	 10520	 10520	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 4985	 0.00105	 0.01196	 0.0	 1481.0	 3675	 3675	 0.0	 0.0	 1	 -30.0	 30.0;
	1650	 165	 0.00073	 0.00626	 0.0	 1514.0	 5012	 5012	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 7698	 0.00112	 0.002329	 0.0	 12223	 12223	 12223	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 9156	 0.0068	 0.032178	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 3879	 0.013871	 0.06308	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	6534	 4210	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 4210	 0.00636	 0.028689	 0.0	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	5216	 4210	 0.005231	 0.020942	 0.0	 1464	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 4210	 0.019129	 0.063111	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 3101	 0.006649	 0.0298	 0.0	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	7698	 5703	 0.0006	 0.001609	 0.0	 260.0	 18395	 18395	 0.0	 0.0	 1	 -30.0	 30.0;
	110	 421	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8243	 421	 0.014849	 0.066942	 0.0	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	8603	 6079	 0.00392	 0.009182	 0.0	 3164	 3164	 3164	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 3703	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 300	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 5936	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 6157	 0.00384	 0.00936	 0.0	 3123	 3123	 3123	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 7080	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 6509	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 1580	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 8603	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 7391	 0.02008	 0.09128	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 7080	 0.023991	 0.092942	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5739	 300	 0.01384	 0.06552	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	365	 6509	 0.00476	 0.022538	 0.0	 1372	 1372	 1372	 0.0	 0.0	 1	 -30.0	 30.0;
	5936	 2528	 0.00496	 0.016382	 0.0	 1846	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	1580	 7735	 0.00244	 0.008049	 0.0	 3756	 3756	 3756	 0.0	 0.0	 1	 -30.0	 30.0;
	8958	 563	 0.000671	 0.002502	 0.0	 12194	 12194	 12194	 0.0	 0.0	 1	 -30.0	 30.0;
	563	 5030	 0.0066	 0.029569	 0.0	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	8958	 7368	 0.000689	 0.002449	 0.0	 12417	 12417	 12417	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 7368	 0.007271	 0.024969	 0.0	 1215	 1215	 1215	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 8958	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 3223	 0.007649	 0.031849	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	6676	 5928	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6676	 7091	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	277	 6676	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3455	 5928	 0.019471	 0.074818	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 7091	 0.009231	 0.041622	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	2742	 8519	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2220	 6355	 0.000258	 0.001089	 0.0	 28225	 28225	 28225	 0.0	 0.0	 1	 -30.0	 30.0;
	2220	 3603	 0.019871	 0.042889	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	3603	 8519	 0.00076	 0.001978	 0.0	 260.0	 14907	 14907	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 8519	 0.000751	 0.001831	 0.0	 15962	 15962	 15962	 0.0	 0.0	 1	 -30.0	 30.0;
	7907	 6056	 0.039151	 0.088	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	396	 5544	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	5544	 2859	 0.032351	 0.141289	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 5544	 0.022569	 0.074449	 0.0	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	5544	 5359	 5.8e-05	 0.000222	 0.0	 192276	 192276	 192276	 0.0	 0.0	 1	 -30.0	 30.0;
	6686	 9134	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 9134	 0.009542	 0.031471	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	7001	 9134	 0.021671	 0.09856	 0.0	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 2334	 0.005609	 0.013978	 0.0	 273.0	 2098	 2098	 0.0	 0.0	 1	 -30.0	 30.0;
	8385	 2334	 0.003751	 0.01016	 0.0	 2917	 2917	 2917	 0.0	 0.0	 1	 -30.0	 30.0;
	8077	 3658	 0.000529	 0.00208	 0.0	 14718	 14718	 14718	 0.0	 0.0	 1	 -30.0	 30.0;
	8077	 4073	 0.008862	 0.029231	 0.0	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	952	 6121	 0.000538	 0.00204	 0.0	 14973	 14973	 14973	 0.0	 0.0	 1	 -30.0	 30.0;
	952	 8220	 0.009569	 0.026289	 0.0	 260.0	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 3418	 0.00028	 0.001209	 0.0	 25454	 25454	 25454	 0.0	 0.0	 1	 -30.0	 30.0;
	1204	 3418	 0.005489	 0.014249	 0.0	 2069	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	6121	 3081	 0.000271	 0.001231	 0.0	 25060	 25060	 25060	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 5770	 0.000338	 0.001311	 0.0	 23332	 23332	 23332	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 5761	 0.005791	 0.02716	 0.0	 1138	 1138	 1138	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 7228	 0.00288	 0.03132	 0.0	 1251.0	 1403	 1403	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 7228	 0.00282	 0.03191	 0.0	 1218.0	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	7228	 5883	 0.00111	 0.01111	 0.0	 1316.0	 3952	 3952	 0.0	 0.0	 1	 -30.0	 30.0;
	7228	 6741	 0.00108	 0.01133	 0.0	 1316.0	 3877	 3877	 0.0	 0.0	 1	 -30.0	 30.0;
	6121	 6360	 0.008751	 0.033911	 0.0	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	6121	 293	 0.002418	 0.00936	 0.0	 3268	 3268	 3268	 0.0	 0.0	 1	 -30.0	 30.0;
	6859	 4743	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6859	 272	 0.00944	 0.044271	 0.0	 698	 698	 698	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 8023	 0.006542	 0.0272	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	3581	 5446	 0.001591	 0.005658	 0.0	 5375	 5375	 5375	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 1108	 0.000711	 0.001822	 0.0	 299.0	 16151	 16151	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 4589	 0.010369	 0.021511	 0.0	 299.0	 1323	 1323	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 7907	 0.001978	 0.0068	 0.0	 4461	 4461	 4461	 0.0	 0.0	 1	 -30.0	 30.0;
	537	 6012	 0.009062	 0.023902	 0.0	 1236	 1236	 1236	 0.0	 0.0	 1	 -30.0	 30.0;
	6012	 670	 0.0092	 0.025249	 0.0	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	8444	 906	 0.0022	 0.005942	 0.0	 4986	 4986	 4986	 0.0	 0.0	 1	 -30.0	 30.0;
	4933	 8444	 0.016169	 0.03352	 0.0	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	2379	 670	 0.006902	 0.014898	 0.0	 1924	 1924	 1924	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 2379	 0.018609	 0.041849	 0.0	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 4913	 0.00156	 0.00696	 0.0	 4429	 4429	 4429	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 3555	 0.01592	 0.07532	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 4913	 0.00176	 0.006822	 0.0	 4484	 4484	 4484	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 8590	 0.015542	 0.069582	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	7322	 1631	 0.00176	 0.004631	 0.0	 6376	 6376	 6376	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 1631	 0.02272	 0.061458	 0.0	 273.0	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	6260	 2820	 0.00348	 0.015809	 0.0	 1952	 1952	 1952	 0.0	 0.0	 1	 -30.0	 30.0;
	8752	 2820	 0.013449	 0.056431	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 1276	 0.002911	 0.01272	 0.0	 2421	 2421	 2421	 0.0	 0.0	 1	 -30.0	 30.0;
	6260	 1276	 0.0034	 0.016102	 0.0	 1920	 1920	 1920	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 4887	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 8970	 0.030151	 0.079538	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 4887	 0.017769	 0.063511	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 4093	 0.031249	 0.084538	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	8678	 6260	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6260	 4531	 0.013698	 0.047049	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	6260	 4531	 0.01396	 0.046031	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	8162	 6260	 0.007938	 0.037569	 0.0	 823	 823	 823	 0.0	 0.0	 1	 -30.0	 30.0;
	8752	 6260	 0.016751	 0.070271	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	7322	 6165	 0.00172	 0.00472	 0.0	 6288	 6288	 6288	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 3406	 0.007271	 0.015689	 0.0	 1827	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	522	 2587	 0.001471	 0.004	 0.0	 7412	 7412	 7412	 0.0	 0.0	 1	 -30.0	 30.0;
	522	 2945	 0.001991	 0.007729	 0.0	 3958	 3958	 3958	 0.0	 0.0	 1	 -30.0	 30.0;
	8340	 522	 0.003151	 0.047689	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	522	 357	 0.000809	 0.002769	 0.0	 10950	 10950	 10950	 0.0	 0.0	 1	 -30.0	 30.0;
	8386	 522	 0.002009	 0.020209	 0.0	 1556	 1556	 1556	 0.0	 0.0	 1	 -30.0	 30.0;
	4203	 6377	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6377	 8739	 0.001	 0.002831	 0.0	 10521	 10521	 10521	 0.0	 0.0	 1	 -30.0	 30.0;
	6377	 8064	 0.001502	 0.005169	 0.0	 5869	 5869	 5869	 0.0	 0.0	 1	 -30.0	 30.0;
	5953	 6377	 0.001969	 0.0206	 0.0	 299.0	 1527	 1527	 0.0	 0.0	 1	 -30.0	 30.0;
	7636	 5216	 0.000151	 0.000649	 0.0	 47405	 47405	 47405	 0.0	 0.0	 1	 -30.0	 30.0;
	7636	 3586	 0.000142	 0.000662	 0.0	 46654	 46654	 46654	 0.0	 0.0	 1	 -30.0	 30.0;
	2378	 3586	 0.004409	 0.01628	 0.0	 1873	 1873	 1873	 0.0	 0.0	 1	 -30.0	 30.0;
	6690	 6713	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9141	 7543	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6713	 8833	 0.00028	 0.000791	 0.0	 37645	 37645	 37645	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 7543	 0.000622	 0.001671	 0.0	 17716	 17716	 17716	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 729	 0.000471	 0.0016	 0.0	 18939	 18939	 18939	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 729	 0.013889	 0.065751	 0.0	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 3214	 0.000471	 0.00156	 0.0	 19385	 19385	 19385	 0.0	 0.0	 1	 -30.0	 30.0;
	4531	 3214	 0.018262	 0.082978	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 2664	 0.02168	 0.077489	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	7963	 5535	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 7952	 0.000538	 0.001902	 0.0	 15981	 15981	 15981	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 5535	 0.004578	 0.017031	 0.0	 1792	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 5535	 0.004662	 0.016671	 0.0	 1825	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	4374	 4531	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4531	 3172	 0.0242	 0.093769	 0.0	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	8863	 2047	 0.002289	 0.008129	 0.0	 3741	 3741	 3741	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 998	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	998	 3666	 0.00668	 0.02588	 0.0	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 3666	 0.00308	 0.013778	 0.0	 2238	 2238	 2238	 0.0	 0.0	 1	 -30.0	 30.0;
	3455	 998	 0.032169	 0.124618	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1333	 8340	 0.006778	 0.02236	 0.0	 1352	 1352	 1352	 0.0	 0.0	 1	 -30.0	 30.0;
	8131	 1333	 0.00308	 0.011929	 0.0	 2564	 2564	 2564	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 7100	 0.016911	 0.070391	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 5859	 0.03196	 0.149969	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 7959	 0.00016	 0.00049	 0.0	 757.0	 85590	 85590	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 5801	 7e-05	 0.00049	 0.0	 1086.0	 89132	 89132	 0.0	 0.0	 1	 -30.0	 30.0;
	8130	 8596	 0.0022	 0.00852	 0.0	 5014	 5014	 5014	 0.0	 0.0	 1	 -30.0	 30.0;
	6396	 8596	 0.000431	 0.000951	 0.0	 42255	 42255	 42255	 0.0	 0.0	 1	 -30.0	 30.0;
	8130	 5832	 0.002249	 0.008351	 0.0	 5102	 5102	 5102	 0.0	 0.0	 1	 -30.0	 30.0;
	7734	 5832	 0.019431	 0.053351	 0.0	 260.0	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 8130	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 5268	 0.001929	 0.008111	 0.0	 3789	 3789	 3789	 0.0	 0.0	 1	 -30.0	 30.0;
	8386	 5802	 0.00652	 0.021511	 0.0	 1406	 1406	 1406	 0.0	 0.0	 1	 -30.0	 30.0;
	6425	 5268	 0.001889	 0.008271	 0.0	 3724	 3724	 3724	 0.0	 0.0	 1	 -30.0	 30.0;
	6425	 8340	 0.012289	 0.051551	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	8368	 5268	 0.001431	 0.005071	 0.0	 5995	 5995	 5995	 0.0	 0.0	 1	 -30.0	 30.0;
	1167	 5268	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8752	 8536	 0.007271	 0.0344	 0.0	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	7237	 8536	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1986	 8863	 0.003289	 0.011329	 0.0	 2678	 2678	 2678	 0.0	 0.0	 1	 -30.0	 30.0;
	8863	 1370	 0.012129	 0.032831	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	8863	 176	 0.006031	 0.025289	 0.0	 1215	 1215	 1215	 0.0	 0.0	 1	 -30.0	 30.0;
	8863	 176	 0.005911	 0.025778	 0.0	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	466	 8863	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2184	 8243	 0.000529	 0.001969	 0.0	 15493	 15493	 15493	 0.0	 0.0	 1	 -30.0	 30.0;
	8435	 8243	 0.000538	 0.001929	 0.0	 15774	 15774	 15774	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 7190	 0.001151	 0.004222	 0.0	 7219	 7219	 7219	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 1718	 0.003818	 0.017222	 0.0	 1791	 1791	 1791	 0.0	 0.0	 1	 -30.0	 30.0;
	2528	 7818	 0.00416	 0.019502	 0.0	 1585	 1585	 1585	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 2661	 0.001991	 0.00372	 0.0	 7487	 7487	 7487	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 3181	 0.009889	 0.026751	 0.0	 1108	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	3829	 2661	 0.002018	 0.00364	 0.0	 260.0	 7590	 7590	 0.0	 0.0	 1	 -30.0	 30.0;
	7229	 3829	 0.01644	 0.036942	 0.0	 782	 782	 782	 0.0	 0.0	 1	 -30.0	 30.0;
	9157	 2661	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 5860	 0.019071	 0.07388	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	517	 5860	 0.02804	 0.1256	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1572	 5860	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 5755	 0.001911	 0.000751	 0.0	 260.0	 15384	 15384	 0.0	 0.0	 1	 -30.0	 30.0;
	7015	 4250	 0.008098	 0.028689	 0.0	 1060	 1060	 1060	 0.0	 0.0	 1	 -30.0	 30.0;
	7462	 7015	 0.017609	 0.068191	 0.0	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	7015	 4590	 0.015018	 0.058191	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	6698	 7012	 0.007031	 0.014578	 0.0	 1952	 1952	 1952	 0.0	 0.0	 1	 -30.0	 30.0;
	6698	 4120	 0.003791	 0.012529	 0.0	 2414	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	6698	 4604	 0.010249	 0.035209	 0.0	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	7740	 937	 0.002489	 0.005818	 0.0	 4992	 4992	 4992	 0.0	 0.0	 1	 -30.0	 30.0;
	3395	 7740	 0.002071	 0.009751	 0.0	 3169	 3169	 3169	 0.0	 0.0	 1	 -30.0	 30.0;
	3395	 3258	 0.001871	 0.006902	 0.0	 4418	 4418	 4418	 0.0	 0.0	 1	 -30.0	 30.0;
	3395	 5402	 0.003658	 0.014062	 0.0	 2174	 2174	 2174	 0.0	 0.0	 1	 -30.0	 30.0;
	7735	 8000	 0.002289	 0.008178	 0.0	 3720	 3720	 3720	 0.0	 0.0	 1	 -30.0	 30.0;
	1215	 8000	 0.002329	 0.008	 0.0	 3792	 3792	 3792	 0.0	 0.0	 1	 -30.0	 30.0;
	1215	 2528	 0.002071	 0.009249	 0.0	 3333	 3333	 3333	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 7168	 0.005951	 0.021249	 0.0	 1432	 1432	 1432	 0.0	 0.0	 1	 -30.0	 30.0;
	365	 7168	 0.006058	 0.0208	 0.0	 1459	 1459	 1459	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 1089	 0.000942	 0.003129	 0.0	 9667	 9667	 9667	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 4120	 0.030849	 0.10176	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	2244	 1089	 0.00084	 0.003551	 0.0	 8657	 8657	 8657	 0.0	 0.0	 1	 -30.0	 30.0;
	2528	 2244	 0.002378	 0.007831	 0.0	 3860	 3860	 3860	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 1373	 0.007231	 0.01624	 0.0	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 3837	 0.001311	 0.005111	 0.0	 5987	 5987	 5987	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 5861	 0.001338	 0.005009	 0.0	 6093	 6093	 6093	 0.0	 0.0	 1	 -30.0	 30.0;
	3624	 3837	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1373	 570	 0.000338	 0.00116	 0.0	 26144	 26144	 26144	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 1288	 0.025778	 0.069751	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	2213	 570	 0.004009	 0.01376	 0.0	 2204	 2204	 2204	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 570	 0.00408	 0.013462	 0.0	 2246	 2246	 2246	 0.0	 0.0	 1	 -30.0	 30.0;
	3735	 570	 0.000329	 0.001262	 0.0	 24221	 24221	 24221	 0.0	 0.0	 1	 -30.0	 30.0;
	4790	 570	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8649	 1466	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2688	 1300	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9062	 1466	 0.000711	 0.002018	 0.0	 14764	 14764	 14764	 0.0	 0.0	 1	 -30.0	 30.0;
	1300	 5066	 0.00068	 0.001502	 0.0	 19159	 19159	 19159	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 936	 0.00012	 0.00056	 0.0	 55154	 55154	 55154	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 936	 0.02516	 0.086418	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 6213	 0.00012	 0.00052	 0.0	 59190	 59190	 59190	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 7001	 0.032591	 0.116511	 0.0	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	8178	 3764	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 2184	 0.01752	 0.062098	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	8435	 2697	 0.00076	 0.003551	 0.0	 8699	 8699	 8699	 0.0	 0.0	 1	 -30.0	 30.0;
	9240	 5446	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	9240	 5638	 0.000858	 0.004458	 0.0	 6958	 6958	 6958	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 6389	 8e-05	 0.000338	 0.0	 90942	 90942	 90942	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 6789	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	6789	 2783	 0.000982	 0.004369	 0.0	 7054	 7054	 7054	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 5729	 0.01704	 0.083271	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	2783	 3040	 7.1e-05	 0.000351	 0.0	 88206	 88206	 88206	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 6061	 0.000271	 0.00068	 0.0	 43152	 43152	 43152	 0.0	 0.0	 1	 -30.0	 30.0;
	9092	 4883	 0.012809	 0.05376	 0.0	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 7381	 0.00364	 0.015262	 0.0	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 4963	 0.00012	 0.000431	 0.0	 70604	 70604	 70604	 0.0	 0.0	 1	 -30.0	 30.0;
	8394	 4963	 0.003982	 0.015271	 0.0	 2002	 2002	 2002	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 4123	 0.00012	 0.000418	 0.0	 72634	 72634	 72634	 0.0	 0.0	 1	 -30.0	 30.0;
	8745	 4123	 0.000431	 0.00172	 0.0	 17814	 17814	 17814	 0.0	 0.0	 1	 -30.0	 30.0;
	631	 3297	 0.00024	 0.00032	 0.0	 78969	 78969	 78969	 0.0	 0.0	 1	 -30.0	 30.0;
	3463	 631	 0.002418	 0.011462	 0.0	 2697	 2697	 2697	 0.0	 0.0	 1	 -30.0	 30.0;
	6912	 4456	 0.00028	 0.000311	 0.0	 75483	 75483	 75483	 0.0	 0.0	 1	 -30.0	 30.0;
	6912	 8394	 0.003658	 0.01664	 0.0	 1855	 1855	 1855	 0.0	 0.0	 1	 -30.0	 30.0;
	8394	 3297	 0.003582	 0.016951	 0.0	 1824	 1824	 1824	 0.0	 0.0	 1	 -30.0	 30.0;
	1875	 5022	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 2347	 0.006231	 0.029249	 0.0	 1057	 1057	 1057	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 8745	 0.00144	 0.005529	 0.0	 5529	 5529	 5529	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 5950	 0.011111	 0.023978	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	8736	 1164	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2401	 5588	 0.001182	 0.002409	 0.0	 11772	 11772	 11772	 0.0	 0.0	 1	 -30.0	 30.0;
	6301	 3049	 0.006098	 0.029822	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 8253	 0.00096	 0.003378	 0.0	 8995	 8995	 8995	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 6645	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6645	 1598	 0.01044	 0.03444	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	6645	 1598	 0.009298	 0.03904	 0.0	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	6645	 5265	 0.017311	 0.078738	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	901	 8970	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8970	 537	 0.012449	 0.029129	 0.0	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	725	 1202	 0.00015	 0.00045	 0.0	 790.0	 93009	 93009	 0.0	 0.0	 1	 -30.0	 30.0;
	7616	 1202	 0.00107	 0.01215	 0.0	 1316.0	 3618	 3618	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 725	 6e-05	 0.00056	 0.0	 1283.0	 78334	 78334	 0.0	 0.0	 1	 -30.0	 30.0;
	4162	 8171	 0.00035	 0.00284	 0.0	 1349.0	 15418	 15418	 0.0	 0.0	 1	 -30.0	 30.0;
	7547	 8171	 0.00163	 0.01512	 0.0	 1448.0	 2902	 2902	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 8171	 0.00115	 0.00913	 0.0	 1415.0	 4795	 4795	 0.0	 0.0	 1	 -30.0	 30.0;
	2869	 8171	 0.00133	 0.01513	 0.0	 889.0	 2905	 2905	 0.0	 0.0	 1	 -30.0	 30.0;
	2869	 8171	 0.00131	 0.01401	 0.0	 987.0	 3136	 3136	 0.0	 0.0	 1	 -30.0	 30.0;
	7616	 8171	 0.00013	 0.00129	 0.0	 1251.0	 34028	 34028	 0.0	 0.0	 1	 -30.0	 30.0;
	7122	 8171	 0.00077	 0.00664	 0.0	 1382.0	 6601	 6601	 0.0	 0.0	 1	 -30.0	 30.0;
	2528	 4120	 0.028391	 0.12908	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	8615	 2528	 0.01216	 0.05532	 0.0	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	8727	 6148	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2399	 6148	 0.023609	 0.053071	 0.0	 544	 544	 544	 0.0	 0.0	 1	 -30.0	 30.0;
	4965	 1761	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 6853	 0.020471	 0.051871	 0.0	 260.0	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	3455	 1761	 0.01744	 0.049862	 0.0	 598	 598	 598	 0.0	 0.0	 1	 -30.0	 30.0;
	8590	 2664	 0.009111	 0.039809	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 7062	 0.033022	 0.13856	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	7062	 2664	 0.009529	 0.045089	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	5900	 9062	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9062	 865	 0.001889	 0.003462	 0.0	 260.0	 8010	 8010	 0.0	 0.0	 1	 -30.0	 30.0;
	9062	 859	 0.006569	 0.0142	 0.0	 286.0	 2019	 2019	 0.0	 0.0	 1	 -30.0	 30.0;
	7046	 9062	 0.003982	 0.018102	 0.0	 1705	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	9062	 632	 0.00232	 0.007969	 0.0	 3806	 3806	 3806	 0.0	 0.0	 1	 -30.0	 30.0;
	1431	 2262	 0.002502	 0.011698	 0.0	 2641	 2641	 2641	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 2262	 0.009351	 0.039209	 0.0	 784	 784	 784	 0.0	 0.0	 1	 -30.0	 30.0;
	2262	 8712	 0.008622	 0.0296	 0.0	 1025	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 2581	 0.008951	 0.037289	 0.0	 824	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	2581	 4528	 0.005369	 0.02144	 0.0	 1430	 1430	 1430	 0.0	 0.0	 1	 -30.0	 30.0;
	6727	 8217	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 8217	 0.00608	 0.025551	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 8217	 0.00596	 0.026049	 0.0	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	8217	 2045	 0.001369	 0.004898	 0.0	 6211	 6211	 6211	 0.0	 0.0	 1	 -30.0	 30.0;
	8217	 2401	 0.00144	 0.006031	 0.0	 5095	 5095	 5095	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 3289	 0.0012	 0.00328	 0.0	 9045	 9045	 9045	 0.0	 0.0	 1	 -30.0	 30.0;
	8394	 4821	 0.00132	 0.006271	 0.0	 4930	 4930	 4930	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 4981	 0.009089	 0.040711	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	6330	 7269	 5.8e-05	 0.00028	 0.0	 110467	 110467	 110467	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 7269	 0.000302	 0.00132	 0.0	 23328	 23328	 23328	 0.0	 0.0	 1	 -30.0	 30.0;
	4461	 3074	 0.00368	 0.016502	 0.0	 1869	 1869	 1869	 0.0	 0.0	 1	 -30.0	 30.0;
	1966	 4461	 0.000329	 0.00124	 0.0	 24622	 24622	 24622	 0.0	 0.0	 1	 -30.0	 30.0;
	5058	 1934	 0.0012	 0.002689	 0.0	 10728	 10728	 10728	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 1934	 0.000338	 0.001289	 0.0	 23704	 23704	 23704	 0.0	 0.0	 1	 -30.0	 30.0;
	414	 6330	 0.000942	 0.002151	 0.0	 13452	 13452	 13452	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 8042	 0.00316	 0.010862	 0.0	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 6916	 0.003222	 0.010618	 0.0	 2847	 2847	 2847	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 8042	 0.010169	 0.037858	 0.0	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	1824	 6916	 0.00552	 0.024129	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	2148	 4236	 0.000449	 0.001889	 0.0	 16269	 16269	 16269	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 6026	 0.00044	 0.001929	 0.0	 15965	 15965	 15965	 0.0	 0.0	 1	 -30.0	 30.0;
	3824	 4962	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 7435	 0.000418	 0.00192	 0.0	 16076	 16076	 16076	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 7190	 0.000409	 0.00196	 0.0	 15777	 15777	 15777	 0.0	 0.0	 1	 -30.0	 30.0;
	8394	 7435	 0.00608	 0.022431	 0.0	 1360	 1360	 1360	 0.0	 0.0	 1	 -30.0	 30.0;
	3139	 3984	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4299	 3984	 0.00016	 0.000751	 0.0	 41138	 41138	 41138	 0.0	 0.0	 1	 -30.0	 30.0;
	4299	 8591	 0.046622	 0.173511	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 3984	 0.000151	 0.000698	 0.0	 44231	 44231	 44231	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 1510	 0.01464	 0.052329	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	6042	 6420	 0.006129	 0.023751	 0.0	 1288	 1288	 1288	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 6420	 0.001049	 0.003311	 0.0	 9095	 9095	 9095	 0.0	 0.0	 1	 -30.0	 30.0;
	8540	 5363	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 3074	 0.003271	 0.012089	 0.0	 2523	 2523	 2523	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 1879	 0.002951	 0.013311	 0.0	 2317	 2317	 2317	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 5150	 0.017489	 0.082769	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 2397	 0.006231	 0.029498	 0.0	 1048	 1048	 1048	 0.0	 0.0	 1	 -30.0	 30.0;
	2789	 5250	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6372	 8660	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7501	 5250	 0.00124	 0.004458	 0.0	 6827	 6827	 6827	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 8660	 0.001169	 0.001969	 0.0	 13795	 13795	 13795	 0.0	 0.0	 1	 -30.0	 30.0;
	4619	 8833	 0.000791	 0.002929	 0.0	 10412	 10412	 10412	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 8833	 0.000911	 0.003138	 0.0	 9667	 9667	 9667	 0.0	 0.0	 1	 -30.0	 30.0;
	1966	 1879	 0.004671	 0.01672	 0.0	 1820	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 2587	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2587	 8368	 0.00064	 0.00188	 0.0	 15906	 15906	 15906	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 7657	 0.00014	 0.00061	 0.0	 889.0	 70492	 70492	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 5902	 0.000698	 0.0024	 0.0	 12638	 12638	 12638	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 2469	 0.000711	 0.002351	 0.0	 12861	 12861	 12861	 0.0	 0.0	 1	 -30.0	 30.0;
	8394	 5902	 0.001858	 0.006391	 0.0	 4746	 4746	 4746	 0.0	 0.0	 1	 -30.0	 30.0;
	4911	 2469	 0.014129	 0.06328	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 4911	 0.0002	 0.00092	 0.0	 33551	 33551	 33551	 0.0	 0.0	 1	 -30.0	 30.0;
	9110	 703	 4e-05	 0.0004	 0.0	 1382.0	 109748	 109748	 0.0	 0.0	 1	 -30.0	 30.0;
	9110	 4162	 4e-05	 0.00039	 0.0	 1251.0	 112533	 112533	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 703	 0.00066	 0.00705	 0.0	 1448.0	 6231	 6231	 0.0	 0.0	 1	 -30.0	 30.0;
	4659	 288	 0.003622	 0.016209	 0.0	 1902	 1902	 1902	 0.0	 0.0	 1	 -30.0	 30.0;
	9038	 4659	 5.8e-05	 0.00028	 0.0	 110467	 110467	 110467	 0.0	 0.0	 1	 -30.0	 30.0;
	2586	 4659	 3.1e-05	 0.00028	 0.0	 112127	 112127	 112127	 0.0	 0.0	 1	 -30.0	 30.0;
	8004	 331	 0.00084	 0.002031	 0.0	 14372	 14372	 14372	 0.0	 0.0	 1	 -30.0	 30.0;
	7143	 8257	 0.004511	 0.01972	 0.0	 1562	 1562	 1562	 0.0	 0.0	 1	 -30.0	 30.0;
	7143	 8589	 0.00064	 0.0028	 0.0	 10998	 10998	 10998	 0.0	 0.0	 1	 -30.0	 30.0;
	8502	 8004	 0.004422	 0.020102	 0.0	 1535	 1535	 1535	 0.0	 0.0	 1	 -30.0	 30.0;
	8004	 4778	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6872	 740	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 3223	 0.000822	 0.003622	 0.0	 8505	 8505	 8505	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 2347	 0.000809	 0.003689	 0.0	 8364	 8364	 8364	 0.0	 0.0	 1	 -30.0	 30.0;
	3528	 6705	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 6705	 0.001471	 0.00528	 0.0	 5763	 5763	 5763	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 6705	 0.001502	 0.005169	 0.0	 5869	 5869	 5869	 0.0	 0.0	 1	 -30.0	 30.0;
	2164	 6705	 0.000769	 0.002858	 0.0	 10673	 10673	 10673	 0.0	 0.0	 1	 -30.0	 30.0;
	6705	 2293	 0.003698	 0.013209	 0.0	 2303	 2303	 2303	 0.0	 0.0	 1	 -30.0	 30.0;
	6705	 2148	 0.00116	 0.005271	 0.0	 5853	 5853	 5853	 0.0	 0.0	 1	 -30.0	 30.0;
	6705	 5053	 0.003378	 0.006178	 0.0	 260.0	 4487	 4487	 0.0	 0.0	 1	 -30.0	 30.0;
	6705	 762	 0.000849	 0.004009	 0.0	 7709	 7709	 7709	 0.0	 0.0	 1	 -30.0	 30.0;
	6705	 169	 0.000431	 0.00112	 0.0	 26322	 26322	 26322	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 9156	 0.006778	 0.002631	 0.0	 4345	 4345	 4345	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 3101	 0.003569	 0.00468	 0.0	 273.0	 5367	 5367	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 3101	 0.003178	 0.005298	 0.0	 260.0	 5113	 5113	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 4260	 0.00388	 0.0174	 0.0	 1772	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 4260	 0.003138	 0.011689	 0.0	 2610	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 3376	 0.0044	 0.017049	 0.0	 1794	 1794	 1794	 0.0	 0.0	 1	 -30.0	 30.0;
	3376	 7682	 0.000791	 0.002631	 0.0	 11498	 11498	 11498	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 2945	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 6853	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 6853	 0.017698	 0.0584	 0.0	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 6853	 0.015769	 0.066191	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 8345	 0.00225	 0.02425	 0.0	 823.0	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 8345	 0.00161	 0.02118	 0.0	 1152.0	 2078	 2078	 0.0	 0.0	 1	 -30.0	 30.0;
	1132	 8345	 0.00312	 0.03268	 0.0	 1251.0	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	1132	 8345	 0.00305	 0.0333	 0.0	 1382.0	 1442	 1442	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 5553	 0.000182	 0.000831	 0.0	 37132	 37132	 37132	 0.0	 0.0	 1	 -30.0	 30.0;
	8827	 6230	 0.013649	 0.054609	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	8979	 7825	 0.007209	 0.03252	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	8823	 8979	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7825	 5553	 0.000169	 0.000769	 0.0	 40119	 40119	 40119	 0.0	 0.0	 1	 -30.0	 30.0;
	2739	 5553	 0.011649	 0.026778	 0.0	 1082	 1082	 1082	 0.0	 0.0	 1	 -30.0	 30.0;
	8257	 2739	 0.004049	 0.01112	 0.0	 2670	 2670	 2670	 0.0	 0.0	 1	 -30.0	 30.0;
	8257	 5553	 0.007898	 0.037338	 0.0	 828	 828	 828	 0.0	 0.0	 1	 -30.0	 30.0;
	8257	 5553	 0.00772	 0.034578	 0.0	 892	 892	 892	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 4699	 0.042582	 0.193609	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 8379	 0.027591	 0.130569	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 5548	 0.018431	 0.065898	 0.0	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 31	 0.02836	 0.1134	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 961	 0.046142	 0.15844	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	7535	 5553	 0.011409	 0.027311	 0.0	 273.0	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 8712	 0.019271	 0.063569	 0.0	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 8712	 0.02212	 0.082329	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	2964	 4792	 0.018249	 0.04624	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 4792	 0.008929	 0.01872	 0.0	 1523	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 4792	 0.008742	 0.017329	 0.0	 1628	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	1577	 5947	 0.001569	 0.00412	 0.0	 7165	 7165	 7165	 0.0	 0.0	 1	 -30.0	 30.0;
	5947	 7826	 0.037409	 0.106911	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	1577	 8385	 0.01836	 0.049671	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 3600	 0.007791	 0.037502	 0.0	 825	 825	 825	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 1490	 0.014911	 0.051218	 0.0	 593	 593	 593	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 4895	 0.007071	 0.0294	 0.0	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 7391	 0.010169	 0.039378	 0.0	 777	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	8257	 8502	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8257	 6493	 0.004449	 0.00924	 0.0	 3081	 3081	 3081	 0.0	 0.0	 1	 -30.0	 30.0;
	3695	 5330	 0.002191	 0.011142	 0.0	 2782	 2782	 2782	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 8074	 0.00244	 0.011951	 0.0	 2590	 2590	 2590	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 7185	 0.004662	 0.020871	 0.0	 1478	 1478	 1478	 0.0	 0.0	 1	 -30.0	 30.0;
	3695	 7185	 0.00528	 0.020449	 0.0	 1496	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 7185	 0.0036	 0.0144	 0.0	 2129	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	2851	 3863	 0.00212	 0.008871	 0.0	 3464	 3464	 3464	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 2851	 0.001991	 0.008271	 0.0	 3713	 3713	 3713	 0.0	 0.0	 1	 -30.0	 30.0;
	384	 3863	 0.002071	 0.009049	 0.0	 3403	 3403	 3403	 0.0	 0.0	 1	 -30.0	 30.0;
	384	 3933	 0.002031	 0.008098	 0.0	 3784	 3784	 3784	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 2696	 0.002631	 0.00868	 0.0	 3483	 3483	 3483	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 2696	 0.00048	 0.001769	 0.0	 17233	 17233	 17233	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 5876	 0.002338	 0.009831	 0.0	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 5876	 0.006911	 0.025742	 0.0	 1186	 1186	 1186	 0.0	 0.0	 1	 -30.0	 30.0;
	8299	 2234	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2399	 3417	 0.005649	 0.020209	 0.0	 1506	 1506	 1506	 0.0	 0.0	 1	 -30.0	 30.0;
	4589	 3417	 0.037822	 0.075338	 0.0	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	9172	 2399	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2399	 7100	 0.005609	 0.020871	 0.0	 1462	 1462	 1462	 0.0	 0.0	 1	 -30.0	 30.0;
	2399	 7610	 0.042569	 0.11516	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	1537	 7100	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8462	 5739	 0.00396	 0.010458	 0.0	 2825	 2825	 2825	 0.0	 0.0	 1	 -30.0	 30.0;
	7001	 5739	 0.019671	 0.088151	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	1217	 8587	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 5454	 0.00912	 0.03364	 0.0	 907	 907	 907	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 7319	 0.010942	 0.051369	 0.0	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	2970	 8587	 0.000182	 0.000822	 0.0	 37519	 37519	 37519	 0.0	 0.0	 1	 -30.0	 30.0;
	2970	 8591	 0.023209	 0.118049	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 8587	 0.0002	 0.000809	 0.0	 37904	 37904	 37904	 0.0	 0.0	 1	 -30.0	 30.0;
	2131	 6235	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 7547	 0.00076	 0.00811	 0.0	 1448.0	 5917	 5917	 0.0	 0.0	 1	 -30.0	 30.0;
	8152	 2837	 5.8e-05	 0.000231	 0.0	 132626	 132626	 132626	 0.0	 0.0	 1	 -30.0	 30.0;
	7610	 8152	 0.013471	 0.053849	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	7307	 7610	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 1864	 0.007489	 0.03376	 0.0	 914	 914	 914	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 1637	 0.004271	 0.016431	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 5112	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8737	 5112	 0.013289	 0.04384	 0.0	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	8737	 5112	 0.01184	 0.049689	 0.0	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	8737	 5112	 0.011338	 0.0508	 0.0	 607	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	3831	 5112	 0.008502	 0.035671	 0.0	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 3588	 0.02216	 0.088622	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 5396	 0.019911	 0.101262	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 443	 0.014551	 0.068258	 0.0	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 4422	 0.014129	 0.050529	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 7387	 0.018022	 0.08072	 0.0	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	517	 7610	 0.005382	 0.02004	 0.0	 1523	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	9081	 646	 0.007769	 0.034791	 0.0	 887	 887	 887	 0.0	 0.0	 1	 -30.0	 30.0;
	646	 7001	 0.068351	 0.30616	 0.0	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 5402	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1396	 9092	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	240	 2292	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	14	 436	 0.00163	 0.01819	 0.0	 1580.0	 2416	 2416	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 14	 0.00241	 0.02622	 0.0	 1251.0	 1676	 1676	 0.0	 0.0	 1	 -30.0	 30.0;
	6741	 14	 0.00236	 0.02672	 0.0	 1349.0	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	14	 2869	 0.00188	 0.02029	 0.0	 1020.0	 2166	 2166	 0.0	 0.0	 1	 -30.0	 30.0;
	14	 2869	 0.00213	 0.01988	 0.0	 1020.0	 2207	 2207	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 2925	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1007	 2925	 0.009822	 0.046449	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	7400	 2925	 0.00344	 0.01628	 0.0	 1899	 1899	 1899	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 1729	 0.00648	 0.025102	 0.0	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 6347	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6347	 183	 0.02368	 0.099338	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	3455	 6347	 0.017169	 0.061382	 0.0	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 8845	 0.00209	 0.01796	 0.0	 1218.0	 1747	 1747	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 8845	 0.00213	 0.01758	 0.0	 1218.0	 1784	 1784	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 8845	 0.0013	 0.01389	 0.0	 1185.0	 3455	 3455	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 8845	 0.00147	 0.01361	 0.0	 1283.0	 3521	 3521	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 4346	 0.00052	 0.00446	 0.0	 1251.0	 9826	 9826	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 4346	 0.00053	 0.00436	 0.0	 1185.0	 10045	 10045	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 7734	 0.014889	 0.05544	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 7734	 0.015178	 0.054289	 0.0	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	2217	 2859	 0.003111	 0.013569	 0.0	 2270	 2270	 2270	 0.0	 0.0	 1	 -30.0	 30.0;
	6322	 2859	 0.000791	 0.00376	 0.0	 8221	 8221	 8221	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 7478	 0.002751	 0.009809	 0.0	 3101	 3101	 3101	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 9076	 0.007129	 0.024471	 0.0	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 8813	 0.017951	 0.0668	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 5166	 0.006178	 0.02812	 0.0	 1098	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 1687	 0.006049	 0.028649	 0.0	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	6072	 4985	 0.00396	 0.03136	 0.0	 1251.0	 1396	 1396	 0.0	 0.0	 1	 -30.0	 30.0;
	6072	 4985	 0.00353	 0.03554	 0.0	 1119.0	 1236	 1236	 0.0	 0.0	 1	 -30.0	 30.0;
	6072	 4985	 0.00387	 0.0331	 0.0	 1283.0	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	6072	 4985	 0.00394	 0.03239	 0.0	 1251.0	 1353	 1353	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 1259	 0.00225	 0.01786	 0.0	 1086.0	 2451	 2451	 0.0	 0.0	 1	 -30.0	 30.0;
	1259	 3056	 0.00124	 0.01101	 0.0	 1152.0	 3982	 3982	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 4460	 0.00201	 0.02024	 0.0	 1185.0	 2170	 2170	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 6257	 0.00197	 0.02063	 0.0	 1086.0	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	6257	 3056	 0.00126	 0.01078	 0.0	 1185.0	 4065	 4065	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 5406	 0.00193	 0.02103	 0.0	 1251.0	 2090	 2090	 0.0	 0.0	 1	 -30.0	 30.0;
	4919	 2617	 0.001209	 0.004551	 0.0	 6709	 6709	 6709	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 1319	 0.000449	 0.002018	 0.0	 15280	 15280	 15280	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 2617	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 3779	 0.007049	 0.0252	 0.0	 1208	 1208	 1208	 0.0	 0.0	 1	 -30.0	 30.0;
	7651	 5798	 0.001191	 0.003222	 0.0	 9196	 9196	 9196	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 859	 0.000511	 0.001978	 0.0	 15462	 15462	 15462	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 7046	 0.001009	 0.004782	 0.0	 6464	 6464	 6464	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 8554	 0.000991	 0.004422	 0.0	 6971	 6971	 6971	 0.0	 0.0	 1	 -30.0	 30.0;
	3385	 2580	 0.000929	 0.003098	 0.0	 9767	 9767	 9767	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 3385	 0.005858	 0.0246	 0.0	 1250	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 8904	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 8904	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 5696	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 1954	 0.002031	 0.009222	 0.0	 3346	 3346	 3346	 0.0	 0.0	 1	 -30.0	 30.0;
	5967	 5696	 0.01036	 0.045231	 0.0	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 2525	 0.026858	 0.062822	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	810	 1954	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1954	 2664	 0.021569	 0.098089	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	8457	 8904	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4166	 5281	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5281	 3138	 0.000418	 0.001769	 0.0	 17378	 17378	 17378	 0.0	 0.0	 1	 -30.0	 30.0;
	5281	 7319	 0.000409	 0.001809	 0.0	 17032	 17032	 17032	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 4619	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5777	 6779	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8354	 4604	 0.000569	 0.00168	 0.0	 17809	 17809	 17809	 0.0	 0.0	 1	 -30.0	 30.0;
	8354	 8730	 0.000582	 0.001649	 0.0	 18064	 18064	 18064	 0.0	 0.0	 1	 -30.0	 30.0;
	8730	 4590	 0.001858	 0.006911	 0.0	 4414	 4414	 4414	 0.0	 0.0	 1	 -30.0	 30.0;
	9226	 8354	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 272	 0.0154	 0.006022	 0.0	 286.0	 1911	 1911	 0.0	 0.0	 1	 -30.0	 30.0;
	3473	 5924	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5924	 9098	 8e-05	 0.0004	 0.0	 77435	 77435	 77435	 0.0	 0.0	 1	 -30.0	 30.0;
	5924	 1012	 9.8e-05	 0.000329	 0.0	 92015	 92015	 92015	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 9098	 0.023129	 0.076289	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	517	 1012	 0.011258	 0.047249	 0.0	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 6301	 0.018822	 0.072271	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 7763	 0.002009	 0.006649	 0.0	 4548	 4548	 4548	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 4464	 0.000942	 0.00424	 0.0	 7273	 7273	 7273	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 8253	 0.017711	 0.060809	 0.0	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 8253	 0.01804	 0.059489	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 6072	 0.0028	 0.03055	 0.0	 1251.0	 1439	 1439	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 6072	 0.00274	 0.03113	 0.0	 1382.0	 1412	 1412	 0.0	 0.0	 1	 -30.0	 30.0;
	1413	 5186	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8591	 288	 0.0002	 0.000942	 0.0	 32802	 32802	 32802	 0.0	 0.0	 1	 -30.0	 30.0;
	3911	 6360	 0.004351	 0.014929	 0.0	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	3911	 8591	 0.004831	 0.017289	 0.0	 1760	 1760	 1760	 0.0	 0.0	 1	 -30.0	 30.0;
	4796	 4222	 0.014289	 0.067609	 0.0	 698	 698	 698	 0.0	 0.0	 1	 -30.0	 30.0;
	4796	 4222	 0.013978	 0.0626	 0.0	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 4073	 0.004431	 0.014609	 0.0	 2070	 2070	 2070	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 4080	 0.00664	 0.025711	 0.0	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 7106	 0.001289	 0.004422	 0.0	 6858	 6858	 6858	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 1824	 0.01448	 0.065822	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 3298	 0.004631	 0.017938	 0.0	 1706	 1706	 1706	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 3298	 0.00492	 0.01692	 0.0	 1793	 1793	 1793	 0.0	 0.0	 1	 -30.0	 30.0;
	7001	 5186	 0.027511	 0.120182	 0.0	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	6385	 5186	 0.004	 0.014898	 0.0	 2048	 2048	 2048	 0.0	 0.0	 1	 -30.0	 30.0;
	7682	 881	 0.000351	 0.001591	 0.0	 19388	 19388	 19388	 0.0	 0.0	 1	 -30.0	 30.0;
	7001	 881	 0.018929	 0.084791	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	1877	 744	 0.013502	 0.063889	 0.0	 484	 484	 484	 0.0	 0.0	 1	 -30.0	 30.0;
	1864	 5371	 0.01632	 0.057871	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	7822	 2159	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 2159	 0.01176	 0.04704	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	3117	 7826	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9038	 7826	 0.02892	 0.057622	 0.0	 260.0	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	2753	 4673	 0.001711	 0.0078	 0.0	 3956	 3956	 3956	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 4673	 0.01224	 0.042022	 0.0	 722	 722	 722	 0.0	 0.0	 1	 -30.0	 30.0;
	6479	 2194	 0.007769	 0.061249	 0.0	 260.0	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	8959	 5687	 0.001391	 0.0048	 0.0	 6321	 6321	 6321	 0.0	 0.0	 1	 -30.0	 30.0;
	4551	 8959	 0.004071	 0.01988	 0.0	 1557	 1557	 1557	 0.0	 0.0	 1	 -30.0	 30.0;
	7837	 5687	 0.001418	 0.004702	 0.0	 6432	 6432	 6432	 0.0	 0.0	 1	 -30.0	 30.0;
	7837	 3086	 0.012711	 0.048809	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 2032	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8146	 5687	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2032	 5687	 0.00448	 0.016698	 0.0	 1828	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 4551	 0.014689	 0.052049	 0.0	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	2032	 176	 0.025631	 0.084538	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	8823	 2628	 0.005431	 0.026551	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 4422	 0.013151	 0.058898	 0.0	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 8257	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3627	 183	 0.00036	 0.001329	 0.0	 22941	 22941	 22941	 0.0	 0.0	 1	 -30.0	 30.0;
	5937	 8409	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8489	 5937	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8409	 5782	 0.00612	 0.014671	 0.0	 1988	 1988	 1988	 0.0	 0.0	 1	 -30.0	 30.0;
	7233	 8489	 0.006942	 0.014378	 0.0	 286.0	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 3272	 4.9e-05	 0.00028	 0.0	 111124	 111124	 111124	 0.0	 0.0	 1	 -30.0	 30.0;
	4108	 6200	 0.002071	 0.008289	 0.0	 3698	 3698	 3698	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 3272	 4.9e-05	 0.00028	 0.0	 111124	 111124	 111124	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 6935	 0.000729	 0.003049	 0.0	 10076	 10076	 10076	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 3272	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3406	 9186	 0.000409	 0.00184	 0.0	 16759	 16759	 16759	 0.0	 0.0	 1	 -30.0	 30.0;
	2964	 9186	 0.0004	 0.00188	 0.0	 16434	 16434	 16434	 0.0	 0.0	 1	 -30.0	 30.0;
	448	 6885	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6885	 6819	 0.003982	 0.020249	 0.0	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	6885	 8589	 0.006498	 0.031791	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	8838	 6404	 0.000129	 0.000609	 0.0	 50742	 50742	 50742	 0.0	 0.0	 1	 -30.0	 30.0;
	8838	 614	 0.00036	 0.000729	 0.0	 38851	 38851	 38851	 0.0	 0.0	 1	 -30.0	 30.0;
	8838	 8684	 0.000129	 0.000569	 0.0	 54140	 54140	 54140	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 8838	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8684	 538	 0.006862	 0.030942	 0.0	 997	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	3553	 4405	 0.0016	 0.00716	 0.0	 4306	 4306	 4306	 0.0	 0.0	 1	 -30.0	 30.0;
	3553	 8092	 0.001849	 0.006542	 0.0	 4647	 4647	 4647	 0.0	 0.0	 1	 -30.0	 30.0;
	768	 4405	 0.001809	 0.007018	 0.0	 4359	 4359	 4359	 0.0	 0.0	 1	 -30.0	 30.0;
	768	 2960	 0.004302	 0.01588	 0.0	 1920	 1920	 1920	 0.0	 0.0	 1	 -30.0	 30.0;
	3252	 4405	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7734	 6855	 0.008831	 0.036751	 0.0	 836	 836	 836	 0.0	 0.0	 1	 -30.0	 30.0;
	7734	 65	 0.011031	 0.045942	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	6562	 7734	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 7734	 0.043418	 0.124111	 0.0	 367	 367	 367	 0.0	 0.0	 1	 -30.0	 30.0;
	9070	 3138	 0.011698	 0.048702	 0.0	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	8737	 3831	 0.005058	 0.02572	 0.0	 1206	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	8080	 3831	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 6018	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8752	 8162	 0.008969	 0.032062	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 7024	 0.000489	 0.002369	 0.0	 13059	 13059	 13059	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 7024	 0.0028	 0.0096	 0.0	 3159	 3159	 3159	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 4707	 0.00048	 0.002191	 0.0	 14083	 14083	 14083	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 4707	 0.002849	 0.0094	 0.0	 3216	 3216	 3216	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 2354	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4160	 8752	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8169	 8752	 0.005138	 0.023391	 0.0	 1319	 1319	 1319	 0.0	 0.0	 1	 -30.0	 30.0;
	3339	 8752	 0.005031	 0.023831	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	6024	 8752	 0.00492	 0.022062	 0.0	 1398	 1398	 1398	 0.0	 0.0	 1	 -30.0	 30.0;
	8752	 4933	 0.012449	 0.03368	 0.0	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 5307	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1374	 5307	 0.005582	 0.021622	 0.0	 1415	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 1931	 0.011769	 0.052729	 0.0	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 7612	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8615	 7612	 0.005489	 0.019618	 0.0	 1551	 1551	 1551	 0.0	 0.0	 1	 -30.0	 30.0;
	7462	 7612	 0.005591	 0.0192	 0.0	 1580	 1580	 1580	 0.0	 0.0	 1	 -30.0	 30.0;
	7034	 1521	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7300	 8169	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3339	 7858	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1521	 7858	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 1061	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9147	 3573	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 7172	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7172	 6024	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	383	 6875	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 494	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	383	 9147	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3998	 1231	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 3998	 0.012969	 0.046369	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	1231	 3686	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3686	 1374	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	494	 7300	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8023	 7470	 0.003151	 0.00128	 0.0	 9288	 9288	 9288	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 310	 0.00154	 0.01649	 0.0	 1415.0	 2911	 2911	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 5858	 0.001298	 0.00568	 0.0	 5422	 5422	 5422	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 1831	 0.0002	 0.000871	 0.0	 35346	 35346	 35346	 0.0	 0.0	 1	 -30.0	 30.0;
	8769	 7921	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9081	 7921	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 7921	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 8591	 0.010071	 0.039	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	4328	 5496	 0.000218	 0.000849	 0.0	 36037	 36037	 36037	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 5496	 0.000231	 0.00084	 0.0	 36258	 36258	 36258	 0.0	 0.0	 1	 -30.0	 30.0;
	8616	 5496	 0.000231	 0.000822	 0.0	 36995	 36995	 36995	 0.0	 0.0	 1	 -30.0	 30.0;
	101	 5496	 0.00024	 0.0008	 0.0	 37819	 37819	 37819	 0.0	 0.0	 1	 -30.0	 30.0;
	7057	 5496	 0.00024	 0.000782	 0.0	 38616	 38616	 38616	 0.0	 0.0	 1	 -30.0	 30.0;
	5496	 3812	 0.000209	 0.000889	 0.0	 34589	 34589	 34589	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 5496	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 5496	 0.000209	 0.000911	 0.0	 33796	 33796	 33796	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 1840	 0.00784	 0.025862	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	8616	 5867	 0.001991	 0.009391	 0.0	 3291	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	101	 5013	 0.003591	 0.01184	 0.0	 2554	 2554	 2554	 0.0	 0.0	 1	 -30.0	 30.0;
	7712	 537	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 2000	 0.00013	 0.00077	 0.0	 954.0	 40451	 40451	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 2000	 0.00013	 0.00076	 0.0	 987.0	 40968	 40968	 0.0	 0.0	 1	 -30.0	 30.0;
	914	 2000	 0.0002	 0.00127	 0.0	 987.0	 24570	 24570	 0.0	 0.0	 1	 -30.0	 30.0;
	4083	 4853	 0.002449	 0.006871	 0.0	 4331	 4331	 4331	 0.0	 0.0	 1	 -30.0	 30.0;
	2542	 7339	 0.00132	 0.004929	 0.0	 260.0	 6191	 6191	 0.0	 0.0	 1	 -30.0	 30.0;
	5925	 2391	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2391	 2525	 0.036111	 0.084471	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	2391	 2757	 0.043129	 0.093129	 0.0	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 8452	 0.001071	 0.004129	 0.0	 7406	 7406	 7406	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 8452	 0.01016	 0.036298	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 6018	 0.010951	 0.055689	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 7088	 0.005831	 0.022591	 0.0	 1354	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 7088	 0.016542	 0.075222	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 5318	 0.015938	 0.00716	 0.0	 1808	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 2612	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 546	 0.009591	 0.02332	 0.0	 1253	 1253	 1253	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 5782	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 3678	 0.03828	 0.10096	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 3678	 0.03036	 0.086778	 0.0	 260.0	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	3318	 1288	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7863	 2217	 0.002182	 0.010329	 0.0	 2993	 2993	 2993	 0.0	 0.0	 1	 -30.0	 30.0;
	7863	 4699	 0.002129	 0.009569	 0.0	 3223	 3223	 3223	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 3060	 0.0018	 0.00668	 0.0	 4566	 4566	 4566	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 3060	 0.004569	 0.01636	 0.0	 1860	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 3172	 0.001831	 0.006542	 0.0	 4650	 4650	 4650	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 4316	 0.006338	 0.026609	 0.0	 1155	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	6955	 7001	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7001	 6078	 0.016231	 0.070902	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	7001	 8303	 0.010138	 0.046102	 0.0	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	5903	 3455	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3455	 9104	 0.006431	 0.028991	 0.0	 1064	 1064	 1064	 0.0	 0.0	 1	 -30.0	 30.0;
	2753	 6223	 0.01184	 0.053022	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	2753	 2779	 0.012529	 0.044422	 0.0	 685	 685	 685	 0.0	 0.0	 1	 -30.0	 30.0;
	7587	 5634	 0.00436	 0.010689	 0.0	 2737	 2737	 2737	 0.0	 0.0	 1	 -30.0	 30.0;
	5030	 7587	 0.019529	 0.055831	 0.0	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	3181	 5634	 0.004942	 0.01048	 0.0	 2727	 2727	 2727	 0.0	 0.0	 1	 -30.0	 30.0;
	8054	 5634	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1272	 2422	 0.006431	 0.01764	 0.0	 1683	 1683	 1683	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 1272	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	8901	 2422	 0.003431	 0.013218	 0.0	 2314	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 2422	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2422	 5951	 0.00708	 0.014702	 0.0	 260.0	 1936	 1936	 0.0	 0.0	 1	 -30.0	 30.0;
	3626	 2422	 0.065422	 0.130311	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	8901	 3561	 0.003049	 0.013831	 0.0	 2231	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	9092	 8901	 0.011209	 0.051009	 0.0	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	812	 8901	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8002	 8901	 0.00504	 0.024622	 0.0	 1257	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 3561	 0.009049	 0.033671	 0.0	 906	 906	 906	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 3561	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 6644	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 4621	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9092	 5951	 0.007631	 0.015569	 0.0	 1822	 1822	 1822	 0.0	 0.0	 1	 -30.0	 30.0;
	9092	 2454	 0.000822	 0.00316	 0.0	 9675	 9675	 9675	 0.0	 0.0	 1	 -30.0	 30.0;
	9092	 7453	 0.017751	 0.060929	 0.0	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 6644	 0.007418	 0.016022	 0.0	 260.0	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 9041	 0.007542	 0.035689	 0.0	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	8932	 469	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	469	 1296	 0.000338	 0.001218	 0.0	 24990	 24990	 24990	 0.0	 0.0	 1	 -30.0	 30.0;
	8559	 178	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	178	 7801	 0.000351	 0.001191	 0.0	 25440	 25440	 25440	 0.0	 0.0	 1	 -30.0	 30.0;
	6944	 1166	 0.004662	 0.016009	 0.0	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	6944	 8394	 0.017489	 0.084191	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 30	 0.003809	 0.013111	 0.0	 2314	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 6094	 0.003489	 0.013502	 0.0	 2266	 2266	 2266	 0.0	 0.0	 1	 -30.0	 30.0;
	3627	 1166	 0.004738	 0.015658	 0.0	 1931	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	3185	 1166	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 2571	 0.010351	 0.035529	 0.0	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 6364	 0.00388	 0.012822	 0.0	 2358	 2358	 2358	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 30	 0.003729	 0.013218	 0.0	 2300	 2300	 2300	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 7095	 0.002418	 0.008298	 0.0	 3655	 3655	 3655	 0.0	 0.0	 1	 -30.0	 30.0;
	7801	 7095	 0.001538	 0.007822	 0.0	 3963	 3963	 3963	 0.0	 0.0	 1	 -30.0	 30.0;
	1288	 6310	 0.005369	 0.010702	 0.0	 260.0	 2639	 2639	 0.0	 0.0	 1	 -30.0	 30.0;
	2522	 7427	 0.00088	 0.0075	 0.0	 1481.0	 4183	 4183	 0.0	 0.0	 1	 -30.0	 30.0;
	2522	 7427	 0.0009	 0.00734	 0.0	 1415.0	 4272	 4272	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 7233	 0.0	 0.00028	 0.0	 286.0	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1569	 8340	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 8340	 0.0	 0.00028	 0.0	 286.0	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5953	 8340	 0.018831	 0.072951	 0.0	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 8340	 0.012351	 0.042409	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	5030	 3901	 0.001938	 0.008698	 0.0	 3545	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 5030	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6437	 8655	 0.017871	 0.047151	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	8655	 669	 0.00076	 0.002098	 0.0	 14156	 14156	 14156	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 5041	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8074	 2571	 0.005249	 0.024631	 0.0	 1255	 1255	 1255	 0.0	 0.0	 1	 -30.0	 30.0;
	8094	 8074	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1727	 3992	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8506	 3992	 0.00016	 0.000502	 0.0	 59952	 59952	 59952	 0.0	 0.0	 1	 -30.0	 30.0;
	3795	 8506	 0.008658	 0.037809	 0.0	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	6078	 3992	 0.000142	 0.00056	 0.0	 54676	 54676	 54676	 0.0	 0.0	 1	 -30.0	 30.0;
	6765	 6437	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	6765	 5606	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	7478	 3154	 0.0002	 0.00092	 0.0	 33551	 33551	 33551	 0.0	 0.0	 1	 -30.0	 30.0;
	3154	 1310	 0.002542	 0.010649	 0.0	 2886	 2886	 2886	 0.0	 0.0	 1	 -30.0	 30.0;
	6322	 31	 0.054	 0.121351	 0.0	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	6593	 7478	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3460	 4287	 0.001969	 0.004271	 0.0	 6717	 6717	 6717	 0.0	 0.0	 1	 -30.0	 30.0;
	3460	 3626	 0.009111	 0.025009	 0.0	 286.0	 1187	 1187	 0.0	 0.0	 1	 -30.0	 30.0;
	1735	 3460	 0.027502	 0.074369	 0.0	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	7871	 6774	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6774	 3588	 0.0002	 0.000942	 0.0	 32802	 32802	 32802	 0.0	 0.0	 1	 -30.0	 30.0;
	6774	 6819	 0.0002	 0.000871	 0.0	 35346	 35346	 35346	 0.0	 0.0	 1	 -30.0	 30.0;
	1986	 9179	 0.00052	 0.00136	 0.0	 21695	 21695	 21695	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 1986	 0.020471	 0.07928	 0.0	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	4841	 845	 3.1e-05	 0.00028	 0.0	 112127	 112127	 112127	 0.0	 0.0	 1	 -30.0	 30.0;
	6226	 845	 0.015609	 0.076289	 0.0	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	4841	 8002	 3.1e-05	 0.00028	 0.0	 112127	 112127	 112127	 0.0	 0.0	 1	 -30.0	 30.0;
	2374	 4841	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8436	 7290	 0.008809	 0.041342	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	8694	 7290	 0.011698	 0.017782	 0.0	 1485	 1485	 1485	 0.0	 0.0	 1	 -30.0	 30.0;
	5950	 8436	 0.029769	 0.069649	 0.0	 260.0	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 5707	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5953	 5707	 0.006738	 0.024089	 0.0	 1263	 1263	 1263	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 8131	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1376	 5827	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8606	 3704	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 2542	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 2542	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 3704	 0.001062	 0.003649	 0.0	 8312	 8312	 8312	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 1780	 0.00204	 0.009129	 0.0	 3377	 3377	 3377	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 1780	 0.00232	 0.008951	 0.0	 3417	 3417	 3417	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 5980	 0.00152	 0.006911	 0.0	 4464	 4464	 4464	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 5980	 0.001489	 0.00704	 0.0	 4390	 4390	 4390	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 5980	 0.001462	 0.00652	 0.0	 4728	 4728	 4728	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 8747	 0.001391	 0.003609	 0.0	 260.0	 8167	 8167	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 5968	 0.001658	 0.003311	 0.0	 8531	 8531	 8531	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 8154	 0.000991	 0.004329	 0.0	 7113	 7113	 7113	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 2690	 0.010369	 0.038569	 0.0	 791	 791	 791	 0.0	 0.0	 1	 -30.0	 30.0;
	1332	 1780	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1332	 6032	 0.026809	 0.126889	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	8632	 1780	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8632	 8461	 0.026218	 0.117489	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	5980	 1780	 0.00064	 0.002662	 0.0	 11538	 11538	 11538	 0.0	 0.0	 1	 -30.0	 30.0;
	5980	 1780	 0.000622	 0.002711	 0.0	 11357	 11357	 11357	 0.0	 0.0	 1	 -30.0	 30.0;
	5980	 86	 0.000609	 0.002271	 0.0	 13435	 13435	 13435	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 8747	 0.002098	 0.005702	 0.0	 260.0	 5199	 5199	 0.0	 0.0	 1	 -30.0	 30.0;
	2179	 5968	 0.002582	 0.006031	 0.0	 4815	 4815	 4815	 0.0	 0.0	 1	 -30.0	 30.0;
	4093	 2179	 0.019458	 0.055618	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 8154	 0.00092	 0.003289	 0.0	 9249	 9249	 9249	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 86	 0.000942	 0.003222	 0.0	 9410	 9410	 9410	 0.0	 0.0	 1	 -30.0	 30.0;
	8238	 1454	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 6125	 0.03868	 0.1062	 0.0	 260.0	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 9170	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2397	 9170	 0.000689	 0.00312	 0.0	 9886	 9886	 9886	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 9170	 0.0008	 0.002991	 0.0	 10203	 10203	 10203	 0.0	 0.0	 1	 -30.0	 30.0;
	997	 8400	 0.000511	 0.001191	 0.0	 24374	 24374	 24374	 0.0	 0.0	 1	 -30.0	 30.0;
	8842	 670	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2525	 2781	 0.01216	 0.048609	 0.0	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	3858	 2690	 0.000769	 0.00348	 0.0	 8864	 8864	 8864	 0.0	 0.0	 1	 -30.0	 30.0;
	3858	 5967	 0.000871	 0.003409	 0.0	 8978	 8978	 8978	 0.0	 0.0	 1	 -30.0	 30.0;
	6301	 8253	 0.007071	 0.03316	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	538	 5635	 0.009609	 0.038418	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 538	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8673	 5635	 0.00724	 0.014951	 0.0	 1902	 1902	 1902	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 4316	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7990	 4316	 0.016071	 0.067418	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	7990	 4316	 0.015738	 0.068751	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 4233	 0.017431	 0.037622	 0.0	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 6412	 0.001031	 0.003378	 0.0	 8944	 8944	 8944	 0.0	 0.0	 1	 -30.0	 30.0;
	6412	 8011	 0.000169	 0.00068	 0.0	 45081	 45081	 45081	 0.0	 0.0	 1	 -30.0	 30.0;
	1687	 6767	 0.006249	 0.023262	 0.0	 1312	 1312	 1312	 0.0	 0.0	 1	 -30.0	 30.0;
	9076	 6042	 8.9e-05	 0.000471	 0.0	 65899	 65899	 65899	 0.0	 0.0	 1	 -30.0	 30.0;
	2991	 2635	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 2635	 0.01564	 0.065089	 0.0	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 1701	 0.018938	 0.085391	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 1476	 0.016511	 0.044662	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	8607	 517	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	517	 8673	 0.002689	 0.012938	 0.0	 2391	 2391	 2391	 0.0	 0.0	 1	 -30.0	 30.0;
	5072	 2873	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	821	 5072	 0.007649	 0.019631	 0.0	 2288	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 363	 0.008849	 0.02096	 0.0	 1940	 1940	 1940	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 6255	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	363	 4835	 0.0	 0.00028	 0.0	 157564	 157564	 157564	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 2378	 0.00232	 0.00928	 0.0	 3303	 3303	 3303	 0.0	 0.0	 1	 -30.0	 30.0;
	2697	 1518	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7453	 5861	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 2213	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5879	 3392	 0.0088	 0.034102	 0.0	 897	 897	 897	 0.0	 0.0	 1	 -30.0	 30.0;
	7381	 4915	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7020	 3247	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8160	 4083	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 1608	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7846	 7693	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7704	 5267	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6804	 8839	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8839	 6276	 0.002542	 0.00392	 0.0	 273.0	 6761	 6761	 0.0	 0.0	 1	 -30.0	 30.0;
	7501	 4568	 0.00296	 0.013462	 0.0	 2292	 2292	 2292	 0.0	 0.0	 1	 -30.0	 30.0;
	7939	 7501	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7501	 103	 0.002489	 0.003991	 0.0	 260.0	 6716	 6716	 0.0	 0.0	 1	 -30.0	 30.0;
	767	 5066	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7976	 5066	 0.000289	 0.000742	 0.0	 39668	 39668	 39668	 0.0	 0.0	 1	 -30.0	 30.0;
	7546	 3927	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2580	 3927	 0.000302	 0.000729	 0.0	 40031	 40031	 40031	 0.0	 0.0	 1	 -30.0	 30.0;
	3927	 6976	 0.000662	 0.002111	 0.0	 14278	 14278	 14278	 0.0	 0.0	 1	 -30.0	 30.0;
	4404	 1206	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6531	 1608	 0.000822	 0.002871	 0.0	 10578	 10578	 10578	 0.0	 0.0	 1	 -30.0	 30.0;
	1608	 8686	 0.006391	 0.028809	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 7693	 0.000831	 0.002809	 0.0	 10784	 10784	 10784	 0.0	 0.0	 1	 -30.0	 30.0;
	6814	 6531	 0.014791	 0.005969	 0.0	 1981	 1981	 1981	 0.0	 0.0	 1	 -30.0	 30.0;
	4321	 2825	 0.01508	 0.005849	 0.0	 1953	 1953	 1953	 0.0	 0.0	 1	 -30.0	 30.0;
	4265	 5267	 0.011302	 0.050578	 0.0	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	997	 5267	 0.01704	 0.033938	 0.0	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	8445	 5396	 0.001262	 0.00532	 0.0	 5778	 5778	 5778	 0.0	 0.0	 1	 -30.0	 30.0;
	8445	 2960	 0.00124	 0.005431	 0.0	 5671	 5671	 5671	 0.0	 0.0	 1	 -30.0	 30.0;
	6309	 357	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	357	 2652	 0.001538	 0.004609	 0.0	 6502	 6502	 6502	 0.0	 0.0	 1	 -30.0	 30.0;
	210	 8739	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2701	 6013	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8296	 6013	 0.00244	 0.004071	 0.0	 299.0	 6656	 6656	 0.0	 0.0	 1	 -30.0	 30.0;
	2210	 5136	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 5136	 0.002649	 0.003631	 0.0	 273.0	 7028	 7028	 0.0	 0.0	 1	 -30.0	 30.0;
	4973	 1490	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2529	 1370	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8281	 5858	 0.000849	 0.001769	 0.0	 16099	 16099	 16099	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 7868	 0.000951	 0.003991	 0.0	 7700	 7700	 7700	 0.0	 0.0	 1	 -30.0	 30.0;
	4691	 4835	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	4691	 7911	 0.0034	 0.00872	 0.0	 4714	 4714	 4714	 0.0	 0.0	 1	 -30.0	 30.0;
	6858	 7990	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 4730	 0.001978	 0.007671	 0.0	 3988	 3988	 3988	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 906	 0.002018	 0.00752	 0.0	 4057	 4057	 4057	 0.0	 0.0	 1	 -30.0	 30.0;
	6984	 4247	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 961	 0.018351	 0.070502	 0.0	 606	 606	 606	 0.0	 0.0	 1	 -30.0	 30.0;
	8394	 5402	 0.0028	 0.014209	 0.0	 2182	 2182	 2182	 0.0	 0.0	 1	 -30.0	 30.0;
	931	 9008	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7382	 1598	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6935	 1598	 0.02624	 0.096858	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	450	 5939	 5.8e-05	 0.00024	 0.0	 127932	 127932	 127932	 0.0	 0.0	 1	 -30.0	 30.0;
	450	 7106	 5.8e-05	 0.000231	 0.0	 132626	 132626	 132626	 0.0	 0.0	 1	 -30.0	 30.0;
	6527	 4080	 0.0012	 0.005809	 0.0	 5326	 5326	 5326	 0.0	 0.0	 1	 -30.0	 30.0;
	6527	 7542	 8.9e-05	 0.00028	 0.0	 107512	 107512	 107512	 0.0	 0.0	 1	 -30.0	 30.0;
	6527	 6380	 8e-05	 0.00032	 0.0	 95764	 95764	 95764	 0.0	 0.0	 1	 -30.0	 30.0;
	7542	 3298	 0.006889	 0.032631	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	6380	 3298	 0.006738	 0.030209	 0.0	 1021	 1021	 1021	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 2929	 0.001218	 0.004031	 0.0	 7502	 7502	 7502	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 997	 0.005751	 0.012929	 0.0	 286.0	 2233	 2233	 0.0	 0.0	 1	 -30.0	 30.0;
	161	 3779	 0.000462	 0.001791	 0.0	 17078	 17078	 17078	 0.0	 0.0	 1	 -30.0	 30.0;
	161	 6235	 0.00352	 0.007302	 0.0	 3897	 3897	 3897	 0.0	 0.0	 1	 -30.0	 30.0;
	74	 4919	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4483	 2164	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1322	 5642	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 990	 0.001289	 0.005022	 0.0	 6093	 6093	 6093	 0.0	 0.0	 1	 -30.0	 30.0;
	3567	 8064	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8386	 8686	 0.00036	 0.0016	 0.0	 19261	 19261	 19261	 0.0	 0.0	 1	 -30.0	 30.0;
	8386	 5080	 0.000409	 0.001569	 0.0	 19482	 19482	 19482	 0.0	 0.0	 1	 -30.0	 30.0;
	8234	 8386	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1222	 8386	 0.001658	 0.004511	 0.0	 6573	 6573	 6573	 0.0	 0.0	 1	 -30.0	 30.0;
	5953	 2603	 0.00176	 0.007911	 0.0	 3898	 3898	 3898	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 5953	 0.00172	 0.008058	 0.0	 3834	 3834	 3834	 0.0	 0.0	 1	 -30.0	 30.0;
	6417	 5953	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 8686	 0.0022	 0.00852	 0.0	 3590	 3590	 3590	 0.0	 0.0	 1	 -30.0	 30.0;
	7552	 5080	 0.000111	 0.000489	 0.0	 62994	 62994	 62994	 0.0	 0.0	 1	 -30.0	 30.0;
	7552	 8700	 0.00396	 0.013058	 0.0	 2315	 2315	 2315	 0.0	 0.0	 1	 -30.0	 30.0;
	2603	 8796	 0.001138	 0.002529	 0.0	 11391	 11391	 11391	 0.0	 0.0	 1	 -30.0	 30.0;
	8637	 1660	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8985	 8637	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8637	 2674	 0.001329	 0.005978	 0.0	 5159	 5159	 5159	 0.0	 0.0	 1	 -30.0	 30.0;
	5382	 8827	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 6533	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	6533	 7911	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 3295	 0.010191	 0.028329	 0.0	 1601	 1601	 1601	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 7057	 0.002391	 0.00788	 0.0	 3836	 3836	 3836	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 1832	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 1832	 0.002249	 0.008351	 0.0	 3653	 3653	 3653	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 3040	 0.000302	 0.000969	 0.0	 31122	 31122	 31122	 0.0	 0.0	 1	 -30.0	 30.0;
	2445	 6389	 0.000271	 0.001102	 0.0	 27835	 27835	 27835	 0.0	 0.0	 1	 -30.0	 30.0;
	3812	 6113	 0.000391	 0.001738	 0.0	 17732	 17732	 17732	 0.0	 0.0	 1	 -30.0	 30.0;
	2445	 3201	 0.002289	 0.008178	 0.0	 3720	 3720	 3720	 0.0	 0.0	 1	 -30.0	 30.0;
	7023	 5867	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 4781	 0.00112	 0.00504	 0.0	 6119	 6119	 6119	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 4781	 0.001271	 0.004942	 0.0	 6191	 6191	 6191	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 4781	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 7229	 0.000418	 0.00192	 0.0	 16076	 16076	 16076	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 4479	 0.000409	 0.001951	 0.0	 15846	 15846	 15846	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 95	 0.03228	 0.106458	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 95	 0.02876	 0.120649	 0.0	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	4479	 95	 0.05888	 0.117289	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	6935	 8061	 0.00324	 0.01584	 0.0	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 8061	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3735	 7710	 0.00176	 0.004449	 0.0	 273.0	 6603	 6603	 0.0	 0.0	 1	 -30.0	 30.0;
	8233	 1007	 0.009929	 0.046969	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	8233	 2158	 0.009711	 0.043489	 0.0	 709	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	6385	 2158	 0.005031	 0.02252	 0.0	 1369	 1369	 1369	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 2652	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8538	 6428	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7389	 6428	 0.000462	 0.00108	 0.0	 26891	 26891	 26891	 0.0	 0.0	 1	 -30.0	 30.0;
	8111	 2652	 0.000471	 0.001049	 0.0	 273.0	 27470	 27470	 0.0	 0.0	 1	 -30.0	 30.0;
	1222	 1449	 0.00104	 0.003729	 0.0	 8160	 8160	 8160	 0.0	 0.0	 1	 -30.0	 30.0;
	8379	 5224	 0.002329	 0.008	 0.0	 3792	 3792	 3792	 0.0	 0.0	 1	 -30.0	 30.0;
	8813	 5224	 0.002378	 0.007831	 0.0	 3860	 3860	 3860	 0.0	 0.0	 1	 -30.0	 30.0;
	2010	 5224	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	598	 6385	 0.006711	 0.026018	 0.0	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	6385	 1729	 0.009298	 0.04232	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	8712	 5548	 0.004751	 0.01632	 0.0	 1859	 1859	 1859	 0.0	 0.0	 1	 -30.0	 30.0;
	2778	 1891	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1891	 3086	 0.000338	 0.001151	 0.0	 26332	 26332	 26332	 0.0	 0.0	 1	 -30.0	 30.0;
	1891	 6226	 0.000338	 0.00112	 0.0	 27001	 27001	 27001	 0.0	 0.0	 1	 -30.0	 30.0;
	8688	 7651	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 470	 0.00484	 0.023329	 0.0	 1326	 1326	 1326	 0.0	 0.0	 1	 -30.0	 30.0;
	5151	 6814	 0.004222	 0.017751	 0.0	 1732	 1732	 1732	 0.0	 0.0	 1	 -30.0	 30.0;
	1149	 4321	 0.004138	 0.018102	 0.0	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	4473	 3315	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4473	 1226	 0.000622	 0.002418	 0.0	 12652	 12652	 12652	 0.0	 0.0	 1	 -30.0	 30.0;
	3315	 632	 0.000631	 0.002369	 0.0	 12885	 12885	 12885	 0.0	 0.0	 1	 -30.0	 30.0;
	7763	 8856	 0.00012	 0.00032	 0.0	 92426	 92426	 92426	 0.0	 0.0	 1	 -30.0	 30.0;
	8048	 5265	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1099	 5950	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 103	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8327	 6276	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5895	 627	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 7433	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2270	 8591	 0.001409	 0.00464	 0.0	 6514	 6514	 6514	 0.0	 0.0	 1	 -30.0	 30.0;
	1735	 2270	 0.003098	 0.014911	 0.0	 2075	 2075	 2075	 0.0	 0.0	 1	 -30.0	 30.0;
	8591	 2586	 0.004662	 0.015369	 0.0	 1967	 1967	 1967	 0.0	 0.0	 1	 -30.0	 30.0;
	119	 8220	 9.8e-05	 0.000369	 0.0	 82735	 82735	 82735	 0.0	 0.0	 1	 -30.0	 30.0;
	8591	 119	 0.001031	 0.003658	 0.0	 8312	 8312	 8312	 0.0	 0.0	 1	 -30.0	 30.0;
	3298	 5761	 0.001049	 0.003591	 0.0	 8444	 8444	 8444	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 3690	 0.003209	 0.012338	 0.0	 2478	 2478	 2478	 0.0	 0.0	 1	 -30.0	 30.0;
	6364	 6147	 0.003311	 0.012689	 0.0	 2409	 2409	 2409	 0.0	 0.0	 1	 -30.0	 30.0;
	7987	 2525	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 373	 0.003871	 0.010458	 0.0	 2833	 2833	 2833	 0.0	 0.0	 1	 -30.0	 30.0;
	8461	 95	 0.000218	 0.000849	 0.0	 36037	 36037	 36037	 0.0	 0.0	 1	 -30.0	 30.0;
	6032	 95	 0.000231	 0.00084	 0.0	 36258	 36258	 36258	 0.0	 0.0	 1	 -30.0	 30.0;
	9163	 95	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	373	 2843	 0.000231	 0.000822	 0.0	 36995	 36995	 36995	 0.0	 0.0	 1	 -30.0	 30.0;
	2757	 2843	 0.00024	 0.0008	 0.0	 37819	 37819	 37819	 0.0	 0.0	 1	 -30.0	 30.0;
	2356	 2843	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5651	 4822	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2548	 5870	 0.000151	 0.00036	 0.0	 80914	 80914	 80914	 0.0	 0.0	 1	 -30.0	 30.0;
	2548	 8296	 8e-05	 0.00028	 0.0	 108472	 108472	 108472	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 5568	 8e-05	 0.00028	 0.0	 108472	 108472	 108472	 0.0	 0.0	 1	 -30.0	 30.0;
	1389	 2548	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2548	 1071	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2227	 1071	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 8703	 0.001711	 0.003058	 0.0	 9015	 9015	 9015	 0.0	 0.0	 1	 -30.0	 30.0;
	7868	 1903	 0.003369	 0.008889	 0.0	 260.0	 3323	 3323	 0.0	 0.0	 1	 -30.0	 30.0;
	1749	 8703	 0.002009	 0.005311	 0.0	 260.0	 5563	 5563	 0.0	 0.0	 1	 -30.0	 30.0;
	2953	 1749	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8092	 856	 0.002551	 0.011578	 0.0	 2665	 2665	 2665	 0.0	 0.0	 1	 -30.0	 30.0;
	4108	 856	 0.002489	 0.0118	 0.0	 2620	 2620	 2620	 0.0	 0.0	 1	 -30.0	 30.0;
	7251	 8394	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8394	 3933	 0.010009	 0.04892	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 3681	 0.000182	 0.000671	 0.0	 45434	 45434	 45434	 0.0	 0.0	 1	 -30.0	 30.0;
	7720	 7409	 0.006169	 0.02036	 0.0	 2074	 2074	 2074	 0.0	 0.0	 1	 -30.0	 30.0;
	7409	 1476	 0.007369	 0.0322	 0.0	 1336	 1336	 1336	 0.0	 0.0	 1	 -30.0	 30.0;
	6549	 7720	 0.005498	 0.023071	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	8011	 6549	 0.004809	 0.021671	 0.0	 2172	 2172	 2172	 0.0	 0.0	 1	 -30.0	 30.0;
	4229	 7720	 0.0	 0.00028	 0.0	 157564	 157564	 157564	 0.0	 0.0	 1	 -30.0	 30.0;
	7720	 961	 0.016169	 0.06784	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	6096	 3626	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8848	 31	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 31	 0.01124	 0.039822	 0.0	 1067	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 176	 0.001169	 0.00532	 0.0	 5800	 5800	 5800	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 176	 0.001138	 0.005418	 0.0	 5706	 5706	 5706	 0.0	 0.0	 1	 -30.0	 30.0;
	8558	 3482	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6643	 5506	 0.0	 0.00028	 0.0	 157564	 157564	 157564	 0.0	 0.0	 1	 -30.0	 30.0;
	2293	 8081	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4800	 5956	 0.00212	 0.008871	 0.0	 3464	 3464	 3464	 0.0	 0.0	 1	 -30.0	 30.0;
	2148	 4800	 0.002289	 0.008902	 0.0	 3437	 3437	 3437	 0.0	 0.0	 1	 -30.0	 30.0;
	5956	 7333	 0.00024	 0.000782	 0.0	 38616	 38616	 38616	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 7333	 0.000209	 0.000889	 0.0	 34589	 34589	 34589	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 8081	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	100	 8081	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 7333	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1745	 4545	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 5392	 0.001209	 0.005529	 0.0	 5582	 5582	 5582	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 4233	 0.001191	 0.00564	 0.0	 5480	 5480	 5480	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 5392	 0.014982	 0.0428	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	6310	 7832	 0.012849	 0.022929	 0.0	 1202	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	7832	 1771	 0.000431	 0.000929	 0.0	 30844	 30844	 30844	 0.0	 0.0	 1	 -30.0	 30.0;
	8694	 1771	 0.000849	 0.003831	 0.0	 8050	 8050	 8050	 0.0	 0.0	 1	 -30.0	 30.0;
	7566	 1771	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 3108	 0.000231	 0.000769	 0.0	 39340	 39340	 39340	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 4265	 0.0002	 0.000871	 0.0	 35346	 35346	 35346	 0.0	 0.0	 1	 -30.0	 30.0;
	7402	 3946	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 598	 0.004049	 0.01844	 0.0	 1674	 1674	 1674	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 3795	 0.003969	 0.018791	 0.0	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	4932	 4070	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 391	 0.002271	 0.004258	 0.0	 260.0	 6546	 6546	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 3667	 0.012449	 0.0248	 0.0	 1139	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	3667	 391	 0.002311	 0.004169	 0.0	 6627	 6627	 6627	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 2856	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7192	 391	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4751	 3593	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8700	 3593	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 3593	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2339	 8303	 0.002071	 0.009049	 0.0	 3403	 3403	 3403	 0.0	 0.0	 1	 -30.0	 30.0;
	2339	 232	 0.002031	 0.009222	 0.0	 3346	 3346	 3346	 0.0	 0.0	 1	 -30.0	 30.0;
	9142	 2339	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9050	 961	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	1476	 961	 0.015511	 0.06772	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	8090	 9041	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	8090	 5879	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 8090	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7470	 1678	 0.0052	 0.013898	 0.0	 2129	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	9104	 4174	 0.009071	 0.032151	 0.0	 946	 946	 946	 0.0	 0.0	 1	 -30.0	 30.0;
	6620	 9104	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	546	 8082	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 6957	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8082	 821	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8082	 3295	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8082	 6957	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 7535	 0.042889	 0.088942	 0.0	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	762	 6026	 0.000609	 0.001618	 0.0	 18272	 18272	 18272	 0.0	 0.0	 1	 -30.0	 30.0;
	443	 8827	 0.011289	 0.057409	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	4030	 865	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5166	 3774	 8.9e-05	 0.000449	 0.0	 69008	 69008	 69008	 0.0	 0.0	 1	 -30.0	 30.0;
	8231	 4778	 0.000169	 0.000662	 0.0	 46233	 46233	 46233	 0.0	 0.0	 1	 -30.0	 30.0;
	2312	 5053	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1310	 5796	 9.8e-05	 0.000511	 0.0	 60709	 60709	 60709	 0.0	 0.0	 1	 -30.0	 30.0;
	8631	 5796	 0.006338	 0.022662	 0.0	 1343	 1343	 1343	 0.0	 0.0	 1	 -30.0	 30.0;
	912	 7046	 0.000809	 0.001729	 0.0	 16548	 16548	 16548	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 1226	 0.00204	 0.007898	 0.0	 3873	 3873	 3873	 0.0	 0.0	 1	 -30.0	 30.0;
	5013	 8984	 0.00188	 0.00516	 0.0	 5752	 5752	 5752	 0.0	 0.0	 1	 -30.0	 30.0;
	8631	 7976	 0.000831	 0.003511	 0.0	 8755	 8755	 8755	 0.0	 0.0	 1	 -30.0	 30.0;
	1319	 169	 0.00064	 0.002871	 0.0	 10739	 10739	 10739	 0.0	 0.0	 1	 -30.0	 30.0;
	6976	 3681	 0.000182	 0.00064	 0.0	 47473	 47473	 47473	 0.0	 0.0	 1	 -30.0	 30.0;
	6976	 1701	 0.000191	 0.000631	 0.0	 47913	 47913	 47913	 0.0	 0.0	 1	 -30.0	 30.0;
	3532	 6976	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2113	 310	 0.00043	 0.00337	 0.0	 1152.0	 12987	 12987	 0.0	 0.0	 1	 -30.0	 30.0;
	2113	 7122	 0.00038	 0.00383	 0.0	 1481.0	 11463	 11463	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 5384	 0.000431	 0.00112	 0.0	 273.0	 26322	 26322	 0.0	 0.0	 1	 -30.0	 30.0;
	1831	 4981	 0.006458	 0.021302	 0.0	 1420	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	7912	 2779	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7400	 9070	 0.000249	 0.001138	 0.0	 27116	 27116	 27116	 0.0	 0.0	 1	 -30.0	 30.0;
	8548	 7400	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7400	 1729	 0.002449	 0.011169	 0.0	 2763	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	4262	 1729	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 4093	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8745	 8757	 0.000271	 0.001089	 0.0	 28148	 28148	 28148	 0.0	 0.0	 1	 -30.0	 30.0;
	6702	 3933	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	308	 1476	 0.0	 0.000222	 0.0	 198730	 198730	 198730	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 885	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3354	 1222	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6873	 4422	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	783	 1931	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5950	 3463	 0.006729	 0.031862	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	5950	 5560	 0.006591	 0.029498	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	7433	 8796	 0.000258	 0.000711	 0.0	 41763	 41763	 41763	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 6479	 0.020311	 0.045649	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	8231	 7387	 0.004102	 0.014089	 0.0	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	7387	 1724	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5984	 2975	 0.038777	 0.100653	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3274	 5984	 0.026711	 0.08357	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	7784	 2829	 0.062719	 0.144537	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 7784	 0.045033	 0.112364	 0.0	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 7656	 0.011659	 0.070599	 0.0	 381.0	 442	 442	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 825	 0.00968	 0.04149	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 825	 0.00862	 0.047021	 0.0	 381.0	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	1340	 2829	 0.077471	 0.185529	 0.0	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3726	 2829	 0.045157	 0.126248	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	3333	 2829	 0.01119	 0.043099	 0.0	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	3333	 2829	 0.01095	 0.043909	 0.0	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	2809	 1340	 0.03681	 0.090496	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	3170	 6229	 0.056174	 0.129223	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	3836	 3170	 0.029256	 0.116322	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 8567	 0.061347	 0.097917	 0.0	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	8567	 8902	 0.088719	 0.24762	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	8084	 269	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	8084	 5675	 0.004612	 0.01738	 0.0	 1757	 1757	 1757	 0.0	 0.0	 1	 -30.0	 30.0;
	8084	 5750	 0.008364	 0.02695	 0.0	 1120	 1120	 1120	 0.0	 0.0	 1	 -30.0	 30.0;
	8084	 5750	 0.014992	 0.043636	 0.0	 685	 685	 685	 0.0	 0.0	 1	 -30.0	 30.0;
	8321	 269	 0.003033	 0.012851	 0.0	 2393	 2393	 2393	 0.0	 0.0	 1	 -30.0	 30.0;
	8321	 269	 0.002967	 0.011901	 0.0	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	269	 1527	 0.015256	 0.042686	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 269	 0.004397	 0.025653	 0.0	 1214	 1214	 1214	 0.0	 0.0	 1	 -30.0	 30.0;
	3371	 3942	 0.0027	 0.012961	 0.0	 381.0	 2386	 2386	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 3942	 0.038169	 0.16812	 0.0	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 5501	 0.015479	 0.073409	 0.0	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	6598	 3466	 0.027868	 0.087843	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 6598	 0.013934	 0.040479	 0.0	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	1781	 3466	 0.019231	 0.076471	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	2296	 5786	 0.013421	 0.037256	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	5545	 2296	 0.022438	 0.046851	 0.0	 609	 609	 609	 0.0	 0.0	 1	 -30.0	 30.0;
	8280	 492	 0.014562	 0.045314	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	492	 2809	 0.000826	 0.002207	 0.0	 13405	 13405	 13405	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 5721	 0.040628	 0.113562	 0.0	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 1902	 0.008058	 0.024438	 0.0	 1228	 1228	 1228	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 5871	 0.022471	 0.041083	 0.0	 675	 675	 675	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 8579	 0.047322	 0.096669	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	8579	 3274	 0.01914	 0.07614	 0.0	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 6059	 0.007802	 0.01924	 0.0	 1522	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 6059	 0.005397	 0.015554	 0.0	 1919	 1919	 1919	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 7334	 0.024719	 0.040702	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 7334	 0.02419	 0.041471	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	4246	 2670	 0.039603	 0.109529	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3457	 4246	 0.013826	 0.039826	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 4246	 0.015174	 0.04981	 0.0	 607	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	8055	 4591	 0.003669	 0.009008	 0.0	 3248	 3248	 3248	 0.0	 0.0	 1	 -30.0	 30.0;
	4591	 2004	 0.03276	 0.106603	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	4591	 2004	 0.03019	 0.107612	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	3677	 4591	 0.019033	 0.051653	 0.0	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 4591	 0.037603	 0.124017	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	4591	 8965	 0.034868	 0.097471	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4591	 6435	 0.043099	 0.130603	 0.0	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 8055	 0.06105	 0.110339	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	2819	 6273	 0.041446	 0.108843	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	6273	 235	 0.063471	 0.123207	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	3092	 5504	 0.02343	 0.073603	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	3092	 1886	 0.022537	 0.091587	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	9232	 4612	 0.036744	 0.106934	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	9232	 826	 0.006207	 0.023959	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	3457	 3414	 0.003157	 0.011008	 0.0	 2759	 2759	 2759	 0.0	 0.0	 1	 -30.0	 30.0;
	3457	 3414	 0.003223	 0.010793	 0.0	 2805	 2805	 2805	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 3414	 0.005	 0.035653	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 3414	 0.004901	 0.036347	 0.0	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	8056	 1574	 0.007917	 0.029603	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	724	 1574	 0.004876	 0.01476	 0.0	 2033	 2033	 2033	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 4612	 0.007182	 0.023579	 0.0	 1282	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 4583	 0.007322	 0.023099	 0.0	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	5871	 8545	 0.010942	 0.040562	 0.0	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	8545	 911	 0.030603	 0.103702	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 879	 0.01176	 0.041421	 0.0	 734	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 1419	 0.011868	 0.03581	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	781	 5786	 0.01757	 0.064579	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	7111	 7331	 0.017099	 0.064281	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	796	 3836	 0.015207	 0.057397	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	1419	 796	 0.009198	 0.036512	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	796	 6856	 0.024281	 0.239446	 0.0	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	9153	 1313	 0.052471	 0.157347	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	411	 1313	 0.009314	 0.035909	 0.0	 852	 852	 852	 0.0	 0.0	 1	 -30.0	 30.0;
	8056	 1313	 0.039314	 0.122777	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	8321	 452	 0.001223	 0.003711	 0.0	 8085	 8085	 8085	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 7383	 0.00518	 0.023091	 0.0	 400.0	 1335	 1335	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 7383	 0.005281	 0.022591	 0.0	 381.0	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	2637	 8045	 0.018198	 0.037149	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 5922	 0.012893	 0.040033	 0.0	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	3838	 5922	 0.007132	 0.020331	 0.0	 1467	 1467	 1467	 0.0	 0.0	 1	 -30.0	 30.0;
	3208	 1429	 0.00479	 0.05497	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 2004	 0.047322	 0.139868	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	3471	 2004	 0.005471	 0.017471	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	3471	 2004	 0.013826	 0.040207	 0.0	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	2975	 2004	 0.010678	 0.03814	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	2975	 2004	 0.010603	 0.034793	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 2004	 0.014579	 0.043331	 0.0	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	2004	 8965	 0.021413	 0.079248	 0.0	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	2004	 7072	 0.031198	 0.098298	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 3371	 0.009651	 0.045031	 0.0	 381.0	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 5518	 0.050207	 0.124066	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	9202	 4539	 0.034314	 0.070521	 0.0	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	6641	 5545	 0.007463	 0.022612	 0.0	 1327	 1327	 1327	 0.0	 0.0	 1	 -30.0	 30.0;
	6641	 5545	 0.007603	 0.022132	 0.0	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 3719	 0.01081	 0.033603	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	9153	 5504	 0.011223	 0.036446	 0.0	 829	 829	 829	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 7916	 0.014182	 0.045669	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 5504	 0.014463	 0.044744	 0.0	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 3677	 0.02124	 0.069099	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	8849	 1628	 0.008041	 0.030504	 0.0	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	8849	 2326	 0.009107	 0.029893	 0.0	 1011	 1011	 1011	 0.0	 0.0	 1	 -30.0	 30.0;
	8650	 7665	 0.024802	 0.074537	 0.0	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 8650	 0.038711	 0.136876	 0.0	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	724	 1886	 0.069413	 0.194223	 0.0	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	9153	 3719	 0.01276	 0.035281	 0.0	 842	 842	 842	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 7497	 0.008744	 0.025802	 0.0	 1160	 1160	 1160	 0.0	 0.0	 1	 -30.0	 30.0;
	7497	 2326	 0.008909	 0.025248	 0.0	 1180	 1180	 1180	 0.0	 0.0	 1	 -30.0	 30.0;
	3333	 1628	 0.009289	 0.029281	 0.0	 1029	 1029	 1029	 0.0	 0.0	 1	 -30.0	 30.0;
	1671	 3726	 0.021421	 0.081298	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	1671	 7111	 0.044479	 0.139058	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	9044	 7656	 0.008479	 0.049461	 0.0	 400.0	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 7656	 0.00394	 0.02236	 0.0	 438.0	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 5654	 0.016174	 0.044463	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 5654	 0.014413	 0.05038	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	771	 738	 0.020198	 0.064678	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	771	 738	 0.020587	 0.063364	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	771	 738	 0.031711	 0.059223	 0.0	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	9202	 3598	 0.056678	 0.178372	 0.0	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 5085	 0.019496	 0.078083	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 7177	 0.045198	 0.111479	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	5378	 5545	 0.015041	 0.057983	 0.0	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 5378	 0.03519	 0.105653	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 6229	 0.044	 0.099339	 0.0	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 8321	 0.013636	 0.039512	 0.0	 756	 756	 756	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 8321	 0.012149	 0.044777	 0.0	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5545	 9196	 0.035281	 0.122702	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	3926	 9196	 0.031967	 0.090248	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 9196	 0.023983	 0.066421	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	9202	 7385	 0.032901	 0.126777	 0.0	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	7385	 8781	 0.015372	 0.059083	 0.0	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 7111	 0.012636	 0.024496	 0.0	 1147	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 7111	 0.012893	 0.024	 0.0	 1160	 1160	 1160	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 7452	 0.001917	 0.006091	 0.0	 4947	 4947	 4947	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 2326	 0.018149	 0.049413	 0.0	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	2178	 861	 0.01276	 0.037083	 0.0	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	8902	 2178	 0.069636	 0.146636	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	2649	 8974	 0.00219	 0.02213	 0.0	 1152.0	 1421	 1421	 0.0	 0.0	 1	 -30.0	 30.0;
	2480	 825	 0.00194	 0.0087	 0.0	 438.0	 3544	 3544	 0.0	 0.0	 1	 -30.0	 30.0;
	2480	 825	 0.001979	 0.00851	 0.0	 419.0	 3616	 3616	 0.0	 0.0	 1	 -30.0	 30.0;
	3836	 2670	 0.028893	 0.108496	 0.0	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	879	 3836	 0.021008	 0.05814	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 3896	 0.018661	 0.056488	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	8800	 1041	 0.01381	 0.03776	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	8800	 3926	 0.012298	 0.042793	 0.0	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	8450	 5871	 0.009281	 0.03038	 0.0	 995	 995	 995	 0.0	 0.0	 1	 -30.0	 30.0;
	7665	 2819	 0.011438	 0.035711	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	8811	 7665	 0.05095	 0.124661	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 9202	 0.058207	 0.110223	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	411	 724	 0.061876	 0.195174	 0.0	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	8140	 3311	 0.013438	 0.032033	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	4583	 8140	 0.03619	 0.085066	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	3896	 2673	 0.05324	 0.154826	 0.0	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	3838	 3311	 0.004579	 0.026017	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	3198	 9073	 0.00795	 0.03657	 0.0	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	2819	 1266	 0.055967	 0.167983	 0.0	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	8811	 2819	 0.070942	 0.168066	 0.0	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	2502	 2649	 0.00389	 0.04149	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	7081	 2502	 0.003	 0.02776	 0.0	 1119.0	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 5229	 0.002159	 0.01261	 0.0	 381.0	 2470	 2470	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 5229	 0.002021	 0.016849	 0.0	 400.0	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	7008	 5229	 0.007151	 0.046719	 0.0	 610.0	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 6924	 0.000539	 0.00368	 0.0	 8493	 8493	 8493	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 6924	 0.000539	 0.003591	 0.0	 8699	 8699	 8699	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 8450	 0.007446	 0.010579	 0.0	 2442	 2442	 2442	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 2543	 0.011992	 0.03276	 0.0	 906	 906	 906	 0.0	 0.0	 1	 -30.0	 30.0;
	771	 2637	 0.034207	 0.085124	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 771	 0.001248	 0.004471	 0.0	 6805	 6805	 6805	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 771	 0.001223	 0.004562	 0.0	 6688	 6688	 6688	 0.0	 0.0	 1	 -30.0	 30.0;
	5501	 3198	 0.006961	 0.04039	 0.0	 381.0	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	5501	 3198	 0.004521	 0.02305	 0.0	 381.0	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	5501	 4417	 0.00395	 0.022789	 0.0	 457.0	 1366	 1366	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 4373	 0.031934	 0.123661	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 3457	 0.019802	 0.070901	 0.0	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 3457	 0.022438	 0.069479	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 1366	 0.014727	 0.04305	 0.0	 695	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 131	 0.01343	 0.06824	 0.0	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 131	 0.022	 0.060388	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 131	 0.019603	 0.068438	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	1266	 1218	 0.048769	 0.114711	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	3471	 4382	 0.046901	 0.148033	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	6911	 4382	 0.055744	 0.139066	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	781	 5545	 0.010917	 0.032901	 0.0	 912	 912	 912	 0.0	 0.0	 1	 -30.0	 30.0;
	7334	 5507	 0.026322	 0.044388	 0.0	 613	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 8280	 0.047438	 0.143727	 0.0	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	7603	 8280	 0.026876	 0.09776	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	8781	 7603	 0.01705	 0.060802	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	911	 8781	 0.028727	 0.075289	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 5585	 0.002388	 0.015942	 0.0	 1960	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 2809	 0.088471	 0.217198	 0.0	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 6658	 0.01714	 0.056248	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	6447	 3471	 0.004479	 0.014008	 0.0	 2148	 2148	 2148	 0.0	 0.0	 1	 -30.0	 30.0;
	2975	 6447	 0.009851	 0.032314	 0.0	 936	 936	 936	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 6447	 0.001636	 0.005587	 0.0	 5426	 5426	 5426	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 3274	 0.021603	 0.084	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	1781	 4698	 0.021727	 0.065893	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	1781	 4583	 0.025686	 0.080256	 0.0	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	4583	 1781	 0.026182	 0.078587	 0.0	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	7008	 5161	 0.00536	 0.040919	 0.0	 629.0	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	2543	 3838	 0.007388	 0.026628	 0.0	 1144	 1144	 1144	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 4408	 0.005826	 0.017488	 0.0	 1714	 1714	 1714	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 4408	 0.005826	 0.016653	 0.0	 1791	 1791	 1791	 0.0	 0.0	 1	 -30.0	 30.0;
	3926	 4408	 0.026826	 0.082273	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	8920	 1527	 0.003256	 0.010587	 0.0	 2852	 2852	 2852	 0.0	 0.0	 1	 -30.0	 30.0;
	8920	 965	 0.003331	 0.010372	 0.0	 2900	 2900	 2900	 0.0	 0.0	 1	 -30.0	 30.0;
	8239	 8056	 0.025174	 0.077661	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 4698	 0.030248	 0.085413	 0.0	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 4698	 0.029471	 0.109198	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	1218	 187	 0.058942	 0.115529	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	1366	 4373	 0.028413	 0.083	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	8811	 4373	 0.005826	 0.016	 0.0	 1856	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	8555	 4373	 0.005512	 0.016612	 0.0	 1805	 1805	 1805	 0.0	 0.0	 1	 -30.0	 30.0;
	5700	 1527	 0.014256	 0.033909	 0.0	 859	 859	 859	 0.0	 0.0	 1	 -30.0	 30.0;
	724	 1527	 0.052826	 0.200702	 0.0	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 1527	 0.01976	 0.061058	 0.0	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 1527	 0.014008	 0.053207	 0.0	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 1527	 0.013711	 0.054207	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 3457	 0.009132	 0.024843	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 3457	 0.010711	 0.040256	 0.0	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	6530	 3457	 0.004562	 0.012421	 0.0	 2388	 2388	 2388	 0.0	 0.0	 1	 -30.0	 30.0;
	8003	 2699	 0.025273	 0.079777	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	965	 5700	 0.009149	 0.028992	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	3333	 2326	 0.027149	 0.096802	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	826	 4583	 0.063033	 0.157099	 0.0	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	826	 8003	 0.009702	 0.035397	 0.0	 861	 861	 861	 0.0	 0.0	 1	 -30.0	 30.0;
	826	 8003	 0.009504	 0.036091	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	235	 6911	 0.029893	 0.105364	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 5675	 0.005397	 0.020298	 0.0	 1504	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	7452	 2875	 0.001124	 0.002942	 0.0	 10030	 10030	 10030	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 2875	 0.001207	 0.003174	 0.0	 9303	 9303	 9303	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 2875	 0.00124	 0.003099	 0.0	 9464	 9464	 9464	 0.0	 0.0	 1	 -30.0	 30.0;
	6530	 5750	 0.004066	 0.014083	 0.0	 2155	 2155	 2155	 0.0	 0.0	 1	 -30.0	 30.0;
	2389	 7008	 0.005099	 0.025479	 0.0	 381.0	 1216	 1216	 0.0	 0.0	 1	 -30.0	 30.0;
	2389	 7008	 0.0052	 0.024961	 0.0	 1239	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	8555	 8811	 0.003868	 0.013901	 0.0	 2190	 2190	 2190	 0.0	 0.0	 1	 -30.0	 30.0;
	7081	 1429	 0.00126	 0.01433	 0.0	 1251.0	 2196	 2196	 0.0	 0.0	 1	 -30.0	 30.0;
	8239	 1928	 0.011752	 0.044314	 0.0	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	8965	 7072	 0.021719	 0.046248	 0.0	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	8965	 6435	 0.05324	 0.100281	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	8416	 6743	 0.00109	 0.01155	 0.0	 1086.0	 4155	 4155	 0.0	 0.0	 1	 -30.0	 30.0;
	8416	 6743	 0.0011	 0.01158	 0.0	 1020.0	 4144	 4144	 0.0	 0.0	 1	 -30.0	 30.0;
	8416	 8715	 0.00096	 0.01293	 0.0	 1218.0	 3718	 3718	 0.0	 0.0	 1	 -30.0	 30.0;
	8416	 8715	 0.00098	 0.01264	 0.0	 1185.0	 3802	 3802	 0.0	 0.0	 1	 -30.0	 30.0;
	8416	 569	 0.00101	 0.01059	 0.0	 1382.0	 4531	 4531	 0.0	 0.0	 1	 -30.0	 30.0;
	8052	 6204	 0.00112	 0.010969	 0.0	 533.0	 2865	 2865	 0.0	 0.0	 1	 -30.0	 30.0;
	290	 6204	 0.00126	 0.01075	 0.0	 533.0	 2919	 2919	 0.0	 0.0	 1	 -30.0	 30.0;
	3684	 8580	 0.00197	 0.0207	 0.0	 954.0	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	3684	 569	 0.00303	 0.0273	 0.0	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	340	 8065	 0.00194	 0.02339	 0.0	 889.0	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	8715	 340	 0.00057	 0.00492	 0.0	 987.0	 6378	 6378	 0.0	 0.0	 1	 -30.0	 30.0;
	6685	 2858	 0.01105	 0.056599	 0.0	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 2858	 0.00482	 0.046521	 0.0	 381.0	 676	 676	 0.0	 0.0	 1	 -30.0	 30.0;
	6743	 8526	 0.00194	 0.01645	 0.0	 954.0	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	8526	 5850	 0.00134	 0.01459	 0.0	 1020.0	 2156	 2156	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 8531	 0.000401	 0.00318	 0.0	 610.0	 9856	 9856	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 7065	 0.000349	 0.00293	 0.0	 572.0	 10705	 10705	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 1402	 0.000401	 0.00324	 0.0	 610.0	 9676	 9676	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 2858	 0.01214	 0.058401	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 2858	 0.012979	 0.053281	 0.0	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 3245	 0.007919	 0.053729	 0.0	 533.0	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 6799	 0.014771	 0.06813	 0.0	 438.0	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 6799	 0.013789	 0.067711	 0.0	 438.0	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	1648	 6204	 0.005349	 0.044469	 0.0	 533.0	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	9004	 6204	 0.005229	 0.04118	 0.0	 533.0	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 4912	 0.0008	 0.00676	 0.0	 553.0	 4641	 4641	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 2144	 0.000781	 0.00626	 0.0	 5008	 5008	 5008	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 7867	 0.00363	 0.017409	 0.0	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 7867	 0.0037	 0.01705	 0.0	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 2395	 0.00449	 0.046469	 0.0	 495.0	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 3604	 0.00052	 0.00727	 0.0	 757.0	 4334	 4334	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 5850	 0.00047	 0.0062	 0.0	 757.0	 5081	 5081	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 5850	 0.00046	 0.00631	 0.0	 757.0	 4993	 4993	 0.0	 0.0	 1	 -30.0	 30.0;
	4998	 6799	 0.003531	 0.013669	 0.0	 495.0	 2238	 2238	 0.0	 0.0	 1	 -30.0	 30.0;
	7458	 8065	 0.00032	 0.00322	 0.0	 1119.0	 9762	 9762	 0.0	 0.0	 1	 -30.0	 30.0;
	7458	 4817	 0.00156	 0.01603	 0.0	 987.0	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	7458	 2368	 0.0022	 0.02389	 0.0	 1317	 1317	 1317	 0.0	 0.0	 1	 -30.0	 30.0;
	7679	 2395	 0.00337	 0.032669	 0.0	 400.0	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	9183	 4817	 0.00199	 0.0195	 0.0	 1152.0	 1612	 1612	 0.0	 0.0	 1	 -30.0	 30.0;
	9183	 2368	 0.00144	 0.01354	 0.0	 1020.0	 2320	 2320	 0.0	 0.0	 1	 -30.0	 30.0;
	9183	 2368	 0.00147	 0.01325	 0.0	 1119.0	 2370	 2370	 0.0	 0.0	 1	 -30.0	 30.0;
	9183	 5062	 0.00211	 0.02433	 0.0	 1152.0	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	4150	 2858	 0.013901	 0.088849	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	4817	 8715	 0.00149	 0.01564	 0.0	 1053.0	 2011	 2011	 0.0	 0.0	 1	 -30.0	 30.0;
	4817	 7979	 0.00294	 0.02278	 0.0	 1349.0	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	8715	 7979	 0.00133	 0.01873	 0.0	 1152.0	 1683	 1683	 0.0	 0.0	 1	 -30.0	 30.0;
	7867	 6799	 0.00581	 0.034229	 0.0	 572.0	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	7979	 6790	 0.00145	 0.02024	 0.0	 1557	 1557	 1557	 0.0	 0.0	 1	 -30.0	 30.0;
	7979	 6790	 0.00142	 0.01874	 0.0	 1681	 1681	 1681	 0.0	 0.0	 1	 -30.0	 30.0;
	7979	 8580	 0.00245	 0.02367	 0.0	 1152.0	 1328	 1328	 0.0	 0.0	 1	 -30.0	 30.0;
	7979	 5062	 0.00178	 0.02175	 0.0	 1119.0	 1448	 1448	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 7152	 0.000701	 0.009299	 0.0	 3388	 3388	 3388	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 7152	 0.001042	 0.007833	 0.0	 3998	 3998	 3998	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 7152	 0.001403	 0.00534	 0.0	 5722	 5722	 5722	 0.0	 0.0	 1	 -30.0	 30.0;
	5850	 3130	 0.00022	 0.00258	 0.0	 823.0	 12199	 12199	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 3245	 0.02024	 0.099349	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 6103	 0.00044	 0.003081	 0.0	 553.0	 10150	 10150	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 2310	 0.00043	 0.00314	 0.0	 553.0	 9967	 9967	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 8726	 0.00461	 0.027531	 0.0	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	8943	 3245	 0.01212	 0.09901	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	364	 6528	 0.000289	 0.00261	 0.0	 381.0	 12029	 12029	 0.0	 0.0	 1	 -30.0	 30.0;
	4572	 364	 0.00043	 0.002831	 0.0	 438.0	 11032	 11032	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 364	 0.000289	 0.000599	 0.0	 419.0	 47495	 47495	 0.0	 0.0	 1	 -30.0	 30.0;
	7489	 1140	 0.000289	 0.00224	 0.0	 533.0	 13986	 13986	 0.0	 0.0	 1	 -30.0	 30.0;
	4133	 7489	 0.000219	 0.001591	 0.0	 400.0	 19669	 19669	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 6725	 0.00045	 0.00786	 0.0	 1810.0	 4013	 4013	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 6725	 0.00044	 0.00728	 0.0	 1645.0	 4332	 4332	 0.0	 0.0	 1	 -30.0	 30.0;
	6725	 8252	 0.00049	 0.00466	 0.0	 1514.0	 6742	 6742	 0.0	 0.0	 1	 -30.0	 30.0;
	6725	 8117	 0.00125	 0.01973	 0.0	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	6810	 6809	 0.001461	 0.00714	 0.0	 419.0	 4335	 4335	 0.0	 0.0	 1	 -30.0	 30.0;
	9113	 6810	 0.00037	 0.00094	 0.0	 419.0	 31269	 31269	 0.0	 0.0	 1	 -30.0	 30.0;
	6810	 1804	 0.001039	 0.00737	 0.0	 4244	 4244	 4244	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 6327	 8.1e-05	 0.00061	 0.0	 381.0	 51332	 51332	 0.0	 0.0	 1	 -30.0	 30.0;
	7311	 8069	 0.00053	 0.00852	 0.0	 1613.0	 3701	 3701	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 8069	 0.00053	 0.00704	 0.0	 1744.0	 4475	 4475	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 3360	 0.0001	 0.00128	 0.0	 823.0	 24603	 24603	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 9075	 0.0015	 0.00705	 0.0	 419.0	 4383	 4383	 0.0	 0.0	 1	 -30.0	 30.0;
	9075	 7066	 0.009771	 0.05363	 0.0	 400.0	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 9075	 0.00088	 0.007771	 0.0	 438.0	 4039	 4039	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 8443	 0.00539	 0.032979	 0.0	 400.0	 946	 946	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 4148	 0.00482	 0.03086	 0.0	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	2139	 4148	 0.010539	 0.065479	 0.0	 457.0	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 7893	 0.01074	 0.06405	 0.0	 476.0	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 4148	 0.0063	 0.048909	 0.0	 533.0	 641	 641	 0.0	 0.0	 1	 -30.0	 30.0;
	1819	 899	 0.0002	 0.00022	 0.0	 1415.0	 106240	 106240	 0.0	 0.0	 1	 -30.0	 30.0;
	4979	 899	 0.0002	 0.00022	 0.0	 1448.0	 106240	 106240	 0.0	 0.0	 1	 -30.0	 30.0;
	6822	 899	 0.00019	 0.00023	 0.0	 1481.0	 105881	 105881	 0.0	 0.0	 1	 -30.0	 30.0;
	924	 1279	 0.000289	 0.0017	 0.0	 18318	 18318	 18318	 0.0	 0.0	 1	 -30.0	 30.0;
	899	 1193	 0.00145	 0.01937	 0.0	 1627	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	3123	 899	 0.00048	 0.00814	 0.0	 1777.0	 3874	 3874	 0.0	 0.0	 1	 -30.0	 30.0;
	3123	 899	 0.00057	 0.00758	 0.0	 1613.0	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	8383	 3807	 0.0002	 0.00187	 0.0	 16796	 16796	 16796	 0.0	 0.0	 1	 -30.0	 30.0;
	8383	 3807	 0.000169	 0.00193	 0.0	 16305	 16305	 16305	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 1977	 0.00216	 0.03591	 0.0	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 3351	 0.00092	 0.01287	 0.0	 1810.0	 2449	 2449	 0.0	 0.0	 1	 -30.0	 30.0;
	1261	 3605	 0.02412	 0.10443	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	1279	 8443	 0.00063	 0.00401	 0.0	 7782	 7782	 7782	 0.0	 0.0	 1	 -30.0	 30.0;
	1279	 3571	 0.00038	 0.002409	 0.0	 12953	 12953	 12953	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 4094	 0.010091	 0.05524	 0.0	 514.0	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 4873	 0.00668	 0.04457	 0.0	 438.0	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 1882	 0.00057	 0.004961	 0.0	 419.0	 6326	 6326	 0.0	 0.0	 1	 -30.0	 30.0;
	1882	 5483	 0.00025	 0.002159	 0.0	 14534	 14534	 14534	 0.0	 0.0	 1	 -30.0	 30.0;
	526	 4516	 0.00443	 0.01807	 0.0	 438.0	 1698	 1698	 0.0	 0.0	 1	 -30.0	 30.0;
	526	 5839	 0.00037	 0.001659	 0.0	 495.0	 18584	 18584	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 834	 0.00037	 0.003599	 0.0	 476.0	 8731	 8731	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 7494	 0.000659	 0.00836	 0.0	 438.0	 3767	 3767	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 7494	 0.00151	 0.012289	 0.0	 381.0	 2552	 2552	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 2388	 0.000539	 0.003711	 0.0	 381.0	 8424	 8424	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 1328	 0.00036	 0.00606	 0.0	 1086.0	 5204	 5204	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 1328	 0.00035	 0.00618	 0.0	 921.0	 5104	 5104	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 660	 0.00101	 0.01675	 0.0	 1883	 1883	 1883	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 5355	 4e-05	 0.00071	 0.0	 1613.0	 44419	 44419	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 5355	 4e-05	 0.00081	 0.0	 1777.0	 38950	 38950	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 984	 0.00013	 0.00152	 0.0	 20706	 20706	 20706	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 984	 0.00014	 0.00149	 0.0	 987.0	 21107	 21107	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 4178	 0.00013	 0.00164	 0.0	 757.0	 19201	 19201	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 4178	 0.00013	 0.00168	 0.0	 889.0	 18746	 18746	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 4448	 0.000669	 0.00511	 0.0	 476.0	 6130	 6130	 0.0	 0.0	 1	 -30.0	 30.0;
	8962	 3465	 3.9e-05	 0.000341	 0.0	 92032	 92032	 92032	 0.0	 0.0	 1	 -30.0	 30.0;
	5885	 5677	 0.004219	 0.02145	 0.0	 1445	 1445	 1445	 0.0	 0.0	 1	 -30.0	 30.0;
	5885	 4035	 0.000229	 0.002849	 0.0	 629.0	 11052	 11052	 0.0	 0.0	 1	 -30.0	 30.0;
	1261	 54	 0.0137	 0.10436	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	2675	 1261	 0.001521	 0.01449	 0.0	 514.0	 2169	 2169	 0.0	 0.0	 1	 -30.0	 30.0;
	765	 437	 8.1e-05	 0.00057	 0.0	 533.0	 54866	 54866	 0.0	 0.0	 1	 -30.0	 30.0;
	6809	 437	 0.001461	 0.00813	 0.0	 476.0	 3825	 3825	 0.0	 0.0	 1	 -30.0	 30.0;
	1423	 437	 0.00049	 0.00381	 0.0	 457.0	 8223	 8223	 0.0	 0.0	 1	 -30.0	 30.0;
	7540	 2578	 0.000401	 0.00287	 0.0	 533.0	 10901	 10901	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 4820	 8.3e-05	 0.000347	 0.0	 88533	 88533	 88533	 0.0	 0.0	 1	 -30.0	 30.0;
	6560	 7044	 0.00023	 0.00285	 0.0	 1316.0	 11048	 11048	 0.0	 0.0	 1	 -30.0	 30.0;
	7044	 3196	 0.00016	 0.00218	 0.0	 14451	 14451	 14451	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 7044	 0.00057	 0.00736	 0.0	 1613.0	 4279	 4279	 0.0	 0.0	 1	 -30.0	 30.0;
	402	 7855	 0.000591	 0.005789	 0.0	 495.0	 5429	 5429	 0.0	 0.0	 1	 -30.0	 30.0;
	402	 3337	 0.002729	 0.011461	 0.0	 495.0	 2682	 2682	 0.0	 0.0	 1	 -30.0	 30.0;
	402	 6107	 0.00051	 0.00205	 0.0	 629.0	 14953	 14953	 0.0	 0.0	 1	 -30.0	 30.0;
	8273	 6750	 0.00031	 0.00374	 0.0	 1876.0	 8417	 8417	 0.0	 0.0	 1	 -30.0	 30.0;
	2710	 8273	 0.00032	 0.00518	 0.0	 6087	 6087	 6087	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 7306	 0.00136	 0.01038	 0.0	 476.0	 3018	 3018	 0.0	 0.0	 1	 -30.0	 30.0;
	8532	 4037	 0.00151	 0.02083	 0.0	 1513	 1513	 1513	 0.0	 0.0	 1	 -30.0	 30.0;
	7664	 4037	 0.00015	 0.00232	 0.0	 1678.0	 13587	 13587	 0.0	 0.0	 1	 -30.0	 30.0;
	2204	 8120	 1e-05	 0.00025	 0.0	 987.0	 126249	 126249	 0.0	 0.0	 1	 -30.0	 30.0;
	9006	 8120	 1e-05	 0.00023	 0.0	 987.0	 137207	 137207	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 8120	 0.00047	 0.00683	 0.0	 1185.0	 4614	 4614	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 8120	 0.00067	 0.00858	 0.0	 1283.0	 3671	 3671	 0.0	 0.0	 1	 -30.0	 30.0;
	2540	 1034	 0.003669	 0.025331	 0.0	 514.0	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	368	 2540	 0.00525	 0.02994	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 6863	 0.00595	 0.03625	 0.0	 495.0	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 7841	 0.004969	 0.03411	 0.0	 476.0	 917	 917	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 1859	 0.005669	 0.04293	 0.0	 553.0	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 1859	 0.00555	 0.043771	 0.0	 514.0	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	1859	 3832	 0.002831	 0.022401	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	1859	 3832	 0.00325	 0.01938	 0.0	 400.0	 1608	 1608	 0.0	 0.0	 1	 -30.0	 30.0;
	8049	 162	 0.00068	 0.00082	 0.0	 1020.0	 29652	 29652	 0.0	 0.0	 1	 -30.0	 30.0;
	8049	 2039	 0.00054	 0.00868	 0.0	 1349.0	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 6793	 0.00061	 0.002909	 0.0	 10628	 10628	 10628	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 1469	 0.002271	 0.01014	 0.0	 3040	 3040	 3040	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 1264	 0.00083	 0.00986	 0.0	 3193	 3193	 3193	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 8139	 0.00031	 0.00511	 0.0	 1613.0	 6171	 6171	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 8139	 0.0003	 0.00521	 0.0	 1645.0	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 1264	 0.00081	 0.01288	 0.0	 2448	 2448	 2448	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 9009	 0.00039	 0.00645	 0.0	 4889	 4889	 4889	 0.0	 0.0	 1	 -30.0	 30.0;
	3769	 2320	 0.00243	 0.012211	 0.0	 2538	 2538	 2538	 0.0	 0.0	 1	 -30.0	 30.0;
	3563	 5302	 0.00018	 0.00226	 0.0	 13933	 13933	 13933	 0.0	 0.0	 1	 -30.0	 30.0;
	2316	 5302	 0.0002	 0.00347	 0.0	 1744.0	 9088	 9088	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 5302	 0.00018	 0.0029	 0.0	 10872	 10872	 10872	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 6750	 0.00045	 0.00494	 0.0	 1382.0	 6368	 6368	 0.0	 0.0	 1	 -30.0	 30.0;
	6750	 2684	 0.00042	 0.00497	 0.0	 1613.0	 6334	 6334	 0.0	 0.0	 1	 -30.0	 30.0;
	3229	 8532	 0.00019	 0.00234	 0.0	 1251.0	 13455	 13455	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 8532	 8e-05	 0.00105	 0.0	 1678.0	 29997	 29997	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 8532	 8e-05	 0.00107	 0.0	 1613.0	 29439	 29439	 0.0	 0.0	 1	 -30.0	 30.0;
	8532	 7922	 8e-05	 0.001	 0.0	 31487	 31487	 31487	 0.0	 0.0	 1	 -30.0	 30.0;
	8532	 3972	 0.00063	 0.01015	 0.0	 1843.0	 3107	 3107	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 6671	 0.00064	 0.005651	 0.0	 5555	 5555	 5555	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 6671	 0.000581	 0.006531	 0.0	 4818	 4818	 4818	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 8723	 0.007099	 0.04432	 0.0	 400.0	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 1804	 0.00144	 0.01157	 0.0	 438.0	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 7804	 0.00114	 0.00695	 0.0	 419.0	 4486	 4486	 0.0	 0.0	 1	 -30.0	 30.0;
	3563	 1684	 0.00044	 0.0053	 0.0	 1613.0	 5940	 5940	 0.0	 0.0	 1	 -30.0	 30.0;
	7071	 6622	 0.00162	 0.009039	 0.0	 400.0	 3440	 3440	 0.0	 0.0	 1	 -30.0	 30.0;
	7071	 6622	 0.00187	 0.0072	 0.0	 400.0	 4247	 4247	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 6622	 0.00101	 0.00564	 0.0	 5513	 5513	 5513	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 6622	 0.0007	 0.00445	 0.0	 7013	 7013	 7013	 0.0	 0.0	 1	 -30.0	 30.0;
	2909	 6622	 0.001081	 0.00619	 0.0	 553.0	 5027	 5027	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 8304	 0.00022	 0.00228	 0.0	 1448.0	 13791	 13791	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 6207	 0.00023	 0.00223	 0.0	 1415.0	 14090	 14090	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 7940	 0.0002	 0.00262	 0.0	 1448.0	 12022	 12022	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 1919	 0.00021	 0.00261	 0.0	 1283.0	 12064	 12064	 0.0	 0.0	 1	 -30.0	 30.0;
	49	 6992	 0.00663	 0.04181	 0.0	 457.0	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 2456	 0.00059	 0.00921	 0.0	 1678.0	 3423	 3423	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 4159	 0.0014	 0.02227	 0.0	 1416	 1416	 1416	 0.0	 0.0	 1	 -30.0	 30.0;
	3871	 2821	 0.000401	 0.002469	 0.0	 438.0	 12629	 12629	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 2821	 0.00212	 0.01218	 0.0	 381.0	 2555	 2555	 0.0	 0.0	 1	 -30.0	 30.0;
	2821	 2025	 0.004169	 0.02439	 0.0	 438.0	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	8443	 9068	 0.02336	 0.122419	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	8443	 684	 0.002729	 0.0137	 0.0	 2262	 2262	 2262	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 8443	 0.000919	 0.003831	 0.0	 8018	 8018	 8018	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 8443	 0.00082	 0.004349	 0.0	 7138	 7138	 7138	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 8443	 0.01325	 0.055159	 0.0	 438.0	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 8443	 0.0108	 0.06074	 0.0	 438.0	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	8443	 4813	 0.001099	 0.00631	 0.0	 419.0	 4932	 4932	 0.0	 0.0	 1	 -30.0	 30.0;
	7787	 6327	 0.00495	 0.029151	 0.0	 419.0	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	6327	 8933	 0.003909	 0.0227	 0.0	 400.0	 1372	 1372	 0.0	 0.0	 1	 -30.0	 30.0;
	2139	 3556	 0.00061	 0.00424	 0.0	 7374	 7374	 7374	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 1140	 0.00068	 0.003919	 0.0	 514.0	 7942	 7942	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 1140	 0.00368	 0.019901	 0.0	 1561	 1561	 1561	 0.0	 0.0	 1	 -30.0	 30.0;
	7420	 2316	 0.00025	 0.00388	 0.0	 1448.0	 8125	 8125	 0.0	 0.0	 1	 -30.0	 30.0;
	7420	 376	 0.00038	 0.00623	 0.0	 1218.0	 5061	 5061	 0.0	 0.0	 1	 -30.0	 30.0;
	6809	 4770	 0.000909	 0.006031	 0.0	 438.0	 5180	 5180	 0.0	 0.0	 1	 -30.0	 30.0;
	4770	 1804	 0.001211	 0.0062	 0.0	 514.0	 5001	 5001	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 405	 0.00022	 0.00322	 0.0	 1119.0	 9787	 9787	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 4512	 0.00018	 0.00307	 0.0	 1777.0	 10272	 10272	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 4928	 0.00068	 0.00873	 0.0	 1119.0	 3608	 3608	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 8161	 0.00124	 0.02016	 0.0	 1316.0	 1564	 1564	 0.0	 0.0	 1	 -30.0	 30.0;
	9139	 7311	 0.00025	 0.00332	 0.0	 1547.0	 9488	 9488	 0.0	 0.0	 1	 -30.0	 30.0;
	9139	 7311	 0.00025	 0.00335	 0.0	 1744.0	 9403	 9403	 0.0	 0.0	 1	 -30.0	 30.0;
	9139	 7311	 0.00025	 0.00325	 0.0	 1711.0	 9691	 9691	 0.0	 0.0	 1	 -30.0	 30.0;
	3068	 9139	 0.00076	 0.01075	 0.0	 1777.0	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 9139	 3e-05	 0.00044	 0.0	 757.0	 71624	 71624	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 7538	 0.001651	 0.010849	 0.0	 533.0	 2879	 2879	 0.0	 0.0	 1	 -30.0	 30.0;
	8320	 3465	 0.00288	 0.018469	 0.0	 476.0	 1690	 1690	 0.0	 0.0	 1	 -30.0	 30.0;
	6895	 1512	 0.00072	 0.00923	 0.0	 1349.0	 3412	 3412	 0.0	 0.0	 1	 -30.0	 30.0;
	6895	 6189	 0.00069	 0.00855	 0.0	 1744.0	 3683	 3683	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 4576	 0.00124	 0.01667	 0.0	 1890	 1890	 1890	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 830	 0.00034	 0.00571	 0.0	 1810.0	 5523	 5523	 0.0	 0.0	 1	 -30.0	 30.0;
	6939	 3180	 0.0004	 0.00638	 0.0	 1909.0	 4942	 4942	 0.0	 0.0	 1	 -30.0	 30.0;
	6939	 3180	 0.00039	 0.0065	 0.0	 1876.0	 4851	 4851	 0.0	 0.0	 1	 -30.0	 30.0;
	7891	 3180	 0.00027	 0.00451	 0.0	 1678.0	 6992	 6992	 0.0	 0.0	 1	 -30.0	 30.0;
	8215	 3892	 0.012409	 0.074961	 0.0	 381.0	 416	 416	 0.0	 0.0	 1	 -30.0	 30.0;
	8215	 8600	 0.002419	 0.01761	 0.0	 438.0	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	8215	 1423	 0.006901	 0.053409	 0.0	 457.0	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 13	 0.000599	 0.00356	 0.0	 495.0	 8750	 8750	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 4516	 0.011841	 0.049341	 0.0	 419.0	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	4572	 904	 0.000521	 0.004831	 0.0	 533.0	 6501	 6501	 0.0	 0.0	 1	 -30.0	 30.0;
	88	 904	 0.00055	 0.00143	 0.0	 381.0	 20617	 20617	 0.0	 0.0	 1	 -30.0	 30.0;
	7718	 904	 0.0005	 0.00364	 0.0	 8598	 8598	 8598	 0.0	 0.0	 1	 -30.0	 30.0;
	7718	 904	 0.00056	 0.003469	 0.0	 8990	 8990	 8990	 0.0	 0.0	 1	 -30.0	 30.0;
	904	 5181	 0.00082	 0.00257	 0.0	 457.0	 11710	 11710	 0.0	 0.0	 1	 -30.0	 30.0;
	4526	 5451	 0.00249	 0.01536	 0.0	 457.0	 2030	 2030	 0.0	 0.0	 1	 -30.0	 30.0;
	4526	 2484	 0.00113	 0.00651	 0.0	 438.0	 4781	 4781	 0.0	 0.0	 1	 -30.0	 30.0;
	8892	 5078	 0.00643	 0.045031	 0.0	 514.0	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	8509	 8892	 0.003581	 0.02706	 0.0	 514.0	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	1814	 3351	 0.00046	 0.00774	 0.0	 1810.0	 4074	 4074	 0.0	 0.0	 1	 -30.0	 30.0;
	1814	 6464	 0.00031	 0.00483	 0.0	 1086.0	 6527	 6527	 0.0	 0.0	 1	 -30.0	 30.0;
	5945	 3767	 0.001099	 0.00345	 0.0	 457.0	 8724	 8724	 0.0	 0.0	 1	 -30.0	 30.0;
	1257	 985	 0.00913	 0.053211	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	985	 8524	 0.021151	 0.095401	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 4576	 0.00034	 0.0055	 0.0	 1810.0	 5733	 5733	 0.0	 0.0	 1	 -30.0	 30.0;
	2756	 3546	 0.00064	 0.01945	 0.0	 1624	 1624	 1624	 0.0	 0.0	 1	 -30.0	 30.0;
	2756	 8663	 0.0004	 0.01026	 0.0	 1448.0	 3077	 3077	 0.0	 0.0	 1	 -30.0	 30.0;
	7268	 2756	 0.00071	 0.01087	 0.0	 1251.0	 2900	 2900	 0.0	 0.0	 1	 -30.0	 30.0;
	8786	 1468	 0.00968	 0.088169	 0.0	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	8786	 1468	 0.012349	 0.086409	 0.0	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	1468	 4089	 0.00288	 0.017211	 0.0	 533.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 1468	 0.00257	 0.0195	 0.0	 495.0	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	3078	 1034	 0.00051	 0.00407	 0.0	 553.0	 7701	 7701	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 6529	 0.00019	 0.00309	 0.0	 1514.0	 10204	 10204	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 7108	 0.00023	 0.00357	 0.0	 1613.0	 8830	 8830	 0.0	 0.0	 1	 -30.0	 30.0;
	3285	 3884	 0.00088	 0.0092	 0.0	 1185.0	 3418	 3418	 0.0	 0.0	 1	 -30.0	 30.0;
	3285	 4680	 0.00023	 0.00179	 0.0	 1580.0	 17503	 17503	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 939	 0.00145	 0.007919	 0.0	 495.0	 3924	 3924	 0.0	 0.0	 1	 -30.0	 30.0;
	471	 939	 0.00143	 0.00812	 0.0	 495.0	 3832	 3832	 0.0	 0.0	 1	 -30.0	 30.0;
	939	 5677	 0.00524	 0.02181	 0.0	 514.0	 1409	 1409	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 3769	 0.00261	 0.01913	 0.0	 438.0	 1637	 1637	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 3769	 0.00164	 0.016591	 0.0	 572.0	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 5253	 0.00087	 0.012719	 0.0	 438.0	 2478	 2478	 0.0	 0.0	 1	 -30.0	 30.0;
	1	 7639	 0.00775	 0.03501	 0.0	 400.0	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	1	 7835	 0.01944	 0.093479	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	1	 7835	 0.01981	 0.091539	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	1523	 5633	 0.003771	 0.020599	 0.0	 419.0	 1509	 1509	 0.0	 0.0	 1	 -30.0	 30.0;
	8681	 1523	 0.001271	 0.00811	 0.0	 495.0	 3848	 3848	 0.0	 0.0	 1	 -30.0	 30.0;
	8724	 1072	 0.00048	 0.01459	 0.0	 1152.0	 2164	 2164	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 8724	 0.00047	 0.01351	 0.0	 1711.0	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	2366	 1470	 0.021729	 0.088281	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 2880	 0.00038	 0.001771	 0.0	 495.0	 17439	 17439	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 1257	 0.022901	 0.101401	 0.0	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 5459	 0.002909	 0.01432	 0.0	 476.0	 2162	 2162	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 2675	 0.015729	 0.08824	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	2905	 6958	 0.00038	 0.002169	 0.0	 14345	 14345	 14345	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 2905	 0.000479	 0.00212	 0.0	 14534	 14534	 14534	 0.0	 0.0	 1	 -30.0	 30.0;
	2905	 399	 0.00019	 0.00086	 0.0	 35865	 35865	 35865	 0.0	 0.0	 1	 -30.0	 30.0;
	763	 142	 0.00089	 0.004901	 0.0	 6342	 6342	 6342	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 1072	 0.00109	 0.03151	 0.0	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 6210	 0.003409	 0.020271	 0.0	 533.0	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 6210	 0.002909	 0.02388	 0.0	 476.0	 1314	 1314	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 3832	 0.00545	 0.042969	 0.0	 495.0	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 3832	 0.005341	 0.0438	 0.0	 476.0	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 7494	 0.001521	 0.00863	 0.0	 3605	 3605	 3605	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 5483	 0.00057	 0.005979	 0.0	 381.0	 5260	 5260	 0.0	 0.0	 1	 -30.0	 30.0;
	9121	 5747	 0.00085	 0.01449	 0.0	 1744.0	 2177	 2177	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 5747	 0.0006	 0.00777	 0.0	 1547.0	 4054	 4054	 0.0	 0.0	 1	 -30.0	 30.0;
	4928	 5747	 0.0003	 0.00492	 0.0	 1119.0	 6409	 6409	 0.0	 0.0	 1	 -30.0	 30.0;
	2685	 2636	 0.003349	 0.02686	 0.0	 629.0	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	2224	 2636	 0.00213	 0.016849	 0.0	 591.0	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	3811	 9236	 0.00077	 0.0106	 0.0	 1415.0	 2973	 2973	 0.0	 0.0	 1	 -30.0	 30.0;
	8237	 9236	 0.00155	 0.0148	 0.0	 1316.0	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 565	 0.016651	 0.10632	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 565	 0.014841	 0.12049	 0.0	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	4666	 565	 9.9e-05	 0.001229	 0.0	 533.0	 25619	 25619	 0.0	 0.0	 1	 -30.0	 30.0;
	7743	 565	 9.9e-05	 0.00114	 0.0	 533.0	 27605	 27605	 0.0	 0.0	 1	 -30.0	 30.0;
	8266	 2199	 0.00048	 0.00781	 0.0	 1810.0	 4037	 4037	 0.0	 0.0	 1	 -30.0	 30.0;
	8266	 3343	 0.00076	 0.01058	 0.0	 2978	 2978	 2978	 0.0	 0.0	 1	 -30.0	 30.0;
	8588	 8266	 0.00073	 0.01181	 0.0	 954.0	 2670	 2670	 0.0	 0.0	 1	 -30.0	 30.0;
	7234	 830	 0.00059	 0.00929	 0.0	 1711.0	 3394	 3394	 0.0	 0.0	 1	 -30.0	 30.0;
	149	 830	 8e-05	 0.00092	 0.0	 1119.0	 34205	 34205	 0.0	 0.0	 1	 -30.0	 30.0;
	295	 1034	 0.00019	 0.000849	 0.0	 36308	 36308	 36308	 0.0	 0.0	 1	 -30.0	 30.0;
	2384	 3948	 0.003479	 0.01538	 0.0	 2004	 2004	 2004	 0.0	 0.0	 1	 -30.0	 30.0;
	2384	 3948	 0.003539	 0.01505	 0.0	 2044	 2044	 2044	 0.0	 0.0	 1	 -30.0	 30.0;
	2384	 1469	 0.01387	 0.084099	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 2384	 0.00375	 0.021341	 0.0	 381.0	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	8375	 5376	 0.00023	 0.00345	 0.0	 1777.0	 9136	 9136	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 1684	 0.00054	 0.00662	 0.0	 1613.0	 4756	 4756	 0.0	 0.0	 1	 -30.0	 30.0;
	405	 8573	 7e-05	 0.00099	 0.0	 1218.0	 31827	 31827	 0.0	 0.0	 1	 -30.0	 30.0;
	5510	 405	 0.00012	 0.002	 0.0	 1744.0	 15766	 15766	 0.0	 0.0	 1	 -30.0	 30.0;
	229	 3884	 0.00075	 0.00888	 0.0	 1185.0	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 3884	 0.00054	 0.00705	 0.0	 1349.0	 4468	 4468	 0.0	 0.0	 1	 -30.0	 30.0;
	6863	 4138	 0.00574	 0.0287	 0.0	 495.0	 1080	 1080	 0.0	 0.0	 1	 -30.0	 30.0;
	6863	 6594	 0.001331	 0.009479	 0.0	 3300	 3300	 3300	 0.0	 0.0	 1	 -30.0	 30.0;
	6594	 6863	 0.00539	 0.024159	 0.0	 400.0	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 6863	 0.000539	 0.0028	 0.0	 438.0	 11078	 11078	 0.0	 0.0	 1	 -30.0	 30.0;
	7718	 8014	 0.000969	 0.00724	 0.0	 381.0	 4325	 4325	 0.0	 0.0	 1	 -30.0	 30.0;
	6649	 8014	 0.000349	 0.00339	 0.0	 457.0	 9269	 9269	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 8375	 0.00021	 0.00349	 0.0	 1942.0	 9035	 9035	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 49	 0.00318	 0.020669	 0.0	 400.0	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 49	 0.003599	 0.02026	 0.0	 419.0	 1536	 1536	 0.0	 0.0	 1	 -30.0	 30.0;
	49	 1236	 0.0053	 0.035521	 0.0	 381.0	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	49	 2803	 0.00486	 0.024331	 0.0	 419.0	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	6809	 4572	 0.000659	 0.00645	 0.0	 438.0	 4872	 4872	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 3571	 0.00239	 0.01531	 0.0	 2039	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	5868	 1571	 0.00119	 0.01215	 0.0	 1678.0	 2588	 2588	 0.0	 0.0	 1	 -30.0	 30.0;
	1571	 6201	 0.00012	 0.0015	 0.0	 1909.0	 20992	 20992	 0.0	 0.0	 1	 -30.0	 30.0;
	1571	 6460	 0.00047	 0.00738	 0.0	 1415.0	 4272	 4272	 0.0	 0.0	 1	 -30.0	 30.0;
	7855	 5959	 0.00068	 0.00189	 0.0	 514.0	 15726	 15726	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 8951	 0.003669	 0.022099	 0.0	 476.0	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	8681	 8951	 0.004771	 0.0218	 0.0	 457.0	 1416	 1416	 0.0	 0.0	 1	 -30.0	 30.0;
	2909	 7639	 0.001469	 0.006591	 0.0	 533.0	 4678	 4678	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 510	 8.1e-05	 0.00045	 0.0	 69084	 69084	 69084	 0.0	 0.0	 1	 -30.0	 30.0;
	510	 471	 0.001021	 0.00782	 0.0	 476.0	 4006	 4006	 0.0	 0.0	 1	 -30.0	 30.0;
	4035	 510	 0.0015	 0.009591	 0.0	 514.0	 3254	 3254	 0.0	 0.0	 1	 -30.0	 30.0;
	6156	 834	 0.00019	 0.001581	 0.0	 514.0	 19837	 19837	 0.0	 0.0	 1	 -30.0	 30.0;
	6156	 7718	 3.9e-05	 0.000479	 0.0	 610.0	 65727	 65727	 0.0	 0.0	 1	 -30.0	 30.0;
	7311	 5471	 0.00027	 0.00281	 0.0	 1283.0	 11190	 11190	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 7311	 0.00096	 0.01609	 0.0	 1777.0	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	7311	 8588	 0.00027	 0.00339	 0.0	 954.0	 9289	 9289	 0.0	 0.0	 1	 -30.0	 30.0;
	7311	 8588	 0.00023	 0.00398	 0.0	 1547.0	 7924	 7924	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 7538	 0.000901	 0.00937	 0.0	 572.0	 3356	 3356	 0.0	 0.0	 1	 -30.0	 30.0;
	7540	 7538	 0.001901	 0.01549	 0.0	 438.0	 2025	 2025	 0.0	 0.0	 1	 -30.0	 30.0;
	8320	 7538	 0.003591	 0.02205	 0.0	 476.0	 1414	 1414	 0.0	 0.0	 1	 -30.0	 30.0;
	7538	 5704	 0.0013	 0.009901	 0.0	 514.0	 3164	 3164	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 3068	 0.00022	 0.00299	 0.0	 10536	 10536	 10536	 0.0	 0.0	 1	 -30.0	 30.0;
	3068	 8635	 0.00047	 0.00564	 0.0	 1843.0	 5582	 5582	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 3068	 0.00046	 0.0075	 0.0	 4204	 4204	 4204	 0.0	 0.0	 1	 -30.0	 30.0;
	6303	 708	 0.00214	 0.020979	 0.0	 438.0	 1498	 1498	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 708	 0.004651	 0.03332	 0.0	 457.0	 939	 939	 0.0	 0.0	 1	 -30.0	 30.0;
	708	 4448	 0.00468	 0.021281	 0.0	 495.0	 1450	 1450	 0.0	 0.0	 1	 -30.0	 30.0;
	708	 4813	 0.00581	 0.028331	 0.0	 1093	 1093	 1093	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 7197	 7e-05	 0.00086	 0.0	 1613.0	 36609	 36609	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 4445	 0.0002	 0.00279	 0.0	 1349.0	 11293	 11293	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 4445	 0.00017	 0.00333	 0.0	 1349.0	 9474	 9474	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 5868	 1e-05	 0.00036	 0.0	 1448.0	 87709	 87709	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 6631	 0.000401	 0.004081	 0.0	 457.0	 7704	 7704	 0.0	 0.0	 1	 -30.0	 30.0;
	6631	 7167	 0.001581	 0.015719	 0.0	 476.0	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	7727	 7841	 0.00012	 0.000229	 0.0	 122178	 122178	 122178	 0.0	 0.0	 1	 -30.0	 30.0;
	7727	 7841	 0.00012	 0.00024	 0.0	 117720	 117720	 117720	 0.0	 0.0	 1	 -30.0	 30.0;
	7841	 8521	 0.00132	 0.005729	 0.0	 438.0	 5373	 5373	 0.0	 0.0	 1	 -30.0	 30.0;
	8774	 7841	 0.00438	 0.024901	 0.0	 419.0	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 104	 0.005521	 0.023711	 0.0	 419.0	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	229	 7359	 0.0008	 0.01014	 0.0	 1283.0	 3106	 3106	 0.0	 0.0	 1	 -30.0	 30.0;
	229	 7359	 0.00068	 0.01229	 0.0	 1349.0	 2567	 2567	 0.0	 0.0	 1	 -30.0	 30.0;
	2685	 1220	 0.001901	 0.01163	 0.0	 495.0	 2681	 2681	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 547	 0.00101	 0.00824	 0.0	 3805	 3805	 3805	 0.0	 0.0	 1	 -30.0	 30.0;
	8786	 5766	 0.00787	 0.068219	 0.0	 457.0	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	8786	 5766	 0.007711	 0.069539	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 5997	 0.00032	 0.002091	 0.0	 14933	 14933	 14933	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 4610	 0.00012	 0.00182	 0.0	 17319	 17319	 17319	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 6	 0.00058	 0.00736	 0.0	 1415.0	 4279	 4279	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 1760	 0.00074	 0.01143	 0.0	 1481.0	 2758	 2758	 0.0	 0.0	 1	 -30.0	 30.0;
	7234	 5575	 0.00084	 0.01378	 0.0	 1843.0	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	7234	 7182	 0.00037	 0.00356	 0.0	 1580.0	 8826	 8826	 0.0	 0.0	 1	 -30.0	 30.0;
	7108	 7234	 0.00012	 0.00206	 0.0	 1481.0	 15308	 15308	 0.0	 0.0	 1	 -30.0	 30.0;
	7487	 6302	 0.00036	 0.00151	 0.0	 20349	 20349	 20349	 0.0	 0.0	 1	 -30.0	 30.0;
	9121	 1512	 0.0012	 0.01835	 0.0	 954.0	 1718	 1718	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 6189	 0.00088	 0.01503	 0.0	 1645.0	 2099	 2099	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 1512	 0.00057	 0.00939	 0.0	 1744.0	 3358	 3358	 0.0	 0.0	 1	 -30.0	 30.0;
	3351	 3696	 0.00157	 0.02006	 0.0	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	3351	 5577	 0.00027	 0.00349	 0.0	 1810.0	 9024	 9024	 0.0	 0.0	 1	 -30.0	 30.0;
	7664	 3351	 0.00136	 0.02325	 0.0	 1357	 1357	 1357	 0.0	 0.0	 1	 -30.0	 30.0;
	3351	 3895	 0.00038	 0.00478	 0.0	 1744.0	 6588	 6588	 0.0	 0.0	 1	 -30.0	 30.0;
	3351	 6444	 0.00077	 0.01171	 0.0	 1613.0	 2692	 2692	 0.0	 0.0	 1	 -30.0	 30.0;
	9121	 5476	 0.00129	 0.02076	 0.0	 1185.0	 1519	 1519	 0.0	 0.0	 1	 -30.0	 30.0;
	9121	 1760	 0.00037	 0.0046	 0.0	 1283.0	 6845	 6845	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 9121	 0.00021	 0.00375	 0.0	 1481.0	 8411	 8411	 0.0	 0.0	 1	 -30.0	 30.0;
	9121	 2160	 0.00055	 0.00885	 0.0	 1382.0	 3563	 3563	 0.0	 0.0	 1	 -30.0	 30.0;
	6809	 1804	 0.001659	 0.01138	 0.0	 457.0	 2747	 2747	 0.0	 0.0	 1	 -30.0	 30.0;
	6809	 4904	 0.001169	 0.010021	 0.0	 457.0	 3131	 3131	 0.0	 0.0	 1	 -30.0	 30.0;
	6809	 1423	 0.002229	 0.00975	 0.0	 533.0	 3159	 3159	 0.0	 0.0	 1	 -30.0	 30.0;
	6809	 7123	 0.00049	 0.004521	 0.0	 438.0	 6947	 6947	 0.0	 0.0	 1	 -30.0	 30.0;
	6809	 6649	 0.0002	 0.001969	 0.0	 591.0	 15961	 15961	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 4836	 0.0001	 0.00158	 0.0	 1678.0	 19953	 19953	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 4836	 0.00011	 0.00151	 0.0	 1547.0	 20864	 20864	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 4943	 3e-05	 0.00043	 0.0	 757.0	 73281	 73281	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 685	 0.00037	 0.00589	 0.0	 1843.0	 5353	 5353	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 1193	 0.00087	 0.01218	 0.0	 1448.0	 2587	 2587	 0.0	 0.0	 1	 -30.0	 30.0;
	6776	 5766	 0.00362	 0.024409	 0.0	 457.0	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	6776	 3832	 0.00488	 0.03119	 0.0	 438.0	 1001	 1001	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 2314	 0.00055	 0.00264	 0.0	 533.0	 11714	 11714	 0.0	 0.0	 1	 -30.0	 30.0;
	6107	 2314	 0.00031	 0.001341	 0.0	 533.0	 22950	 22950	 0.0	 0.0	 1	 -30.0	 30.0;
	5959	 2314	 0.00012	 0.000669	 0.0	 495.0	 46475	 46475	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 1688	 3.1e-05	 0.000469	 0.0	 67204	 67204	 67204	 0.0	 0.0	 1	 -30.0	 30.0;
	1991	 1688	 3.1e-05	 0.000461	 0.0	 68365	 68365	 68365	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 4502	 0.00607	 0.03457	 0.0	 381.0	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	4502	 4516	 0.0087	 0.047719	 0.0	 457.0	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	3811	 8237	 0.00129	 0.02159	 0.0	 1382.0	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	3811	 1224	 0.00091	 0.00903	 0.0	 1645.0	 3481	 3481	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 3811	 0.0004	 0.00518	 0.0	 1744.0	 6080	 6080	 0.0	 0.0	 1	 -30.0	 30.0;
	3811	 6736	 0.00032	 0.00557	 0.0	 5662	 5662	 5662	 0.0	 0.0	 1	 -30.0	 30.0;
	7494	 4719	 3.1e-05	 0.0002	 0.0	 156073	 156073	 156073	 0.0	 0.0	 1	 -30.0	 30.0;
	7494	 6191	 3.1e-05	 0.000211	 0.0	 148114	 148114	 148114	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 2570	 0.00199	 0.011591	 0.0	 457.0	 2686	 2686	 0.0	 0.0	 1	 -30.0	 30.0;
	3699	 5451	 0.000211	 0.000919	 0.0	 33500	 33500	 33500	 0.0	 0.0	 1	 -30.0	 30.0;
	3972	 2456	 0.00109	 0.01525	 0.0	 1547.0	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	748	 2570	 0.005789	 0.02826	 0.0	 438.0	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	6529	 2884	 0.00041	 0.0064	 0.0	 1843.0	 4926	 4926	 0.0	 0.0	 1	 -30.0	 30.0;
	6529	 2684	 0.00051	 0.00603	 0.0	 1678.0	 5220	 5220	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 4283	 0.00245	 0.02726	 0.0	 514.0	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 7167	 0.000271	 0.00337	 0.0	 438.0	 9343	 9343	 0.0	 0.0	 1	 -30.0	 30.0;
	3634	 6892	 0.000151	 0.00064	 0.0	 48037	 48037	 48037	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 3634	 0.003341	 0.022091	 0.0	 1414	 1414	 1414	 0.0	 0.0	 1	 -30.0	 30.0;
	3634	 1236	 0.022	 0.125771	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	3634	 2317	 0.0153	 0.08863	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	3634	 2317	 0.015599	 0.08682	 0.0	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 2034	 0.001169	 0.00844	 0.0	 3708	 3708	 3708	 0.0	 0.0	 1	 -30.0	 30.0;
	6302	 704	 0.00081	 0.004271	 0.0	 7267	 7267	 7267	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 5913	 0.000349	 0.0015	 0.0	 20511	 20511	 20511	 0.0	 0.0	 1	 -30.0	 30.0;
	3696	 6444	 0.00058	 0.00717	 0.0	 1942.0	 4392	 4392	 0.0	 0.0	 1	 -30.0	 30.0;
	3696	 5623	 0.0007	 0.01203	 0.0	 1810.0	 2622	 2622	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 3696	 0.00061	 0.00957	 0.0	 1909.0	 3294	 3294	 0.0	 0.0	 1	 -30.0	 30.0;
	8663	 2589	 2e-05	 0.00075	 0.0	 1514.0	 42102	 42102	 0.0	 0.0	 1	 -30.0	 30.0;
	7268	 8663	 0.00041	 0.01221	 0.0	 2586	 2586	 2586	 0.0	 0.0	 1	 -30.0	 30.0;
	1034	 2103	 0.00157	 0.007969	 0.0	 3890	 3890	 3890	 0.0	 0.0	 1	 -30.0	 30.0;
	4243	 2103	 0.00151	 0.00625	 0.0	 4913	 4913	 4913	 0.0	 0.0	 1	 -30.0	 30.0;
	4433	 4436	 2e-05	 0.00023	 0.0	 1218.0	 136820	 136820	 0.0	 0.0	 1	 -30.0	 30.0;
	4433	 4436	 2e-05	 0.00022	 0.0	 1185.0	 142990	 142990	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 4433	 0.00026	 0.00395	 0.0	 1613.0	 7980	 7980	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 4433	 0.00025	 0.00403	 0.0	 1711.0	 7824	 7824	 0.0	 0.0	 1	 -30.0	 30.0;
	5945	 238	 0.00111	 0.005099	 0.0	 457.0	 6054	 6054	 0.0	 0.0	 1	 -30.0	 30.0;
	238	 4715	 0.000729	 0.0023	 0.0	 476.0	 13092	 13092	 0.0	 0.0	 1	 -30.0	 30.0;
	4715	 8036	 0.003831	 0.016271	 0.0	 438.0	 1890	 1890	 0.0	 0.0	 1	 -30.0	 30.0;
	7479	 9135	 0.001849	 0.014719	 0.0	 514.0	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	7403	 7479	 0.00157	 0.010169	 0.0	 457.0	 3070	 3070	 0.0	 0.0	 1	 -30.0	 30.0;
	528	 6303	 0.00149	 0.01513	 0.0	 2078	 2078	 2078	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 528	 0.003229	 0.02918	 0.0	 1076	 1076	 1076	 0.0	 0.0	 1	 -30.0	 30.0;
	8237	 2100	 1e-05	 0.00021	 0.0	 1711.0	 150246	 150246	 0.0	 0.0	 1	 -30.0	 30.0;
	2302	 2199	 0.00054	 0.00765	 0.0	 1547.0	 4119	 4119	 0.0	 0.0	 1	 -30.0	 30.0;
	4036	 5577	 1e-05	 0.0002	 0.0	 757.0	 157740	 157740	 0.0	 0.0	 1	 -30.0	 30.0;
	5577	 6444	 0.00053	 0.00746	 0.0	 1645.0	 4224	 4224	 0.0	 0.0	 1	 -30.0	 30.0;
	3238	 3892	 0.010469	 0.057979	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	3238	 2650	 0.00014	 0.000781	 0.0	 39811	 39811	 39811	 0.0	 0.0	 1	 -30.0	 30.0;
	3238	 893	 0.00181	 0.013039	 0.0	 2400	 2400	 2400	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 8774	 0.01107	 0.04905	 0.0	 419.0	 629	 629	 0.0	 0.0	 1	 -30.0	 30.0;
	2615	 1610	 0.00038	 0.00468	 0.0	 1613.0	 6728	 6728	 0.0	 0.0	 1	 -30.0	 30.0;
	2615	 1610	 0.00034	 0.0053	 0.0	 1415.0	 5948	 5948	 0.0	 0.0	 1	 -30.0	 30.0;
	3343	 2615	 0.00012	 0.00185	 0.0	 757.0	 17039	 17039	 0.0	 0.0	 1	 -30.0	 30.0;
	3343	 2615	 0.00013	 0.00181	 0.0	 757.0	 17407	 17407	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 7753	 0.000211	 0.0018	 0.0	 553.0	 17430	 17430	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 3384	 0.00037	 0.00225	 0.0	 572.0	 13853	 13853	 0.0	 0.0	 1	 -30.0	 30.0;
	2766	 7891	 0.00025	 0.00317	 0.0	 1909.0	 9934	 9934	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 2766	 0.00029	 0.00484	 0.0	 1876.0	 6515	 6515	 0.0	 0.0	 1	 -30.0	 30.0;
	99	 7248	 0.00057	 0.00858	 0.0	 3674	 3674	 3674	 0.0	 0.0	 1	 -30.0	 30.0;
	99	 9009	 0.0005	 0.00665	 0.0	 1909.0	 4737	 4737	 0.0	 0.0	 1	 -30.0	 30.0;
	7804	 3024	 0.00239	 0.012289	 0.0	 457.0	 2524	 2524	 0.0	 0.0	 1	 -30.0	 30.0;
	6566	 3024	 0.0008	 0.005211	 0.0	 381.0	 5992	 5992	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 4019	 0.00067	 0.01081	 0.0	 1580.0	 2917	 2917	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 6189	 0.00105	 0.01455	 0.0	 1744.0	 2166	 2166	 0.0	 0.0	 1	 -30.0	 30.0;
	485	 7248	 0.0002	 0.00261	 0.0	 790.0	 12068	 12068	 0.0	 0.0	 1	 -30.0	 30.0;
	5982	 8708	 1e-05	 0.0002	 0.0	 757.0	 157740	 157740	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 8708	 0.00036	 0.00601	 0.0	 5247	 5247	 5247	 0.0	 0.0	 1	 -30.0	 30.0;
	9009	 8708	 0.0001	 0.00151	 0.0	 20874	 20874	 20874	 0.0	 0.0	 1	 -30.0	 30.0;
	4487	 802	 2e-05	 0.00021	 0.0	 757.0	 149739	 149739	 0.0	 0.0	 1	 -30.0	 30.0;
	8237	 802	 0.00046	 0.00568	 0.0	 1251.0	 5544	 5544	 0.0	 0.0	 1	 -30.0	 30.0;
	660	 802	 0.00041	 0.00531	 0.0	 1283.0	 5931	 5931	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 2302	 0.0003	 0.00482	 0.0	 1876.0	 6541	 6541	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 220	 1e-05	 0.0002	 0.0	 1744.0	 157740	 157740	 0.0	 0.0	 1	 -30.0	 30.0;
	7664	 1131	 1e-05	 0.00022	 0.0	 1843.0	 143431	 143431	 0.0	 0.0	 1	 -30.0	 30.0;
	2709	 8573	 2e-05	 0.00025	 0.0	 790.0	 125947	 125947	 0.0	 0.0	 1	 -30.0	 30.0;
	2709	 8573	 2e-05	 0.00026	 0.0	 757.0	 121132	 121132	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 3174	 0.00032	 0.00528	 0.0	 1711.0	 5972	 5972	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 3174	 0.0006	 0.0084	 0.0	 1876.0	 3751	 3751	 0.0	 0.0	 1	 -30.0	 30.0;
	6464	 8139	 0.00105	 0.01735	 0.0	 1514.0	 1818	 1818	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 6464	 0.00135	 0.01758	 0.0	 1481.0	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	7248	 8139	 0.0004	 0.0068	 0.0	 1810.0	 4638	 4638	 0.0	 0.0	 1	 -30.0	 30.0;
	7248	 8139	 0.00039	 0.0063	 0.0	 1711.0	 5005	 5005	 0.0	 0.0	 1	 -30.0	 30.0;
	8139	 9009	 0.00067	 0.00834	 0.0	 1415.0	 3776	 3776	 0.0	 0.0	 1	 -30.0	 30.0;
	7672	 685	 0.00084	 0.01114	 0.0	 1876.0	 2828	 2828	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 685	 0.00081	 0.011	 0.0	 1613.0	 2864	 2864	 0.0	 0.0	 1	 -30.0	 30.0;
	3123	 3159	 0.00059	 0.00726	 0.0	 1448.0	 4337	 4337	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 3159	 0.001	 0.01178	 0.0	 1744.0	 2672	 2672	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 2344	 0.00031	 0.00197	 0.0	 1218.0	 15840	 15840	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 2344	 0.00035	 0.00193	 0.0	 1251.0	 16104	 16104	 0.0	 0.0	 1	 -30.0	 30.0;
	6408	 2344	 2e-05	 0.0004	 0.0	 954.0	 78870	 78870	 0.0	 0.0	 1	 -30.0	 30.0;
	6408	 2344	 2e-05	 0.00041	 0.0	 1020.0	 76951	 76951	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 4564	 3.1e-05	 0.000271	 0.0	 457.0	 115804	 115804	 0.0	 0.0	 1	 -30.0	 30.0;
	4564	 4869	 3.1e-05	 0.000281	 0.0	 457.0	 111733	 111733	 0.0	 0.0	 1	 -30.0	 30.0;
	4564	 3228	 0.000229	 0.000271	 0.0	 514.0	 89029	 89029	 0.0	 0.0	 1	 -30.0	 30.0;
	2232	 5854	 0.000289	 0.001229	 0.0	 25020	 25020	 25020	 0.0	 0.0	 1	 -30.0	 30.0;
	2232	 8774	 0.002479	 0.01106	 0.0	 2787	 2787	 2787	 0.0	 0.0	 1	 -30.0	 30.0;
	8524	 748	 0.00738	 0.04069	 0.0	 419.0	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	6939	 6560	 0.00058	 0.00872	 0.0	 1744.0	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	6560	 5868	 0.00116	 0.01483	 0.0	 1909.0	 2124	 2124	 0.0	 0.0	 1	 -30.0	 30.0;
	6560	 5868	 0.00118	 0.01452	 0.0	 1942.0	 2169	 2169	 0.0	 0.0	 1	 -30.0	 30.0;
	7248	 3123	 0.00139	 0.02265	 0.0	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	7248	 3123	 0.00149	 0.02349	 0.0	 1343	 1343	 1343	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 3123	 0.00086	 0.01488	 0.0	 1876.0	 2120	 2120	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 3123	 0.00095	 0.01554	 0.0	 1942.0	 2029	 2029	 0.0	 0.0	 1	 -30.0	 30.0;
	342	 759	 0.019651	 0.09944	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	7071	 1269	 0.0002	 0.001831	 0.0	 476.0	 17150	 17150	 0.0	 0.0	 1	 -30.0	 30.0;
	8857	 2822	 7e-05	 0.00062	 0.0	 457.0	 50626	 50626	 0.0	 0.0	 1	 -30.0	 30.0;
	2822	 13	 0.004039	 0.023081	 0.0	 457.0	 1349	 1349	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 2822	 0.0132	 0.064331	 0.0	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	2822	 9013	 0.001401	 0.008729	 0.0	 3573	 3573	 3573	 0.0	 0.0	 1	 -30.0	 30.0;
	6444	 9132	 0.00021	 0.00247	 0.0	 1119.0	 12743	 12743	 0.0	 0.0	 1	 -30.0	 30.0;
	6444	 5623	 0.00138	 0.01791	 0.0	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	8237	 660	 0.00056	 0.00795	 0.0	 1744.0	 3964	 3964	 0.0	 0.0	 1	 -30.0	 30.0;
	8237	 5328	 0.00081	 0.00788	 0.0	 1152.0	 3988	 3988	 0.0	 0.0	 1	 -30.0	 30.0;
	7619	 6939	 3e-05	 0.00042	 0.0	 757.0	 75017	 75017	 0.0	 0.0	 1	 -30.0	 30.0;
	1748	 6939	 3e-05	 0.00042	 0.0	 856.0	 75017	 75017	 0.0	 0.0	 1	 -30.0	 30.0;
	8569	 6939	 3e-05	 0.00035	 0.0	 823.0	 89920	 89920	 0.0	 0.0	 1	 -30.0	 30.0;
	6778	 6939	 3e-05	 0.00036	 0.0	 757.0	 87440	 87440	 0.0	 0.0	 1	 -30.0	 30.0;
	7891	 6939	 0.00035	 0.00423	 0.0	 954.0	 7443	 7443	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 5109	 0.00076	 0.00904	 0.0	 1316.0	 3482	 3482	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 4680	 0.00029	 0.00361	 0.0	 1382.0	 8722	 8722	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 6070	 0.010349	 0.056729	 0.0	 476.0	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 2034	 0.001581	 0.012771	 0.0	 533.0	 2455	 2455	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 1034	 0.001081	 0.01136	 0.0	 2769	 2769	 2769	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 4243	 0.001669	 0.00914	 0.0	 438.0	 3400	 3400	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 5677	 0.01757	 0.07575	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	817	 7182	 0.00037	 0.00558	 0.0	 5649	 5649	 5649	 0.0	 0.0	 1	 -30.0	 30.0;
	817	 8635	 0.00041	 0.0072	 0.0	 1415.0	 4381	 4381	 0.0	 0.0	 1	 -30.0	 30.0;
	7787	 4574	 0.002479	 0.017961	 0.0	 419.0	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 7787	 0.00155	 0.0127	 0.0	 438.0	 2469	 2469	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 7835	 0.001961	 0.010419	 0.0	 457.0	 2980	 2980	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 2034	 0.00138	 0.007521	 0.0	 4131	 4131	 4131	 0.0	 0.0	 1	 -30.0	 30.0;
	8907	 2135	 0.00281	 0.02543	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 8634	 0.000211	 0.000901	 0.0	 495.0	 34135	 34135	 0.0	 0.0	 1	 -30.0	 30.0;
	7540	 3816	 0.000789	 0.00519	 0.0	 6018	 6018	 6018	 0.0	 0.0	 1	 -30.0	 30.0;
	7540	 102	 0.00056	 0.004281	 0.0	 7317	 7317	 7317	 0.0	 0.0	 1	 -30.0	 30.0;
	7540	 8320	 0.00163	 0.012031	 0.0	 591.0	 2602	 2602	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 7540	 0.000211	 0.00161	 0.0	 495.0	 19454	 19454	 0.0	 0.0	 1	 -30.0	 30.0;
	7540	 5704	 0.00018	 0.00144	 0.0	 476.0	 21767	 21767	 0.0	 0.0	 1	 -30.0	 30.0;
	7320	 1804	 9.1e-05	 0.00081	 0.0	 38753	 38753	 38753	 0.0	 0.0	 1	 -30.0	 30.0;
	8484	 1804	 9.1e-05	 0.00099	 0.0	 31773	 31773	 31773	 0.0	 0.0	 1	 -30.0	 30.0;
	3337	 5089	 0.001219	 0.01461	 0.0	 2155	 2155	 2155	 0.0	 0.0	 1	 -30.0	 30.0;
	3337	 2200	 0.00769	 0.035169	 0.0	 629.0	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	7618	 8246	 5e-05	 0.000219	 0.0	 438.0	 140617	 140617	 0.0	 0.0	 1	 -30.0	 30.0;
	8246	 5913	 0.000281	 0.00112	 0.0	 438.0	 27356	 27356	 0.0	 0.0	 1	 -30.0	 30.0;
	5746	 4283	 0.003591	 0.01825	 0.0	 438.0	 1699	 1699	 0.0	 0.0	 1	 -30.0	 30.0;
	5746	 4283	 0.00125	 0.01386	 0.0	 457.0	 2270	 2270	 0.0	 0.0	 1	 -30.0	 30.0;
	342	 4283	 0.000961	 0.00513	 0.0	 514.0	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	1610	 4381	 0.00022	 0.00295	 0.0	 757.0	 10678	 10678	 0.0	 0.0	 1	 -30.0	 30.0;
	5668	 8426	 0.00326	 0.02562	 0.0	 419.0	 1224	 1224	 0.0	 0.0	 1	 -30.0	 30.0;
	5668	 7593	 0.00164	 0.013219	 0.0	 572.0	 2372	 2372	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 832	 8.1e-05	 0.00019	 0.0	 152932	 152932	 152932	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 832	 3.9e-05	 0.00032	 0.0	 381.0	 97986	 97986	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 832	 0.00011	 0.0002	 0.0	 138387	 138387	 138387	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 832	 0.000103	 0.000171	 0.0	 158234	 158234	 158234	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 832	 0.00011	 0.00019	 0.0	 143877	 143877	 143877	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 3816	 8.1e-05	 0.001	 0.0	 438.0	 31485	 31485	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 102	 0.000281	 0.00213	 0.0	 419.0	 14703	 14703	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 4168	 0.00025	 0.000831	 0.0	 457.0	 36400	 36400	 0.0	 0.0	 1	 -30.0	 30.0;
	8275	 4168	 0.00013	 0.000469	 0.0	 419.0	 64904	 64904	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 229	 0.00088	 0.01144	 0.0	 1283.0	 2753	 2753	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 229	 0.00076	 0.01445	 0.0	 1020.0	 2183	 2183	 0.0	 0.0	 1	 -30.0	 30.0;
	2187	 7672	 0.00048	 0.0076	 0.0	 1777.0	 4148	 4148	 0.0	 0.0	 1	 -30.0	 30.0;
	7672	 2362	 0.00017	 0.00273	 0.0	 1876.0	 11549	 11549	 0.0	 0.0	 1	 -30.0	 30.0;
	8933	 7564	 0.00014	 0.000849	 0.0	 36710	 36710	 36710	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 8933	 0.0022	 0.01289	 0.0	 419.0	 2416	 2416	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 3807	 0.00582	 0.03749	 0.0	 476.0	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 3807	 0.00593	 0.03669	 0.0	 476.0	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	3807	 5809	 0.000281	 0.003419	 0.0	 629.0	 9208	 9208	 0.0	 0.0	 1	 -30.0	 30.0;
	3807	 4089	 0.00645	 0.03995	 0.0	 476.0	 781	 781	 0.0	 0.0	 1	 -30.0	 30.0;
	3807	 4089	 0.00657	 0.039081	 0.0	 457.0	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 8869	 8e-05	 0.00125	 0.0	 1744.0	 25219	 25219	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 8741	 8e-05	 0.00127	 0.0	 757.0	 24823	 24823	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 4606	 7e-05	 0.0013	 0.0	 757.0	 24263	 24263	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 1488	 7e-05	 0.0012	 0.0	 757.0	 26279	 26279	 0.0	 0.0	 1	 -30.0	 30.0;
	8876	 5575	 5e-05	 0.0006	 0.0	 1514.0	 52464	 52464	 0.0	 0.0	 1	 -30.0	 30.0;
	5575	 6	 0.00034	 0.00466	 0.0	 6761	 6761	 6761	 0.0	 0.0	 1	 -30.0	 30.0;
	6594	 6302	 0.000591	 0.00588	 0.0	 495.0	 5346	 5346	 0.0	 0.0	 1	 -30.0	 30.0;
	6302	 6594	 0.00139	 0.00818	 0.0	 495.0	 3807	 3807	 0.0	 0.0	 1	 -30.0	 30.0;
	4243	 6594	 0.00169	 0.013969	 0.0	 572.0	 2245	 2245	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 339	 0.000229	 0.00163	 0.0	 438.0	 19191	 19191	 0.0	 0.0	 1	 -30.0	 30.0;
	4352	 8521	 0.00275	 0.02836	 0.0	 610.0	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 8521	 0.004909	 0.02468	 0.0	 438.0	 1256	 1256	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 8774	 0.001419	 0.02212	 0.0	 419.0	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	4561	 8399	 0.0016	 0.02118	 0.0	 1488	 1488	 1488	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 6316	 0.00116	 0.01869	 0.0	 1547.0	 1687	 1687	 0.0	 0.0	 1	 -30.0	 30.0;
	8161	 8399	 0.00169	 0.02149	 0.0	 1415.0	 1466	 1466	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 5328	 0.00171	 0.02913	 0.0	 856.0	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 1031	 0.00138	 0.0212	 0.0	 1487	 1487	 1487	 0.0	 0.0	 1	 -30.0	 30.0;
	2484	 2139	 0.00511	 0.02775	 0.0	 495.0	 1120	 1120	 0.0	 0.0	 1	 -30.0	 30.0;
	3972	 4159	 0.0008	 0.01262	 0.0	 2498	 2498	 2498	 0.0	 0.0	 1	 -30.0	 30.0;
	5130	 376	 0.0005	 0.00851	 0.0	 1744.0	 3706	 3706	 0.0	 0.0	 1	 -30.0	 30.0;
	5130	 2710	 0.00032	 0.00558	 0.0	 1843.0	 5652	 5652	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 5510	 0.00039	 0.00601	 0.0	 1876.0	 5245	 5245	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 4512	 0.00036	 0.00575	 0.0	 1514.0	 5483	 5483	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 8117	 0.00117	 0.01616	 0.0	 1810.0	 1950	 1950	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 6161	 0.0003	 0.00471	 0.0	 1448.0	 6693	 6693	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 745	 0.00011	 0.00081	 0.0	 476.0	 38643	 38643	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 1613	 0.01087	 0.06457	 0.0	 457.0	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 1613	 0.00968	 0.073169	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	2034	 7618	 0.00105	 0.005781	 0.0	 5377	 5377	 5377	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 2880	 0.002961	 0.029021	 0.0	 438.0	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	4147	 376	 4e-05	 0.00033	 0.0	 1349.0	 95024	 95024	 0.0	 0.0	 1	 -30.0	 30.0;
	2332	 376	 4e-05	 0.00035	 0.0	 1415.0	 89666	 89666	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 376	 4e-05	 0.0003	 0.0	 757.0	 104368	 104368	 0.0	 0.0	 1	 -30.0	 30.0;
	3348	 376	 4e-05	 0.00028	 0.0	 757.0	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 88	 0.000211	 0.00045	 0.0	 63555	 63555	 63555	 0.0	 0.0	 1	 -30.0	 30.0;
	9197	 3721	 0.00024	 0.001099	 0.0	 381.0	 28081	 28081	 0.0	 0.0	 1	 -30.0	 30.0;
	4133	 9197	 0.00544	 0.029831	 0.0	 381.0	 1042	 1042	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 7182	 0.00076	 0.0101	 0.0	 1942.0	 3119	 3119	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 5839	 0.01106	 0.06313	 0.0	 381.0	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 5746	 0.001909	 0.011401	 0.0	 476.0	 2733	 2733	 0.0	 0.0	 1	 -30.0	 30.0;
	6566	 5694	 0.00113	 0.005479	 0.0	 419.0	 5647	 5647	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 3705	 0.000151	 0.000961	 0.0	 495.0	 32471	 32471	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 2317	 0.00156	 0.01125	 0.0	 400.0	 2782	 2782	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 2317	 0.00344	 0.021599	 0.0	 1445	 1445	 1445	 0.0	 0.0	 1	 -30.0	 30.0;
	1308	 5089	 0.00106	 0.01276	 0.0	 2467	 2467	 2467	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 5866	 0.001349	 0.008831	 0.0	 3536	 3536	 3536	 0.0	 0.0	 1	 -30.0	 30.0;
	3721	 8857	 0.001901	 0.010031	 0.0	 381.0	 3094	 3094	 0.0	 0.0	 1	 -30.0	 30.0;
	2224	 7403	 0.001719	 0.012159	 0.0	 476.0	 2573	 2573	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 105	 4e-05	 0.00061	 0.0	 51672	 51672	 51672	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 191	 0.00126	 0.00595	 0.0	 5194	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 6	 0.00018	 0.00224	 0.0	 1942.0	 14057	 14057	 0.0	 0.0	 1	 -30.0	 30.0;
	6107	 1236	 0.000521	 0.002039	 0.0	 533.0	 15010	 15010	 0.0	 0.0	 1	 -30.0	 30.0;
	7893	 8857	 0.002169	 0.016479	 0.0	 419.0	 1901	 1901	 0.0	 0.0	 1	 -30.0	 30.0;
	4561	 5510	 0.00073	 0.01168	 0.0	 1876.0	 2700	 2700	 0.0	 0.0	 1	 -30.0	 30.0;
	8161	 5510	 0.00131	 0.0162	 0.0	 1481.0	 1944	 1944	 0.0	 0.0	 1	 -30.0	 30.0;
	7494	 2388	 0.00112	 0.007591	 0.0	 438.0	 4117	 4117	 0.0	 0.0	 1	 -30.0	 30.0;
	7123	 7494	 0.00162	 0.01332	 0.0	 457.0	 2355	 2355	 0.0	 0.0	 1	 -30.0	 30.0;
	6217	 8161	 0.00027	 0.00344	 0.0	 757.0	 9155	 9155	 0.0	 0.0	 1	 -30.0	 30.0;
	8009	 8161	 0.0003	 0.00313	 0.0	 757.0	 10046	 10046	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 1760	 0.00014	 0.00243	 0.0	 1744.0	 12978	 12978	 0.0	 0.0	 1	 -30.0	 30.0;
	1826	 4832	 0.00019	 0.001781	 0.0	 419.0	 17636	 17636	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 4832	 0.000151	 0.001969	 0.0	 457.0	 15996	 15996	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 1236	 0.025461	 0.14561	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	7593	 8426	 0.004599	 0.028581	 0.0	 476.0	 1092	 1092	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 1688	 0.00987	 0.05706	 0.0	 457.0	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 2577	 9e-05	 0.00103	 0.0	 1218.0	 30551	 30551	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 2577	 0.0001	 0.00101	 0.0	 1086.0	 31123	 31123	 0.0	 0.0	 1	 -30.0	 30.0;
	2710	 2577	 0.00023	 0.00381	 0.0	 8276	 8276	 8276	 0.0	 0.0	 1	 -30.0	 30.0;
	127	 2034	 0.002219	 0.01374	 0.0	 553.0	 2270	 2270	 0.0	 0.0	 1	 -30.0	 30.0;
	8623	 3099	 0.00092	 0.00895	 0.0	 3511	 3511	 3511	 0.0	 0.0	 1	 -30.0	 30.0;
	127	 6302	 0.001151	 0.009479	 0.0	 553.0	 3309	 3309	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 2200	 0.00188	 0.012151	 0.0	 610.0	 2570	 2570	 0.0	 0.0	 1	 -30.0	 30.0;
	3823	 1610	 0.00036	 0.00471	 0.0	 1645.0	 6687	 6687	 0.0	 0.0	 1	 -30.0	 30.0;
	3823	 946	 0.00085	 0.01337	 0.0	 2358	 2358	 2358	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 3823	 9e-05	 0.00105	 0.0	 1481.0	 29974	 29974	 0.0	 0.0	 1	 -30.0	 30.0;
	3343	 3823	 0.00037	 0.00634	 0.0	 1514.0	 4974	 4974	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 2983	 0.00056	 0.004979	 0.0	 381.0	 6305	 6305	 0.0	 0.0	 1	 -30.0	 30.0;
	3832	 5766	 0.00488	 0.029039	 0.0	 438.0	 1073	 1073	 0.0	 0.0	 1	 -30.0	 30.0;
	3832	 5766	 0.004349	 0.032919	 0.0	 438.0	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 2884	 0.00046	 0.00571	 0.0	 1942.0	 5515	 5515	 0.0	 0.0	 1	 -30.0	 30.0;
	9135	 5645	 0.010841	 0.04989	 0.0	 438.0	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	3234	 992	 0.00282	 0.01436	 0.0	 400.0	 2159	 2159	 0.0	 0.0	 1	 -30.0	 30.0;
	3234	 992	 0.00282	 0.014789	 0.0	 476.0	 2099	 2099	 0.0	 0.0	 1	 -30.0	 30.0;
	256	 2650	 0.00012	 0.000841	 0.0	 419.0	 37183	 37183	 0.0	 0.0	 1	 -30.0	 30.0;
	256	 893	 0.00175	 0.01189	 0.0	 381.0	 2629	 2629	 0.0	 0.0	 1	 -30.0	 30.0;
	256	 1688	 0.00851	 0.04389	 0.0	 495.0	 707	 707	 0.0	 0.0	 1	 -30.0	 30.0;
	6680	 6756	 0.00063	 0.00374	 0.0	 8329	 8329	 8329	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 162	 0.00037	 0.00484	 0.0	 987.0	 6508	 6508	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 5328	 0.00161	 0.02178	 0.0	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	8600	 1423	 0.00745	 0.03588	 0.0	 419.0	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 4991	 0.00051	 0.00829	 0.0	 1678.0	 3804	 3804	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 8117	 0.00124	 0.01751	 0.0	 1382.0	 1800	 1800	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 7891	 0.0008	 0.01242	 0.0	 987.0	 2539	 2539	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 5476	 0.00118	 0.01502	 0.0	 1843.0	 2097	 2097	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 7268	 0.00131	 0.01723	 0.0	 1152.0	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	1269	 5959	 0.000271	 0.001081	 0.0	 457.0	 28344	 28344	 0.0	 0.0	 1	 -30.0	 30.0;
	6201	 2986	 0.00014	 0.00178	 0.0	 1218.0	 17692	 17692	 0.0	 0.0	 1	 -30.0	 30.0;
	1269	 1236	 0.00051	 0.00201	 0.0	 514.0	 15233	 15233	 0.0	 0.0	 1	 -30.0	 30.0;
	7891	 2920	 9e-05	 0.00091	 0.0	 1744.0	 34543	 34543	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 471	 9.1e-05	 0.000591	 0.0	 52825	 52825	 52825	 0.0	 0.0	 1	 -30.0	 30.0;
	3228	 5014	 2.1e-05	 0.00025	 0.0	 419.0	 125906	 125906	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 6408	 0.00035	 0.00556	 0.0	 1711.0	 5670	 5670	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 6408	 0.0004	 0.00545	 0.0	 1777.0	 5781	 5781	 0.0	 0.0	 1	 -30.0	 30.0;
	6316	 4521	 0.0004	 0.00517	 0.0	 1020.0	 6092	 6092	 0.0	 0.0	 1	 -30.0	 30.0;
	4521	 5328	 0.00037	 0.00456	 0.0	 1218.0	 6905	 6905	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 6316	 0.00133	 0.01413	 0.0	 1415.0	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	7066	 4348	 0.01187	 0.05524	 0.0	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 3188	 0.00063	 0.0065	 0.0	 438.0	 4837	 4837	 0.0	 0.0	 1	 -30.0	 30.0;
	1688	 4348	 0.011841	 0.052289	 0.0	 400.0	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	660	 1356	 0.00055	 0.00517	 0.0	 921.0	 6076	 6076	 0.0	 0.0	 1	 -30.0	 30.0;
	1356	 5355	 0.00097	 0.01163	 0.0	 1382.0	 2707	 2707	 0.0	 0.0	 1	 -30.0	 30.0;
	1826	 5532	 0.000969	 0.01039	 0.0	 495.0	 3028	 3028	 0.0	 0.0	 1	 -30.0	 30.0;
	8907	 6670	 0.00326	 0.015581	 0.0	 457.0	 1985	 1985	 0.0	 0.0	 1	 -30.0	 30.0;
	2710	 4680	 0.00099	 0.01348	 0.0	 2337	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	5868	 4680	 0.00045	 0.00368	 0.0	 8521	 8521	 8521	 0.0	 0.0	 1	 -30.0	 30.0;
	1034	 4243	 0.002021	 0.011331	 0.0	 2745	 2745	 2745	 0.0	 0.0	 1	 -30.0	 30.0;
	9115	 1034	 0.00076	 0.0073	 0.0	 553.0	 4304	 4304	 0.0	 0.0	 1	 -30.0	 30.0;
	2187	 4040	 0.00101	 0.01505	 0.0	 2095	 2095	 2095	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 692	 0.0	 0.000347	 0.0	 301.0	 91030	 91030	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 4019	 0.00065	 0.00768	 0.0	 4099	 4099	 4099	 0.0	 0.0	 1	 -30.0	 30.0;
	4991	 6161	 0.00025	 0.0035	 0.0	 1415.0	 9003	 9003	 0.0	 0.0	 1	 -30.0	 30.0;
	3816	 2574	 0.00013	 0.000331	 0.0	 381.0	 88825	 88825	 0.0	 0.0	 1	 -30.0	 30.0;
	102	 2574	 3.9e-05	 0.00036	 0.0	 495.0	 87233	 87233	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 2880	 0.011021	 0.061901	 0.0	 457.0	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 5839	 0.007901	 0.04495	 0.0	 419.0	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 6302	 0.00369	 0.02186	 0.0	 438.0	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	6302	 6567	 0.000281	 0.001091	 0.0	 457.0	 28038	 28038	 0.0	 0.0	 1	 -30.0	 30.0;
	6302	 5913	 0.000461	 0.001841	 0.0	 476.0	 16644	 16644	 0.0	 0.0	 1	 -30.0	 30.0;
	1257	 3605	 0.006271	 0.02999	 0.0	 400.0	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 13	 0.011219	 0.05245	 0.0	 381.0	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	8509	 4352	 0.000281	 0.004091	 0.0	 572.0	 7704	 7704	 0.0	 0.0	 1	 -30.0	 30.0;
	2709	 3963	 0.00041	 0.00534	 0.0	 1678.0	 5898	 5898	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 8320	 0.002659	 0.01557	 0.0	 2000	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	8774	 54	 0.00795	 0.0483	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	6649	 3195	 0.00037	 0.00361	 0.0	 457.0	 8705	 8705	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 5292	 0.001211	 0.0082	 0.0	 591.0	 3811	 3811	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 3850	 9.9e-05	 0.00101	 0.0	 400.0	 31126	 31126	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 3480	 9.9e-05	 0.00099	 0.0	 31749	 31749	 31749	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 5192	 0.000169	 0.001539	 0.0	 495.0	 20402	 20402	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 3841	 0.000169	 0.00157	 0.0	 476.0	 20004	 20004	 0.0	 0.0	 1	 -30.0	 30.0;
	893	 1867	 0.00011	 0.000349	 0.0	 381.0	 86322	 86322	 0.0	 0.0	 1	 -30.0	 30.0;
	893	 1867	 0.00012	 0.000341	 0.0	 400.0	 87379	 87379	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 875	 0.00017	 0.00314	 0.0	 790.0	 10045	 10045	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 3540	 0.00012	 0.00056	 0.0	 55154	 55154	 55154	 0.0	 0.0	 1	 -30.0	 30.0;
	1688	 1561	 0.000219	 0.001469	 0.0	 476.0	 21268	 21268	 0.0	 0.0	 1	 -30.0	 30.0;
	1688	 1561	 0.0002	 0.001781	 0.0	 438.0	 17625	 17625	 0.0	 0.0	 1	 -30.0	 30.0;
	8588	 946	 0.00038	 0.00623	 0.0	 1645.0	 5061	 5061	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 7403	 0.003669	 0.01631	 0.0	 438.0	 1890	 1890	 0.0	 0.0	 1	 -30.0	 30.0;
	697	 5355	 0.00013	 0.00117	 0.0	 1744.0	 26833	 26833	 0.0	 0.0	 1	 -30.0	 30.0;
	8413	 5355	 0.00012	 0.0013	 0.0	 1415.0	 24196	 24196	 0.0	 0.0	 1	 -30.0	 30.0;
	7066	 3020	 0.00082	 0.004969	 0.0	 6273	 6273	 6273	 0.0	 0.0	 1	 -30.0	 30.0;
	7066	 3020	 0.0008	 0.004599	 0.0	 6767	 6767	 6767	 0.0	 0.0	 1	 -30.0	 30.0;
	1688	 7066	 0.00914	 0.060289	 0.0	 495.0	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 8036	 0.005219	 0.02681	 0.0	 1157	 1157	 1157	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 8036	 0.005919	 0.026271	 0.0	 1173	 1173	 1173	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 5839	 0.00381	 0.02086	 0.0	 419.0	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 7574	 0.004539	 0.01957	 0.0	 419.0	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 1236	 0.00112	 0.00632	 0.0	 400.0	 4922	 4922	 0.0	 0.0	 1	 -30.0	 30.0;
	6736	 4414	 0.00027	 0.00426	 0.0	 1777.0	 7401	 7401	 0.0	 0.0	 1	 -30.0	 30.0;
	9009	 4414	 0.0002	 0.00238	 0.0	 987.0	 13226	 13226	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 4414	 8e-05	 0.00077	 0.0	 1645.0	 40803	 40803	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 1209	 0.00149	 0.012091	 0.0	 591.0	 2593	 2593	 0.0	 0.0	 1	 -30.0	 30.0;
	9187	 4243	 0.00064	 0.00356	 0.0	 8733	 8733	 8733	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 1220	 0.005729	 0.033	 0.0	 572.0	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	9013	 6680	 0.0017	 0.007599	 0.0	 4057	 4057	 4057	 0.0	 0.0	 1	 -30.0	 30.0;
	8117	 6460	 0.00221	 0.02589	 0.0	 1216	 1216	 1216	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 191	 0.000331	 0.000831	 0.0	 35314	 35314	 35314	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 8275	 9.9e-05	 0.00045	 0.0	 68555	 68555	 68555	 0.0	 0.0	 1	 -30.0	 30.0;
	8634	 4243	 0.00039	 0.00163	 0.0	 476.0	 18847	 18847	 0.0	 0.0	 1	 -30.0	 30.0;
	8161	 5328	 0.00383	 0.04628	 0.0	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	6566	 7167	 0.00106	 0.01101	 0.0	 438.0	 2856	 2856	 0.0	 0.0	 1	 -30.0	 30.0;
	9115	 7306	 0.00131	 0.012659	 0.0	 495.0	 2482	 2482	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 5623	 0.00052	 0.00735	 0.0	 1415.0	 4287	 4287	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 2680	 0.00058	 0.0074	 0.0	 1086.0	 4256	 4256	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 2680	 0.0013	 0.01837	 0.0	 1251.0	 1716	 1716	 0.0	 0.0	 1	 -30.0	 30.0;
	4666	 7743	 3.9e-05	 0.000599	 0.0	 52623	 52623	 52623	 0.0	 0.0	 1	 -30.0	 30.0;
	1257	 7574	 0.00031	 0.001461	 0.0	 495.0	 21150	 21150	 0.0	 0.0	 1	 -30.0	 30.0;
	3228	 6963	 0.001151	 0.008771	 0.0	 476.0	 3571	 3571	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 4126	 0.00095	 0.00457	 0.0	 572.0	 6768	 6768	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 1303	 0.001419	 0.00982	 0.0	 438.0	 3184	 3184	 0.0	 0.0	 1	 -30.0	 30.0;
	8634	 6567	 0.00037	 0.00144	 0.0	 476.0	 21246	 21246	 0.0	 0.0	 1	 -30.0	 30.0;
	7306	 1308	 0.00143	 0.01225	 0.0	 629.0	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 7574	 0.00044	 0.00207	 0.0	 381.0	 14927	 14927	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 6460	 0.00076	 0.01509	 0.0	 1613.0	 2091	 2091	 0.0	 0.0	 1	 -30.0	 30.0;
	2317	 2909	 0.0007	 0.004039	 0.0	 7706	 7706	 7706	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 8681	 0.004419	 0.01918	 0.0	 400.0	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	6670	 4035	 0.006099	 0.029539	 0.0	 514.0	 1048	 1048	 0.0	 0.0	 1	 -30.0	 30.0;
	7622	 7362	 0.00106	 0.00513	 0.0	 6030	 6030	 6030	 0.0	 0.0	 1	 -30.0	 30.0;
	8785	 9233	 0.001021	 0.004711	 0.0	 572.0	 6553	 6553	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 4892	 0.000211	 0.00106	 0.0	 533.0	 29226	 29226	 0.0	 0.0	 1	 -30.0	 30.0;
	8125	 3977	 7e-05	 0.00087	 0.0	 36191	 36191	 36191	 0.0	 0.0	 1	 -30.0	 30.0;
	8125	 4892	 3.9e-05	 0.000651	 0.0	 48435	 48435	 48435	 0.0	 0.0	 1	 -30.0	 30.0;
	9233	 8132	 0.002039	 0.008271	 0.0	 3709	 3709	 3709	 0.0	 0.0	 1	 -30.0	 30.0;
	9233	 8132	 0.002	 0.00843	 0.0	 3646	 3646	 3646	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 7362	 0.001219	 0.00725	 0.0	 591.0	 4297	 4297	 0.0	 0.0	 1	 -30.0	 30.0;
	7362	 9233	 0.001151	 0.006789	 0.0	 514.0	 4588	 4588	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 7362	 0.0012	 0.006711	 0.0	 591.0	 4634	 4634	 0.0	 0.0	 1	 -30.0	 30.0;
	7362	 9233	 0.00112	 0.006289	 0.0	 553.0	 4945	 4945	 0.0	 0.0	 1	 -30.0	 30.0;
	7667	 7154	 0.002021	 0.01101	 0.0	 2822	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	7154	 4064	 0.0015	 0.008521	 0.0	 3651	 3651	 3651	 0.0	 0.0	 1	 -30.0	 30.0;
	7154	 4064	 0.001469	 0.00868	 0.0	 3589	 3589	 3589	 0.0	 0.0	 1	 -30.0	 30.0;
	9233	 3977	 0.000719	 0.00443	 0.0	 7039	 7039	 7039	 0.0	 0.0	 1	 -30.0	 30.0;
	9233	 4892	 0.0005	 0.00268	 0.0	 591.0	 11587	 11587	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 1932	 0.029149	 0.051802	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	5698	 1932	 0.035777	 0.063587	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 3089	 0.025967	 0.058702	 0.0	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	3089	 82	 0.01943	 0.043942	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	3089	 1874	 0.05776	 0.115802	 0.0	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	213	 3089	 0.027388	 0.054917	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	82	 1874	 0.028438	 0.104719	 0.0	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 5020	 0.008091	 0.03755	 0.0	 419.0	 823	 823	 0.0	 0.0	 1	 -30.0	 30.0;
	8496	 5020	 0.00556	 0.02913	 0.0	 438.0	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	7721	 213	 0.033512	 0.069909	 0.0	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	8496	 4810	 0.00587	 0.02949	 0.0	 400.0	 1051	 1051	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 5752	 0.013314	 0.040719	 0.0	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 5752	 0.01357	 0.039876	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 5752	 0.014579	 0.041157	 0.0	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 4270	 0.031298	 0.112364	 0.0	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 4270	 0.030653	 0.114521	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 3888	 0.00537	 0.04394	 0.0	 438.0	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 3888	 0.005461	 0.04726	 0.0	 438.0	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 246	 0.01312	 0.074419	 0.0	 419.0	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 6862	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	6862	 1997	 0.052702	 0.121281	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	9122	 3262	 0.00103	 0.01397	 0.0	 1152.0	 3150	 3150	 0.0	 0.0	 1	 -30.0	 30.0;
	4270	 1874	 0.002959	 0.014851	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	4270	 1874	 0.002769	 0.016339	 0.0	 1907	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	9122	 7674	 0.00167	 0.02105	 0.0	 1218.0	 2090	 2090	 0.0	 0.0	 1	 -30.0	 30.0;
	5698	 1874	 0.067826	 0.163702	 0.0	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	3618	 2417	 0.009463	 0.038388	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 2417	 0.021289	 0.124008	 0.0	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	5901	 5542	 0.035587	 0.104182	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	1182	 5542	 0.040678	 0.119107	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	7330	 8344	 0.00156	 0.01963	 0.0	 1283.0	 2241	 2241	 0.0	 0.0	 1	 -30.0	 30.0;
	7330	 3259	 0.00255	 0.02314	 0.0	 1415.0	 1896	 1896	 0.0	 0.0	 1	 -30.0	 30.0;
	7033	 8469	 0.01305	 0.035686	 0.0	 1269	 1269	 1269	 0.0	 0.0	 1	 -30.0	 30.0;
	7033	 8469	 0.013314	 0.034959	 0.0	 1289	 1289	 1289	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 8469	 0.005612	 0.022636	 0.0	 1355	 1355	 1355	 0.0	 0.0	 1	 -30.0	 30.0;
	64	 8469	 0.029826	 0.113909	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	6752	 8469	 0.04824	 0.109727	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	7033	 7533	 0.010802	 0.04124	 0.0	 1131	 1131	 1131	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 7033	 0.021851	 0.050934	 0.0	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 7033	 0.070223	 0.192198	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 7033	 0.071603	 0.188281	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 7533	 0.008339	 0.021066	 0.0	 1395	 1395	 1395	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 2048	 0.024744	 0.092099	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	2950	 3875	 0.029579	 0.114661	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	1182	 3875	 0.009298	 0.035488	 0.0	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 3875	 0.020149	 0.078107	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	3053	 5901	 0.017826	 0.063777	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 8344	 0.00158	 0.02095	 0.0	 1316.0	 2100	 2100	 0.0	 0.0	 1	 -30.0	 30.0;
	3146	 8344	 0.00076	 0.00957	 0.0	 1251.0	 4596	 4596	 0.0	 0.0	 1	 -30.0	 30.0;
	4760	 2950	 0.005678	 0.044198	 0.0	 709	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	4760	 2950	 0.006438	 0.043314	 0.0	 722	 722	 722	 0.0	 0.0	 1	 -30.0	 30.0;
	6500	 2950	 0.013612	 0.043157	 0.0	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 2950	 0.056248	 0.147934	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 2950	 0.057339	 0.144851	 0.0	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	8464	 2950	 0.000463	 0.003603	 0.0	 238.0	 8696	 8696	 0.0	 0.0	 1	 -30.0	 30.0;
	2950	 7557	 0.037107	 0.138157	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4760	 8119	 0.004058	 0.015107	 0.0	 2020	 2020	 2020	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 1283	 0.011793	 0.034521	 0.0	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 1283	 0.019636	 0.073132	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	4309	 1736	 0.0	 0.000413	 0.0	 248.0	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	3618	 917	 0.014339	 0.041983	 0.0	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 917	 0.029314	 0.118281	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	8495	 2727	 0.016636	 0.064488	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	6392	 2727	 0.034273	 0.127612	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	2727	 5251	 0.00886	 0.02495	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	8495	 6483	 0.026587	 0.084364	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	6392	 4559	 0.039298	 0.115058	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	6392	 6573	 0.036066	 0.134289	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	6392	 1696	 0.000529	 0.001554	 0.0	 19243	 19243	 19243	 0.0	 0.0	 1	 -30.0	 30.0;
	64	 6500	 0.03981	 0.160628	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	8119	 6500	 0.008438	 0.025744	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	6500	 3796	 0.024223	 0.093876	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	6483	 4705	 0.019868	 0.054017	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	6752	 4705	 0.051248	 0.121347	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 5561	 0.042793	 0.101314	 0.0	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 5561	 0.030091	 0.099372	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	2280	 5561	 0.005488	 0.020959	 0.0	 1458	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	2062	 5036	 0.009198	 0.025851	 0.0	 1152	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	5036	 6122	 0.019752	 0.057843	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 5036	 0.032934	 0.096413	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	6721	 8513	 0.05586	 0.112686	 0.0	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	8767	 8513	 0.029744	 0.057636	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	3575	 6721	 0.004868	 0.013686	 0.0	 2175	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	418	 6721	 0.005413	 0.015207	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 6721	 0.043669	 0.084653	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	418	 3575	 0.004818	 0.01724	 0.0	 1765	 1765	 1765	 0.0	 0.0	 1	 -30.0	 30.0;
	48	 3575	 0.017719	 0.054017	 0.0	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 3897	 0.004364	 0.017719	 0.0	 1731	 1731	 1731	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 1710	 0.007463	 0.041727	 0.0	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	2062	 4559	 0.016289	 0.065711	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	2280	 3053	 0.02014	 0.072066	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 8453	 0.003091	 0.011826	 0.0	 2585	 2585	 2585	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 8453	 0.00386	 0.013793	 0.0	 2206	 2206	 2206	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 3014	 0.036	 0.114223	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 3516	 0.027942	 0.081793	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 4694	 0.027008	 0.061041	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	7272	 4694	 0.025504	 0.072198	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 6483	 0.01686	 0.060331	 0.0	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	7648	 1710	 0.010091	 0.038529	 0.0	 794	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	7272	 7648	 0.027099	 0.082603	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	4703	 5524	 0.014463	 0.051719	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 5251	 0.014612	 0.041066	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	1830	 64	 0.001661	 0.006446	 0.0	 4746	 4746	 4746	 0.0	 0.0	 1	 -30.0	 30.0;
	7286	 64	 0.005198	 0.019331	 0.0	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	6784	 1830	 0.003512	 0.011587	 0.0	 2609	 2609	 2609	 0.0	 0.0	 1	 -30.0	 30.0;
	6784	 7286	 0.004339	 0.015512	 0.0	 1962	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 8767	 0.043628	 0.081231	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 1182	 0.031661	 0.092669	 0.0	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 48	 0.017562	 0.070818	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 4559	 0.008843	 0.033802	 0.0	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	6860	 8859	 0.01164	 0.05205	 0.0	 400.0	 593	 593	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 6573	 0.007934	 0.042653	 0.0	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	8967	 6573	 0.00343	 0.014488	 0.0	 2122	 2122	 2122	 0.0	 0.0	 1	 -30.0	 30.0;
	121	 6573	 0.004339	 0.022421	 0.0	 1384	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 4309	 0.00143	 0.007149	 0.0	 4333	 4333	 4333	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 4309	 0.001446	 0.007	 0.0	 4420	 4420	 4420	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 4309	 0.001504	 0.007256	 0.0	 4263	 4263	 4263	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 4309	 0.001529	 0.007099	 0.0	 4350	 4350	 4350	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 2073	 0.015653	 0.051669	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 3259	 0.00046	 0.00424	 0.0	 1251.0	 10345	 10345	 0.0	 0.0	 1	 -30.0	 30.0;
	3618	 5251	 0.049339	 0.138727	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 5593	 0.005421	 0.017876	 0.0	 1691	 1691	 1691	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 2717	 0.001678	 0.006421	 0.0	 4760	 4760	 4760	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 7557	 0.024512	 0.055752	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 1696	 0.019347	 0.072058	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	4703	 3882	 0.002364	 0.008777	 0.0	 3476	 3476	 3476	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 5251	 0.032331	 0.102537	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	121	 8967	 0.00305	 0.017711	 0.0	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 7272	 0.005289	 0.009463	 0.0	 2914	 2914	 2914	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 8425	 0.00181	 0.007298	 0.0	 4201	 4201	 4201	 0.0	 0.0	 1	 -30.0	 30.0;
	8425	 7272	 0.000893	 0.00338	 0.0	 9036	 9036	 9036	 0.0	 0.0	 1	 -30.0	 30.0;
	3796	 8425	 0.012033	 0.046579	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	6000	 1689	 0.00017	 0.01734	 0.0	 1185.0	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	4192	 8230	 0.00017	 0.01767	 0.0	 1086.0	 1788	 1788	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 2030	 0.0006	 0.040218	 0.0	 637.0	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	8832	 2180	 0.00076	 0.002409	 0.0	 12505	 12505	 12505	 0.0	 0.0	 1	 -30.0	 30.0;
	8832	 3771	 0.0	 0.000538	 0.0	 58713	 58713	 58713	 0.0	 0.0	 1	 -30.0	 30.0;
	6395	 1564	 0.00528	 0.027569	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	6395	 1564	 0.005382	 0.026978	 0.0	 1149	 1149	 1149	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 6395	 0.00104	 0.009649	 0.0	 3255	 3255	 3255	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 6395	 0.001062	 0.009449	 0.0	 273.0	 3323	 3323	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 5247	 0.000289	 0.000889	 0.0	 33791	 33791	 33791	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 5247	 0.003502	 0.01524	 0.0	 2021	 2021	 2021	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 7958	 0.000289	 0.00088	 0.0	 34103	 34103	 34103	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 7958	 0.003431	 0.014111	 0.0	 2176	 2176	 2176	 0.0	 0.0	 1	 -30.0	 30.0;
	8389	 5526	 0.001502	 0.1272	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 722	 8e-05	 0.000729	 0.0	 312.0	 43072	 43072	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 722	 0.003818	 0.012911	 0.0	 2347	 2347	 2347	 0.0	 0.0	 1	 -30.0	 30.0;
	9083	 722	 0.001618	 0.013711	 0.0	 2288	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 1870	 0.001062	 0.007791	 0.0	 4018	 4018	 4018	 0.0	 0.0	 1	 -30.0	 30.0;
	6539	 1870	 0.001809	 0.008951	 0.0	 3459	 3459	 3459	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 1870	 0.007142	 0.020311	 0.0	 1468	 1468	 1468	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 8356	 0.000942	 0.008831	 0.0	 3557	 3557	 3557	 0.0	 0.0	 1	 -30.0	 30.0;
	6539	 8356	 0.001769	 0.008289	 0.0	 3727	 3727	 3727	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 8356	 0.00728	 0.019898	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	8828	 5740	 0.003569	 0.017951	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	3443	 8828	 0.001991	 0.007271	 0.0	 4191	 4191	 4191	 0.0	 0.0	 1	 -30.0	 30.0;
	7701	 8828	 0.000391	 0.001462	 0.0	 20873	 20873	 20873	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 8167	 0.003502	 0.018289	 0.0	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	244	 2619	 0.001769	 0.00824	 0.0	 3749	 3749	 3749	 0.0	 0.0	 1	 -30.0	 30.0;
	7701	 2619	 0.0004	 0.001431	 0.0	 21259	 21259	 21259	 0.0	 0.0	 1	 -30.0	 30.0;
	1810	 4740	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 7525	 0.001471	 0.1296	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2180	 7374	 0.00056	 0.015018	 0.0	 2102	 2102	 2102	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 8490	 0.000631	 0.01472	 0.0	 2144	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 2180	 0.0	 0.001169	 0.0	 27021	 27021	 27021	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 7596	 0.000942	 0.003342	 0.0	 9098	 9098	 9098	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 2708	 0.001582	 0.002831	 0.0	 9741	 9741	 9741	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 7059	 0.0008	 0.003422	 0.0	 8989	 8989	 8989	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 7059	 0.000822	 0.003351	 0.0	 9155	 9155	 9155	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 2708	 0.002631	 0.004889	 0.0	 5690	 5690	 5690	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 2305	 0.005418	 0.022489	 0.0	 1366	 1366	 1366	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 2305	 0.00552	 0.022018	 0.0	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 7575	 0.004091	 0.020893	 0.0	 1484	 1484	 1484	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 7575	 0.004	 0.019339	 0.0	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 4415	 0.016479	 0.037058	 0.0	 779	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 4686	 0.016347	 0.05124	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 7575	 0.007058	 0.030587	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 7575	 0.007149	 0.029934	 0.0	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	6823	 6202	 0.002089	 0.003449	 0.0	 7834	 7834	 7834	 0.0	 0.0	 1	 -30.0	 30.0;
	6823	 6202	 0.002129	 0.003378	 0.0	 7911	 7911	 7911	 0.0	 0.0	 1	 -30.0	 30.0;
	2330	 712	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 4272	 0.007489	 0.0516	 0.0	 606	 606	 606	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 4272	 0.008489	 0.050569	 0.0	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	878	 3206	 0.0	 0.047951	 0.0	 659	 659	 659	 0.0	 0.0	 1	 -30.0	 30.0;
	7090	 3206	 0.001649	 0.016591	 0.0	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	7844	 3206	 0.001618	 0.016898	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 6202	 0.006871	 0.039911	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 6202	 0.007009	 0.039089	 0.0	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 3182	 0.001658	 0.011871	 0.0	 2636	 2636	 2636	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 3182	 0.001631	 0.010991	 0.0	 2843	 2843	 2843	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 9120	 0.00092	 0.004689	 0.0	 6611	 6611	 6611	 0.0	 0.0	 1	 -30.0	 30.0;
	133	 9120	 0.002049	 0.0038	 0.0	 7317	 7317	 7317	 0.0	 0.0	 1	 -30.0	 30.0;
	6323	 9120	 0.005649	 0.026	 0.0	 1188	 1188	 1188	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 3047	 0.000902	 0.004782	 0.0	 6492	 6492	 6492	 0.0	 0.0	 1	 -30.0	 30.0;
	275	 3047	 0.003471	 0.014471	 0.0	 2123	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	133	 3047	 0.002089	 0.00372	 0.0	 7404	 7404	 7404	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 1880	 0.003569	 0.010671	 0.0	 2808	 2808	 2808	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 4188	 0.019782	 0.061658	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 5740	 0.000409	 0.0014	 0.0	 21658	 21658	 21658	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 539	 0.003302	 0.017311	 0.0	 1793	 1793	 1793	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 8167	 0.000409	 0.001369	 0.0	 22108	 22108	 22108	 0.0	 0.0	 1	 -30.0	 30.0;
	8167	 539	 0.003231	 0.016031	 0.0	 1932	 1932	 1932	 0.0	 0.0	 1	 -30.0	 30.0;
	9094	 8463	 0.000751	 0.005711	 0.0	 5484	 5484	 5484	 0.0	 0.0	 1	 -30.0	 30.0;
	9094	 8994	 0.0018	 0.00716	 0.0	 299.0	 4279	 4279	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 9094	 0.001978	 0.013462	 0.0	 2322	 2322	 2322	 0.0	 0.0	 1	 -30.0	 30.0;
	9094	 1936	 0.001502	 0.0056	 0.0	 5449	 5449	 5449	 0.0	 0.0	 1	 -30.0	 30.0;
	3280	 6423	 0.005991	 0.0284	 0.0	 1089	 1089	 1089	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 6423	 0.000302	 0.000858	 0.0	 34727	 34727	 34727	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 6423	 0.002622	 0.013231	 0.0	 2342	 2342	 2342	 0.0	 0.0	 1	 -30.0	 30.0;
	7138	 5618	 0.004271	 0.019502	 0.0	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 5618	 0.000271	 0.000969	 0.0	 31394	 31394	 31394	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 5618	 0.00356	 0.014378	 0.0	 2133	 2133	 2133	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 3456	 0.0022	 0.009569	 0.0	 3218	 3218	 3218	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 3456	 0.000311	 0.001169	 0.0	 26113	 26113	 26113	 0.0	 0.0	 1	 -30.0	 30.0;
	3301	 3456	 0.001889	 0.006311	 0.0	 4795	 4795	 4795	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 3280	 0.000271	 0.00132	 0.0	 23441	 23441	 23441	 0.0	 0.0	 1	 -30.0	 30.0;
	3301	 3280	 0.001929	 0.006178	 0.0	 260.0	 4881	 4881	 0.0	 0.0	 1	 -30.0	 30.0;
	790	 6600	 0.000339	 0.001149	 0.0	 26368	 26368	 26368	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 8889	 0.002591	 0.014418	 0.0	 2157	 2157	 2157	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 775	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6356	 3443	 0.0014	 0.00652	 0.0	 4737	 4737	 4737	 0.0	 0.0	 1	 -30.0	 30.0;
	8164	 3443	 0.000418	 0.001338	 0.0	 22534	 22534	 22534	 0.0	 0.0	 1	 -30.0	 30.0;
	6356	 244	 0.001369	 0.006649	 0.0	 4654	 4654	 4654	 0.0	 0.0	 1	 -30.0	 30.0;
	8164	 244	 0.000369	 0.00152	 0.0	 20195	 20195	 20195	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5320	 0.004689	 0.018151	 0.0	 1685	 1685	 1685	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5320	 0.004591	 0.018498	 0.0	 1658	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 143	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 3974	 0.003698	 0.0198	 0.0	 1569	 1569	 1569	 0.0	 0.0	 1	 -30.0	 30.0;
	8016	 1255	 0.005471	 0.0206	 0.0	 1482	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	8016	 1255	 0.0062	 0.020191	 0.0	 1496	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 4362	 0.006098	 0.030551	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 5792	 0.004809	 0.019751	 0.0	 1554	 1554	 1554	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 5792	 0.004711	 0.018289	 0.0	 260.0	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 6045	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 7138	 0.007929	 0.044022	 0.0	 707	 707	 707	 0.0	 0.0	 1	 -30.0	 30.0;
	6057	 1352	 0.009782	 0.033938	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	6057	 6559	 0.003609	 0.016889	 0.0	 1829	 1829	 1829	 0.0	 0.0	 1	 -30.0	 30.0;
	656	 1392	 0.00044	 0.027591	 0.0	 1145	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	6835	 3538	 0.000419	 0.027979	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	351	 3538	 0.000409	 0.02851	 0.0	 1108	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 3538	 0.0	 0.000461	 0.0	 68520	 68520	 68520	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 2824	 0.000531	 0.005581	 0.0	 5635	 5635	 5635	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 1392	 0.003841	 0.022461	 0.0	 476.0	 1387	 1387	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 140	 0.000539	 0.005461	 0.0	 400.0	 5757	 5757	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 3538	 0.00376	 0.022901	 0.0	 457.0	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 8862	 0.028843	 0.060992	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 8862	 0.029397	 0.059744	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	1810	 6342	 0.001727	 0.00924	 0.0	 3361	 3361	 3361	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 1810	 0.004851	 0.02724	 0.0	 1142	 1142	 1142	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 6559	 0.0138	 0.040249	 0.0	 260.0	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 643	 0.007098	 0.022329	 0.0	 1349	 1349	 1349	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 1836	 0.001902	 0.008391	 0.0	 3672	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 1836	 0.001929	 0.008209	 0.0	 3746	 3746	 3746	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 1352	 0.001649	 0.01228	 0.0	 2550	 2550	 2550	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 1352	 0.001471	 0.01392	 0.0	 2257	 2257	 2257	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 7628	 0.000582	 0.040991	 0.0	 299.0	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 311	 0.01116	 0.033671	 0.0	 286.0	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 2482	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 8249	 0.00031	 0.00312	 0.0	 1251.0	 10075	 10075	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 8249	 0.00069	 0.00769	 0.0	 1810.0	 4092	 4092	 0.0	 0.0	 1	 -30.0	 30.0;
	6139	 5450	 0.010471	 0.029289	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	6139	 5450	 0.010671	 0.028671	 0.0	 1033	 1033	 1033	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 6139	 0.00624	 0.021871	 0.0	 299.0	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 6139	 0.007071	 0.021431	 0.0	 299.0	 1400	 1400	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 7751	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 6559	 0.001062	 0.003351	 0.0	 8986	 8986	 8986	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 5342	 0.002111	 0.02008	 0.0	 1565	 1565	 1565	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 6399	 0.001009	 0.010929	 0.0	 2878	 2878	 2878	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 8881	 0.004711	 0.050609	 0.0	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 9083	 0.011462	 0.02396	 0.0	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 2350	 0.0	 0.0444	 0.0	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1123	 0.001698	 0.1128	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1633	 8.9e-05	 0.000742	 0.0	 42268	 42268	 42268	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1633	 8.9e-05	 0.000729	 0.0	 43011	 43011	 43011	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 2812	 0.000302	 0.000809	 0.0	 36580	 36580	 36580	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 9029	 0.001502	 0.002182	 0.0	 11925	 11925	 11925	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 6149	 0.001311	 0.001871	 0.0	 13827	 13827	 13827	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 6149	 0.001369	 0.00204	 0.0	 12858	 12858	 12858	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 4616	 0.001049	 0.00308	 0.0	 273.0	 9709	 9709	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 5893	 0.014967	 0.09105	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 5893	 0.028959	 0.12905	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 5893	 0.006438	 0.041256	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 5893	 0.006554	 0.040364	 0.0	 773	 773	 773	 0.0	 0.0	 1	 -30.0	 30.0;
	2350	 1260	 0.0	 0.012742	 0.0	 2479	 2479	 2479	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 8463	 0.001018	 0.00868	 0.0	 3615	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 8994	 0.001871	 0.00548	 0.0	 5455	 5455	 5455	 0.0	 0.0	 1	 -30.0	 30.0;
	8994	 7476	 0.00228	 0.004338	 0.0	 6446	 6446	 6446	 0.0	 0.0	 1	 -30.0	 30.0;
	8994	 7476	 0.00224	 0.004431	 0.0	 6362	 6362	 6362	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 806	 0.00076	 0.00747	 0.0	 1678.0	 4207	 4207	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 806	 0.00103	 0.01061	 0.0	 1481.0	 2964	 2964	 0.0	 0.0	 1	 -30.0	 30.0;
	2240	 8991	 0.002689	 0.013818	 0.0	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	539	 2240	 0.002111	 0.003769	 0.0	 7313	 7313	 7313	 0.0	 0.0	 1	 -30.0	 30.0;
	539	 2240	 0.002151	 0.003689	 0.0	 273.0	 7397	 7397	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5426	 0.00176	 0.012702	 0.0	 2464	 2464	 2464	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5426	 0.001729	 0.012951	 0.0	 2418	 2418	 2418	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1046	 0.000151	 0.000511	 0.0	 59281	 59281	 59281	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1046	 0.000151	 0.000502	 0.0	 260.0	 60257	 60257	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1836	 0.01076	 0.05508	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1836	 0.010542	 0.05616	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 6824	 0.003089	 0.009	 0.0	 3320	 3320	 3320	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 6824	 0.003031	 0.009169	 0.0	 3271	 3271	 3271	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 6275	 0.001849	 0.00872	 0.0	 3544	 3544	 3544	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 6275	 0.00188	 0.008538	 0.0	 3614	 3614	 3614	 0.0	 0.0	 1	 -30.0	 30.0;
	2974	 3301	 0.004151	 0.01556	 0.0	 1962	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 2974	 0.006591	 0.026778	 0.0	 299.0	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 8875	 0.00056	 0.038671	 0.0	 507.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	1747	 593	 0.0	 0.00045	 0.0	 757.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	593	 8230	 0.00162	 0.01968	 0.0	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 8772	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 6356	 0.002649	 0.015111	 0.0	 2059	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 6356	 0.002702	 0.014809	 0.0	 2099	 2099	 2099	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 5031	 0.0008	 0.005711	 0.0	 5478	 5478	 5478	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 5031	 0.000782	 0.005809	 0.0	 5390	 5390	 5390	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 3299	 0.001049	 0.007738	 0.0	 286.0	 4046	 4046	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 3299	 0.001071	 0.007569	 0.0	 299.0	 4133	 4133	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 3119	 0.005138	 0.025338	 0.0	 1222	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 3119	 0.005031	 0.025831	 0.0	 1201	 1201	 1201	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 1464	 0.003658	 0.029071	 0.0	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 1464	 0.004151	 0.028489	 0.0	 1098	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 1350	 0.001471	 0.011471	 0.0	 2732	 2732	 2732	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 1350	 0.001502	 0.011218	 0.0	 2791	 2791	 2791	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 1350	 0.001871	 0.014511	 0.0	 2159	 2159	 2159	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 1350	 0.001902	 0.0142	 0.0	 2205	 2205	 2205	 0.0	 0.0	 1	 -30.0	 30.0;
	199	 7195	 0.000351	 0.004662	 0.0	 6757	 6757	 6757	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 199	 0.00772	 0.033818	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 8432	 0.0	 0.00051	 0.0	 1909.0	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	8432	 3190	 0.00076	 0.0119	 0.0	 790.0	 2650	 2650	 0.0	 0.0	 1	 -30.0	 30.0;
	8432	 3352	 0.00025	 0.00316	 0.0	 1580.0	 9965	 9965	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 3484	 0.00077	 0.01164	 0.0	 823.0	 2708	 2708	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 6766	 0.00025	 0.00322	 0.0	 1481.0	 9781	 9781	 0.0	 0.0	 1	 -30.0	 30.0;
	838	 6295	 0.001369	 0.021182	 0.0	 494.0	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	3190	 3484	 0.0	 0.00052	 0.0	 757.0	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	3190	 6263	 0.00015	 0.00328	 0.0	 790.0	 9621	 9621	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 3190	 0.00016	 0.00314	 0.0	 1349.0	 10047	 10047	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 6068	 0.00017	 0.00321	 0.0	 987.0	 9827	 9827	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 3484	 0.00018	 0.00308	 0.0	 954.0	 10239	 10239	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 4021	 0.00024	 0.01948	 0.0	 757.0	 1622	 1622	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 7425	 0.000631	 0.037902	 0.0	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 5772	 0.00244	 0.01532	 0.0	 2037	 2037	 2037	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 8086	 0.0	 0.00053	 0.0	 757.0	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 6068	 0.00013	 0.00282	 0.0	 987.0	 11190	 11190	 0.0	 0.0	 1	 -30.0	 30.0;
	4077	 281	 0.00038	 0.00708	 0.0	 1218.0	 4456	 4456	 0.0	 0.0	 1	 -30.0	 30.0;
	8086	 6263	 0.00013	 0.00261	 0.0	 1086.0	 12088	 12088	 0.0	 0.0	 1	 -30.0	 30.0;
	5888	 8086	 0.00038	 0.00722	 0.0	 1448.0	 4369	 4369	 0.0	 0.0	 1	 -30.0	 30.0;
	1477	 5255	 0.00016	 0.002769	 0.0	 11389	 11389	 11389	 0.0	 0.0	 1	 -30.0	 30.0;
	3960	 5255	 0.00016	 0.00272	 0.0	 299.0	 11593	 11593	 0.0	 0.0	 1	 -30.0	 30.0;
	8037	 5255	 0.00016	 0.002662	 0.0	 299.0	 11845	 11845	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 1597	 0.024479	 0.081727	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	6923	 1597	 0.024248	 0.064893	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	676	 8706	 0.0084	 0.04056	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	8706	 205	 0.003809	 0.0248	 0.0	 1259	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	8706	 4362	 0.002542	 0.014569	 0.0	 2136	 2136	 2136	 0.0	 0.0	 1	 -30.0	 30.0;
	8706	 4362	 0.002591	 0.01428	 0.0	 2177	 2177	 2177	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 7736	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 5591	 0.003071	 0.01636	 0.0	 1898	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 5364	 0.003889	 0.027022	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 7584	 0.00624	 0.036009	 0.0	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 7584	 0.00636	 0.035258	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 2796	 0.000982	 0.001529	 0.0	 17383	 17383	 17383	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 2796	 0.000991	 0.001502	 0.0	 17554	 17554	 17554	 0.0	 0.0	 1	 -30.0	 30.0;
	8642	 5255	 0.00052	 0.004991	 0.0	 260.0	 6295	 6295	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 2703	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	650	 4104	 0.012182	 0.034826	 0.0	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 650	 0.025744	 0.059	 0.0	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 1635	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6167	 4130	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6167	 5872	 0.003129	 0.015031	 0.0	 2058	 2058	 2058	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 496	 0.00228	 0.019871	 0.0	 1580	 1580	 1580	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 5872	 0.002791	 0.017031	 0.0	 1831	 1831	 1831	 0.0	 0.0	 1	 -30.0	 30.0;
	6582	 3462	 0.001431	 0.01252	 0.0	 2507	 2507	 2507	 0.0	 0.0	 1	 -30.0	 30.0;
	6582	 4082	 0.001649	 0.007631	 0.0	 4046	 4046	 4046	 0.0	 0.0	 1	 -30.0	 30.0;
	6582	 5246	 0.001471	 0.008649	 0.0	 3601	 3601	 3601	 0.0	 0.0	 1	 -30.0	 30.0;
	496	 5872	 0.00656	 0.009071	 0.0	 260.0	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 3664	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 9063	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 8044	 0.000521	 0.001529	 0.0	 391.0	 19555	 19555	 0.0	 0.0	 1	 -30.0	 30.0;
	76	 5742	 0.000219	 0.00095	 0.0	 438.0	 32401	 32401	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 5742	 0.000219	 0.00088	 0.0	 533.0	 34833	 34833	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 9118	 0.002391	 0.015618	 0.0	 2000	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 919	 0.0	 0.00054	 0.0	 1448.0	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 5008	 0.00079	 0.01037	 0.0	 1678.0	 3038	 3038	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 5008	 0.00022	 0.00296	 0.0	 1645.0	 10643	 10643	 0.0	 0.0	 1	 -30.0	 30.0;
	8604	 919	 0.00077	 0.01056	 0.0	 1810.0	 2984	 2984	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 4295	 0.000649	 0.03712	 0.0	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 5203	 0.003302	 0.019138	 0.0	 1627	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 5203	 0.003369	 0.018742	 0.0	 1659	 1659	 1659	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 472	 0.001769	 0.018222	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 7476	 0.000858	 0.006809	 0.0	 4603	 4603	 4603	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 7476	 0.000969	 0.006671	 0.0	 4686	 4686	 4686	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 8792	 0.005551	 0.03908	 0.0	 801	 801	 801	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 8792	 0.005431	 0.039822	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 8792	 0.005311	 0.036871	 0.0	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 1094	 0.002169	 0.016271	 0.0	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 1094	 0.007418	 0.07832	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 3023	 0.0	 0.0005	 0.0	 757.0	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 6345	 0.0	 0.00049	 0.0	 757.0	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 8114	 0.00079	 0.00848	 0.0	 1580.0	 3709	 3709	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 3210	 0.00183	 0.0174	 0.0	 1415.0	 1806	 1806	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 6345	 0.0	 0.00048	 0.0	 757.0	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 8773	 0.0008	 0.0083	 0.0	 1678.0	 3789	 3789	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 71	 0.004449	 0.02404	 0.0	 1293	 1293	 1293	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 71	 0.004529	 0.023551	 0.0	 1318	 1318	 1318	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 6202	 0.006791	 0.013271	 0.0	 260.0	 2119	 2119	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 1106	 0.00424	 0.030378	 0.0	 1030	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 1106	 0.004151	 0.028129	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 7305	 0.002311	 0.003622	 0.0	 7352	 7352	 7352	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 7305	 0.002062	 0.004102	 0.0	 6881	 6881	 6881	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 6987	 0.00452	 0.029609	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 6987	 0.004422	 0.030169	 0.0	 1036	 1036	 1036	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 4774	 0.00416	 0.023058	 0.0	 1349	 1349	 1349	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 3620	 0.002831	 0.020742	 0.0	 273.0	 1509	 1509	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 1722	 0.002338	 0.01592	 0.0	 1964	 1964	 1964	 0.0	 0.0	 1	 -30.0	 30.0;
	585	 3148	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 585	 0.004969	 0.03636	 0.0	 861	 861	 861	 0.0	 0.0	 1	 -30.0	 30.0;
	6987	 585	 0.003431	 0.015698	 0.0	 1966	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	7275	 585	 0.00456	 0.027582	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 8773	 0.0	 0.00047	 0.0	 757.0	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	8393	 8114	 0.00093	 0.01185	 0.0	 1810.0	 2658	 2658	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 8773	 0.00091	 0.01207	 0.0	 1810.0	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	676	 6439	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 676	 0.000529	 0.003151	 0.0	 9887	 9887	 9887	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 676	 0.00052	 0.003209	 0.0	 9717	 9717	 9717	 0.0	 0.0	 1	 -30.0	 30.0;
	676	 205	 0.00352	 0.020578	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	8862	 6915	 0.039182	 0.089413	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	8862	 9205	 0.033686	 0.067124	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	6393	 4057	 0.044992	 0.093174	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 6393	 0.013678	 0.052479	 0.0	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	4872	 6393	 0.005686	 0.022893	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	6393	 7136	 0.034281	 0.094653	 0.0	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2769	 6118	 0.0	 0.00045	 0.0	 70195	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	76	 2769	 0.00032	 0.001469	 0.0	 438.0	 21010	 21010	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 6118	 0.000289	 0.001039	 0.0	 457.0	 29290	 29290	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 7117	 0.00324	 0.017628	 0.0	 1763	 1763	 1763	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 8525	 0.002678	 0.019298	 0.0	 1622	 1622	 1622	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 5346	 0.000529	 0.001504	 0.0	 19813	 19813	 19813	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 3335	 0.00042	 0.0261	 0.0	 757.0	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	6832	 4797	 0.00043	 0.02555	 0.0	 757.0	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	6489	 4797	 0.00044	 0.02499	 0.0	 757.0	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	8284	 4797	 0.00039	 0.02833	 0.0	 757.0	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	577	 1362	 0.00019	 0.01594	 0.0	 1982	 1982	 1982	 0.0	 0.0	 1	 -30.0	 30.0;
	268	 1057	 0.000419	 0.026099	 0.0	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 5979	 0.00043	 0.02555	 0.0	 1237	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	8662	 8298	 0.00038	 0.02888	 0.0	 757.0	 1094	 1094	 0.0	 0.0	 1	 -30.0	 30.0;
	6884	 4059	 0.00038	 0.02944	 0.0	 757.0	 1073	 1073	 0.0	 0.0	 1	 -30.0	 30.0;
	3723	 3335	 0.00037	 0.02999	 0.0	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	1890	 3335	 0.00036	 0.02777	 0.0	 1138	 1138	 1138	 0.0	 0.0	 1	 -30.0	 30.0;
	71	 8141	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	7295	 71	 0.003951	 0.02048	 0.0	 1515	 1515	 1515	 0.0	 0.0	 1	 -30.0	 30.0;
	71	 7297	 0.003858	 0.020871	 0.0	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 8298	 0.0	 0.00046	 0.0	 757.0	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 4059	 0.0	 0.00045	 0.0	 757.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 7388	 0.0	 0.00051	 0.0	 823.0	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 2002	 0.0	 0.00052	 0.0	 823.0	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 5979	 0.0	 0.00051	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 1057	 0.0	 0.000521	 0.0	 60629	 60629	 60629	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 6282	 0.0	 0.000531	 0.0	 381.0	 59487	 59487	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 4340	 0.0	 0.000539	 0.0	 58604	 58604	 58604	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 8298	 0.0	 0.00053	 0.0	 1415.0	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 4059	 0.0	 0.00054	 0.0	 954.0	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 7388	 0.0	 0.0005	 0.0	 1119.0	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 2002	 0.0	 0.00049	 0.0	 921.0	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	326	 5979	 0.0	 0.0005	 0.0	 63175	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	326	 1057	 0.0	 0.00049	 0.0	 64464	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	326	 6282	 0.0	 0.000479	 0.0	 65945	 65945	 65945	 0.0	 0.0	 1	 -30.0	 30.0;
	326	 4340	 0.0	 0.000469	 0.0	 67351	 67351	 67351	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 8298	 0.00043	 0.00544	 0.0	 1580.0	 5789	 5789	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 5979	 0.0	 0.000461	 0.0	 476.0	 68520	 68520	 0.0	 0.0	 1	 -30.0	 30.0;
	1057	 1362	 0.0	 0.00045	 0.0	 457.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 7388	 0.00038	 0.00616	 0.0	 1448.0	 5119	 5119	 0.0	 0.0	 1	 -30.0	 30.0;
	5299	 2002	 0.00041	 0.02721	 0.0	 1086.0	 1161	 1161	 0.0	 0.0	 1	 -30.0	 30.0;
	4340	 1052	 0.002081	 0.023	 0.0	 533.0	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	6662	 838	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 2722	 0.0	 0.00048	 0.0	 1514.0	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 1689	 0.0011	 0.01189	 0.0	 1810.0	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 3210	 0.00084	 0.00906	 0.0	 1020.0	 3472	 3472	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 1689	 0.00112	 0.01165	 0.0	 1876.0	 2699	 2699	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 8230	 0.00115	 0.0114	 0.0	 1744.0	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 5674	 0.00086	 0.00887	 0.0	 1283.0	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 7195	 0.00116	 0.00912	 0.0	 260.0	 3436	 3436	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 7195	 0.001129	 0.009298	 0.0	 3373	 3373	 3373	 0.0	 0.0	 1	 -30.0	 30.0;
	7195	 8977	 0.000609	 0.005058	 0.0	 6201	 6201	 6201	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 7195	 0.008009	 0.04	 0.0	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	7195	 3868	 0.002289	 0.016218	 0.0	 1929	 1929	 1929	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 392	 0.003098	 0.032729	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 3530	 0.002982	 0.013058	 0.0	 2359	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 3530	 0.00304	 0.0128	 0.0	 2401	 2401	 2401	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 5829	 0.008791	 0.059622	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	8977	 6539	 0.000511	 0.004409	 0.0	 7117	 7117	 7117	 0.0	 0.0	 1	 -30.0	 30.0;
	7675	 6539	 0.009391	 0.030809	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	7675	 6539	 0.009191	 0.031391	 0.0	 260.0	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	1702	 2900	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 1702	 0.00276	 0.014782	 0.0	 2101	 2101	 2101	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 1702	 0.002809	 0.014458	 0.0	 2145	 2145	 2145	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 1702	 0.003138	 0.017502	 0.0	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 1702	 0.0032	 0.017138	 0.0	 1812	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	5916	 6342	 0.002033	 0.005273	 0.0	 5590	 5590	 5590	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 6342	 0.036066	 0.160107	 0.0	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	733	 8917	 0.027686	 0.04614	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 8917	 0.025107	 0.051372	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 548	 0.002479	 0.01086	 0.0	 2836	 2836	 2836	 0.0	 0.0	 1	 -30.0	 30.0;
	548	 6923	 0.013603	 0.051876	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 8508	 0.00176	 0.108	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	1591	 5558	 0.0	 0.00047	 0.0	 987.0	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	1591	 8604	 0.00038	 0.00366	 0.0	 1744.0	 8585	 8585	 0.0	 0.0	 1	 -30.0	 30.0;
	1591	 8264	 0.00052	 0.00633	 0.0	 1909.0	 4974	 4974	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 8510	 0.0	 0.00051	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 3257	 0.001599	 0.015599	 0.0	 2015	 2015	 2015	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 1124	 0.00212	 0.022349	 0.0	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 1788	 0.00034	 0.00415	 0.0	 1645.0	 7586	 7586	 0.0	 0.0	 1	 -30.0	 30.0;
	8211	 5558	 0.00051	 0.00646	 0.0	 1744.0	 4875	 4875	 0.0	 0.0	 1	 -30.0	 30.0;
	8510	 369	 0.00163	 0.015271	 0.0	 2057	 2057	 2057	 0.0	 0.0	 1	 -30.0	 30.0;
	3891	 8510	 0.002159	 0.021901	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 784	 0.00224	 0.015018	 0.0	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 3182	 0.004111	 0.00652	 0.0	 4099	 4099	 4099	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 3182	 0.004191	 0.006391	 0.0	 4134	 4134	 4134	 0.0	 0.0	 1	 -30.0	 30.0;
	6923	 5108	 0.00238	 0.006744	 0.0	 4417	 4417	 4417	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 392	 0.003329	 0.033129	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	1633	 8389	 0.005809	 0.021182	 0.0	 1439	 1439	 1439	 0.0	 0.0	 1	 -30.0	 30.0;
	1633	 8389	 0.005689	 0.021591	 0.0	 1415	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	8389	 2720	 0.00132	 0.01052	 0.0	 2980	 2980	 2980	 0.0	 0.0	 1	 -30.0	 30.0;
	8389	 243	 0.001129	 0.012329	 0.0	 2552	 2552	 2552	 0.0	 0.0	 1	 -30.0	 30.0;
	8389	 4409	 0.001569	 0.1224	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 2572	 0.000662	 0.036351	 0.0	 468.0	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 7404	 0.001777	 0.009107	 0.0	 3405	 3405	 3405	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 1338	 0.002967	 0.002901	 0.0	 7613	 7613	 7613	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 8288	 0.017893	 0.057479	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	7404	 8882	 0.000554	 0.001091	 0.0	 25816	 25816	 25816	 0.0	 0.0	 1	 -30.0	 30.0;
	7404	 7565	 0.006339	 0.022603	 0.0	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	1338	 360	 0.004174	 0.006702	 0.0	 4001	 4001	 4001	 0.0	 0.0	 1	 -30.0	 30.0;
	360	 7565	 0.009818	 0.040099	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	275	 6323	 0.003729	 0.01876	 0.0	 1652	 1652	 1652	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 7230	 0.000782	 0.059938	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	8194	 5872	 0.000769	 0.061111	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 6514	 0.000382	 0.019378	 0.0	 1630	 1630	 1630	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 387	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 6838	 1.8e-05	 0.00188	 0.0	 637.0	 16802	 16802	 0.0	 0.0	 1	 -30.0	 30.0;
	8480	 6025	 0.000372	 0.001223	 0.0	 24710	 24710	 24710	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 5835	 0.000809	 0.001751	 0.0	 16377	 16377	 16377	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 878	 0.0	 0.043511	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 3374	 0.003529	 0.022178	 0.0	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 3374	 0.0036	 0.021711	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	6383	 231	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 6383	 0.047479	 0.102603	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 6383	 0.053727	 0.091281	 0.0	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	1010	 6383	 0.021678	 0.045669	 0.0	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 8878	 0.004397	 0.030678	 0.0	 1020	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 8878	 0.004314	 0.031256	 0.0	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 7117	 0.008347	 0.055512	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 2698	 0.006223	 0.039744	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 2228	 0.006124	 0.041686	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 2228	 0.006942	 0.040851	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	4057	 5783	 0.019248	 0.039041	 0.0	 191.0	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	7136	 4057	 0.015719	 0.04943	 0.0	 609	 609	 609	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 1207	 0.00296	 0.011871	 0.0	 2582	 2582	 2582	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 9083	 0.01328	 0.04144	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 7138	 0.00736	 0.033222	 0.0	 929	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 7138	 0.007502	 0.032529	 0.0	 947	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 2745	 0.00192	 0.02576	 0.0	 299.0	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 2745	 0.002169	 0.02524	 0.0	 299.0	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 8492	 0.00656	 0.017071	 0.0	 1728	 1728	 1728	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 2748	 0.002662	 0.007471	 0.0	 3983	 3983	 3983	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 3215	 0.003191	 0.009062	 0.0	 3288	 3288	 3288	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 8668	 0.00981	 0.057298	 0.0	 544	 544	 544	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 6356	 0.008342	 0.037031	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	1464	 6356	 0.0086	 0.039791	 0.0	 776	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 8230	 0.0	 0.00046	 0.0	 1843.0	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 1689	 0.00055	 0.00685	 0.0	 1645.0	 4597	 4597	 0.0	 0.0	 1	 -30.0	 30.0;
	6263	 8230	 0.00054	 0.00699	 0.0	 1645.0	 4506	 4506	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 69	 0.0056	 0.052889	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5949	 0.006058	 0.023591	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5949	 0.0054	 0.026729	 0.0	 1159	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 8613	 0.00168	 0.01188	 0.0	 299.0	 2633	 2633	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 9007	 0.003178	 0.028658	 0.0	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5188	 0.003178	 0.028542	 0.0	 299.0	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 6442	 0.00068	 0.004449	 0.0	 7019	 7019	 7019	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 3462	 0.00076	 0.004818	 0.0	 6477	 6477	 6477	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 1778	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 1633	 9e-06	 0.000222	 0.0	 142169	 142169	 142169	 0.0	 0.0	 1	 -30.0	 30.0;
	3983	 1633	 0.0	 0.000222	 0.0	 299.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7442	 1633	 1.8e-05	 0.004329	 0.0	 7297	 7297	 7297	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 5271	 0.001831	 0.001698	 0.0	 12650	 12650	 12650	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 5271	 0.002209	 0.001471	 0.0	 11902	 11902	 11902	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 2832	 0.017653	 0.070289	 0.0	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 2832	 0.013231	 0.042207	 0.0	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 2832	 0.013479	 0.041331	 0.0	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	2804	 2832	 0.013934	 0.055702	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 6028	 0.000537	 0.001471	 0.0	 20172	 20172	 20172	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 4872	 0.009967	 0.048959	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 9146	 0.030612	 0.055058	 0.0	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 9146	 0.031207	 0.053934	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 6028	 0.01314	 0.040579	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 6028	 0.012851	 0.03757	 0.0	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 7011	 0.006901	 0.021174	 0.0	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 7011	 0.007653	 0.01924	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	7295	 5595	 0.008982	 0.038462	 0.0	 800	 800	 800	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 7297	 0.009151	 0.037649	 0.0	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 1020	 0.004258	 0.03952	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 5595	 0.003489	 0.0264	 0.0	 1187	 1187	 1187	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 2305	 0.003849	 0.05232	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 4104	 0.032669	 0.080273	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 4104	 0.004901	 0.014967	 0.0	 2006	 2006	 2006	 0.0	 0.0	 1	 -30.0	 30.0;
	312	 5783	 0.000562	 0.001058	 0.0	 26367	 26367	 26367	 0.0	 0.0	 1	 -30.0	 30.0;
	8393	 139	 0.0	 0.00045	 0.0	 1547.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	8393	 8264	 0.001	 0.01169	 0.0	 1481.0	 2693	 2693	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 8211	 0.00098	 0.01192	 0.0	 1448.0	 2642	 2642	 0.0	 0.0	 1	 -30.0	 30.0;
	6600	 7565	 0.002339	 0.006223	 0.0	 4752	 4752	 4752	 0.0	 0.0	 1	 -30.0	 30.0;
	6600	 7565	 0.002388	 0.006091	 0.0	 4829	 4829	 4829	 0.0	 0.0	 1	 -30.0	 30.0;
	2555	 6600	 0.000504	 0.001207	 0.0	 24150	 24150	 24150	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 7565	 0.00105	 0.007959	 0.0	 248.0	 3935	 3935	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 7565	 0.001033	 0.007372	 0.0	 267.0	 4244	 4244	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 2648	 0.018752	 0.042339	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 2648	 0.018339	 0.039231	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 6923	 0.036793	 0.081719	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 8480	 0.003702	 0.015132	 0.0	 2028	 2028	 2028	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 1989	 0.00124	 0.007314	 0.0	 219.0	 4258	 4258	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 5760	 0.002329	 0.00356	 0.0	 299.0	 7426	 7426	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 5760	 0.002378	 0.00348	 0.0	 299.0	 7495	 7495	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 5760	 0.00212	 0.003951	 0.0	 299.0	 7045	 7045	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 7476	 0.001951	 0.003791	 0.0	 364.0	 7409	 7409	 0.0	 0.0	 1	 -30.0	 30.0;
	69	 7852	 0.002542	 0.01472	 0.0	 2115	 2115	 2115	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 5342	 0.003262	 0.024151	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 4757	 0.0036	 0.01548	 0.0	 260.0	 1988	 1988	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 4757	 0.00352	 0.014329	 0.0	 260.0	 2141	 2141	 0.0	 0.0	 1	 -30.0	 30.0;
	1880	 4380	 0.002591	 0.014418	 0.0	 2157	 2157	 2157	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 1880	 0.001071	 0.003058	 0.0	 9749	 9749	 9749	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 4687	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 1330	 0.017458	 0.052129	 0.0	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	7295	 8442	 0.00136	 0.00216	 0.0	 12376	 12376	 12376	 0.0	 0.0	 1	 -30.0	 30.0;
	7297	 8442	 0.001391	 0.00212	 0.0	 12458	 12458	 12458	 0.0	 0.0	 1	 -30.0	 30.0;
	6399	 9083	 0.005858	 0.016591	 0.0	 1796	 1796	 1796	 0.0	 0.0	 1	 -30.0	 30.0;
	898	 8668	 0.004562	 0.011653	 0.0	 2525	 2525	 2525	 0.0	 0.0	 1	 -30.0	 30.0;
	898	 6526	 0.030868	 0.064174	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	3257	 369	 0.0	 0.000521	 0.0	 60629	 60629	 60629	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 1020	 0.005929	 0.053271	 0.0	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 297	 0.00664	 0.040849	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 3182	 0.00968	 0.049382	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 4692	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 69	 0.00044	 0.004489	 0.0	 7004	 7004	 7004	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 3898	 0.01064	 0.043751	 0.0	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 3898	 0.0104	 0.040511	 0.0	 756	 756	 756	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 5829	 0.0024	 0.025498	 0.0	 1234	 1234	 1234	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 1205	 0.00264	 0.01412	 0.0	 2199	 2199	 2199	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 6131	 0.000609	 0.03944	 0.0	 663.0	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	8565	 472	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 5760	 0.001182	 0.003018	 0.0	 299.0	 9746	 9746	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 5760	 0.0012	 0.002951	 0.0	 299.0	 9916	 9916	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 5760	 0.001071	 0.003351	 0.0	 286.0	 8979	 8979	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 7073	 0.001031	 0.01544	 0.0	 2042	 2042	 2042	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 349	 0.001009	 0.015738	 0.0	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 7156	 0.000991	 0.01604	 0.0	 1966	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 7305	 0.003898	 0.008862	 0.0	 3263	 3263	 3263	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 7305	 0.003818	 0.009031	 0.0	 3222	 3222	 3222	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 311	 0.003831	 0.012502	 0.0	 2416	 2416	 2416	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 6263	 0.0	 0.00051	 0.0	 856.0	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 6263	 0.00127	 0.0132	 0.0	 1481.0	 2382	 2382	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 2271	 0.0	 0.000222	 0.0	 299.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 7666	 0.001338	 0.011209	 0.0	 2799	 2799	 2799	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 7018	 0.004222	 0.030062	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 7450	 0.001182	 0.0104	 0.0	 3018	 3018	 3018	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 3846	 9e-06	 0.000222	 0.0	 142169	 142169	 142169	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 7018	 0.004138	 0.03064	 0.0	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 7018	 0.004049	 0.031209	 0.0	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	733	 5423	 0.022603	 0.051959	 0.0	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 733	 0.013636	 0.032041	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	8492	 3216	 0.00228	 0.009222	 0.0	 3326	 3326	 3326	 0.0	 0.0	 1	 -30.0	 30.0;
	2748	 3216	 0.002471	 0.010302	 0.0	 273.0	 2982	 2982	 0.0	 0.0	 1	 -30.0	 30.0;
	3215	 3216	 0.001831	 0.007378	 0.0	 273.0	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	8878	 4302	 0.006843	 0.049248	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	8878	 4302	 0.006686	 0.045603	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 8016	 0.004102	 0.011529	 0.0	 2582	 2582	 2582	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 8016	 0.004182	 0.01128	 0.0	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 2120	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8155	 1913	 0.003649	 0.0122	 0.0	 2481	 2481	 2481	 0.0	 0.0	 1	 -30.0	 30.0;
	8155	 1913	 0.00372	 0.011938	 0.0	 2527	 2527	 2527	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 7090	 0.005031	 0.028102	 0.0	 1107	 1107	 1107	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 7090	 0.005129	 0.02752	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 7844	 0.005218	 0.026951	 0.0	 1151	 1151	 1151	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 3462	 0.00288	 0.01992	 0.0	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 3462	 0.003262	 0.01952	 0.0	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 1106	 0.00956	 0.061022	 0.0	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 2760	 0.005382	 0.033911	 0.0	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 2760	 0.005271	 0.034569	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 6218	 0.004102	 0.023018	 0.0	 1352	 1352	 1352	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 8604	 0.0	 0.00052	 0.0	 757.0	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 2335	 0.0	 0.000222	 0.0	 481.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 3182	 0.011631	 0.094591	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 1020	 0.0012	 0.008769	 0.0	 299.0	 3569	 3569	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 9072	 0.001218	 0.008582	 0.0	 299.0	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	7138	 7586	 0.002689	 0.013818	 0.0	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	2648	 8288	 0.005	 0.008934	 0.0	 3086	 3086	 3086	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 140	 0.0	 0.000531	 0.0	 59487	 59487	 59487	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 5311	 0.001281	 0.0158	 0.0	 1993	 1993	 1993	 0.0	 0.0	 1	 -30.0	 30.0;
	140	 3891	 0.00125	 0.016099	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 6526	 0.010058	 0.048	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 6526	 0.010248	 0.047	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 2804	 0.004314	 0.024537	 0.0	 1268	 1268	 1268	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 3301	 0.010791	 0.042151	 0.0	 299.0	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 1011	 0.0006	 0.040218	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	243	 8621	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 5674	 0.0	 0.00053	 0.0	 1711.0	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 4337	 0.0	 0.00054	 0.0	 1251.0	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 8204	 0.00196	 0.010249	 0.0	 3028	 3028	 3028	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 1516	 0.002182	 0.010498	 0.0	 2946	 2946	 2946	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 6480	 0.000582	 0.040991	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 5655	 0.000569	 0.04176	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	1464	 3177	 0.003818	 0.013209	 0.0	 2298	 2298	 2298	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 6323	 0.00428	 0.023511	 0.0	 1322	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 6323	 0.004182	 0.021769	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 4858	 0.0	 0.0005	 0.0	 1086.0	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 8264	 0.00114	 0.01661	 0.0	 1481.0	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 4248	 0.0	 0.000539	 0.0	 58604	 58604	 58604	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 76	 0.00119	 0.014081	 0.0	 2236	 2236	 2236	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 8211	 0.00117	 0.01626	 0.0	 1711.0	 1938	 1938	 0.0	 0.0	 1	 -30.0	 30.0;
	4248	 38	 0.00106	 0.01595	 0.0	 1977	 1977	 1977	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 999	 0.018058	 0.065719	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 1010	 0.012826	 0.025058	 0.0	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 1010	 0.013331	 0.024	 0.0	 1151	 1151	 1151	 0.0	 0.0	 1	 -30.0	 30.0;
	8204	 1516	 0.001089	 0.003151	 0.0	 9475	 9475	 9475	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 2428	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 1277	 0.000631	 0.054471	 0.0	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 2117	 0.000622	 0.055489	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 8895	 0.0006	 0.051382	 0.0	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 6526	 0.017702	 0.064331	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 1787	 0.012314	 0.04924	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	2331	 8380	 0.001223	 0.001248	 0.0	 18078	 18078	 18078	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 8380	 0.001471	 0.00481	 0.0	 6280	 6280	 6280	 0.0	 0.0	 1	 -30.0	 30.0;
	999	 8380	 0.011521	 0.03138	 0.0	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 7915	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 6149	 0.000289	 0.00056	 0.0	 50125	 50125	 50125	 0.0	 0.0	 1	 -30.0	 30.0;
	3968	 3370	 0.00034	 0.01805	 0.0	 757.0	 1750	 1750	 0.0	 0.0	 1	 -30.0	 30.0;
	7480	 2720	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 6687	 0.00035	 0.01766	 0.0	 1053.0	 1789	 1789	 0.0	 0.0	 1	 -30.0	 30.0;
	8956	 4209	 0.00035	 0.01728	 0.0	 1053.0	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	5065	 8318	 0.00031	 0.01958	 0.0	 1614	 1614	 1614	 0.0	 0.0	 1	 -30.0	 30.0;
	7270	 3370	 0.00031	 0.01997	 0.0	 856.0	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	6424	 3370	 0.0003	 0.02035	 0.0	 757.0	 1553	 1553	 0.0	 0.0	 1	 -30.0	 30.0;
	5888	 8223	 0.00016	 0.0025	 0.0	 1020.0	 12610	 12610	 0.0	 0.0	 1	 -30.0	 30.0;
	4776	 3370	 0.00029	 0.02074	 0.0	 1119.0	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	1331	 8318	 0.00029	 0.0192	 0.0	 757.0	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	8483	 8318	 0.00033	 0.01882	 0.0	 757.0	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	6687	 4209	 0.0	 0.00049	 0.0	 757.0	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	4733	 6687	 0.0	 0.00048	 0.0	 1283.0	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	7856	 4209	 0.0	 0.00047	 0.0	 1382.0	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 5897	 0.0	 0.00046	 0.0	 1349.0	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 420	 0.0	 0.00045	 0.0	 1086.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 8898	 0.0	 0.00051	 0.0	 757.0	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	8318	 7856	 0.0	 0.00052	 0.0	 987.0	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	8318	 4733	 0.0	 0.00053	 0.0	 921.0	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	8318	 8898	 0.0	 0.00054	 0.0	 757.0	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	5897	 4087	 0.0	 0.0005	 0.0	 1448.0	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	4087	 7856	 0.0	 0.00049	 0.0	 1843.0	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	4087	 4077	 0.00028	 0.00403	 0.0	 1382.0	 7820	 7820	 0.0	 0.0	 1	 -30.0	 30.0;
	6283	 4087	 0.00021	 0.00396	 0.0	 1777.0	 7966	 7966	 0.0	 0.0	 1	 -30.0	 30.0;
	420	 2927	 0.0	 0.00048	 0.0	 1119.0	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 4733	 0.0	 0.00047	 0.0	 1251.0	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 5888	 0.00029	 0.00394	 0.0	 954.0	 7996	 7996	 0.0	 0.0	 1	 -30.0	 30.0;
	4485	 2927	 0.0002	 0.00404	 0.0	 1744.0	 7810	 7810	 0.0	 0.0	 1	 -30.0	 30.0;
	2720	 243	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	243	 558	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8492	 2748	 0.004471	 0.020791	 0.0	 1486	 1486	 1486	 0.0	 0.0	 1	 -30.0	 30.0;
	8492	 3215	 0.002791	 0.01132	 0.0	 2710	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 8392	 0.000822	 0.001649	 0.0	 17144	 17144	 17144	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 8392	 0.0008	 0.00168	 0.0	 16976	 16976	 16976	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 8392	 0.000782	 0.00156	 0.0	 18102	 18102	 18102	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 311	 0.00432	 0.012662	 0.0	 2362	 2362	 2362	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 311	 0.003849	 0.014351	 0.0	 2126	 2126	 2126	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 2552	 0.001418	 0.004618	 0.0	 6539	 6539	 6539	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 7275	 0.001689	 0.011631	 0.0	 2688	 2688	 2688	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 6218	 0.005991	 0.03832	 0.0	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 1936	 0.001169	 0.007098	 0.0	 403.0	 4392	 4392	 0.0	 0.0	 1	 -30.0	 30.0;
	7476	 1936	 0.0012	 0.00696	 0.0	 299.0	 4473	 4473	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 9146	 0.030066	 0.046289	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 9146	 0.026793	 0.052463	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	7729	 4415	 0.023413	 0.057397	 0.0	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 5364	 0.001631	 0.00832	 0.0	 3726	 3726	 3726	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 4431	 0.012569	 0.04732	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 4431	 0.012311	 0.048231	 0.0	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	8017	 6519	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 8017	 0.000982	 0.004751	 0.0	 6511	 6511	 6511	 0.0	 0.0	 1	 -30.0	 30.0;
	2965	 1260	 0.00144	 0.12	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 5364	 0.001249	 0.0064	 0.0	 4845	 4845	 4845	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 5364	 0.00112	 0.007249	 0.0	 4307	 4307	 4307	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 3891	 0.0	 0.0005	 0.0	 63175	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	9205	 8668	 0.022843	 0.098893	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	8668	 6526	 0.034909	 0.072893	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	7666	 377	 0.00188	 0.092222	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	7666	 1227	 0.00184	 0.093991	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	7666	 4006	 0.0018	 0.09576	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 7666	 0.00132	 0.01088	 0.0	 2883	 2883	 2883	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 1889	 0.01924	 0.056603	 0.0	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 1889	 0.017124	 0.064149	 0.0	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 6747	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 838	 0.006889	 0.03404	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 838	 0.007018	 0.033329	 0.0	 928	 928	 928	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 7951	 0.006169	 0.035689	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 7951	 0.00628	 0.034929	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 8792	 0.004271	 0.026418	 0.0	 1181	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 8792	 0.00436	 0.02588	 0.0	 1204	 1204	 1204	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 8792	 0.00444	 0.025338	 0.0	 1228	 1228	 1228	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 1330	 0.00852	 0.02444	 0.0	 1221	 1221	 1221	 0.0	 0.0	 1	 -30.0	 30.0;
	8613	 52	 0.002671	 0.018929	 0.0	 1653	 1653	 1653	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 3352	 0.0	 0.00046	 0.0	 1613.0	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 6766	 0.0	 0.00045	 0.0	 1481.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 3352	 0.0	 0.00051	 0.0	 1185.0	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 6766	 0.0	 0.00052	 0.0	 1382.0	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 7275	 0.000329	 0.000902	 0.0	 32900	 32900	 32900	 0.0	 0.0	 1	 -30.0	 30.0;
	8792	 3712	 0.00068	 0.050351	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	3388	 838	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 2523	 0.0	 0.00049	 0.0	 64464	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 1052	 0.00212	 0.022531	 0.0	 553.0	 1396	 1396	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 76	 0.000919	 0.012789	 0.0	 2464	 2464	 2464	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 3878	 0.002159	 0.02206	 0.0	 438.0	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 38	 0.00094	 0.012531	 0.0	 2514	 2514	 2514	 0.0	 0.0	 1	 -30.0	 30.0;
	194	 7018	 0.00032	 0.014102	 0.0	 299.0	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 7018	 0.000329	 0.0138	 0.0	 299.0	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 7018	 0.000329	 0.013502	 0.0	 299.0	 2339	 2339	 0.0	 0.0	 1	 -30.0	 30.0;
	6323	 539	 0.005818	 0.02396	 0.0	 1282	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	6323	 539	 0.005942	 0.023462	 0.0	 1306	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 6707	 0.000671	 0.001871	 0.0	 260.0	 15892	 15892	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 6707	 0.0	 0.001791	 0.0	 17637	 17637	 17637	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 3509	 0.002249	 0.003471	 0.0	 7638	 7638	 7638	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 3509	 0.001631	 0.0042	 0.0	 7011	 7011	 7011	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 3776	 0.00092	 0.002582	 0.0	 11524	 11524	 11524	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 3509	 0.0	 0.000222	 0.0	 585.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 5974	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 7018	 0.000822	 0.00572	 0.0	 5467	 5467	 5467	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 4565	 0.001338	 0.013622	 0.0	 2308	 2308	 2308	 0.0	 0.0	 1	 -30.0	 30.0;
	8058	 7018	 0.00136	 0.004649	 0.0	 6522	 6522	 6522	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 4863	 0.0	 0.001751	 0.0	 18040	 18040	 18040	 0.0	 0.0	 1	 -30.0	 30.0;
	3776	 3509	 0.0	 0.001711	 0.0	 18462	 18462	 18462	 0.0	 0.0	 1	 -30.0	 30.0;
	4082	 6442	 0.000662	 0.004529	 0.0	 273.0	 6902	 6902	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 6442	 0.000649	 0.004618	 0.0	 6774	 6774	 6774	 0.0	 0.0	 1	 -30.0	 30.0;
	6526	 1787	 0.005669	 0.028992	 0.0	 1070	 1070	 1070	 0.0	 0.0	 1	 -30.0	 30.0;
	4616	 7260	 0.001631	 0.1176	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 7996	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 1221	 0.006942	 0.04516	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 1221	 0.0068	 0.04604	 0.0	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	8525	 2698	 0.003289	 0.017909	 0.0	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	3215	 7407	 0.00056	 0.038671	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	4686	 7729	 0.02162	 0.062612	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 2494	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 9007	 0.000822	 0.00656	 0.0	 4778	 4778	 4778	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 928	 0.003009	 0.004649	 0.0	 273.0	 5704	 5704	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 928	 0.003071	 0.004551	 0.0	 286.0	 5754	 5754	 0.0	 0.0	 1	 -30.0	 30.0;
	6987	 4509	 0.00464	 0.029431	 0.0	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	6987	 4509	 0.005249	 0.02884	 0.0	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 6047	 0.001902	 0.012702	 0.0	 2460	 2460	 2460	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 6047	 0.001858	 0.012938	 0.0	 2417	 2417	 2417	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 7662	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6149	 5442	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 3819	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 6015	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	9083	 994	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 3169	 9.8e-05	 0.000222	 0.0	 260.0	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 838	 0.004738	 0.012529	 0.0	 2359	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 838	 0.004831	 0.012262	 0.0	 2397	 2397	 2397	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 838	 0.002711	 0.018431	 0.0	 1696	 1696	 1696	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 9223	 0.01205	 0.03281	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 838	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	838	 7779	 0.000649	 0.03712	 0.0	 390.0	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	838	 4477	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6320	 838	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 3620	 0.00076	 0.005329	 0.0	 5869	 5869	 5869	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 297	 0.005769	 0.03528	 0.0	 884	 884	 884	 0.0	 0.0	 1	 -30.0	 30.0;
	7476	 1463	 0.002258	 0.004849	 0.0	 5906	 5906	 5906	 0.0	 0.0	 1	 -30.0	 30.0;
	7476	 1463	 0.002209	 0.004489	 0.0	 260.0	 6314	 6314	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 3878	 0.0	 0.000479	 0.0	 65945	 65945	 65945	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 6477	 0.00256	 0.01561	 0.0	 533.0	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 5295	 0.00269	 0.01451	 0.0	 591.0	 2141	 2141	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 5887	 0.003372	 0.028231	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 9127	 0.007033	 0.047083	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	76	 38	 0.0	 0.000469	 0.0	 67351	 67351	 67351	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 1984	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 3182	 0.00392	 0.025191	 0.0	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 3182	 0.00444	 0.024689	 0.0	 1260	 1260	 1260	 0.0	 0.0	 1	 -30.0	 30.0;
	9127	 5887	 0.003529	 0.021223	 0.0	 1469	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	4082	 5246	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4485	 395	 0.00069	 0.00134	 0.0	 1481.0	 20958	 20958	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 6283	 0.00067	 0.00136	 0.0	 1448.0	 20835	 20835	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 8480	 0.012992	 0.070207	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 5843	 0.0	 0.00053	 0.0	 823.0	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	6477	 5295	 0.0	 0.000461	 0.0	 68520	 68520	 68520	 0.0	 0.0	 1	 -30.0	 30.0;
	8264	 8211	 0.0	 0.00054	 0.0	 790.0	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	7011	 4614	 0.002314	 0.005661	 0.0	 5165	 5165	 5165	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 7011	 0.002512	 0.005909	 0.0	 4920	 4920	 4920	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 7011	 0.006364	 0.018488	 0.0	 1616	 1616	 1616	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 7011	 0.005959	 0.017752	 0.0	 1687	 1687	 1687	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 9223	 0.018397	 0.04176	 0.0	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 9223	 0.018058	 0.042653	 0.0	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	7090	 7844	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 559	 0.0	 0.000529	 0.0	 59712	 59712	 59712	 0.0	 0.0	 1	 -30.0	 30.0;
	9072	 559	 0.0	 0.00052	 0.0	 60745	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 9072	 0.003369	 0.031329	 0.0	 338.0	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	2509	 6268	 0.07449	 0.527603	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	3039	 6268	 0.01093	 0.074531	 0.0	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 6268	 0.00887	 0.04576	 0.0	 553.0	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	3909	 6268	 0.01099	 0.06689	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	8610	 1050	 0.04732	 0.42186	 0.0	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	8610	 1050	 0.004469	 0.03124	 0.0	 1001	 1001	 1001	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 431	 0.500289	 1.586157	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 3953	 0.01089	 0.060719	 0.0	 457.0	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 4805	 0.133469	 0.882645	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	8610	 1050	 0.005531	 0.032521	 0.0	 476.0	 958	 958	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 4805	 0.005219	 0.025659	 0.0	 495.0	 1207	 1207	 0.0	 0.0	 1	 -30.0	 30.0;
	8652	 3848	 0.00186	 0.012789	 0.0	 400.0	 2445	 2445	 0.0	 0.0	 1	 -30.0	 30.0;
	3991	 3848	 0.001	 0.234938	 0.0	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 6701	 0.00081	 0.004781	 0.0	 6515	 6515	 6515	 0.0	 0.0	 1	 -30.0	 30.0;
	2862	 8175	 0.00082	 0.00468	 0.0	 6649	 6649	 6649	 0.0	 0.0	 1	 -30.0	 30.0;
	4581	 4595	 0.03374	 0.614711	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	8537	 4595	 0.04612	 0.366777	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 4595	 0.001461	 0.01239	 0.0	 2532	 2532	 2532	 0.0	 0.0	 1	 -30.0	 30.0;
	8537	 4581	 0.078599	 0.394649	 0.0	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	8758	 4581	 0.00143	 0.01263	 0.0	 2486	 2486	 2486	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 977	 0.007841	 0.05613	 0.0	 553.0	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 2453	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 2453	 0.001	 0.328946	 0.0	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 2453	 0.224855	 1.532376	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 2453	 0.136781	 1.457355	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 2453	 0.01055	 0.074979	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 2453	 0.014909	 0.523802	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 2453	 0.001	 0.71781	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	7551	 2453	 0.134271	 1.687004	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	4163	 5310	 0.002341	 0.01263	 0.0	 457.0	 2460	 2460	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 5310	 0.235227	 1.541777	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 5310	 0.16344	 1.266136	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 5310	 0.015479	 0.562376	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 5310	 0.001	 0.767789	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	7551	 5310	 0.158281	 1.596364	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 3438	 0.006169	 0.039289	 0.0	 553.0	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 3438	 0.08256	 0.638182	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 3438	 0.221653	 1.097397	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	3438	 6708	 0.0118	 0.05445	 0.0	 381.0	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 3438	 0.08986	 0.756921	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 638	 0.03887	 0.335083	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	638	 4002	 0.00455	 0.036539	 0.0	 457.0	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	173	 638	 0.002169	 0.01688	 0.0	 1857	 1857	 1857	 0.0	 0.0	 1	 -30.0	 30.0;
	173	 638	 0.01045	 0.244731	 0.0	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	6601	 638	 0.001	 0.259525	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 638	 0.036651	 0.378657	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	6591	 6287	 0.004669	 0.03839	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	587	 6287	 0.000781	 0.00674	 0.0	 629.0	 4656	 4656	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 6287	 0.001461	 0.01201	 0.0	 2611	 2611	 2611	 0.0	 0.0	 1	 -30.0	 30.0;
	9234	 6287	 0.00087	 0.00614	 0.0	 591.0	 5094	 5094	 0.0	 0.0	 1	 -30.0	 30.0;
	8971	 4163	 0.00464	 0.02919	 0.0	 419.0	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 4163	 0.004719	 0.02719	 0.0	 476.0	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 4163	 0.00169	 0.01361	 0.0	 476.0	 2304	 2304	 0.0	 0.0	 1	 -30.0	 30.0;
	7984	 4163	 0.00751	 0.04581	 0.0	 553.0	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	1342	 6591	 0.00368	 0.022469	 0.0	 1388	 1388	 1388	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 6591	 0.001659	 0.012599	 0.0	 495.0	 2486	 2486	 0.0	 0.0	 1	 -30.0	 30.0;
	7551	 6591	 0.007341	 0.042419	 0.0	 533.0	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	6591	 7511	 0.00186	 0.01456	 0.0	 514.0	 2152	 2152	 0.0	 0.0	 1	 -30.0	 30.0;
	6238	 3368	 0.00312	 0.03151	 0.0	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	8822	 6238	 0.00073	 0.00808	 0.0	 1283.0	 3894	 3894	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 3001	 0.013479	 0.27064	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 3001	 0.00187	 0.020289	 0.0	 1551	 1551	 1551	 0.0	 0.0	 1	 -30.0	 30.0;
	9040	 3001	 0.012169	 0.298636	 0.0	 106	 106	 106	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 6937	 0.00337	 0.027831	 0.0	 591.0	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	3909	 7293	 0.00461	 0.03301	 0.0	 533.0	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	6937	 7293	 0.005781	 0.039789	 0.0	 533.0	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	6937	 7293	 0.035151	 0.987397	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	2284	 7293	 0.013099	 0.631736	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	3039	 2509	 0.118409	 1.072417	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	3039	 2509	 0.006281	 0.051961	 0.0	 457.0	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	2063	 2509	 0.284979	 1.491054	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 3251	 0.006409	 0.038081	 0.0	 629.0	 818	 818	 0.0	 0.0	 1	 -30.0	 30.0;
	173	 4002	 0.225806	 1.262624	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	6601	 4002	 0.282252	 1.121529	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 4002	 0.561921	 1.55469	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 3797	 0.00322	 0.02808	 0.0	 1118	 1118	 1118	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 3797	 0.00196	 0.01843	 0.0	 1283.0	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	7025	 8449	 0.552066	 1.574607	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 8449	 0.010151	 0.087021	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 8449	 0.16999	 0.991054	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	262	 8449	 0.003831	 0.02386	 0.0	 553.0	 1308	 1308	 0.0	 0.0	 1	 -30.0	 30.0;
	262	 8449	 0.00863	 0.535785	 0.0	 59	 59	 59	 0.0	 0.0	 1	 -30.0	 30.0;
	6169	 8449	 0.04357	 0.617335	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 2827	 0.008081	 0.03963	 0.0	 438.0	 781	 781	 0.0	 0.0	 1	 -30.0	 30.0;
	2827	 1837	 0.00213	 0.01488	 0.0	 438.0	 2102	 2102	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 4533	 0.00219	 0.02232	 0.0	 1218.0	 2150	 2150	 0.0	 0.0	 1	 -30.0	 30.0;
	4533	 1315	 0.00352	 0.03947	 0.0	 987.0	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	4533	 8401	 0.00222	 0.02857	 0.0	 1481.0	 1682	 1682	 0.0	 0.0	 1	 -30.0	 30.0;
	361	 5822	 0.00104	 0.00901	 0.0	 1283.0	 4865	 4865	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 361	 0.00106	 0.00881	 0.0	 1448.0	 5432	 5432	 0.0	 0.0	 1	 -30.0	 30.0;
	6634	 4051	 0.00301	 0.031271	 0.0	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5822	 3147	 0.00133	 0.01852	 0.0	 1349.0	 2377	 2377	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 3930	 0.00253	 0.0287	 0.0	 954.0	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	5822	 3147	 0.06395	 0.413802	 0.0	 106	 106	 106	 0.0	 0.0	 1	 -30.0	 30.0;
	1315	 9238	 0.00075	 0.00981	 0.0	 1909.0	 4485	 4485	 0.0	 0.0	 1	 -30.0	 30.0;
	7890	 2274	 0.234814	 1.148326	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	1507	 2274	 0.222417	 1.185971	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	8764	 2274	 0.08124	 0.548574	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	8764	 2274	 0.01132	 0.074211	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 2274	 0.115849	 0.953099	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 4257	 0.0	 0.0002	 0.0	 1283.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 4257	 0.001	 0.517348	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 7553	 0.00051	 0.00504	 0.0	 1382.0	 6236	 6236	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 5209	 0.00258	 0.02748	 0.0	 1145	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	993	 5462	 0.00224	 0.02852	 0.0	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 2758	 0.00144	 0.01774	 0.0	 1415.0	 1775	 1775	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 8387	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 8387	 0.06794	 0.65593	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	8387	 7174	 0.028479	 0.136841	 0.0	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 4051	 0.02019	 0.10464	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	7553	 2758	 0.00128	 0.01333	 0.0	 1613.0	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	328	 6829	 0.667066	 1.759628	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 6829	 0.0232	 0.385289	 0.0	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 6829	 0.00686	 0.03882	 0.0	 553.0	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	7854	 6829	 0.04143	 0.328037	 0.0	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	9215	 6829	 0.00107	 0.00707	 0.0	 457.0	 4418	 4418	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 328	 0.173021	 1.092025	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 328	 0.010849	 0.074771	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	578	 328	 0.18632	 0.723574	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	7707	 328	 0.077651	 0.853368	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	7707	 328	 0.011169	 0.07225	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	7854	 328	 0.14268	 0.506488	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 328	 0.352417	 1.255207	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	262	 328	 0.391322	 1.63	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	3219	 2771	 0.006271	 0.037341	 0.0	 553.0	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 3219	 0.005961	 0.054719	 0.0	 572.0	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 4695	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 4695	 0.001	 0.333822	 0.0	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	4695	 3720	 0.00587	 0.040281	 0.0	 419.0	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 9040	 0.003599	 0.046841	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 5209	 0.00224	 0.02796	 0.0	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 6100	 0.08693	 0.670269	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 6100	 0.301839	 1.820372	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 6100	 0.00136	 0.01051	 0.0	 495.0	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 6100	 0.00445	 0.344835	 0.0	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	8330	 6100	 0.197159	 1.014752	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 6100	 0.097341	 0.78186	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 6100	 0.013039	 0.297211	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 6100	 0.035521	 0.685351	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	3991	 6100	 0.367335	 1.746467	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	3084	 6100	 0.04186	 0.505517	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 6100	 0.001021	 0.284401	 0.0	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	6708	 6100	 0.02575	 0.548884	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	7511	 6100	 0.002211	 0.016599	 0.0	 495.0	 1887	 1887	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 8652	 0.0015	 0.00876	 0.0	 3555	 3555	 3555	 0.0	 0.0	 1	 -30.0	 30.0;
	3991	 5139	 0.00062	 0.00386	 0.0	 514.0	 8080	 8080	 0.0	 0.0	 1	 -30.0	 30.0;
	6708	 8971	 0.00188	 0.008651	 0.0	 457.0	 3569	 3569	 0.0	 0.0	 1	 -30.0	 30.0;
	3084	 8971	 0.00651	 0.278678	 0.0	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 8971	 0.080781	 0.659587	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 6861	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 6861	 0.001	 0.232851	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	6861	 3015	 0.01614	 0.08307	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	431	 6861	 0.190479	 0.901095	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	431	 6861	 0.00281	 0.01663	 0.0	 514.0	 1873	 1873	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 6861	 0.032841	 0.593161	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	8537	 6861	 0.004599	 0.03094	 0.0	 476.0	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 6861	 0.100021	 0.542231	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	431	 5369	 0.1945	 0.883884	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 5369	 0.028409	 0.617727	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 5158	 0.003281	 0.04162	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 5369	 0.09636	 0.566219	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 5369	 0.007521	 0.044719	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	9040	 7174	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	9040	 7174	 0.001	 0.19056	 0.0	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 3326	 0.01356	 0.08876	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	9040	 3326	 0.005271	 0.068591	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3404	 8652	 0.003591	 0.03075	 0.0	 629.0	 1021	 1021	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 8652	 0.01	 0.056159	 0.0	 400.0	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 8652	 0.011831	 0.067969	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	8758	 8652	 0.00937	 0.05893	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	8652	 7493	 0.000909	 0.004719	 0.0	 495.0	 6573	 6573	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 1315	 0.00176	 0.01759	 0.0	 1448.0	 2496	 2496	 0.0	 0.0	 1	 -30.0	 30.0;
	2997	 2216	 0.00137	 0.01801	 0.0	 1514.0	 2443	 2443	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 7625	 0.00184	 0.01756	 0.0	 1283.0	 2730	 2730	 0.0	 0.0	 1	 -30.0	 30.0;
	6708	 3084	 0.00213	 0.012539	 0.0	 457.0	 2484	 2484	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 3084	 0.07664	 0.597665	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 3084	 0.07132	 0.544959	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 3084	 0.00405	 0.02507	 0.0	 495.0	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	6708	 3084	 0.001	 0.348058	 0.0	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 2771	 0.06064	 0.52688	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 3003	 0.005271	 0.03093	 0.0	 514.0	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	3404	 1342	 0.002841	 0.023409	 0.0	 400.0	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	6972	 2013	 0.00226	 0.015841	 0.0	 457.0	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 2013	 0.01237	 0.060909	 0.0	 419.0	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 3404	 0.01637	 0.07345	 0.0	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 2013	 0.00243	 0.018341	 0.0	 553.0	 1708	 1708	 0.0	 0.0	 1	 -30.0	 30.0;
	3454	 791	 0.0026	 0.02813	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 2862	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 2862	 0.02631	 0.515517	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	2862	 6937	 0.00394	 0.041169	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	2862	 6937	 0.343719	 1.744855	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	2862	 7984	 0.017159	 0.080591	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 5513	 0.005	 0.066591	 0.0	 438.0	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 6937	 0.065229	 1.288988	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 3616	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 3616	 0.001	 0.56	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 3616	 0.063599	 0.651508	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	8330	 3616	 0.075159	 1.271095	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 3616	 0.360475	 1.617479	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 3616	 0.001	 0.740702	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 3616	 0.363884	 2.00314	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 3616	 0.3925	 1.858533	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 734	 0.04769	 0.602128	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	8330	 734	 0.050341	 1.259855	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 734	 0.001	 0.829566	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 8610	 0.00049	 0.00324	 0.0	 533.0	 9640	 9640	 0.0	 0.0	 1	 -30.0	 30.0;
	8610	 3782	 0.018659	 0.111289	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	8610	 4805	 0.509835	 1.831384	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 8610	 0.0005	 0.00318	 0.0	 572.0	 9813	 9813	 0.0	 0.0	 1	 -30.0	 30.0;
	6708	 1481	 0.05936	 0.582149	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 1481	 0.003331	 0.0203	 0.0	 629.0	 1536	 1536	 0.0	 0.0	 1	 -30.0	 30.0;
	8330	 1481	 0.12286	 0.888244	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 1481	 0.033599	 0.599959	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 1481	 0.100539	 0.767066	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 1481	 0.0822	 0.730331	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 1481	 0.15512	 0.82874	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 1492	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 1492	 0.001	 0.194781	 0.0	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 2539	 0.0132	 0.071979	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 378	 0.0148	 0.073031	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 1492	 0.005781	 0.0378	 0.0	 533.0	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 1492	 0.153961	 1.590021	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 1492	 0.00631	 0.03855	 0.0	 495.0	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 1492	 0.14124	 1.705702	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 5305	 0.00589	 0.03699	 0.0	 533.0	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 5305	 0.18032	 1.449298	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 5305	 0.150651	 1.729298	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 5305	 0.00636	 0.045409	 0.0	 438.0	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 3762	 0.00173	 0.01602	 0.0	 1316.0	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 2835	 0.00207	 0.02233	 0.0	 1218.0	 1409	 1409	 0.0	 0.0	 1	 -30.0	 30.0;
	1443	 2835	 0.00178	 0.02178	 0.0	 1283.0	 1446	 1446	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 6972	 0.00589	 0.214174	 0.0	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 6972	 0.105789	 1.66719	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 6972	 0.108969	 1.629731	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	7854	 4844	 0.024581	 0.231446	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	7854	 4844	 0.004599	 0.035341	 0.0	 572.0	 887	 887	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 1103	 0.00106	 0.01023	 0.0	 757.0	 3072	 3072	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 1103	 0.00403	 0.04889	 0.0	 644	 644	 644	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 5505	 0.00123	 0.01589	 0.0	 1415.0	 1982	 1982	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 3368	 0.00158	 0.01592	 0.0	 1909.0	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	248	 7089	 0.00219	 0.02123	 0.0	 1481	 1481	 1481	 0.0	 0.0	 1	 -30.0	 30.0;
	248	 4244	 0.00171	 0.01708	 0.0	 1547.0	 1841	 1841	 0.0	 0.0	 1	 -30.0	 30.0;
	248	 4244	 0.00174	 0.0167	 0.0	 1580.0	 1882	 1882	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 248	 0.00515	 0.285942	 0.0	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 248	 0.00058	 0.00775	 0.0	 1678.0	 4065	 4065	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 248	 0.00057	 0.0079	 0.0	 1415.0	 3989	 3989	 0.0	 0.0	 1	 -30.0	 30.0;
	3404	 6708	 0.009341	 0.6725	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	3991	 6708	 0.171229	 1.013678	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	7511	 6708	 0.00251	 0.02049	 0.0	 400.0	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	6708	 7493	 0.005909	 0.036349	 0.0	 591.0	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	9027	 7625	 0.00091	 0.00886	 0.0	 1251.0	 3547	 3547	 0.0	 0.0	 1	 -30.0	 30.0;
	8822	 9027	 0.00054	 0.00532	 0.0	 1547.0	 5908	 5908	 0.0	 0.0	 1	 -30.0	 30.0;
	262	 7025	 0.009531	 0.051211	 0.0	 476.0	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	262	 7025	 0.785124	 1.943678	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	7025	 3787	 0.010789	 0.05194	 0.0	 514.0	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	6169	 7025	 0.173281	 0.62781	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 3404	 0.00613	 0.033659	 0.0	 400.0	 924	 924	 0.0	 0.0	 1	 -30.0	 30.0;
	3991	 3404	 0.11576	 0.840434	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	7707	 578	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7707	 578	 0.05964	 0.314938	 0.0	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	578	 1267	 0.002169	 0.017341	 0.0	 438.0	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 578	 0.454215	 1.265475	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	578	 2604	 0.007091	 0.061521	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	7707	 1719	 0.013021	 0.087711	 0.0	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 7707	 0.35781	 1.954277	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 7707	 0.0485	 0.815537	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 5513	 0.415537	 1.939483	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 5513	 0.097031	 0.677913	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 5656	 0.003031	 0.033021	 0.0	 457.0	 953	 953	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 5656	 0.00637	 0.038979	 0.0	 572.0	 800	 800	 0.0	 0.0	 1	 -30.0	 30.0;
	7551	 5513	 0.024271	 0.588967	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	7984	 5513	 0.00439	 0.372438	 0.0	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	212	 5513	 0.001	 0.198331	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	212	 5513	 0.00232	 0.01226	 0.0	 381.0	 2532	 2532	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 1719	 0.014211	 0.079219	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	173	 1719	 0.015151	 0.07637	 0.0	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 1719	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 1719	 0.001	 0.258698	 0.0	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	6601	 1719	 0.01544	 0.074781	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 3251	 0.013909	 0.073349	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 4468	 0.006919	 0.04764	 0.0	 438.0	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	2250	 4468	 0.224318	 1.85469	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	8764	 4468	 0.015169	 0.1077	 0.0	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	378	 4468	 0.130771	 1.06564	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 4468	 0.249669	 1.169917	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	3762	 499	 0.00127	 0.01444	 0.0	 1382.0	 2180	 2180	 0.0	 0.0	 1	 -30.0	 30.0;
	3762	 6109	 0.00318	 0.04235	 0.0	 744	 744	 744	 0.0	 0.0	 1	 -30.0	 30.0;
	3762	 8685	 0.00131	 0.01758	 0.0	 1283.0	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	2284	 3039	 0.469607	 1.302025	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	2063	 3039	 0.001	 0.205711	 0.0	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2063	 3039	 0.002969	 0.02201	 0.0	 514.0	 1423	 1423	 0.0	 0.0	 1	 -30.0	 30.0;
	9215	 7854	 0.00549	 0.044831	 0.0	 495.0	 700	 700	 0.0	 0.0	 1	 -30.0	 30.0;
	3411	 2250	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3411	 2250	 0.08343	 1.583099	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	2539	 2250	 0.094651	 1.363719	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	2250	 3015	 0.00112	 0.00895	 0.0	 553.0	 3502	 3502	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 2250	 0.00151	 0.00944	 0.0	 553.0	 3305	 3305	 0.0	 0.0	 1	 -30.0	 30.0;
	378	 2250	 0.018669	 0.563368	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 2250	 0.00538	 0.652851	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	2539	 3411	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2539	 3411	 0.001	 0.495455	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	378	 3411	 0.036849	 0.734215	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 3411	 0.001	 0.459566	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 3411	 0.00095	 0.00638	 0.0	 533.0	 4898	 4898	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 2539	 0.00105	 0.00818	 0.0	 514.0	 3831	 3831	 0.0	 0.0	 1	 -30.0	 30.0;
	378	 2539	 0.040151	 0.657893	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	378	 2539	 0.00193	 0.01406	 0.0	 514.0	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 2539	 0.001	 0.49438	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 8330	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 8330	 0.08057	 0.906178	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 8330	 0.0347	 0.658202	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 8330	 0.032719	 0.534318	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 8330	 0.004281	 0.033461	 0.0	 553.0	 937	 937	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 5732	 0.001	 0.395785	 0.0	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 5732	 0.14007	 0.838595	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	8685	 499	 0.04194	 0.384211	 0.0	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	499	 8685	 0.00034	 0.00341	 0.0	 1415.0	 9218	 9218	 0.0	 0.0	 1	 -30.0	 30.0;
	770	 7890	 0.001969	 0.014021	 0.0	 2231	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	1507	 7890	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1507	 7890	 0.001	 0.26219	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	7890	 3938	 0.03032	 0.14413	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	1507	 764	 0.01325	 0.11038	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	2573	 3015	 0.011901	 0.07319	 0.0	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 3782	 0.00401	 0.03175	 0.0	 495.0	 988	 988	 0.0	 0.0	 1	 -30.0	 30.0;
	8685	 2997	 0.00368	 0.03712	 0.0	 1293	 1293	 1293	 0.0	 0.0	 1	 -30.0	 30.0;
	8685	 2948	 0.00169	 0.02158	 0.0	 1283.0	 1460	 1460	 0.0	 0.0	 1	 -30.0	 30.0;
	791	 4638	 0.00116	 0.01472	 0.0	 1283.0	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 7089	 0.05575	 0.602438	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 214	 0.00163	 0.01604	 0.0	 1382.0	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 2997	 0.00269	 0.02759	 0.0	 1251.0	 1739	 1739	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 1315	 0.00256	 0.02877	 0.0	 1316.0	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 8764	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 8764	 0.09549	 0.768967	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 431	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 431	 0.05899	 0.428306	 0.0	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 431	 0.005591	 0.04031	 0.0	 610.0	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 431	 0.00714	 0.15039	 0.0	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	8758	 3953	 0.005469	 0.041099	 0.0	 591.0	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 3953	 0.036711	 0.380269	 0.0	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 214	 0.00056	 0.124578	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 214	 0.0007	 0.00889	 0.0	 1645.0	 3543	 3543	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 2573	 0.013479	 0.11436	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 3326	 0.012	 0.066919	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	3782	 2573	 0.3925	 1.654463	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 6937	 0.301178	 1.948719	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 6937	 0.009169	 0.06301	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	3368	 791	 0.00176	 0.02342	 0.0	 856.0	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	3676	 791	 0.00108	 0.01167	 0.0	 1481.0	 2696	 2696	 0.0	 0.0	 1	 -30.0	 30.0;
	3782	 378	 0.191961	 1.234649	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 378	 0.03699	 0.374917	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	8758	 8537	 0.00361	 0.03024	 0.0	 610.0	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	262	 7298	 0.350806	 1.554649	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 262	 0.004831	 0.06375	 0.0	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 2553	 0.007099	 0.07076	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	6169	 262	 0.0022	 0.01318	 0.0	 381.0	 2364	 2364	 0.0	 0.0	 1	 -30.0	 30.0;
	262	 966	 0.01775	 0.099419	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	6169	 262	 0.186581	 1.067335	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	2997	 2948	 0.00373	 0.05005	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 966	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3787	 966	 0.001	 0.16038	 0.0	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 966	 0.010531	 0.17819	 0.0	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 966	 0.0025	 0.017081	 0.0	 495.0	 1830	 1830	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 3787	 0.0777	 0.498492	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	7551	 1837	 0.01907	 1.485992	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	7984	 1837	 0.120669	 1.890888	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 5148	 0.010271	 0.06219	 0.0	 400.0	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 3996	 0.298079	 1.623781	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 3996	 0.273223	 1.612107	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	2997	 8822	 0.00277	 0.02823	 0.0	 1448.0	 1700	 1700	 0.0	 0.0	 1	 -30.0	 30.0;
	1315	 2997	 0.00077	 0.00747	 0.0	 1251.0	 5875	 5875	 0.0	 0.0	 1	 -30.0	 30.0;
	7625	 8401	 0.00102	 0.01145	 0.0	 757.0	 2748	 2748	 0.0	 0.0	 1	 -30.0	 30.0;
	7625	 8401	 0.00112	 0.01049	 0.0	 757.0	 2995	 2995	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 6166	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 6166	 0.001	 0.22343	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 3676	 0.0	 0.0002	 0.0	 1810.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 3676	 0.001	 0.26178	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	3368	 3676	 0.00153	 0.0214	 0.0	 823.0	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	8822	 3676	 0.00468	 0.06143	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	212	 5656	 0.271756	 1.50345	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	7984	 7551	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7984	 7551	 0.015271	 0.796736	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	212	 7551	 0.02776	 0.935537	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	212	 7551	 0.004219	 0.026599	 0.0	 400.0	 1173	 1173	 0.0	 0.0	 1	 -30.0	 30.0;
	212	 7984	 0.001	 0.620888	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 3782	 0.361364	 1.973368	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	3909	 2284	 0.001599	 0.00825	 0.0	 476.0	 3759	 3759	 0.0	 0.0	 1	 -30.0	 30.0;
	2063	 2284	 0.659194	 1.990062	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	6601	 173	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6601	 173	 0.11788	 0.822417	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 173	 0.086341	 0.745145	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 6601	 0.00569	 0.033281	 0.0	 533.0	 936	 936	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 6601	 0.03618	 0.609897	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	27	 4847	 0.00087	 0.00898	 0.0	 1711.0	 3502	 3502	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 3720	 0.001	 0.211322	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 3720	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 3720	 0.13407	 1.029876	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	1835	 3720	 0.141419	 0.956033	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 141	 0.12913	 1.151054	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	1835	 141	 0.14487	 1.008244	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 1835	 0.007599	 0.05356	 0.0	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 3003	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 3003	 0.024219	 0.488657	 0.0	 65	 65	 65	 0.0	 0.0	 1	 -30.0	 30.0;
	1835	 3938	 0.001	 0.226901	 0.0	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	1835	 3938	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7493	 3991	 0.00063	 0.005159	 0.0	 495.0	 6078	 6078	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 2553	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 2553	 0.001	 0.214277	 0.0	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3341	 4259	 0.019671	 0.07004	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	3341	 4259	 0.01812	 0.06872	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4721	 0.001582	 0.00724	 0.0	 4263	 4263	 4263	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4721	 0.001551	 0.007231	 0.0	 4272	 4272	 4272	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4721	 0.001262	 0.00796	 0.0	 3920	 3920	 3920	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 2734	 0.0264	 0.075129	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 5274	 0.00824	 0.044751	 0.0	 695	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	7879	 4721	 0.018271	 0.070191	 0.0	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	7879	 4721	 0.021711	 0.063129	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	7879	 7569	 0.013191	 0.0428	 0.0	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 2734	 0.027631	 0.102502	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 7358	 0.005369	 0.052622	 0.0	 598	 598	 598	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 7358	 0.013938	 0.0534	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 7358	 0.01364	 0.049449	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 1407	 0.007991	 0.037738	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 4721	 0.007671	 0.04096	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 4721	 0.007511	 0.041769	 0.0	 745	 745	 745	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 3429	 0.004089	 0.010978	 0.0	 2697	 2697	 2697	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 3429	 0.003	 0.014769	 0.0	 2096	 2096	 2096	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 610	 0.001351	 0.00784	 0.0	 3971	 3971	 3971	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 948	 0.003671	 0.022089	 0.0	 1411	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 2954	 0.002378	 0.00772	 0.0	 3911	 3911	 3911	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 610	 0.006911	 0.03268	 0.0	 946	 946	 946	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 2140	 0.00944	 0.03284	 0.0	 925	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 6512	 0.009831	 0.02848	 0.0	 1049	 1049	 1049	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 948	 0.003671	 0.02092	 0.0	 1488	 1488	 1488	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 2734	 0.019378	 0.10932	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 2734	 0.021969	 0.107129	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 5274	 0.009151	 0.063249	 0.0	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 4116	 0.029169	 0.088102	 0.0	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 4868	 0.031351	 0.115698	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 7358	 0.04936	 0.182018	 0.0	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 6329	 0.001609	 0.016889	 0.0	 299.0	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 2817	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	702	 8927	 0.008698	 0.033591	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 1862	 0.01792	 0.070169	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 8629	 0.00308	 0.008422	 0.0	 299.0	 3523	 3523	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 552	 0.002031	 0.012102	 0.0	 2575	 2575	 2575	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 552	 0.0068	 0.03452	 0.0	 898	 898	 898	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 3791	 0.01176	 0.055871	 0.0	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	4344	 6512	 0.04856	 0.135111	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 6188	 0.039289	 0.146129	 0.0	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 6188	 0.038471	 0.148938	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 3413	 0.010911	 0.04116	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 1407	 0.002898	 0.017409	 0.0	 1790	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 1250	 0.00544	 0.051431	 0.0	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 5331	 0.003791	 0.014342	 0.0	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 5927	 0.005969	 0.026302	 0.0	 1172	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 4771	 0.00608	 0.02572	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 2660	 0.010818	 0.066769	 0.0	 260.0	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 2407	 0.006649	 0.024138	 0.0	 1262	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 2407	 0.007542	 0.023662	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 2407	 0.007991	 0.036622	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 2407	 0.0116	 0.046018	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	4116	 2140	 0.011631	 0.047049	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 7358	 0.018822	 0.064009	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	1250	 5927	 0.008071	 0.049138	 0.0	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	1250	 4771	 0.007889	 0.045502	 0.0	 684	 684	 684	 0.0	 0.0	 1	 -30.0	 30.0;
	1250	 8278	 0.009822	 0.057222	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 3711	 0.00656	 0.023831	 0.0	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 3711	 0.007431	 0.023351	 0.0	 1290	 1290	 1290	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 7411	 0.007391	 0.026978	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 4277	 0.001871	 0.012142	 0.0	 2572	 2572	 2572	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 987	 0.003969	 0.026169	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 2206	 0.008151	 0.04664	 0.0	 299.0	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 39	 0.00076	 0.005622	 0.0	 5568	 5568	 5568	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 3711	 0.0094	 0.035791	 0.0	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 7792	 0.00844	 0.031031	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 1685	 0.00028	 0.002062	 0.0	 15180	 15180	 15180	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 2894	 0.004849	 0.030031	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 4277	 0.00268	 0.022391	 0.0	 1401	 1401	 1401	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 987	 0.002391	 0.025382	 0.0	 1239	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 3711	 0.017551	 0.078191	 0.0	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 1543	 0.003849	 0.02475	 0.0	 591.0	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 7041	 0.0042	 0.02005	 0.0	 1542	 1542	 1542	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 3585	 0.00011	 0.000581	 0.0	 53419	 53419	 53419	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 780	 0.000169	 0.000651	 0.0	 46965	 46965	 46965	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 3957	 0.000169	 0.000659	 0.0	 46430	 46430	 46430	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 6254	 0.00219	 0.01125	 0.0	 495.0	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 8957	 0.00018	 0.000599	 0.0	 495.0	 50503	 50503	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 8861	 0.00018	 0.000591	 0.0	 400.0	 51129	 51129	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 1734	 0.00019	 0.000581	 0.0	 438.0	 51675	 51675	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 3266	 0.000169	 0.000651	 0.0	 495.0	 46965	 46965	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 1974	 0.00231	 0.0138	 0.0	 457.0	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 1974	 0.00082	 0.003841	 0.0	 8043	 8043	 8043	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 177	 0.00305	 0.01762	 0.0	 495.0	 1767	 1767	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 5333	 0.01101	 0.055469	 0.0	 476.0	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 7901	 0.009169	 0.0462	 0.0	 533.0	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 7041	 0.00201	 0.00905	 0.0	 3408	 3408	 3408	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 2006	 0.005969	 0.038841	 0.0	 553.0	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 7761	 0.00474	 0.02687	 0.0	 438.0	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 5559	 0.005409	 0.03438	 0.0	 476.0	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 3211	 0.005401	 0.03264	 0.0	 572.0	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 8963	 0.00311	 0.015919	 0.0	 610.0	 1948	 1948	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 1770	 0.00462	 0.02613	 0.0	 419.0	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 1109	 0.01044	 0.05187	 0.0	 476.0	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 1109	 0.01001	 0.05113	 0.0	 476.0	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 8493	 0.008331	 0.051729	 0.0	 533.0	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 6280	 0.000169	 0.00089	 0.0	 438.0	 34869	 34869	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 3987	 0.00214	 0.01099	 0.0	 495.0	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 5825	 0.004669	 0.042349	 0.0	 476.0	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 7252	 0.00139	 0.008789	 0.0	 419.0	 3550	 3550	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 7252	 0.000219	 0.001669	 0.0	 495.0	 18766	 18766	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 177	 0.00119	 0.01063	 0.0	 2954	 2954	 2954	 0.0	 0.0	 1	 -30.0	 30.0;
	2410	 2006	 0.004169	 0.02724	 0.0	 514.0	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	2410	 2006	 0.004081	 0.025219	 0.0	 495.0	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	2410	 315	 0.00168	 0.01039	 0.0	 533.0	 3002	 3002	 0.0	 0.0	 1	 -30.0	 30.0;
	2410	 1489	 0.0017	 0.01055	 0.0	 495.0	 2956	 2956	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 5797	 0.00139	 0.008771	 0.0	 495.0	 3557	 3557	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 6381	 0.000651	 0.00261	 0.0	 476.0	 11743	 11743	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 6381	 0.000729	 0.00256	 0.0	 476.0	 11868	 11868	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 1239	 0.0	 0.008169	 0.0	 400.0	 3867	 3867	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 5643	 5e-05	 0.00025	 0.0	 438.0	 123896	 123896	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 7901	 0.003719	 0.022669	 0.0	 514.0	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 6415	 0.00732	 0.042711	 0.0	 476.0	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 6415	 0.003599	 0.025331	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 8998	 0.00494	 0.027401	 0.0	 533.0	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 6795	 0.0062	 0.03519	 0.0	 533.0	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 6795	 0.00739	 0.04574	 0.0	 438.0	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 3211	 0.006781	 0.034289	 0.0	 572.0	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	6795	 3054	 0.003669	 0.03205	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	6795	 3054	 0.002789	 0.026289	 0.0	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	6795	 2562	 0.005979	 0.031979	 0.0	 533.0	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 6254	 0.00425	 0.02132	 0.0	 553.0	 1453	 1453	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 1543	 0.002469	 0.015099	 0.0	 2065	 2065	 2065	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 8957	 0.004341	 0.02662	 0.0	 514.0	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 3266	 0.005219	 0.02287	 0.0	 610.0	 1347	 1347	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 7615	 0.0095	 0.04693	 0.0	 495.0	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 177	 0.01099	 0.052909	 0.0	 457.0	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 6415	 0.004901	 0.02949	 0.0	 533.0	 1057	 1057	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 4744	 0.00832	 0.038531	 0.0	 457.0	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 5669	 0.003909	 0.018091	 0.0	 381.0	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 3416	 0.000331	 0.00189	 0.0	 476.0	 16463	 16463	 0.0	 0.0	 1	 -30.0	 30.0;
	7901	 6415	 0.01101	 0.05514	 0.0	 495.0	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	7901	 7503	 0.00345	 0.01925	 0.0	 457.0	 1616	 1616	 0.0	 0.0	 1	 -30.0	 30.0;
	8459	 177	 0.00162	 0.00889	 0.0	 3496	 3496	 3496	 0.0	 0.0	 1	 -30.0	 30.0;
	8459	 8998	 0.00039	 0.00464	 0.0	 6784	 6784	 6784	 0.0	 0.0	 1	 -30.0	 30.0;
	8459	 5361	 0.00064	 0.010099	 0.0	 3122	 3122	 3122	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 5797	 0.003151	 0.01613	 0.0	 572.0	 1922	 1922	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 5797	 0.002091	 0.012409	 0.0	 629.0	 2511	 2511	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 9136	 0.0	 0.00799	 0.0	 3954	 3954	 3954	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 4650	 0.0	 0.00906	 0.0	 3487	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 7037	 0.000909	 0.010401	 0.0	 3026	 3026	 3026	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 2497	 0.003211	 0.016081	 0.0	 591.0	 1927	 1927	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 8861	 0.00314	 0.017711	 0.0	 457.0	 1757	 1757	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 1734	 0.00214	 0.010591	 0.0	 476.0	 2924	 2924	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 3211	 0.00056	 0.003169	 0.0	 9816	 9816	 9816	 0.0	 0.0	 1	 -30.0	 30.0;
	7252	 7236	 0.001719	 0.0108	 0.0	 514.0	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 3954	 0.0005	 0.00174	 0.0	 514.0	 17448	 17448	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 5643	 0.00126	 0.00587	 0.0	 419.0	 5262	 5262	 0.0	 0.0	 1	 -30.0	 30.0;
	6960	 2562	 0.007909	 0.03607	 0.0	 533.0	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	6960	 7037	 0.00057	 0.00457	 0.0	 6859	 6859	 6859	 0.0	 0.0	 1	 -30.0	 30.0;
	6960	 5643	 0.00132	 0.008409	 0.0	 400.0	 3711	 3711	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 2460	 0.003581	 0.017289	 0.0	 610.0	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 4744	 0.002711	 0.01526	 0.0	 476.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 6311	 0.00039	 0.006081	 0.0	 5184	 5184	 5184	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 5361	 0.00037	 0.005409	 0.0	 5827	 5827	 5827	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 7236	 0.00244	 0.013789	 0.0	 476.0	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 2497	 0.000349	 0.00149	 0.0	 533.0	 20641	 20641	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 6415	 0.00212	 0.010531	 0.0	 591.0	 2941	 2941	 0.0	 0.0	 1	 -30.0	 30.0;
	380	 5339	 0.003039	 0.031151	 0.0	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	380	 5669	 0.001831	 0.0187	 0.0	 1682	 1682	 1682	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 3932	 0.006599	 0.043169	 0.0	 438.0	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 5094	 0.006729	 0.046599	 0.0	 438.0	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 3623	 0.002159	 0.010789	 0.0	 476.0	 2871	 2871	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 785	 0.0022	 0.01057	 0.0	 476.0	 2926	 2926	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 1036	 0.003461	 0.02049	 0.0	 1521	 1521	 1521	 0.0	 0.0	 1	 -30.0	 30.0;
	8021	 698	 0.00311	 0.019469	 0.0	 495.0	 1603	 1603	 0.0	 0.0	 1	 -30.0	 30.0;
	8021	 628	 0.01064	 0.065969	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 315	 0.003539	 0.020479	 0.0	 495.0	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 1489	 0.00357	 0.020719	 0.0	 495.0	 1503	 1503	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 3932	 0.00275	 0.013831	 0.0	 457.0	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 5094	 0.0028	 0.013531	 0.0	 457.0	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	6415	 5669	 0.005151	 0.04851	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	6415	 8493	 0.005401	 0.025281	 0.0	 533.0	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	6415	 8493	 0.0055	 0.02475	 0.0	 514.0	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	7503	 5559	 0.00093	 0.00538	 0.0	 438.0	 5786	 5786	 0.0	 0.0	 1	 -30.0	 30.0;
	7041	 2006	 0.010331	 0.061849	 0.0	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	4712	 3623	 0.00686	 0.032771	 0.0	 476.0	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	4712	 785	 0.007	 0.032081	 0.0	 476.0	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 4170	 0.007729	 0.038099	 0.0	 813	 813	 813	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 698	 0.006581	 0.035281	 0.0	 572.0	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 698	 0.003711	 0.02651	 0.0	 533.0	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 4333	 0.00482	 0.021979	 0.0	 572.0	 1404	 1404	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 4333	 0.003979	 0.026099	 0.0	 533.0	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 8963	 0.0038	 0.017271	 0.0	 553.0	 1787	 1787	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 7661	 0.00626	 0.03626	 0.0	 629.0	 859	 859	 0.0	 0.0	 1	 -30.0	 30.0;
	8493	 628	 0.00538	 0.02588	 0.0	 572.0	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	8493	 628	 0.005479	 0.025341	 0.0	 553.0	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 3080	 0.00134	 0.01235	 0.0	 1218.0	 2543	 2543	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 536	 0.00127	 0.01399	 0.0	 1349.0	 2249	 2249	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 4393	 0.00142	 0.01374	 0.0	 1349.0	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	7827	 7969	 0.00039	 0.00365	 0.0	 1218.0	 8606	 8606	 0.0	 0.0	 1	 -30.0	 30.0;
	7827	 6760	 0.00058	 0.00507	 0.0	 1283.0	 6190	 6190	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 6298	 0.00129	 0.01577	 0.0	 1349.0	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 3007	 0.00033	 0.00373	 0.0	 1316.0	 8436	 8436	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 3265	 0.00086	 0.00799	 0.0	 1415.0	 3931	 3931	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 3265	 0.00189	 0.02135	 0.0	 1448.0	 1474	 1474	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 1774	 0.00106	 0.01219	 0.0	 1218.0	 2582	 2582	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 2899	 0.00147	 0.01622	 0.0	 1316.0	 1940	 1940	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 1703	 0.00215	 0.02108	 0.0	 1349.0	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 8088	 0.00063	 0.0052	 0.0	 1382.0	 6031	 6031	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 3265	 0.00159	 0.01792	 0.0	 1119.0	 1756	 1756	 0.0	 0.0	 1	 -30.0	 30.0;
	6298	 1774	 0.00157	 0.01981	 0.0	 1251.0	 1590	 1590	 0.0	 0.0	 1	 -30.0	 30.0;
	6298	 2899	 0.00158	 0.02014	 0.0	 1481.0	 1564	 1564	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 3080	 0.0018	 0.02388	 0.0	 1316.0	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 544	 0.00034	 0.00318	 0.0	 1349.0	 9877	 9877	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 7079	 0.00015	 0.00132	 0.0	 757.0	 23777	 23777	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 8601	 0.00014	 0.0015	 0.0	 757.0	 20968	 20968	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 1155	 0.00013	 0.00153	 0.0	 757.0	 20572	 20572	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 3256	 0.00013	 0.00156	 0.0	 757.0	 20179	 20179	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 5815	 0.0004	 0.00449	 0.0	 1283.0	 7008	 7008	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 5815	 0.00045	 0.0044	 0.0	 1152.0	 7142	 7142	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 1899	 0.0023	 0.01984	 0.0	 1185.0	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 9032	 0.0002	 0.00235	 0.0	 757.0	 13394	 13394	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 6004	 0.00019	 0.00239	 0.0	 757.0	 13175	 13175	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 7810	 0.00169	 0.01602	 0.0	 1316.0	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 8630	 0.00024	 0.00253	 0.0	 790.0	 12430	 12430	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 8183	 0.00022	 0.00244	 0.0	 757.0	 12894	 12894	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 6390	 0.00025	 0.00239	 0.0	 757.0	 13145	 13145	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 7969	 0.00066	 0.0061	 0.0	 1316.0	 5149	 5149	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 7969	 0.00062	 0.00844	 0.0	 1316.0	 3733	 3733	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 7860	 0.00124	 0.01353	 0.0	 1580.0	 2325	 2325	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 6187	 0.00046	 0.00452	 0.0	 1283.0	 6953	 6953	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 3265	 0.00045	 0.00531	 0.0	 1349.0	 5928	 5928	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 544	 0.00123	 0.01433	 0.0	 1152.0	 2197	 2197	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 7810	 0.00174	 0.01696	 0.0	 1448.0	 1853	 1853	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 6187	 0.00086	 0.00877	 0.0	 1382.0	 3585	 3585	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 6760	 0.00096	 0.00999	 0.0	 1218.0	 3148	 3148	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 4926	 0.00082	 0.00761	 0.0	 757.0	 4127	 4127	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 1703	 0.00185	 0.01803	 0.0	 1283.0	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 2031	 0.00138	 0.01246	 0.0	 1481.0	 2520	 2520	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 7980	 0.00062	 0.00605	 0.0	 1514.0	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 6760	 0.00073	 0.00817	 0.0	 757.0	 3851	 3851	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 7509	 0.00094	 0.00999	 0.0	 1316.0	 3148	 3148	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 3990	 0.00058	 0.00671	 0.0	 1218.0	 4691	 4691	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 1703	 0.00108	 0.01279	 0.0	 1349.0	 2461	 2461	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 7980	 0.00225	 0.02472	 0.0	 1273	 1273	 1273	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 4543	 0.00019	 0.00244	 0.0	 757.0	 12907	 12907	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 6340	 0.00018	 0.00248	 0.0	 757.0	 12704	 12704	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 261	 0.0001	 0.0011	 0.0	 757.0	 28598	 28598	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 2058	 0.00011	 0.00108	 0.0	 757.0	 29098	 29098	 0.0	 0.0	 1	 -30.0	 30.0;
	7860	 6187	 0.00089	 0.00815	 0.0	 1283.0	 3853	 3853	 0.0	 0.0	 1	 -30.0	 30.0;
	6080	 2899	 0.0009	 0.00859	 0.0	 1415.0	 3658	 3658	 0.0	 0.0	 1	 -30.0	 30.0;
	6080	 7509	 0.00167	 0.02239	 0.0	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 5263	 2e-05	 0.00024	 0.0	 757.0	 131160	 131160	 0.0	 0.0	 1	 -30.0	 30.0;
	1703	 138	 0.00157	 0.01326	 0.0	 1349.0	 2366	 2366	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 5562	 0.00155	 0.0139	 0.0	 1349.0	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	138	 2031	 0.00142	 0.01472	 0.0	 1349.0	 2136	 2136	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 2031	 0.00187	 0.02232	 0.0	 1411	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 1570	 0.00049	 0.00572	 0.0	 1349.0	 5503	 5503	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 1999	 0.0	 0.00021	 0.0	 757.0	 150416	 150416	 0.0	 0.0	 1	 -30.0	 30.0;
	7509	 3990	 0.00104	 0.00939	 0.0	 1349.0	 3344	 3344	 0.0	 0.0	 1	 -30.0	 30.0;
	7509	 7935	 0.00043	 0.0049	 0.0	 757.0	 6422	 6422	 0.0	 0.0	 1	 -30.0	 30.0;
	7509	 7935	 0.00049	 0.0048	 0.0	 757.0	 6547	 6547	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 1174	 0.002009	 0.01464	 0.0	 2138	 2138	 2138	 0.0	 0.0	 1	 -30.0	 30.0;
	1174	 3711	 0.003302	 0.026	 0.0	 1206	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	389	 4259	 0.006222	 0.018089	 0.0	 1652	 1652	 1652	 0.0	 0.0	 1	 -30.0	 30.0;
	3711	 7411	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3711	 2894	 8.9e-05	 0.000911	 0.0	 34509	 34509	 34509	 0.0	 0.0	 1	 -30.0	 30.0;
	8771	 7792	 1.8e-05	 0.000222	 0.0	 141820	 141820	 141820	 0.0	 0.0	 1	 -30.0	 30.0;
	6459	 7411	 0.00388	 0.014289	 0.0	 286.0	 2134	 2134	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 610	 0.001329	 0.007898	 0.0	 3944	 3944	 3944	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 4577	 0.00048	 0.002951	 0.0	 10566	 10566	 10566	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 8007	 8e-05	 0.00032	 0.0	 95764	 95764	 95764	 0.0	 0.0	 1	 -30.0	 30.0;
	2853	 5331	 0.000302	 0.001102	 0.0	 27645	 27645	 27645	 0.0	 0.0	 1	 -30.0	 30.0;
	6512	 304	 0.003742	 0.013098	 0.0	 2319	 2319	 2319	 0.0	 0.0	 1	 -30.0	 30.0;
	7569	 6135	 0.008911	 0.032298	 0.0	 943	 943	 943	 0.0	 0.0	 1	 -30.0	 30.0;
	5927	 6540	 0.00124	 0.005409	 0.0	 5693	 5693	 5693	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 7104	 0.0025	 0.0123	 0.0	 400.0	 2517	 2517	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 7104	 0.001781	 0.013729	 0.0	 400.0	 2282	 2282	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 4333	 0.00324	 0.016039	 0.0	 553.0	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	8998	 6311	 0.00037	 0.00474	 0.0	 6644	 6644	 6644	 0.0	 0.0	 1	 -30.0	 30.0;
	7761	 1770	 9.1e-05	 0.000521	 0.0	 419.0	 59725	 59725	 0.0	 0.0	 1	 -30.0	 30.0;
	6311	 5361	 3.1e-05	 0.00043	 0.0	 73269	 73269	 73269	 0.0	 0.0	 1	 -30.0	 30.0;
	1770	 7709	 0.001281	 0.005909	 0.0	 5225	 5225	 5225	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 5790	 0.000909	 0.00476	 0.0	 6519	 6519	 6519	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 5266	 0.00011	 0.000599	 0.0	 51867	 51867	 51867	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 7927	 0.000289	 0.001719	 0.0	 18122	 18122	 18122	 0.0	 0.0	 1	 -30.0	 30.0;
	7236	 4098	 0.00026	 0.001591	 0.0	 514.0	 19594	 19594	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 3990	 0.00108	 0.01382	 0.0	 1481.0	 2279	 2279	 0.0	 0.0	 1	 -30.0	 30.0;
	7329	 7661	 0.0	 0.0002	 0.0	 572.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2318	 5347	 0.014281	 0.033446	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	6361	 5347	 0.038273	 0.11138	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 215	 0.039504	 0.11795	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 2798	 0.039893	 0.095083	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 5313	 0.025107	 0.052256	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	1762	 4607	 0.010124	 0.017818	 0.0	 1542	 1542	 1542	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 6834	 0.035198	 0.083893	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	6834	 6517	 0.026149	 0.064851	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	7201	 7419	 0.0	 0.000793	 0.0	 39833	 39833	 39833	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 7201	 0.02086	 0.051744	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 7419	 0.041992	 0.117446	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 5050	 0.014031	 0.079591	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	5050	 3362	 0.0075	 0.054099	 0.0	 400.0	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	3441	 5050	 0.013841	 0.0733	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	5050	 2086	 0.006469	 0.041401	 0.0	 438.0	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 2592	 0.005628	 0.015826	 0.0	 1881	 1881	 1881	 0.0	 0.0	 1	 -30.0	 30.0;
	8645	 1996	 0.026364	 0.056017	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 3752	 0.026099	 0.062182	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 5227	 0.04481	 0.131231	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 2592	 0.005512	 0.01614	 0.0	 1853	 1853	 1853	 0.0	 0.0	 1	 -30.0	 30.0;
	8645	 1298	 0.023488	 0.063479	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 6250	 0.044198	 0.129446	 0.0	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	902	 1424	 0.006612	 0.01657	 0.0	 1771	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	2744	 902	 0.003967	 0.007521	 0.0	 3715	 3715	 3715	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 6338	 0.027496	 0.067438	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 5811	 0.044587	 0.102702	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 4486	 0.051438	 0.143868	 0.0	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 9017	 0.029256	 0.072579	 0.0	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 5811	 0.049149	 0.122653	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 5811	 0.043372	 0.125157	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	6991	 5811	 0.016471	 0.042529	 0.0	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	7486	 62	 0.0	 0.00076	 0.0	 41563	 41563	 41563	 0.0	 0.0	 1	 -30.0	 30.0;
	62	 4451	 0.038017	 0.110653	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 62	 0.025174	 0.07938	 0.0	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	5474	 62	 0.043017	 0.128446	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 7486	 0.051636	 0.189413	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	7486	 3527	 0.04714	 0.113008	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	2830	 7486	 0.008149	 0.025711	 0.0	 1172	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 653	 0.039686	 0.102843	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	7109	 653	 0.006372	 0.01857	 0.0	 1609	 1609	 1609	 0.0	 0.0	 1	 -30.0	 30.0;
	653	 4653	 0.045711	 0.108901	 0.0	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	1192	 1472	 0.04119	 0.106331	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	3369	 1192	 0.013752	 0.03024	 0.0	 951	 951	 951	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 4696	 0.00595	 0.019008	 0.0	 1586	 1586	 1586	 0.0	 0.0	 1	 -30.0	 30.0;
	4696	 7930	 0.00576	 0.020331	 0.0	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	2857	 8018	 0.03586	 0.082107	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	428	 2857	 0.022223	 0.055099	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3128	 6642	 0.008802	 0.02862	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	6642	 7549	 0.032719	 0.124942	 0.0	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 8235	 0.019793	 0.055331	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	8235	 8241	 0.01395	 0.034612	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	3682	 2209	 0.004727	 0.010107	 0.0	 2831	 2831	 2831	 0.0	 0.0	 1	 -30.0	 30.0;
	8720	 3682	 0.007289	 0.014364	 0.0	 1962	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 4045	 0.004818	 0.009901	 0.0	 2869	 2869	 2869	 0.0	 0.0	 1	 -30.0	 30.0;
	468	 5221	 0.012223	 0.031554	 0.0	 934	 934	 934	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 3142	 0.00108	 0.01189	 0.0	 1349.0	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	971	 1360	 0.0032	 0.03265	 0.0	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	6710	 1360	 0.0007	 0.00731	 0.0	 1415.0	 4302	 4302	 0.0	 0.0	 1	 -30.0	 30.0;
	2537	 5741	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	2537	 4213	 0.009248	 0.022041	 0.0	 1322	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 8586	 0.008124	 0.02286	 0.0	 1302	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	8476	 7518	 0.007702	 0.019893	 0.0	 1481	 1481	 1481	 0.0	 0.0	 1	 -30.0	 30.0;
	7518	 7308	 0.015579	 0.04914	 0.0	 613	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	8820	 3120	 0.00981	 0.068021	 0.0	 381.0	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	8820	 1695	 0.006341	 0.042211	 0.0	 400.0	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 6205	 0.060281	 0.144512	 0.0	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 6205	 0.061438	 0.141504	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	6205	 2744	 0.016579	 0.039917	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	1583	 3733	 0.0	 0.000843	 0.0	 37471	 37471	 37471	 0.0	 0.0	 1	 -30.0	 30.0;
	2239	 1583	 0.010256	 0.022711	 0.0	 1268	 1268	 1268	 0.0	 0.0	 1	 -30.0	 30.0;
	1583	 4862	 0.024983	 0.073149	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	3733	 4263	 0.008388	 0.02557	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	2565	 2868	 0.063512	 0.200339	 0.0	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 2565	 0.037562	 0.085967	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 746	 0.002579	 0.007752	 0.0	 3867	 3867	 3867	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 746	 0.001777	 0.00495	 0.0	 6006	 6006	 6006	 0.0	 0.0	 1	 -30.0	 30.0;
	6614	 6815	 0.030248	 0.084612	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	6815	 8666	 0.013281	 0.037124	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 8313	 0.009488	 0.023521	 0.0	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 8313	 0.022579	 0.058314	 0.0	 506	 506	 506	 0.0	 0.0	 1	 -30.0	 30.0;
	4560	 4833	 0.02743	 0.062793	 0.0	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 4560	 0.001719	 0.003777	 0.0	 7612	 7612	 7612	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 1988	 0.035992	 0.085876	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	2442	 2774	 0.008777	 0.01962	 0.0	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 8062	 0.001793	 0.001521	 0.0	 13435	 13435	 13435	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 2275	 0.004917	 0.007702	 0.0	 3457	 3457	 3457	 0.0	 0.0	 1	 -30.0	 30.0;
	7126	 4227	 0.001521	 0.004554	 0.0	 6579	 6579	 6579	 0.0	 0.0	 1	 -30.0	 30.0;
	508	 4227	 0.011198	 0.041099	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	1732	 67	 0.00144	 0.01155	 0.0	 1218.0	 2714	 2714	 0.0	 0.0	 1	 -30.0	 30.0;
	1732	 6449	 0.00123	 0.01345	 0.0	 1053.0	 2339	 2339	 0.0	 0.0	 1	 -30.0	 30.0;
	456	 6247	 0.007669	 0.02419	 0.0	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	456	 189	 0.003661	 0.008769	 0.0	 3325	 3325	 3325	 0.0	 0.0	 1	 -30.0	 30.0;
	8643	 456	 0.00943	 0.036008	 0.0	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 456	 0.012661	 0.037802	 0.0	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 799	 0.006083	 0.024099	 0.0	 1271	 1271	 1271	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 1158	 0.002248	 0.004248	 0.0	 6573	 6573	 6573	 0.0	 0.0	 1	 -30.0	 30.0;
	1756	 4746	 0.019651	 0.141771	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4746	 3640	 0.004841	 0.02718	 0.0	 400.0	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	4746	 3640	 0.00493	 0.02661	 0.0	 419.0	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 4746	 0.008729	 0.04569	 0.0	 400.0	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	8844	 7067	 0.002529	 0.005793	 0.0	 4998	 4998	 4998	 0.0	 0.0	 1	 -30.0	 30.0;
	7067	 6106	 0.003579	 0.007876	 0.0	 3652	 3652	 3652	 0.0	 0.0	 1	 -30.0	 30.0;
	8208	 850	 0.014182	 0.03119	 0.0	 922	 922	 922	 0.0	 0.0	 1	 -30.0	 30.0;
	8208	 3805	 0.061124	 0.192777	 0.0	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 4682	 0.114603	 0.284256	 0.0	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 7613	 0.00786	 0.019488	 0.0	 1504	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	8844	 8594	 0.002669	 0.006124	 0.0	 4729	 4729	 4729	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 5039	 0.00895	 0.022182	 0.0	 1321	 1321	 1321	 0.0	 0.0	 1	 -30.0	 30.0;
	5039	 233	 0.002281	 0.008033	 0.0	 3783	 3783	 3783	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 850	 0.005314	 0.013719	 0.0	 2148	 2148	 2148	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 5447	 0.031521	 0.069298	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 8594	 0.003719	 0.013223	 0.0	 2300	 2300	 2300	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 233	 0.009719	 0.027818	 0.0	 1072	 1072	 1072	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 3952	 0.042669	 0.127397	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 6712	 0.031157	 0.077281	 0.0	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	6106	 850	 0.00319	 0.008934	 0.0	 3330	 3330	 3330	 0.0	 0.0	 1	 -30.0	 30.0;
	850	 6592	 0.01462	 0.046124	 0.0	 653	 653	 653	 0.0	 0.0	 1	 -30.0	 30.0;
	8251	 4421	 0.007587	 0.018628	 0.0	 1571	 1571	 1571	 0.0	 0.0	 1	 -30.0	 30.0;
	7397	 8251	 0.024529	 0.052826	 0.0	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 5071	 0.041223	 0.115314	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 2723	 0.022512	 0.051521	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	7109	 5103	 0.063537	 0.189702	 0.0	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 5582	 0.01524	 0.045496	 0.0	 659	 659	 659	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 5582	 0.035876	 0.092612	 0.0	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	6247	 5306	 0.015471	 0.046198	 0.0	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	8424	 5646	 0.043364	 0.152818	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 5646	 0.03095	 0.100686	 0.0	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 5646	 0.035628	 0.107959	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 6614	 0.010901	 0.034397	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	3444	 2792	 0.026099	 0.060099	 0.0	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 3444	 0.025942	 0.057008	 0.0	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	8884	 1619	 0.001901	 0.004636	 0.0	 6305	 6305	 6305	 0.0	 0.0	 1	 -30.0	 30.0;
	1619	 8755	 0.00176	 0.003124	 0.0	 8810	 8810	 8810	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 2868	 0.003876	 0.010909	 0.0	 2729	 2729	 2729	 0.0	 0.0	 1	 -30.0	 30.0;
	2868	 713	 0.003802	 0.011124	 0.0	 2687	 2687	 2687	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 2868	 0.013339	 0.029298	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	1849	 2868	 0.031719	 0.11181	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 3706	 0.021521	 0.05557	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	4223	 3373	 0.037008	 0.107752	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	6513	 1961	 0.05743	 0.142463	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	6513	 1548	 0.036091	 0.074041	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	7889	 4187	 0.001211	 0.00545	 0.0	 514.0	 5658	 5658	 0.0	 0.0	 1	 -30.0	 30.0;
	2108	 4187	 0.013711	 0.078669	 0.0	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	1245	 4546	 0.050521	 0.125331	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	4546	 5231	 0.085818	 0.221579	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	4546	 5614	 0.014909	 0.034132	 0.0	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	4546	 4764	 0.035826	 0.113033	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 6341	 0.008289	 0.026017	 0.0	 1157	 1157	 1157	 0.0	 0.0	 1	 -30.0	 30.0;
	3986	 6341	 0.023339	 0.089587	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 2383	 0.00661	 0.039521	 0.0	 419.0	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 3731	 0.00349	 0.01574	 0.0	 419.0	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 6800	 0.03714	 0.088496	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 3893	 0.037256	 0.087669	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 4584	 0.03081	 0.07957	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 5336	 0.033248	 0.096818	 0.0	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	9093	 5336	 0.011479	 0.034298	 0.0	 874	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	4837	 1091	 0.0	 0.000893	 0.0	 35373	 35373	 35373	 0.0	 0.0	 1	 -30.0	 30.0;
	4837	 3393	 0.019273	 0.042628	 0.0	 676	 676	 676	 0.0	 0.0	 1	 -30.0	 30.0;
	4837	 3732	 0.019628	 0.041702	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	5955	 4837	 0.029512	 0.062719	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 1091	 0.034901	 0.105744	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	2246	 1091	 0.026289	 0.071083	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	560	 1091	 0.041893	 0.121942	 0.0	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2156	 5071	 0.024851	 0.071711	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	7365	 6441	 0.006512	 0.01681	 0.0	 1753	 1753	 1753	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 7365	 0.00305	 0.009099	 0.0	 3292	 3292	 3292	 0.0	 0.0	 1	 -30.0	 30.0;
	1446	 7216	 0.014678	 0.04105	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	6305	 1446	 0.054149	 0.119066	 0.0	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	8302	 4667	 0.08557	 0.197909	 0.0	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	8840	 8302	 0.038314	 0.075496	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	6515	 8271	 0.036554	 0.115289	 0.0	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2464	 6515	 0.047636	 0.11019	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	2238	 2773	 0.0	 0.000826	 0.0	 38242	 38242	 38242	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 2773	 0.013397	 0.037488	 0.0	 794	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	2238	 925	 0.03095	 0.079917	 0.0	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 2238	 0.014058	 0.032198	 0.0	 900	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	4756	 9199	 0.03086	 0.093488	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	6305	 4756	 0.023669	 0.071066	 0.0	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	6305	 4756	 0.028083	 0.078537	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	788	 2352	 0.016661	 0.052554	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	2352	 8127	 0.022223	 0.050868	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	336	 1070	 0.017	 0.043909	 0.0	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	1070	 8148	 0.017727	 0.05595	 0.0	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	620	 1536	 0.022223	 0.052967	 0.0	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	3642	 1536	 0.027628	 0.071347	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 4585	 0.0	 0.00081	 0.0	 38997	 38997	 38997	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 8949	 0.002983	 0.010149	 0.0	 2987	 2987	 2987	 0.0	 0.0	 1	 -30.0	 30.0;
	2567	 6063	 0.008678	 0.023463	 0.0	 1263	 1263	 1263	 0.0	 0.0	 1	 -30.0	 30.0;
	4585	 215	 0.002917	 0.010347	 0.0	 2939	 2939	 2939	 0.0	 0.0	 1	 -30.0	 30.0;
	2567	 4585	 0.008512	 0.023917	 0.0	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 3965	 0.003603	 0.011339	 0.0	 2655	 2655	 2655	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 2318	 0.006347	 0.015132	 0.0	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 5725	 0.027777	 0.08295	 0.0	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 3077	 0.045438	 0.105124	 0.0	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	3077	 7747	 0.07486	 0.187603	 0.0	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 4949	 0.01919	 0.053198	 0.0	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	8289	 4949	 0.008488	 0.032421	 0.0	 943	 943	 943	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 7418	 0.00365	 0.03434	 0.0	 1053.0	 1396	 1396	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 7418	 0.0049	 0.04432	 0.0	 1081	 1081	 1081	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 3365	 0.000901	 0.005539	 0.0	 5629	 5629	 5629	 0.0	 0.0	 1	 -30.0	 30.0;
	2152	 3120	 0.00894	 0.06106	 0.0	 438.0	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 1764	 0.006919	 0.049419	 0.0	 381.0	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 2251	 0.006771	 0.04576	 0.0	 476.0	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 3328	 0.0	 0.000793	 0.0	 39833	 39833	 39833	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 8348	 0.019628	 0.061364	 0.0	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 6353	 0.011727	 0.033826	 0.0	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	3328	 5964	 0.006438	 0.01943	 0.0	 1544	 1544	 1544	 0.0	 0.0	 1	 -30.0	 30.0;
	3328	 5964	 0.006562	 0.019033	 0.0	 1569	 1569	 1569	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 3328	 0.006421	 0.020893	 0.0	 1446	 1446	 1446	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 4736	 0.00031	 0.00355	 0.0	 1251.0	 8865	 8865	 0.0	 0.0	 1	 -30.0	 30.0;
	4282	 2111	 0.016752	 0.046397	 0.0	 641	 641	 641	 0.0	 0.0	 1	 -30.0	 30.0;
	3250	 4282	 0.009347	 0.035702	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 8351	 0.011298	 0.040033	 0.0	 760	 760	 760	 0.0	 0.0	 1	 -30.0	 30.0;
	8754	 1297	 0.001298	 0.004322	 0.0	 7000	 7000	 7000	 0.0	 0.0	 1	 -30.0	 30.0;
	7703	 1297	 0.000347	 0.000876	 0.0	 33525	 33525	 33525	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 841	 0.00028	 0.00301	 0.0	 757.0	 14595	 14595	 0.0	 0.0	 1	 -30.0	 30.0;
	67	 2427	 0.00297	 0.02796	 0.0	 1086.0	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 3192	 0.00274	 0.03157	 0.0	 1020.0	 1393	 1393	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 831	 0.00286	 0.010554	 0.0	 2889	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 9209	 0.025818	 0.091446	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 6265	 0.027066	 0.065554	 0.0	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 2845	 0.086198	 0.151504	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	753	 6265	 0.010893	 0.02719	 0.0	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	5981	 6265	 0.03162	 0.072818	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	6770	 831	 0.002802	 0.010752	 0.0	 2843	 2843	 2843	 0.0	 0.0	 1	 -30.0	 30.0;
	6770	 8705	 0.054802	 0.152636	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	6770	 6975	 0.014223	 0.048397	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 6770	 0.01814	 0.043521	 0.0	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	6770	 3964	 0.038248	 0.07586	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 6849	 0.017331	 0.061314	 0.0	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	3338	 6849	 0.009182	 0.032339	 0.0	 940	 940	 940	 0.0	 0.0	 1	 -30.0	 30.0;
	841	 4396	 0.00281	 0.02539	 0.0	 1053.0	 1728	 1728	 0.0	 0.0	 1	 -30.0	 30.0;
	6729	 4396	 0.00158	 0.01426	 0.0	 1053.0	 3360	 3360	 0.0	 0.0	 1	 -30.0	 30.0;
	6317	 3570	 0.0	 0.000211	 0.0	 476.0	 149704	 149704	 0.0	 0.0	 1	 -30.0	 30.0;
	9218	 6317	 0.00888	 0.061021	 0.0	 419.0	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	6317	 1764	 0.006961	 0.04406	 0.0	 709	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 9005	 0.00869	 0.06218	 0.0	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 7271	 0.002401	 0.027581	 0.0	 438.0	 1141	 1141	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 2251	 0.00682	 0.04493	 0.0	 438.0	 696	 696	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 8025	 0.00238	 0.009446	 0.0	 3243	 3243	 3243	 0.0	 0.0	 1	 -30.0	 30.0;
	7397	 3434	 0.017653	 0.060008	 0.0	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	7344	 3031	 0.01838	 0.051397	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 677	 0.02995	 0.071388	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 3899	 0.023223	 0.042223	 0.0	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	3899	 633	 0.018636	 0.052124	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	6729	 2707	 0.00096	 0.01102	 0.0	 1218.0	 2856	 2856	 0.0	 0.0	 1	 -30.0	 30.0;
	2707	 5009	 0.00364	 0.02923	 0.0	 1073	 1073	 1073	 0.0	 0.0	 1	 -30.0	 30.0;
	2707	 2226	 0.00248	 0.02649	 0.0	 1020.0	 1188	 1188	 0.0	 0.0	 1	 -30.0	 30.0;
	7017	 2707	 0.00384	 0.04229	 0.0	 744	 744	 744	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 2534	 0.0	 0.000219	 0.0	 144235	 144235	 144235	 0.0	 0.0	 1	 -30.0	 30.0;
	9218	 2534	 0.00344	 0.02181	 0.0	 514.0	 1431	 1431	 0.0	 0.0	 1	 -30.0	 30.0;
	2534	 9005	 0.00337	 0.02224	 0.0	 476.0	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	2534	 204	 0.010521	 0.05913	 0.0	 400.0	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	2534	 545	 0.00081	 0.005341	 0.0	 438.0	 5848	 5848	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 2275	 0.002579	 0.00476	 0.0	 5835	 5835	 5835	 0.0	 0.0	 1	 -30.0	 30.0;
	8918	 3029	 0.004388	 0.01595	 0.0	 1910	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 7048	 0.004752	 0.017868	 0.0	 1709	 1709	 1709	 0.0	 0.0	 1	 -30.0	 30.0;
	1176	 4669	 0.00338	 0.012959	 0.0	 2359	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	7909	 1176	 0.007008	 0.02338	 0.0	 1295	 1295	 1295	 0.0	 0.0	 1	 -30.0	 30.0;
	5978	 4443	 0.025347	 0.057942	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	3847	 5978	 0.06314	 0.162959	 0.0	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 3043	 0.007967	 0.023802	 0.0	 1259	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	6571	 3833	 0.006636	 0.016463	 0.0	 1780	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	4989	 7588	 0.012091	 0.022893	 0.0	 1221	 1221	 1221	 0.0	 0.0	 1	 -30.0	 30.0;
	4989	 3700	 0.012322	 0.022388	 0.0	 1237	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	6144	 6805	 0.016529	 0.049347	 0.0	 607	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	8377	 8754	 0.00119	 0.007017	 0.0	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	8377	 4617	 0.002331	 0.009636	 0.0	 3187	 3187	 3187	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 1797	 0.008091	 0.02681	 0.0	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	1412	 1797	 0.001347	 0.006876	 0.0	 4509	 4509	 4509	 0.0	 0.0	 1	 -30.0	 30.0;
	7703	 1797	 0.002281	 0.009818	 0.0	 3134	 3134	 3134	 0.0	 0.0	 1	 -30.0	 30.0;
	400	 8024	 0.001149	 0.00243	 0.0	 11752	 11752	 11752	 0.0	 0.0	 1	 -30.0	 30.0;
	3559	 400	 0.002909	 0.006909	 0.0	 4214	 4214	 4214	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 2207	 0.000413	 0.000959	 0.0	 30252	 30252	 30252	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 2207	 0.000421	 0.000942	 0.0	 30614	 30614	 30614	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 7598	 0.024628	 0.073504	 0.0	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	7598	 6339	 0.041496	 0.094992	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	3310	 447	 0.01	 0.021273	 0.0	 1344	 1344	 1344	 0.0	 0.0	 1	 -30.0	 30.0;
	447	 1849	 0.030479	 0.08795	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	447	 1849	 0.031157	 0.094992	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	8572	 6177	 0.00962	 0.023298	 0.0	 1254	 1254	 1254	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 8572	 0.018248	 0.040397	 0.0	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	6792	 5621	 0.005868	 0.01781	 0.0	 1685	 1685	 1685	 0.0	 0.0	 1	 -30.0	 30.0;
	6792	 9020	 0.01	 0.02814	 0.0	 1058	 1058	 1058	 0.0	 0.0	 1	 -30.0	 30.0;
	6792	 37	 0.016562	 0.052033	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	6792	 37	 0.016893	 0.050967	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	5621	 3639	 0.013281	 0.033149	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 1306	 0.005463	 0.020008	 0.0	 1523	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 5249	 0.02695	 0.066868	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	3639	 5076	 0.002752	 0.008397	 0.0	 3575	 3575	 3575	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 5076	 0.002686	 0.007777	 0.0	 3840	 3840	 3840	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 37	 0.019099	 0.057876	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 3908	 0.017339	 0.043008	 0.0	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	1306	 37	 0.017843	 0.068107	 0.0	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	588	 8735	 0.022289	 0.070314	 0.0	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	8735	 2311	 0.035008	 0.101917	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	1405	 991	 0.045231	 0.147174	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 991	 0.011413	 0.03424	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	7142	 2259	 0.001124	 0.002579	 0.0	 11228	 11228	 11228	 0.0	 0.0	 1	 -30.0	 30.0;
	7142	 6105	 0.046909	 0.135298	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	7142	 4984	 0.035446	 0.075124	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	8363	 7142	 0.011107	 0.025793	 0.0	 1125	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	7142	 9078	 0.005983	 0.023752	 0.0	 1290	 1290	 1290	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 3453	 0.016132	 0.04695	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 3453	 0.008008	 0.019083	 0.0	 1527	 1527	 1527	 0.0	 0.0	 1	 -30.0	 30.0;
	4311	 463	 0.034281	 0.088488	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	463	 5045	 0.009149	 0.036372	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	463	 4759	 0.008711	 0.024124	 0.0	 1232	 1232	 1232	 0.0	 0.0	 1	 -30.0	 30.0;
	463	 1532	 0.03624	 0.109818	 0.0	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	6105	 2259	 0.036777	 0.116041	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	8018	 8533	 0.003851	 0.00995	 0.0	 2961	 2961	 2961	 0.0	 0.0	 1	 -30.0	 30.0;
	8018	 8482	 0.025793	 0.056702	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 8018	 0.027942	 0.061421	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	8533	 8922	 0.021488	 0.047248	 0.0	 609	 609	 609	 0.0	 0.0	 1	 -30.0	 30.0;
	7506	 3142	 0.00015	 0.00136	 0.0	 1251.0	 23086	 23086	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 9035	 0.016909	 0.037174	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 1195	 0.040496	 0.088512	 0.0	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 566	 0.035231	 0.111132	 0.0	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	2198	 4960	 0.031017	 0.086752	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	3965	 2318	 0.003983	 0.014017	 0.0	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	6706	 996	 0.003521	 0.010496	 0.0	 2854	 2854	 2854	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 996	 0.002686	 0.00805	 0.0	 3723	 3723	 3723	 0.0	 0.0	 1	 -30.0	 30.0;
	6881	 1045	 0.05195	 0.145298	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	3079	 7469	 0.023207	 0.053132	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	2115	 3079	 0.049587	 0.150256	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 1472	 0.036719	 0.111298	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	508	 2560	 0.008364	 0.023207	 0.0	 1281	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	1412	 6037	 0.005256	 0.024653	 0.0	 1254	 1254	 1254	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 6037	 0.001347	 0.004397	 0.0	 6869	 6869	 6869	 0.0	 0.0	 1	 -30.0	 30.0;
	8754	 6919	 0.005149	 0.022826	 0.0	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 6919	 0.001207	 0.004992	 0.0	 6151	 6151	 6151	 0.0	 0.0	 1	 -30.0	 30.0;
	3805	 5074	 0.003934	 0.009744	 0.0	 3006	 3006	 3006	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 7216	 0.01438	 0.04186	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	1424	 1834	 0.005744	 0.014967	 0.0	 1971	 1971	 1971	 0.0	 0.0	 1	 -30.0	 30.0;
	6245	 282	 0.00176	 0.01659	 0.0	 1086.0	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 282	 0.00151	 0.01378	 0.0	 1185.0	 2279	 2279	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 282	 0.00128	 0.01392	 0.0	 1152.0	 2260	 2260	 0.0	 0.0	 1	 -30.0	 30.0;
	282	 3729	 0.00052	 0.00397	 0.0	 1185.0	 7890	 7890	 0.0	 0.0	 1	 -30.0	 30.0;
	2226	 282	 0.00221	 0.02248	 0.0	 1152.0	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	7109	 6801	 0.007182	 0.017107	 0.0	 1703	 1703	 1703	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 4102	 0.005149	 0.011339	 0.0	 2537	 2537	 2537	 0.0	 0.0	 1	 -30.0	 30.0;
	8586	 4213	 0.00943	 0.02157	 0.0	 1342	 1342	 1342	 0.0	 0.0	 1	 -30.0	 30.0;
	7166	 4421	 0.040636	 0.11257	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	7585	 7166	 0.014496	 0.042231	 0.0	 708	 708	 708	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 831	 0.002744	 0.00995	 0.0	 3061	 3061	 3061	 0.0	 0.0	 1	 -30.0	 30.0;
	831	 6580	 0.003099	 0.009752	 0.0	 3087	 3087	 3087	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 8815	 0.007322	 0.016744	 0.0	 1729	 1729	 1729	 0.0	 0.0	 1	 -30.0	 30.0;
	5906	 8815	 0.03024	 0.069231	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	6733	 1361	 0.008438	 0.018669	 0.0	 1542	 1542	 1542	 0.0	 0.0	 1	 -30.0	 30.0;
	1361	 508	 0.006727	 0.027942	 0.0	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	1361	 508	 0.006587	 0.028488	 0.0	 1081	 1081	 1081	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 2515	 0.014579	 0.040463	 0.0	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	7899	 2515	 0.012826	 0.036992	 0.0	 807	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	2515	 4930	 0.006909	 0.019917	 0.0	 1499	 1499	 1499	 0.0	 0.0	 1	 -30.0	 30.0;
	6242	 7909	 0.003421	 0.011041	 0.0	 2733	 2733	 2733	 0.0	 0.0	 1	 -30.0	 30.0;
	6242	 8918	 0.005364	 0.016289	 0.0	 1842	 1842	 1842	 0.0	 0.0	 1	 -30.0	 30.0;
	4443	 4179	 0.012463	 0.030909	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	4443	 4179	 0.012702	 0.030273	 0.0	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	7040	 4179	 0.008331	 0.02438	 0.0	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	7536	 4179	 0.008149	 0.024843	 0.0	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	1669	 1821	 0.010789	 0.071169	 0.0	 400.0	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	3853	 1821	 0.011901	 0.08499	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	2156	 4359	 0.035942	 0.113397	 0.0	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	2723	 2156	 0.035818	 0.078752	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	2156	 4441	 0.052587	 0.147083	 0.0	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	6571	 1658	 0.007273	 0.016661	 0.0	 1738	 1738	 1738	 0.0	 0.0	 1	 -30.0	 30.0;
	3161	 1658	 0.023488	 0.072488	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	8922	 3132	 0.004207	 0.011777	 0.0	 2526	 2526	 2526	 0.0	 0.0	 1	 -30.0	 30.0;
	8482	 3132	 0.005339	 0.020388	 0.0	 1499	 1499	 1499	 0.0	 0.0	 1	 -30.0	 30.0;
	7993	 1302	 0.007446	 0.01638	 0.0	 1756	 1756	 1756	 0.0	 0.0	 1	 -30.0	 30.0;
	3059	 1302	 0.023033	 0.057124	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	189	 2691	 0.030198	 0.095248	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	6285	 5126	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 6285	 0.003628	 0.012	 0.0	 2520	 2520	 2520	 0.0	 0.0	 1	 -30.0	 30.0;
	6285	 3902	 0.00681	 0.028273	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 5724	 0.006669	 0.028826	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 1535	 0.04543	 0.100521	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 1535	 0.046273	 0.098331	 0.0	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	2333	 1535	 0.005041	 0.014554	 0.0	 2051	 2051	 2051	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 4780	 0.007818	 0.021653	 0.0	 1373	 1373	 1373	 0.0	 0.0	 1	 -30.0	 30.0;
	4780	 5335	 0.041992	 0.154033	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4273	 224	 0.003711	 0.009612	 0.0	 3066	 3066	 3066	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 4273	 0.009959	 0.025719	 0.0	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	7549	 224	 0.006744	 0.014314	 0.0	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 6711	 0.023909	 0.052901	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	6711	 6672	 0.024347	 0.051752	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 949	 0.04324	 0.088702	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 533	 0.045223	 0.125488	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 1316	 0.00305	 0.007893	 0.0	 3733	 3733	 3733	 0.0	 0.0	 1	 -30.0	 30.0;
	4364	 8402	 0.01905	 0.060107	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	8402	 8812	 0.023471	 0.055934	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	7902	 2258	 0.004893	 0.014339	 0.0	 2085	 2085	 2085	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 6786	 0.022934	 0.050397	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 7265	 0.037248	 0.081901	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	1321	 7265	 0.013347	 0.039083	 0.0	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	4988	 7265	 0.013058	 0.039818	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	7211	 8780	 0.04038	 0.11757	 0.0	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	8780	 7549	 0.037397	 0.111653	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	47	 2221	 0.029273	 0.069752	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	47	 2609	 0.023678	 0.070702	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 6800	 0.001868	 0.005463	 0.0	 5472	 5472	 5472	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 4335	 0.00048	 0.00423	 0.0	 1152.0	 7420	 7420	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 8777	 0.003992	 0.010289	 0.0	 2863	 2863	 2863	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 3350	 0.003777	 0.009413	 0.0	 3115	 3115	 3115	 0.0	 0.0	 1	 -30.0	 30.0;
	6339	 5849	 0.015091	 0.047174	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	7930	 3804	 0.013826	 0.039917	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	7930	 617	 0.015678	 0.039124	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	7930	 6105	 0.066851	 0.192818	 0.0	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	7930	 9078	 0.039653	 0.128983	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	8777	 4976	 0.005091	 0.009702	 0.0	 2883	 2883	 2883	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 1048	 0.004066	 0.010083	 0.0	 2906	 2906	 2906	 0.0	 0.0	 1	 -30.0	 30.0;
	1048	 3804	 0.007661	 0.024058	 0.0	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 3804	 0.045636	 0.13286	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	3350	 1048	 0.018421	 0.042868	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	1865	 5619	 0.00805	 0.04211	 0.0	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 4375	 0.003211	 0.02194	 0.0	 381.0	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 4327	 0.00974	 0.05531	 0.0	 438.0	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	9209	 1796	 0.019719	 0.05495	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 2404	 0.03495	 0.086686	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	6305	 2404	 0.041149	 0.122851	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	3904	 596	 0.01124	 0.027893	 0.0	 1051	 1051	 1051	 0.0	 0.0	 1	 -30.0	 30.0;
	4726	 1455	 0.02219	 0.057281	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 857	 0.011843	 0.030529	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	949	 633	 0.014298	 0.039983	 0.0	 744	 744	 744	 0.0	 0.0	 1	 -30.0	 30.0;
	8940	 4443	 0.008083	 0.028636	 0.0	 1062	 1062	 1062	 0.0	 0.0	 1	 -30.0	 30.0;
	7040	 4443	 0.012942	 0.02962	 0.0	 978	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	2651	 5816	 0.01657	 0.050017	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 2651	 0.006331	 0.019107	 0.0	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	8705	 3986	 0.003983	 0.013537	 0.0	 2239	 2239	 2239	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 6245	 0.00136	 0.01515	 0.0	 954.0	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 9020	 0.007876	 0.01743	 0.0	 1652	 1652	 1652	 0.0	 0.0	 1	 -30.0	 30.0;
	7224	 215	 0.018636	 0.055653	 0.0	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	2691	 7224	 0.010554	 0.031504	 0.0	 951	 951	 951	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 1740	 0.013488	 0.039686	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 5068	 0.021934	 0.048198	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 8071	 0.0	 0.00086	 0.0	 36730	 36730	 36730	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 8499	 0.026463	 0.075669	 0.0	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 967	 0.029446	 0.081364	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 1858	 0.055851	 0.127826	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 8071	 0.047818	 0.124744	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 3970	 0.02562	 0.063256	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	3970	 2993	 0.006372	 0.012298	 0.0	 2281	 2281	 2281	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 2747	 0.009603	 0.021099	 0.0	 1363	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	8922	 6974	 0.014917	 0.052579	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	741	 6974	 0.03014	 0.083512	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	7294	 6082	 0.03319	 0.092818	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 6788	 0.024248	 0.067826	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	7866	 8314	 0.048529	 0.153091	 0.0	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	3451	 7866	 0.055397	 0.137421	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	9227	 6787	 0.0	 0.000219	 0.0	 400.0	 144235	 144235	 0.0	 0.0	 1	 -30.0	 30.0;
	9227	 5487	 0.0013	 0.008539	 0.0	 400.0	 3658	 3658	 0.0	 0.0	 1	 -30.0	 30.0;
	4716	 9227	 0.007169	 0.04463	 0.0	 400.0	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	9227	 7225	 0.01787	 0.097419	 0.0	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	6787	 5487	 0.00164	 0.007409	 0.0	 381.0	 4163	 4163	 0.0	 0.0	 1	 -30.0	 30.0;
	6787	 8633	 0.0097	 0.06274	 0.0	 400.0	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	4716	 6787	 0.007021	 0.045469	 0.0	 419.0	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 8115	 0.007496	 0.022397	 0.0	 1338	 1338	 1338	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 8115	 0.007959	 0.024124	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	7649	 2996	 0.00405	 0.011686	 0.0	 2554	 2554	 2554	 0.0	 0.0	 1	 -30.0	 30.0;
	7649	 1785	 0.005471	 0.01581	 0.0	 1889	 1889	 1889	 0.0	 0.0	 1	 -30.0	 30.0;
	3873	 7109	 0.012727	 0.031579	 0.0	 928	 928	 928	 0.0	 0.0	 1	 -30.0	 30.0;
	4708	 3873	 0.009529	 0.027496	 0.0	 1086	 1086	 1086	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 2061	 0.0	 0.000876	 0.0	 36059	 36059	 36059	 0.0	 0.0	 1	 -30.0	 30.0;
	7806	 2061	 0.01243	 0.040413	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	4708	 2061	 0.002636	 0.007967	 0.0	 3765	 3765	 3765	 0.0	 0.0	 1	 -30.0	 30.0;
	4708	 2061	 0.002686	 0.007802	 0.0	 3829	 3829	 3829	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 4532	 0.049421	 0.127587	 0.0	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5489	 922	 0.006587	 0.018248	 0.0	 1629	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 1961	 0.064438	 0.166364	 0.0	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	7372	 1828	 0.085322	 0.155132	 0.0	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	68	 4881	 0.050488	 0.130339	 0.0	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	8831	 68	 0.035471	 0.111893	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	7211	 5540	 0.013876	 0.045132	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	5540	 4391	 0.042744	 0.16319	 0.0	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	5012	 4660	 0.027512	 0.080083	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 5012	 0.013132	 0.038223	 0.0	 782	 782	 782	 0.0	 0.0	 1	 -30.0	 30.0;
	8666	 7516	 0.017347	 0.051802	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	3451	 7516	 0.036446	 0.086851	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	3877	 87	 0.0	 0.000893	 0.0	 35373	 35373	 35373	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 87	 0.013223	 0.056876	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	87	 5955	 0.01662	 0.035322	 0.0	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 3877	 0.023752	 0.069157	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	3877	 5193	 0.029851	 0.100967	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	3877	 4149	 0.014322	 0.031504	 0.0	 913	 913	 913	 0.0	 0.0	 1	 -30.0	 30.0;
	3877	 7798	 0.01481	 0.040017	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	4359	 4441	 0.038066	 0.094413	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 5736	 0.018702	 0.058967	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	7798	 5639	 0.008554	 0.023917	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	1756	 1865	 0.009849	 0.05651	 0.0	 400.0	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	8476	 741	 0.013554	 0.032066	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	8476	 2506	 0.013719	 0.042876	 0.0	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	7426	 1256	 0.032512	 0.094636	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1256	 4223	 0.040008	 0.116479	 0.0	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	7760	 428	 0.02319	 0.055273	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	967	 7760	 0.013248	 0.046413	 0.0	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 7760	 0.073289	 0.23843	 0.0	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	6463	 301	 0.008083	 0.029661	 0.0	 1028	 1028	 1028	 0.0	 0.0	 1	 -30.0	 30.0;
	7186	 301	 0.014661	 0.058273	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 3562	 0.017273	 0.044587	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 1705	 0.016413	 0.049	 0.0	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	1713	 7696	 0.054587	 0.120008	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	6361	 1713	 0.049521	 0.144149	 0.0	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	8645	 2592	 0.02757	 0.063124	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	7356	 4726	 0.037686	 0.089818	 0.0	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 617	 0.106033	 0.321289	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	9199	 5578	 0.066959	 0.153273	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 6712	 0.074421	 0.208132	 0.0	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 9214	 0.054157	 0.123967	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 4219	 0.086802	 0.24276	 0.0	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 5908	 0.007628	 0.018826	 0.0	 1556	 1556	 1556	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 588	 0.021256	 0.050669	 0.0	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	6546	 108	 0.015893	 0.046223	 0.0	 647	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	108	 3595	 0.01562	 0.034331	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	7812	 6011	 0.011174	 0.023008	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 7812	 0.014438	 0.036174	 0.0	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	6011	 3595	 0.012636	 0.029752	 0.0	 978	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	2996	 7806	 0.0	 0.000826	 0.0	 38242	 38242	 38242	 0.0	 0.0	 1	 -30.0	 30.0;
	2996	 2834	 0.00086	 0.003157	 0.0	 9654	 9654	 9654	 0.0	 0.0	 1	 -30.0	 30.0;
	2996	 1785	 0.01005	 0.027843	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	7806	 1022	 0.000843	 0.003223	 0.0	 9482	 9482	 9482	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 1988	 0.022983	 0.064256	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 6062	 0.008603	 0.018273	 0.0	 1564	 1564	 1564	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 6062	 0.007661	 0.020702	 0.0	 1431	 1431	 1431	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 6580	 0.002678	 0.007174	 0.0	 4125	 4125	 4125	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 6580	 0.002388	 0.008132	 0.0	 3727	 3727	 3727	 0.0	 0.0	 1	 -30.0	 30.0;
	1764	 719	 0.00237	 0.011781	 0.0	 2629	 2629	 2629	 0.0	 0.0	 1	 -30.0	 30.0;
	2251	 3536	 0.001901	 0.012831	 0.0	 2436	 2436	 2436	 0.0	 0.0	 1	 -30.0	 30.0;
	2209	 4045	 0.0	 0.00081	 0.0	 38997	 38997	 38997	 0.0	 0.0	 1	 -30.0	 30.0;
	2209	 5628	 0.017273	 0.025289	 0.0	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 1104	 0.030909	 0.042397	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 1053	 0.020967	 0.066149	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 5710	 0.049719	 0.109298	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 2318	 0.065909	 0.144901	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1211	 6729	 0.00614	 0.05775	 0.0	 830	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 8754	 0.020678	 0.079256	 0.0	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	2221	 8754	 0.020529	 0.051702	 0.0	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	1412	 3504	 0.015066	 0.050711	 0.0	 598	 598	 598	 0.0	 0.0	 1	 -30.0	 30.0;
	247	 6487	 0.032364	 0.074058	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	2531	 247	 0.024893	 0.069612	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	3847	 7696	 0.051289	 0.112769	 0.0	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	7836	 8922	 0.024124	 0.069562	 0.0	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	8922	 1274	 0.026769	 0.10219	 0.0	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	7933	 8922	 0.025909	 0.077347	 0.0	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	8922	 773	 0.01324	 0.046628	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	8424	 7813	 0.01676	 0.03686	 0.0	 781	 781	 781	 0.0	 0.0	 1	 -30.0	 30.0;
	2506	 8424	 0.017612	 0.043678	 0.0	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	7993	 4563	 0.02043	 0.057124	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	6319	 7017	 0.00084	 0.00669	 0.0	 987.0	 4685	 4685	 0.0	 0.0	 1	 -30.0	 30.0;
	1853	 4311	 0.019893	 0.062752	 0.0	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	6406	 78	 0.058719	 0.164223	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	6406	 2531	 0.021661	 0.049587	 0.0	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 2018	 0.008	 0.030686	 0.0	 997	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 4534	 0.024017	 0.057248	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	4669	 717	 0.005636	 0.020727	 0.0	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 7048	 0.004769	 0.016826	 0.0	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 5157	 0.00895	 0.031554	 0.0	 964	 964	 964	 0.0	 0.0	 1	 -30.0	 30.0;
	7946	 3802	 0.010919	 0.07275	 0.0	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	3802	 8166	 0.004841	 0.02861	 0.0	 419.0	 1089	 1089	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 2959	 0.044909	 0.092107	 0.0	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	3161	 3043	 0.011901	 0.039537	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	404	 9056	 0.008421	 0.020066	 0.0	 1452	 1452	 1452	 0.0	 0.0	 1	 -30.0	 30.0;
	9056	 1505	 0.07076	 0.184612	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	9056	 4987	 0.00624	 0.018917	 0.0	 1586	 1586	 1586	 0.0	 0.0	 1	 -30.0	 30.0;
	9056	 2011	 0.055157	 0.127587	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 756	 0.03562	 0.084876	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 8455	 0.024248	 0.073463	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	1834	 2239	 0.006372	 0.012686	 0.0	 2226	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	6851	 460	 0.003397	 0.009802	 0.0	 3045	 3045	 3045	 0.0	 0.0	 1	 -30.0	 30.0;
	6851	 4930	 0.002793	 0.008397	 0.0	 3570	 3570	 3570	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 7441	 0.035636	 0.100248	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	3235	 7441	 0.034901	 0.102182	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	1197	 5647	 0.032388	 0.094281	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 5647	 0.031421	 0.093802	 0.0	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	7946	 4977	 0.02455	 0.175521	 0.0	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	7828	 4977	 0.011281	 0.058469	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 403	 0.015979	 0.102281	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	7344	 6465	 0.0	 0.000777	 0.0	 40653	 40653	 40653	 0.0	 0.0	 1	 -30.0	 30.0;
	7344	 8403	 0.010868	 0.037488	 0.0	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	7344	 7864	 0.011967	 0.024562	 0.0	 1157	 1157	 1157	 0.0	 0.0	 1	 -30.0	 30.0;
	6465	 8403	 0.010636	 0.034711	 0.0	 871	 871	 871	 0.0	 0.0	 1	 -30.0	 30.0;
	6465	 1744	 0.055091	 0.164496	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	6465	 7606	 0.073091	 0.221488	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	8271	 8283	 0.01938	 0.056421	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	3131	 8283	 0.018983	 0.057496	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 7040	 0.031413	 0.07795	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 7304	 0.046231	 0.119372	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 2915	 0.012066	 0.029901	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	1038	 336	 0.022529	 0.071066	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 1038	 0.027471	 0.065471	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	717	 4312	 0.0	 0.00076	 0.0	 41563	 41563	 41563	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 4312	 0.005868	 0.020678	 0.0	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	1532	 620	 0.022636	 0.049769	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	6689	 1104	 0.033909	 0.047901	 0.0	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	6689	 1104	 0.034537	 0.04686	 0.0	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 5628	 0.012959	 0.028661	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	3050	 7889	 0.003919	 0.02719	 0.0	 591.0	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 3153	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 5252	 0.013909	 0.038909	 0.0	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 3153	 0.007579	 0.023	 0.0	 1305	 1305	 1305	 0.0	 0.0	 1	 -30.0	 30.0;
	1634	 4532	 0.032587	 0.077653	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1548	 0.035744	 0.085851	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	1196	 2170	 0.011969	 0.0687	 0.0	 400.0	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	2170	 3213	 0.00431	 0.024719	 0.0	 438.0	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	335	 4881	 0.107463	 0.250107	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 864	 0.043099	 0.099678	 0.0	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 1705	 0.033058	 0.075669	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	8501	 4881	 0.045273	 0.099537	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 2466	 0.071182	 0.141157	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 2466	 0.072554	 0.138223	 0.0	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	1048	 617	 0.00781	 0.02357	 0.0	 1273	 1273	 1273	 0.0	 0.0	 1	 -30.0	 30.0;
	617	 6517	 0.014298	 0.042702	 0.0	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	8836	 8050	 0.016793	 0.041661	 0.0	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	8050	 7588	 0.011017	 0.021711	 0.0	 1298	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	2108	 7946	 0.01255	 0.08125	 0.0	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	9015	 7853	 0.008041	 0.022488	 0.0	 1323	 1323	 1323	 0.0	 0.0	 1	 -30.0	 30.0;
	9015	 7853	 0.009149	 0.017438	 0.0	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	9015	 6647	 0.032876	 0.06481	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	8076	 9015	 0.022512	 0.056769	 0.0	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	7853	 1712	 0.01276	 0.035702	 0.0	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	1766	 6081	 0.007793	 0.02457	 0.0	 1226	 1226	 1226	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 6081	 0.00762	 0.022752	 0.0	 1317	 1317	 1317	 0.0	 0.0	 1	 -30.0	 30.0;
	2311	 6579	 0.010157	 0.025198	 0.0	 1163	 1163	 1163	 0.0	 0.0	 1	 -30.0	 30.0;
	2311	 5047	 0.018289	 0.054603	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	2311	 5614	 0.031876	 0.082322	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	9204	 1766	 0.011289	 0.033917	 0.0	 884	 884	 884	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 7836	 0.055537	 0.203711	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	3129	 8755	 0.001488	 0.003314	 0.0	 8696	 8696	 8696	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 3129	 0.009083	 0.012124	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	3685	 3207	 0.0	 0.000876	 0.0	 36059	 36059	 36059	 0.0	 0.0	 1	 -30.0	 30.0;
	6256	 3510	 0.0011	 0.01267	 0.0	 1053.0	 3790	 3790	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 8137	 0.00252	 0.02751	 0.0	 1119.0	 1144	 1144	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 1053	 0.04314	 0.128802	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 1190	 0.011562	 0.029843	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	7800	 799	 0.011256	 0.041174	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	7800	 799	 0.011017	 0.04195	 0.0	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	7469	 398	 0.029496	 0.076149	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	8166	 1196	 0.009401	 0.05757	 0.0	 381.0	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 1197	 0.056934	 0.185223	 0.0	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 1197	 0.005479	 0.016479	 0.0	 1819	 1819	 1819	 0.0	 0.0	 1	 -30.0	 30.0;
	8643	 6764	 0.011289	 0.029157	 0.0	 1011	 1011	 1011	 0.0	 0.0	 1	 -30.0	 30.0;
	8643	 6264	 0.000504	 0.001446	 0.0	 20628	 20628	 20628	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 8643	 0.014347	 0.035802	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 8643	 0.014628	 0.035066	 0.0	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	8643	 6144	 0.019537	 0.05462	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	1785	 5489	 0.003281	 0.009488	 0.0	 3147	 3147	 3147	 0.0	 0.0	 1	 -30.0	 30.0;
	6339	 2338	 0.033339	 0.086091	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	9214	 2338	 0.032628	 0.095	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 6975	 0.008281	 0.029331	 0.0	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 545	 0.008711	 0.059841	 0.0	 400.0	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 7225	 0.0127	 0.06389	 0.0	 400.0	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 2488	 0.0	 0.000826	 0.0	 38242	 38242	 38242	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 7899	 0.016992	 0.051281	 0.0	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 460	 0.017322	 0.050223	 0.0	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 3527	 0.016901	 0.06357	 0.0	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 3366	 0.037231	 0.112777	 0.0	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 675	 0.039636	 0.115388	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 675	 0.067339	 0.212438	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 6764	 0.061322	 0.134818	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 460	 0.04114	 0.119752	 0.0	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	1417	 1655	 0.03657	 0.109198	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	925	 1417	 0.042488	 0.097248	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	1417	 4739	 0.039099	 0.089512	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	1908	 1717	 0.013537	 0.032471	 0.0	 898	 898	 898	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 4736	 0.00158	 0.01747	 0.0	 987.0	 1801	 1801	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 5487	 0.00894	 0.04824	 0.0	 419.0	 644	 644	 0.0	 0.0	 1	 -30.0	 30.0;
	4716	 2027	 0.003531	 0.018341	 0.0	 400.0	 1692	 1692	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 7426	 0.029818	 0.068256	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	6279	 5737	 0.0	 0.00081	 0.0	 38997	 38997	 38997	 0.0	 0.0	 1	 -30.0	 30.0;
	6279	 7703	 0.003512	 0.004661	 0.0	 5413	 5413	 5413	 0.0	 0.0	 1	 -30.0	 30.0;
	4441	 3310	 0.010959	 0.027322	 0.0	 1074	 1074	 1074	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 5737	 0.003579	 0.004562	 0.0	 5448	 5448	 5448	 0.0	 0.0	 1	 -30.0	 30.0;
	3642	 1853	 0.045843	 0.136851	 0.0	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	3642	 3751	 0.044678	 0.135421	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3642	 1751	 0.015793	 0.04786	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	7045	 4223	 0.036248	 0.10138	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 67	 0.00336	 0.02922	 0.0	 1074	 1074	 1074	 0.0	 0.0	 1	 -30.0	 30.0;
	5537	 7828	 0.01663	 0.097229	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	8949	 215	 0.0	 0.000777	 0.0	 40653	 40653	 40653	 0.0	 0.0	 1	 -30.0	 30.0;
	215	 6647	 0.09357	 0.184397	 0.0	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	2024	 215	 0.090248	 0.177719	 0.0	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	2024	 215	 0.091983	 0.174017	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	215	 1254	 0.018256	 0.05314	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	215	 8076	 0.112273	 0.205446	 0.0	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 3441	 0.003401	 0.02362	 0.0	 438.0	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 7515	 0.002719	 0.012781	 0.0	 400.0	 2418	 2418	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 2185	 0.00205	 0.022719	 0.0	 438.0	 1385	 1385	 0.0	 0.0	 1	 -30.0	 30.0;
	8010	 7745	 0.036579	 0.090719	 0.0	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	8010	 7578	 0.038802	 0.092446	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 5029	 0.029397	 0.067298	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 9093	 0.054289	 0.124289	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 7902	 0.007421	 0.023438	 0.0	 1285	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 5259	 0.006124	 0.018554	 0.0	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	3250	 8351	 0.010446	 0.034017	 0.0	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	788	 2830	 0.045702	 0.127802	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 7043	 0.057438	 0.171496	 0.0	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 7043	 0.025182	 0.057636	 0.0	 503	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 2845	 0.03224	 0.075033	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	335	 864	 0.075653	 0.13295	 0.0	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 7800	 0.005058	 0.017017	 0.0	 1780	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 7800	 0.005157	 0.016669	 0.0	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	2318	 4068	 0.046777	 0.101124	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	6338	 512	 0.045364	 0.135446	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	7040	 6579	 0.037471	 0.113529	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 2146	 0.058372	 0.168446	 0.0	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 2146	 0.066157	 0.165083	 0.0	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	3131	 2146	 0.046628	 0.120388	 0.0	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 4587	 0.029868	 0.087488	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	4764	 2767	 0.015562	 0.047107	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	7813	 2114	 0.045967	 0.109562	 0.0	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 8024	 0.00705	 0.016876	 0.0	 1728	 1728	 1728	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 3559	 0.004	 0.009537	 0.0	 3055	 3055	 3055	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 2643	 0.06243	 0.161207	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	1158	 7864	 0.005942	 0.014149	 0.0	 2059	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	8692	 6481	 0.004651	 0.024159	 0.0	 419.0	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	8692	 1563	 0.00474	 0.02363	 0.0	 457.0	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	7549	 9035	 0.036669	 0.115669	 0.0	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	8740	 5791	 0.043273	 0.095132	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	8740	 5671	 0.004521	 0.011661	 0.0	 2526	 2526	 2526	 0.0	 0.0	 1	 -30.0	 30.0;
	3192	 6256	 0.00207	 0.01871	 0.0	 1283.0	 2344	 2344	 0.0	 0.0	 1	 -30.0	 30.0;
	3213	 1756	 0.00419	 0.02712	 0.0	 381.0	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	3213	 1756	 0.002349	 0.022039	 0.0	 419.0	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	6105	 4984	 0.02	 0.04314	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	7948	 3504	 0.00676	 0.016124	 0.0	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	7415	 7555	 0.007876	 0.022529	 0.0	 1324	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	7555	 3815	 0.025793	 0.060298	 0.0	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	6550	 7045	 0.067587	 0.204793	 0.0	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	6062	 7294	 0.053008	 0.116554	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	6696	 6647	 0.01195	 0.030868	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 6696	 0.015463	 0.04876	 0.0	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	508	 3059	 0.018702	 0.071413	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	3115	 4736	 0.00142	 0.01555	 0.0	 757.0	 2023	 2023	 0.0	 0.0	 1	 -30.0	 30.0;
	3115	 1540	 0.00123	 0.01312	 0.0	 1086.0	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	3115	 1540	 0.00121	 0.01337	 0.0	 1185.0	 2353	 2353	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 3115	 0.00079	 0.01226	 0.0	 1086.0	 2572	 2572	 0.0	 0.0	 1	 -30.0	 30.0;
	2904	 3115	 0.00062	 0.00673	 0.0	 757.0	 4674	 4674	 0.0	 0.0	 1	 -30.0	 30.0;
	6116	 5487	 0.0	 0.000211	 0.0	 149704	 149704	 149704	 0.0	 0.0	 1	 -30.0	 30.0;
	4716	 5487	 0.00763	 0.05451	 0.0	 381.0	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	7109	 8455	 0.0	 0.00076	 0.0	 41563	 41563	 41563	 0.0	 0.0	 1	 -30.0	 30.0;
	8940	 5842	 0.00657	 0.019603	 0.0	 1528	 1528	 1528	 0.0	 0.0	 1	 -30.0	 30.0;
	6706	 6363	 0.011512	 0.028562	 0.0	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	7933	 8499	 0.014612	 0.05362	 0.0	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	9166	 404	 0.00976	 0.02419	 0.0	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	1532	 4664	 0.007876	 0.022934	 0.0	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	4664	 3751	 0.01795	 0.042769	 0.0	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	6463	 5886	 0.023488	 0.046364	 0.0	 608	 608	 608	 0.0	 0.0	 1	 -30.0	 30.0;
	6463	 1717	 0.013802	 0.031802	 0.0	 912	 912	 912	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 7439	 0.036678	 0.080636	 0.0	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	7439	 4351	 0.005917	 0.017066	 0.0	 1749	 1749	 1749	 0.0	 0.0	 1	 -30.0	 30.0;
	7948	 1847	 0.003364	 0.012901	 0.0	 2370	 2370	 2370	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 7948	 0.038107	 0.120198	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 1847	 0.003289	 0.011942	 0.0	 2551	 2551	 2551	 0.0	 0.0	 1	 -30.0	 30.0;
	925	 4271	 0.047818	 0.109479	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4271	 4497	 0.023603	 0.060744	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	4271	 4992	 0.042851	 0.125488	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	4271	 4992	 0.04376	 0.123124	 0.0	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 1540	 0.00089	 0.0071	 0.0	 1185.0	 4415	 4415	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 6550	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 8148	 0.039554	 0.086942	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	508	 3369	 0.046364	 0.078843	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	8097	 3671	 0.006248	 0.007702	 0.0	 3185	 3185	 3185	 0.0	 0.0	 1	 -30.0	 30.0;
	8884	 8097	 0.001273	 0.002661	 0.0	 10709	 10709	 10709	 0.0	 0.0	 1	 -30.0	 30.0;
	6487	 4364	 0.027711	 0.061314	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	6487	 4364	 0.028231	 0.059967	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	1047	 5791	 0.029702	 0.056231	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	2993	 6422	 0.006256	 0.011397	 0.0	 2430	 2430	 2430	 0.0	 0.0	 1	 -30.0	 30.0;
	4584	 4794	 0.010298	 0.032512	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	4794	 9148	 0.01805	 0.039686	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 7120	 0.012849	 0.07226	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 8583	 0.013099	 0.07075	 0.0	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 8289	 0.008314	 0.033033	 0.0	 928	 928	 928	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 8794	 0.031843	 0.096463	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	8801	 3893	 0.002207	 0.005273	 0.0	 5526	 5526	 5526	 0.0	 0.0	 1	 -30.0	 30.0;
	6503	 8801	 0.009124	 0.027669	 0.0	 1085	 1085	 1085	 0.0	 0.0	 1	 -30.0	 30.0;
	1655	 5370	 0.010777	 0.032653	 0.0	 919	 919	 919	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 7975	 0.00757	 0.018901	 0.0	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	2966	 6672	 0.007719	 0.018512	 0.0	 1575	 1575	 1575	 0.0	 0.0	 1	 -30.0	 30.0;
	3964	 4641	 0.016198	 0.040818	 0.0	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	737	 2882	 0.054512	 0.162752	 0.0	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	2882	 2752	 0.030802	 0.067719	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	4563	 7126	 0.012298	 0.029281	 0.0	 995	 995	 995	 0.0	 0.0	 1	 -30.0	 30.0;
	278	 8290	 0.074322	 0.221901	 0.0	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 8290	 0.009669	 0.023033	 0.0	 1265	 1265	 1265	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 2024	 0.0	 0.000843	 0.0	 37471	 37471	 37471	 0.0	 0.0	 1	 -30.0	 30.0;
	46	 1286	 0.073463	 0.189678	 0.0	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	1286	 1053	 0.058653	 0.145488	 0.0	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 3729	 0.00102	 0.01773	 0.0	 757.0	 1779	 1779	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 4252	 0.00838	 0.02438	 0.0	 1226	 1226	 1226	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 7215	 0.01219	 0.03024	 0.0	 969	 969	 969	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 4916	 0.048744	 0.11614	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	7215	 3393	 0.012967	 0.030934	 0.0	 942	 942	 942	 0.0	 0.0	 1	 -30.0	 30.0;
	4252	 3732	 0.006983	 0.021149	 0.0	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 4252	 0.017347	 0.058702	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	2466	 7221	 0.02457	 0.058562	 0.0	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	6522	 5436	 0.016083	 0.044983	 0.0	 662	 662	 662	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 5436	 0.004843	 0.011512	 0.0	 2530	 2530	 2530	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 8363	 0.005058	 0.011339	 0.0	 2545	 2545	 2545	 0.0	 0.0	 1	 -30.0	 30.0;
	7003	 2557	 0.023727	 0.074843	 0.0	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	8794	 2557	 0.031157	 0.098281	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	773	 741	 0.014372	 0.048661	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	971	 3192	 0.00331	 0.02754	 0.0	 1053.0	 1738	 1738	 0.0	 0.0	 1	 -30.0	 30.0;
	7515	 7278	 0.002669	 0.01732	 0.0	 457.0	 1803	 1803	 0.0	 0.0	 1	 -30.0	 30.0;
	7278	 7750	 0.019719	 0.103289	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	7515	 3441	 0.00261	 0.016039	 0.0	 400.0	 1944	 1944	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 6546	 0.008587	 0.017446	 0.0	 1625	 1625	 1625	 0.0	 0.0	 1	 -30.0	 30.0;
	8836	 1405	 0.0	 0.000876	 0.0	 36059	 36059	 36059	 0.0	 0.0	 1	 -30.0	 30.0;
	8348	 8836	 0.017413	 0.05443	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	8836	 6353	 0.024744	 0.074289	 0.0	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	1405	 5283	 0.036421	 0.11381	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5045	 4759	 0.004198	 0.012587	 0.0	 2381	 2381	 2381	 0.0	 0.0	 1	 -30.0	 30.0;
	8127	 7151	 0.014686	 0.044521	 0.0	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 7151	 0.015231	 0.041256	 0.0	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 6786	 0.01438	 0.045364	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	7345	 1008	 0.025562	 0.076298	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 6361	 0.028083	 0.061744	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 5132	 0.05019	 0.152107	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	700	 5132	 0.027909	 0.072033	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 4653	 0.020512	 0.061248	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 6048	 0.025364	 0.053893	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	8314	 7211	 0.054479	 0.165099	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	8314	 7211	 0.055636	 0.161983	 0.0	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	8314	 3128	 0.051579	 0.154	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	1053	 533	 0.035752	 0.106752	 0.0	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	633	 6689	 0.021124	 0.054537	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	633	 6689	 0.021537	 0.05343	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	6665	 545	 0.0082	 0.04119	 0.0	 381.0	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	4364	 8812	 0.040281	 0.122058	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 4497	 0.031934	 0.10086	 0.0	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 1634	 0.048347	 0.145008	 0.0	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 4739	 0.056636	 0.164901	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 7232	 0.048091	 0.119281	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 4902	 0.00305	 0.008793	 0.0	 3394	 3394	 3394	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 4902	 0.003463	 0.00862	 0.0	 3401	 3401	 3401	 0.0	 0.0	 1	 -30.0	 30.0;
	5908	 4537	 0.004223	 0.009339	 0.0	 3082	 3082	 3082	 0.0	 0.0	 1	 -30.0	 30.0;
	5908	 4537	 0.005281	 0.009603	 0.0	 2883	 2883	 2883	 0.0	 0.0	 1	 -30.0	 30.0;
	6338	 4486	 0.028033	 0.066033	 0.0	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	2645	 9204	 0.012983	 0.051587	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	6710	 4394	 0.00183	 0.01416	 0.0	 987.0	 2213	 2213	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 7061	 0.012504	 0.036397	 0.0	 821	 821	 821	 0.0	 0.0	 1	 -30.0	 30.0;
	8794	 7061	 0.024488	 0.074198	 0.0	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 8025	 0.010579	 0.045496	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	7232	 1744	 0.025372	 0.065512	 0.0	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 6592	 0.015058	 0.042124	 0.0	 707	 707	 707	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 5037	 0.038248	 0.084099	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	8212	 737	 0.045719	 0.113397	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	8212	 3908	 0.046603	 0.111041	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	756	 8286	 0.013843	 0.041934	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	8831	 8501	 0.052083	 0.134446	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 278	 0.013579	 0.03981	 0.0	 751	 751	 751	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 278	 0.013868	 0.039058	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 6991	 0.035099	 0.077182	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	8840	 4667	 0.11376	 0.27386	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	278	 8070	 0.069628	 0.153091	 0.0	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 4394	 0.00296	 0.03263	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 5407	 0.048322	 0.115149	 0.0	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 5087	 0.009802	 0.028678	 0.0	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 3671	 0.003132	 0.004347	 0.0	 5896	 5896	 5896	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 4697	 0.00284	 0.02937	 0.0	 1415.0	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 7017	 0.00353	 0.03885	 0.0	 1020.0	 1236	 1236	 0.0	 0.0	 1	 -30.0	 30.0;
	1211	 4697	 0.00193	 0.02044	 0.0	 1185.0	 2149	 2149	 0.0	 0.0	 1	 -30.0	 30.0;
	3853	 1669	 0.00918	 0.065591	 0.0	 457.0	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	7671	 3853	 0.0	 0.000211	 0.0	 419.0	 149704	 149704	 0.0	 0.0	 1	 -30.0	 30.0;
	3853	 8692	 0.01776	 0.09207	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	3853	 8692	 0.018081	 0.09007	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	3853	 3915	 0.0017	 0.0117	 0.0	 2672	 2672	 2672	 0.0	 0.0	 1	 -30.0	 30.0;
	3853	 1127	 0.001669	 0.011919	 0.0	 2625	 2625	 2625	 0.0	 0.0	 1	 -30.0	 30.0;
	4171	 9166	 0.009041	 0.023331	 0.0	 1263	 1263	 1263	 0.0	 0.0	 1	 -30.0	 30.0;
	2462	 3359	 0.075851	 0.15557	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 2462	 0.012471	 0.036587	 0.0	 818	 818	 818	 0.0	 0.0	 1	 -30.0	 30.0;
	2645	 7415	 0.003702	 0.011537	 0.0	 2607	 2607	 2607	 0.0	 0.0	 1	 -30.0	 30.0;
	5955	 2246	 0.003661	 0.009066	 0.0	 3231	 3231	 3231	 0.0	 0.0	 1	 -30.0	 30.0;
	5955	 7798	 0.0	 0.000893	 0.0	 35373	 35373	 35373	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 5175	 0.00537	 0.032901	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	9105	 6503	 0.016661	 0.041331	 0.0	 1082	 1082	 1082	 0.0	 0.0	 1	 -30.0	 30.0;
	9105	 7348	 0.002628	 0.007587	 0.0	 5495	 5495	 5495	 0.0	 0.0	 1	 -30.0	 30.0;
	9105	 9148	 0.009446	 0.025388	 0.0	 1780	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	7897	 7745	 0.023248	 0.060017	 0.0	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	1316	 737	 0.053711	 0.127983	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	8286	 560	 0.009851	 0.022537	 0.0	 1285	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	2777	 7757	 0.007256	 0.021702	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	2777	 8241	 0.001058	 0.003149	 0.0	 9509	 9509	 9509	 0.0	 0.0	 1	 -30.0	 30.0;
	7757	 7348	 0.014744	 0.048893	 0.0	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	3366	 2780	 0.040901	 0.119017	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	6881	 7613	 0.026653	 0.063504	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	4538	 2011	 0.005198	 0.011909	 0.0	 2431	 2431	 2431	 0.0	 0.0	 1	 -30.0	 30.0;
	4538	 978	 0.006603	 0.020793	 0.0	 1448	 1448	 1448	 0.0	 0.0	 1	 -30.0	 30.0;
	925	 1351	 0.023909	 0.054744	 0.0	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 1351	 0.01286	 0.038959	 0.0	 770	 770	 770	 0.0	 0.0	 1	 -30.0	 30.0;
	6522	 355	 0.0	 0.000826	 0.0	 38242	 38242	 38242	 0.0	 0.0	 1	 -30.0	 30.0;
	7588	 355	 0.005488	 0.011256	 0.0	 2523	 2523	 2523	 0.0	 0.0	 1	 -30.0	 30.0;
	3700	 355	 0.018983	 0.055579	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	6522	 4444	 0.013479	 0.038876	 0.0	 768	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	7397	 4851	 0.010041	 0.02205	 0.0	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 7585	 0.01224	 0.037099	 0.0	 809	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	7397	 4053	 0.0	 0.00081	 0.0	 38997	 38997	 38997	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 7397	 0.011	 0.030959	 0.0	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 4053	 0.010777	 0.031554	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 5906	 0.030521	 0.069868	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 6918	 0.016901	 0.051198	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	6441	 3904	 0.008868	 0.027967	 0.0	 1077	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	7585	 3338	 0.006322	 0.02319	 0.0	 1315	 1315	 1315	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 5626	 0.006488	 0.019008	 0.0	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	3273	 5095	 0.006347	 0.019372	 0.0	 1550	 1550	 1550	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 3273	 0.018339	 0.038967	 0.0	 734	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	1245	 5231	 0.037793	 0.093752	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	1284	 753	 0.018603	 0.048017	 0.0	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	4191	 6548	 0.04086	 0.128893	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	6548	 1375	 0.004587	 0.010083	 0.0	 2852	 2852	 2852	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 5474	 0.012529	 0.028661	 0.0	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	46	 4029	 0.016339	 0.035909	 0.0	 801	 801	 801	 0.0	 0.0	 1	 -30.0	 30.0;
	1284	 7199	 0.021702	 0.058653	 0.0	 506	 506	 506	 0.0	 0.0	 1	 -30.0	 30.0;
	6250	 7975	 0.037339	 0.109364	 0.0	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 2966	 0.036554	 0.11143	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	6048	 6144	 0.027149	 0.062149	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 3847	 0.034281	 0.103876	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 5047	 0.023479	 0.06843	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	7536	 5141	 0.053149	 0.116868	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	5886	 6733	 0.004802	 0.013298	 0.0	 2235	 2235	 2235	 0.0	 0.0	 1	 -30.0	 30.0;
	6733	 508	 0.012669	 0.038231	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 2464	 0.040339	 0.079496	 0.0	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	8501	 1693	 0.054521	 0.171992	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5632	 1693	 0.05514	 0.122	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	2333	 1693	 0.056157	 0.119339	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	9017	 4486	 0.034248	 0.075289	 0.0	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 887	 0.0018	 0.01865	 0.0	 1448.0	 1686	 1686	 0.0	 0.0	 1	 -30.0	 30.0;
	7549	 4391	 0.0	 0.000793	 0.0	 39833	 39833	 39833	 0.0	 0.0	 1	 -30.0	 30.0;
	7839	 7345	 0.023231	 0.064983	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	1695	 2152	 0.00163	 0.01087	 0.0	 400.0	 2874	 2874	 0.0	 0.0	 1	 -30.0	 30.0;
	6409	 37	 0.020727	 0.053512	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	508	 7186	 0.022364	 0.064488	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	925	 4378	 0.014579	 0.04805	 0.0	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	925	 4378	 0.014281	 0.048992	 0.0	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	6449	 3017	 0.00228	 0.02412	 0.0	 1086.0	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	7578	 1505	 0.004298	 0.009132	 0.0	 3130	 3130	 3130	 0.0	 0.0	 1	 -30.0	 30.0;
	3359	 7578	 0.003826	 0.010347	 0.0	 2864	 2864	 2864	 0.0	 0.0	 1	 -30.0	 30.0;
	3359	 1505	 0.0	 0.000777	 0.0	 40653	 40653	 40653	 0.0	 0.0	 1	 -30.0	 30.0;
	7897	 1505	 0.042256	 0.092917	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 7010	 0.005021	 0.029341	 0.0	 419.0	 1062	 1062	 0.0	 0.0	 1	 -30.0	 30.0;
	482	 1309	 0.066248	 0.151661	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	1309	 4451	 0.007587	 0.016702	 0.0	 1722	 1722	 1722	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 4987	 0.008579	 0.019636	 0.0	 1475	 1475	 1475	 0.0	 0.0	 1	 -30.0	 30.0;
	7536	 5842	 0.008942	 0.024992	 0.0	 1191	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	3941	 3566	 0.049124	 0.154983	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	2198	 3941	 0.018289	 0.04186	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	887	 7506	 0.00064	 0.00617	 0.0	 1415.0	 5093	 5093	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 1511	 0.0	 0.00076	 0.0	 41563	 41563	 41563	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 5018	 0.024421	 0.073331	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 6571	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	7003	 8794	 0.025653	 0.056388	 0.0	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 5337	 0.003711	 0.02356	 0.0	 419.0	 1325	 1325	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 4351	 0.015777	 0.089537	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 3030	 0.001587	 0.005612	 0.0	 5417	 5417	 5417	 0.0	 0.0	 1	 -30.0	 30.0;
	978	 4171	 0.008934	 0.027091	 0.0	 1108	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 2011	 0.021298	 0.052603	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	7660	 8633	 0.01036	 0.05943	 0.0	 400.0	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	8749	 934	 0.036438	 0.114909	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	566	 8749	 0.038876	 0.113207	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	3952	 6726	 0.045058	 0.127901	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	6726	 2198	 0.014083	 0.042661	 0.0	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	941	 482	 0.016537	 0.052157	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	6788	 5981	 0.045711	 0.136504	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 3192	 0.00579	 0.06394	 0.0	 688	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	1762	 1321	 0.012512	 0.03381	 0.0	 877	 877	 877	 0.0	 0.0	 1	 -30.0	 30.0;
	1321	 125	 0.053149	 0.149512	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	1762	 4988	 0.012248	 0.034471	 0.0	 864	 864	 864	 0.0	 0.0	 1	 -30.0	 30.0;
	4988	 3235	 0.052041	 0.152388	 0.0	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 4191	 0.024471	 0.056033	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 2442	 0.008752	 0.016322	 0.0	 1706	 1706	 1706	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 7017	 0.00211	 0.01832	 0.0	 1316.0	 2614	 2614	 0.0	 0.0	 1	 -30.0	 30.0;
	6825	 7308	 0.0	 0.00086	 0.0	 36730	 36730	 36730	 0.0	 0.0	 1	 -30.0	 30.0;
	1853	 78	 0.0	 0.000876	 0.0	 36059	 36059	 36059	 0.0	 0.0	 1	 -30.0	 30.0;
	398	 78	 0.007248	 0.021107	 0.0	 1416	 1416	 1416	 0.0	 0.0	 1	 -30.0	 30.0;
	1751	 1853	 0.036653	 0.106661	 0.0	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 4072	 0.003107	 0.007727	 0.0	 3793	 3793	 3793	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 5569	 0.013612	 0.029917	 0.0	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	7304	 5231	 0.064182	 0.141124	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 5231	 0.058331	 0.150579	 0.0	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	7271	 4990	 0.00337	 0.03668	 0.0	 400.0	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	4068	 7839	 0.033959	 0.080934	 0.0	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	7040	 7536	 0.0	 0.000826	 0.0	 38242	 38242	 38242	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 7536	 0.07314	 0.181438	 0.0	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	7536	 5728	 0.01476	 0.04295	 0.0	 696	 696	 696	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 8070	 0.018488	 0.044091	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	6703	 4903	 0.00025	 0.00227	 0.0	 1283.0	 19319	 19319	 0.0	 0.0	 1	 -30.0	 30.0;
	6703	 4903	 0.00025	 0.00222	 0.0	 1415.0	 19749	 19749	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 1211	 0.00179	 0.01494	 0.0	 1020.0	 2933	 2933	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 2904	 0.00133	 0.01403	 0.0	 1218.0	 2242	 2242	 0.0	 0.0	 1	 -30.0	 30.0;
	1047	 1712	 0.027438	 0.076752	 0.0	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	7585	 3881	 0.0	 0.00081	 0.0	 38997	 38997	 38997	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 6918	 0.014347	 0.03705	 0.0	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	7660	 5185	 0.00286	 0.015591	 0.0	 419.0	 1993	 1993	 0.0	 0.0	 1	 -30.0	 30.0;
	6363	 5569	 0.0	 0.000793	 0.0	 39833	 39833	 39833	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 4378	 0.008231	 0.021273	 0.0	 1385	 1385	 1385	 0.0	 0.0	 1	 -30.0	 30.0;
	1254	 7356	 0.013653	 0.031231	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	3161	 2645	 0.0	 0.000777	 0.0	 40653	 40653	 40653	 0.0	 0.0	 1	 -30.0	 30.0;
	8720	 1053	 0.028364	 0.063479	 0.0	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 1053	 0.023636	 0.051983	 0.0	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	468	 1053	 0.022752	 0.066248	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	6422	 5632	 0.004512	 0.013099	 0.0	 2280	 2280	 2280	 0.0	 0.0	 1	 -30.0	 30.0;
	6422	 2333	 0.006331	 0.015124	 0.0	 1927	 1927	 1927	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 941	 0.048058	 0.143504	 0.0	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 2643	 0.02676	 0.077901	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 576	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 1211	 0.00031	 0.00329	 0.0	 1251.0	 13351	 13351	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 1211	 0.00035	 0.00322	 0.0	 1218.0	 13621	 13621	 0.0	 0.0	 1	 -30.0	 30.0;
	5906	 700	 0.01276	 0.028033	 0.0	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	7372	 7747	 0.049983	 0.088198	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 3700	 0.0	 0.000876	 0.0	 36059	 36059	 36059	 0.0	 0.0	 1	 -30.0	 30.0;
	4263	 3700	 0.020157	 0.04643	 0.0	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	8013	 8192	 0.050554	 0.09781	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 8013	 0.050157	 0.093818	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	7604	 3914	 0.03338	 0.08238	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	24	 3914	 0.041554	 0.156107	 0.0	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 6572	 0.04676	 0.124372	 0.0	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 6572	 0.043868	 0.116678	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	6878	 5727	 0.015529	 0.049017	 0.0	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	6878	 1427	 0.019471	 0.052802	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	4763	 5554	 0.030339	 0.062124	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 4763	 0.043488	 0.11219	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	4763	 5865	 0.025934	 0.052198	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	7765	 7534	 0.024372	 0.057347	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	7765	 6673	 0.023868	 0.058446	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 1427	 0.032636	 0.103934	 0.0	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	8969	 7722	 0.02695	 0.081719	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 4437	 0.022521	 0.13874	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 3103	 0.0117	 0.053091	 0.0	 438.0	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 5043	 0.001401	 0.006789	 0.0	 476.0	 4557	 4557	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 2402	 0.00139	 0.0113	 0.0	 457.0	 2775	 2775	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 5733	 0.01818	 0.095349	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	7978	 5733	 0.005729	 0.043599	 0.0	 629.0	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 9168	 0.00095	 0.006409	 0.0	 4876	 4876	 4876	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 1390	 0.00093	 0.006531	 0.0	 629.0	 4789	 4789	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 4899	 0.025659	 0.11894	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 694	 0.01036	 0.04869	 0.0	 533.0	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 2731	 0.022231	 0.051521	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 2731	 0.038099	 0.092579	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	3548	 1289	 0.018041	 0.066793	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	4784	 1289	 0.019942	 0.075554	 0.0	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	186	 4406	 0.028347	 0.064727	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	186	 4671	 0.028124	 0.066826	 0.0	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	6352	 1299	 0.017107	 0.031438	 0.0	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	7705	 1299	 0.028322	 0.109331	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	8430	 7590	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	8430	 1528	 0.002248	 0.008413	 0.0	 3628	 3628	 3628	 0.0	 0.0	 1	 -30.0	 30.0;
	7590	 2106	 0.003421	 0.010397	 0.0	 2886	 2886	 2886	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 7590	 0.039554	 0.071554	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 7590	 0.012612	 0.036818	 0.0	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	5931	 155	 0.004471	 0.014041	 0.0	 2144	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 3924	 0.013628	 0.050934	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 877	 0.002438	 0.007959	 0.0	 3795	 3795	 3795	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 3394	 0.014579	 0.030132	 0.0	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 8418	 0.04186	 0.08719	 0.0	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 8051	 0.072653	 0.128339	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	7730	 940	 0.013612	 0.049421	 0.0	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	7730	 7970	 0.037256	 0.107727	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 2939	 0.003349	 0.0237	 0.0	 1320	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 2939	 0.003281	 0.024159	 0.0	 1296	 1296	 1296	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 2939	 0.003599	 0.023469	 0.0	 1331	 1331	 1331	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 2939	 0.003669	 0.02299	 0.0	 572.0	 1357	 1357	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 918	 0.009124	 0.02781	 0.0	 1080	 1080	 1080	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 918	 0.008661	 0.026479	 0.0	 1134	 1134	 1134	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 918	 0.008488	 0.027033	 0.0	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 1795	 0.002248	 0.006554	 0.0	 4559	 4559	 4559	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 5057	 0.001612	 0.004636	 0.0	 6436	 6436	 6436	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 1528	 0.012223	 0.027331	 0.0	 1056	 1056	 1056	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 5397	 0.002099	 0.01181	 0.0	 2634	 2634	 2634	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 5397	 0.002058	 0.012058	 0.0	 2583	 2583	 2583	 0.0	 0.0	 1	 -30.0	 30.0;
	918	 1377	 0.019008	 0.055876	 0.0	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	918	 2864	 0.020727	 0.05795	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 1441	 0.004471	 0.010471	 0.0	 2775	 2775	 2775	 0.0	 0.0	 1	 -30.0	 30.0;
	8617	 1441	 0.010479	 0.025967	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 5057	 0.001636	 0.004537	 0.0	 6550	 6550	 6550	 0.0	 0.0	 1	 -30.0	 30.0;
	2106	 5931	 0.001603	 0.005256	 0.0	 5749	 5749	 5749	 0.0	 0.0	 1	 -30.0	 30.0;
	8470	 303	 0.001039	 0.00812	 0.0	 591.0	 3859	 3859	 0.0	 0.0	 1	 -30.0	 30.0;
	8470	 303	 0.001169	 0.007961	 0.0	 629.0	 3926	 3926	 0.0	 0.0	 1	 -30.0	 30.0;
	940	 3924	 0.001802	 0.006628	 0.0	 4599	 4599	 4599	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 9016	 0.00022	 0.00217	 0.0	 1283.0	 14483	 14483	 0.0	 0.0	 1	 -30.0	 30.0;
	1686	 9016	 0.00067	 0.0072	 0.0	 1152.0	 4369	 4369	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 2977	 0.019826	 0.06962	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 4437	 0.005919	 0.02874	 0.0	 533.0	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	2345	 4437	 0.001271	 0.009651	 0.0	 514.0	 3245	 3245	 0.0	 0.0	 1	 -30.0	 30.0;
	8470	 4437	 0.00126	 0.00955	 0.0	 572.0	 3280	 3280	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 5327	 0.0009	 0.01149	 0.0	 1251.0	 4182	 4182	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 8358	 0.00115	 0.01172	 0.0	 1185.0	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	2345	 1753	 0.00431	 0.033729	 0.0	 457.0	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	8470	 6350	 0.001841	 0.0115	 0.0	 2713	 2713	 2713	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 7978	 0.008401	 0.053719	 0.0	 572.0	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 3103	 0.0013	 0.006021	 0.0	 419.0	 5129	 5129	 0.0	 0.0	 1	 -30.0	 30.0;
	9036	 8471	 0.016083	 0.036347	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	8471	 4399	 0.01576	 0.037058	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	6262	 8471	 0.039661	 0.101099	 0.0	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	3745	 379	 0.015777	 0.058099	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 379	 0.044901	 0.08681	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	4824	 2855	 0.00173	 0.01919	 0.0	 1251.0	 2502	 2502	 0.0	 0.0	 1	 -30.0	 30.0;
	2855	 8562	 0.00213	 0.02194	 0.0	 1481.0	 2187	 2187	 0.0	 0.0	 1	 -30.0	 30.0;
	223	 2023	 0.00395	 0.008331	 0.0	 3426	 3426	 3426	 0.0	 0.0	 1	 -30.0	 30.0;
	8308	 2023	 0.157273	 0.234413	 0.0	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	223	 3864	 0.003421	 0.009099	 0.0	 3250	 3250	 3250	 0.0	 0.0	 1	 -30.0	 30.0;
	3864	 6150	 0.06795	 0.151058	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	223	 3162	 0.040099	 0.154554	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	223	 4678	 0.070769	 0.175471	 0.0	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	223	 3203	 0.008504	 0.028322	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	223	 9124	 0.02738	 0.069876	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 8783	 0.010347	 0.023041	 0.0	 1251	 1251	 1251	 0.0	 0.0	 1	 -30.0	 30.0;
	8969	 8783	 0.044281	 0.083967	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 989	 0.055744	 0.101992	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	1699	 4406	 0.015446	 0.026554	 0.0	 1029	 1029	 1029	 0.0	 0.0	 1	 -30.0	 30.0;
	4406	 1495	 0.035388	 0.067603	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 7301	 0.007273	 0.013752	 0.0	 2031	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	7301	 6988	 0.00362	 0.007033	 0.0	 3994	 3994	 3994	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 6988	 0.001182	 0.003727	 0.0	 8079	 8079	 8079	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 4465	 0.013314	 0.052752	 0.0	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 4547	 0.028372	 0.075868	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 3026	 0.033917	 0.080413	 0.0	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	8734	 4361	 0.004669	 0.03695	 0.0	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	4361	 7978	 0.004229	 0.025271	 0.0	 1233	 1233	 1233	 0.0	 0.0	 1	 -30.0	 30.0;
	7604	 2638	 0.041909	 0.072157	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	3122	 2638	 0.031174	 0.078554	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 3548	 0.030777	 0.114017	 0.0	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 6755	 0.021479	 0.05195	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	6755	 1427	 0.04881	 0.09786	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	7243	 1178	 0.043992	 0.107769	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	7243	 1427	 0.017347	 0.059826	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	2976	 6988	 0.006281	 0.014802	 0.0	 1965	 1965	 1965	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 2976	 0.045818	 0.086281	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 2976	 0.022521	 0.077653	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	2123	 5547	 0.014132	 0.053744	 0.0	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	801	 2123	 0.025901	 0.082504	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	2473	 2123	 0.05905	 0.233421	 0.0	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 8407	 0.035174	 0.062992	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 7208	 0.015901	 0.059529	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	8407	 975	 0.005174	 0.015322	 0.0	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	8407	 2348	 0.021471	 0.063207	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 2037	 0.030033	 0.114521	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 5629	 0.050537	 0.090521	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 5629	 0.026446	 0.070959	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 3839	 0.028157	 0.075636	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 8357	 0.021413	 0.212132	 0.0	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 8357	 0.046446	 0.096702	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	7900	 4639	 0.042562	 0.102702	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	7528	 4639	 0.034314	 0.071603	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	4727	 8617	 0.034033	 0.077537	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 4727	 0.01919	 0.035669	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	7604	 8192	 0.046826	 0.094587	 0.0	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	8990	 2947	 0.059909	 0.111868	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	7477	 8990	 0.020909	 0.037934	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	5875	 6843	 0.009727	 0.025347	 0.0	 1164	 1164	 1164	 0.0	 0.0	 1	 -30.0	 30.0;
	4814	 5875	 0.01981	 0.040331	 0.0	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	2687	 5557	 1.7e-05	 0.000413	 0.0	 76418	 76418	 76418	 0.0	 0.0	 1	 -30.0	 30.0;
	591	 2687	 0.017091	 0.04114	 0.0	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 877	 0.03014	 0.111744	 0.0	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 1699	 0.012628	 0.026339	 0.0	 1082	 1082	 1082	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 862	 0.032934	 0.078298	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	1960	 1246	 0.025198	 0.050942	 0.0	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	2802	 7323	 0.025529	 0.049421	 0.0	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	6262	 7323	 0.026124	 0.06962	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	393	 6461	 0.00036	 0.00188	 0.0	 16502	 16502	 16502	 0.0	 0.0	 1	 -30.0	 30.0;
	393	 6461	 0.00043	 0.00174	 0.0	 17624	 17624	 17624	 0.0	 0.0	 1	 -30.0	 30.0;
	8382	 5269	 0.026091	 0.052298	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	8382	 5269	 0.015413	 0.048636	 0.0	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 6628	 0.024463	 0.08705	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	6461	 3688	 0.00638	 0.04836	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	6461	 5000	 0.002081	 0.01214	 0.0	 533.0	 2565	 2565	 0.0	 0.0	 1	 -30.0	 30.0;
	6461	 5000	 0.002081	 0.01257	 0.0	 514.0	 2480	 2480	 0.0	 0.0	 1	 -30.0	 30.0;
	8942	 2861	 0.005314	 0.015017	 0.0	 1983	 1983	 1983	 0.0	 0.0	 1	 -30.0	 30.0;
	8942	 4671	 0.004331	 0.011752	 0.0	 2523	 2523	 2523	 0.0	 0.0	 1	 -30.0	 30.0;
	2861	 4671	 0.00386	 0.013322	 0.0	 2278	 2278	 2278	 0.0	 0.0	 1	 -30.0	 30.0;
	4671	 3839	 0.02181	 0.080802	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	4671	 1714	 0.036992	 0.107727	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4671	 5190	 0.029273	 0.105248	 0.0	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 4465	 0.016909	 0.05057	 0.0	 593	 593	 593	 0.0	 0.0	 1	 -30.0	 30.0;
	8474	 4824	 0.00302	 0.03553	 0.0	 1251.0	 1352	 1352	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 7607	 0.005983	 0.023132	 0.0	 1323	 1323	 1323	 0.0	 0.0	 1	 -30.0	 30.0;
	7149	 7607	 0.003777	 0.011421	 0.0	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	3203	 7607	 0.050041	 0.180397	 0.0	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	7607	 9124	 0.056562	 0.179397	 0.0	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	6448	 2195	 0.012818	 0.046769	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	8618	 6350	 0.00286	 0.017581	 0.0	 514.0	 1774	 1774	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 9036	 0.012554	 0.029083	 0.0	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	2015	 2982	 0.000909	 0.002876	 0.0	 10473	 10473	 10473	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 586	 0.018719	 0.033769	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	3136	 6626	 0.032149	 0.059041	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	8096	 4986	 0.005198	 0.013488	 0.0	 2186	 2186	 2186	 0.0	 0.0	 1	 -30.0	 30.0;
	2947	 8096	 0.018636	 0.044149	 0.0	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	2947	 4986	 0.014554	 0.028438	 0.0	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	7477	 2947	 0.032934	 0.155826	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	2947	 6610	 0.015231	 0.035843	 0.0	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	2947	 9193	 0.037248	 0.089901	 0.0	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	2947	 430	 0.04643	 0.09338	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	245	 8481	 0.075612	 0.155504	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	8481	 4343	 0.04057	 0.08876	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	8481	 329	 0.114628	 0.20105	 0.0	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	4269	 9219	 0.018521	 0.090322	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 9219	 0.013702	 0.052983	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 7848	 0.006017	 0.019198	 0.0	 1571	 1571	 1571	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 6827	 0.052686	 0.090653	 0.0	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 2195	 0.065826	 0.122818	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 7534	 0.04443	 0.105719	 0.0	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	7739	 7354	 0.00838	 0.018942	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	8306	 7354	 0.058017	 0.142983	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 7830	 0.00085	 0.01148	 0.0	 856.0	 2744	 2744	 0.0	 0.0	 1	 -30.0	 30.0;
	8562	 7830	 0.00172	 0.0234	 0.0	 1283.0	 2055	 2055	 0.0	 0.0	 1	 -30.0	 30.0;
	7604	 7739	 0.04805	 0.152256	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	7739	 5830	 0.028372	 0.069471	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	6843	 7739	 0.038364	 0.12214	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 5547	 0.013463	 0.05405	 0.0	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	3394	 8418	 0.025083	 0.060273	 0.0	 484	 484	 484	 0.0	 0.0	 1	 -30.0	 30.0;
	3523	 1372	 0.012438	 0.047124	 0.0	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	8969	 3523	 0.022388	 0.084818	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 3011	 0.005471	 0.020281	 0.0	 1504	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	4784	 3011	 0.107174	 0.201248	 0.0	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 2554	 0.035058	 0.124769	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2037	 7848	 0.015934	 0.05876	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	591	 5557	 0.020099	 0.03862	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	2218	 4034	 0.04176	 0.103083	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 4034	 0.066719	 0.165537	 0.0	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5000	 4997	 0.00013	 0.00095	 0.0	 32943	 32943	 32943	 0.0	 0.0	 1	 -30.0	 30.0;
	2802	 3300	 0.033777	 0.06776	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	8261	 3300	 0.057388	 0.126289	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 9054	 0.0019	 0.0204	 0.0	 1218.0	 2353	 2353	 0.0	 0.0	 1	 -30.0	 30.0;
	8306	 8423	 0.007529	 0.025372	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	8306	 1661	 0.023917	 0.064636	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	8306	 5865	 0.039612	 0.099818	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	8306	 7414	 0.012388	 0.038802	 0.0	 776	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	8423	 7414	 0.004281	 0.015678	 0.0	 1944	 1944	 1944	 0.0	 0.0	 1	 -30.0	 30.0;
	7595	 5344	 0.013463	 0.033289	 0.0	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	8570	 5344	 0.015893	 0.039901	 0.0	 736	 736	 736	 0.0	 0.0	 1	 -30.0	 30.0;
	8570	 7595	 0.005934	 0.021686	 0.0	 1405	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	3770	 7595	 0.009107	 0.02843	 0.0	 1059	 1059	 1059	 0.0	 0.0	 1	 -30.0	 30.0;
	8570	 3770	 0.005802	 0.020083	 0.0	 1512	 1512	 1512	 0.0	 0.0	 1	 -30.0	 30.0;
	8570	 1806	 0.10495	 0.203661	 0.0	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	8570	 1018	 0.026372	 0.04995	 0.0	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	663	 8734	 0.00738	 0.044	 0.0	 709	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	8734	 7978	 0.010591	 0.05825	 0.0	 514.0	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 663	 0.01318	 0.05764	 0.0	 514.0	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	663	 4392	 0.0143	 0.06869	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	7604	 2201	 0.022099	 0.080636	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 1665	 0.039843	 0.08557	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 8437	 0.007909	 0.022124	 0.0	 1345	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	8343	 24	 0.051017	 0.111273	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	6843	 1661	 0.010331	 0.038289	 0.0	 797	 797	 797	 0.0	 0.0	 1	 -30.0	 30.0;
	862	 2568	 0.02343	 0.058603	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	8562	 1978	 0.0009	 0.00851	 0.0	 1251.0	 5156	 5156	 0.0	 0.0	 1	 -30.0	 30.0;
	1978	 6098	 0.00157	 0.01488	 0.0	 1086.0	 2949	 2949	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 3104	 0.00682	 0.03224	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	7477	 7900	 0.01719	 0.033322	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	7900	 7528	 0.080446	 0.14995	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 245	 0.055678	 0.123917	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 1714	 0.014463	 0.040066	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 7938	 0.013107	 0.048314	 0.0	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	4343	 1960	 0.123174	 0.23414	 0.0	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	3162	 6150	 0.00557	 0.011256	 0.0	 2516	 2516	 2516	 0.0	 0.0	 1	 -30.0	 30.0;
	3162	 2633	 0.007967	 0.018719	 0.0	 1553	 1553	 1553	 0.0	 0.0	 1	 -30.0	 30.0;
	8308	 2633	 0.076711	 0.159554	 0.0	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	551	 2348	 0.012669	 0.049364	 0.0	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	551	 5195	 0.015719	 0.058826	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	6709	 1408	 0.007397	 0.027686	 0.0	 1103	 1103	 1103	 0.0	 0.0	 1	 -30.0	 30.0;
	6709	 2195	 0.006967	 0.02505	 0.0	 1215	 1215	 1215	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 8665	 0.037653	 0.076876	 0.0	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	3745	 7705	 0.011	 0.029826	 0.0	 994	 994	 994	 0.0	 0.0	 1	 -30.0	 30.0;
	4784	 5153	 0.042446	 0.107058	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 7149	 0.011008	 0.025711	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 7528	 0.014818	 0.04719	 0.0	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 7528	 0.011802	 0.040711	 0.0	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	7528	 6141	 0.010802	 0.039769	 0.0	 767	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 8015	 0.003331	 0.011496	 0.0	 2640	 2640	 2640	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 8343	 0.041256	 0.083702	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	8015	 7528	 0.011223	 0.030413	 0.0	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	7528	 2015	 0.105562	 0.208901	 0.0	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	7528	 2218	 0.021612	 0.065496	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	8562	 2398	 0.0056	 0.03178	 0.0	 1053.0	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 1377	 0.005364	 0.01443	 0.0	 2052	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	6043	 8364	 0.007132	 0.016347	 0.0	 1772	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	8364	 2195	 0.035281	 0.111719	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 6043	 0.027669	 0.067686	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	6043	 3136	 0.086157	 0.181149	 0.0	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	4555	 8382	 0.019983	 0.054711	 0.0	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	4555	 4269	 0.007041	 0.032174	 0.0	 960	 960	 960	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 6352	 0.050587	 0.128397	 0.0	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	8382	 6471	 0.014983	 0.031364	 0.0	 909	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	6471	 6278	 0.010653	 0.019	 0.0	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 4801	 0.00189	 0.02064	 0.0	 1349.0	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 4801	 0.00227	 0.01922	 0.0	 1251.0	 2280	 2280	 0.0	 0.0	 1	 -30.0	 30.0;
	4801	 895	 0.00167	 0.02044	 0.0	 1283.0	 2351	 2351	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 3372	 0.016341	 0.07818	 0.0	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	7521	 3372	 0.005409	 0.024729	 0.0	 533.0	 1248	 1248	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 1473	 0.00525	 0.04099	 0.0	 553.0	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	8382	 3410	 0.00714	 0.025347	 0.0	 1200	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	8382	 3756	 0.00819	 0.025802	 0.0	 1167	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	6278	 8382	 0.006322	 0.014314	 0.0	 2019	 2019	 2019	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 1087	 0.037678	 0.087512	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 7200	 0.010942	 0.034529	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 7200	 0.007041	 0.02714	 0.0	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	7200	 3756	 0.002826	 0.010496	 0.0	 2906	 2906	 2906	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 5684	 0.0001	 0.00124	 0.0	 1349.0	 35464	 35464	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 4447	 3e-05	 0.00027	 0.0	 1382.0	 162401	 162401	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 6248	 2e-05	 0.00021	 0.0	 757.0	 209139	 209139	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 5684	 0.00011	 0.00133	 0.0	 1251.0	 33059	 33059	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 9054	 0.00062	 0.00694	 0.0	 1251.0	 6332	 6332	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 465	 0.005281	 0.04189	 0.0	 610.0	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 3597	 0.00014	 0.000651	 0.0	 47437	 47437	 47437	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 1139	 0.000229	 0.00107	 0.0	 28868	 28868	 28868	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 3288	 0.000229	 0.001039	 0.0	 29690	 29690	 29690	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 894	 0.00013	 0.00086	 0.0	 629.0	 36317	 36317	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 7627	 0.00013	 0.00087	 0.0	 400.0	 35909	 35909	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 5731	 0.001539	 0.012651	 0.0	 2479	 2479	 2479	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 694	 0.00806	 0.047091	 0.0	 662	 662	 662	 0.0	 0.0	 1	 -30.0	 30.0;
	8437	 1178	 0.04943	 0.099331	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 329	 0.050488	 0.104149	 0.0	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	6628	 7468	 0.003702	 0.008934	 0.0	 3267	 3267	 3267	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 7468	 0.074446	 0.138033	 0.0	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 8418	 0.008479	 0.021653	 0.0	 1359	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 8418	 0.005314	 0.019479	 0.0	 1565	 1565	 1565	 0.0	 0.0	 1	 -30.0	 30.0;
	8474	 1686	 0.00104	 0.01121	 0.0	 1448.0	 2806	 2806	 0.0	 0.0	 1	 -30.0	 30.0;
	1473	 8618	 0.01118	 0.07193	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	5830	 3122	 0.002777	 0.008174	 0.0	 3659	 3659	 3659	 0.0	 0.0	 1	 -30.0	 30.0;
	7208	 6827	 0.006058	 0.02362	 0.0	 1296	 1296	 1296	 0.0	 0.0	 1	 -30.0	 30.0;
	2398	 7314	 0.00192	 0.01477	 0.0	 1086.0	 2963	 2963	 0.0	 0.0	 1	 -30.0	 30.0;
	7848	 6827	 0.025331	 0.098711	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 3917	 0.05886	 0.113157	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 3917	 0.046851	 0.110231	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	801	 4784	 0.02895	 0.10819	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 8308	 0.079438	 0.11481	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 8308	 0.077967	 0.117314	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	8308	 6843	 0.032669	 0.091388	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	876	 2015	 0.008421	 0.02657	 0.0	 1134	 1134	 1134	 0.0	 0.0	 1	 -30.0	 30.0;
	2218	 876	 0.082727	 0.14876	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4392	 5000	 0.00637	 0.029669	 0.0	 514.0	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 1063	 0.020223	 0.033198	 0.0	 813	 813	 813	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 1063	 0.017843	 0.033876	 0.0	 825	 825	 825	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 2802	 0.022058	 0.05405	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 8865	 0.019826	 0.073909	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	9193	 1495	 0.063107	 0.131711	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	5127	 1714	 0.012099	 0.029041	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	5127	 1714	 0.006273	 0.019033	 0.0	 1577	 1577	 1577	 0.0	 0.0	 1	 -30.0	 30.0;
	5127	 7687	 0.007603	 0.021273	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	5127	 7687	 0.011041	 0.027339	 0.0	 1072	 1072	 1072	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 3725	 0.011636	 0.032562	 0.0	 914	 914	 914	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 1714	 0.007091	 0.019058	 0.0	 1554	 1554	 1554	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 7687	 0.006653	 0.020967	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	2349	 5000	 0.00212	 0.01695	 0.0	 514.0	 1850	 1850	 0.0	 0.0	 1	 -30.0	 30.0;
	2349	 5000	 0.002349	 0.0155	 0.0	 2015	 2015	 2015	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 8357	 0.053901	 0.092744	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 5629	 0.003273	 0.010033	 0.0	 2994	 2994	 2994	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 2505	 0.005066	 0.013769	 0.0	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 2505	 0.007826	 0.028587	 0.0	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	2505	 5195	 0.032769	 0.058711	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	8051	 7970	 0.053702	 0.134017	 0.0	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 2585	 0.00147	 0.01305	 0.0	 1218.0	 3360	 3360	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 5684	 0.00019	 0.00195	 0.0	 1415.0	 22518	 22518	 0.0	 0.0	 1	 -30.0	 30.0;
	5985	 5684	 0.00019	 0.00191	 0.0	 1448.0	 22985	 22985	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 3016	 0.006413	 0.019917	 0.0	 1510	 1510	 1510	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 3016	 0.011562	 0.044182	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	6034	 4815	 0.002512	 0.008421	 0.0	 3595	 3595	 3595	 0.0	 0.0	 1	 -30.0	 30.0;
	493	 3738	 0.041702	 0.098711	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 493	 0.034347	 0.061636	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 5238	 0.004289	 0.01243	 0.0	 2403	 2403	 2403	 0.0	 0.0	 1	 -30.0	 30.0;
	5995	 5238	 0.000686	 0.001471	 0.0	 19462	 19462	 19462	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 5775	 0.006612	 0.01886	 0.0	 1581	 1581	 1581	 0.0	 0.0	 1	 -30.0	 30.0;
	7783	 5775	 0.008388	 0.023339	 0.0	 1274	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 5995	 0.004372	 0.012174	 0.0	 2442	 2442	 2442	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 7783	 0.013413	 0.047793	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 1372	 0.08438	 0.183769	 0.0	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2802	 4015	 0.006372	 0.01681	 0.0	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	7938	 5195	 0.028579	 0.084149	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	7938	 4240	 0.007008	 0.022388	 0.0	 1347	 1347	 1347	 0.0	 0.0	 1	 -30.0	 30.0;
	8051	 8566	 0.003	 0.005058	 0.0	 5372	 5372	 5372	 0.0	 0.0	 1	 -30.0	 30.0;
	274	 8566	 0.002669	 0.005727	 0.0	 5000	 5000	 5000	 0.0	 0.0	 1	 -30.0	 30.0;
	8566	 2295	 0.003661	 0.008818	 0.0	 3309	 3309	 3309	 0.0	 0.0	 1	 -30.0	 30.0;
	8566	 4131	 0.029843	 0.069744	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	274	 3470	 0.006438	 0.01824	 0.0	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	274	 3470	 0.006322	 0.018636	 0.0	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	8358	 8474	 0.00068	 0.00797	 0.0	 1218.0	 3949	 3949	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 8665	 0.032364	 0.088289	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 4131	 0.027066	 0.084496	 0.0	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 4131	 0.026554	 0.086256	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 2295	 0.029901	 0.071322	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	591	 504	 0.011901	 0.023818	 0.0	 1187	 1187	 1187	 0.0	 0.0	 1	 -30.0	 30.0;
	7705	 504	 0.012132	 0.023322	 0.0	 1202	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	4899	 7521	 0.0098	 0.062349	 0.0	 400.0	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	591	 6898	 0.004182	 0.012678	 0.0	 2367	 2367	 2367	 0.0	 0.0	 1	 -30.0	 30.0;
	7705	 6898	 0.003636	 0.014636	 0.0	 2095	 2095	 2095	 0.0	 0.0	 1	 -30.0	 30.0;
	8665	 4814	 0.01919	 0.045041	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 5208	 0.009793	 0.037174	 0.0	 822	 822	 822	 0.0	 0.0	 1	 -30.0	 30.0;
	5208	 1427	 0.004281	 0.010339	 0.0	 2823	 2823	 2823	 0.0	 0.0	 1	 -30.0	 30.0;
	5208	 1427	 0.005521	 0.021471	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	895	 254	 0.0011	 0.01325	 0.0	 1349.0	 2376	 2376	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 8437	 0.018421	 0.051372	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 1003	 0.011521	 0.042529	 0.0	 717	 717	 717	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 3399	 0.025182	 0.071554	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	8969	 3232	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	1408	 4220	 0.014603	 0.03386	 0.0	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	4383	 2568	 0.022066	 0.054521	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	1960	 4383	 0.041471	 0.090793	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 6034	 0.008843	 0.031901	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	3750	 5000	 0.00038	 0.003091	 0.0	 533.0	 10143	 10143	 0.0	 0.0	 1	 -30.0	 30.0;
	3750	 5000	 0.0005	 0.002901	 0.0	 514.0	 10731	 10731	 0.0	 0.0	 1	 -30.0	 30.0;
	7687	 8357	 0.032132	 0.318198	 0.0	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	7687	 2195	 0.058554	 0.146124	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 7687	 0.023917	 0.073289	 0.0	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	7687	 4220	 0.040818	 0.089273	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	2398	 2253	 2e-05	 0.00025	 0.0	 1185.0	 175910	 175910	 0.0	 0.0	 1	 -30.0	 30.0;
	2398	 2253	 2e-05	 0.00026	 0.0	 1086.0	 169185	 169185	 0.0	 0.0	 1	 -30.0	 30.0;
	2253	 2737	 0.00082	 0.00822	 0.0	 1086.0	 5341	 5341	 0.0	 0.0	 1	 -30.0	 30.0;
	2201	 1018	 0.014339	 0.031777	 0.0	 907	 907	 907	 0.0	 0.0	 1	 -30.0	 30.0;
	4784	 6358	 0.011364	 0.034364	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	6358	 2988	 0.000347	 0.001066	 0.0	 28177	 28177	 28177	 0.0	 0.0	 1	 -30.0	 30.0;
	4240	 8357	 0.012752	 0.036041	 0.0	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 8357	 0.000669	 0.001281	 0.0	 21858	 21858	 21858	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 8357	 0.000661	 0.001314	 0.0	 21475	 21475	 21475	 0.0	 0.0	 1	 -30.0	 30.0;
	8865	 4015	 0.005289	 0.014942	 0.0	 1993	 1993	 1993	 0.0	 0.0	 1	 -30.0	 30.0;
	1960	 8261	 0.004256	 0.007364	 0.0	 3714	 3714	 3714	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 8261	 0.003992	 0.009107	 0.0	 3177	 3177	 3177	 0.0	 0.0	 1	 -30.0	 30.0;
	6610	 3637	 0.041488	 0.08662	 0.0	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 9193	 0.00486	 0.010132	 0.0	 2811	 2811	 2811	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 430	 0.00495	 0.009934	 0.0	 2846	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	430	 9193	 0.00505	 0.009719	 0.0	 2884	 2884	 2884	 0.0	 0.0	 1	 -30.0	 30.0;
	1003	 8437	 0.00776	 0.027521	 0.0	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 2473	 0.00262	 0.007628	 0.0	 3917	 3917	 3917	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 4220	 0.001793	 0.005471	 0.0	 5487	 5487	 5487	 0.0	 0.0	 1	 -30.0	 30.0;
	9124	 3713	 0.000537	 0.015661	 0.0	 2016	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	4784	 2988	 0.01124	 0.036826	 0.0	 821	 821	 821	 0.0	 0.0	 1	 -30.0	 30.0;
	8556	 1920	 0.00156	 0.01791	 0.0	 1152.0	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 6907	 0.00155	 0.01686	 0.0	 1283.0	 1866	 1866	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 6907	 0.00152	 0.01719	 0.0	 1218.0	 1831	 1831	 0.0	 0.0	 1	 -30.0	 30.0;
	8263	 1920	 0.00068	 0.00644	 0.0	 1415.0	 4878	 4878	 0.0	 0.0	 1	 -30.0	 30.0;
	8263	 1920	 0.00069	 0.0063	 0.0	 1448.0	 4985	 4985	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 5824	 0.00112	 0.01064	 0.0	 1711.0	 2953	 2953	 0.0	 0.0	 1	 -30.0	 30.0;
	3447	 4966	 0.00151	 0.011539	 0.0	 476.0	 2715	 2715	 0.0	 0.0	 1	 -30.0	 30.0;
	8145	 3447	 0.00788	 0.05236	 0.0	 476.0	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 6907	 0.00128	 0.0126	 0.0	 1251.0	 2495	 2495	 0.0	 0.0	 1	 -30.0	 30.0;
	816	 1542	 0.00037	 0.00409	 0.0	 1053.0	 7692	 7692	 0.0	 0.0	 1	 -30.0	 30.0;
	816	 1542	 0.00036	 0.00417	 0.0	 1152.0	 7547	 7547	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 5824	 0.00122	 0.0112	 0.0	 1020.0	 2804	 2804	 0.0	 0.0	 1	 -30.0	 30.0;
	8145	 8325	 0.006591	 0.04075	 0.0	 419.0	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	2887	 4966	 0.007961	 0.05756	 0.0	 419.0	 544	 544	 0.0	 0.0	 1	 -30.0	 30.0;
	5092	 2646	 0.00059	 0.0085	 0.0	 1053.0	 3708	 3708	 0.0	 0.0	 1	 -30.0	 30.0;
	2646	 5503	 0.00084	 0.0118	 0.0	 954.0	 2671	 2671	 0.0	 0.0	 1	 -30.0	 30.0;
	2646	 6446	 0.00178	 0.01804	 0.0	 790.0	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 2492	 0.00937	 0.073969	 0.0	 419.0	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 3197	 0.011081	 0.06593	 0.0	 400.0	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 2846	 0.009669	 0.04251	 0.0	 381.0	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	6930	 9030	 0.00073	 0.00713	 0.0	 790.0	 4408	 4408	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 5503	 0.00034	 0.00345	 0.0	 1053.0	 9112	 9112	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 7063	 0.00012	 0.00128	 0.0	 987.0	 24570	 24570	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 255	 0.00012	 0.00123	 0.0	 1020.0	 25560	 25560	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 2051	 9e-05	 0.00112	 0.0	 921.0	 28113	 28113	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 846	 0.00062	 0.00866	 0.0	 1448.0	 3639	 3639	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 1337	 0.00157	 0.01614	 0.0	 1448.0	 1948	 1948	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 1337	 0.0014	 0.01829	 0.0	 1415.0	 1722	 1722	 0.0	 0.0	 1	 -30.0	 30.0;
	287	 2807	 0.00078	 0.00805	 0.0	 1349.0	 3906	 3906	 0.0	 0.0	 1	 -30.0	 30.0;
	2807	 4111	 0.00094	 0.01427	 0.0	 1481.0	 2209	 2209	 0.0	 0.0	 1	 -30.0	 30.0;
	7758	 5503	 0.00024	 0.00283	 0.0	 1349.0	 11122	 11122	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 846	 0.00099	 0.00865	 0.0	 1251.0	 3629	 3629	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 5503	 0.0011	 0.01426	 0.0	 1316.0	 2209	 2209	 0.0	 0.0	 1	 -30.0	 30.0;
	2492	 689	 0.006919	 0.050521	 0.0	 419.0	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 5107	 0.0006	 0.00646	 0.0	 1349.0	 4869	 4869	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 5819	 0.00127	 0.0128	 0.0	 823.0	 2456	 2456	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 9107	 0.00052	 0.00496	 0.0	 1349.0	 6334	 6334	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 1118	 0.00064	 0.00886	 0.0	 1448.0	 3556	 3556	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 1118	 0.00072	 0.00868	 0.0	 1547.0	 3627	 3627	 0.0	 0.0	 1	 -30.0	 30.0;
	287	 8245	 0.00232	 0.02522	 0.0	 823.0	 1248	 1248	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 287	 0.0003	 0.00304	 0.0	 1448.0	 10341	 10341	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 287	 0.00032	 0.00306	 0.0	 1316.0	 10267	 10267	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 287	 0.00028	 0.00307	 0.0	 1448.0	 10247	 10247	 0.0	 0.0	 1	 -30.0	 30.0;
	9030	 7562	 0.00092	 0.00969	 0.0	 921.0	 3246	 3246	 0.0	 0.0	 1	 -30.0	 30.0;
	9030	 5819	 0.00181	 0.01696	 0.0	 1020.0	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	9030	 6446	 0.00132	 0.01148	 0.0	 1283.0	 2734	 2734	 0.0	 0.0	 1	 -30.0	 30.0;
	7562	 4111	 0.00108	 0.01087	 0.0	 1349.0	 2892	 2892	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 8245	 0.00209	 0.01924	 0.0	 823.0	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	9107	 5107	 0.00036	 0.00457	 0.0	 1053.0	 6891	 6891	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 1723	 0.0017	 0.01986	 0.0	 757.0	 1585	 1585	 0.0	 0.0	 1	 -30.0	 30.0;
	846	 2294	 0.00059	 0.00982	 0.0	 954.0	 3211	 3211	 0.0	 0.0	 1	 -30.0	 30.0;
	8760	 2846	 0.00494	 0.03182	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	8760	 2846	 0.004841	 0.03245	 0.0	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 6446	 0.00036	 0.00391	 0.0	 1613.0	 8045	 8045	 0.0	 0.0	 1	 -30.0	 30.0;
	1118	 1723	 0.00071	 0.00983	 0.0	 921.0	 3206	 3206	 0.0	 0.0	 1	 -30.0	 30.0;
	1118	 1723	 0.00081	 0.00963	 0.0	 1020.0	 3269	 3269	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 794	 0.006271	 0.03645	 0.0	 855	 855	 855	 0.0	 0.0	 1	 -30.0	 30.0;
	7724	 4924	 0.186281	 0.374281	 0.0	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	8041	 4924	 0.089612	 0.230339	 0.0	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	7870	 4190	 0.00393	 0.04552	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 6091	 0.004169	 0.02651	 0.0	 438.0	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 6091	 0.003831	 0.02438	 0.0	 457.0	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 5389	 0.00789	 0.04725	 0.0	 591.0	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 5389	 0.008039	 0.046219	 0.0	 381.0	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	956	 8067	 0.040174	 0.084397	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 607	 0.00166	 0.01276	 0.0	 1429.0	 2455	 2455	 0.0	 0.0	 1	 -30.0	 30.0;
	7678	 6091	 0.00094	 0.00599	 0.0	 381.0	 5210	 5210	 0.0	 0.0	 1	 -30.0	 30.0;
	7678	 6091	 0.00107	 0.00587	 0.0	 400.0	 5294	 5294	 0.0	 0.0	 1	 -30.0	 30.0;
	1075	 4063	 0.011901	 0.028364	 0.0	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	4063	 8067	 0.059091	 0.102636	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	8041	 4063	 0.090471	 0.19919	 0.0	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	599	 1683	 0.00755	 0.050919	 0.0	 438.0	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	599	 1683	 0.0077	 0.04988	 0.0	 514.0	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	4242	 7724	 0.238893	 0.453901	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	446	 4242	 0.062719	 0.104479	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 1683	 0.000979	 0.074909	 0.0	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 1683	 0.000961	 0.076349	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 1683	 0.002159	 0.079031	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 1683	 0.001961	 0.09125	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	446	 7724	 0.066636	 0.183934	 0.0	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 3464	 0.00028	 0.00282	 0.0	 1593.0	 11147	 11147	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 5920	 0.00018	 0.00233	 0.0	 1905.0	 13517	 13517	 0.0	 0.0	 1	 -30.0	 30.0;
	813	 5466	 4e-05	 0.0004	 0.0	 1212.0	 78577	 78577	 0.0	 0.0	 1	 -30.0	 30.0;
	813	 5757	 0.0017	 0.01741	 0.0	 1316.0	 1806	 1806	 0.0	 0.0	 1	 -30.0	 30.0;
	813	 5920	 0.00097	 0.0123	 0.0	 1940.0	 2561	 2561	 0.0	 0.0	 1	 -30.0	 30.0;
	813	 2028	 0.00057	 0.00725	 0.0	 1871.0	 4344	 4344	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 5466	 0.00177	 0.01811	 0.0	 1247.0	 1736	 1736	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 6929	 0.00049	 0.00505	 0.0	 1247.0	 6226	 6226	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 6588	 0.00199	 0.02534	 0.0	 1243	 1243	 1243	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 3464	 0.00024	 0.00242	 0.0	 1593.0	 12989	 12989	 0.0	 0.0	 1	 -30.0	 30.0;
	530	 4654	 0.01379	 0.0443	 0.0	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	530	 6324	 0.00615	 0.04848	 0.0	 647	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	530	 8648	 0.02224	 0.07142	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	530	 5734	 0.0084	 0.06621	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 3212	 7e-05	 0.00068	 0.0	 307.0	 46208	 46208	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 6237	 0.00669	 0.05272	 0.0	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 8472	 0.003	 0.03068	 0.0	 1025	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 423	 0.01129	 0.05381	 0.0	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 1664	 0.02312	 0.11021	 0.0	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 8472	 0.0044	 0.03467	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 581	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 581	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 2370	 0.00603	 0.02877	 0.0	 280.0	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	9034	 6237	 0.01127	 0.0691	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	9034	 151	 0.01447	 0.04647	 0.0	 650	 650	 650	 0.0	 0.0	 1	 -30.0	 30.0;
	9034	 4654	 0.00858	 0.06762	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	9034	 7363	 0.00026	 0.00161	 0.0	 19369	 19369	 19369	 0.0	 0.0	 1	 -30.0	 30.0;
	6237	 151	 0.0037	 0.02918	 0.0	 1074	 1074	 1074	 0.0	 0.0	 1	 -30.0	 30.0;
	6237	 8105	 0.00847	 0.0404	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	6237	 8770	 0.00026	 0.00161	 0.0	 19369	 19369	 19369	 0.0	 0.0	 1	 -30.0	 30.0;
	151	 8472	 0.00935	 0.03001	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	151	 8472	 0.00553	 0.02634	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	151	 4090	 0.00318	 0.0251	 0.0	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	151	 2370	 0.00689	 0.05429	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	7326	 2171	 0.00617	 0.02941	 0.0	 1052	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	7326	 6324	 0.00476	 0.0375	 0.0	 836	 836	 836	 0.0	 0.0	 1	 -30.0	 30.0;
	2171	 6266	 0.0157	 0.07482	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 7733	 0.02731	 0.08769	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 6388	 0.03423	 0.10993	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	4654	 6536	 0.00112	 0.01141	 0.0	 2756	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	4654	 4090	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	4654	 8218	 0.01187	 0.05656	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	2408	 6388	 0.00922	 0.04395	 0.0	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	2408	 5734	 0.00995	 0.07845	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	6266	 8648	 0.01548	 0.04972	 0.0	 607	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	6266	 8218	 0.00339	 0.01616	 0.0	 1914	 1914	 1914	 0.0	 0.0	 1	 -30.0	 30.0;
	234	 8105	 0.00851	 0.04056	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	6536	 7363	 0.0099	 0.06074	 0.0	 280.0	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	6388	 1154	 0.01001	 0.07892	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	6388	 5734	 0.01647	 0.07854	 0.0	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	8472	 1154	 0.00392	 0.03091	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 2370	 0.00603	 0.02877	 0.0	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	6370	 5757	 0.00043	 0.00443	 0.0	 1351.0	 7097	 7097	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 1941	 6e-05	 0.0008	 0.0	 39374	 39374	 39374	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 836	 0.00029	 0.00366	 0.0	 1836.0	 8604	 8604	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 644	 0.00051	 0.00643	 0.0	 2044.0	 4898	 4898	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 6300	 0.00033	 0.00424	 0.0	 7428	 7428	 7428	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 3628	 0.00034	 0.00432	 0.0	 7290	 7290	 7290	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 8793	 0.00013	 0.00145	 0.0	 1247.0	 21698	 21698	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 836	 0.00018	 0.00233	 0.0	 1905.0	 13517	 13517	 0.0	 0.0	 1	 -30.0	 30.0;
	3628	 8089	 0.00034	 0.00432	 0.0	 1871.0	 7290	 7290	 0.0	 0.0	 1	 -30.0	 30.0;
	3628	 4455	 0.00208	 0.02643	 0.0	 1192	 1192	 1192	 0.0	 0.0	 1	 -30.0	 30.0;
	3628	 7408	 0.00209	 0.0266	 0.0	 1184	 1184	 1184	 0.0	 0.0	 1	 -30.0	 30.0;
	3628	 2028	 0.00057	 0.00725	 0.0	 1905.0	 4344	 4344	 0.0	 0.0	 1	 -30.0	 30.0;
	7962	 2264	 0.00034	 0.00153	 0.0	 20154	 20154	 20154	 0.0	 0.0	 1	 -30.0	 30.0;
	7962	 2264	 0.00034	 0.00153	 0.0	 20154	 20154	 20154	 0.0	 0.0	 1	 -30.0	 30.0;
	8793	 836	 8e-05	 0.00089	 0.0	 935.0	 35349	 35349	 0.0	 0.0	 1	 -30.0	 30.0;
	8793	 8390	 6e-05	 0.00067	 0.0	 1039.0	 46958	 46958	 0.0	 0.0	 1	 -30.0	 30.0;
	6269	 5427	 0.00181	 0.01428	 0.0	 2195	 2195	 2195	 0.0	 0.0	 1	 -30.0	 30.0;
	6269	 5427	 0.00181	 0.01428	 0.0	 2195	 2195	 2195	 0.0	 0.0	 1	 -30.0	 30.0;
	6269	 3045	 0.00576	 0.03535	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	6269	 8988	 0.00576	 0.03535	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 3386	 0.00526	 0.02505	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 3386	 0.00526	 0.02505	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 4212	 0.00159	 0.01612	 0.0	 1951	 1951	 1951	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 4212	 0.00159	 0.01612	 0.0	 1951	 1951	 1951	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 2750	 0.00121	 0.01227	 0.0	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 2750	 0.00121	 0.01227	 0.0	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	7084	 852	 0.00132	 0.0063	 0.0	 4908	 4908	 4908	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 2001	 0.0019	 0.00905	 0.0	 3416	 3416	 3416	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 2001	 0.0019	 0.00905	 0.0	 3416	 3416	 3416	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 1983	 0.00025	 0.00264	 0.0	 11912	 11912	 11912	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 1983	 0.0002	 0.00204	 0.0	 15411	 15411	 15411	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 852	 0.00031	 0.00316	 0.0	 9949	 9949	 9949	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 4061	 0.00031	 0.00316	 0.0	 9949	 9949	 9949	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 2266	 0.00145	 0.01145	 0.0	 2737	 2737	 2737	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 8928	 0.00141	 0.01116	 0.0	 2809	 2809	 2809	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 7802	 0.00036	 0.00359	 0.0	 8755	 8755	 8755	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 7802	 0.00036	 0.00359	 0.0	 8755	 8755	 8755	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 8928	 0.00066	 0.00518	 0.0	 6050	 6050	 6050	 0.0	 0.0	 1	 -30.0	 30.0;
	120	 5840	 0.00049	 0.00496	 0.0	 267.0	 6338	 6338	 0.0	 0.0	 1	 -30.0	 30.0;
	120	 2373	 0.00028	 0.00296	 0.0	 10624	 10624	 10624	 0.0	 0.0	 1	 -30.0	 30.0;
	120	 6678	 0.00028	 0.00304	 0.0	 10347	 10347	 10347	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 3386	 0.00654	 0.03119	 0.0	 992	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 3403	 0.00108	 0.00517	 0.0	 5981	 5981	 5981	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 3403	 0.00108	 0.00517	 0.0	 5981	 5981	 5981	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 872	 0.00119	 0.00941	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 872	 0.00119	 0.00941	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	3045	 3402	 0.0061	 0.03744	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	3045	 3402	 0.0061	 0.03744	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	3045	 8988	 0.00052	 0.00321	 0.0	 267.0	 9714	 9714	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 8928	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 8928	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 6731	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 6731	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	2375	 8122	 0.00026	 0.00267	 0.0	 11775	 11775	 11775	 0.0	 0.0	 1	 -30.0	 30.0;
	2375	 8563	 0.00021	 0.00224	 0.0	 14040	 14040	 14040	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 6545	 0.00173	 0.01365	 0.0	 2296	 2296	 2296	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 6545	 0.00173	 0.01365	 0.0	 2296	 2296	 2296	 0.0	 0.0	 1	 -30.0	 30.0;
	2373	 872	 0.00037	 0.00401	 0.0	 7844	 7844	 7844	 0.0	 0.0	 1	 -30.0	 30.0;
	2373	 872	 0.00037	 0.00401	 0.0	 7844	 7844	 7844	 0.0	 0.0	 1	 -30.0	 30.0;
	872	 4769	 0.00073	 0.00744	 0.0	 4226	 4226	 4226	 0.0	 0.0	 1	 -30.0	 30.0;
	872	 4769	 0.00073	 0.00744	 0.0	 4226	 4226	 4226	 0.0	 0.0	 1	 -30.0	 30.0;
	6277	 2264	 0.00031	 0.00329	 0.0	 9559	 9559	 9559	 0.0	 0.0	 1	 -30.0	 30.0;
	6277	 2264	 0.00025	 0.00254	 0.0	 12377	 12377	 12377	 0.0	 0.0	 1	 -30.0	 30.0;
	6277	 1995	 0.00031	 0.0031	 0.0	 10139	 10139	 10139	 0.0	 0.0	 1	 -30.0	 30.0;
	6277	 1995	 0.00031	 0.0031	 0.0	 10139	 10139	 10139	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 7288	 0.00034	 0.00108	 0.0	 27898	 27898	 27898	 0.0	 0.0	 1	 -30.0	 30.0;
	9129	 7288	 0.00042	 0.00449	 0.0	 307.0	 7005	 7005	 0.0	 0.0	 1	 -30.0	 30.0;
	9129	 8563	 0.00025	 0.00248	 0.0	 12673	 12673	 12673	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 7281	 0.00119	 0.01202	 0.0	 2616	 2616	 2616	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 7281	 0.00119	 0.01202	 0.0	 2616	 2616	 2616	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 7802	 0.00034	 0.00341	 0.0	 9218	 9218	 9218	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 7802	 0.00034	 0.00341	 0.0	 9218	 9218	 9218	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 5345	 0.00034	 0.00369	 0.0	 307.0	 8525	 8525	 0.0	 0.0	 1	 -30.0	 30.0;
	8122	 8563	 0.00053	 0.00569	 0.0	 5528	 5528	 5528	 0.0	 0.0	 1	 -30.0	 30.0;
	8122	 4061	 0.00336	 0.016	 0.0	 1933	 1933	 1933	 0.0	 0.0	 1	 -30.0	 30.0;
	7281	 2298	 0.00827	 0.03943	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	7281	 2298	 0.00827	 0.03943	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	4212	 7277	 0.00073	 0.00785	 0.0	 293.0	 4007	 4007	 0.0	 0.0	 1	 -30.0	 30.0;
	4212	 2750	 0.00117	 0.00926	 0.0	 3385	 3385	 3385	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 5200	 0.00037	 0.00401	 0.0	 293.0	 7844	 7844	 0.0	 0.0	 1	 -30.0	 30.0;
	1941	 8390	 0.00012	 0.00134	 0.0	 1039.0	 23479	 23479	 0.0	 0.0	 1	 -30.0	 30.0;
	8089	 1827	 0.00023	 0.00298	 0.0	 2009.0	 10569	 10569	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 1420	 0.00087	 0.01433	 0.0	 1316.0	 2201	 2201	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 1420	 0.00088	 0.01455	 0.0	 901.0	 2167	 2167	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 8680	 0.00133	 0.01364	 0.0	 1351.0	 2305	 2305	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 4917	 0.00064	 0.00644	 0.0	 1524.0	 4881	 4881	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 7408	 0.00025	 0.00324	 0.0	 9721	 9721	 9721	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 8714	 0.00276	 0.02823	 0.0	 1114	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 1738	 0.00266	 0.02691	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 366	 0.00196	 0.01981	 0.0	 1386.0	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 4305	 0.0023	 0.03797	 0.0	 831	 831	 831	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 1827	 0.00027	 0.00344	 0.0	 9155	 9155	 9155	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 644	 0.00032	 0.00526	 0.0	 1074.0	 5995	 5995	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 4917	 0.001	 0.0101	 0.0	 1559.0	 3113	 3113	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 4888	 0.00017	 0.00279	 0.0	 1351.0	 11301	 11301	 0.0	 0.0	 1	 -30.0	 30.0;
	8680	 4455	 0.00097	 0.0123	 0.0	 1905.0	 2561	 2561	 0.0	 0.0	 1	 -30.0	 30.0;
	8680	 4920	 0.00228	 0.02898	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	8680	 1152	 0.00269	 0.03425	 0.0	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	8680	 7378	 0.00096	 0.00982	 0.0	 1247.0	 3202	 3202	 0.0	 0.0	 1	 -30.0	 30.0;
	1827	 7408	 0.00105	 0.01739	 0.0	 1351.0	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	1827	 6300	 0.00028	 0.00351	 0.0	 8971	 8971	 8971	 0.0	 0.0	 1	 -30.0	 30.0;
	644	 4888	 0.00017	 0.00279	 0.0	 866.0	 11301	 11301	 0.0	 0.0	 1	 -30.0	 30.0;
	3591	 1291	 0.00278	 0.01325	 0.0	 2334	 2334	 2334	 0.0	 0.0	 1	 -30.0	 30.0;
	3591	 2287	 0.04068	 0.19392	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 6674	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 2618	 0.01526	 0.07272	 0.0	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 6123	 0.02017	 0.09615	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 6903	 0.01254	 0.05979	 0.0	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	6386	 8366	 0.0046	 0.03624	 0.0	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	6386	 2007	 0.01993	 0.064	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 1223	 0.00974	 0.03128	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 1659	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 2287	 0.04605	 0.14789	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 4078	 0.00287	 0.00922	 0.0	 3272	 3272	 3272	 0.0	 0.0	 1	 -30.0	 30.0;
	3135	 4066	 0.00308	 0.0315	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	3135	 2336	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 1799	 0.0033	 0.02605	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 4777	 0.00239	 0.02444	 0.0	 1287	 1287	 1287	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 8116	 0.0003	 0.00312	 0.0	 333.0	 10078	 10078	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 4303	 0.00318	 0.0251	 0.0	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	897	 4292	 0.00043	 0.00434	 0.0	 7243	 7243	 7243	 0.0	 0.0	 1	 -30.0	 30.0;
	897	 371	 0.00259	 0.0204	 0.0	 1537	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	1799	 8078	 0.00305	 0.01454	 0.0	 2127	 2127	 2127	 0.0	 0.0	 1	 -30.0	 30.0;
	1799	 8078	 0.00305	 0.01454	 0.0	 2127	 2127	 2127	 0.0	 0.0	 1	 -30.0	 30.0;
	1799	 2336	 0.00119	 0.00941	 0.0	 307.0	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	6674	 8366	 0.02353	 0.07557	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	9188	 9099	 0.00306	 0.02416	 0.0	 1298	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	9188	 777	 0.00398	 0.03138	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1312	 8366	 0.01471	 0.07013	 0.0	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 5129	 0.00325	 0.03326	 0.0	 946	 946	 946	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 5230	 0.0006	 0.00607	 0.0	 307.0	 5179	 5179	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 4777	 0.00146	 0.01493	 0.0	 2106	 2106	 2106	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 5785	 0.00061	 0.0062	 0.0	 5071	 5071	 5071	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 374	 0.00075	 0.00356	 0.0	 8683	 8683	 8683	 0.0	 0.0	 1	 -30.0	 30.0;
	6111	 5291	 0.00921	 0.0305	 0.0	 992	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 8366	 0.01233	 0.0396	 0.0	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	8597	 3783	 0.0117	 0.05575	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	8597	 3783	 0.0117	 0.05575	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	8597	 1244	 0.00169	 0.00808	 0.0	 3827	 3827	 3827	 0.0	 0.0	 1	 -30.0	 30.0;
	8597	 2818	 0.00235	 0.01851	 0.0	 1693	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	8597	 2818	 0.00235	 0.01851	 0.0	 1693	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	8597	 777	 0.00119	 0.00941	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	8597	 777	 0.00119	 0.00941	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	7888	 4007	 0.00046	 0.00497	 0.0	 293.0	 6329	 6329	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 5129	 0.00024	 0.00188	 0.0	 16667	 16667	 16667	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 2618	 0.01288	 0.06141	 0.0	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 2287	 0.02105	 0.10035	 0.0	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 8116	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 4303	 0.008	 0.06307	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 319	 0.00046	 0.00497	 0.0	 6329	 6329	 6329	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 7263	 0.00034	 0.0036	 0.0	 8736	 8736	 8736	 0.0	 0.0	 1	 -30.0	 30.0;
	4630	 4303	 0.01068	 0.0509	 0.0	 608	 608	 608	 0.0	 0.0	 1	 -30.0	 30.0;
	4630	 3140	 0.00475	 0.02262	 0.0	 1367	 1367	 1367	 0.0	 0.0	 1	 -30.0	 30.0;
	3143	 374	 0.00022	 0.0024	 0.0	 13107	 13107	 13107	 0.0	 0.0	 1	 -30.0	 30.0;
	3143	 1230	 0.00054	 0.00259	 0.0	 11940	 11940	 11940	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 4086	 0.00041	 0.00441	 0.0	 7132	 7132	 7132	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 4086	 0.00041	 0.00441	 0.0	 7132	 7132	 7132	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 7263	 0.00031	 0.0031	 0.0	 10139	 10139	 10139	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 3168	 0.00259	 0.0204	 0.0	 1537	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	9103	 43	 0.0044	 0.03467	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	9103	 3783	 0.01353	 0.10669	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	6646	 3783	 0.01736	 0.08274	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	6646	 3783	 0.01736	 0.08274	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	4007	 7263	 0.00034	 0.0036	 0.0	 293.0	 8736	 8736	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 5113	 0.00035	 0.00353	 0.0	 280.0	 8905	 8905	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 5113	 0.00035	 0.00353	 0.0	 307.0	 8905	 8905	 0.0	 0.0	 1	 -30.0	 30.0;
	9099	 777	 0.00131	 0.01036	 0.0	 3025	 3025	 3025	 0.0	 0.0	 1	 -30.0	 30.0;
	4455	 7408	 1.5e-05	 0.000199	 0.0	 1905.0	 158282	 158282	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 3783	 0.00637	 0.05021	 0.0	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 5291	 0.0105	 0.03466	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 3140	 0.01576	 0.07514	 0.0	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 371	 0.00112	 0.01202	 0.0	 2617	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 2818	 0.00028	 0.0009	 0.0	 33513	 33513	 33513	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 8518	 0.0165	 0.05297	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	4917	 8714	 0.00233	 0.02385	 0.0	 1319	 1319	 1319	 0.0	 0.0	 1	 -30.0	 30.0;
	2818	 5899	 0.00547	 0.04315	 0.0	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	2818	 5899	 0.00547	 0.04315	 0.0	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	7408	 4305	 0.00219	 0.03613	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	8657	 8714	 0.00032	 0.00326	 0.0	 1212.0	 9644	 9644	 0.0	 0.0	 1	 -30.0	 30.0;
	8657	 1881	 0.00215	 0.022	 0.0	 1247.0	 1429	 1429	 0.0	 0.0	 1	 -30.0	 30.0;
	8657	 7429	 0.00173	 0.01767	 0.0	 1247.0	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 8654	 0.00318	 0.0251	 0.0	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 4173	 0.00497	 0.03923	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 4420	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 543	 0.00147	 0.01161	 0.0	 2700	 2700	 2700	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 7032	 0.00511	 0.04032	 0.0	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	9052	 8440	 0.00103	 0.00816	 0.0	 3841	 3841	 3841	 0.0	 0.0	 1	 -30.0	 30.0;
	9052	 1134	 0.00139	 0.01098	 0.0	 2855	 2855	 2855	 0.0	 0.0	 1	 -30.0	 30.0;
	9052	 1444	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	8440	 1444	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 5134	 0.01132	 0.05397	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 6175	 0.00358	 0.02824	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 2741	 0.00085	 0.00404	 0.0	 7652	 7652	 7652	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 8654	 0.00358	 0.02824	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 8654	 0.00358	 0.02824	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	7558	 7964	 0.00086	 0.0053	 0.0	 267.0	 5883	 5883	 0.0	 0.0	 1	 -30.0	 30.0;
	7558	 7964	 0.00086	 0.0053	 0.0	 267.0	 5883	 5883	 0.0	 0.0	 1	 -30.0	 30.0;
	7558	 7032	 0.00219	 0.01726	 0.0	 1816	 1816	 1816	 0.0	 0.0	 1	 -30.0	 30.0;
	7558	 3345	 0.00505	 0.02408	 0.0	 267.0	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 3989	 0.00402	 0.03169	 0.0	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 3755	 0.00468	 0.03687	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 3755	 0.00468	 0.03687	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 7032	 0.00643	 0.05068	 0.0	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 6123	 0.04025	 0.12927	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	3989	 7032	 0.00302	 0.02385	 0.0	 1314	 1314	 1314	 0.0	 0.0	 1	 -30.0	 30.0;
	109	 2746	 0.01417	 0.06755	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	109	 4043	 0.01503	 0.04827	 0.0	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	109	 5134	 0.02556	 0.12185	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 3755	 0.02618	 0.08407	 0.0	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 5134	 0.01105	 0.05268	 0.0	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	4043	 6640	 0.00788	 0.06213	 0.0	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	4043	 6175	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	4043	 1134	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 5134	 0.02098	 0.10003	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 2281	 0.00793	 0.03781	 0.0	 818	 818	 818	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 2741	 0.01136	 0.05414	 0.0	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 2281	 0.02597	 0.12379	 0.0	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	6640	 6123	 0.02004	 0.06436	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	8714	 5846	 0.00229	 0.02909	 0.0	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 1134	 0.00338	 0.02667	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 1134	 0.00338	 0.02667	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	8654	 4420	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 2281	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	1881	 2775	 0.00128	 0.01308	 0.0	 1351.0	 2404	 2404	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 1558	 0.00438	 0.03452	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 9182	 0.01992	 0.15706	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 2281	 0.03389	 0.10884	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 7188	 0.01313	 0.10355	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 1975	 0.00557	 0.04393	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	1558	 3336	 0.01008	 0.03236	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	1558	 2833	 0.01493	 0.11768	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 6890	 0.03074	 0.09872	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 6890	 0.04301	 0.13813	 0.0	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4633	 6941	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	4633	 2281	 0.02883	 0.09257	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	4633	 7188	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	4633	 6850	 0.0045	 0.01446	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	6941	 1772	 0.01712	 0.05496	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 9182	 0.02573	 0.08263	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 1772	 0.05152	 0.16543	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	9182	 3590	 0.01871	 0.11474	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	9182	 2533	 0.05489	 0.17628	 0.0	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	9182	 7188	 0.01186	 0.09351	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	9182	 3979	 0.00169	 0.01334	 0.0	 2350	 2350	 2350	 0.0	 0.0	 1	 -30.0	 30.0;
	9182	 3979	 0.00169	 0.01334	 0.0	 2350	 2350	 2350	 0.0	 0.0	 1	 -30.0	 30.0;
	3590	 185	 0.00811	 0.02603	 0.0	 1159	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	3590	 7337	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	3590	 7337	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 185	 0.00736	 0.05805	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	9061	 2833	 0.01094	 0.0863	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	9061	 185	 0.01214	 0.09571	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 3501	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 2104	 0.03063	 0.09836	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 2775	 0.00242	 0.03076	 0.0	 1024	 1024	 1024	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 7429	 0.00083	 0.00845	 0.0	 1039.0	 3721	 3721	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 4567	 0.0056	 0.05722	 0.0	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 5934	 0.0036	 0.03646	 0.0	 797.0	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 7658	 0.001	 0.0101	 0.0	 1282.0	 3113	 3113	 0.0	 0.0	 1	 -30.0	 30.0;
	2793	 5033	 0.02308	 0.07413	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	2793	 7926	 0.01683	 0.05406	 0.0	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	6728	 5826	 0.03322	 0.10667	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	6728	 5040	 0.01094	 0.0863	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	1975	 5817	 0.01546	 0.07369	 0.0	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	9082	 6123	 0.00526	 0.02505	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	9082	 4629	 0.02898	 0.13817	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	8341	 4955	 0.01773	 0.08452	 0.0	 267.0	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	8341	 4891	 0.01368	 0.04393	 0.0	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	8341	 1080	 0.02365	 0.07594	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	8341	 7238	 0.00078	 0.00372	 0.0	 8311	 8311	 8311	 0.0	 0.0	 1	 -30.0	 30.0;
	8341	 7238	 0.00078	 0.00372	 0.0	 8311	 8311	 8311	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 4042	 0.02759	 0.08859	 0.0	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	4627	 8309	 0.01576	 0.05062	 0.0	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 9220	 0.02664	 0.12702	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	8584	 9220	 0.02162	 0.06943	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	8584	 4768	 0.03187	 0.10233	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	5431	 7926	 0.02168	 0.06961	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 4629	 0.03827	 0.18245	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 2289	 0.01465	 0.06981	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 1080	 0.00661	 0.05209	 0.0	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 1080	 0.00782	 0.06166	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	4042	 4955	 0.0366	 0.11752	 0.0	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 5932	 0.00326	 0.01049	 0.0	 2876	 2876	 2876	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 5932	 0.00326	 0.01049	 0.0	 2876	 2876	 2876	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 5932	 0.00326	 0.01049	 0.0	 2876	 2876	 2876	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 4955	 0.00732	 0.03491	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 4955	 0.00732	 0.03491	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 9220	 0.03063	 0.09836	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 9220	 0.03063	 0.09836	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 4891	 0.01768	 0.05677	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 4629	 0.03438	 0.16386	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 6903	 0.01017	 0.04848	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	7113	 4629	 0.0	 0.04891	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	7113	 9220	 0.00081	 0.00388	 0.0	 7970	 7970	 7970	 0.0	 0.0	 1	 -30.0	 30.0;
	7113	 9220	 0.00081	 0.00388	 0.0	 7970	 7970	 7970	 0.0	 0.0	 1	 -30.0	 30.0;
	4629	 1080	 0.03824	 0.18228	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4768	 8309	 0.02207	 0.07087	 0.0	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	4768	 4999	 0.0165	 0.05297	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 4567	 0.00094	 0.00958	 0.0	 1282.0	 3282	 3282	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 2659	 0.0009	 0.01147	 0.0	 1905.0	 2746	 2746	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 8317	 2e-05	 0.00026	 0.0	 1282.0	 121132	 121132	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 8317	 2e-05	 0.00026	 0.0	 1143.0	 121132	 121132	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 2775	 0.00162	 0.01656	 0.0	 1247.0	 1899	 1899	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 2683	 0.00039	 0.00641	 0.0	 1039.0	 4919	 4919	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 2683	 0.00027	 0.00444	 0.0	 901.0	 7102	 7102	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 926	 0.00288	 0.02946	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 926	 0.00192	 0.02444	 0.0	 1289	 1289	 1289	 0.0	 0.0	 1	 -30.0	 30.0;
	2659	 2455	 0.00094	 0.01197	 0.0	 1663.0	 2631	 2631	 0.0	 0.0	 1	 -30.0	 30.0;
	2659	 294	 0.00106	 0.01087	 0.0	 1178.0	 2893	 2893	 0.0	 0.0	 1	 -30.0	 30.0;
	1948	 5367	 0.00677	 0.05335	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	1948	 5367	 0.00677	 0.05335	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	787	 487	 0.00051	 0.00242	 0.0	 12773	 12773	 12773	 0.0	 0.0	 1	 -30.0	 30.0;
	787	 487	 0.00051	 0.00242	 0.0	 12773	 12773	 12773	 0.0	 0.0	 1	 -30.0	 30.0;
	787	 2711	 0.00026	 0.00204	 0.0	 15360	 15360	 15360	 0.0	 0.0	 1	 -30.0	 30.0;
	787	 2711	 0.00026	 0.00204	 0.0	 15360	 15360	 15360	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 487	 0.00139	 0.00663	 0.0	 4663	 4663	 4663	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 487	 0.00139	 0.00663	 0.0	 4663	 4663	 4663	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 2711	 0.00075	 0.00356	 0.0	 8683	 8683	 8683	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 2711	 0.00075	 0.00356	 0.0	 8683	 8683	 8683	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 7654	 0.00321	 0.03286	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 7654	 0.00321	 0.03286	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	7794	 5028	 0.01875	 0.06021	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	7794	 2791	 0.02489	 0.07991	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	9207	 2735	 0.00115	 0.0091	 0.0	 3444	 3444	 3444	 0.0	 0.0	 1	 -30.0	 30.0;
	9207	 1203	 0.00037	 0.00164	 0.0	 18789	 18789	 18789	 0.0	 0.0	 1	 -30.0	 30.0;
	9207	 1958	 0.00082	 0.00881	 0.0	 3570	 3570	 3570	 0.0	 0.0	 1	 -30.0	 30.0;
	9207	 334	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	9207	 7060	 0.00043	 0.00465	 0.0	 6765	 6765	 6765	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 4980	 0.00045	 0.00203	 0.0	 15192	 15192	 15192	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 3226	 0.00028	 0.00304	 0.0	 10347	 10347	 10347	 0.0	 0.0	 1	 -30.0	 30.0;
	1845	 6073	 0.00037	 0.00164	 0.0	 18789	 18789	 18789	 0.0	 0.0	 1	 -30.0	 30.0;
	1845	 9031	 0.00033	 0.00148	 0.0	 20832	 20832	 20832	 0.0	 0.0	 1	 -30.0	 30.0;
	1845	 5118	 0.0002	 0.00216	 0.0	 14562	 14562	 14562	 0.0	 0.0	 1	 -30.0	 30.0;
	1845	 2999	 0.00037	 0.00372	 0.0	 8450	 8450	 8450	 0.0	 0.0	 1	 -30.0	 30.0;
	1694	 5118	 0.00065	 0.00697	 0.0	 4513	 4513	 4513	 0.0	 0.0	 1	 -30.0	 30.0;
	1694	 5415	 0.00015	 0.0016	 0.0	 19656	 19656	 19656	 0.0	 0.0	 1	 -30.0	 30.0;
	2353	 7654	 0.002	 0.00953	 0.0	 3244	 3244	 3244	 0.0	 0.0	 1	 -30.0	 30.0;
	2353	 7654	 0.002	 0.00953	 0.0	 3244	 3244	 3244	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 9031	 0.0006	 0.00268	 0.0	 11502	 11502	 11502	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 8106	 0.00239	 0.01883	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 2999	 0.00117	 0.00926	 0.0	 3385	 3385	 3385	 0.0	 0.0	 1	 -30.0	 30.0;
	2711	 7983	 0.00026	 0.00161	 0.0	 19369	 19369	 19369	 0.0	 0.0	 1	 -30.0	 30.0;
	2711	 7983	 0.00026	 0.00161	 0.0	 19369	 19369	 19369	 0.0	 0.0	 1	 -30.0	 30.0;
	4319	 3058	 0.00061	 0.00291	 0.0	 10624	 10624	 10624	 0.0	 0.0	 1	 -30.0	 30.0;
	4319	 3058	 0.00061	 0.00291	 0.0	 10624	 10624	 10624	 0.0	 0.0	 1	 -30.0	 30.0;
	7689	 2735	 0.00062	 0.00632	 0.0	 4975	 4975	 4975	 0.0	 0.0	 1	 -30.0	 30.0;
	7689	 2735	 0.00062	 0.00632	 0.0	 4975	 4975	 4975	 0.0	 0.0	 1	 -30.0	 30.0;
	7689	 334	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	8106	 2999	 0.00231	 0.0182	 0.0	 1722	 1722	 1722	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 7654	 0.00233	 0.01836	 0.0	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 9085	 0.0043	 0.03389	 0.0	 925	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 2999	 0.00017	 0.00174	 0.0	 18068	 18068	 18068	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 2999	 0.00017	 0.00174	 0.0	 18068	 18068	 18068	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 7677	 0.0005	 0.00537	 0.0	 5857	 5857	 5857	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 1958	 0.006	 0.0286	 0.0	 1081	 1081	 1081	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 409	 0.01187	 0.05656	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 3253	 0.00022	 0.0024	 0.0	 267.0	 13107	 13107	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 5028	 0.01419	 0.04556	 0.0	 662	 662	 662	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 2808	 0.01712	 0.08161	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	8203	 3058	 0.00173	 0.00824	 0.0	 3752	 3752	 3752	 0.0	 0.0	 1	 -30.0	 30.0;
	8203	 3058	 0.00173	 0.00824	 0.0	 3752	 3752	 3752	 0.0	 0.0	 1	 -30.0	 30.0;
	3226	 7654	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	3226	 9085	 0.00716	 0.05648	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	7814	 5367	 0.00915	 0.07217	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	7814	 2999	 0.00793	 0.03781	 0.0	 818	 818	 818	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 2791	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 2999	 0.01796	 0.05768	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 9224	 0.00013	 0.00136	 0.0	 23121	 23121	 23121	 0.0	 0.0	 1	 -30.0	 30.0;
	9071	 3058	 0.00179	 0.01412	 0.0	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	9071	 5073	 0.00338	 0.01085	 0.0	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	1958	 9085	 0.0009	 0.00706	 0.0	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	1958	 9085	 0.0009	 0.00706	 0.0	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	8576	 2514	 0.02308	 0.07413	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	8576	 4429	 0.00669	 0.05272	 0.0	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 4609	 0.02866	 0.09203	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 2666	 0.06565	 0.21081	 0.0	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 1097	 0.03479	 0.11173	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	3501	 2104	 0.03243	 0.10414	 0.0	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 6890	 0.00784	 0.06182	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 5073	 0.02196	 0.07051	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 2215	 0.01323	 0.04249	 0.0	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	7754	 409	 0.00336	 0.016	 0.0	 1933	 1933	 1933	 0.0	 0.0	 1	 -30.0	 30.0;
	7754	 409	 0.00325	 0.01551	 0.0	 1994	 1994	 1994	 0.0	 0.0	 1	 -30.0	 30.0;
	7754	 7447	 0.02303	 0.07395	 0.0	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	7754	 2514	 0.00845	 0.02712	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	409	 7060	 0.00678	 0.03232	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	2215	 7447	 0.0322	 0.10342	 0.0	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	6890	 4429	 0.0002	 0.00157	 0.0	 19959	 19959	 19959	 0.0	 0.0	 1	 -30.0	 30.0;
	4999	 5615	 0.05906	 0.18966	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	4999	 6525	 0.00676	 0.0217	 0.0	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	2666	 5040	 0.02488	 0.19613	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2666	 6525	 0.00676	 0.0217	 0.0	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 926	 0.00094	 0.00956	 0.0	 1316.0	 3289	 3289	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 7728	 0.00025	 0.00258	 0.0	 1351.0	 12187	 12187	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 7728	 0.00082	 0.00843	 0.0	 1247.0	 3730	 3730	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 7498	 0.00156	 0.01988	 0.0	 1585	 1585	 1585	 0.0	 0.0	 1	 -30.0	 30.0;
	7728	 2455	 0.00146	 0.01855	 0.0	 1698	 1698	 1698	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 4972	 0.02449	 0.07865	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 5411	 0.01055	 0.08316	 0.0	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	4106	 8824	 0.02753	 0.08841	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	4106	 1442	 0.02393	 0.07684	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	4524	 325	 0.01566	 0.07466	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	2808	 2791	 0.00519	 0.04095	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	2808	 4266	 0.02286	 0.0734	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	2808	 1982	 0.02226	 0.08078	 0.0	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	5613	 325	 0.01817	 0.08662	 0.0	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	5613	 1800	 0.01576	 0.07514	 0.0	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	8008	 8824	 0.02697	 0.0866	 0.0	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	8008	 1213	 0.00929	 0.02983	 0.0	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	8008	 4972	 0.03508	 0.11264	 0.0	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	8008	 6945	 0.01405	 0.11077	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	8824	 6979	 0.03479	 0.11173	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	3096	 1474	 0.01937	 0.06219	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	3096	 1348	 0.03778	 0.12132	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	3096	 1440	 0.00497	 0.03923	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 1042	 0.01864	 0.08888	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 1042	 0.01864	 0.08888	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	1213	 1442	 0.01774	 0.05695	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	1213	 5411	 0.00292	 0.02306	 0.0	 1359	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 1691	 0.004	 0.01284	 0.0	 2349	 2349	 2349	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 1529	 0.00985	 0.03164	 0.0	 954	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 5411	 0.00336	 0.02652	 0.0	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 5411	 0.00336	 0.02652	 0.0	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	1691	 3694	 0.02179	 0.07184	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 1440	 0.00697	 0.05491	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 6920	 0.01119	 0.05333	 0.0	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 6920	 0.01119	 0.05333	 0.0	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 41	 0.04645	 0.14916	 0.0	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 755	 0.00402	 0.04114	 0.0	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 5536	 0.00279	 0.02851	 0.0	 1103	 1103	 1103	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 2182	 0.02688	 0.12815	 0.0	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	1097	 4266	 0.03125	 0.10034	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	1097	 1529	 0.00619	 0.01989	 0.0	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 1348	 0.02466	 0.07919	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 8254	 0.00563	 0.01808	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 1800	 0.00693	 0.02224	 0.0	 1356	 1356	 1356	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 1800	 0.00693	 0.02224	 0.0	 1356	 1356	 1356	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 4972	 0.02567	 0.08245	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 6821	 0.02944	 0.09456	 0.0	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	755	 5536	 0.0025	 0.02552	 0.0	 1232	 1232	 1232	 0.0	 0.0	 1	 -30.0	 30.0;
	1042	 1348	 0.00584	 0.05974	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	1042	 2182	 0.00956	 0.09776	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	1042	 5204	 0.00563	 0.01808	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	325	 2182	 0.01044	 0.04977	 0.0	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	325	 1800	 0.00495	 0.03907	 0.0	 803	 803	 803	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 2182	 0.00545	 0.04299	 0.0	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	4266	 8254	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	2182	 1800	 0.01603	 0.07644	 0.0	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	2182	 3694	 0.03924	 0.12602	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	2182	 1982	 0.01798	 0.06704	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	7498	 8248	 0.0	 -0.0207	 0.0	 831.0	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	6181	 2436	 0.00149	 0.01526	 0.0	 1282.0	 2061	 2061	 0.0	 0.0	 1	 -30.0	 30.0;
	6181	 2436	 0.00099	 0.01264	 0.0	 1905.0	 2492	 2492	 0.0	 0.0	 1	 -30.0	 30.0;
	6181	 1925	 0.00168	 0.01713	 0.0	 1247.0	 1836	 1836	 0.0	 0.0	 1	 -30.0	 30.0;
	6181	 3292	 0.00131	 0.01663	 0.0	 1894	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	2436	 1925	 0.00131	 0.01663	 0.0	 1524.0	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	2436	 8248	 0.00222	 0.02826	 0.0	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	1336	 8135	 0.01284	 0.04122	 0.0	 732	 732	 732	 0.0	 0.0	 1	 -30.0	 30.0;
	1336	 5904	 0.00563	 0.01808	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	8063	 7179	 0.01094	 0.0863	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	8063	 1292	 0.0061	 0.02909	 0.0	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	8063	 605	 0.00537	 0.04236	 0.0	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	8911	 1589	 0.01255	 0.04032	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	8911	 6821	 0.01092	 0.03508	 0.0	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	8911	 5105	 0.01689	 0.05424	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	8911	 8053	 0.00011	 0.00036	 0.0	 83913	 83913	 83913	 0.0	 0.0	 1	 -30.0	 30.0;
	8365	 8177	 0.02393	 0.07684	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	8365	 8177	 0.00856	 0.06747	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	8365	 8177	 0.00856	 0.06747	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	8365	 1589	 0.00602	 0.01935	 0.0	 1559	 1559	 1559	 0.0	 0.0	 1	 -30.0	 30.0;
	8365	 6821	 0.0058	 0.02763	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	8365	 6821	 0.0058	 0.02763	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	8177	 8682	 0.02978	 0.09564	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	8177	 8682	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	8177	 8682	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	8135	 5851	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	8135	 2623	 0.00398	 0.03138	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	8135	 8150	 0.00458	 0.03609	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	7213	 1589	 0.00298	 0.00958	 0.0	 3149	 3149	 3149	 0.0	 0.0	 1	 -30.0	 30.0;
	8682	 41	 0.03001	 0.09637	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	6950	 1292	 0.00983	 0.04686	 0.0	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	6950	 1292	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 6821	 0.00462	 0.01483	 0.0	 2034	 2034	 2034	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 1208	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 1208	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 5851	 0.01239	 0.03978	 0.0	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 5851	 0.00749	 0.03571	 0.0	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 5851	 0.00749	 0.03571	 0.0	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 605	 0.00478	 0.03766	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 8150	 0.0038	 0.02997	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 347	 0.00394	 0.01266	 0.0	 2383	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 1292	 0.0199	 0.1569	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 7769	 0.00677	 0.05335	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	6821	 5904	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	6821	 5904	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	5904	 2623	 0.00458	 0.03609	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 7985	 0.00133	 0.01349	 0.0	 1143.0	 2331	 2331	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 6518	 0.00047	 0.00772	 0.0	 1143.0	 4085	 4085	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 4097	 0.00698	 0.07071	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	7985	 6518	 0.00048	 0.00615	 0.0	 1940.0	 5121	 5121	 0.0	 0.0	 1	 -30.0	 30.0;
	7985	 5921	 0.00048	 0.00615	 0.0	 1871.0	 5121	 5121	 0.0	 0.0	 1	 -30.0	 30.0;
	7985	 7026	 0.0014	 0.01429	 0.0	 1109.0	 2200	 2200	 0.0	 0.0	 1	 -30.0	 30.0;
	7985	 2874	 0.00156	 0.01982	 0.0	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	3317	 6587	 0.02032	 0.06527	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	3317	 6507	 0.04842	 0.15549	 0.0	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	3317	 3982	 0.00957	 0.03074	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	3317	 5090	 0.00729	 0.03474	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	6782	 6507	 0.0198	 0.15612	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	6782	 4278	 0.07263	 0.23323	 0.0	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	6782	 3612	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	6782	 3612	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	7173	 1088	 0.00902	 0.04299	 0.0	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	7173	 1088	 0.00902	 0.04299	 0.0	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	7173	 2243	 0.00203	 0.0097	 0.0	 3188	 3188	 3188	 0.0	 0.0	 1	 -30.0	 30.0;
	1088	 4514	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	1088	 6966	 0.01149	 0.05478	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	774	 1640	 0.01396	 0.04484	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	774	 1640	 0.01396	 0.04484	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 1938	 0.00712	 0.03394	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 1938	 0.00712	 0.03394	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 1640	 0.02421	 0.07774	 0.0	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 7370	 0.02083	 0.0669	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 9151	 0.02034	 0.09696	 0.0	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 302	 0.01526	 0.07272	 0.0	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 6623	 0.02949	 0.14059	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 2810	 0.01095	 0.0522	 0.0	 593	 593	 593	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 2810	 0.01095	 0.0522	 0.0	 593	 593	 593	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 7567	 0.01763	 0.08403	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 5602	 0.00814	 0.03878	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	7350	 7379	 0.01898	 0.0905	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	7350	 7379	 0.01898	 0.0905	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 8226	 0.00394	 0.01266	 0.0	 2383	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 6623	 0.00576	 0.02747	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 8202	 0.01436	 0.0461	 0.0	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 5375	 0.02534	 0.08136	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	8226	 7614	 0.02646	 0.08498	 0.0	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	8226	 6623	 0.0059	 0.02812	 0.0	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	8226	 1640	 0.02984	 0.09582	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	8226	 5722	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	8226	 5602	 0.01729	 0.08242	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 4552	 0.00569	 0.02715	 0.0	 1139	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 7623	 0.01543	 0.07353	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 7623	 0.01543	 0.07353	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 6623	 0.00529	 0.02521	 0.0	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 6623	 0.00529	 0.02521	 0.0	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 7481	 0.00024	 0.00113	 0.0	 27344	 27344	 27344	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 7481	 0.00024	 0.00113	 0.0	 27344	 27344	 27344	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 6473	 0.00959	 0.04573	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 8896	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 8790	 0.01689	 0.05424	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	7140	 6507	 0.03125	 0.10034	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	7140	 3982	 0.0078	 0.03717	 0.0	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	7140	 3982	 0.0078	 0.03717	 0.0	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	7140	 7223	 0.00678	 0.03232	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	7140	 7223	 0.00678	 0.03232	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	7140	 5090	 0.01295	 0.06173	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 6966	 0.012	 0.05721	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 6966	 0.012	 0.05721	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 1640	 0.00332	 0.01584	 0.0	 1952	 1952	 1952	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 1640	 0.00332	 0.01584	 0.0	 1952	 1952	 1952	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 8083	 0.00986	 0.04703	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 8083	 0.00986	 0.04703	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	2881	 8083	 0.0002	 0.00204	 0.0	 15411	 15411	 15411	 0.0	 0.0	 1	 -30.0	 30.0;
	2881	 8083	 0.0002	 0.00204	 0.0	 15411	 15411	 15411	 0.0	 0.0	 1	 -30.0	 30.0;
	9151	 4552	 0.02081	 0.09922	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	9151	 4552	 0.02081	 0.09922	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	9151	 8083	 0.01672	 0.0537	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	9151	 8202	 0.01171	 0.03761	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	9151	 7567	 0.00407	 0.01939	 0.0	 1595	 1595	 1595	 0.0	 0.0	 1	 -30.0	 30.0;
	4552	 6473	 0.00959	 0.04573	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	4552	 2450	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	4514	 8083	 0.00296	 0.02338	 0.0	 1341	 1341	 1341	 0.0	 0.0	 1	 -30.0	 30.0;
	6966	 6618	 0.01366	 0.06513	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	6966	 8083	 0.00093	 0.0095	 0.0	 3310	 3310	 3310	 0.0	 0.0	 1	 -30.0	 30.0;
	6966	 1404	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	6618	 2243	 0.01786	 0.08516	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	3426	 6587	 0.0045	 0.01446	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	3426	 2082	 0.0116	 0.03725	 0.0	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	3426	 6462	 0.02629	 0.08443	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	6587	 2082	 0.00709	 0.02278	 0.0	 1324	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	302	 7614	 0.01051	 0.0501	 0.0	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	7623	 7788	 0.02353	 0.07557	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	7623	 5722	 0.00799	 0.02567	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	7623	 2082	 0.02168	 0.06961	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	7623	 6142	 0.00608	 0.01953	 0.0	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	7623	 534	 0.00169	 0.00808	 0.0	 3827	 3827	 3827	 0.0	 0.0	 1	 -30.0	 30.0;
	7623	 534	 0.00169	 0.00808	 0.0	 3827	 3827	 3827	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 2082	 0.15283	 0.86416	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 1935	 0.0045	 0.01446	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 6086	 0.00336	 0.016	 0.0	 1933	 1933	 1933	 0.0	 0.0	 1	 -30.0	 30.0;
	7379	 2082	 0.00125	 0.00989	 0.0	 3169	 3169	 3169	 0.0	 0.0	 1	 -30.0	 30.0;
	7379	 5294	 0.00153	 0.01208	 0.0	 2595	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	7379	 534	 0.01265	 0.06028	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	7379	 534	 0.01265	 0.06028	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	7379	 5090	 0.00576	 0.02747	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	7379	 5090	 0.00576	 0.02747	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	1640	 4452	 0.00056	 0.00181	 0.0	 16672	 16672	 16672	 0.0	 0.0	 1	 -30.0	 30.0;
	8083	 1349	 0.00225	 0.00723	 0.0	 4172	 4172	 4172	 0.0	 0.0	 1	 -30.0	 30.0;
	8083	 3230	 0.0006	 0.00471	 0.0	 6653	 6653	 6653	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 6142	 0.01413	 0.04538	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 5375	 0.00338	 0.01085	 0.0	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 5889	 0.01065	 0.05074	 0.0	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 5889	 0.01065	 0.05074	 0.0	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 5998	 0.00506	 0.03985	 0.0	 307.0	 787	 787	 0.0	 0.0	 1	 -30.0	 30.0;
	2082	 6142	 0.01368	 0.04393	 0.0	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	6507	 896	 0.00034	 0.00108	 0.0	 27898	 27898	 27898	 0.0	 0.0	 1	 -30.0	 30.0;
	6507	 4278	 0.05067	 0.16272	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	6462	 2490	 0.03125	 0.10034	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 1935	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	8202	 6473	 0.01293	 0.10199	 0.0	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	8202	 6473	 0.01293	 0.10199	 0.0	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	8202	 2499	 0.00106	 0.01086	 0.0	 2895	 2895	 2895	 0.0	 0.0	 1	 -30.0	 30.0;
	8202	 2499	 0.00106	 0.01086	 0.0	 2895	 2895	 2895	 0.0	 0.0	 1	 -30.0	 30.0;
	6142	 4198	 0.00139	 0.01098	 0.0	 2855	 2855	 2855	 0.0	 0.0	 1	 -30.0	 30.0;
	6142	 4198	 0.00139	 0.01098	 0.0	 2855	 2855	 2855	 0.0	 0.0	 1	 -30.0	 30.0;
	6518	 1929	 0.0017	 0.02161	 0.0	 1458	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	2243	 9069	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	2243	 9069	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 5090	 0.00695	 0.03313	 0.0	 934	 934	 934	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 5090	 0.00746	 0.03555	 0.0	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 6086	 0.00929	 0.04428	 0.0	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 5921	 0.00084	 0.01064	 0.0	 1801.0	 2960	 2960	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 2874	 0.00274	 0.03491	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	1738	 4920	 0.00153	 0.01547	 0.0	 1282.0	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 2151	 0.00328	 0.03317	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 7658	 0.00137	 0.01387	 0.0	 1143.0	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	2151	 4920	 0.00066	 0.00666	 0.0	 1005.0	 4720	 4720	 0.0	 0.0	 1	 -30.0	 30.0;
	2151	 8679	 0.0053	 0.05369	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	2151	 5243	 0.0053	 0.05369	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 4305	 0.00025	 0.00417	 0.0	 797.0	 7562	 7562	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 2325	 0.00037	 0.00465	 0.0	 1940.0	 6772	 6772	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 6050	 0.00347	 0.04417	 0.0	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 4237	 0.00347	 0.04417	 0.0	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	4305	 7157	 0.0017	 0.02819	 0.0	 866.0	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	4305	 2165	 0.0017	 0.02819	 0.0	 866.0	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	8434	 2065	 0.00049	 0.00496	 0.0	 6338	 6338	 6338	 0.0	 0.0	 1	 -30.0	 30.0;
	8434	 3269	 0.00139	 0.01098	 0.0	 2855	 2855	 2855	 0.0	 0.0	 1	 -30.0	 30.0;
	8434	 2521	 0.00031	 0.00329	 0.0	 9559	 9559	 9559	 0.0	 0.0	 1	 -30.0	 30.0;
	8434	 2137	 0.00424	 0.0202	 0.0	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	8434	 2137	 0.00424	 0.0202	 0.0	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	8434	 3564	 0.01197	 0.05705	 0.0	 293.0	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	8434	 5321	 0.00052	 0.00561	 0.0	 5607	 5607	 5607	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 3269	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 3269	 0.00139	 0.01098	 0.0	 2855	 2855	 2855	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 6044	 0.00255	 0.02008	 0.0	 1561	 1561	 1561	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 6044	 0.00777	 0.02495	 0.0	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 6044	 0.00255	 0.02008	 0.0	 1561	 1561	 1561	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 6044	 0.00777	 0.02495	 0.0	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	2065	 3269	 0.00475	 0.02262	 0.0	 1367	 1367	 1367	 0.0	 0.0	 1	 -30.0	 30.0;
	2065	 5708	 0.00031	 0.00329	 0.0	 9559	 9559	 9559	 0.0	 0.0	 1	 -30.0	 30.0;
	2065	 3564	 0.0101	 0.04816	 0.0	 307.0	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	2768	 2137	 0.00929	 0.04428	 0.0	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	2768	 9102	 0.01119	 0.05333	 0.0	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 4626	 0.00468	 0.03687	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 8695	 0.00225	 0.00723	 0.0	 4172	 4172	 4172	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 8766	 0.05517	 0.17718	 0.0	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	8817	 9	 0.01616	 0.05189	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	8817	 3564	 0.03603	 0.11571	 0.0	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	8909	 2483	 0.00263	 0.02071	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	8909	 3164	 0.00508	 0.02424	 0.0	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 2287	 0.00545	 0.04299	 0.0	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	8995	 2483	 0.01505	 0.07175	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	8995	 2483	 0.01505	 0.07175	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	7645	 1235	 0.01431	 0.0682	 0.0	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	7645	 2324	 0.00267	 0.02103	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	7645	 2324	 0.00267	 0.02103	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	2325	 5478	 0.00346	 0.04406	 0.0	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	2483	 3164	 0.00332	 0.0262	 0.0	 1197	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	2483	 5603	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	2483	 4530	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 6403	 0.00079	 0.00253	 0.0	 11918	 11918	 11918	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 7746	 0.00451	 0.02149	 0.0	 1439	 1439	 1439	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 7302	 0.01458	 0.06949	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	1235	 7746	 0.02044	 0.06563	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	1235	 824	 0.03316	 0.10649	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	7746	 9102	 0.00441	 0.02101	 0.0	 1472	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	7746	 9102	 0.00441	 0.02101	 0.0	 1472	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	7746	 6289	 0.02373	 0.11312	 0.0	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 5422	 0.00251	 0.01977	 0.0	 1586	 1586	 1586	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 2324	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 5604	 0.00607	 0.02893	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 5321	 0.0003	 0.0032	 0.0	 9828	 9828	 9828	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 2324	 0.00106	 0.00832	 0.0	 3767	 3767	 3767	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 4749	 0.00762	 0.06009	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 8047	 0.00524	 0.03214	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 8047	 0.00524	 0.03214	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 3766	 0.00068	 0.00323	 0.0	 9570	 9570	 9570	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 3564	 0.00526	 0.02505	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 3564	 0.00526	 0.02505	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 4749	 0.00345	 0.0353	 0.0	 280.0	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 4749	 0.00345	 0.0353	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 6488	 0.00122	 0.01306	 0.0	 2409	 2409	 2409	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 6488	 0.00122	 0.01306	 0.0	 2409	 2409	 2409	 0.0	 0.0	 1	 -30.0	 30.0;
	8047	 2324	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	5603	 4530	 0.00677	 0.05335	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	2324	 6840	 0.00239	 0.01883	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	2324	 70	 0.00239	 0.01883	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	8695	 9096	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	9102	 5604	 0.00763	 0.03636	 0.0	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	6840	 5321	 0.00022	 0.0024	 0.0	 280.0	 13107	 13107	 0.0	 0.0	 1	 -30.0	 30.0;
	70	 5321	 0.00022	 0.0024	 0.0	 280.0	 13107	 13107	 0.0	 0.0	 1	 -30.0	 30.0;
	3220	 1152	 0.00282	 0.03584	 0.0	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	3220	 7928	 0.0	 -0.0228	 0.0	 1143.0	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	5478	 7928	 0.0	 -0.0228	 0.0	 1039.0	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 7928	 0.0	 -0.0228	 0.0	 866.0	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 4519	 0.00219	 0.02793	 0.0	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	7928	 8227	 0.00198	 0.02025	 0.0	 1455.0	 1553	 1553	 0.0	 0.0	 1	 -30.0	 30.0;
	7928	 6124	 0.00248	 0.02534	 0.0	 1241	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 434	 0.02365	 0.07594	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 5756	 0.0532	 0.17086	 0.0	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	8491	 8039	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	8491	 6325	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 8733	 0.02624	 0.08425	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 7134	 0.00951	 0.03056	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 16	 0.01802	 0.05786	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	9087	 8259	 0.00845	 0.02712	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	9087	 623	 0.02736	 0.08787	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 6467	 0.01393	 0.10983	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 4071	 0.0131	 0.08035	 0.0	 267.0	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 6700	 0.01847	 0.0593	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	824	 6400	 0.06942	 0.22293	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	824	 8543	 0.0183	 0.05876	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	824	 2405	 0.04065	 0.13054	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 8039	 0.01098	 0.03526	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 8259	 0.03665	 0.1177	 0.0	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 623	 0.03001	 0.09637	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 3625	 0.00478	 0.03766	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 3625	 0.00478	 0.03766	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	8039	 8259	 0.01592	 0.12552	 0.0	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	8733	 5810	 0.04189	 0.13452	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	8259	 3708	 0.02049	 0.06581	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	7134	 203	 0.06227	 0.19997	 0.0	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	8543	 152	 0.03806	 0.12222	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	8543	 2049	 0.01393	 0.10983	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 434	 0.01671	 0.07967	 0.0	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 3379	 0.02712	 0.12928	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 4358	 0.03361	 0.10794	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	6467	 6325	 0.01204	 0.05737	 0.0	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 3708	 0.02522	 0.081	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 5756	 0.00591	 0.01898	 0.0	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 4199	 0.04375	 0.14048	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 7244	 0.01171	 0.03761	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 6087	 0.03389	 0.10884	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	7244	 6325	 0.01019	 0.03272	 0.0	 922	 922	 922	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 2141	 0.0131	 0.08035	 0.0	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 7157	 0.0	 -0.03116	 0.0	 866.0	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 9022	 0.00123	 0.02042	 0.0	 1005.0	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	8945	 2165	 0.0	 -0.03116	 0.0	 866.0	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	8945	 9022	 0.00123	 0.02042	 0.0	 901.0	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	323	 6740	 0.0	 -0.0228	 0.0	 901.0	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	323	 6050	 0.0	 -0.0228	 0.0	 1212.0	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 4237	 0.0	 -0.023	 0.0	 935.0	 1374	 1374	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 6781	 0.0	 -0.023	 0.0	 935.0	 1374	 1374	 0.0	 0.0	 1	 -30.0	 30.0;
	6740	 715	 0.00262	 0.03338	 0.0	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	6781	 5432	 0.00266	 0.03382	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	8679	 634	 0.0	 -0.0242	 0.0	 797.0	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 634	 0.0	 -0.0242	 0.0	 797.0	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	634	 715	 0.00287	 0.02938	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	634	 6008	 0.00544	 0.05508	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	634	 6008	 0.00544	 0.05508	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	9022	 968	 0.00139	 0.02301	 0.0	 935.0	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	9022	 5079	 0.00139	 0.02301	 0.0	 935.0	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	9022	 3064	 0.00099	 0.01644	 0.0	 866.0	 1918	 1918	 0.0	 0.0	 1	 -30.0	 30.0;
	9022	 7083	 0.00294	 0.03741	 0.0	 842	 842	 842	 0.0	 0.0	 1	 -30.0	 30.0;
	6551	 2141	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	6551	 6700	 0.0174	 0.05587	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	6551	 4358	 0.02509	 0.11958	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	6551	 6535	 0.00902	 0.04299	 0.0	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	6551	 6535	 0.00902	 0.04299	 0.0	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	6551	 2547	 0.04087	 0.13126	 0.0	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	6551	 7184	 0.02196	 0.07051	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	2490	 7581	 0.01582	 0.0508	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	2490	 668	 0.04712	 0.15133	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 160	 0.02055	 0.06599	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 6476	 0.00339	 0.01616	 0.0	 1914	 1914	 1914	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 6476	 0.00339	 0.01616	 0.0	 1914	 1914	 1914	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 3283	 0.01098	 0.03526	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 6087	 0.03271	 0.10504	 0.0	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 3980	 0.02145	 0.06888	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 7302	 0.00644	 0.0307	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 6289	 0.00644	 0.0307	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 1621	 0.03029	 0.09727	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 160	 0.00255	 0.02008	 0.0	 1561	 1561	 1561	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 160	 0.00434	 0.02069	 0.0	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 160	 0.00434	 0.02069	 0.0	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	2952	 160	 0.01633	 0.05243	 0.0	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 6476	 0.00729	 0.03474	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 6476	 0.00729	 0.03474	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	6476	 1371	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	6476	 1371	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	8297	 7302	 0.00085	 0.00404	 0.0	 7652	 7652	 7652	 0.0	 0.0	 1	 -30.0	 30.0;
	8297	 6289	 0.00085	 0.00404	 0.0	 7652	 7652	 7652	 0.0	 0.0	 1	 -30.0	 30.0;
	6087	 2547	 0.00501	 0.01609	 0.0	 1875	 1875	 1875	 0.0	 0.0	 1	 -30.0	 30.0;
	820	 7581	 0.02015	 0.06473	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	820	 7184	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	7581	 5287	 0.00935	 0.07374	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 3283	 0.01042	 0.03345	 0.0	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 5287	 0.01478	 0.07046	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	3980	 668	 0.04572	 0.14681	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 7949	 0.01029	 0.08112	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 7949	 0.01029	 0.08112	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 7184	 0.00836	 0.0659	 0.0	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 1925	 0.0	 -0.0207	 0.0	 831.0	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 1515	 0.00193	 0.01978	 0.0	 1178.0	 1590	 1590	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 5934	 0.00224	 0.02269	 0.0	 1282.0	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	7769	 8523	 0.01071	 0.08441	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 2070	 0.02733	 0.09705	 0.0	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 1621	 0.03029	 0.09727	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	8996	 8937	 0.02308	 0.07413	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	8996	 2070	 0.02305	 0.08331	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	4812	 1130	 0.03288	 0.10559	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4812	 50	 0.0077	 0.04725	 0.0	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	4812	 7749	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	4812	 4611	 0.00648	 0.02079	 0.0	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	4278	 6578	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	4278	 6868	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 5788	 0.00816	 0.02622	 0.0	 1151	 1151	 1151	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 6578	 0.00959	 0.07563	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 5838	 0.01017	 0.04848	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 2640	 0.01786	 0.08516	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	3439	 50	 0.01926	 0.11812	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 863	 0.00239	 0.01883	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 863	 0.00239	 0.01883	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 8523	 0.04076	 0.1309	 0.0	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 50	 0.00814	 0.06417	 0.0	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	863	 8937	 0.00776	 0.06119	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	8937	 50	 0.00665	 0.04082	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	8937	 50	 0.00665	 0.04082	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	2640	 5788	 0.04943	 0.15874	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	8523	 5244	 0.02196	 0.07051	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	8523	 4611	 0.04155	 0.13343	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 7083	 0.0	 -0.01731	 0.0	 866.0	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	50	 4459	 0.01127	 0.0691	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 6931	 0.04279	 0.13741	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 4611	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 5040	 0.00108	 0.00847	 0.0	 3700	 3700	 3700	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 2477	 0.05089	 0.16344	 0.0	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 3803	 0.05315	 0.17067	 0.0	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 6979	 0.00995	 0.07845	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	6931	 3803	 0.03406	 0.10938	 0.0	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	6931	 9138	 0.00966	 0.04606	 0.0	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	6931	 7634	 0.03429	 0.11011	 0.0	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	2477	 5599	 0.01858	 0.05966	 0.0	 506	 506	 506	 0.0	 0.0	 1	 -30.0	 30.0;
	2477	 6617	 0.00466	 0.03672	 0.0	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 57	 0.01485	 0.07078	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 3091	 0.01509	 0.04845	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 1433	 0.01824	 0.05858	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 5105	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	57	 8075	 0.00432	 0.03405	 0.0	 921	 921	 921	 0.0	 0.0	 1	 -30.0	 30.0;
	57	 6945	 0.01183	 0.0564	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	3803	 8766	 0.03367	 0.10812	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3803	 6979	 0.04712	 0.15133	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 1433	 0.0165	 0.05297	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 6414	 0.02204	 0.10504	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	8075	 6617	 0.00219	 0.01726	 0.0	 1816	 1816	 1816	 0.0	 0.0	 1	 -30.0	 30.0;
	8075	 1191	 0.00225	 0.00723	 0.0	 4172	 4172	 4172	 0.0	 0.0	 1	 -30.0	 30.0;
	3091	 5864	 0.00715	 0.02296	 0.0	 1314	 1314	 1314	 0.0	 0.0	 1	 -30.0	 30.0;
	6617	 6979	 0.01791	 0.14121	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	9138	 6414	 0.01356	 0.06464	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	6401	 2718	 0.01768	 0.05677	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	6401	 7570	 0.0103	 0.03309	 0.0	 912	 912	 912	 0.0	 0.0	 1	 -30.0	 30.0;
	8227	 6124	 0.00124	 0.01579	 0.0	 1871.0	 1995	 1995	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 3304	 0.00037	 0.00374	 0.0	 1247.0	 8405	 8405	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 3304	 0.00037	 0.00374	 0.0	 1247.0	 8405	 8405	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 3475	 0.00207	 0.03419	 0.0	 797.0	 923	 923	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 2718	 0.00946	 0.04509	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 3959	 0.00576	 0.02747	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	2090	 7094	 0.02387	 0.07666	 0.0	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	2090	 5187	 0.04842	 0.15549	 0.0	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	2718	 3959	 0.00508	 0.02424	 0.0	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	2718	 7094	 0.05444	 0.17483	 0.0	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 8262	 0.0326	 0.10468	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 3638	 0.02269	 0.07286	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	7850	 2524	 0.01831	 0.08726	 0.0	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	7850	 4386	 0.04183	 0.13433	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 5277	 0.00513	 0.04048	 0.0	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 524	 0.00169	 0.00542	 0.0	 5564	 5564	 5564	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 7355	 0.00541	 0.04268	 0.0	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 2485	 0.00396	 0.03122	 0.0	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 114	 0.02288	 0.10908	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 5449	 0.02881	 0.13736	 0.0	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	8136	 2049	 0.03941	 0.12656	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	8136	 3638	 0.01396	 0.04484	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	8262	 3424	 0.03969	 0.12746	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	2	 2447	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	2	 4898	 0.00051	 0.00242	 0.0	 12773	 12773	 12773	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 4347	 0.02145	 0.06888	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 1024	 0.00518	 0.01663	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 2447	 0.00085	 0.00404	 0.0	 7652	 7652	 7652	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 4898	 0.00052	 0.00246	 0.0	 12563	 12563	 12563	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 8350	 0.00555	 0.04377	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	2265	 152	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	2265	 8518	 0.0165	 0.05297	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	152	 8384	 0.02398	 0.07702	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	8384	 2049	 0.00822	 0.0264	 0.0	 1143	 1143	 1143	 0.0	 0.0	 1	 -30.0	 30.0;
	7906	 623	 0.04954	 0.1591	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	7906	 2405	 0.0237	 0.07612	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 2524	 0.02117	 0.06798	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 2405	 0.02809	 0.09022	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 6553	 0.01126	 0.03616	 0.0	 835	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	3424	 6553	 0.01278	 0.04104	 0.0	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	3424	 5187	 0.0036	 0.01157	 0.0	 2607	 2607	 2607	 0.0	 0.0	 1	 -30.0	 30.0;
	8133	 623	 0.02871	 0.09221	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	8133	 7570	 0.03384	 0.10866	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	623	 7570	 0.04971	 0.15965	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	623	 4386	 0.01576	 0.05062	 0.0	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	7570	 5277	 0.00306	 0.02416	 0.0	 1298	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	7570	 7355	 0.00346	 0.0273	 0.0	 1148	 1148	 1148	 0.0	 0.0	 1	 -30.0	 30.0;
	7570	 2485	 0.00522	 0.02489	 0.0	 1243	 1243	 1243	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 7355	 0.00048	 0.00226	 0.0	 13672	 13672	 13672	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 8326	 0.00048	 0.00226	 0.0	 13672	 13672	 13672	 0.0	 0.0	 1	 -30.0	 30.0;
	3638	 4347	 0.00766	 0.02459	 0.0	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	3638	 8350	 0.00557	 0.04393	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	8326	 2485	 0.00237	 0.01131	 0.0	 2734	 2734	 2734	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 6893	 0.00258	 0.04274	 0.0	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	85	 1906	 0.00861	 0.04105	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	85	 847	 0.01719	 0.08193	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	85	 847	 0.01719	 0.08193	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	85	 4377	 0.01305	 0.06222	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 3323	 0.01326	 0.06319	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 3799	 0.03288	 0.15675	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 7908	 0.0059	 0.02812	 0.0	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 9074	 0.01898	 0.0905	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	9123	 5399	 0.02173	 0.06979	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	9123	 7217	 0.01007	 0.07939	 0.0	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	9123	 5701	 0.04673	 0.15006	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	9123	 5023	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 847	 0.02168	 0.06961	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	1906	 3323	 0.01261	 0.06011	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	3800	 3799	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 3217	 0.01647	 0.07854	 0.0	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 3217	 0.0264	 0.08479	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 3799	 0.01441	 0.06868	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 3799	 0.02393	 0.07684	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	1573	 3217	 0.01407	 0.06706	 0.0	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	1573	 7995	 0.00508	 0.02424	 0.0	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	847	 1846	 0.00557	 0.04393	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	847	 1846	 0.00557	 0.04393	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	847	 553	 0.00393	 0.0241	 0.0	 1294	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	3323	 4377	 0.00783	 0.03733	 0.0	 829	 829	 829	 0.0	 0.0	 1	 -30.0	 30.0;
	3323	 7908	 0.01824	 0.08694	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 3799	 0.00951	 0.075	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 2452	 0.00438	 0.03452	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	655	 4882	 0.02314	 0.07431	 0.0	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	655	 2255	 0.0199	 0.1569	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	655	 9089	 0.00818	 0.06449	 0.0	 486	 486	 486	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 3799	 0.03085	 0.14706	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 114	 0.01814	 0.08646	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 5449	 0.01187	 0.05656	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 7995	 0.01356	 0.06464	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	4377	 4001	 0.05844	 0.18767	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 2452	 0.01075	 0.08473	 0.0	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 7908	 0.04729	 0.15187	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 9074	 0.01458	 0.06949	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 9089	 0.00774	 0.06103	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	2452	 7908	 0.01094	 0.0863	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	2452	 7908	 0.01094	 0.0863	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	6893	 2181	 0.00033	 0.00416	 0.0	 1801.0	 7570	 7570	 0.0	 0.0	 1	 -30.0	 30.0;
	1846	 7217	 0.00318	 0.0251	 0.0	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	1846	 4264	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	7217	 5023	 0.00597	 0.04707	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	7217	 4264	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	7128	 4225	 0.00238	 0.03034	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	7128	 6085	 0.00264	 0.03358	 0.0	 938	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	7128	 2181	 0.00228	 0.02909	 0.0	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	6951	 2765	 0.05152	 0.16543	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	6951	 4722	 0.01719	 0.13556	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	6951	 2396	 0.02074	 0.16349	 0.0	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 7206	 0.04358	 0.13994	 0.0	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 4001	 0.03136	 0.10071	 0.0	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 5667	 0.00782	 0.06166	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 8323	 0.01807	 0.05804	 0.0	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 1157	 0.00022	 0.00072	 0.0	 41957	 41957	 41957	 0.0	 0.0	 1	 -30.0	 30.0;
	4001	 5338	 0.03158	 0.10143	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	7206	 2255	 0.02477	 0.07955	 0.0	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 5689	 0.02314	 0.07431	 0.0	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	3287	 3521	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	3287	 5338	 0.02902	 0.13833	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	3287	 3055	 0.0241	 0.07738	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	3287	 203	 0.07702	 0.24733	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	6980	 5264	 0.00619	 0.01989	 0.0	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	2599	 5667	 0.00448	 0.02748	 0.0	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	2599	 5667	 0.00448	 0.02748	 0.0	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	2599	 412	 0.02929	 0.13962	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	2599	 4722	 0.01572	 0.12395	 0.0	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	2599	 4608	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 637	 0.00629	 0.04958	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	3521	 3458	 0.03491	 0.1121	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 2826	 0.01593	 0.07595	 0.0	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 2255	 0.05405	 0.17357	 0.0	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 4608	 0.01174	 0.09257	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 2255	 0.03254	 0.19959	 0.0	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 203	 0.00659	 0.02115	 0.0	 1426	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 203	 0.00659	 0.02115	 0.0	 1426	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 8323	 0.03356	 0.10776	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 168	 0.03277	 0.10523	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	3458	 203	 0.03783	 0.1215	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	203	 5349	 0.0181	 0.08629	 0.0	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 7642	 0.00235	 0.02992	 0.0	 1053	 1053	 1053	 0.0	 0.0	 1	 -30.0	 30.0;
	7026	 5432	 0.00211	 0.02153	 0.0	 1039.0	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 5432	 0.00232	 0.02949	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 7780	 0.00179	 0.02959	 0.0	 970.0	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 7434	 0.00179	 0.02959	 0.0	 1005.0	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 2874	 0.00134	 0.01702	 0.0	 1851	 1851	 1851	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 4469	 0.00084	 0.01064	 0.0	 2044.0	 2960	 2960	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 5098	 0.00124	 0.01268	 0.0	 866.0	 2480	 2480	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 3194	 0.00106	 0.01347	 0.0	 1732.0	 2338	 2338	 0.0	 0.0	 1	 -30.0	 30.0;
	715	 5432	 0.00023	 0.00231	 0.0	 1282.0	 13607	 13607	 0.0	 0.0	 1	 -30.0	 30.0;
	715	 6008	 0.00335	 0.03421	 0.0	 919	 919	 919	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 4613	 0.00024	 0.00241	 0.0	 1247.0	 13043	 13043	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 4613	 0.00024	 0.00241	 0.0	 1247.0	 13043	 13043	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 4613	 0.00024	 0.00241	 0.0	 1247.0	 13043	 13043	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 4613	 0.00024	 0.00241	 0.0	 1247.0	 13043	 13043	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 3064	 0.00075	 0.01233	 0.0	 797.0	 2558	 2558	 0.0	 0.0	 1	 -30.0	 30.0;
	7780	 968	 0.0	 -0.03116	 0.0	 970.0	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	7434	 5079	 0.0	 -0.03116	 0.0	 970.0	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	2874	 5751	 3e-05	 0.00033	 0.0	 1940.0	 95327	 95327	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 6008	 0.00182	 0.02317	 0.0	 1360	 1360	 1360	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 4519	 0.00081	 0.01031	 0.0	 2009.0	 3055	 3055	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 6008	 0.00177	 0.01813	 0.0	 831.0	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 6008	 0.00175	 0.01789	 0.0	 831.0	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 3194	 0.00099	 0.01257	 0.0	 1905.0	 2506	 2506	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 407	 0.00125	 0.01594	 0.0	 1976	 1976	 1976	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 407	 0.00125	 0.01594	 0.0	 1976	 1976	 1976	 0.0	 0.0	 1	 -30.0	 30.0;
	6008	 1117	 0.00014	 0.00139	 0.0	 1282.0	 22611	 22611	 0.0	 0.0	 1	 -30.0	 30.0;
	6008	 1117	 0.00014	 0.00139	 0.0	 1282.0	 22611	 22611	 0.0	 0.0	 1	 -30.0	 30.0;
	6008	 1117	 0.00014	 0.00139	 0.0	 1282.0	 22611	 22611	 0.0	 0.0	 1	 -30.0	 30.0;
	6008	 6085	 0.00198	 0.02527	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 5220	 0.00845	 0.02712	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 20	 0.00736	 0.05805	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 1357	 0.02438	 0.07829	 0.0	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 2979	 0.02308	 0.07413	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 5180	 0.01802	 0.05786	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 126	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	6228	 8595	 0.01397	 0.08565	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	6228	 6751	 0.01937	 0.06219	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	6228	 8196	 0.01205	 0.07392	 0.0	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	5889	 7683	 0.00788	 0.02531	 0.0	 1192	 1192	 1192	 0.0	 0.0	 1	 -30.0	 30.0;
	5889	 4834	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 2979	 0.00394	 0.01266	 0.0	 2383	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 3943	 0.03491	 0.1121	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 8460	 0.02534	 0.08136	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 1381	 0.0469	 0.15061	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 1381	 0.0469	 0.15061	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 5430	 0.03913	 0.12566	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 5430	 0.03913	 0.12566	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 7147	 0.05332	 0.17309	 0.0	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	2186	 7147	 0.05332	 0.17309	 0.0	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 1329	 0.01015	 0.08002	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 8595	 0.0317	 0.10179	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 6498	 0.00719	 0.03426	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 6498	 0.00719	 0.03426	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 3822	 0.00143	 0.0113	 0.0	 2774	 2774	 2774	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 3822	 0.00143	 0.0113	 0.0	 2774	 2774	 2774	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 5538	 0.03463	 0.11119	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 7716	 0.01306	 0.04195	 0.0	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 8121	 0.01689	 0.05424	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 1054	 0.03074	 0.09872	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 7009	 0.03547	 0.1139	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	454	 7894	 0.04622	 0.14844	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	454	 6326	 0.04949	 0.15892	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	454	 5349	 0.05106	 0.16399	 0.0	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 3379	 0.0282	 0.13445	 0.0	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 7147	 0.01391	 0.04653	 0.0	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 7147	 0.01391	 0.04653	 0.0	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 3271	 0.00282	 0.00904	 0.0	 3336	 3336	 3336	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 3271	 0.00282	 0.00904	 0.0	 3336	 3336	 3336	 0.0	 0.0	 1	 -30.0	 30.0;
	7370	 3660	 0.03744	 0.12023	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 3660	 0.00974	 0.03128	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 3660	 0.01357	 0.04357	 0.0	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 1329	 0.00563	 0.01808	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 3845	 0.02263	 0.07268	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	5010	 3271	 0.03265	 0.10486	 0.0	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5010	 2122	 0.03491	 0.1121	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 4818	 0.00444	 0.02117	 0.0	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 4818	 0.00444	 0.02117	 0.0	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 5430	 0.01605	 0.05153	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 5430	 0.01605	 0.05153	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 4640	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	4818	 1329	 0.01244	 0.03996	 0.0	 755	 755	 755	 0.0	 0.0	 1	 -30.0	 30.0;
	4818	 1329	 0.01244	 0.03996	 0.0	 755	 755	 755	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 8100	 0.01271	 0.0606	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	7009	 7894	 0.02928	 0.09402	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	7009	 7894	 0.02928	 0.09402	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	7009	 5649	 0.04909	 0.15766	 0.0	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 2584	 0.04335	 0.13922	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	7894	 4199	 0.02695	 0.12847	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	7894	 1612	 0.02695	 0.12847	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	2584	 4135	 0.0122	 0.09618	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	2584	 2346	 0.0304	 0.09763	 0.0	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	6326	 7371	 0.03536	 0.11354	 0.0	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	6326	 7013	 0.00338	 0.01085	 0.0	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	6326	 2346	 0.02837	 0.09112	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	6326	 497	 0.0139	 0.06626	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	5998	 7386	 0.00325	 0.01551	 0.0	 1994	 1994	 1994	 0.0	 0.0	 1	 -30.0	 30.0;
	5998	 5430	 0.01376	 0.06561	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	5998	 7977	 0.00472	 0.03718	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 860	 0.00756	 0.05962	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 860	 0.00756	 0.05962	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 1887	 0.00631	 0.02025	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 263	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	286	 7386	 0.0047	 0.03703	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	286	 5430	 0.0152	 0.04882	 0.0	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	286	 7977	 0.00115	 0.0091	 0.0	 3444	 3444	 3444	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 7371	 0.0179	 0.05749	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 1381	 0.01211	 0.03887	 0.0	 776	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 126	 0.02517	 0.08082	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	7386	 2122	 0.00619	 0.01989	 0.0	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 4640	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	8391	 5612	 0.01757	 0.05641	 0.0	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	8391	 6136	 0.01878	 0.06123	 0.0	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 3845	 0.02674	 0.08588	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	4199	 5349	 0.04673	 0.15006	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	4199	 1612	 0.00271	 0.01293	 0.0	 2391	 2391	 2391	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 6136	 0.02424	 0.07877	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	8595	 6498	 0.00822	 0.0648	 0.0	 484	 484	 484	 0.0	 0.0	 1	 -30.0	 30.0;
	8595	 1186	 0.02871	 0.09221	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	6294	 2762	 0.00263	 0.02071	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	6294	 6751	 0.02224	 0.07142	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	6294	 5590	 0.00261	 0.02055	 0.0	 1525	 1525	 1525	 0.0	 0.0	 1	 -30.0	 30.0;
	6294	 1186	 0.00845	 0.02712	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	7716	 8196	 0.0114	 0.0699	 0.0	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 3693	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	5612	 860	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	5612	 8121	 0.00563	 0.01808	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	5612	 5394	 0.01126	 0.03616	 0.0	 835	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 1186	 0.00597	 0.04707	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 8196	 0.01393	 0.10983	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 5394	 0.03828	 0.12294	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	4469	 7789	 0.00117	 0.01496	 0.0	 1940.0	 2106	 2106	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 5751	 0.00076	 0.00964	 0.0	 2009.0	 3267	 3267	 0.0	 0.0	 1	 -30.0	 30.0;
	9114	 5683	 0.00085	 0.01081	 0.0	 1767.0	 2914	 2914	 0.0	 0.0	 1	 -30.0	 30.0;
	9114	 7789	 0.00093	 0.0118	 0.0	 1767.0	 2669	 2669	 0.0	 0.0	 1	 -30.0	 30.0;
	1559	 6136	 0.00697	 0.05491	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	1559	 6136	 0.00697	 0.05491	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	313	 2122	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	2315	 5394	 0.00056	 0.00181	 0.0	 16672	 16672	 16672	 0.0	 0.0	 1	 -30.0	 30.0;
	7013	 3032	 0.00338	 0.01085	 0.0	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	407	 8422	 0.00122	 0.01546	 0.0	 1940.0	 2037	 2037	 0.0	 0.0	 1	 -30.0	 30.0;
	3302	 2396	 0.03378	 0.10848	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3302	 6812	 0.0117	 0.09226	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	3302	 2826	 0.01891	 0.14906	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3302	 2826	 0.01891	 0.14906	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	7986	 3568	 0.07702	 0.24733	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	7986	 4370	 0.01526	 0.07272	 0.0	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	1805	 4457	 0.0308	 0.0989	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	1805	 691	 0.02787	 0.0895	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	1805	 3260	 0.00038	 0.00298	 0.0	 10515	 10515	 10515	 0.0	 0.0	 1	 -30.0	 30.0;
	1805	 3260	 0.00038	 0.00298	 0.0	 10515	 10515	 10515	 0.0	 0.0	 1	 -30.0	 30.0;
	2245	 6812	 0.02291	 0.18059	 0.0	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	2245	 2491	 0.00593	 0.02828	 0.0	 1094	 1094	 1094	 0.0	 0.0	 1	 -30.0	 30.0;
	2245	 541	 0.00776	 0.06119	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 251	 0.04262	 0.13687	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 2508	 0.02065	 0.09841	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 4870	 0.05591	 0.17953	 0.0	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 735	 0.01196	 0.0943	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 735	 0.01196	 0.0943	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	505	 8085	 0.00644	 0.0307	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	505	 8085	 0.00644	 0.0307	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 723	 0.00241	 0.01898	 0.0	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 723	 0.00241	 0.01898	 0.0	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 723	 0.00249	 0.01961	 0.0	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 6281	 0.01208	 0.09524	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 3663	 0.07229	 0.23215	 0.0	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	723	 982	 0.0264	 0.08479	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	723	 8085	 0.00762	 0.06009	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	723	 691	 0.01057	 0.08331	 0.0	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	723	 613	 0.0029	 0.02291	 0.0	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	723	 613	 0.0029	 0.02291	 0.0	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 6927	 0.01582	 0.0508	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 6812	 0.04887	 0.15693	 0.0	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	2346	 251	 0.01668	 0.07951	 0.0	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	2346	 251	 0.01668	 0.07951	 0.0	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	2346	 705	 0.00749	 0.02405	 0.0	 1254	 1254	 1254	 0.0	 0.0	 1	 -30.0	 30.0;
	2346	 497	 0.00617	 0.02941	 0.0	 1052	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	2346	 3032	 0.02815	 0.0904	 0.0	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	2346	 728	 0.02388	 0.0804	 0.0	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 6812	 0.05461	 0.17538	 0.0	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 7950	 0.02032	 0.06527	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	2396	 7950	 0.05236	 0.16814	 0.0	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	982	 8085	 0.00555	 0.04377	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	982	 2076	 0.00788	 0.02531	 0.0	 1192	 1192	 1192	 0.0	 0.0	 1	 -30.0	 30.0;
	6281	 1887	 0.01003	 0.07908	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	251	 4900	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 2076	 0.01982	 0.06364	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 5352	 0.00169	 0.00542	 0.0	 5564	 5564	 5564	 0.0	 0.0	 1	 -30.0	 30.0;
	2508	 2491	 0.01393	 0.10983	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	1887	 3663	 0.01172	 0.09241	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	6001	 2400	 0.00441	 0.02101	 0.0	 1472	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	4870	 6812	 0.04014	 0.12891	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 5260	 0.00597	 0.04707	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 5260	 0.00597	 0.04707	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 2278	 0.01017	 0.04848	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 2278	 0.01017	 0.04848	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 4900	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 735	 0.0002	 0.00157	 0.0	 19959	 19959	 19959	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 735	 0.0002	 0.00157	 0.0	 19959	 19959	 19959	 0.0	 0.0	 1	 -30.0	 30.0;
	6410	 5240	 0.01689	 0.05424	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	6410	 828	 4e-05	 0.00041	 0.0	 76679	 76679	 76679	 0.0	 0.0	 1	 -30.0	 30.0;
	6410	 3199	 0.01848	 0.06679	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	6410	 3199	 0.02061	 0.06617	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 3663	 0.01925	 0.06183	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	8359	 5240	 0.00617	 0.04864	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	3663	 263	 0.00847	 0.0404	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	6927	 4457	 0.01064	 0.03417	 0.0	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	6927	 3199	 0.04286	 0.14508	 0.0	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	168	 2400	 0.01729	 0.08242	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	168	 2400	 0.01729	 0.08242	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	168	 728	 0.01149	 0.04063	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 4370	 0.01328	 0.13577	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 3199	 0.02061	 0.06617	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 3260	 0.02567	 0.2024	 0.0	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	8422	 7642	 0.00268	 0.03408	 0.0	 925	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	8422	 5683	 0.00052	 0.00665	 0.0	 1940.0	 4736	 4736	 0.0	 0.0	 1	 -30.0	 30.0;
	3260	 541	 0.0004	 0.00314	 0.0	 307.0	 9980	 9980	 0.0	 0.0	 1	 -30.0	 30.0;
	358	 3032	 0.01126	 0.03616	 0.0	 835	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	7642	 4050	 0.00209	 0.0266	 0.0	 1184	 1184	 1184	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 5581	 0.00105	 0.0133	 0.0	 1801.0	 2368	 2368	 0.0	 0.0	 1	 -30.0	 30.0;
	3292	 1929	 0.00189	 0.02411	 0.0	 1307	 1307	 1307	 0.0	 0.0	 1	 -30.0	 30.0;
	8110	 7789	 0.0	 0.0002	 0.0	 1351.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4050	 5581	 0.00196	 0.02494	 0.0	 1263	 1263	 1263	 0.0	 0.0	 1	 -30.0	 30.0;
	5581	 6746	 0.00034	 0.00432	 0.0	 1351.0	 7290	 7290	 0.0	 0.0	 1	 -30.0	 30.0;
	5785	 7668	 0.00067	 0.00682	 0.0	 4610	 4610	 4610	 0.0	 0.0	 1	 -30.0	 30.0;
	7668	 1230	 0.00022	 0.0024	 0.0	 13107	 13107	 13107	 0.0	 0.0	 1	 -30.0	 30.0;
	7677	 5415	 0.00636	 0.02043	 0.0	 1477	 1477	 1477	 0.0	 0.0	 1	 -30.0	 30.0;
	6677	 8254	 6.3e-05	 0.00019	 0.0	 157801	 157801	 157801	 0.0	 0.0	 1	 -30.0	 30.0;
	5023	 9089	 0.00398	 0.03138	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	5023	 9089	 0.00398	 0.03138	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	3693	 8460	 0.00394	 0.01266	 0.0	 2383	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	8441	 8121	 0.00011	 0.00036	 0.0	 83913	 83913	 83913	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 6929	 0.00135	 0.01379	 0.0	 1711.0	 2280	 2280	 1.052632	 0.0	 1	 -30.0	 30.0;
	2935	 4959	 0.00097	 0.01239	 0.0	 3879	 3879	 3879	 1.052632	 0.0	 1	 -30.0	 30.0;
	436	 4458	 0.00084	 0.01064	 0.0	 4516	 4516	 4516	 1.052632	 0.0	 1	 -30.0	 30.0;
	6967	 4635	 0.00431	 0.09324	 0.0	 339	 339	 339	 1.0	 0.0	 1	 -30.0	 30.0;
	6967	 4635	 0.0044	 0.091339	 0.0	 346	 346	 346	 1.0	 0.0	 1	 -30.0	 30.0;
	1335	 7131	 0.006356	 0.142878	 0.0	 221	 221	 221	 1.026667	 0.0	 1	 -30.0	 30.0;
	2474	 7141	 0.00523	 0.10214	 0.0	 309	 309	 309	 1.0	 0.0	 1	 -30.0	 30.0;
	2474	 7141	 0.00532	 0.099917	 0.0	 316	 316	 316	 1.0	 0.0	 1	 -30.0	 30.0;
	2474	 7141	 0.00442	 0.105388	 0.0	 300	 300	 300	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 5657	 0.001002	 0.059033	 0.0	 817	 817	 817	 1.052632	 0.0	 1	 -30.0	 30.0;
	8258	 5657	 0.000812	 0.056028	 0.0	 861	 861	 861	 1.052632	 0.0	 1	 -30.0	 30.0;
	7313	 7931	 0.000921	 0.058347	 0.0	 826	 826	 826	 1.052632	 0.0	 1	 -30.0	 30.0;
	7931	 4322	 0.0016	 0.07243	 0.0	 437	 437	 437	 1.0	 0.0	 1	 -30.0	 30.0;
	7931	 4322	 0.00182	 0.07098	 0.0	 445	 445	 445	 1.0	 0.0	 1	 -30.0	 30.0;
	7931	 4322	 0.00185	 0.06953	 0.0	 455	 455	 455	 1.0	 0.0	 1	 -30.0	 30.0;
	273	 8339	 0.00349	 0.07969	 0.0	 396	 396	 396	 1.0	 0.0	 1	 -30.0	 30.0;
	273	 8339	 0.00355	 0.07799	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	1544	 273	 0.001101	 0.048618	 0.0	 992	 992	 992	 1.052632	 0.0	 1	 -30.0	 30.0;
	1544	 273	 0.000984	 0.055107	 0.0	 875	 875	 875	 1.052632	 0.0	 1	 -30.0	 30.0;
	6505	 8826	 0.00175	 0.07752	 0.0	 408	 408	 408	 1.0	 0.0	 1	 -30.0	 30.0;
	6505	 8826	 0.00171	 0.07901	 0.0	 400	 400	 400	 1.0	 0.0	 1	 -30.0	 30.0;
	5976	 4329	 0.00302	 0.091446	 0.0	 346	 346	 346	 1.0	 0.0	 1	 -30.0	 30.0;
	5976	 4329	 0.00295	 0.084678	 0.0	 373	 373	 373	 1.0	 0.0	 1	 -30.0	 30.0;
	5989	 4625	 0.0018	 0.07815	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	5989	 4625	 0.00185	 0.07724	 0.0	 409	 409	 409	 1.0	 0.0	 1	 -30.0	 30.0;
	5989	 4625	 0.00193	 0.07007	 0.0	 451	 451	 451	 1.0	 0.0	 1	 -30.0	 30.0;
	106	 2546	 0.00205	 0.094653	 0.0	 510	 510	 510	 1.052632	 0.0	 1	 -30.0	 30.0;
	5177	 515	 0.000454	 0.031593	 0.0	 691.0	 1000	 1000	 0.976831	 0.055998	 1	 -30.0	 30.0;
	5177	 515	 0.0004	 0.035809	 0.0	 691.0	 883	 883	 0.976831	 0.055998	 1	 -30.0	 30.0;
	2203	 7638	 0.000342	 0.033341	 0.0	 724.0	 948	 948	 0.905856	 0.0	 1	 -30.0	 30.0;
	1363	 7638	 0.000342	 0.03398	 0.0	 724.0	 930	 930	 0.905856	 0.0	 1	 -30.0	 30.0;
	4463	 7638	 0.000121	 0.028823	 0.0	 705.0	 1096	 1096	 0.953802	 0.305147	 1	 -30.0	 30.0;
	4463	 3826	 0.000121	 0.014044	 0.0	 705.0	 2250	 2250	 0.0	 0.0	 1	 -30.0	 30.0;
	6962	 1829	 0.000347	 0.044669	 0.0	 691.0	 708	 708	 1.098173	 -0.129803	 1	 -30.0	 30.0;
	6962	 1829	 0.000356	 0.043761	 0.0	 691.0	 722	 722	 1.098173	 -0.129803	 1	 -30.0	 30.0;
	4310	 667	 0.0	 0.026535	 0.0	 1191	 1191	 1191	 1.0	 0.047371	 1	 -30.0	 30.0;
	4310	 1829	 0.0	 0.025962	 0.0	 1217	 1217	 1217	 1.0	 -0.047371	 1	 -30.0	 30.0;
	8228	 5594	 0.000431	 0.041394	 0.0	 724.0	 764	 764	 0.950048	 0.115349	 1	 -30.0	 30.0;
	8228	 5594	 0.00038	 0.043903	 0.0	 720	 720	 720	 0.955131	 0.103215	 1	 -30.0	 30.0;
	3508	 5847	 0.0004	 0.03651	 0.0	 691.0	 866	 866	 0.976831	 0.055998	 1	 -30.0	 30.0;
	3508	 5847	 0.0004	 0.037209	 0.0	 691.0	 849	 849	 0.976831	 0.055998	 1	 -30.0	 30.0;
	4115	 5847	 0.000121	 0.015661	 0.0	 838.0	 2017	 2017	 0.0	 0.0	 1	 -30.0	 30.0;
	4115	 3702	 0.000121	 0.014499	 0.0	 838.0	 2179	 2179	 0.0	 0.0	 1	 -30.0	 30.0;
	345	 298	 0.000131	 0.014799	 0.0	 800.0	 2135	 2135	 0.998827	 -0.048422	 1	 -30.0	 30.0;
	345	 6762	 0.000141	 0.013923	 0.0	 800.0	 2269	 2269	 0.0	 0.0	 1	 -30.0	 30.0;
	3025	 3887	 0.000194	 0.013059	 0.0	 1185.0	 2419	 2419	 1.002506	 0.0	 1	 -30.0	 30.0;
	7992	 265	 0.000463	 0.031001	 0.0	 757.0	 1019	 1019	 0.956361	 0.0	 1	 -30.0	 30.0;
	7992	 265	 0.000472	 0.030331	 0.0	 757.0	 1042	 1042	 0.956361	 0.0	 1	 -30.0	 30.0;
	458	 7393	 0.000163	 0.015501	 0.0	 1415.0	 2038	 2038	 0.943535	 0.0	 1	 -30.0	 30.0;
	5718	 4010	 0.001987	 0.071722	 0.0	 441	 441	 441	 0.9625	 0.0	 1	 -30.0	 30.0;
	2512	 6346	 0.000756	 0.051399	 0.0	 615	 615	 615	 0.995296	 0.0	 1	 -30.0	 30.0;
	2512	 6346	 0.000746	 0.05345	 0.0	 591	 591	 591	 0.995296	 0.0	 1	 -30.0	 30.0;
	7262	 9177	 0.00069	 0.04333	 0.0	 729	 729	 729	 1.052632	 0.0	 1	 -30.0	 30.0;
	2738	 7390	 0.0022	 0.065399	 0.0	 483	 483	 483	 0.925	 0.0	 1	 -30.0	 30.0;
	2738	 7390	 0.002235	 0.064019	 0.0	 494	 494	 494	 0.925	 0.0	 1	 -30.0	 30.0;
	8612	 5070	 0.00168	 0.07424	 0.0	 426	 426	 426	 1.0	 0.0	 1	 -30.0	 30.0;
	963	 3467	 0.002036	 0.070048	 0.0	 451	 451	 451	 0.992391	 0.0	 1	 -30.0	 30.0;
	963	 3467	 0.001997	 0.071368	 0.0	 443	 443	 443	 0.992391	 0.0	 1	 -30.0	 30.0;
	3622	 963	 0.00035	 0.032859	 0.0	 962	 962	 962	 1.052632	 0.0	 1	 -30.0	 30.0;
	3622	 963	 0.0004	 0.0322	 0.0	 981	 981	 981	 1.052632	 0.0	 1	 -30.0	 30.0;
	2613	 3801	 0.00205	 0.06915	 0.0	 457	 457	 457	 1.0	 0.0	 1	 -30.0	 30.0;
	2613	 3801	 0.00082	 0.07342	 0.0	 431	 431	 431	 1.0	 0.0	 1	 -30.0	 30.0;
	353	 8577	 0.002658	 0.07732	 0.0	 409	 409	 409	 0.992391	 0.0	 1	 -30.0	 30.0;
	353	 8577	 0.002712	 0.075649	 0.0	 418	 418	 418	 0.992391	 0.0	 1	 -30.0	 30.0;
	4022	 3856	 0.00065	 0.04604	 0.0	 687	 687	 687	 1.052632	 0.0	 1	 -30.0	 30.0;
	7105	 2625	 0.00062	 0.03629	 0.0	 871	 871	 871	 1.052632	 0.0	 1	 -30.0	 30.0;
	7105	 8172	 0.00019	 0.03263	 0.0	 969	 969	 969	 1.052632	 0.0	 1	 -30.0	 30.0;
	2682	 974	 0.001797	 0.07284	 0.0	 434	 434	 434	 0.992248	 0.0	 1	 -30.0	 30.0;
	3236	 8398	 0.002712	 0.072578	 0.0	 435	 435	 435	 0.966477	 0.0	 1	 -30.0	 30.0;
	7285	 353	 0.00047	 0.0307	 0.0	 1570	 1570	 1570	 1.052632	 0.0	 1	 -30.0	 30.0;
	7695	 3936	 0.002601	 0.071481	 0.0	 442	 442	 442	 0.975	 0.0	 1	 -30.0	 30.0;
	7695	 3936	 0.002653	 0.06993	 0.0	 452	 452	 452	 0.975	 0.0	 1	 -30.0	 30.0;
	5625	 7695	 0.00037	 0.034169	 0.0	 925	 925	 925	 1.052632	 0.0	 1	 -30.0	 30.0;
	5625	 7695	 0.00037	 0.034831	 0.0	 907	 907	 907	 1.052632	 0.0	 1	 -30.0	 30.0;
	6688	 3790	 0.0004	 0.03524	 0.0	 1368	 1368	 1368	 1.052632	 0.0	 1	 -30.0	 30.0;
	6688	 5196	 0.00069	 0.04525	 0.0	 1066	 1066	 1066	 1.052632	 0.0	 1	 -30.0	 30.0;
	8894	 7768	 0.00069	 0.04231	 0.0	 747	 747	 747	 1.052632	 0.0	 1	 -30.0	 30.0;
	3098	 7531	 0.00119	 0.073146	 0.0	 432	 432	 432	 0.9625	 0.0	 1	 -30.0	 30.0;
	3098	 7531	 0.002764	 0.071607	 0.0	 441	 441	 441	 0.9625	 0.0	 1	 -30.0	 30.0;
	9024	 6542	 0.000742	 0.067219	 0.0	 470	 470	 470	 0.994359	 0.0	 1	 -30.0	 30.0;
	9024	 6542	 0.000793	 0.06388	 0.0	 495	 495	 495	 0.998418	 0.0	 1	 -30.0	 30.0;
	6069	 9192	 0.000609	 0.046809	 0.0	 675	 675	 675	 0.933053	 0.0	 1	 -30.0	 30.0;
	6069	 1968	 0.00059	 0.04521	 0.0	 691.0	 699	 699	 0.91223	 0.0	 1	 -30.0	 30.0;
	7829	 1968	 0.519194	 5.108058	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	8574	 2299	 0.000559	 0.039982	 0.0	 790	 790	 790	 0.919523	 0.0	 1	 -30.0	 30.0;
	8574	 5587	 0.000537	 0.045312	 0.0	 698	 698	 698	 0.948262	 0.0	 1	 -30.0	 30.0;
	4929	 1815	 0.000889	 0.061549	 0.0	 514	 514	 514	 0.996867	 0.0	 1	 -30.0	 30.0;
	1815	 792	 1.467822	 7.764888	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	6704	 4586	 0.000586	 0.049031	 0.0	 645	 645	 645	 0.923407	 0.0	 1	 -30.0	 30.0;
	2441	 3506	 0.000417	 0.047801	 0.0	 658.0	 661	 661	 0.952413	 0.0	 1	 -30.0	 30.0;
	1367	 6826	 0.000755	 0.05143	 0.0	 615	 615	 615	 0.924009	 0.0	 1	 -30.0	 30.0;
	1676	 228	 0.000733	 0.052399	 0.0	 603	 603	 603	 0.934986	 0.0	 1	 -30.0	 30.0;
	7829	 6826	 0.00078	 0.064311	 0.0	 492	 492	 492	 1.0	 0.0	 1	 -30.0	 30.0;
	659	 3279	 0.00089	 0.048632	 0.0	 650	 650	 650	 0.987002	 0.0	 1	 -30.0	 30.0;
	5210	 792	 0.00855	 0.08972	 0.0	 351	 351	 351	 1.0	 0.0	 1	 -30.0	 30.0;
	1445	 792	 0.00223	 0.04836	 0.0	 653	 653	 653	 1.0	 0.0	 1	 -30.0	 30.0;
	7180	 2168	 0.000581	 0.043111	 0.0	 658.0	 733	 733	 0.924038	 0.0	 1	 -30.0	 30.0;
	6833	 8964	 0.000579	 0.043272	 0.0	 691.0	 730	 730	 0.901005	 0.0	 1	 -30.0	 30.0;
	3659	 3242	 0.000586	 0.049031	 0.0	 645	 645	 645	 0.923407	 0.0	 1	 -30.0	 30.0;
	8181	 4427	 0.000559	 0.049192	 0.0	 643	 643	 643	 0.924009	 0.0	 1	 -30.0	 30.0;
	9025	 7563	 0.000573	 0.051129	 0.0	 618	 618	 618	 0.934986	 0.0	 1	 -30.0	 30.0;
	2267	 5210	 0.000417	 0.039229	 0.0	 724.0	 806	 806	 0.967059	 0.0	 1	 -30.0	 30.0;
	5210	 7279	 0.230542	 1.197733	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 8335	 0.02284	 0.2644	 0.0	 120	 120	 120	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 2449	 0.08537	 0.736798	 0.0	 43	 43	 43	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 4665	 1.402768	 3.640289	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 4495	 1.050227	 4.450207	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	8179	 7279	 0.000716	 0.04371	 0.0	 723	 723	 723	 0.934986	 0.0	 1	 -30.0	 30.0;
	1445	 7279	 0.518622	 2.317689	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	5509	 8335	 0.00059	 0.045662	 0.0	 692	 692	 692	 0.955958	 0.0	 1	 -30.0	 30.0;
	5509	 1531	 0.000603	 0.050959	 0.0	 620	 620	 620	 0.968125	 0.0	 1	 -30.0	 30.0;
	1445	 8335	 0.047769	 0.554178	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	7762	 5155	 0.000591	 0.045153	 0.0	 700	 700	 700	 0.918868	 0.0	 1	 -30.0	 30.0;
	7762	 271	 0.0006	 0.047778	 0.0	 662	 662	 662	 0.948976	 0.0	 1	 -30.0	 30.0;
	7829	 5776	 0.02436	 0.270151	 0.0	 117	 117	 117	 1.0	 0.0	 1	 -30.0	 30.0;
	8329	 1445	 0.000802	 0.05727	 0.0	 552	 552	 552	 0.967021	 0.0	 1	 -30.0	 30.0;
	8329	 1445	 0.000823	 0.056059	 0.0	 564	 564	 564	 0.967021	 0.0	 1	 -30.0	 30.0;
	1445	 2449	 0.188099	 1.291901	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	1445	 4665	 2.466323	 7.26343	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	2268	 2908	 0.000523	 0.050352	 0.0	 628	 628	 628	 0.934622	 0.0	 1	 -30.0	 30.0;
	8847	 5776	 0.000682	 0.049638	 0.0	 637	 637	 637	 0.913034	 0.0	 1	 -30.0	 30.0;
	8847	 8103	 0.00099	 0.04736	 0.0	 667	 667	 667	 1.012146	 0.0	 1	 -30.0	 30.0;
	317	 2449	 0.000616	 0.048759	 0.0	 648	 648	 648	 0.933053	 0.0	 1	 -30.0	 30.0;
	7637	 8581	 9e-05	 0.015499	 0.0	 1678.0	 2038	 2038	 1.0	 -0.428189	 1	 -30.0	 30.0;
	5848	 7526	 9e-05	 0.00963	 0.0	 1678.0	 3280	 3280	 1.0	 0.178581	 1	 -30.0	 30.0;
	89	 4495	 0.000664	 0.045609	 0.0	 693	 693	 693	 0.924009	 0.0	 1	 -30.0	 30.0;
	2520	 4665	 0.000649	 0.044862	 0.0	 691.0	 705	 705	 0.933053	 0.0	 1	 -30.0	 30.0;
	5996	 8420	 0.00067	 0.04326	 0.0	 724.0	 731	 731	 0.923407	 0.0	 1	 -30.0	 30.0;
	2154	 5996	 9e-05	 0.009901	 0.0	 1678.0	 3191	 3191	 1.0	 -0.153178	 1	 -30.0	 30.0;
	6999	 4008	 0.000246	 0.02678	 0.0	 1382.0	 1800	 1800	 1.015668	 -0.130098	 1	 -30.0	 30.0;
	4008	 5521	 0.00131	 0.07578	 0.0	 417	 417	 417	 1.045454	 0.0	 1	 -30.0	 30.0;
	4008	 5521	 0.00128	 0.07077	 0.0	 447	 447	 447	 1.045454	 0.0	 1	 -30.0	 30.0;
	3173	 8768	 0.00131	 0.062651	 0.0	 505	 505	 505	 1.0	 0.0	 1	 -30.0	 30.0;
	3173	 8768	 0.00133	 0.0577	 0.0	 548	 548	 548	 1.0	 0.0	 1	 -30.0	 30.0;
	5055	 1450	 0.001495	 0.059475	 0.0	 531	 531	 531	 0.974576	 0.0	 1	 -30.0	 30.0;
	5055	 9237	 0.001453	 0.061392	 0.0	 515	 515	 515	 0.974576	 0.0	 1	 -30.0	 30.0;
	6568	 5424	 0.001475	 0.074554	 0.0	 647	 647	 647	 0.981267	 0.0	 1	 -30.0	 30.0;
	6568	 5424	 0.001309	 0.084508	 0.0	 571	 571	 571	 0.981267	 0.0	 1	 -30.0	 30.0;
	888	 4877	 0.00119	 0.084099	 0.0	 376	 376	 376	 1.0	 0.0	 1	 -30.0	 30.0;
	4388	 1073	 0.00117	 0.064859	 0.0	 487	 487	 487	 1.0	 0.0	 1	 -30.0	 30.0;
	4388	 1073	 0.00114	 0.066091	 0.0	 478	 478	 478	 1.0	 0.0	 1	 -30.0	 30.0;
	7572	 5954	 0.001225	 0.083401	 0.0	 379	 379	 379	 0.973021	 0.0	 1	 -30.0	 30.0;
	7572	 5954	 0.001394	 0.082574	 0.0	 383	 383	 383	 0.973021	 0.0	 1	 -30.0	 30.0;
	3440	 4599	 0.001415	 0.080475	 0.0	 393	 393	 393	 0.973021	 0.0	 1	 -30.0	 30.0;
	3440	 4599	 0.001447	 0.078793	 0.0	 401	 401	 401	 0.973021	 0.0	 1	 -30.0	 30.0;
	9010	 8830	 0.001444	 0.074683	 0.0	 423	 423	 423	 0.981267	 0.0	 1	 -30.0	 30.0;
	9010	 8830	 0.001475	 0.073051	 0.0	 433	 433	 433	 0.981267	 0.0	 1	 -30.0	 30.0;
	921	 4570	 0.001316	 0.070415	 0.0	 449	 449	 449	 0.974576	 0.0	 1	 -30.0	 30.0;
	7790	 3437	 0.00128	 0.065919	 0.0	 480	 480	 480	 1.0	 0.0	 1	 -30.0	 30.0;
	8885	 480	 0.001056	 0.075919	 0.0	 635	 635	 635	 1.052632	 0.0	 1	 -30.0	 30.0;
	1263	 480	 0.001451	 0.078431	 0.0	 403	 403	 403	 0.905512	 0.0	 1	 -30.0	 30.0;
	1263	 480	 0.001415	 0.075297	 0.0	 420	 420	 420	 0.905512	 0.0	 1	 -30.0	 30.0;
	2677	 1682	 0.001411	 0.061844	 0.0	 511	 511	 511	 0.974576	 0.0	 1	 -30.0	 30.0;
	2677	 1682	 0.001432	 0.058938	 0.0	 536	 536	 536	 0.974576	 0.0	 1	 -30.0	 30.0;
	2386	 2068	 0.00229	 0.085231	 0.0	 371	 371	 371	 0.979339	 0.0	 1	 -30.0	 30.0;
	5160	 572	 0.001474	 0.06058	 0.0	 522	 522	 522	 0.974576	 0.0	 1	 -30.0	 30.0;
	1438	 1324	 0.00125	 0.064651	 0.0	 489	 489	 489	 1.0	 0.0	 1	 -30.0	 30.0;
	1438	 1324	 0.00123	 0.065919	 0.0	 480	 480	 480	 1.0	 0.0	 1	 -30.0	 30.0;
	1438	 1324	 0.0012	 0.06718	 0.0	 471	 471	 471	 1.0	 0.0	 1	 -30.0	 30.0;
	2419	 7336	 0.001221	 0.069631	 0.0	 454	 454	 454	 0.982906	 0.0	 1	 -30.0	 30.0;
	2419	 7336	 0.00119	 0.065604	 0.0	 482	 482	 482	 0.982906	 0.0	 1	 -30.0	 30.0;
	1668	 9145	 0.001039	 0.045925	 0.0	 688	 688	 688	 0.981267	 0.0	 1	 -30.0	 30.0;
	3885	 9144	 0.000406	 0.019067	 0.0	 1316.0	 2528	 2528	 0.79272	 0.154768	 1	 -30.0	 30.0;
	9144	 1873	 0.001563	 0.060356	 0.0	 731	 731	 731	 0.982906	 0.0	 1	 -30.0	 30.0;
	9144	 1873	 0.001459	 0.059041	 0.0	 748	 748	 748	 0.982906	 0.0	 1	 -30.0	 30.0;
	6046	 1098	 0.001531	 0.068989	 0.0	 640	 640	 640	 0.942623	 0.0	 1	 -30.0	 30.0;
	8322	 6434	 0.000318	 0.014328	 0.0	 954.0	 3363	 3363	 1.002506	 0.0	 1	 -30.0	 30.0;
	2041	 6006	 0.000246	 0.02678	 0.0	 954.0	 1180	 1180	 1.015668	 -0.130098	 1	 -30.0	 30.0;
	6006	 3669	 0.00121	 0.066091	 0.0	 478	 478	 478	 1.0	 0.0	 1	 -30.0	 30.0;
	6006	 3669	 0.00118	 0.062289	 0.0	 508	 508	 508	 1.0	 0.0	 1	 -30.0	 30.0;
	8551	 6258	 0.001646	 0.071174	 0.0	 444	 444	 444	 0.905512	 0.0	 1	 -30.0	 30.0;
	8551	 6258	 0.00229	 0.087099	 0.0	 363	 363	 363	 1.045454	 0.0	 1	 -30.0	 30.0;
	1922	 1084	 0.001421	 0.061107	 0.0	 517	 517	 517	 0.974576	 0.0	 1	 -30.0	 30.0;
	9194	 3141	 0.001573	 0.080941	 0.0	 391	 391	 391	 0.956938	 0.0	 1	 -30.0	 30.0;
	9194	 3141	 0.001594	 0.078385	 0.0	 403	 403	 403	 0.956938	 0.0	 1	 -30.0	 30.0;
	5497	 8408	 0.001369	 0.06454	 0.0	 490	 490	 490	 0.974576	 0.0	 1	 -30.0	 30.0;
	5497	 8408	 0.001348	 0.065203	 0.0	 485	 485	 485	 0.974576	 0.0	 1	 -30.0	 30.0;
	1143	 5082	 0.001295	 0.071353	 0.0	 443	 443	 443	 0.974576	 0.0	 1	 -30.0	 30.0;
	1143	 5082	 0.001295	 0.070826	 0.0	 446	 446	 446	 0.974576	 0.0	 1	 -30.0	 30.0;
	1506	 4304	 0.001441	 0.084934	 0.0	 372	 372	 372	 0.956938	 0.0	 1	 -30.0	 30.0;
	1506	 4304	 0.001463	 0.083626	 0.0	 378	 378	 378	 0.956938	 0.0	 1	 -30.0	 30.0;
	3981	 36	 0.000448	 0.016447	 0.0	 724.0	 1920	 1920	 1.002506	 0.0	 1	 -30.0	 30.0;
	3981	 1641	 0.001134	 0.053193	 0.0	 594	 594	 594	 0.998185	 0.0	 1	 -30.0	 30.0;
	36	 1641	 0.00136	 0.057539	 0.0	 549	 549	 549	 1.0	 0.0	 1	 -30.0	 30.0;
	2110	 4184	 0.001432	 0.06454	 0.0	 490	 490	 490	 0.974576	 0.0	 1	 -30.0	 30.0;
	665	 4028	 0.00195	 0.114628	 0.0	 276	 276	 276	 0.979339	 0.0	 1	 -30.0	 30.0;
	1820	 7456	 0.001295	 0.067067	 0.0	 471	 471	 471	 0.974576	 0.0	 1	 -30.0	 30.0;
	4788	 8978	 0.001242	 0.074563	 0.0	 424	 424	 424	 0.974576	 0.0	 1	 -30.0	 30.0;
	6158	 4518	 0.00126	 0.060099	 0.0	 802	 802	 802	 1.0	 0.0	 1	 -30.0	 30.0;
	6158	 4518	 0.00135	 0.06051	 0.0	 797	 797	 797	 1.0	 0.0	 1	 -30.0	 30.0;
	7455	 3505	 0.00036	 0.042469	 0.0	 691.0	 1135	 1135	 1.052174	 0.0	 1	 -30.0	 30.0;
	1199	 5962	 0.001278	 0.05335	 0.0	 592	 592	 592	 0.973021	 0.0	 1	 -30.0	 30.0;
	6775	 5438	 0.000503	 0.028047	 0.0	 1127	 1127	 1127	 0.977126	 0.026068	 1	 -30.0	 30.0;
	6775	 5438	 0.000503	 0.039314	 0.0	 804	 804	 804	 0.977126	 -0.112848	 1	 -30.0	 30.0;
	3433	 4540	 0.000333	 0.021103	 0.0	 691.0	 1497	 1497	 0.99559	 0.0	 1	 -30.0	 30.0;
	8905	 4631	 0.00044	 0.031706	 0.0	 997	 997	 997	 0.977126	 0.026068	 1	 -30.0	 30.0;
	3494	 5807	 0.000164	 0.013858	 0.0	 1185.0	 2280	 2280	 1.019598	 0.0	 1	 -30.0	 30.0;
	4938	 2987	 0.000353	 0.025975	 0.0	 921.0	 1216	 1216	 0.937567	 0.0	 1	 -30.0	 30.0;
	1557	 3569	 0.000159	 0.016667	 0.0	 1185.0	 1896	 1896	 0.937567	 0.0	 1	 -30.0	 30.0;
	3277	 2487	 0.000273	 0.017971	 0.0	 987.0	 1758	 1758	 0.956938	 0.066854	 1	 -30.0	 30.0;
	1369	 6520	 0.000289	 0.02558	 0.0	 691.0	 1235	 1235	 1.030079	 -0.153295	 1	 -30.0	 30.0;
	5778	 6433	 0.00142	 0.02765	 0.0	 476.0	 1141	 1141	 1.0	 0.0	 1	 -30.0	 30.0;
	5778	 6433	 0.00145	 0.02707	 0.0	 476.0	 1166	 1166	 1.0	 0.0	 1	 -30.0	 30.0;
	1679	 381	 0.000469	 0.030842	 0.0	 1025	 1025	 1025	 1.097063	 0.0	 1	 -30.0	 30.0;
	1615	 381	 0.00435	 0.076291	 0.0	 414	 414	 414	 1.0	 0.432244	 1	 -30.0	 30.0;
	4201	 7219	 0.000352	 0.020852	 0.0	 691.0	 1515	 1515	 1.011235	 0.0	 1	 -30.0	 30.0;
	4079	 153	 0.0003	 0.01099	 0.0	 2874	 2874	 2874	 1.0	 0.0	 1	 -30.0	 30.0;
	4079	 153	 0.00029	 0.0112	 0.0	 2820	 2820	 2820	 1.0	 0.0	 1	 -30.0	 30.0;
	4830	 4176	 0.000375	 0.018768	 0.0	 691.0	 1683	 1683	 1.011235	 0.0	 1	 -30.0	 30.0;
	6666	 2191	 0.000537	 0.028553	 0.0	 691.0	 1107	 1107	 1.013158	 0.0	 1	 -30.0	 30.0;
	6666	 2191	 0.000537	 0.028002	 0.0	 691.0	 1128	 1128	 1.013158	 0.0	 1	 -30.0	 30.0;
	1653	 3973	 0.000622	 0.033296	 0.0	 949	 949	 949	 0.956938	 0.0	 1	 -30.0	 30.0;
	1653	 3973	 0.000622	 0.034627	 0.0	 913	 913	 913	 0.956938	 0.076921	 1	 -30.0	 30.0;
	2716	 382	 0.00072	 0.026242	 0.0	 1204	 1204	 1204	 0.957131	 0.0	 1	 -30.0	 30.0;
	2716	 382	 0.000644	 0.029735	 0.0	 1063	 1063	 1063	 0.957131	 0.0	 1	 -30.0	 30.0;
	6375	 4762	 0.00314	 0.168628	 0.0	 188	 188	 188	 1.0	 0.0	 1	 -30.0	 30.0;
	6375	 4762	 0.00307	 0.171877	 0.0	 184	 184	 184	 1.0	 0.0	 1	 -30.0	 30.0;
	611	 5905	 0.000188	 0.016506	 0.0	 954.0	 1914	 1914	 0.979483	 0.0	 1	 -30.0	 30.0;
	2153	 6014	 0.000259	 0.027074	 0.0	 1167	 1167	 1167	 1.002506	 0.0	 1	 -30.0	 30.0;
	3290	 291	 0.000437	 0.02611	 0.0	 1210	 1210	 1210	 1.047869	 0.0	 1	 -30.0	 30.0;
	5343	 3340	 0.000446	 0.025573	 0.0	 1235	 1235	 1235	 1.047869	 0.0	 1	 -30.0	 30.0;
	1884	 2588	 0.00032	 0.02243	 0.0	 1409	 1409	 1409	 1.034211	 0.0	 1	 -30.0	 30.0;
	6848	 6234	 6.091942	 8.676029	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 6234	 6.444008	 8.676035	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 6234	 23.9876	 40.776864	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 6234	 35.24587	 57.202482	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 6234	 45.97521	 69.597102	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 6234	 0.081469	 0.775971	 0.0	 41	 41	 41	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 6234	 32.03719	 50.568181	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 6234	 0.628884	 2.485744	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 7410	 12.31426	 19.110329	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 7410	 13.03616	 19.128307	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 7410	 0.197581	 1.393719	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 7410	 1.415165	 4.81467	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	5401	 2743	 0.13108	 0.821607	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	6284	 2743	 0.129079	 0.839681	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	6272	 2631	 0.069591	 0.599051	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	6272	 1144	 0.04983	 0.471267	 0.0	 67	 67	 67	 1.0	 0.0	 1	 -30.0	 30.0;
	6272	 3332	 0.00502	 0.310928	 0.0	 102	 102	 102	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 7786	 5.68843	 10.297518	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 7786	 48.32851	 56.749998	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 7786	 23.27066	 28.824377	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 7786	 50.96074	 55.43596	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 6212	 5.967355	 9.180988	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 6212	 44.27686	 58.522723	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 6212	 20.49132	 30.954553	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 6212	 43.12397	 61.993787	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 4012	 -0.04093	 0.365413	 0.0	 86	 86	 86	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 1029	 0.140533	 1.138574	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 3431	 0.151053	 1.206163	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 4033	 3.496607	 8.23892	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 1238	 3.21482	 7.345567	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 438	 0.136738	 1.1482	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 1907	 0.138539	 1.094044	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 3330	 0.077251	 0.917036	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 1587	 0.954778	 3.73151	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 8938	 0.745845	 4.144945	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 1177	 0.723892	 4.195776	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 4012	 0.47093	 3.07252	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 4012	 0.45124	 2.967768	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 4012	 0.460083	 2.907231	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 4012	 2.286777	 7.419422	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 4012	 3.438636	 9.067975	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	9100	 4012	 0.885578	 3.747314	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 4012	 0.788967	 4.246901	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 4012	 1.804731	 7.772521	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	7035	 6171	 0.000716	 0.032505	 0.0	 972	 972	 972	 0.963948	 0.0	 1	 -30.0	 30.0;
	7035	 6171	 0.00056	 0.04105	 0.0	 770	 770	 770	 0.965484	 0.0	 1	 -30.0	 30.0;
	7035	 6171	 0.00057	 0.040211	 0.0	 786	 786	 786	 0.965484	 0.0	 1	 -30.0	 30.0;
	7502	 6171	 10.24442	 15.278311	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	4101	 6171	 10.4376	 14.953303	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2511	 6171	 31.55372	 31.927684	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	1522	 6171	 0.02494	 0.501983	 0.0	 63	 63	 63	 1.0	 0.0	 1	 -30.0	 30.0;
	4866	 6171	 2.458264	 5.693595	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	6724	 6171	 21.7686	 29.266527	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8429	 6171	 0.260765	 1.554236	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	7816	 6171	 0.41095	 2.453926	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	5428	 6171	 1.358636	 3.804546	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	8762	 8498	 0.00445	 0.11669	 0.0	 271	 271	 271	 1.0	 0.0	 1	 -30.0	 30.0;
	2306	 182	 0.02812	 0.471488	 0.0	 67	 67	 67	 1.0	 0.0	 1	 -30.0	 30.0;
	1667	 182	 0.109781	 0.670062	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	3514	 182	 0.11731	 0.676136	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	7102	 7711	 0.000443	 0.034282	 0.0	 724.0	 922	 922	 0.957287	 0.0	 1	 -30.0	 30.0;
	4645	 7711	 0.000407	 0.0336	 0.0	 724.0	 941	 941	 0.957287	 0.0	 1	 -30.0	 30.0;
	92	 7711	 0.05005	 0.961922	 0.0	 33	 33	 33	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 7711	 20.2438	 55.378103	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 7711	 20.42293	 51.698341	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 7711	 7.97376	 20.509093	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 7711	 1.402252	 5.36219	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 7711	 4.842562	 10.371072	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 7711	 0.593884	 2.602686	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 7711	 9.390701	 21.464872	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 7711	 1.334504	 5.801447	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 1029	 1.754986	 5.357133	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 3431	 1.766898	 5.923268	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 4033	 1.832964	 7.959834	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 1238	 1.611565	 6.707825	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 438	 -0.019578	 0.602618	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 1907	 -0.018109	 0.575138	 0.0	 55	 55	 55	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 3330	 2.305263	 5.580056	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 1587	 0.324709	 1.981648	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 8938	 11.49377	 18.997923	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 1177	 10.16551	 21.393357	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 3860	 0.00083	 0.06663	 0.0	 475	 475	 475	 1.054155	 0.0	 1	 -30.0	 30.0;
	6584	 5323	 0.220599	 1.426839	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	9037	 5323	 0.215413	 1.319979	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	6497	 5323	 0.07932	 0.491198	 0.0	 64	 64	 64	 1.0	 0.0	 1	 -30.0	 30.0;
	4766	 5323	 0.05112	 0.388202	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	4296	 5323	 7.957025	 11.110533	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	5611	 5323	 8.10723	 10.874171	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	4647	 5323	 0.19505	 0.651797	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	7483	 5323	 0.273698	 1.122666	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	6584	 6715	 -0.016694	 0.279194	 0.0	 113	 113	 113	 1.0	 0.0	 1	 -30.0	 30.0;
	6584	 6715	 0.00066	 0.04694	 0.0	 673	 673	 673	 1.101233	 0.0	 1	 -30.0	 30.0;
	6584	 5301	 0.262431	 2.115858	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	6584	 2237	 0.251911	 2.002563	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	6584	 4350	 0.086669	 0.634127	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	9037	 6715	 -0.018471	 0.253657	 0.0	 125	 125	 125	 1.0	 0.0	 1	 -30.0	 30.0;
	9037	 6715	 0.000298	 0.012803	 0.0	 1547.0	 2467	 2467	 1.110134	 0.0	 1	 -30.0	 30.0;
	9037	 5301	 0.307389	 1.800831	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	9037	 2237	 0.307181	 1.800693	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	9037	 4350	 0.083082	 0.659398	 0.0	 48	 48	 48	 1.0	 0.0	 1	 -30.0	 30.0;
	6497	 6715	 2.852479	 6.564462	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	4766	 6715	 0.610723	 2.391322	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	4296	 6715	 0.796095	 2.828719	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	5611	 6715	 0.778781	 2.619215	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	4647	 6715	 5.253512	 8.690912	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	7483	 6715	 0.14057	 0.924359	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	424	 5439	 0.00012	 0.008723	 0.0	 3621	 3621	 3621	 1.0	 -0.157232	 1	 -30.0	 30.0;
	6497	 2222	 0.00012	 0.008273	 0.0	 3818	 3818	 3818	 1.0	 0.13111	 1	 -30.0	 30.0;
	6497	 5301	 34.83864	 37.361504	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6497	 2237	 31.4626	 43.434901	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6497	 4350	 9.837258	 14.382266	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2016	 8929	 0.124359	 1.222541	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	8517	 8929	 0.121719	 1.24562	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	2016	 7457	 0.11651	 1.13624	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	8517	 7457	 0.13205	 1.113513	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	4334	 818	 0.000447	 0.03387	 0.0	 933	 933	 933	 0.988622	 0.0	 1	 -30.0	 30.0;
	4334	 2743	 0.188878	 0.872161	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	4334	 7299	 0.000399	 0.010683	 0.0	 790.0	 2955	 2955	 1.031067	 0.0	 1	 -30.0	 30.0;
	8421	 2608	 0.01902	 0.177292	 0.0	 178	 178	 178	 1.0	 0.0	 1	 -30.0	 30.0;
	8421	 9077	 0.079771	 0.509993	 0.0	 62	 62	 62	 1.0	 0.0	 1	 -30.0	 30.0;
	8421	 7321	 0.00919	 0.137159	 0.0	 230	 230	 230	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 6451	 10.8518	 37.942518	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 5680	 20.41343	 54.805408	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 2895	 20.30263	 51.706374	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 8022	 0.787812	 4.341828	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 260	 0.590422	 4.326316	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 242	 0.712119	 2.758379	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 1067	 0.891274	 4.745083	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 3533	 27.32618	 53.325484	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 4789	 0.072382	 1.414889	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 7592	 0.070083	 1.331163	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 6421	 0.02163	 0.743629	 0.0	 43	 43	 43	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 1581	 3.623961	 20.259002	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 1085	 0.851039	 4.324031	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 3913	 1.040443	 4.789612	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	4766	 5301	 8.633058	 14.86384	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	4296	 5301	 0.05238	 0.529835	 0.0	 60	 60	 60	 1.0	 0.0	 1	 -30.0	 30.0;
	5611	 5301	 0.05337	 0.518554	 0.0	 61	 61	 61	 1.0	 0.0	 1	 -30.0	 30.0;
	4647	 5301	 56.80165	 51.109504	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	7483	 5301	 2.452686	 6.967768	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	4766	 2237	 8.052273	 16.496276	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	4296	 2237	 0.04414	 0.60938	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	5611	 2237	 0.0432	 0.620868	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	4647	 2237	 47.16736	 58.301648	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	7483	 2237	 2.566529	 6.851652	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 6451	 21.60319	 36.731304	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 5680	 38.25416	 49.701504	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 2895	 39.65235	 49.572723	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 8022	 13.37881	 27.533241	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 260	 11.70014	 34.83726	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 242	 0.03578	 2.06572	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 6718	 44.92382	 57.412053	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 4702	 5.792867	 13.966068	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 7500	 5.68705	 12.979224	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 1067	 23.49307	 56.524238	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 3533	 0.817382	 3.615513	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 4789	 1.090651	 5.780887	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 7592	 1.04626	 5.209279	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 5440	 0.644758	 1.803532	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 2605	 0.580852	 2.069945	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 6421	 15.32341	 41.617723	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 1971	 37.75623	 69.158594	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 1581	 4.031925	 12.920362	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 6451	 19.41759	 39.081025	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 5680	 38.13227	 52.87396	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 2895	 39.55609	 52.783939	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 8022	 13.35596	 29.188359	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 260	 13.38227	 31.89335	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 242	 0.06002	 1.808379	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 6718	 48.46122	 56.359411	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 4702	 6.294598	 13.758307	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 7500	 6.185319	 14.074795	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 1067	 21.89474	 63.064402	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 3533	 0.750554	 3.860318	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 4789	 1.114889	 6.088781	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 7592	 1.069114	 5.491413	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 5440	 0.653109	 1.929778	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 2605	 0.672888	 1.912604	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 6421	 18.13504	 36.319253	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 1971	 40.86842	 68.019379	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5523	 1581	 4.398892	 12.729917	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	5941	 2743	 0.0384	 0.48786	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 1029	 0.17575	 1.589628	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 3431	 0.16178	 1.59079	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 4033	 22.34695	 35.318561	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 1238	 20.61288	 31.520779	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 438	 1.071953	 3.96018	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 1907	 1.073546	 3.773961	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 3330	 1.477701	 3.981233	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 1587	 5.635665	 13.348342	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 8938	 13.41828	 27.828945	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	192	 1177	 13.04432	 28.183522	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 1029	 0.17575	 1.589628	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 3431	 0.161789	 1.590785	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 4033	 22.34695	 35.318561	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 1238	 20.61288	 31.520779	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 438	 1.071953	 3.96018	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 1907	 1.073546	 3.773961	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 3330	 1.477701	 3.981233	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 1587	 5.635665	 13.348342	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 8938	 13.41828	 27.828945	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	3349	 1177	 13.04432	 28.183522	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 1029	 7.514876	 17.076863	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 1029	 10.18967	 19.679343	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	9100	 1029	 1.403533	 4.891322	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 1029	 1.431054	 4.791528	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 1029	 7.830992	 14.143185	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 3431	 9.209711	 15.822724	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 3431	 13.04525	 19.283054	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	9100	 3431	 1.367066	 5.515496	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 3431	 1.339153	 5.62376	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 3431	 7.23719	 17.339673	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	6554	 1242	 0.00696	 0.20656	 0.0	 153	 153	 153	 1.0	 0.0	 1	 -30.0	 30.0;
	2016	 1242	 0.085711	 0.903781	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	8517	 1242	 0.09713	 0.885702	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	4766	 4350	 2.771122	 4.936011	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	2016	 7198	 0.296032	 1.447438	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	2016	 98	 0.281413	 1.320152	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	8517	 7198	 0.307202	 1.385873	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	8517	 98	 0.25536	 1.463643	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	1079	 7198	 0.00046	 0.03669	 0.0	 724.0	 861	 861	 0.926928	 0.0	 1	 -30.0	 30.0;
	6847	 98	 0.000808	 0.04562	 0.0	 693	 693	 693	 0.937579	 0.0	 1	 -30.0	 30.0;
	6847	 98	 0.000438	 0.03862	 0.0	 724.0	 818	 818	 0.933083	 0.0	 1	 -30.0	 30.0;
	2306	 2912	 0.037081	 0.480186	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	1667	 2912	 0.074531	 0.583946	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	3514	 2912	 0.08	 0.590186	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	5102	 2788	 0.10579	 0.434903	 0.0	 71	 71	 71	 1.0	 0.0	 1	 -30.0	 30.0;
	5102	 9077	 0.09937	 0.415727	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	1811	 2788	 0.095997	 0.482181	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	1811	 9077	 0.086717	 0.480388	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 4033	 0.873905	 3.992149	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 4033	 0.120211	 1.173533	 0.0	 27	 27	 27	 1.0	 0.0	 1	 -30.0	 30.0;
	9100	 4033	 7.082025	 15.591937	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 4033	 7.220868	 15.273755	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 4033	 0.872831	 3.28905	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 1238	 0.921508	 3.094834	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 1238	 0.129919	 0.960764	 0.0	 33	 33	 33	 1.0	 0.0	 1	 -30.0	 30.0;
	9100	 1238	 6.142769	 14.777069	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 1238	 6.017355	 15.066946	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 1238	 0.694463	 3.375206	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 438	 7.254848	 17.556091	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 1907	 6.944598	 15.819948	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 3330	 0.962188	 3.649169	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 1587	 2.525	 6.52029	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 8938	 0.00154	 0.39572	 0.0	 80	 80	 80	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 1177	 0.0014	 0.384758	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	4296	 4350	 0.590782	 1.406718	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	5611	 4350	 0.526337	 1.594252	 0.0	 19	 19	 19	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 6451	 0.836859	 5.618595	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 6451	 1.237665	 7.884711	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 6451	 3.449174	 20.571071	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 6451	 5.302273	 16.162393	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 6451	 0.789525	 4.620455	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 6451	 2.372521	 10.507644	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	1493	 2895	 0.000495	 0.033881	 0.0	 724.0	 933	 933	 0.957287	 0.0	 1	 -30.0	 30.0;
	2891	 5680	 2.23905	 7.164463	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 5680	 3.327273	 9.634503	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 5680	 8.134091	 27.90289	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 5680	 10.55806	 23.307847	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 5680	 1.718843	 7.201859	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 5680	 4.571488	 16.921905	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 2895	 1.894649	 7.933677	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 2895	 3.133678	 10.68802	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 2895	 8.769008	 26.754135	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 2895	 11.85517	 21.464873	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 2895	 2.005517	 6.368182	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 2895	 5.553718	 14.366735	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 438	 4.540289	 12.081814	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	9100	 438	 0.14887	 1.547789	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 438	 0.145641	 1.433141	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 438	 7.255165	 15.148962	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 1907	 4.918802	 10.649998	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	9100	 1907	 0.170281	 1.312108	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 1907	 0.17349	 1.284174	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 1907	 7.658058	 13.540087	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	7093	 3332	 1.803947	 6.514197	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	7093	 6130	 1.414404	 5.42687	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	7093	 1258	 0.097091	 1.338712	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	7093	 4085	 0.069813	 0.61338	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 3332	 1.656925	 6.386704	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 6130	 1.503047	 5.113989	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 1258	 0.107382	 1.212396	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 4085	 0.080478	 0.53394	 0.0	 59	 59	 59	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 3330	 1.566157	 4.554339	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	9100	 3330	 3.21405	 6.727273	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 3330	 2.86343	 7.62438	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 3330	 0.784091	 3.665289	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 8022	 -0.013061	 0.68473	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 260	 0.02627	 0.92126	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 242	 5.225831	 17.344184	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 629	 37.01108	 55.722988	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 3423	 38.53255	 55.73961	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 1067	 0.00421	 0.609432	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 3533	 3.373338	 12.718144	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 4789	 5.841413	 14.226459	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 7592	 4.851247	 14.847647	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 5440	 15.98753	 46.096945	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 2605	 15.83449	 47.580335	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 6421	 5.167521	 17.612876	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 1581	 0.170402	 3.131509	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 6655	 13.13227	 24.978533	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2891	 6307	 11.55748	 21.738223	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 8022	 0.071828	 1.118006	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 260	 0.01624	 0.986219	 0.0	 33	 33	 33	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 242	 1.180471	 4.696329	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 1067	 0.01296	 0.834834	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 3533	 4.962535	 20.238919	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 4789	 0.872438	 4.821676	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 7592	 0.801593	 4.526524	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 5440	 20.20014	 50.806099	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 2605	 23.16066	 50.423823	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 6421	 0.966621	 4.164474	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 1581	 0.448781	 4.337397	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 1085	 11.58657	 23.771465	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 3913	 13.00554	 26.333102	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 6655	 17.94044	 35.608035	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	4737	 6307	 15.18213	 32.262467	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 1587	 0.430249	 2.466066	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 8938	 0.0683	 0.916828	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	6894	 1177	 0.06612	 0.843352	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	9100	 1587	 1.444298	 4.757438	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 1587	 1.472603	 4.660331	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 1587	 2.284917	 6.055578	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	491	 8934	 0.000504	 0.031781	 0.0	 994	 994	 994	 1.058045	 0.0	 1	 -30.0	 30.0;
	491	 3332	 0.086683	 1.502285	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	491	 6130	 0.05572	 1.389266	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	491	 1258	 0.40606	 1.910249	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	491	 4085	 0.0265	 0.438137	 0.0	 72	 72	 72	 1.0	 0.0	 1	 -30.0	 30.0;
	7545	 6173	 0.000669	 0.032368	 0.0	 976	 976	 976	 1.067245	 0.0	 1	 -30.0	 30.0;
	9100	 8938	 16.48554	 31.878093	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 8938	 18.68347	 31.239671	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 8938	 -0.006984	 0.380578	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	9100	 1177	 19.27748	 29.774787	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	5717	 1177	 19.64132	 29.142564	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 1177	 -0.0075	 0.354442	 0.0	 90	 90	 90	 1.0	 0.0	 1	 -30.0	 30.0;
	324	 3332	 0.979504	 4.164463	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	5862	 3332	 0.241095	 2.041488	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	4052	 3332	 0.239525	 2.084091	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	324	 6130	 0.733492	 3.60186	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	5862	 6130	 0.176539	 1.602479	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	4052	 6130	 0.203141	 1.572934	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 8022	 3.658471	 11.068596	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 8022	 0.10706	 1.950682	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 8022	 10.14339	 24.185954	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 8022	 0.07038	 1.132707	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 8022	 3.802686	 12.010955	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 8022	 3.583058	 17.321278	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 260	 2.938636	 13.075416	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 260	 0.00024	 2.372521	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 260	 9.23781	 30.750004	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 260	 0.041469	 1.048347	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 260	 3.576446	 11.947316	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 260	 4.138017	 18.151449	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	324	 2743	 0.107147	 0.58482	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	324	 1258	 7.159972	 13.527699	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	324	 4085	 1.77874	 5.115028	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 5909	 7.195455	 16.568181	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 5909	 40.97313	 63.811984	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 2828	 7.423554	 18.762807	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 2828	 42.39256	 65.737609	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 242	 -0.016674	 0.278698	 0.0	 114	 114	 114	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 1067	 5.349861	 16.166202	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 3533	 9.134349	 25.279081	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 4789	 0.197001	 1.168768	 0.0	 27	 27	 27	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 7592	 0.18955	 1.05277	 0.0	 30	 30	 30	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 5440	 6.030263	 16.006928	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 2605	 5.975346	 16.528394	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 6421	 3.107895	 9.123269	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 1581	 11.81025	 37.443907	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 1085	 27.31856	 49.591408	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	63	 3913	 34.37812	 55.136426	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 242	 0.231281	 1.502872	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 242	 7.048967	 19.24607	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 242	 0.229277	 1.235537	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 242	 2.544835	 7.532231	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 5596	 35.47521	 51.481403	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 4099	 34.64256	 52.336781	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	4647	 4350	 15.75277	 20.093496	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	6538	 1944	 0.000283	 0.012832	 0.0	 790.0	 2462	 2462	 1.031067	 0.0	 1	 -30.0	 30.0;
	8333	 1962	 0.000292	 0.01188	 0.0	 790.0	 2659	 2659	 1.031067	 0.0	 1	 -30.0	 30.0;
	7135	 629	 0.000398	 0.034511	 0.0	 691.0	 916	 916	 0.982076	 0.0	 1	 -30.0	 30.0;
	8336	 629	 33.09298	 47.6281	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 3423	 34.44215	 47.623971	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 1067	 0.161039	 2.815236	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 3533	 9.489612	 27.308865	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 4789	 0.246808	 1.61939	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 7592	 0.228082	 1.521121	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 5440	 18.28047	 42.772855	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 2605	 18.10111	 44.135045	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 6421	 0.331281	 2.194459	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 1581	 0.752078	 9.020083	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 1085	 4.985803	 12.659968	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 3913	 5.581648	 14.030467	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	6485	 4424	 0.000476	 0.03161	 0.0	 724.0	 1000	 1000	 0.957287	 0.0	 1	 -30.0	 30.0;
	6485	 7189	 0.000457	 0.030901	 0.0	 724.0	 1023	 1023	 0.957287	 0.0	 1	 -30.0	 30.0;
	7082	 8182	 1.305041	 5.872521	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 8182	 12.81343	 30.764465	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 6718	 0.657355	 3.229132	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 6718	 6.467975	 16.903509	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 4702	 -0.017839	 0.427271	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 7500	 -0.020298	 0.420457	 0.0	 76	 76	 76	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 3533	 0.05596	 1.32043	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 5440	 0.430997	 2.378602	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 2605	 0.443573	 2.357341	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 1971	 0.073677	 2.231025	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 1581	 0.927909	 4.907895	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 6655	 42.82895	 57.943891	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 6307	 36.44598	 52.531845	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	4849	 7500	 0.00037	 0.03817	 0.0	 724.0	 828	 828	 0.982076	 0.0	 1	 -30.0	 30.0;
	4849	 4702	 0.000309	 0.035711	 0.0	 724.0	 885	 885	 0.982076	 0.0	 1	 -30.0	 30.0;
	1268	 4702	 0.529731	 3.305372	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 7500	 0.54188	 3.249793	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 1067	 -0.008017	 0.233843	 0.0	 135	 135	 135	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 3533	 5.680748	 16.603181	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 4789	 6.552285	 16.597649	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 7592	 5.444182	 17.322713	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 5440	 24.32756	 59.210516	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 2605	 24.09903	 61.117023	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 6421	 5.625068	 20.064407	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 1581	 0.456198	 4.138435	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 6655	 11.52632	 21.784622	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 6307	 10.14543	 18.959839	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 1067	 0.000476	 0.031631	 0.0	 889.0	 999	 999	 0.969682	 0.0	 1	 -30.0	 30.0;
	2724	 1067	 5.521694	 14.730582	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 1067	 19.34525	 41.508264	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 3533	 32.73967	 68.105374	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 3533	 -0.083244	 0.946591	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	4535	 4789	 0.000447	 0.035271	 0.0	 724.0	 896	 896	 0.957287	 0.0	 1	 -30.0	 30.0;
	2724	 4789	 -0.015103	 0.337521	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 7592	 -0.012686	 0.286488	 0.0	 111	 111	 111	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 5440	 27.97992	 45.335871	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 2605	 28.86773	 44.978518	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 6421	 0.994044	 4.152008	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 1581	 19.05609	 41.630194	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 1085	 11.95776	 23.687676	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 3913	 11.73892	 30.398893	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 4789	 10.39773	 25.376037	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 7592	 9.457438	 23.791321	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 5440	 0.000409	 0.036341	 0.0	 724.0	 870	 870	 0.907709	 0.0	 1	 -30.0	 30.0;
	1268	 5440	 -0.006942	 0.494855	 0.0	 64	 64	 64	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 2605	 -0.008161	 0.491033	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 1971	 4.701801	 16.907201	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 1581	 0.18313	 2.973269	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 6655	 30.6392	 44.945983	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	1268	 6307	 27.01524	 39.081706	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 5142	 0.000757	 0.064121	 0.0	 493	 493	 493	 1.042007	 0.0	 1	 -30.0	 30.0;
	5862	 1258	 2.158264	 7.671693	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	4052	 1258	 2.128512	 7.829339	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	5862	 4085	 0.536593	 2.637604	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	4052	 4085	 0.529487	 2.445638	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	7483	 6978	 0.00039	 0.018483	 0.0	 856.0	 1709	 1709	 0.945981	 -0.090668	 1	 -30.0	 30.0;
	7483	 4350	 0.856787	 2.082133	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	8193	 2196	 0.000515	 0.03175	 0.0	 691.0	 995	 995	 1.002506	 0.0	 1	 -30.0	 30.0;
	8193	 2196	 0.000408	 0.036729	 0.0	 691.0	 860	 860	 0.988471	 0.0	 1	 -30.0	 30.0;
	7650	 3606	 0.00648	 0.148407	 0.0	 213	 213	 213	 1.0	 0.0	 1	 -30.0	 30.0;
	2532	 3606	 0.00055	 0.038349	 0.0	 824	 824	 824	 0.977825	 0.0	 1	 -30.0	 30.0;
	1663	 2883	 0.114331	 0.894649	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	7966	 2883	 3.931818	 5.960743	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	5100	 2883	 1.022872	 2.477479	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	1588	 2883	 1.145744	 2.668595	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	2890	 2883	 0.115521	 0.652645	 0.0	 48	 48	 48	 1.0	 0.0	 1	 -30.0	 30.0;
	1663	 6197	 0.342335	 1.036053	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	6605	 7815	 0.08144	 0.487603	 0.0	 64	 64	 64	 1.0	 0.0	 1	 -30.0	 30.0;
	8855	 56	 0.492025	 1.533306	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	2420	 5088	 0.00079	 0.058401	 0.0	 541	 541	 541	 1.0	 0.0	 1	 -30.0	 30.0;
	2420	 5088	 0.00077	 0.05951	 0.0	 531	 531	 531	 1.0	 0.0	 1	 -30.0	 30.0;
	1663	 3944	 0.000209	 0.016646	 0.0	 1185.0	 1898	 1898	 0.947763	 0.0	 1	 -30.0	 30.0;
	1663	 397	 -0.020062	 0.263393	 0.0	 120	 120	 120	 1.0	 0.0	 1	 -30.0	 30.0;
	1663	 4971	 0.02611	 0.389661	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	1663	 1120	 0.02953	 0.274197	 0.0	 115	 115	 115	 1.0	 0.0	 1	 -30.0	 30.0;
	1663	 397	 0.000249	 0.015313	 0.0	 1185.0	 2063	 2063	 0.975409	 0.0	 1	 -30.0	 30.0;
	4637	 1675	 0.01135	 0.389938	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	4637	 3539	 0.03467	 0.4241	 0.0	 75	 75	 75	 1.0	 0.0	 1	 -30.0	 30.0;
	8855	 1624	 0.000159	 0.018964	 0.0	 1185.0	 1666	 1666	 0.962403	 0.0	 1	 -30.0	 30.0;
	8855	 1624	 -0.01126	 0.214855	 0.0	 147	 147	 147	 1.0	 0.0	 1	 -30.0	 30.0;
	8855	 7127	 0.20036	 1.026385	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	8855	 9165	 0.117071	 0.511302	 0.0	 61	 61	 61	 1.0	 0.0	 1	 -30.0	 30.0;
	3835	 417	 0.093303	 0.945014	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	4366	 417	 0.01297	 0.327971	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	2385	 417	 0.05929	 0.601787	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	6605	 5325	 0.05013	 0.919979	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	6605	 4167	 0.0477	 0.865888	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	7966	 3537	 0.749308	 2.45464	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	7966	 5869	 2.902839	 5.007549	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	2906	 1675	 0.03282	 0.444566	 0.0	 71	 71	 71	 1.0	 0.0	 1	 -30.0	 30.0;
	7920	 417	 0.186479	 0.852913	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	2080	 417	 0.185979	 0.818905	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	7424	 417	 1.207107	 3.026033	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	6193	 417	 0.414669	 1.672355	 0.0	 19	 19	 19	 1.0	 0.0	 1	 -30.0	 30.0;
	5100	 3537	 0.129612	 0.934834	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	5100	 5869	 0.796053	 2.21392	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	1588	 3537	 0.136461	 1.06849	 0.0	 30	 30	 30	 1.0	 0.0	 1	 -30.0	 30.0;
	1588	 5869	 0.838366	 2.528809	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	7617	 1346	 0.000298	 0.029295	 0.0	 790.0	 1079	 1079	 1.085859	 -0.169703	 1	 -30.0	 30.0;
	4634	 5622	 0.01604	 0.374051	 0.0	 85	 85	 85	 1.0	 0.0	 1	 -30.0	 30.0;
	2138	 5622	 0.01635	 0.36626	 0.0	 87	 87	 87	 1.0	 0.0	 1	 -30.0	 30.0;
	2906	 5622	 0.024141	 0.327376	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	6274	 5622	 0.02194	 0.458409	 0.0	 69	 69	 69	 1.0	 0.0	 1	 -30.0	 30.0;
	1994	 8916	 0.00046	 0.03512	 0.0	 724.0	 900	 900	 1.01926	 0.0	 1	 -30.0	 30.0;
	1994	 6586	 0.000328	 0.017373	 0.0	 790.0	 1818	 1818	 1.016586	 0.0	 1	 -30.0	 30.0;
	2906	 3539	 0.00056	 0.05575	 0.0	 567	 567	 567	 1.0	 0.0	 1	 -30.0	 30.0;
	6605	 2663	 0.09537	 0.774091	 0.0	 41	 41	 41	 1.0	 0.0	 1	 -30.0	 30.0;
	6605	 4804	 0.325393	 1.201922	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	6605	 7602	 0.367459	 1.167149	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	6274	 2901	 0.0008	 0.04856	 0.0	 651	 651	 651	 1.0	 0.0	 1	 -30.0	 30.0;
	7914	 1627	 0.00033	 0.038031	 0.0	 724.0	 831	 831	 1.027774	 0.0	 1	 -30.0	 30.0;
	7914	 1627	 0.00034	 0.037211	 0.0	 724.0	 849	 849	 1.027774	 0.0	 1	 -30.0	 30.0;
	2890	 3537	 -0.016405	 0.249504	 0.0	 127	 127	 127	 1.0	 0.0	 1	 -30.0	 30.0;
	2890	 5869	 0.087209	 0.621302	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	8725	 5433	 0.15538	 0.761901	 0.0	 41	 41	 41	 1.0	 0.0	 1	 -30.0	 30.0;
	6965	 5433	 0.15969	 0.749463	 0.0	 42	 42	 42	 1.0	 0.0	 1	 -30.0	 30.0;
	6906	 5433	 1.428926	 3.608884	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	5754	 5433	 0.861797	 2.342768	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	6227	 2903	 0.119958	 0.657978	 0.0	 48	 48	 48	 1.0	 0.0	 1	 -30.0	 30.0;
	3784	 6418	 0.172789	 1.348017	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	2409	 6418	 0.00088	 0.381756	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	4578	 6418	 0.0061	 0.418244	 0.0	 76	 76	 76	 1.0	 0.0	 1	 -30.0	 30.0;
	6524	 7097	 0.05995	 0.76688	 0.0	 42	 42	 42	 1.0	 0.0	 1	 -30.0	 30.0;
	5969	 7097	 0.0653	 0.750992	 0.0	 42	 42	 42	 1.0	 0.0	 1	 -30.0	 30.0;
	2429	 7097	 -0.003347	 0.292562	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	3116	 7748	 1.83593	 3.666115	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	9160	 7748	 0.052409	 0.497211	 0.0	 64	 64	 64	 1.0	 0.0	 1	 -30.0	 30.0;
	1148	 8113	 0.436797	 1.36533	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	7116	 8113	 0.094151	 0.896736	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	1400	 7609	 0.00721	 0.237881	 0.0	 133	 133	 133	 1.0	 0.0	 1	 -30.0	 30.0;
	1400	 4793	 0.140762	 0.856856	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	8187	 7609	 0.05419	 0.633158	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	8187	 4793	 0.0291	 0.36903	 0.0	 86	 86	 86	 1.0	 0.0	 1	 -30.0	 30.0;
	3149	 2903	 0.143641	 0.91531	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	1214	 2903	 0.025969	 0.445888	 0.0	 71	 71	 71	 1.0	 0.0	 1	 -30.0	 30.0;
	1253	 2903	 0.270372	 0.785723	 0.0	 39	 39	 39	 1.0	 0.0	 1	 -30.0	 30.0;
	5528	 2903	 0.05175	 0.49312	 0.0	 64	 64	 64	 1.0	 0.0	 1	 -30.0	 30.0;
	4786	 2903	 0.08601	 0.600496	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	6027	 2903	 0.531591	 1.712665	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	4294	 2903	 0.43593	 1.756797	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	5380	 4151	 0.01926	 0.358289	 0.0	 89	 89	 89	 1.0	 0.0	 1	 -30.0	 30.0;
	7399	 3905	 0.01795	 0.317397	 0.0	 100	 100	 100	 1.0	 0.0	 1	 -30.0	 30.0;
	3784	 158	 0.00761	 0.279277	 0.0	 114	 114	 114	 1.0	 0.0	 1	 -30.0	 30.0;
	2409	 158	 0.260062	 1.120476	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	4578	 158	 0.158651	 0.983822	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	3784	 4593	 0.00395	 0.366116	 0.0	 87	 87	 87	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 4593	 0.083409	 0.606219	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	2409	 4593	 0.195669	 1.120144	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	4578	 4593	 0.104969	 1.02188	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	3160	 4593	 0.042831	 0.74374	 0.0	 43	 43	 43	 1.0	 0.0	 1	 -30.0	 30.0;
	3116	 8216	 0.000242	 0.032753	 0.0	 965	 965	 965	 1.062286	 -0.114968	 1	 -30.0	 30.0;
	3116	 5779	 -0.003203	 0.14994	 0.0	 211	 211	 211	 1.0	 0.0	 1	 -30.0	 30.0;
	3116	 5779	 0.000451	 0.034969	 0.0	 724.0	 904	 904	 1.031654	 0.0	 1	 -30.0	 30.0;
	3116	 6997	 0.113213	 0.498338	 0.0	 62	 62	 62	 1.0	 0.0	 1	 -30.0	 30.0;
	6470	 4466	 0.00055	 0.0343	 0.0	 724.0	 921	 921	 0.964912	 0.0	 1	 -30.0	 30.0;
	6965	 8955	 0.000264	 0.015752	 0.0	 1185.0	 2006	 2006	 1.002506	 0.0	 1	 -30.0	 30.0;
	8725	 3934	 0.01862	 0.220201	 0.0	 143	 143	 143	 1.0	 0.0	 1	 -30.0	 30.0;
	6965	 3934	 0.0168	 0.250561	 0.0	 126	 126	 126	 1.0	 0.0	 1	 -30.0	 30.0;
	1148	 4793	 0.202902	 0.952701	 0.0	 33	 33	 33	 1.0	 0.0	 1	 -30.0	 30.0;
	1148	 8798	 0.949862	 3.139543	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	1148	 1657	 0.00261	 0.215422	 0.0	 147	 147	 147	 1.0	 0.0	 1	 -30.0	 30.0;
	7444	 4154	 -0.02155	 0.439897	 0.0	 72	 72	 72	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 4154	 0.07045	 1.003492	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	7444	 8638	 0.00807	 0.465263	 0.0	 68	 68	 68	 1.0	 0.0	 1	 -30.0	 30.0;
	7444	 6336	 0.194723	 1.065305	 0.0	 30	 30	 30	 1.0	 0.0	 1	 -30.0	 30.0;
	7444	 3479	 0.7241	 1.639128	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	7444	 5232	 0.514127	 1.973476	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	7444	 8699	 0.06643	 0.866482	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	7444	 3777	 0.55937	 2.088574	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	7444	 5261	 0.522202	 2.029502	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	7444	 7620	 0.30876	 1.923338	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	3225	 7451	 0.06357	 0.598203	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	4121	 7451	 0.000445	 0.035961	 0.0	 724.0	 879	 879	 0.941156	 0.0	 1	 -30.0	 30.0;
	6589	 7451	 0.01179	 0.332211	 0.0	 96	 96	 96	 1.0	 0.0	 1	 -30.0	 30.0;
	798	 7451	 0.02131	 0.372955	 0.0	 85	 85	 85	 1.0	 0.0	 1	 -30.0	 30.0;
	4500	 7451	 0.00274	 0.381756	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	6906	 3934	 0.293141	 1.107872	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	5754	 3934	 0.144281	 0.82905	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	2486	 2443	 0.00458	 0.288905	 0.0	 110	 110	 110	 1.0	 0.0	 1	 -30.0	 30.0;
	8427	 309	 0.365888	 1.746611	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	2176	 309	 1.44438	 5.252272	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	1823	 309	 0.059581	 0.615888	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	3583	 309	 3.709298	 8.934297	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	6864	 309	 0.140919	 0.944236	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	6413	 167	 0.0005	 0.0343	 0.0	 724.0	 921	 921	 0.893644	 0.0	 1	 -30.0	 30.0;
	9160	 167	 0.01962	 0.216178	 0.0	 146	 146	 146	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 8638	 0.398678	 1.516364	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 886	 0.09755	 0.839897	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	3160	 886	 0.499525	 2.142562	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	1323	 4151	 0.01537	 0.348347	 0.0	 91	 91	 91	 1.0	 0.0	 1	 -30.0	 30.0;
	3655	 4151	 0.01946	 0.372727	 0.0	 85	 85	 85	 1.0	 0.0	 1	 -30.0	 30.0;
	6589	 6321	 0.01679	 0.350455	 0.0	 91	 91	 91	 1.0	 0.0	 1	 -30.0	 30.0;
	798	 6321	 0.0005	 0.324174	 0.0	 98	 98	 98	 1.0	 0.0	 1	 -30.0	 30.0;
	4500	 6321	 0.049469	 0.557004	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	1214	 5896	 0.0005	 0.031271	 0.0	 1010	 1010	 1010	 1.0	 0.0	 1	 -30.0	 30.0;
	8427	 5896	 0.422748	 2.328099	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	2176	 5896	 1.022934	 4.279959	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	1823	 5896	 0.256612	 1.738141	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	3583	 5896	 2.300207	 9.353099	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	6864	 5896	 0.0157	 0.997789	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 7997	 0.022021	 0.625496	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	3160	 7997	 0.223988	 1.463946	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	8427	 6120	 -0.037934	 0.385868	 0.0	 82	 82	 82	 1.0	 0.0	 1	 -30.0	 30.0;
	2176	 6120	 2.334711	 7.437397	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	1823	 6120	 0.137849	 1.103905	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	3583	 6120	 5.726446	 13.392563	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	6864	 6120	 0.183531	 1.402418	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	8687	 8427	 3.1e-05	 0.002125	 0.0	 14864	 14864	 14864	 0.999938	 0.011109	 1	 -30.0	 30.0;
	8427	 5152	 2.374861	 8.881579	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	8427	 8134	 0.158643	 1.604501	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	8427	 8123	 0.204162	 1.92777	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	8427	 8451	 0.169439	 2.010873	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	2176	 5152	 -0.011343	 0.25657	 0.0	 123	 123	 123	 1.0	 0.0	 1	 -30.0	 30.0;
	2176	 5152	 0.000423	 0.033381	 0.0	 757.0	 947	 947	 0.944892	 0.0	 1	 -30.0	 30.0;
	1823	 5152	 6.533884	 12.310123	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	3583	 5152	 0.04751	 0.576054	 0.0	 55	 55	 55	 1.0	 0.0	 1	 -30.0	 30.0;
	6864	 5152	 0.21343	 1.602582	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	2176	 8134	 7.076177	 15.615651	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2176	 8123	 6.591413	 15.880881	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2176	 8451	 0.187507	 2.209903	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	829	 4146	 0.0004	 0.149419	 0.0	 212	 212	 212	 1.0	 0.0	 1	 -30.0	 30.0;
	5754	 4146	 0.027469	 0.320806	 0.0	 99	 99	 99	 1.0	 0.0	 1	 -30.0	 30.0;
	7399	 4146	 0.00659	 0.53155	 0.0	 60	 60	 60	 1.0	 0.0	 1	 -30.0	 30.0;
	4501	 6155	 0.45281	 1.969855	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	9088	 6155	 0.561302	 2.344628	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	8388	 6155	 0.03438	 0.839277	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	7731	 417	 -0.00126	 0.238202	 0.0	 133	 133	 133	 1.0	 0.0	 1	 -30.0	 30.0;
	7731	 417	 0.000426	 0.017209	 0.0	 921.0	 1835	 1835	 1.002506	 0.0	 1	 -30.0	 30.0;
	7731	 129	 0.01628	 0.291863	 0.0	 109	 109	 109	 1.0	 0.0	 1	 -30.0	 30.0;
	6977	 8503	 -0.010145	 0.227045	 0.0	 139	 139	 139	 1.0	 0.0	 1	 -30.0	 30.0;
	4501	 3617	 0.00079	 0.680124	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	9088	 3617	 -6.2e-05	 0.76438	 0.0	 42	 42	 42	 1.0	 0.0	 1	 -30.0	 30.0;
	8388	 3617	 0.288988	 1.328967	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	4501	 296	 0.289174	 0.947893	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	9088	 296	 0.357831	 1.127893	 0.0	 27	 27	 27	 1.0	 0.0	 1	 -30.0	 30.0;
	8388	 296	 0.00434	 0.222459	 0.0	 142	 142	 142	 1.0	 0.0	 1	 -30.0	 30.0;
	9080	 8059	 0.162281	 0.824401	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	1765	 8059	 0.510455	 1.73717	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	624	 8059	 0.218822	 1.471838	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	1485	 8059	 0.029581	 0.641756	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	4718	 8059	 0.269194	 1.398492	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	798	 6886	 0.01824	 0.407147	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	798	 7161	 0.01992	 0.388733	 0.0	 82	 82	 82	 1.0	 0.0	 1	 -30.0	 30.0;
	6977	 1949	 0.504669	 1.26314	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	584	 5530	 0.180042	 0.913089	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	584	 2223	 0.28705	 1.359279	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	9154	 4522	 0.02939	 0.690041	 0.0	 46	 46	 46	 1.0	 0.0	 1	 -30.0	 30.0;
	7942	 4522	 0.106211	 0.857975	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	9154	 1707	 0.03057	 0.640372	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	7942	 1707	 0.11774	 0.83438	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	1823	 8123	 0.000416	 0.031501	 0.0	 724.0	 1003	 1003	 0.969682	 0.0	 1	 -30.0	 30.0;
	1823	 8134	 -0.02392	 0.308892	 0.0	 102	 102	 102	 1.0	 0.0	 1	 -30.0	 30.0;
	1823	 8123	 -0.021129	 0.40847	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	1823	 8451	 0.801524	 3.248477	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	3583	 8134	 15.18223	 29.541321	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6864	 8134	 0.810744	 3.364049	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	3583	 8123	 13.91921	 30.6467	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6864	 8123	 0.716322	 3.154132	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	7399	 540	 0.00489	 0.406095	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	9080	 5958	 0.447909	 1.098823	 0.0	 27	 27	 27	 1.0	 0.0	 1	 -30.0	 30.0;
	9080	 6603	 0.01056	 0.353927	 0.0	 90	 90	 90	 1.0	 0.0	 1	 -30.0	 30.0;
	9080	 1690	 0.7509	 1.841551	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	1765	 5958	 0.375789	 0.752493	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	1765	 6603	 0.190388	 1.261149	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	1765	 1690	 0.05324	 0.584501	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	5116	 5530	 0.01773	 0.615173	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	5116	 6981	 0.01987	 0.600173	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	2260	 5530	 0.466918	 1.296815	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	2260	 2223	 0.815443	 1.930956	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	4501	 4268	 0.02061	 0.308595	 0.0	 103	 103	 103	 1.0	 0.0	 1	 -30.0	 30.0;
	9088	 4268	 0.02549	 0.367231	 0.0	 86	 86	 86	 1.0	 0.0	 1	 -30.0	 30.0;
	8388	 4268	 0.00824	 0.278492	 0.0	 114	 114	 114	 1.0	 0.0	 1	 -30.0	 30.0;
	3583	 8451	 0.71662	 3.572645	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	3225	 3261	 0.045599	 0.50595	 0.0	 63	 63	 63	 1.0	 0.0	 1	 -30.0	 30.0;
	9154	 683	 0.00887	 0.706717	 0.0	 45	 45	 45	 1.0	 0.0	 1	 -30.0	 30.0;
	9154	 7360	 0.04089	 0.90831	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	9154	 4557	 0.04322	 0.911288	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	330	 5530	 0.032849	 0.6625	 0.0	 48	 48	 48	 1.0	 0.0	 1	 -30.0	 30.0;
	7781	 5530	 0.03726	 0.637562	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	873	 5530	 0.074341	 0.632975	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	6343	 5530	 0.07781	 0.62157	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	624	 5958	 0.534411	 1.302908	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	624	 6603	 0.02355	 0.61356	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	624	 1690	 0.420249	 1.970499	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	1485	 5958	 0.229855	 0.963099	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	4718	 5958	 0.074669	 0.41343	 0.0	 76	 76	 76	 1.0	 0.0	 1	 -30.0	 30.0;
	6977	 822	 0.06182	 0.403213	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	6864	 8451	 -0.029256	 0.40562	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 6336	 0.0033	 0.455227	 0.0	 70	 70	 70	 1.0	 0.0	 1	 -30.0	 30.0;
	3225	 6336	 0.00124	 0.284731	 0.0	 111	 111	 111	 1.0	 0.0	 1	 -30.0	 30.0;
	79	 6886	 0.04584	 0.400152	 0.0	 79	 79	 79	 1.0	 0.0	 1	 -30.0	 30.0;
	79	 7161	 0.03961	 0.441877	 0.0	 72	 72	 72	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 2610	 0.282149	 1.82343	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	3160	 2610	 -0.001467	 0.288285	 0.0	 110	 110	 110	 1.0	 0.0	 1	 -30.0	 30.0;
	8759	 3479	 0.000203	 0.019723	 0.0	 1185.0	 1602	 1602	 1.023144	 -0.036838	 1	 -30.0	 30.0;
	6083	 3479	 3.246901	 6.102273	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	5491	 5673	 0.000187	 0.025917	 0.0	 1185.0	 1219	 1219	 0.945816	 -0.090914	 1	 -30.0	 30.0;
	5491	 5673	 0.000198	 0.025388	 0.0	 1185.0	 1245	 1245	 0.945816	 -0.090914	 1	 -30.0	 30.0;
	5914	 5673	 0.046659	 0.29938	 0.0	 105	 105	 105	 1.0	 0.0	 1	 -30.0	 30.0;
	6524	 8516	 0.02508	 0.489778	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	6524	 7655	 0.0359	 0.39268	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	5969	 8516	 0.01931	 0.550478	 0.0	 58	 58	 58	 1.0	 0.0	 1	 -30.0	 30.0;
	5969	 7655	 0.0365	 0.48437	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	1485	 6603	 -0.015393	 0.242665	 0.0	 130	 130	 130	 1.0	 0.0	 1	 -30.0	 30.0;
	1485	 6603	 0.00024	 0.016571	 0.0	 1185.0	 1906	 1906	 0.988772	 0.0	 1	 -30.0	 30.0;
	4718	 6603	 0.778884	 2.360744	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	1485	 1690	 0.834349	 2.163366	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	2429	 8516	 0.02768	 0.486653	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	2429	 8516	 0.0005	 0.0343	 0.0	 724.0	 921	 921	 1.012424	 0.0	 1	 -30.0	 30.0;
	2429	 7655	 0.170748	 0.871399	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 5232	 3.440496	 6.966735	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 8699	 -0.025	 0.350744	 0.0	 90	 90	 90	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 3777	 3.294252	 7.269391	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 5261	 3.075277	 7.063712	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 7620	 2.188573	 6.820568	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	5914	 2223	 0.03254	 0.295443	 0.0	 107	 107	 107	 1.0	 0.0	 1	 -30.0	 30.0;
	3160	 8552	 0.000216	 0.016549	 0.0	 1185.0	 1909	 1909	 1.016627	 0.0	 1	 -30.0	 30.0;
	7116	 4793	 0.00914	 0.394959	 0.0	 80	 80	 80	 1.0	 0.0	 1	 -30.0	 30.0;
	7942	 683	 0.11943	 0.839463	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	7399	 683	 0.02832	 0.560682	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	7399	 3854	 0.025289	 0.560351	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	7116	 8798	 0.203901	 1.623181	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	6164	 8033	 0.000184	 0.018745	 0.0	 1185.0	 1686	 1686	 1.023144	 -0.036838	 1	 -30.0	 30.0;
	4500	 6886	 0.0086	 0.46804	 0.0	 68	 68	 68	 1.0	 0.0	 1	 -30.0	 30.0;
	4500	 7161	 0.00772	 0.464148	 0.0	 69	 69	 69	 1.0	 0.0	 1	 -30.0	 30.0;
	9160	 8639	 0.08261	 0.429463	 0.0	 73	 73	 73	 1.0	 0.0	 1	 -30.0	 30.0;
	9160	 5580	 0.09332	 0.419277	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	330	 6981	 0.06593	 0.705471	 0.0	 45	 45	 45	 1.0	 0.0	 1	 -30.0	 30.0;
	7781	 6981	 0.070298	 0.687417	 0.0	 46	 46	 46	 1.0	 0.0	 1	 -30.0	 30.0;
	8899	 1508	 0.000348	 0.017003	 0.0	 790.0	 1858	 1858	 0.967332	 -0.0579	 1	 -30.0	 30.0;
	9160	 5324	 0.000239	 0.015483	 0.0	 1185.0	 2040	 2040	 0.988494	 -0.023724	 1	 -30.0	 30.0;
	7942	 7360	 0.0275	 0.64187	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	7942	 4557	 0.02423	 0.621711	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	7116	 1657	 0.021711	 0.411839	 0.0	 77	 77	 77	 1.0	 0.0	 1	 -30.0	 30.0;
	7116	 1657	 0.000216	 0.018022	 0.0	 1185.0	 1753	 1753	 1.002506	 0.0	 1	 -30.0	 30.0;
	7116	 8778	 0.000173	 0.017112	 0.0	 1185.0	 1846	 1846	 1.016627	 0.0	 1	 -30.0	 30.0;
	7803	 7620	 0.000179	 0.017308	 0.0	 1185.0	 1825	 1825	 1.016325	 -0.024392	 1	 -30.0	 30.0;
	7803	 7620	 0.000209	 0.016741	 0.0	 1185.0	 1887	 1887	 1.016325	 -0.024392	 1	 -30.0	 30.0;
	4718	 1690	 -0.024793	 0.19232	 0.0	 163	 163	 163	 1.0	 0.0	 1	 -30.0	 30.0;
	4501	 1497	 0.000274	 0.016144	 0.0	 1185.0	 1957	 1957	 1.016325	 -0.024392	 1	 -30.0	 30.0;
	8388	 1773	 0.000476	 0.030991	 0.0	 724.0	 1020	 1020	 0.944892	 0.0	 1	 -30.0	 30.0;
	873	 2223	 0.11386	 1.025723	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	6343	 2223	 0.111979	 1.046363	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	6343	 3155	 0.00022	 0.03264	 0.0	 968	 968	 968	 1.062286	 -0.114968	 1	 -30.0	 30.0;
	8779	 8414	 0.383283	 2.185803	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	8779	 6794	 0.497389	 1.835595	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	4670	 7006	 0.000615	 0.029917	 0.0	 1056	 1056	 1056	 1.040949	 0.0	 1	 -30.0	 30.0;
	4670	 7006	 0.000634	 0.029307	 0.0	 1078	 1078	 1078	 1.054426	 0.0	 1	 -30.0	 30.0;
	1900	 8944	 -0.02062	 0.218203	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1900	 2852	 0.20759	 1.109002	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	1900	 439	 0.275429	 1.015166	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	1900	 484	 1.042036	 2.256095	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	511	 8944	 0.10976	 0.74593	 0.0	 42	 42	 42	 1.0	 0.0	 1	 -30.0	 30.0;
	3396	 8944	 0.287831	 1.163678	 0.0	 27	 27	 27	 1.0	 0.0	 1	 -30.0	 30.0;
	7799	 8198	 0.07	 0.46124	 0.0	 68	 68	 68	 1.0	 0.0	 1	 -30.0	 30.0;
	6956	 8198	 0.068479	 0.427066	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	7680	 6621	 0.103857	 0.477763	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	7680	 4122	 1.274515	 2.49626	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	6466	 6621	 0.107943	 0.458262	 0.0	 68	 68	 68	 1.0	 0.0	 1	 -30.0	 30.0;
	6466	 4122	 1.323546	 2.392243	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	8256	 8414	 0.209487	 1.002909	 0.0	 48	 48	 48	 1.0	 0.0	 1	 -30.0	 30.0;
	8256	 6794	 0.126607	 0.574751	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	2192	 4218	 0.00044	 0.03688	 0.0	 757.0	 857	 857	 1.002506	 0.0	 1	 -30.0	 30.0;
	2192	 2418	 0.01559	 0.151898	 0.0	 207	 207	 207	 1.0	 0.0	 1	 -30.0	 30.0;
	6900	 2736	 0.20449	 0.679959	 0.0	 45	 45	 45	 1.0	 0.0	 1	 -30.0	 30.0;
	6458	 2852	 0.105249	 0.487299	 0.0	 64	 64	 64	 1.0	 0.0	 1	 -30.0	 30.0;
	511	 2852	 0.000246	 0.030366	 0.0	 954.0	 1041	 1041	 1.015668	 -0.130098	 1	 -30.0	 30.0;
	511	 2852	 -0.01905	 0.247025	 0.0	 128	 128	 128	 1.0	 0.0	 1	 -30.0	 30.0;
	511	 439	 1.418837	 2.394528	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	511	 484	 0.205332	 0.854986	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	8415	 2852	 1.852727	 2.747521	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	3396	 2852	 1.359979	 2.972315	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	3396	 439	 0.02269	 0.199771	 0.0	 158	 158	 158	 1.0	 0.0	 1	 -30.0	 30.0;
	6900	 3759	 0.00688	 0.14088	 0.0	 224	 224	 224	 1.0	 0.0	 1	 -30.0	 30.0;
	7934	 6621	 0.00021	 0.022916	 0.0	 954.0	 1379	 1379	 0.976337	 -0.045364	 1	 -30.0	 30.0;
	7934	 6621	 0.00021	 0.021219	 0.0	 954.0	 1489	 1489	 0.976337	 -0.045364	 1	 -30.0	 30.0;
	1601	 193	 0.021781	 0.193349	 0.0	 163	 163	 163	 1.0	 0.0	 1	 -30.0	 30.0;
	3396	 484	 0.037729	 0.222665	 0.0	 140	 140	 140	 1.0	 0.0	 1	 -30.0	 30.0;
	5986	 2418	 0.05599	 0.311752	 0.0	 153	 153	 153	 1.0	 0.0	 1	 -30.0	 30.0;
	4732	 5584	 0.000687	 0.037873	 0.0	 834	 834	 834	 1.027812	 0.0	 1	 -30.0	 30.0;
	2932	 5584	 0.000697	 0.03705	 0.0	 853	 853	 853	 1.027812	 0.0	 1	 -30.0	 30.0;
	1601	 5880	 0.000258	 0.015179	 0.0	 954.0	 2081	 2081	 1.031474	 0.0	 1	 -30.0	 30.0;
	1601	 5880	 -0.008698	 0.24938	 0.0	 127	 127	 127	 1.0	 0.0	 1	 -30.0	 30.0;
	1601	 5880	 0.000218	 0.015068	 0.0	 954.0	 2097	 2097	 1.031407	 0.0	 1	 -30.0	 30.0;
	7799	 5880	 0.055651	 0.515413	 0.0	 61	 61	 61	 1.0	 0.0	 1	 -30.0	 30.0;
	6956	 5880	 0.05444	 0.477231	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	6900	 3189	 0.153248	 0.626697	 0.0	 49	 49	 49	 1.0	 0.0	 1	 -30.0	 30.0;
	3057	 7741	 -0.003823	 0.150277	 0.0	 321	 321	 321	 1.0	 0.0	 1	 -30.0	 30.0;
	3057	 7741	 0.00069	 0.03981	 0.0	 1211	 1211	 1211	 1.125914	 0.0	 1	 -30.0	 30.0;
	197	 7741	 0.056219	 0.23343	 0.0	 132	 132	 132	 1.0	 0.0	 1	 -30.0	 30.0;
	2309	 8414	 0.000243	 0.015553	 0.0	 954.0	 3099	 3099	 0.946281	 -0.010988	 1	 -30.0	 30.0;
	2309	 8414	 -0.011591	 0.366818	 0.0	 132	 132	 132	 1.0	 0.0	 1	 -30.0	 30.0;
	2309	 6794	 0.145519	 0.713643	 0.0	 44	 44	 44	 1.0	 0.0	 1	 -30.0	 30.0;
	503	 8414	 0.000231	 0.01967	 0.0	 954.0	 2451	 2451	 0.993682	 0.080858	 1	 -30.0	 30.0;
	503	 8414	 -0.010888	 0.388409	 0.0	 125	 125	 125	 1.0	 0.0	 1	 -30.0	 30.0;
	503	 6794	 0.157909	 0.659799	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	6457	 7514	 0.00297	 0.141711	 0.0	 223	 223	 223	 1.0	 0.0	 1	 -30.0	 30.0;
	4498	 3189	 0.000245	 0.011573	 0.0	 954.0	 2729	 2729	 1.060747	 0.0	 1	 -30.0	 30.0;
	4498	 3189	 0.000255	 0.011329	 0.0	 954.0	 2788	 2788	 1.060747	 0.0	 1	 -30.0	 30.0;
	197	 866	 0.000697	 0.027473	 0.0	 1150	 1150	 1150	 1.054426	 0.0	 1	 -30.0	 30.0;
	197	 866	 0.000627	 0.031139	 0.0	 1015	 1015	 1015	 1.054426	 0.0	 1	 -30.0	 30.0;
	7692	 4384	 0.00203	 0.101959	 0.0	 310	 310	 310	 0.900834	 0.0	 1	 -30.0	 30.0;
	7692	 4384	 0.00195	 0.103917	 0.0	 304	 304	 304	 0.900834	 0.0	 1	 -30.0	 30.0;
	7843	 4871	 0.00341	 0.149108	 0.0	 212	 212	 212	 0.978276	 0.039847	 1	 -30.0	 30.0;
	6159	 2530	 0.001812	 0.126988	 0.0	 249	 249	 249	 0.89161	 0.149487	 1	 -30.0	 30.0;
	6159	 2530	 0.001982	 0.124457	 0.0	 254	 254	 254	 0.89161	 0.149487	 1	 -30.0	 30.0;
	4569	 5702	 0.00153	 0.094124	 0.0	 336	 336	 336	 0.939166	 0.0	 1	 -30.0	 30.0;
	4569	 5702	 0.00156	 0.092157	 0.0	 343	 343	 343	 0.939166	 0.0	 1	 -30.0	 30.0;
	2175	 4515	 0.00512	 0.156934	 0.0	 202	 202	 202	 1.075001	 0.0	 1	 -30.0	 30.0;
	2175	 3358	 0.00513	 0.153636	 0.0	 206	 206	 206	 1.03	 0.0	 1	 -30.0	 30.0;
	7876	 5794	 0.001473	 0.055275	 0.0	 572	 572	 572	 1.001399	 0.0	 1	 -30.0	 30.0;
	5600	 7708	 0.000628	 0.026981	 0.0	 1171	 1171	 1171	 0.982004	 0.0	 1	 -30.0	 30.0;
	6653	 8761	 0.000768	 0.027532	 0.0	 1147	 1147	 1147	 0.982004	 0.0	 1	 -30.0	 30.0;
	1636	 4228	 0.000778	 0.05467	 0.0	 578	 578	 578	 0.963346	 0.0	 1	 -30.0	 30.0;
	1636	 4228	 0.000767	 0.055473	 0.0	 570	 570	 570	 0.963346	 0.0	 1	 -30.0	 30.0;
	1953	 8611	 0.000905	 0.055047	 0.0	 574	 574	 574	 1.001399	 0.0	 1	 -30.0	 30.0;
	7416	 2069	 0.000902	 0.025704	 0.0	 1229	 1229	 1229	 1.021576	 0.0	 1	 -30.0	 30.0;
	7416	 2069	 0.000902	 0.024552	 0.0	 1286	 1286	 1286	 1.021576	 0.0	 1	 -30.0	 30.0;
	5046	 2069	 0.000437	 0.013336	 0.0	 2368	 2368	 2368	 0.975505	 0.0	 1	 -30.0	 30.0;
	285	 8032	 0.001665	 0.048767	 0.0	 648	 648	 648	 1.001399	 0.0	 1	 -30.0	 30.0;
	4217	 2285	 0.00083	 0.05142	 0.0	 615	 615	 615	 1.001399	 0.0	 1	 -30.0	 30.0;
	4217	 2285	 0.000754	 0.045701	 0.0	 692	 692	 692	 1.021576	 0.0	 1	 -30.0	 30.0;
	8206	 7559	 0.000798	 0.052223	 0.0	 605	 605	 605	 0.982004	 0.0	 1	 -30.0	 30.0;
	6492	 1673	 0.000748	 0.052717	 0.0	 600	 600	 600	 0.963346	 0.0	 1	 -30.0	 30.0;
	3525	 222	 0.000435	 0.02158	 0.0	 1464	 1464	 1464	 0.987916	 0.0	 1	 -30.0	 30.0;
	5101	 8201	 0.000871	 0.0262	 0.0	 1205	 1205	 1205	 0.982004	 0.0	 1	 -30.0	 30.0;
	6084	 4601	 0.000881	 0.047183	 0.0	 670	 670	 670	 0.982004	 0.0	 1	 -30.0	 30.0;
	4241	 2248	 0.000214	 0.018189	 0.0	 691.0	 1737	 1737	 0.997518	 0.0	 1	 -30.0	 30.0;
	4717	 5787	 0.000545	 0.028951	 0.0	 1091	 1091	 1091	 1.002304	 0.0	 1	 -30.0	 30.0;
	5425	 7431	 0.000433	 0.016641	 0.0	 691.0	 1898	 1898	 1.052632	 0.0	 1	 -30.0	 30.0;
	5425	 7431	 0.000271	 0.019483	 0.0	 691.0	 1622	 1622	 1.046093	 0.0	 1	 -30.0	 30.0;
	6632	 3650	 0.000292	 0.041885	 0.0	 755	 755	 755	 1.035986	 0.0	 1	 -30.0	 30.0;
	6632	 3650	 0.000283	 0.025435	 0.0	 1242	 1242	 1242	 1.035986	 0.0	 1	 -30.0	 30.0;
	6917	 4958	 0.00019	 0.020772	 0.0	 691.0	 1521	 1521	 1.016388	 0.0	 1	 -30.0	 30.0;
	2962	 8888	 0.000567	 0.0487	 0.0	 649	 649	 649	 1.01961	 0.0	 1	 -30.0	 30.0;
	2962	 8888	 0.000292	 0.024683	 0.0	 1280	 1280	 1280	 1.026095	 0.0	 1	 -30.0	 30.0;
	4542	 7510	 0.000238	 0.020505	 0.0	 691.0	 1541	 1541	 1.016388	 0.0	 1	 -30.0	 30.0;
	4542	 7510	 0.000302	 0.024253	 0.0	 1303	 1303	 1303	 1.016399	 0.0	 1	 -30.0	 30.0;
	1549	 3282	 0.000394	 0.025662	 0.0	 1231	 1231	 1231	 0.997518	 0.0	 1	 -30.0	 30.0;
	1549	 3282	 0.000403	 0.026263	 0.0	 1203	 1203	 1203	 0.997518	 0.0	 1	 -30.0	 30.0;
	1549	 3282	 0.000358	 0.02845	 0.0	 1111	 1111	 1111	 0.997518	 0.0	 1	 -30.0	 30.0;
	1200	 3549	 0.000184	 0.020004	 0.0	 691.0	 1579	 1579	 1.016388	 0.0	 1	 -30.0	 30.0;
	6771	 4806	 0.000287	 0.030676	 0.0	 1030	 1030	 1030	 1.026104	 0.0	 1	 -30.0	 30.0;
	1086	 6443	 0.000183	 0.021447	 0.0	 691.0	 1473	 1473	 0.997518	 0.0	 1	 -30.0	 30.0;
	1086	 6443	 0.000183	 0.019858	 0.0	 691.0	 1591	 1591	 0.997518	 0.0	 1	 -30.0	 30.0;
	9159	 6499	 0.000196	 0.019264	 0.0	 691.0	 1640	 1640	 0.997518	 0.0	 1	 -30.0	 30.0;
	9159	 6499	 0.000205	 0.018521	 0.0	 691.0	 1706	 1706	 0.997518	 0.0	 1	 -30.0	 30.0;
	5685	 3378	 0.000205	 0.018131	 0.0	 691.0	 1743	 1743	 0.997518	 0.0	 1	 -30.0	 30.0;
	693	 6994	 0.000224	 0.01875	 0.0	 691.0	 1685	 1685	 1.035986	 0.0	 1	 -30.0	 30.0;
	693	 6994	 0.000685	 0.016451	 0.0	 691.0	 1919	 1919	 1.032682	 0.0	 1	 -30.0	 30.0;
	5332	 3633	 0.00021	 0.024641	 0.0	 691.0	 1282	 1282	 0.961805	 0.0	 1	 -30.0	 30.0;
	5332	 3633	 0.00021	 0.025112	 0.0	 691.0	 1258	 1258	 0.961805	 0.0	 1	 -30.0	 30.0;
	8034	 4020	 0.0	 0.00554	 0.0	 1514.0	 5702	 5702	 0.0	 0.0	 1	 -30.0	 30.0;
	1985	 1023	 0.0	 0.006182	 0.0	 895.0	 5110	 5110	 0.969385	 0.248079	 1	 -30.0	 30.0;
	477	 6769	 0.000205	 0.016639	 0.0	 691.0	 1899	 1899	 0.997518	 0.0	 1	 -30.0	 30.0;
	477	 6769	 0.000214	 0.017035	 0.0	 691.0	 1855	 1855	 0.997518	 0.0	 1	 -30.0	 30.0;
	477	 6769	 0.000214	 0.016674	 0.0	 691.0	 1895	 1895	 0.997518	 0.0	 1	 -30.0	 30.0;
	2188	 5170	 0.000224	 0.018397	 0.0	 691.0	 1717	 1717	 1.016388	 0.0	 1	 -30.0	 30.0;
	3061	 699	 0.000522	 0.027299	 0.0	 1157	 1157	 1157	 1.006865	 0.0	 1	 -30.0	 30.0;
	3061	 699	 0.000646	 0.037462	 0.0	 844	 844	 844	 0.997538	 0.0	 1	 -30.0	 30.0;
	5823	 7110	 0.000244	 0.033945	 0.0	 931	 931	 931	 1.052632	 0.0	 1	 -30.0	 30.0;
	5823	 7110	 0.000196	 0.023262	 0.0	 691.0	 1358	 1358	 1.035986	 0.0	 1	 -30.0	 30.0;
	5280	 7110	 0.00091	 0.001686	 0.0	 457.0	 16487	 16487	 0.999945	 -0.010479	 1	 -30.0	 30.0;
	1947	 4317	 0.000179	 0.016955	 0.0	 691.0	 1863	 1863	 1.056356	 0.0	 1	 -30.0	 30.0;
	7303	 429	 0.000206	 0.01883	 0.0	 691.0	 1678	 1678	 1.016388	 0.0	 1	 -30.0	 30.0;
	6039	 7973	 0.000233	 0.018474	 0.0	 691.0	 1710	 1710	 1.006865	 0.0	 1	 -30.0	 30.0;
	6039	 7973	 0.000421	 0.031827	 0.0	 993	 993	 993	 1.014604	 0.0	 1	 -30.0	 30.0;
	1060	 8981	 0.000219	 0.016973	 0.0	 691.0	 1861	 1861	 1.026095	 0.0	 1	 -30.0	 30.0;
	8034	 1752	 0.000213	 0.020004	 0.0	 691.0	 1579	 1579	 0.997518	 0.0	 1	 -30.0	 30.0;
	739	 1393	 0.000556	 0.033053	 0.0	 956	 956	 956	 0.998185	 0.0	 1	 -30.0	 30.0;
	2235	 8512	 0.000508	 0.028375	 0.0	 1114	 1114	 1114	 0.998185	 0.0	 1	 -30.0	 30.0;
	3428	 1439	 0.000179	 0.022003	 0.0	 691.0	 1436	 1436	 1.006865	 0.0	 1	 -30.0	 30.0;
	2730	 6127	 0.000209	 0.02019	 0.0	 691.0	 1565	 1565	 0.970491	 0.0	 1	 -30.0	 30.0;
	2730	 6127	 0.000214	 0.020311	 0.0	 691.0	 1556	 1556	 0.970491	 0.0	 1	 -30.0	 30.0;
	7395	 5435	 0.000616	 0.030505	 0.0	 1036	 1036	 1036	 0.991996	 0.0	 1	 -30.0	 30.0;
	7395	 5435	 0.000626	 0.029369	 0.0	 1076	 1076	 1076	 0.991996	 0.0	 1	 -30.0	 30.0;
	2437	 3792	 0.000214	 0.019409	 0.0	 691.0	 1628	 1628	 0.988343	 0.0	 1	 -30.0	 30.0;
	2437	 3792	 0.000192	 0.022	 0.0	 691.0	 1436	 1436	 0.979336	 0.0	 1	 -30.0	 30.0;
	5239	 8438	 0.000531	 0.03466	 0.0	 912	 912	 912	 0.991996	 0.0	 1	 -30.0	 30.0;
	5873	 8147	 0.000531	 0.035228	 0.0	 897	 897	 897	 0.99508	 0.0	 1	 -30.0	 30.0;
	5873	 8147	 0.00049	 0.031535	 0.0	 1002	 1002	 1002	 0.995061	 0.0	 1	 -30.0	 30.0;
	5873	 8147	 0.000209	 0.020964	 0.0	 691.0	 1507	 1507	 0.988343	 0.0	 1	 -30.0	 30.0;
	7508	 1240	 0.000393	 0.02663	 0.0	 1187	 1187	 1187	 1.035986	 0.0	 1	 -30.0	 30.0;
	7508	 1240	 0.000402	 0.026088	 0.0	 1211	 1211	 1211	 1.035986	 0.0	 1	 -30.0	 30.0;
	3268	 6397	 0.000201	 0.017787	 0.0	 691.0	 1776	 1776	 1.006865	 0.0	 1	 -30.0	 30.0;
	4290	 797	 0.000289	 0.018121	 0.0	 691.0	 1743	 1743	 1.033257	 0.0	 1	 -30.0	 30.0;
	7929	 4592	 0.000643	 0.024464	 0.0	 1291	 1291	 1291	 1.066843	 0.0	 1	 -30.0	 30.0;
	7929	 4592	 0.000568	 0.027771	 0.0	 1138	 1138	 1138	 1.066843	 0.0	 1	 -30.0	 30.0;
	849	 3840	 0.000506	 0.031833	 0.0	 993	 993	 993	 0.998185	 0.0	 1	 -30.0	 30.0;
	849	 3840	 0.000196	 0.024118	 0.0	 691.0	 1310	 1310	 0.997518	 0.0	 1	 -30.0	 30.0;
	5919	 8871	 0.000205	 0.022593	 0.0	 691.0	 1399	 1399	 0.997518	 0.0	 1	 -30.0	 30.0;
	5919	 8871	 0.000186	 0.01968	 0.0	 691.0	 1605	 1605	 0.997518	 0.0	 1	 -30.0	 30.0;
	5919	 8871	 0.000205	 0.01997	 0.0	 691.0	 1582	 1582	 0.997518	 0.0	 1	 -30.0	 30.0;
	1168	 2686	 0.000215	 0.018787	 0.0	 691.0	 1682	 1682	 1.016388	 0.0	 1	 -30.0	 30.0;
	1168	 2686	 0.000215	 0.018388	 0.0	 691.0	 1718	 1718	 1.016388	 0.0	 1	 -30.0	 30.0;
	3275	 6243	 0.000224	 0.018834	 0.0	 691.0	 1678	 1678	 0.997518	 0.0	 1	 -30.0	 30.0;
	3798	 1121	 0.000433	 0.043546	 0.0	 726	 726	 726	 1.052632	 0.0	 1	 -30.0	 30.0;
	5884	 8207	 0.000234	 0.018757	 0.0	 691.0	 1684	 1684	 0.996896	 0.0	 1	 -30.0	 30.0;
	5884	 8207	 0.000197	 0.019207	 0.0	 691.0	 1645	 1645	 0.991986	 0.0	 1	 -30.0	 30.0;
	5884	 8207	 0.000197	 0.019495	 0.0	 691.0	 1621	 1621	 0.991986	 0.0	 1	 -30.0	 30.0;
	6681	 7819	 0.00018	 0.021226	 0.0	 691.0	 1489	 1489	 1.046093	 0.0	 1	 -30.0	 30.0;
	6681	 7819	 0.000812	 0.03849	 0.0	 821	 821	 821	 1.046093	 0.0	 1	 -30.0	 30.0;
	2261	 4204	 0.000205	 0.02035	 0.0	 691.0	 1553	 1553	 1.056356	 0.0	 1	 -30.0	 30.0;
	731	 3728	 0.000593	 0.031521	 0.0	 1002	 1002	 1002	 1.001309	 0.0	 1	 -30.0	 30.0;
	731	 3728	 0.000612	 0.031123	 0.0	 1015	 1015	 1015	 1.001309	 0.0	 1	 -30.0	 30.0;
	731	 3728	 0.000427	 0.024994	 0.0	 1264	 1264	 1264	 1.006865	 0.0	 1	 -30.0	 30.0;
	2764	 415	 0.000667	 0.027207	 0.0	 1161	 1161	 1161	 1.026095	 0.0	 1	 -30.0	 30.0;
	2764	 415	 0.000621	 0.030836	 0.0	 1025	 1025	 1025	 1.026095	 0.0	 1	 -30.0	 30.0;
	299	 947	 0.000192	 0.020791	 0.0	 691.0	 1520	 1520	 1.066843	 0.0	 1	 -30.0	 30.0;
	299	 947	 0.000192	 0.02119	 0.0	 691.0	 1491	 1491	 1.066843	 0.0	 1	 -30.0	 30.0;
	8806	 32	 0.000686	 0.030987	 0.0	 1020	 1020	 1020	 1.026958	 0.0	 1	 -30.0	 30.0;
	3008	 5670	 0.000194	 0.020764	 0.0	 691.0	 1522	 1522	 0.988343	 0.0	 1	 -30.0	 30.0;
	179	 1850	 0.000717	 0.038087	 0.0	 830	 830	 830	 1.035986	 0.0	 1	 -30.0	 30.0;
	7918	 6660	 0.000206	 0.01883	 0.0	 691.0	 1678	 1678	 1.016388	 0.0	 1	 -30.0	 30.0;
	7918	 77	 0.000206	 0.018439	 0.0	 691.0	 1713	 1713	 1.016388	 0.0	 1	 -30.0	 30.0;
	7029	 33	 0.000219	 0.017019	 0.0	 691.0	 1856	 1856	 1.035986	 0.0	 1	 -30.0	 30.0;
	7029	 33	 0.000224	 0.016641	 0.0	 691.0	 1898	 1898	 1.035986	 0.0	 1	 -30.0	 30.0;
	6607	 9039	 0.000676	 0.047085	 0.0	 671	 671	 671	 1.026095	 0.0	 1	 -30.0	 30.0;
	6607	 9039	 0.000667	 0.048014	 0.0	 658	 658	 658	 1.016388	 0.0	 1	 -30.0	 30.0;
	7343	 8338	 0.000196	 0.019215	 0.0	 691.0	 1644	 1644	 0.997518	 0.0	 1	 -30.0	 30.0;
	3966	 5890	 0.000253	 0.025528	 0.0	 1238	 1238	 1238	 1.011609	 0.0	 1	 -30.0	 30.0;
	8210	 6936	 0.00021	 0.017884	 0.0	 691.0	 1767	 1767	 1.016388	 0.0	 1	 -30.0	 30.0;
	8210	 6936	 0.00021	 0.017518	 0.0	 691.0	 1804	 1804	 1.016388	 0.0	 1	 -30.0	 30.0;
	1716	 6544	 0.000219	 0.017358	 0.0	 691.0	 1820	 1820	 1.006865	 0.0	 1	 -30.0	 30.0;
	1716	 6544	 0.000219	 0.016973	 0.0	 691.0	 1861	 1861	 1.006865	 0.0	 1	 -30.0	 30.0;
	3544	 869	 0.000295	 0.027995	 0.0	 1129	 1129	 1129	 1.021673	 0.0	 1	 -30.0	 30.0;
	3544	 869	 0.000277	 0.027486	 0.0	 1150	 1150	 1150	 1.026115	 0.0	 1	 -30.0	 30.0;
	3662	 8242	 0.000489	 0.032074	 0.0	 985	 985	 985	 0.998185	 0.0	 1	 -30.0	 30.0;
	6092	 3109	 0.00018	 0.02129	 0.0	 691.0	 1484	 1484	 1.020734	 0.0	 1	 -30.0	 30.0;
	1074	 1769	 0.000366	 0.029147	 0.0	 1084	 1084	 1084	 1.000611	 0.0	 1	 -30.0	 30.0;
	1074	 1769	 0.000366	 0.028067	 0.0	 1126	 1126	 1126	 1.002235	 0.0	 1	 -30.0	 30.0;
	1074	 1769	 0.00042	 0.026331	 0.0	 1200	 1200	 1200	 1.000611	 0.0	 1	 -30.0	 30.0;
	4957	 1513	 0.000441	 0.01916	 0.0	 691.0	 1649	 1649	 1.012394	 0.0	 1	 -30.0	 30.0;
	7428	 6134	 0.000391	 0.024766	 0.0	 1276	 1276	 1276	 0.988343	 0.0	 1	 -30.0	 30.0;
	7428	 6134	 0.000401	 0.024225	 0.0	 1304	 1304	 1304	 0.997518	 0.0	 1	 -30.0	 30.0;
	7428	 4651	 0.000408	 0.028237	 0.0	 1119	 1119	 1119	 1.006865	 0.0	 1	 -30.0	 30.0;
	6970	 4632	 0.000199	 0.018609	 0.0	 691.0	 1698	 1698	 0.997518	 0.0	 1	 -30.0	 30.0;
	2700	 8953	 0.000196	 0.021597	 0.0	 691.0	 1463	 1463	 0.997518	 0.0	 1	 -30.0	 30.0;
	2700	 8953	 0.000186	 0.022003	 0.0	 691.0	 1436	 1436	 0.997518	 0.0	 1	 -30.0	 30.0;
	2849	 3291	 0.000186	 0.019718	 0.0	 691.0	 1602	 1602	 1.006865	 0.0	 1	 -30.0	 30.0;
	4446	 1457	 0.000205	 0.022703	 0.0	 691.0	 1392	 1392	 1.016388	 0.0	 1	 -30.0	 30.0;
	814	 7820	 0.000228	 0.021908	 0.0	 691.0	 1442	 1442	 0.988343	 0.0	 1	 -30.0	 30.0;
	7436	 7629	 0.000322	 0.028734	 0.0	 1100	 1100	 1100	 0.996603	 0.0	 1	 -30.0	 30.0;
	7436	 9106	 0.000319	 0.026574	 0.0	 1189	 1189	 1189	 1.042861	 0.0	 1	 -30.0	 30.0;
	3587	 1241	 0.000289	 0.018298	 0.0	 691.0	 1727	 1727	 1.046093	 0.0	 1	 -30.0	 30.0;
	3587	 1241	 0.000199	 0.02111	 0.0	 691.0	 1497	 1497	 1.046093	 0.0	 1	 -30.0	 30.0;
	7688	 8301	 0.000196	 0.02119	 0.0	 691.0	 1491	 1491	 1.016388	 0.0	 1	 -30.0	 30.0;
	7688	 8301	 0.000196	 0.021597	 0.0	 691.0	 1463	 1463	 1.016388	 0.0	 1	 -30.0	 30.0;
	4507	 1503	 0.001097	 0.082091	 0.0	 385	 385	 385	 1.006865	 0.0	 1	 -30.0	 30.0;
	4507	 1503	 0.000406	 0.048834	 0.0	 647	 647	 647	 1.033257	 0.0	 1	 -30.0	 30.0;
	4507	 1503	 7.2e-05	 0.017798	 0.0	 691.0	 1775	 1775	 0.988343	 0.0	 1	 -30.0	 30.0;
	4507	 1503	 0.000424	 0.04684	 0.0	 675	 675	 675	 1.033257	 0.0	 1	 -30.0	 30.0;
	8260	 4081	 0.000224	 0.01875	 0.0	 691.0	 1685	 1685	 1.006865	 0.0	 1	 -30.0	 30.0;
	8260	 4081	 0.000224	 0.018334	 0.0	 691.0	 1723	 1723	 1.006865	 0.0	 1	 -30.0	 30.0;
	1280	 4279	 0.000379	 0.018493	 0.0	 691.0	 1708	 1708	 1.046093	 0.0	 1	 -30.0	 30.0;
	1280	 4279	 0.000253	 0.019711	 0.0	 691.0	 1603	 1603	 1.046093	 0.0	 1	 -30.0	 30.0;
	385	 9028	 0.000196	 0.016483	 0.0	 1053.0	 1917	 1917	 0.997518	 0.0	 1	 -30.0	 30.0;
	385	 9028	 0.000186	 0.022421	 0.0	 691.0	 1409	 1409	 0.997518	 0.0	 1	 -30.0	 30.0;
	6768	 4096	 0.00046	 0.030794	 0.0	 1026	 1026	 1026	 1.002506	 0.0	 1	 -30.0	 30.0;
	9203	 2426	 0.000695	 0.049098	 0.0	 644	 644	 644	 0.982143	 0.0	 1	 -30.0	 30.0;
	9203	 2426	 0.000355	 0.024893	 0.0	 691.0	 1269	 1269	 0.93617	 0.0	 1	 -30.0	 30.0;
	118	 2426	 0.000365	 0.024372	 0.0	 691.0	 1296	 1296	 0.979227	 0.0	 1	 -30.0	 30.0;
	3145	 7770	 0.000411	 0.023652	 0.0	 691.0	 1336	 1336	 0.93617	 0.0	 1	 -30.0	 30.0;
	7267	 4918	 0.000386	 0.025673	 0.0	 691.0	 1231	 1231	 0.93617	 0.0	 1	 -30.0	 30.0;
	7267	 4918	 0.000344	 0.029336	 0.0	 691.0	 1077	 1077	 0.93617	 0.0	 1	 -30.0	 30.0;
	839	 4506	 0.000653	 0.052104	 0.0	 607	 607	 607	 0.982143	 0.0	 1	 -30.0	 30.0;
	839	 4506	 0.000767	 0.043531	 0.0	 726	 726	 726	 0.982143	 0.0	 1	 -30.0	 30.0;
	3445	 6114	 0.000323	 0.028314	 0.0	 691.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	3445	 6114	 0.000323	 0.025999	 0.0	 691.0	 1215	 1215	 0.93617	 0.0	 1	 -30.0	 30.0;
	3445	 7264	 0.000365	 0.025478	 0.0	 691.0	 1240	 1240	 0.93617	 0.0	 1	 -30.0	 30.0;
	891	 6306	 0.00086	 0.039291	 0.0	 804	 804	 804	 0.982143	 0.0	 1	 -30.0	 30.0;
	720	 1711	 0.000355	 0.026586	 0.0	 691.0	 1189	 1189	 0.93617	 0.0	 1	 -30.0	 30.0;
	720	 1711	 0.000375	 0.026313	 0.0	 691.0	 1201	 1201	 0.93617	 0.0	 1	 -30.0	 30.0;
	6206	 3240	 0.000344	 0.023329	 0.0	 691.0	 1354	 1354	 0.979227	 0.0	 1	 -30.0	 30.0;
	6206	 3240	 0.000302	 0.026375	 0.0	 691.0	 1198	 1198	 0.979227	 0.0	 1	 -30.0	 30.0;
	9174	 2924	 0.000788	 0.04323	 0.0	 731	 731	 731	 0.982143	 0.0	 1	 -30.0	 30.0;
	9174	 2924	 0.000767	 0.04407	 0.0	 717	 717	 717	 0.982143	 0.0	 1	 -30.0	 30.0;
	1355	 5856	 0.000767	 0.043562	 0.0	 725	 725	 725	 0.982143	 0.0	 1	 -30.0	 30.0;
	1355	 5856	 0.000788	 0.041281	 0.0	 766	 766	 766	 0.982143	 0.0	 1	 -30.0	 30.0;
	1355	 5856	 0.000892	 0.040524	 0.0	 780	 780	 780	 0.982143	 0.0	 1	 -30.0	 30.0;
	3205	 4683	 0.000975	 0.043562	 0.0	 725	 725	 725	 0.982143	 0.0	 1	 -30.0	 30.0;
	3205	 4683	 0.000757	 0.042649	 0.0	 741	 741	 741	 0.982143	 0.0	 1	 -30.0	 30.0;
	5350	 2361	 0.000261	 0.030762	 0.0	 691.0	 1027	 1027	 0.93617	 0.0	 1	 -30.0	 30.0;
	5350	 2361	 0.000261	 0.030088	 0.0	 691.0	 1050	 1050	 0.93617	 0.0	 1	 -30.0	 30.0;
	5016	 6112	 0.000323	 0.026447	 0.0	 691.0	 1195	 1195	 0.979227	 0.0	 1	 -30.0	 30.0;
	5016	 8860	 0.000323	 0.026885	 0.0	 691.0	 1175	 1175	 0.979227	 0.0	 1	 -30.0	 30.0;
	7471	 549	 0.000323	 0.02748	 0.0	 691.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	7471	 549	 0.000292	 0.028158	 0.0	 691.0	 1122	 1122	 0.93617	 0.0	 1	 -30.0	 30.0;
	549	 5002	 0.0	 0.010856	 0.0	 667.0	 2910	 2910	 1.0	 0.120551	 1	 -30.0	 30.0;
	5490	 3817	 0.000736	 0.044526	 0.0	 710	 710	 710	 0.982143	 0.0	 1	 -30.0	 30.0;
	2854	 9112	 0.00086	 0.039488	 0.0	 800	 800	 800	 0.982143	 0.0	 1	 -30.0	 30.0;
	2918	 6532	 0.000365	 0.024372	 0.0	 691.0	 1296	 1296	 0.93617	 0.0	 1	 -30.0	 30.0;
	2918	 6532	 0.000375	 0.023986	 0.0	 691.0	 1317	 1317	 0.93617	 0.0	 1	 -30.0	 30.0;
	4494	 7284	 0.000386	 0.025673	 0.0	 691.0	 1231	 1231	 0.93617	 0.0	 1	 -30.0	 30.0;
	2656	 1775	 0.000809	 0.042318	 0.0	 747	 747	 747	 0.982143	 0.0	 1	 -30.0	 30.0;
	3519	 5641	 0.000705	 0.042038	 0.0	 752	 752	 752	 0.982143	 0.0	 1	 -30.0	 30.0;
	3543	 367	 0.000334	 0.028022	 0.0	 691.0	 1128	 1128	 0.93617	 0.0	 1	 -30.0	 30.0;
	3543	 1833	 0.000353	 0.022403	 0.0	 691.0	 1410	 1410	 0.982143	 0.0	 1	 -30.0	 30.0;
	2372	 367	 0.000313	 0.026354	 0.0	 691.0	 1199	 1199	 0.93617	 0.0	 1	 -30.0	 30.0;
	2372	 367	 0.000323	 0.025478	 0.0	 691.0	 1240	 1240	 0.93617	 0.0	 1	 -30.0	 30.0;
	1876	 7752	 0.000344	 0.024622	 0.0	 691.0	 1283	 1283	 0.979227	 0.0	 1	 -30.0	 30.0;
	113	 7752	 0.000355	 0.024038	 0.0	 691.0	 1314	 1314	 0.979227	 0.0	 1	 -30.0	 30.0;
	3499	 7289	 0.000881	 0.038244	 0.0	 826	 826	 826	 0.982143	 0.0	 1	 -30.0	 30.0;
	3499	 7289	 0.000757	 0.040959	 0.0	 772	 772	 772	 0.982143	 0.0	 1	 -30.0	 30.0;
	3082	 2083	 0.000354	 0.028765	 0.0	 691.0	 1099	 1099	 0.93617	 0.0	 1	 -30.0	 30.0;
	6224	 2083	 0.000354	 0.027114	 0.0	 691.0	 1165	 1165	 0.93617	 0.0	 1	 -30.0	 30.0;
	2174	 2083	 0.000695	 0.04748	 0.0	 666	 666	 666	 0.982143	 0.0	 1	 -30.0	 30.0;
	4623	 1609	 0.000323	 0.028314	 0.0	 691.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	4623	 1609	 0.000323	 0.026354	 0.0	 691.0	 1199	 1199	 0.93617	 0.0	 1	 -30.0	 30.0;
	4623	 1609	 0.000323	 0.025696	 0.0	 691.0	 1230	 1230	 0.93617	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000355	 0.027305	 0.0	 691.0	 1157	 1157	 0.979227	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000355	 0.026666	 0.0	 691.0	 1185	 1185	 0.979227	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000923	 0.037456	 0.0	 844	 844	 844	 0.982143	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000788	 0.035217	 0.0	 897	 897	 897	 0.982143	 0.0	 1	 -30.0	 30.0;
	1198	 7473	 0.000323	 0.026739	 0.0	 691.0	 1182	 1182	 0.93617	 0.0	 1	 -30.0	 30.0;
	1198	 7473	 0.000323	 0.02749	 0.0	 691.0	 1149	 1149	 0.93617	 0.0	 1	 -30.0	 30.0;
	2479	 5482	 0.000313	 0.027324	 0.0	 691.0	 1156	 1156	 0.93617	 0.0	 1	 -30.0	 30.0;
	2479	 5482	 0.000313	 0.028074	 0.0	 691.0	 1126	 1126	 0.93617	 0.0	 1	 -30.0	 30.0;
	7831	 5525	 0.000601	 0.024984	 0.0	 1264	 1264	 1264	 0.982143	 0.0	 1	 -30.0	 30.0;
	7831	 5525	 0.000715	 0.022797	 0.0	 1385	 1385	 1385	 0.982143	 0.0	 1	 -30.0	 30.0;
	7831	 5525	 0.000344	 0.024893	 0.0	 691.0	 1269	 1269	 0.93617	 0.0	 1	 -30.0	 30.0;
	4970	 7955	 0.000365	 0.024163	 0.0	 691.0	 1308	 1308	 0.979227	 0.0	 1	 -30.0	 30.0;
	4970	 7955	 0.000344	 0.02385	 0.0	 691.0	 1325	 1325	 0.979227	 0.0	 1	 -30.0	 30.0;
	5007	 7367	 0.000757	 0.040182	 0.0	 786	 786	 786	 0.982143	 0.0	 1	 -30.0	 30.0;
	757	 3758	 0.000323	 0.028937	 0.0	 691.0	 1092	 1092	 0.979227	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000354	 0.026958	 0.0	 691.0	 1172	 1172	 0.93617	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000778	 0.045656	 0.0	 692	 692	 692	 0.982143	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000695	 0.048932	 0.0	 646	 646	 646	 0.982143	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000302	 0.025926	 0.0	 691.0	 1219	 1219	 0.93617	 0.0	 1	 -30.0	 30.0;
	6738	 8180	 0.000355	 0.027328	 0.0	 691.0	 1156	 1156	 0.93617	 0.0	 1	 -30.0	 30.0;
	6738	 8180	 0.000365	 0.027156	 0.0	 691.0	 1164	 1164	 0.93617	 0.0	 1	 -30.0	 30.0;
	9222	 5935	 0.000355	 0.024299	 0.0	 691.0	 1300	 1300	 0.979227	 0.0	 1	 -30.0	 30.0;
	7988	 804	 0.000375	 0.026313	 0.0	 691.0	 1201	 1201	 0.93617	 0.0	 1	 -30.0	 30.0;
	7988	 804	 0.000375	 0.025605	 0.0	 691.0	 1234	 1234	 0.93617	 0.0	 1	 -30.0	 30.0;
	3239	 1539	 0.000334	 0.026291	 0.0	 691.0	 1202	 1202	 0.979227	 0.0	 1	 -30.0	 30.0;
	3239	 1539	 0.000705	 0.046735	 0.0	 676	 676	 676	 0.982143	 0.0	 1	 -30.0	 30.0;
	2056	 4084	 0.000313	 0.026875	 0.0	 691.0	 1176	 1176	 0.979227	 0.0	 1	 -30.0	 30.0;
	2056	 4084	 0.000302	 0.027376	 0.0	 691.0	 1154	 1154	 0.979227	 0.0	 1	 -30.0	 30.0;
	4598	 5110	 0.000664	 0.044868	 0.0	 704	 704	 704	 0.982143	 0.0	 1	 -30.0	 30.0;
	2129	 5110	 0.000809	 0.044526	 0.0	 710	 710	 710	 0.982143	 0.0	 1	 -30.0	 30.0;
	5658	 5550	 0.00086	 0.034253	 0.0	 922	 922	 922	 0.982143	 0.0	 1	 -30.0	 30.0;
	5658	 5550	 0.000355	 0.024372	 0.0	 691.0	 1296	 1296	 0.93617	 0.0	 1	 -30.0	 30.0;
	2848	 1526	 0.000365	 0.023788	 0.0	 691.0	 1328	 1328	 0.93617	 0.0	 1	 -30.0	 30.0;
	4541	 7464	 0.000375	 0.023204	 0.0	 691.0	 1362	 1362	 0.979227	 0.0	 1	 -30.0	 30.0;
	4541	 7464	 0.000302	 0.026593	 0.0	 691.0	 1188	 1188	 0.979227	 0.0	 1	 -30.0	 30.0;
	1754	 3857	 0.000323	 0.029256	 0.0	 691.0	 1080	 1080	 0.93617	 0.0	 1	 -30.0	 30.0;
	1754	 3857	 0.000334	 0.029986	 0.0	 691.0	 1054	 1054	 0.93617	 0.0	 1	 -30.0	 30.0;
	1754	 3857	 0.000355	 0.030979	 0.0	 691.0	 1020	 1020	 0.93617	 0.0	 1	 -30.0	 30.0;
	2518	 4544	 0.000302	 0.025707	 0.0	 691.0	 1229	 1229	 0.93617	 0.0	 1	 -30.0	 30.0;
	2518	 4544	 0.000344	 0.025405	 0.0	 691.0	 1244	 1244	 0.93617	 0.0	 1	 -30.0	 30.0;
	3069	 6115	 0.00012	 0.009612	 0.0	 591.0	 3286	 3286	 1.0	 -0.096484	 1	 -30.0	 30.0;
	5067	 7641	 0.000365	 0.023715	 0.0	 691.0	 1332	 1332	 0.93617	 0.0	 1	 -30.0	 30.0;
	6036	 8670	 0.000365	 0.023517	 0.0	 691.0	 1344	 1344	 0.979227	 0.0	 1	 -30.0	 30.0;
	6036	 5522	 0.000334	 0.026812	 0.0	 691.0	 1179	 1179	 0.979227	 0.0	 1	 -30.0	 30.0;
	8486	 8791	 0.000695	 0.047253	 0.0	 669	 669	 669	 0.982143	 0.0	 1	 -30.0	 30.0;
	7530	 8791	 0.000778	 0.043759	 0.0	 722	 722	 722	 0.982143	 0.0	 1	 -30.0	 30.0;
	7522	 7571	 0.000313	 0.030636	 0.0	 691.0	 1031	 1031	 0.93617	 0.0	 1	 -30.0	 30.0;
	7522	 7571	 0.000313	 0.028286	 0.0	 691.0	 1117	 1117	 0.93617	 0.0	 1	 -30.0	 30.0;
	7522	 7571	 0.000344	 0.028115	 0.0	 691.0	 1124	 1124	 0.93617	 0.0	 1	 -30.0	 30.0;
	2526	 1483	 0.000902	 0.039425	 0.0	 801	 801	 801	 0.982143	 0.0	 1	 -30.0	 30.0;
	2365	 8316	 0.000355	 0.024237	 0.0	 691.0	 1304	 1304	 0.93617	 0.0	 1	 -30.0	 30.0;
	8672	 1860	 0.000375	 0.023986	 0.0	 691.0	 1317	 1317	 0.93617	 0.0	 1	 -30.0	 30.0;
	8672	 1860	 0.000375	 0.023861	 0.0	 691.0	 1324	 1324	 0.93617	 0.0	 1	 -30.0	 30.0;
	1494	 583	 0.000819	 0.04153	 0.0	 761	 761	 761	 0.982143	 0.0	 1	 -30.0	 30.0;
	1494	 583	 0.000809	 0.042701	 0.0	 740	 740	 740	 0.982143	 0.0	 1	 -30.0	 30.0;
	1502	 2795	 0.000334	 0.028022	 0.0	 691.0	 1128	 1128	 0.93617	 0.0	 1	 -30.0	 30.0;
	8195	 933	 0.000632	 0.048237	 0.0	 655	 655	 655	 0.982143	 0.0	 1	 -30.0	 30.0;
	8195	 933	 0.000632	 0.045159	 0.0	 700	 700	 700	 0.982143	 0.0	 1	 -30.0	 30.0;
	8195	 933	 0.000715	 0.044039	 0.0	 718	 718	 718	 0.982143	 0.0	 1	 -30.0	 30.0;
	3918	 6802	 0.00074	 0.044479	 0.0	 711	 711	 711	 0.986547	 0.0	 1	 -30.0	 30.0;
	3918	 4025	 0.00074	 0.043811	 0.0	 721	 721	 721	 0.986547	 0.0	 1	 -30.0	 30.0;
	4435	 2079	 0.000375	 0.02385	 0.0	 691.0	 1325	 1325	 0.93617	 0.0	 1	 -30.0	 30.0;
	4435	 2079	 0.000365	 0.023267	 0.0	 691.0	 1358	 1358	 0.93617	 0.0	 1	 -30.0	 30.0;
	4435	 2079	 0.000323	 0.026739	 0.0	 691.0	 1182	 1182	 0.93617	 0.0	 1	 -30.0	 30.0;
	1081	 7361	 0.000684	 0.047025	 0.0	 672	 672	 672	 0.982143	 0.0	 1	 -30.0	 30.0;
	9101	 2177	 0.000313	 0.02748	 0.0	 691.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	6555	 8475	 0.000323	 0.028554	 0.0	 691.0	 1107	 1107	 0.93617	 0.0	 1	 -30.0	 30.0;
	6555	 8475	 0.000302	 0.026437	 0.0	 691.0	 1195	 1195	 0.93617	 0.0	 1	 -30.0	 30.0;
	7056	 7577	 0.000365	 0.025551	 0.0	 691.0	 1237	 1237	 0.93617	 0.0	 1	 -30.0	 30.0;
	7056	 7577	 0.000344	 0.024893	 0.0	 691.0	 1269	 1269	 0.93617	 0.0	 1	 -30.0	 30.0;
	7056	 9051	 0.000375	 0.024508	 0.0	 691.0	 1289	 1289	 0.979227	 0.0	 1	 -30.0	 30.0;
	6889	 6785	 0.000778	 0.041157	 0.0	 768	 768	 768	 0.982143	 0.0	 1	 -30.0	 30.0;
	6889	 6785	 0.000923	 0.03702	 0.0	 853	 853	 853	 0.982143	 0.0	 1	 -30.0	 30.0;
	6889	 6785	 0.000302	 0.026593	 0.0	 691.0	 1188	 1188	 0.979227	 0.0	 1	 -30.0	 30.0;
	1027	 7148	 0.000344	 0.029667	 0.0	 691.0	 1065	 1065	 0.93617	 0.0	 1	 -30.0	 30.0;
	1027	 44	 0.000334	 0.02748	 0.0	 691.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	5308	 7148	 0.000323	 0.030636	 0.0	 691.0	 1031	 1031	 0.89674	 0.0	 1	 -30.0	 30.0;
	5308	 44	 0.000323	 0.028526	 0.0	 691.0	 1108	 1108	 0.93617	 0.0	 1	 -30.0	 30.0;
	9213	 6231	 0.000344	 0.025332	 0.0	 691.0	 1247	 1247	 0.979227	 0.0	 1	 -30.0	 30.0;
	9213	 8291	 0.000334	 0.024674	 0.0	 691.0	 1281	 1281	 0.979227	 0.0	 1	 -30.0	 30.0;
	9213	 6842	 0.000344	 0.02457	 0.0	 691.0	 1286	 1286	 0.979227	 0.0	 1	 -30.0	 30.0;
	3608	 6664	 0.000365	 0.023788	 0.0	 691.0	 1328	 1328	 0.93617	 0.0	 1	 -30.0	 30.0;
	4339	 6570	 0.000365	 0.023601	 0.0	 691.0	 1339	 1339	 0.93617	 0.0	 1	 -30.0	 30.0;
	4339	 6570	 0.000344	 0.02652	 0.0	 691.0	 1191	 1191	 0.93617	 0.0	 1	 -30.0	 30.0;
	7513	 6570	 0.000344	 0.027272	 0.0	 691.0	 1159	 1159	 0.93617	 0.0	 1	 -30.0	 30.0;
	7513	 6570	 0.000334	 0.027563	 0.0	 691.0	 1146	 1146	 0.93617	 0.0	 1	 -30.0	 30.0;
	8887	 6639	 0.000313	 0.030636	 0.0	 691.0	 1031	 1031	 0.979227	 0.0	 1	 -30.0	 30.0;
	8887	 6639	 0.000313	 0.028286	 0.0	 691.0	 1117	 1117	 0.979227	 0.0	 1	 -30.0	 30.0;
	5461	 4816	 0.000881	 0.036803	 0.0	 859	 859	 859	 0.982143	 0.0	 1	 -30.0	 30.0;
	5461	 4816	 0.000902	 0.036668	 0.0	 862	 862	 862	 0.982143	 0.0	 1	 -30.0	 30.0;
	5461	 4816	 0.000881	 0.034014	 0.0	 929	 929	 929	 0.982143	 0.0	 1	 -30.0	 30.0;
	5460	 3786	 0.000365	 0.026027	 0.0	 691.0	 1214	 1214	 0.93617	 0.0	 1	 -30.0	 30.0;
	5460	 3786	 0.000386	 0.025673	 0.0	 691.0	 1231	 1231	 0.93617	 0.0	 1	 -30.0	 30.0;
	7256	 4491	 0.00012	 0.009966	 0.0	 686.0	 3170	 3170	 1.0	 0.036236	 1	 -30.0	 30.0;
	6153	 58	 0.00017	 0.007798	 0.0	 1316.0	 4050	 4050	 1.0	 -0.119536	 1	 -30.0	 30.0;
	6153	 6807	 0.000664	 0.047107	 0.0	 671	 671	 671	 0.982143	 0.0	 1	 -30.0	 30.0;
	1465	 1262	 0.000313	 0.028314	 0.0	 691.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	1465	 1262	 0.000334	 0.025707	 0.0	 691.0	 1229	 1229	 0.93617	 0.0	 1	 -30.0	 30.0;
	1465	 1551	 0.000344	 0.025478	 0.0	 691.0	 1240	 1240	 0.93617	 0.0	 1	 -30.0	 30.0;
	7537	 1551	 0.000344	 0.027236	 0.0	 691.0	 1160	 1160	 0.93617	 0.0	 1	 -30.0	 30.0;
	7537	 1551	 0.000375	 0.026518	 0.0	 691.0	 1192	 1192	 0.93617	 0.0	 1	 -30.0	 30.0;
	6901	 4874	 0.000386	 0.02646	 0.0	 691.0	 1194	 1194	 0.93617	 0.0	 1	 -30.0	 30.0;
	5241	 4	 0.000788	 0.040317	 0.0	 784	 784	 784	 0.982143	 0.0	 1	 -30.0	 30.0;
	7520	 561	 0.000323	 0.025863	 0.0	 691.0	 1222	 1222	 0.979227	 0.0	 1	 -30.0	 30.0;
	749	 4324	 1e-05	 0.022863	 0.0	 1048.0	 1382	 1382	 1.0	 0.04898	 1	 -30.0	 30.0;
	4141	 7124	 0.000334	 0.030306	 0.0	 691.0	 1043	 1043	 0.93617	 0.0	 1	 -30.0	 30.0;
	4141	 7124	 0.000302	 0.030636	 0.0	 691.0	 1032	 1032	 0.93617	 0.0	 1	 -30.0	 30.0;
	7466	 3649	 0.00011	 0.012655	 0.0	 572.0	 2496	 2496	 1.0	 -0.110406	 1	 -30.0	 30.0;
	8222	 6556	 0.000344	 0.024841	 0.0	 691.0	 1272	 1272	 0.979227	 0.0	 1	 -30.0	 30.0;
	8222	 6556	 0.000365	 0.025029	 0.0	 691.0	 1262	 1262	 0.979227	 0.0	 1	 -30.0	 30.0;
	8222	 6556	 0.000355	 0.024101	 0.0	 691.0	 1311	 1311	 0.979227	 0.0	 1	 -30.0	 30.0;
	4125	 163	 0.000344	 0.02385	 0.0	 691.0	 1325	 1325	 0.93617	 0.0	 1	 -30.0	 30.0;
	4125	 163	 0.000411	 0.02313	 0.0	 691.0	 1366	 1366	 0.93617	 0.0	 1	 -30.0	 30.0;
	4125	 163	 0.000829	 0.042764	 0.0	 739	 739	 739	 0.982143	 0.0	 1	 -30.0	 30.0;
	5837	 9217	 0.000705	 0.04748	 0.0	 666	 666	 666	 0.982143	 0.0	 1	 -30.0	 30.0;
	5837	 1448	 0.000323	 0.029986	 0.0	 691.0	 1054	 1054	 0.93617	 0.0	 1	 -30.0	 30.0;
	5837	 1448	 0.000302	 0.029952	 0.0	 691.0	 1055	 1055	 0.93617	 0.0	 1	 -30.0	 30.0;
	8267	 5365	 0.000746	 0.041064	 0.0	 770	 770	 770	 0.982143	 0.0	 1	 -30.0	 30.0;
	8267	 5365	 0.000881	 0.042214	 0.0	 749	 749	 749	 0.982143	 0.0	 1	 -30.0	 30.0;
	2359	 8005	 0.00086	 0.041209	 0.0	 767	 767	 767	 0.982143	 0.0	 1	 -30.0	 30.0;
	2359	 8005	 0.000912	 0.038669	 0.0	 817	 817	 817	 0.982143	 0.0	 1	 -30.0	 30.0;
	8109	 171	 0.000375	 0.026244	 0.0	 691.0	 1204	 1204	 0.979227	 0.0	 1	 -30.0	 30.0;
	8109	 171	 0.000375	 0.025457	 0.0	 691.0	 1241	 1241	 0.979227	 0.0	 1	 -30.0	 30.0;
	3485	 1156	 0.000302	 0.029096	 0.0	 691.0	 1086	 1086	 0.93617	 0.0	 1	 -30.0	 30.0;
	4734	 2229	 0.000302	 0.029667	 0.0	 691.0	 1065	 1065	 0.93617	 0.0	 1	 -30.0	 30.0;
	1709	 7702	 0.000334	 0.027563	 0.0	 691.0	 1146	 1146	 0.979227	 0.0	 1	 -30.0	 30.0;
	1709	 7702	 0.000323	 0.028074	 0.0	 691.0	 1126	 1126	 0.979227	 0.0	 1	 -30.0	 30.0;
	905	 8189	 0.000736	 0.041064	 0.0	 770	 770	 770	 0.982143	 0.0	 1	 -30.0	 30.0;
	8334	 8189	 0.001234	 0.040109	 0.0	 788	 788	 788	 0.982143	 0.0	 1	 -30.0	 30.0;
	8334	 8189	 0.000757	 0.043209	 0.0	 731	 731	 731	 0.982143	 0.0	 1	 -30.0	 30.0;
	7998	 6734	 0.000323	 0.026586	 0.0	 954.0	 1189	 1189	 0.93617	 0.0	 1	 -30.0	 30.0;
	4196	 280	 0.000788	 0.040296	 0.0	 784	 784	 784	 0.982143	 0.0	 1	 -30.0	 30.0;
	4196	 280	 0.000912	 0.040514	 0.0	 780	 780	 780	 0.982143	 0.0	 1	 -30.0	 30.0;
	6475	 3503	 0.000798	 0.042183	 0.0	 749	 749	 749	 0.982143	 0.0	 1	 -30.0	 30.0;
	6475	 3503	 0.000778	 0.043147	 0.0	 732	 732	 732	 0.982143	 0.0	 1	 -30.0	 30.0;
	7328	 4235	 0.000323	 0.027793	 0.0	 691.0	 1137	 1137	 0.93617	 0.0	 1	 -30.0	 30.0;
	7328	 4235	 0.000302	 0.027918	 0.0	 691.0	 1132	 1132	 0.93617	 0.0	 1	 -30.0	 30.0;
	7328	 4235	 0.000302	 0.025926	 0.0	 691.0	 1219	 1219	 0.93617	 0.0	 1	 -30.0	 30.0;
	6921	 2949	 0.000344	 0.024956	 0.0	 691.0	 1266	 1266	 0.979227	 0.0	 1	 -30.0	 30.0;
	6921	 2949	 0.000355	 0.024435	 0.0	 691.0	 1293	 1293	 0.979227	 0.0	 1	 -30.0	 30.0;
	3830	 306	 0.000386	 0.026392	 0.0	 691.0	 1197	 1197	 0.93617	 0.0	 1	 -30.0	 30.0;
	5648	 306	 0.000365	 0.025525	 0.0	 691.0	 1238	 1238	 0.93617	 0.0	 1	 -30.0	 30.0;
	1730	 115	 0.000344	 0.029986	 0.0	 691.0	 1054	 1054	 0.93617	 0.0	 1	 -30.0	 30.0;
	1730	 115	 0.000323	 0.029838	 0.0	 691.0	 1059	 1059	 0.93617	 0.0	 1	 -30.0	 30.0;
	2721	 5720	 0.000323	 0.02748	 0.0	 691.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	2721	 5720	 0.000313	 0.028001	 0.0	 691.0	 1129	 1129	 0.93617	 0.0	 1	 -30.0	 30.0;
	432	 3246	 0.000179	 0.012988	 0.0	 1251.0	 2432	 2432	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 8846	 0.000198	 0.012724	 0.0	 1251.0	 2483	 2483	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 2393	 0.000207	 0.012469	 0.0	 1251.0	 2533	 2533	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 1895	 0.000207	 0.012206	 0.0	 1251.0	 2588	 2588	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 3412	 0.000217	 0.012912	 0.0	 1251.0	 2447	 2447	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 5586	 0.000217	 0.012627	 0.0	 1251.0	 2502	 2502	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 3112	 0.000198	 0.014317	 0.0	 1251.0	 2207	 2207	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 3112	 0.000189	 0.014592	 0.0	 1251.0	 2165	 2165	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 7857	 0.000354	 0.02725	 0.0	 691.0	 1160	 1160	 0.979227	 0.0	 1	 -30.0	 30.0;
	960	 8497	 0.000628	 0.042428	 0.0	 745	 745	 745	 1.009174	 0.0	 1	 -30.0	 30.0;
	960	 8497	 0.000726	 0.044039	 0.0	 718	 718	 718	 0.982143	 0.0	 1	 -30.0	 30.0;
	3577	 5907	 0.000365	 0.024893	 0.0	 691.0	 1269	 1269	 0.979227	 0.0	 1	 -30.0	 30.0;
	3577	 5907	 0.000438	 0.02457	 0.0	 691.0	 1286	 1286	 0.979227	 0.0	 1	 -30.0	 30.0;
	3577	 5907	 0.000365	 0.023986	 0.0	 691.0	 1317	 1317	 0.979227	 0.0	 1	 -30.0	 30.0;
	7164	 5918	 0.000375	 0.023267	 0.0	 691.0	 1358	 1358	 0.979227	 0.0	 1	 -30.0	 30.0;
	7164	 5918	 0.000323	 0.026375	 0.0	 691.0	 1198	 1198	 0.93617	 0.0	 1	 -30.0	 30.0;
	1798	 2467	 0.000334	 0.029735	 0.0	 691.0	 1063	 1063	 0.93617	 0.0	 1	 -30.0	 30.0;
	1798	 2467	 0.000313	 0.030237	 0.0	 691.0	 1045	 1045	 0.93617	 0.0	 1	 -30.0	 30.0;
	3346	 2132	 0.000767	 0.044049	 0.0	 717	 717	 717	 0.982143	 0.0	 1	 -30.0	 30.0;
	3346	 2132	 0.000302	 0.026072	 0.0	 691.0	 1212	 1212	 0.93617	 0.0	 1	 -30.0	 30.0;
	3346	 2132	 0.00085	 0.039892	 0.0	 792	 792	 792	 0.982143	 0.0	 1	 -30.0	 30.0;
	3483	 8992	 0.000344	 0.024956	 0.0	 691.0	 1266	 1266	 0.979227	 0.0	 1	 -30.0	 30.0;
	8886	 8992	 0.000334	 0.026666	 0.0	 691.0	 1185	 1185	 0.93617	 0.0	 1	 -30.0	 30.0;
	2093	 805	 0.000365	 0.023788	 0.0	 691.0	 1328	 1328	 0.93617	 0.0	 1	 -30.0	 30.0;
	2093	 805	 0.000365	 0.023465	 0.0	 691.0	 1346	 1346	 0.93617	 0.0	 1	 -30.0	 30.0;
	221	 1541	 0.000334	 0.026447	 0.0	 691.0	 1195	 1195	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 5383	 0.000323	 0.027042	 0.0	 691.0	 1169	 1169	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 5383	 0.000313	 0.02748	 0.0	 691.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 5383	 0.000302	 0.028314	 0.0	 691.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 7507	 0.000323	 0.025853	 0.0	 691.0	 1222	 1222	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 7507	 0.000365	 0.026197	 0.0	 691.0	 1206	 1206	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 7507	 0.000365	 0.025165	 0.0	 691.0	 1256	 1256	 0.93617	 0.0	 1	 -30.0	 30.0;
	4000	 4852	 0.000355	 0.024237	 0.0	 691.0	 1304	 1304	 0.979227	 0.0	 1	 -30.0	 30.0;
	4000	 2012	 0.000375	 0.024247	 0.0	 691.0	 1303	 1303	 0.93617	 0.0	 1	 -30.0	 30.0;
	2183	 4852	 0.000365	 0.023267	 0.0	 691.0	 1358	 1358	 0.979227	 0.0	 1	 -30.0	 30.0;
	2183	 2012	 0.000342	 0.023139	 0.0	 691.0	 1365	 1365	 0.982143	 0.0	 1	 -30.0	 30.0;
	1642	 7098	 0.000344	 0.026666	 0.0	 691.0	 1185	 1185	 0.979227	 0.0	 1	 -30.0	 30.0;
	1642	 687	 0.000334	 0.027021	 0.0	 691.0	 1169	 1169	 0.93617	 0.0	 1	 -30.0	 30.0;
	809	 7098	 0.000302	 0.027615	 0.0	 691.0	 1144	 1144	 0.979227	 0.0	 1	 -30.0	 30.0;
	809	 687	 0.000313	 0.026135	 0.0	 691.0	 1209	 1209	 0.93617	 0.0	 1	 -30.0	 30.0;
	4594	 8804	 0.000365	 0.025905	 0.0	 691.0	 1220	 1220	 0.93617	 0.0	 1	 -30.0	 30.0;
	4594	 8804	 0.000355	 0.025238	 0.0	 691.0	 1252	 1252	 0.93617	 0.0	 1	 -30.0	 30.0;
	2919	 4215	 0.000334	 0.026814	 0.0	 691.0	 1178	 1178	 0.93617	 0.0	 1	 -30.0	 30.0;
	1142	 6577	 0.001242	 0.083148	 0.0	 380	 380	 380	 0.945477	 0.0	 1	 -30.0	 30.0;
	1142	 4137	 0.0017	 0.090508	 0.0	 349	 349	 349	 0.945477	 0.0	 1	 -30.0	 30.0;
	1930	 3448	 0.001648	 0.071935	 0.0	 670	 670	 670	 1.018675	 0.0	 1	 -30.0	 30.0;
	1930	 6445	 0.001742	 0.073131	 0.0	 659	 659	 659	 0.999333	 0.0	 1	 -30.0	 30.0;
	165	 7904	 0.000914	 0.088676	 0.0	 357	 357	 357	 0.986842	 0.0	 1	 -30.0	 30.0;
	165	 5140	 0.000955	 0.085404	 0.0	 370	 370	 370	 0.986842	 0.0	 1	 -30.0	 30.0;
	1786	 3879	 0.001479	 0.088626	 0.0	 357	 357	 357	 0.986842	 0.0	 1	 -30.0	 30.0;
	1786	 4210	 0.00153	 0.084928	 0.0	 372	 372	 372	 0.986842	 0.0	 1	 -30.0	 30.0;
	7228	 6121	 0.00151	 0.102577	 0.0	 470	 470	 470	 0.945477	 0.0	 1	 -30.0	 30.0;
	8171	 2528	 0.000884	 0.108054	 0.0	 447	 447	 447	 0.945477	 0.0	 1	 -30.0	 30.0;
	8345	 5553	 0.001099	 0.069265	 0.0	 696	 696	 696	 1.018675	 0.0	 1	 -30.0	 30.0;
	14	 2925	 0.000904	 0.088121	 0.0	 547	 547	 547	 0.986842	 0.0	 1	 -30.0	 30.0;
	4346	 2859	 0.001386	 0.094158	 0.0	 512	 512	 512	 0.986842	 0.0	 1	 -30.0	 30.0;
	4346	 2859	 0.001355	 0.096007	 0.0	 502	 502	 502	 0.986842	 0.0	 1	 -30.0	 30.0;
	4985	 1166	 0.001456	 0.098925	 0.0	 488	 488	 488	 0.962772	 0.0	 1	 -30.0	 30.0;
	4985	 1166	 0.001424	 0.100867	 0.0	 478	 478	 478	 0.962772	 0.0	 1	 -30.0	 30.0;
	1972	 1780	 0.001442	 0.086424	 0.0	 558	 558	 558	 0.999333	 0.0	 1	 -30.0	 30.0;
	1132	 8445	 0.001317	 0.070127	 0.0	 451	 451	 451	 1.074114	 0.0	 1	 -30.0	 30.0;
	603	 2617	 0.000991	 0.083602	 0.0	 577	 577	 577	 0.999333	 0.0	 1	 -30.0	 30.0;
	603	 2617	 0.001272	 0.097228	 0.0	 496	 496	 496	 0.999333	 0.0	 1	 -30.0	 30.0;
	603	 5798	 0.000968	 0.088836	 0.0	 543	 543	 543	 0.974659	 0.0	 1	 -30.0	 30.0;
	603	 5798	 0.001537	 0.08896	 0.0	 542	 542	 542	 0.974659	 0.0	 1	 -30.0	 30.0;
	603	 5798	 0.0018	 0.078579	 0.0	 614	 614	 614	 0.974659	 0.0	 1	 -30.0	 30.0;
	436	 2576	 0.001071	 0.079233	 0.0	 609	 609	 609	 0.999333	 0.0	 1	 -30.0	 30.0;
	5883	 3911	 0.001301	 0.088365	 0.0	 546	 546	 546	 1.018675	 0.0	 1	 -30.0	 30.0;
	5883	 4796	 0.001436	 0.082886	 0.0	 533	 533	 533	 1.018675	 0.0	 1	 -30.0	 30.0;
	5883	 3632	 0.001701	 0.102782	 0.0	 469	 469	 469	 0.923361	 0.0	 1	 -30.0	 30.0;
	8845	 8752	 0.001352	 0.091819	 0.0	 344	 344	 344	 0.999333	 0.0	 1	 -30.0	 30.0;
	1533	 1966	 0.001737	 0.085791	 0.0	 369	 369	 369	 0.962772	 0.0	 1	 -30.0	 30.0;
	1533	 3165	 0.001331	 0.087657	 0.0	 361	 361	 361	 0.945477	 0.0	 1	 -30.0	 30.0;
	1533	 1966	 0.001877	 0.07879	 0.0	 401	 401	 401	 0.962772	 0.0	 1	 -30.0	 30.0;
	1533	 4590	 0.001672	 0.089295	 0.0	 354	 354	 354	 0.962772	 0.0	 1	 -30.0	 30.0;
	1533	 3165	 0.001421	 0.10862	 0.0	 291	 291	 291	 0.945477	 0.0	 1	 -30.0	 30.0;
	1533	 4590	 0.001338	 0.09699	 0.0	 326	 326	 326	 0.962772	 0.0	 1	 -30.0	 30.0;
	3056	 5496	 0.001224	 0.093571	 0.0	 516	 516	 516	 1.018675	 0.0	 1	 -30.0	 30.0;
	2000	 2548	 0.001667	 0.092522	 0.0	 342	 342	 342	 0.945477	 0.0	 1	 -30.0	 30.0;
	2000	 1071	 0.0017	 0.090508	 0.0	 349	 349	 349	 0.945477	 0.0	 1	 -30.0	 30.0;
	2869	 3455	 0.001177	 0.089984	 0.0	 536	 536	 536	 1.038781	 0.0	 1	 -30.0	 30.0;
	6072	 9092	 0.000976	 0.083762	 0.0	 576	 576	 576	 0.986842	 0.0	 1	 -30.0	 30.0;
	6072	 2292	 0.001221	 0.074424	 0.0	 648	 648	 648	 0.974659	 0.0	 1	 -30.0	 30.0;
	5226	 8340	 0.001205	 0.088315	 0.0	 358	 358	 358	 1.038781	 0.0	 1	 -30.0	 30.0;
	2522	 8386	 0.000951	 0.081618	 0.0	 387	 387	 387	 0.999333	 0.0	 1	 -30.0	 30.0;
	2522	 5953	 0.0011	 0.085679	 0.0	 369	 369	 369	 0.962772	 0.0	 1	 -30.0	 30.0;
	2522	 5953	 0.000895	 0.099866	 0.0	 317	 317	 317	 0.962772	 0.0	 1	 -30.0	 30.0;
	4490	 2829	 0.0	 0.064	 0.0	 494	 494	 494	 0.937501	 0.0	 1	 -30.0	 30.0;
	4490	 2829	 0.0	 0.06267	 0.0	 505	 505	 505	 0.937501	 0.0	 1	 -30.0	 30.0;
	4490	 2829	 0.0	 0.06134	 0.0	 515	 515	 515	 0.937501	 0.0	 1	 -30.0	 30.0;
	1575	 4591	 0.0	 0.06295	 0.0	 502	 502	 502	 0.975	 0.0	 1	 -30.0	 30.0;
	1575	 4591	 0.0	 0.07135	 0.0	 443	 443	 443	 0.975	 0.0	 1	 -30.0	 30.0;
	3208	 2004	 0.0	 0.04729	 0.0	 668	 668	 668	 1.019713	 0.0	 1	 -30.0	 30.0;
	3208	 2004	 0.0	 0.0482	 0.0	 656	 656	 656	 1.019713	 0.0	 1	 -30.0	 30.0;
	3208	 2004	 0.0	 0.04911	 0.0	 644	 644	 644	 1.019713	 0.0	 1	 -30.0	 30.0;
	3371	 5721	 0.0	 0.06744	 0.0	 469	 469	 469	 0.980435	 0.0	 1	 -30.0	 30.0;
	7656	 738	 0.0	 0.145661	 0.0	 217	 217	 217	 1.052174	 0.0	 1	 -30.0	 30.0;
	8974	 825	 0.0	 0.03024	 0.0	 1045	 1045	 1045	 1.052632	 0.0	 1	 -30.0	 30.0;
	8974	 825	 0.0	 0.029729	 0.0	 1063	 1063	 1063	 1.052632	 0.0	 1	 -30.0	 30.0;
	825	 7111	 0.0	 0.07191	 0.0	 440	 440	 440	 0.937501	 0.0	 1	 -30.0	 30.0;
	825	 7111	 0.0	 0.0815	 0.0	 388	 388	 388	 0.937501	 0.0	 1	 -30.0	 30.0;
	9073	 2819	 0.0	 0.07843	 0.0	 403	 403	 403	 0.944565	 0.0	 1	 -30.0	 30.0;
	2502	 5229	 0.0	 0.033891	 0.0	 933	 933	 933	 1.052632	 0.0	 1	 -30.0	 30.0;
	2502	 5229	 0.0	 0.035419	 0.0	 892	 892	 892	 1.052632	 0.0	 1	 -30.0	 30.0;
	5229	 7916	 0.0	 0.07323	 0.0	 432	 432	 432	 0.980435	 0.0	 1	 -30.0	 30.0;
	5229	 7916	 0.0	 0.07177	 0.0	 441	 441	 441	 0.980435	 0.0	 1	 -30.0	 30.0;
	5501	 131	 0.0	 0.06789	 0.0	 466	 466	 466	 0.956521	 0.0	 1	 -30.0	 30.0;
	5501	 131	 0.0	 0.06524	 0.0	 485	 485	 485	 0.956521	 0.0	 1	 -30.0	 30.0;
	5501	 131	 0.0	 0.06385	 0.0	 495	 495	 495	 0.956521	 0.0	 1	 -30.0	 30.0;
	2649	 5585	 0.0	 0.04033	 0.0	 784	 784	 784	 1.052174	 0.0	 1	 -30.0	 30.0;
	5161	 3838	 0.0	 0.07024	 0.0	 450	 450	 450	 0.980435	 0.0	 1	 -30.0	 30.0;
	5161	 3838	 0.0	 0.07161	 0.0	 442	 442	 442	 0.980435	 0.0	 1	 -30.0	 30.0;
	6182	 861	 0.0	 0.06784	 0.0	 466	 466	 466	 1.0119	 0.0	 1	 -30.0	 30.0;
	3198	 8811	 0.0	 0.071916	 0.0	 440	 440	 440	 0.948274	 0.0	 1	 -30.0	 30.0;
	7008	 4583	 0.0	 0.07323	 0.0	 432	 432	 432	 0.991844	 0.0	 1	 -30.0	 30.0;
	7008	 4583	 0.0	 0.07177	 0.0	 441	 441	 441	 0.991844	 0.0	 1	 -30.0	 30.0;
	7081	 1928	 0.0	 0.0447	 0.0	 707	 707	 707	 1.052174	 0.0	 1	 -30.0	 30.0;
	7081	 1928	 0.0	 0.04377	 0.0	 722	 722	 722	 1.052174	 0.0	 1	 -30.0	 30.0;
	7081	 1928	 0.0	 0.04123	 0.0	 767	 767	 767	 1.052174	 0.0	 1	 -30.0	 30.0;
	2389	 8003	 0.0	 0.06295	 0.0	 502	 502	 502	 1.0	 0.0	 1	 -30.0	 30.0;
	2389	 8003	 0.0	 0.07135	 0.0	 443	 443	 443	 1.0	 0.0	 1	 -30.0	 30.0;
	2480	 181	 0.0	 0.07014	 0.0	 451	 451	 451	 0.932609	 0.0	 1	 -30.0	 30.0;
	2480	 181	 0.0	 0.07149	 0.0	 442	 442	 442	 0.932609	 0.0	 1	 -30.0	 30.0;
	1429	 4417	 0.0	 0.034531	 0.0	 915	 915	 915	 1.035087	 0.0	 1	 -30.0	 30.0;
	1429	 6856	 0.0	 0.04656	 0.0	 679	 679	 679	 1.007866	 0.0	 1	 -30.0	 30.0;
	1429	 6856	 0.0	 0.04563	 0.0	 693	 693	 693	 1.007866	 0.0	 1	 -30.0	 30.0;
	1809	 8416	 0.000229	 0.01234	 0.0	 1429.0	 3906	 3906	 0.859545	 0.0	 1	 -30.0	 30.0;
	1809	 8416	 0.000229	 0.0122	 0.0	 1494.0	 3950	 3950	 0.859545	 0.0	 1	 -30.0	 30.0;
	8526	 2840	 0.001485	 0.065805	 0.0	 480	 480	 480	 0.956938	 0.0	 1	 -30.0	 30.0;
	8526	 2840	 0.001583	 0.06586	 0.0	 480	 480	 480	 0.956938	 0.0	 1	 -30.0	 30.0;
	5284	 2840	 0.00175	 0.070701	 0.0	 447	 447	 447	 0.952381	 0.0	 1	 -30.0	 30.0;
	5284	 2840	 0.00169	 0.0715	 0.0	 442	 442	 442	 0.952381	 0.0	 1	 -30.0	 30.0;
	6743	 6609	 0.001228	 0.060916	 0.0	 519	 519	 519	 0.992489	 0.0	 1	 -30.0	 30.0;
	6743	 6609	 0.00116	 0.063798	 0.0	 496	 496	 496	 1.010798	 0.0	 1	 -30.0	 30.0;
	6743	 6609	 0.00113	 0.059295	 0.0	 533	 533	 533	 1.010736	 0.0	 1	 -30.0	 30.0;
	4998	 6609	 0.00177	 0.06853	 0.0	 461	 461	 461	 0.973143	 0.0	 1	 -30.0	 30.0;
	7458	 2173	 0.001363	 0.063835	 0.0	 495	 495	 495	 0.980349	 0.0	 1	 -30.0	 30.0;
	7458	 2173	 0.001457	 0.067155	 0.0	 471	 471	 471	 0.980349	 0.0	 1	 -30.0	 30.0;
	7679	 2173	 0.00193	 0.06377	 0.0	 496	 496	 496	 0.952381	 0.0	 1	 -30.0	 30.0;
	7679	 2173	 0.00194	 0.06188	 0.0	 511	 511	 511	 0.952381	 0.0	 1	 -30.0	 30.0;
	8715	 4912	 0.00045	 0.02807	 0.0	 1126	 1126	 1126	 1.002506	 0.0	 1	 -30.0	 30.0;
	8715	 2144	 0.00042	 0.028021	 0.0	 1128	 1128	 1128	 1.002506	 0.0	 1	 -30.0	 30.0;
	8580	 5624	 0.001208	 0.06631	 0.0	 477	 477	 477	 1.030783	 0.0	 1	 -30.0	 30.0;
	8580	 5624	 0.001228	 0.066264	 0.0	 477	 477	 477	 1.030783	 0.0	 1	 -30.0	 30.0;
	5850	 2858	 0.00047	 0.026469	 0.0	 1194	 1194	 1194	 1.002506	 0.0	 1	 -30.0	 30.0;
	8943	 7152	 0.00186	 0.06826	 0.0	 463	 463	 463	 0.931619	 0.0	 1	 -30.0	 30.0;
	569	 146	 0.001431	 0.068667	 0.0	 702	 702	 702	 0.956938	 0.0	 1	 -30.0	 30.0;
	569	 146	 0.001529	 0.068787	 0.0	 701	 701	 701	 0.956938	 0.0	 1	 -30.0	 30.0;
	3245	 146	 0.00193	 0.06377	 0.0	 756	 756	 756	 0.952381	 0.0	 1	 -30.0	 30.0;
	3245	 146	 0.00194	 0.06188	 0.0	 779	 779	 779	 0.952381	 0.0	 1	 -30.0	 30.0;
	3360	 5138	 0.0	 0.00898	 0.0	 3518	 3518	 3518	 0.0	 0.0	 1	 -30.0	 30.0;
	2578	 6334	 0.0	 0.00433	 0.0	 7295	 7295	 7295	 0.0	 0.0	 1	 -30.0	 30.0;
	6334	 4820	 0.007955	 0.151636	 0.0	 209	 209	 209	 0.929293	 0.0	 1	 -30.0	 30.0;
	7044	 402	 0.000271	 0.030694	 0.0	 1030	 1030	 1030	 1.052632	 0.0	 1	 -30.0	 30.0;
	7044	 402	 0.000271	 0.02842	 0.0	 1112	 1112	 1112	 1.052632	 0.0	 1	 -30.0	 30.0;
	2204	 672	 0.00064	 0.0518	 0.0	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	9006	 7212	 0.00072	 0.05075	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 8170	 0.0	 0.23657	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	8532	 6671	 0.0	 0.020113	 0.0	 1571	 1571	 1571	 1.006865	 0.0	 1	 -30.0	 30.0;
	8532	 8723	 0.0	 0.019669	 0.0	 1606	 1606	 1606	 1.006865	 0.0	 1	 -30.0	 30.0;
	3563	 6622	 0.000325	 0.028508	 0.0	 1108	 1108	 1108	 1.006865	 0.0	 1	 -30.0	 30.0;
	3563	 6622	 0.000316	 0.031545	 0.0	 1002	 1002	 1002	 1.006865	 0.0	 1	 -30.0	 30.0;
	9139	 3465	 0.000355	 0.023171	 0.0	 1364	 1364	 1364	 1.006865	 0.0	 1	 -30.0	 30.0;
	2756	 1468	 0.000296	 0.032897	 0.0	 961	 961	 961	 1.006865	 0.0	 1	 -30.0	 30.0;
	2756	 1468	 0.000296	 0.030461	 0.0	 1037	 1037	 1037	 1.006865	 0.0	 1	 -30.0	 30.0;
	2316	 1	 5.9e-05	 0.022767	 0.0	 1388	 1388	 1388	 1.006865	 0.0	 1	 -30.0	 30.0;
	1072	 6210	 0.000335	 0.029237	 0.0	 1081	 1081	 1081	 1.006865	 0.0	 1	 -30.0	 30.0;
	5747	 9068	 0.000385	 0.027846	 0.0	 1135	 1135	 1135	 1.006865	 0.0	 1	 -30.0	 30.0;
	3884	 6863	 0.000444	 0.020064	 0.0	 1574	 1574	 1574	 1.006865	 0.0	 1	 -30.0	 30.0;
	8375	 49	 0.00033	 0.02558	 0.0	 1235	 1235	 1235	 1.0	 0.0	 1	 -30.0	 30.0;
	7639	 5714	 0.0	 0.026909	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	7311	 7538	 0.000385	 0.022737	 0.0	 1390	 1390	 1390	 1.006865	 0.0	 1	 -30.0	 30.0;
	3068	 708	 0.000375	 0.022441	 0.0	 1408	 1408	 1408	 1.006865	 0.0	 1	 -30.0	 30.0;
	7922	 6129	 -0.002742	 0.00908	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	7922	 2956	 -0.00268	 0.00837	 0.0	 3595	 3595	 3595	 0.0	 0.0	 1	 -30.0	 30.0;
	7922	 6874	 -0.00304	 0.00824	 0.0	 3597	 3597	 3597	 0.0	 0.0	 1	 -30.0	 30.0;
	7197	 5398	 -0.003927	 0.00795	 0.0	 3563	 3563	 3563	 0.0	 0.0	 1	 -30.0	 30.0;
	7197	 6249	 -0.00401	 0.00794	 0.0	 3552	 3552	 3552	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 9000	 0.0	 0.00765	 0.0	 4130	 4130	 4130	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 1546	 0.0	 0.00748	 0.0	 4223	 4223	 4223	 0.0	 0.0	 1	 -30.0	 30.0;
	7359	 9167	 -0.000111	 0.00565	 0.0	 5590	 5590	 5590	 0.0	 0.0	 1	 -30.0	 30.0;
	7359	 4027	 -0.000339	 0.00645	 0.0	 4891	 4891	 4891	 0.0	 0.0	 1	 -30.0	 30.0;
	7359	 5841	 -0.000332	 0.00657	 0.0	 4802	 4802	 4802	 0.0	 0.0	 1	 -30.0	 30.0;
	7359	 4398	 -0.000118	 0.00525	 0.0	 6016	 6016	 6016	 0.0	 0.0	 1	 -30.0	 30.0;
	4836	 348	 0.00593	 0.0602	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	4836	 3227	 8e-05	 0.00811	 0.0	 3895	 3895	 3895	 0.0	 0.0	 1	 -30.0	 30.0;
	4836	 4994	 -0.003927	 0.00835	 0.0	 3424	 3424	 3424	 0.0	 0.0	 1	 -30.0	 30.0;
	2615	 7753	 0.0	 0.028951	 0.0	 1092	 1092	 1092	 1.006865	 0.0	 1	 -30.0	 30.0;
	2615	 3384	 0.0	 0.02833	 0.0	 1115	 1115	 1115	 1.006865	 0.0	 1	 -30.0	 30.0;
	99	 3024	 0.000424	 0.020212	 0.0	 1563	 1563	 1563	 1.006865	 0.0	 1	 -30.0	 30.0;
	4564	 1743	 0.00128	 0.05539	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	4564	 5572	 0.00126	 0.056469	 0.0	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	4564	 4075	 0.00123	 0.05756	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	1469	 289	 0.0	 0.046831	 0.0	 675	 675	 675	 0.0	 0.0	 1	 -30.0	 30.0;
	3123	 759	 0.0	 0.03197	 0.0	 989	 989	 989	 1.006865	 0.0	 1	 -30.0	 30.0;
	5109	 7103	 0.0	 0.027151	 0.0	 1164	 1164	 1164	 1.044622	 0.0	 1	 -30.0	 30.0;
	3699	 927	 0.0	 0.0197	 0.0	 1604	 1604	 1604	 0.0	 0.0	 1	 -30.0	 30.0;
	7248	 4283	 0.000335	 0.028458	 0.0	 1110	 1110	 1110	 1.006865	 0.0	 1	 -30.0	 30.0;
	7248	 4283	 0.000375	 0.027846	 0.0	 1135	 1135	 1135	 1.006865	 0.0	 1	 -30.0	 30.0;
	7564	 1170	 0.00073	 0.01489	 0.0	 2119	 2119	 2119	 0.0	 0.0	 1	 -30.0	 30.0;
	8876	 8157	 0.0	 0.00864	 0.0	 3656	 3656	 3656	 0.0	 0.0	 1	 -30.0	 30.0;
	8876	 1365	 0.0	 0.00881	 0.0	 3586	 3586	 3586	 0.0	 0.0	 1	 -30.0	 30.0;
	7182	 2040	 0.000325	 0.028961	 0.0	 1091	 1091	 1091	 1.006865	 0.0	 1	 -30.0	 30.0;
	3196	 6067	 0.000296	 0.025084	 0.0	 1260	 1260	 1260	 1.006865	 0.0	 1	 -30.0	 30.0;
	1224	 7494	 0.000325	 0.025765	 0.0	 1226	 1226	 1226	 1.006865	 0.0	 1	 -30.0	 30.0;
	1224	 7494	 0.000375	 0.020301	 0.0	 1556	 1556	 1556	 1.006865	 0.0	 1	 -30.0	 30.0;
	1224	 7494	 0.000345	 0.021109	 0.0	 1497	 1497	 1497	 1.006865	 0.0	 1	 -30.0	 30.0;
	3099	 127	 0.000385	 0.02101	 0.0	 1504	 1504	 1504	 1.006865	 0.0	 1	 -30.0	 30.0;
	1610	 7593	 0.000424	 0.019472	 0.0	 1622	 1622	 1622	 1.006865	 0.0	 1	 -30.0	 30.0;
	1610	 7593	 0.000434	 0.019048	 0.0	 1658	 1658	 1658	 1.006865	 0.0	 1	 -30.0	 30.0;
	6316	 4348	 0.000325	 0.025637	 0.0	 1233	 1233	 1233	 1.006865	 0.0	 1	 -30.0	 30.0;
	6316	 4348	 0.000355	 0.026564	 0.0	 1189	 1189	 1189	 1.006865	 0.0	 1	 -30.0	 30.0;
	660	 5532	 0.000355	 0.021553	 0.0	 1466	 1466	 1466	 1.006865	 0.0	 1	 -30.0	 30.0;
	660	 5532	 0.000128	 0.022007	 0.0	 1436	 1436	 1436	 1.006865	 0.0	 1	 -30.0	 30.0;
	835	 4680	 6e-05	 0.007574	 0.0	 1942.0	 4171	 4171	 0.0	 0.0	 1	 -30.0	 30.0;
	3449	 4680	 7e-05	 0.007392	 0.0	 1942.0	 4273	 4273	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 1034	 0.000395	 0.021454	 0.0	 1473	 1473	 1473	 1.006865	 0.0	 1	 -30.0	 30.0;
	4147	 3284	 -0.000388	 0.0074	 0.0	 4263	 4263	 4263	 0.0	 0.0	 1	 -30.0	 30.0;
	2332	 5059	 -0.000402	 0.00724	 0.0	 4357	 4357	 4357	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 1620	 -0.000589	 0.01411	 0.0	 2237	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	3348	 7947	 -0.00036	 0.00803	 0.0	 3930	 3930	 3930	 0.0	 0.0	 1	 -30.0	 30.0;
	8252	 6362	 0.0	 0.040449	 0.0	 781	 781	 781	 0.956938	 0.0	 1	 -30.0	 30.0;
	3963	 5493	 0.000345	 0.026071	 0.0	 1212	 1212	 1212	 1.006865	 0.0	 1	 -30.0	 30.0;
	2634	 8185	 0.0	 0.00046	 0.0	 68669	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 6910	 0.0	 0.00043	 0.0	 73459	 73459	 73459	 0.0	 0.0	 1	 -30.0	 30.0;
	875	 1867	 0.000375	 0.022007	 0.0	 1436	 1436	 1436	 1.006865	 0.0	 1	 -30.0	 30.0;
	946	 7403	 0.000385	 0.020196	 0.0	 1564	 1564	 1564	 0.993901	 0.0	 1	 -30.0	 30.0;
	5355	 7066	 0.000375	 0.026624	 0.0	 1187	 1187	 1187	 0.993901	 0.0	 1	 -30.0	 30.0;
	4414	 1423	 0.000425	 0.021208	 0.0	 1490	 1490	 1490	 0.993901	 0.0	 1	 -30.0	 30.0;
	8117	 2675	 0.000466	 0.020185	 0.0	 1565	 1565	 1565	 0.993901	 0.0	 1	 -30.0	 30.0;
	3874	 1613	 0.000324	 0.022139	 0.0	 1427	 1427	 1427	 0.993901	 0.0	 1	 -30.0	 30.0;
	3874	 1613	 0.000324	 0.022706	 0.0	 1392	 1392	 1392	 0.993901	 0.0	 1	 -30.0	 30.0;
	3874	 1613	 0.000314	 0.023142	 0.0	 1365	 1365	 1365	 0.993901	 0.0	 1	 -30.0	 30.0;
	9009	 7320	 0.000344	 0.024832	 0.0	 1272	 1272	 1272	 0.993901	 0.0	 1	 -30.0	 30.0;
	9009	 8484	 0.000334	 0.023071	 0.0	 1369	 1369	 1369	 0.993901	 0.0	 1	 -30.0	 30.0;
	2710	 368	 0.000335	 0.022767	 0.0	 1388	 1388	 1388	 1.006865	 0.0	 1	 -30.0	 30.0;
	2680	 339	 0.00071	 0.030845	 0.0	 1024	 1024	 1024	 1.006865	 0.0	 1	 -30.0	 30.0;
	3972	 6963	 0.000385	 0.019472	 0.0	 1622	 1622	 1622	 1.006865	 0.0	 1	 -30.0	 30.0;
	3972	 4126	 0.000395	 0.019057	 0.0	 1658	 1658	 1658	 1.006865	 0.0	 1	 -30.0	 30.0;
	3972	 1303	 0.000404	 0.018643	 0.0	 1694	 1694	 1694	 1.006865	 0.0	 1	 -30.0	 30.0;
	3972	 5114	 0.0	 0.027866	 0.0	 1134	 1134	 1134	 1.006865	 0.0	 1	 -30.0	 30.0;
	1684	 7574	 0.000325	 0.032245	 0.0	 980	 980	 980	 1.006865	 0.0	 1	 -30.0	 30.0;
	4330	 8509	 0.000365	 0.022599	 0.0	 1398	 1398	 1398	 1.006865	 0.0	 1	 -30.0	 30.0;
	4330	 8509	 0.000355	 0.023023	 0.0	 1372	 1372	 1372	 1.006865	 0.0	 1	 -30.0	 30.0;
	8524	 4017	 0.0	 0.032004	 0.0	 987	 987	 987	 1.045454	 0.0	 1	 -30.0	 30.0;
	6195	 4017	 0.00141	 0.103559	 0.0	 305	 305	 305	 0.882842	 -0.48891	 1	 -30.0	 30.0;
	2684	 2317	 0.000434	 0.019018	 0.0	 1661	 1661	 1661	 1.006865	 0.0	 1	 -30.0	 30.0;
	6460	 8774	 0.000404	 0.020497	 0.0	 1541	 1541	 1541	 1.006865	 0.0	 1	 -30.0	 30.0;
	5623	 7633	 0.00074	 0.029553	 0.0	 1069	 1069	 1069	 1.006865	 0.0	 1	 -30.0	 30.0;
	1031	 1688	 0.000454	 0.019669	 0.0	 1606	 1606	 1606	 1.006865	 0.0	 1	 -30.0	 30.0;
	4810	 2729	 0.00206	 0.09005	 0.0	 351	 351	 351	 1.0	 0.0	 1	 -30.0	 30.0;
	3262	 246	 0.00039	 0.03411	 0.0	 1413	 1413	 1413	 1.052632	 0.0	 1	 -30.0	 30.0;
	3262	 246	 0.0004	 0.034469	 0.0	 1399	 1399	 1399	 1.052632	 0.0	 1	 -30.0	 30.0;
	8496	 4270	 0.00183	 0.090471	 0.0	 350	 350	 350	 1.026087	 0.0	 1	 -30.0	 30.0;
	8496	 4270	 0.00187	 0.07429	 0.0	 426	 426	 426	 1.026087	 0.0	 1	 -30.0	 30.0;
	7674	 1874	 0.00077	 0.04355	 0.0	 1107	 1107	 1107	 0.999313	 0.0	 1	 -30.0	 30.0;
	7674	 1874	 0.00077	 0.04266	 0.0	 1130	 1130	 1130	 0.999313	 0.0	 1	 -30.0	 30.0;
	7330	 7033	 0.00116	 0.04106	 0.0	 1075	 1075	 1075	 1.052632	 0.0	 1	 -30.0	 30.0;
	7330	 7033	 0.00118	 0.04119	 0.0	 1071	 1071	 1071	 1.052632	 0.0	 1	 -30.0	 30.0;
	8344	 2950	 0.0012	 0.03931	 0.0	 1226	 1226	 1226	 1.052632	 0.0	 1	 -30.0	 30.0;
	8344	 2950	 0.00107	 0.04567	 0.0	 1056	 1056	 1056	 1.052632	 0.0	 1	 -30.0	 30.0;
	6860	 6573	 0.002282	 0.077224	 0.0	 409	 409	 409	 0.942174	 0.0	 1	 -30.0	 30.0;
	4208	 6573	 0.00102	 0.04862	 0.0	 992	 992	 992	 1.052632	 0.0	 1	 -30.0	 30.0;
	4208	 6573	 0.001	 0.04954	 0.0	 973	 973	 973	 1.052632	 0.0	 1	 -30.0	 30.0;
	3259	 1710	 0.00098	 0.04477	 0.0	 1077	 1077	 1077	 1.052632	 0.0	 1	 -30.0	 30.0;
	3259	 1710	 0.00111	 0.04387	 0.0	 1099	 1099	 1099	 1.052632	 0.0	 1	 -30.0	 30.0;
	3146	 5593	 0.00113	 0.04193	 0.0	 1150	 1150	 1150	 1.052632	 0.0	 1	 -30.0	 30.0;
	8859	 5251	 0.002522	 0.074933	 0.0	 422	 422	 422	 1.013913	 0.0	 1	 -30.0	 30.0;
	1392	 5001	 0.001252	 0.073601	 0.0	 430	 430	 430	 0.94	 0.0	 1	 -30.0	 30.0;
	3538	 5001	 0.001271	 0.072001	 0.0	 439	 439	 439	 0.94	 0.0	 1	 -30.0	 30.0;
	8249	 6139	 0.000442	 0.040802	 0.0	 775	 775	 775	 0.88	 0.0	 1	 -30.0	 30.0;
	806	 91	 0.00048	 0.041601	 0.0	 760	 760	 760	 0.97	 0.0	 1	 -30.0	 30.0;
	1747	 6998	 0.000543	 0.04261	 0.0	 742	 742	 742	 1.0	 0.0	 1	 -30.0	 30.0;
	593	 6998	 0.000534	 0.04342	 0.0	 728	 728	 728	 1.0	 0.0	 1	 -30.0	 30.0;
	8432	 6295	 0.003895	 0.040564	 0.0	 776	 776	 776	 0.97	 0.0	 1	 -30.0	 30.0;
	8432	 6295	 0.004413	 0.039762	 0.0	 790	 790	 790	 0.97	 0.0	 1	 -30.0	 30.0;
	8432	 6295	 0.004498	 0.038954	 0.0	 806	 806	 806	 0.97	 0.0	 1	 -30.0	 30.0;
	3190	 7090	 0.000621	 0.0376	 0.0	 840	 840	 840	 1.0	 0.0	 1	 -30.0	 30.0;
	3484	 7090	 0.00063	 0.0368	 0.0	 859	 859	 859	 1.0	 0.0	 1	 -30.0	 30.0;
	3484	 7844	 0.00064	 0.036	 0.0	 878	 878	 878	 1.0	 0.0	 1	 -30.0	 30.0;
	281	 3960	 0.000555	 0.040801	 0.0	 775	 775	 775	 0.984999	 0.0	 1	 -30.0	 30.0;
	8086	 1477	 0.000546	 0.0416	 0.0	 760	 760	 760	 0.984999	 0.0	 1	 -30.0	 30.0;
	8086	 8037	 0.000527	 0.0424	 0.0	 745	 745	 745	 0.984999	 0.0	 1	 -30.0	 30.0;
	5008	 6354	 0.000456	 0.043201	 0.0	 732	 732	 732	 0.97	 0.0	 1	 -30.0	 30.0;
	5008	 6354	 0.000447	 0.040001	 0.0	 790	 790	 790	 0.97	 0.0	 1	 -30.0	 30.0;
	919	 6354	 0.000505	 0.039202	 0.0	 806	 806	 806	 0.97	 0.0	 1	 -30.0	 30.0;
	919	 6354	 0.000513	 0.038402	 0.0	 823	 823	 823	 0.97	 0.0	 1	 -30.0	 30.0;
	4825	 7884	 0.000513	 0.037602	 0.0	 840	 840	 840	 0.954999	 0.0	 1	 -30.0	 30.0;
	3023	 7884	 0.00052	 0.036802	 0.0	 859	 859	 859	 0.954999	 0.0	 1	 -30.0	 30.0;
	6345	 7884	 0.000529	 0.036002	 0.0	 878	 878	 878	 0.954999	 0.0	 1	 -30.0	 30.0;
	8114	 8738	 0.000473	 0.040802	 0.0	 775	 775	 775	 0.984999	 0.0	 1	 -30.0	 30.0;
	8773	 8738	 0.000465	 0.041601	 0.0	 760	 760	 760	 0.984999	 0.0	 1	 -30.0	 30.0;
	4059	 6282	 7e-05	 0.021201	 0.0	 790.0	 1490	 1490	 1.0	 0.0	 1	 -30.0	 30.0;
	2002	 4340	 7e-05	 0.021599	 0.0	 790.0	 1463	 1463	 1.0	 0.0	 1	 -30.0	 30.0;
	5165	 3363	 0.00054	 0.04	 0.0	 790	 790	 790	 0.98421	 0.0	 1	 -30.0	 30.0;
	5165	 3363	 0.000472	 0.039202	 0.0	 806	 806	 806	 0.984999	 0.0	 1	 -30.0	 30.0;
	2722	 3363	 0.00048	 0.038402	 0.0	 823	 823	 823	 0.984999	 0.0	 1	 -30.0	 30.0;
	2722	 3363	 0.00064	 0.0376	 0.0	 840	 840	 840	 0.98421	 0.0	 1	 -30.0	 30.0;
	1591	 1124	 0.000333	 0.029441	 0.0	 1073	 1073	 1073	 0.925	 0.0	 1	 -30.0	 30.0;
	5558	 8510	 0.000353	 0.028801	 0.0	 1097	 1097	 1097	 0.925	 0.0	 1	 -30.0	 30.0;
	5558	 8510	 0.000312	 0.032641	 0.0	 968	 968	 968	 0.925	 0.0	 1	 -30.0	 30.0;
	1689	 8814	 0.000529	 0.041601	 0.0	 760	 760	 760	 0.94	 0.0	 1	 -30.0	 30.0;
	8230	 8814	 0.000511	 0.042401	 0.0	 745	 745	 745	 0.94	 0.0	 1	 -30.0	 30.0;
	8393	 7565	 0.000633	 0.051521	 0.0	 614	 614	 614	 0.94	 0.0	 1	 -30.0	 30.0;
	8393	 7565	 0.000616	 0.047701	 0.0	 663	 663	 663	 0.94	 0.0	 1	 -30.0	 30.0;
	139	 7565	 0.000701	 0.046752	 0.0	 676	 676	 676	 0.94	 0.0	 1	 -30.0	 30.0;
	3257	 6058	 0.000811	 0.04579	 0.0	 690	 690	 690	 0.98871	 0.0	 1	 -30.0	 30.0;
	369	 6058	 0.000831	 0.04484	 0.0	 705	 705	 705	 0.98871	 0.0	 1	 -30.0	 30.0;
	369	 6058	 0.000841	 0.043881	 0.0	 720	 720	 720	 0.98871	 0.0	 1	 -30.0	 30.0;
	6068	 7450	 0.000621	 0.036001	 0.0	 878	 878	 878	 1.015	 0.0	 1	 -30.0	 30.0;
	6068	 2271	 0.000555	 0.040801	 0.0	 775	 775	 775	 1.015	 0.0	 1	 -30.0	 30.0;
	6263	 3846	 0.000563	 0.0416	 0.0	 760	 760	 760	 1.015	 0.0	 1	 -30.0	 30.0;
	1788	 1020	 0.000543	 0.0424	 0.0	 745	 745	 745	 1.015	 0.0	 1	 -30.0	 30.0;
	2824	 211	 0.001026	 0.086398	 0.0	 366	 366	 366	 0.97	 0.0	 1	 -30.0	 30.0;
	140	 211	 0.001007	 0.080001	 0.0	 395	 395	 395	 0.955	 0.0	 1	 -30.0	 30.0;
	3210	 1670	 0.000522	 0.039201	 0.0	 806	 806	 806	 0.954999	 0.0	 1	 -30.0	 30.0;
	5674	 1670	 0.00053	 0.038401	 0.0	 823	 823	 823	 0.954999	 0.0	 1	 -30.0	 30.0;
	4337	 1670	 0.000548	 0.037601	 0.0	 840	 840	 840	 0.94	 0.0	 1	 -30.0	 30.0;
	4779	 1956	 3e-05	 0.006499	 0.0	 4861	 4861	 4861	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 4302	 0.000907	 0.042929	 0.0	 736	 736	 736	 0.97	 0.0	 1	 -30.0	 30.0;
	4858	 4248	 7.7e-05	 0.0204	 0.0	 724.0	 1549	 1549	 1.105	 0.0	 1	 -30.0	 30.0;
	7235	 4858	 3e-05	 0.007522	 0.0	 4200	 4200	 4200	 0.995481	 -0.09511	 1	 -30.0	 30.0;
	4248	 4302	 0.000773	 0.05056	 0.0	 625	 625	 625	 0.97	 0.0	 1	 -30.0	 30.0;
	5897	 2720	 0.000728	 0.043197	 0.0	 732	 732	 732	 1.045	 0.0	 1	 -30.0	 30.0;
	420	 243	 0.000447	 0.040001	 0.0	 790	 790	 790	 1.045	 0.0	 1	 -30.0	 30.0;
	8898	 6052	 0.00061	 0.0392	 0.0	 806	 806	 806	 1.03	 0.0	 1	 -30.0	 30.0;
	5311	 8668	 0.001203	 0.076801	 0.0	 412	 412	 412	 1.03	 0.0	 1	 -30.0	 30.0;
	3891	 8668	 0.001223	 0.075201	 0.0	 420	 420	 420	 1.03	 0.0	 1	 -30.0	 30.0;
	662	 7073	 0.004533	 0.037356	 0.0	 840	 840	 840	 0.984999	 0.0	 1	 -30.0	 30.0;
	6017	 349	 0.004615	 0.036549	 0.0	 858	 858	 858	 0.984999	 0.0	 1	 -30.0	 30.0;
	6766	 7156	 0.004113	 0.041392	 0.0	 760	 760	 760	 0.984999	 0.0	 1	 -30.0	 30.0;
	4077	 7442	 0.000627	 0.041599	 0.0	 760	 760	 760	 1.039999	 0.0	 1	 -30.0	 30.0;
	1052	 8277	 0.001048	 0.084802	 0.0	 373	 373	 373	 1.045	 0.0	 1	 -30.0	 30.0;
	3878	 8277	 0.001029	 0.086397	 0.0	 366	 366	 366	 1.045	 0.0	 1	 -30.0	 30.0;
	76	 5346	 0.000808	 0.047709	 0.0	 662	 662	 662	 1.0	 0.0	 1	 -30.0	 30.0;
	4485	 3000	 0.00061	 0.0392	 0.0	 806	 806	 806	 1.015	 0.0	 1	 -30.0	 30.0;
	4485	 3000	 0.00062	 0.0384	 0.0	 823	 823	 823	 1.015	 0.0	 1	 -30.0	 30.0;
	6283	 3000	 0.00064	 0.0376	 0.0	 840	 840	 840	 1.015	 0.0	 1	 -30.0	 30.0;
	395	 4082	 0.00063	 0.0368	 0.0	 859	 859	 859	 0.984999	 0.0	 1	 -30.0	 30.0;
	5843	 5246	 0.00064	 0.036	 0.0	 878	 878	 878	 0.984999	 0.0	 1	 -30.0	 30.0;
	5843	 5246	 0.000573	 0.0408	 0.0	 775	 775	 775	 0.984999	 0.0	 1	 -30.0	 30.0;
	6477	 2478	 0.001067	 0.083199	 0.0	 380	 380	 380	 1.0	 0.0	 1	 -30.0	 30.0;
	5295	 2478	 0.001048	 0.084802	 0.0	 373	 373	 373	 1.0	 0.0	 1	 -30.0	 30.0;
	1443	 6268	 6e-05	 0.11487	 0.0	 275	 275	 275	 1.0	 0.0	 1	 -30.0	 30.0;
	4638	 6268	 0.20187	 1.758347	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	1315	 3848	 0.03911	 0.342562	 0.0	 140	 140	 140	 1.0	 0.0	 1	 -30.0	 30.0;
	2997	 4595	 0.01564	 0.58593	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	2997	 4581	 -0.000248	 0.227727	 0.0	 212	 212	 212	 1.0	 0.0	 1	 -30.0	 30.0;
	6190	 977	 0.01414	 0.513223	 0.0	 62	 62	 62	 1.0	 0.0	 1	 -30.0	 30.0;
	3676	 977	 -0.007335	 0.347624	 0.0	 91	 91	 91	 1.0	 0.0	 1	 -30.0	 30.0;
	5505	 977	 -0.006901	 0.404112	 0.0	 79	 79	 79	 1.0	 0.0	 1	 -30.0	 30.0;
	7625	 3438	 0.051021	 0.452583	 0.0	 70	 70	 70	 1.0	 0.0	 1	 -30.0	 30.0;
	3797	 638	 0.586797	 1.843698	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 638	 0.487562	 1.572644	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	4847	 638	 0.12936	 0.588864	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	6238	 4163	 0.000246	 0.025121	 0.0	 1258	 1258	 1258	 0.963066	 0.0	 1	 -30.0	 30.0;
	4638	 7293	 0.10005	 1.276798	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	3676	 7293	 0.21936	 1.401591	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	5505	 7293	 0.22688	 1.394834	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	1443	 2509	 0.04986	 0.379174	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	3797	 966	 0.02303	 0.62419	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	3797	 2604	 0.03435	 0.639633	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	248	 8449	 0.01742	 0.603616	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	4244	 8449	 0.14245	 1.97967	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	1110	 8449	 -0.000145	 0.32938	 0.0	 96	 96	 96	 1.0	 0.0	 1	 -30.0	 30.0;
	4533	 3219	 -0.000298	 0.102701	 0.0	 470	 470	 470	 1.0	 0.0	 1	 -30.0	 30.0;
	3147	 6634	 0.000708	 0.03271	 0.0	 1474	 1474	 1474	 1.065848	 0.0	 1	 -30.0	 30.0;
	3147	 7854	 0.06719	 0.834339	 0.0	 58	 58	 58	 1.0	 0.0	 1	 -30.0	 30.0;
	6109	 2274	 0.050909	 0.307686	 0.0	 102	 102	 102	 1.0	 0.0	 1	 -30.0	 30.0;
	993	 2274	 0.212521	 0.943657	 0.0	 33	 33	 33	 1.0	 0.0	 1	 -30.0	 30.0;
	4257	 8387	 -0.002652	 0.490201	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	4257	 5640	 0.02628	 0.438469	 0.0	 72	 72	 72	 1.0	 0.0	 1	 -30.0	 30.0;
	5462	 8387	 -0.008241	 0.388947	 0.0	 82	 82	 82	 1.0	 0.0	 1	 -30.0	 30.0;
	7553	 8387	 0.000226	 0.024837	 0.0	 1272	 1272	 1272	 1.039739	 0.0	 1	 -30.0	 30.0;
	2758	 8387	 0.106109	 0.699359	 0.0	 45	 45	 45	 1.0	 0.0	 1	 -30.0	 30.0;
	2758	 5640	 0.02855	 0.418988	 0.0	 76	 76	 76	 1.0	 0.0	 1	 -30.0	 30.0;
	1110	 328	 0.292479	 1.229545	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 3219	 0.757066	 1.631798	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	4847	 3219	 0.384752	 1.021653	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	5209	 4695	 -0.014297	 0.212851	 0.0	 149	 149	 149	 1.0	 0.0	 1	 -30.0	 30.0;
	5209	 4695	 0.000444	 0.031171	 0.0	 1014	 1014	 1014	 0.974118	 0.0	 1	 -30.0	 30.0;
	5209	 3515	 -0.014091	 0.217459	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	7625	 6100	 0.00894	 0.300393	 0.0	 106	 106	 106	 1.0	 0.0	 1	 -30.0	 30.0;
	8822	 8971	 0.049771	 0.546674	 0.0	 58	 58	 58	 1.0	 0.0	 1	 -30.0	 30.0;
	2216	 8652	 0.000737	 0.026925	 0.0	 1790	 1790	 1790	 1.059199	 0.0	 1	 -30.0	 30.0;
	2216	 8652	 0.000845	 0.026029	 0.0	 1851	 1851	 1851	 1.059199	 0.0	 1	 -30.0	 30.0;
	8822	 3084	 0.05157	 0.475537	 0.0	 67	 67	 67	 1.0	 0.0	 1	 -30.0	 30.0;
	7625	 2771	 0.054781	 0.446446	 0.0	 71	 71	 71	 1.0	 0.0	 1	 -30.0	 30.0;
	3454	 2013	 0.000452	 0.023578	 0.0	 1340	 1340	 1340	 0.979739	 0.0	 1	 -30.0	 30.0;
	3368	 2862	 -0.010579	 0.27814	 0.0	 114	 114	 114	 1.0	 0.0	 1	 -30.0	 30.0;
	3368	 5075	 -0.007004	 0.324484	 0.0	 98	 98	 98	 1.0	 0.0	 1	 -30.0	 30.0;
	4244	 8610	 -0.034029	 0.423698	 0.0	 75	 75	 75	 1.0	 0.0	 1	 -30.0	 30.0;
	2835	 1492	 0.000384	 0.0242	 0.0	 1306	 1306	 1306	 1.027158	 0.0	 1	 -30.0	 30.0;
	1443	 1492	 0.299587	 1.849794	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	1443	 5305	 0.301095	 1.740868	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	1103	 4844	 0.000759	 0.019191	 0.0	 921.0	 1645	 1645	 1.046145	 0.0	 1	 -30.0	 30.0;
	248	 7025	 0.170173	 0.568199	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	7625	 6708	 0.00708	 0.453843	 0.0	 70	 70	 70	 1.0	 0.0	 1	 -30.0	 30.0;
	8822	 6708	 0.057719	 0.644008	 0.0	 49	 49	 49	 1.0	 0.0	 1	 -30.0	 30.0;
	7089	 7025	 0.077609	 0.938223	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	1110	 7025	 0.200409	 0.618946	 0.0	 49	 49	 49	 1.0	 0.0	 1	 -30.0	 30.0;
	7625	 3404	 0.152771	 0.863657	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	8822	 3404	 -0.001921	 0.311818	 0.0	 102	 102	 102	 1.0	 0.0	 1	 -30.0	 30.0;
	1110	 578	 0.305992	 1.948119	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	8822	 5513	 0.17005	 0.993099	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	5479	 1719	 0.000257	 0.029742	 0.0	 691.0	 1063	 1063	 0.963066	 0.0	 1	 -30.0	 30.0;
	5479	 3251	 0.000268	 0.029134	 0.0	 691.0	 1085	 1085	 0.968561	 0.0	 1	 -30.0	 30.0;
	3762	 4468	 -0.014277	 0.154039	 0.0	 205	 205	 205	 1.0	 0.0	 1	 -30.0	 30.0;
	3762	 4468	 0.000738	 0.031616	 0.0	 999	 999	 999	 0.967563	 0.0	 1	 -30.0	 30.0;
	499	 4468	 0.251178	 0.958099	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	3762	 378	 0.08599	 0.668788	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	3930	 7854	 0.000241	 0.02217	 0.0	 1425	 1425	 1425	 0.996999	 0.0	 1	 -30.0	 30.0;
	499	 2250	 -0.003678	 0.380909	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	8685	 2250	 -0.011302	 0.627045	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	499	 3411	 0.00797	 0.426157	 0.0	 75	 75	 75	 1.0	 0.0	 1	 -30.0	 30.0;
	8685	 3411	 0.058159	 0.835806	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	499	 2539	 0.00907	 0.406178	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	8685	 2539	 0.059789	 0.790103	 0.0	 40	 40	 40	 1.0	 0.0	 1	 -30.0	 30.0;
	499	 378	 0.04738	 0.355028	 0.0	 89	 89	 89	 1.0	 0.0	 1	 -30.0	 30.0;
	499	 5386	 0.00166	 0.210118	 0.0	 151	 151	 151	 1.0	 0.0	 1	 -30.0	 30.0;
	993	 770	 0.000234	 0.03334	 0.0	 948	 948	 948	 0.974118	 0.0	 1	 -30.0	 30.0;
	993	 7890	 -0.007978	 0.33365	 0.0	 95	 95	 95	 1.0	 0.0	 1	 -30.0	 30.0;
	993	 1507	 -0.007673	 0.339439	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	8685	 3015	 0.000213	 0.026084	 0.0	 1211	 1211	 1211	 0.952263	 0.0	 1	 -30.0	 30.0;
	8685	 378	 0.079162	 0.676053	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	8685	 3782	 -0.012742	 0.556163	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	8685	 5386	 0.05625	 0.586697	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	1315	 3953	 0.11012	 1.389876	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	4244	 3326	 0.12839	 0.634174	 0.0	 49	 49	 49	 1.0	 0.0	 1	 -30.0	 30.0;
	4244	 3326	 0.000265	 0.029415	 0.0	 1074	 1074	 1074	 0.963066	 0.0	 1	 -30.0	 30.0;
	2948	 2573	 0.01031	 0.165651	 0.0	 191	 191	 191	 1.0	 0.0	 1	 -30.0	 30.0;
	791	 6937	 0.000906	 0.032368	 0.0	 976	 976	 976	 1.052632	 0.0	 1	 -30.0	 30.0;
	3368	 6937	 0.258574	 1.91281	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	2997	 8537	 0.114169	 0.69781	 0.0	 69	 69	 69	 1.0	 0.0	 1	 -30.0	 30.0;
	1110	 7298	 0.215475	 0.921488	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	1110	 262	 0.000388	 0.026559	 0.0	 1190	 1190	 1190	 1.020981	 0.0	 1	 -30.0	 30.0;
	1110	 262	 -0.012727	 0.168081	 0.0	 188	 188	 188	 1.0	 0.0	 1	 -30.0	 30.0;
	1110	 6169	 0.11171	 0.548317	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	2948	 3782	 0.04893	 0.453587	 0.0	 70	 70	 70	 1.0	 0.0	 1	 -30.0	 30.0;
	2997	 5158	 0.000427	 0.025869	 0.0	 1863	 1863	 1863	 1.059199	 0.0	 1	 -30.0	 30.0;
	2997	 8758	 0.000379	 0.029319	 0.0	 1644	 1644	 1644	 1.065848	 0.0	 1	 -30.0	 30.0;
	7625	 3003	 0.086233	 0.611399	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	7625	 3991	 0.03295	 0.399238	 0.0	 79	 79	 79	 1.0	 0.0	 1	 -30.0	 30.0;
	8822	 5656	 0.034401	 0.560661	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	5822	 2553	 0.04848	 0.4525	 0.0	 106	 106	 106	 1.0	 0.0	 1	 -30.0	 30.0;
	5822	 4051	 0.05627	 0.448553	 0.0	 107	 107	 107	 1.0	 0.0	 1	 -30.0	 30.0;
	27	 173	 0.000262	 0.020993	 0.0	 1505	 1505	 1505	 1.03341	 0.0	 1	 -30.0	 30.0;
	4847	 173	 0.093521	 0.726302	 0.0	 44	 44	 44	 1.0	 0.0	 1	 -30.0	 30.0;
	4847	 6601	 0.170831	 0.824835	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	1315	 3991	 0.05836	 0.35759	 0.0	 134	 134	 134	 1.0	 0.0	 1	 -30.0	 30.0;
	8401	 3003	 0.000563	 0.031553	 0.0	 1001	 1001	 1001	 1.002888	 0.0	 1	 -30.0	 30.0;
	4847	 3607	 0.04447	 0.619827	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	6504	 3341	 0.001519	 0.050701	 0.0	 623	 623	 623	 1.013513	 0.0	 1	 -30.0	 30.0;
	130	 5452	 0.000821	 0.051524	 0.0	 613	 613	 613	 1.052632	 0.0	 1	 -30.0	 30.0;
	130	 5452	 0.000803	 0.047869	 0.0	 660	 660	 660	 1.052632	 0.0	 1	 -30.0	 30.0;
	441	 2233	 0.000466	 0.029318	 0.0	 1078	 1078	 1078	 1.025291	 0.0	 1	 -30.0	 30.0;
	8088	 4721	 0.000463	 0.028006	 0.0	 1128	 1128	 1128	 1.038781	 0.0	 1	 -30.0	 30.0;
	8088	 4721	 0.000463	 0.026569	 0.0	 1189	 1189	 1189	 1.038781	 0.0	 1	 -30.0	 30.0;
	3080	 8789	 0.000556	 0.030088	 0.0	 1050	 1050	 1050	 1.08147	 0.0	 1	 -30.0	 30.0;
	3080	 8789	 0.000581	 0.029019	 0.0	 1089	 1089	 1089	 1.08147	 0.0	 1	 -30.0	 30.0;
	5825	 702	 0.0017	 0.077979	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	8224	 5517	 0.000569	 0.046371	 0.0	 682	 682	 682	 1.052632	 0.0	 1	 -30.0	 30.0;
	8224	 5517	 0.00056	 0.047255	 0.0	 669	 669	 669	 1.052632	 0.0	 1	 -30.0	 30.0;
	536	 4344	 0.0008	 0.050159	 0.0	 630	 630	 630	 1.066857	 0.0	 1	 -30.0	 30.0;
	6080	 5006	 0.000379	 0.039836	 0.0	 793	 793	 793	 1.052632	 0.0	 1	 -30.0	 30.0;
	6080	 5006	 0.000433	 0.039042	 0.0	 810	 810	 810	 1.052632	 0.0	 1	 -30.0	 30.0;
	1899	 7358	 0.000448	 0.032183	 0.0	 982	 982	 982	 1.066857	 0.0	 1	 -30.0	 30.0;
	4712	 1250	 0.000498	 0.034255	 0.0	 923	 923	 923	 1.041667	 0.0	 1	 -30.0	 30.0;
	4712	 1250	 0.000507	 0.033509	 0.0	 943	 943	 943	 1.041667	 0.0	 1	 -30.0	 30.0;
	6187	 2407	 0.000415	 0.040631	 0.0	 778	 778	 778	 1.052632	 0.0	 1	 -30.0	 30.0;
	6187	 2407	 0.000406	 0.041434	 0.0	 763	 763	 763	 1.052632	 0.0	 1	 -30.0	 30.0;
	5562	 1407	 0.000397	 0.037986	 0.0	 832	 832	 832	 1.052632	 0.0	 1	 -30.0	 30.0;
	7827	 1974	 0.000322	 0.035886	 0.0	 881	 881	 881	 1.043149	 0.0	 1	 -30.0	 30.0;
	1025	 8926	 0.000408	 0.039074	 0.0	 809	 809	 809	 0.989653	 0.0	 1	 -30.0	 30.0;
	6298	 6795	 0.000417	 0.026115	 0.0	 1210	 1210	 1210	 1.062288	 0.0	 1	 -30.0	 30.0;
	6298	 6795	 0.000443	 0.02577	 0.0	 1226	 1226	 1226	 1.062288	 0.0	 1	 -30.0	 30.0;
	3007	 6254	 0.000396	 0.033918	 0.0	 932	 932	 932	 1.02924	 0.0	 1	 -30.0	 30.0;
	7969	 177	 0.000406	 0.023438	 0.0	 1348	 1348	 1348	 1.052632	 0.0	 1	 -30.0	 30.0;
	7969	 177	 0.000352	 0.026759	 0.0	 1181	 1181	 1181	 1.052632	 0.0	 1	 -30.0	 30.0;
	1703	 7503	 0.000334	 0.036651	 0.0	 862	 862	 862	 1.052632	 0.0	 1	 -30.0	 30.0;
	1703	 7503	 0.000334	 0.037354	 0.0	 846	 846	 846	 1.052632	 0.0	 1	 -30.0	 30.0;
	4704	 4170	 0.000305	 0.035675	 0.0	 886	 886	 886	 1.087225	 0.0	 1	 -30.0	 30.0;
	4704	 4170	 0.000296	 0.033035	 0.0	 957	 957	 957	 1.087225	 0.0	 1	 -30.0	 30.0;
	4704	 4170	 0.000338	 0.032376	 0.0	 976	 976	 976	 1.087225	 0.0	 1	 -30.0	 30.0;
	2031	 8493	 0.000285	 0.02604	 0.0	 1213	 1213	 1213	 1.199891	 0.0	 1	 -30.0	 30.0;
	1025	 1239	 0.000419	 0.02814	 0.0	 1123	 1123	 1123	 0.989653	 0.0	 1	 -30.0	 30.0;
	3007	 9136	 0.000453	 0.025129	 0.0	 1257	 1257	 1257	 1.02924	 0.0	 1	 -30.0	 30.0;
	3007	 4650	 0.000453	 0.02528	 0.0	 1250	 1250	 1250	 1.02924	 0.0	 1	 -30.0	 30.0;
	5050	 1996	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	5050	 1298	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	1360	 5741	 0.00172	 0.099322	 0.0	 318	 318	 318	 1.052632	 0.0	 1	 -30.0	 30.0;
	1360	 5741	 0.00168	 0.101198	 0.0	 313	 313	 313	 1.052632	 0.0	 1	 -30.0	 30.0;
	8820	 6205	 0.00363	 0.146413	 0.0	 216	 216	 216	 1.049587	 0.0	 1	 -30.0	 30.0;
	8820	 6205	 0.00182	 0.07175	 0.0	 441	 441	 441	 1.049587	 0.0	 1	 -30.0	 30.0;
	1732	 456	 0.0019	 0.08995	 0.0	 352	 352	 352	 1.052632	 0.0	 1	 -30.0	 30.0;
	4746	 5447	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	4746	 850	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	4187	 7499	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	3731	 760	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	5537	 6063	 0.00167	 0.0776	 0.0	 407	 407	 407	 1.049587	 0.0	 1	 -30.0	 30.0;
	7418	 3120	 0.000646	 0.038909	 0.0	 812	 812	 812	 1.002832	 -0.000564	 1	 -30.0	 30.0;
	7418	 3120	 0.000636	 0.056994	 0.0	 555	 555	 555	 1.003288	 -0.001353	 1	 -30.0	 30.0;
	3120	 117	 0.00182	 0.07175	 0.0	 441	 441	 441	 1.049587	 0.0	 1	 -30.0	 30.0;
	3120	 3328	 0.00185	 0.07028	 0.0	 450	 450	 450	 1.049587	 0.0	 1	 -30.0	 30.0;
	2427	 6265	 0.00194	 0.088083	 0.0	 548	 548	 548	 1.052632	 0.0	 1	 -30.0	 30.0;
	2427	 6770	 0.00198	 0.086207	 0.0	 559	 559	 559	 1.052632	 0.0	 1	 -30.0	 30.0;
	3570	 6849	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	4396	 6317	 0.000697	 0.032338	 0.0	 1491	 1491	 1491	 1.002506	 0.0	 1	 -30.0	 30.0;
	6317	 3434	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	2707	 2534	 0.000667	 0.033601	 0.0	 940	 940	 940	 1.002506	 0.0	 1	 -30.0	 30.0;
	2707	 2534	 0.000647	 0.034238	 0.0	 923	 923	 923	 1.002506	 0.0	 1	 -30.0	 30.0;
	2534	 3029	 0.0016	 0.07553	 0.0	 419	 419	 419	 1.061984	 0.0	 1	 -30.0	 30.0;
	2534	 1176	 0.00182	 0.07402	 0.0	 427	 427	 427	 1.061984	 0.0	 1	 -30.0	 30.0;
	4335	 5849	 0.0019	 0.08995	 0.0	 352	 352	 352	 1.052632	 0.0	 1	 -30.0	 30.0;
	5619	 3804	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	5619	 617	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	6245	 87	 0.00201	 0.084331	 0.0	 375	 375	 375	 1.052632	 0.0	 1	 -30.0	 30.0;
	6245	 87	 0.00179	 0.095578	 0.0	 331	 331	 331	 1.052632	 0.0	 1	 -30.0	 30.0;
	9227	 2061	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	6787	 922	 0.00167	 0.0776	 0.0	 407	 407	 407	 1.049587	 0.0	 1	 -30.0	 30.0;
	841	 1988	 0.00168	 0.101198	 0.0	 477	 477	 477	 1.052632	 0.0	 1	 -30.0	 30.0;
	6729	 8754	 0.00165	 0.093702	 0.0	 338	 338	 338	 1.052632	 0.0	 1	 -30.0	 30.0;
	6729	 1412	 0.00187	 0.091826	 0.0	 344	 344	 344	 1.052632	 0.0	 1	 -30.0	 30.0;
	6319	 8922	 0.0019	 0.08995	 0.0	 352	 352	 352	 1.052632	 0.0	 1	 -30.0	 30.0;
	3802	 9056	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	3802	 9056	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	4977	 7344	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	4977	 6465	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	7889	 3153	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	2170	 4881	 0.00167	 0.0776	 0.0	 407	 407	 407	 1.049587	 0.0	 1	 -30.0	 30.0;
	2108	 7853	 0.00164	 0.07907	 0.0	 400	 400	 400	 1.049587	 0.0	 1	 -30.0	 30.0;
	9218	 3129	 0.00045	 0.04299	 0.0	 735	 735	 735	 1.113821	 0.0	 1	 -30.0	 30.0;
	9005	 3207	 0.00051	 0.04213	 0.0	 750	 750	 750	 1.113821	 0.0	 1	 -30.0	 30.0;
	1196	 1197	 0.00185	 0.07028	 0.0	 450	 450	 450	 1.049587	 0.0	 1	 -30.0	 30.0;
	1196	 1197	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	204	 675	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	204	 2488	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	5009	 3642	 0.00179	 0.095578	 0.0	 331	 331	 331	 1.052632	 0.0	 1	 -30.0	 30.0;
	5009	 3642	 0.00176	 0.097446	 0.0	 325	 325	 325	 1.052632	 0.0	 1	 -30.0	 30.0;
	2027	 1274	 0.00167	 0.0776	 0.0	 407	 407	 407	 1.049587	 0.0	 1	 -30.0	 30.0;
	2027	 1274	 0.00164	 0.07907	 0.0	 400	 400	 400	 1.049587	 0.0	 1	 -30.0	 30.0;
	67	 5537	 0.000637	 0.031701	 0.0	 997	 997	 997	 1.002506	 0.0	 1	 -30.0	 30.0;
	67	 7946	 0.000716	 0.031064	 0.0	 1017	 1017	 1017	 1.002506	 0.0	 1	 -30.0	 30.0;
	7946	 8949	 0.00185	 0.07028	 0.0	 450	 450	 450	 1.049587	 0.0	 1	 -30.0	 30.0;
	7946	 215	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	2383	 1921	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	2383	 1921	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	6481	 9035	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	1563	 5322	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	6256	 1756	 0.00084	 0.0322	 0.0	 1497	 1497	 1497	 1.052632	 0.0	 1	 -30.0	 30.0;
	1756	 2984	 0.00238	 0.123248	 0.0	 257	 257	 257	 1.049587	 0.0	 1	 -30.0	 30.0;
	5487	 7109	 0.00269	 0.109562	 0.0	 289	 289	 289	 1.049587	 0.0	 1	 -30.0	 30.0;
	6116	 8455	 0.00275	 0.107281	 0.0	 295	 295	 295	 1.049587	 0.0	 1	 -30.0	 30.0;
	4736	 3050	 0.000766	 0.029164	 0.0	 1083	 1083	 1083	 1.002506	 0.0	 1	 -30.0	 30.0;
	4736	 3050	 0.000776	 0.028526	 0.0	 1107	 1107	 1107	 1.002506	 0.0	 1	 -30.0	 30.0;
	3050	 8351	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	3050	 6550	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	3511	 1783	 0.00167	 0.0776	 0.0	 407	 407	 407	 1.049587	 0.0	 1	 -30.0	 30.0;
	3729	 3393	 0.00168	 0.101198	 0.0	 313	 313	 313	 1.052632	 0.0	 1	 -30.0	 30.0;
	3729	 3732	 0.00165	 0.093702	 0.0	 338	 338	 338	 1.052632	 0.0	 1	 -30.0	 30.0;
	971	 7278	 0.000716	 0.031064	 0.0	 1017	 1017	 1017	 1.002506	 0.0	 1	 -30.0	 30.0;
	971	 3441	 0.000736	 0.030437	 0.0	 1038	 1038	 1038	 1.002506	 0.0	 1	 -30.0	 30.0;
	3441	 479	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	3441	 479	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	6665	 4364	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	7828	 4537	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	1669	 3810	 0.00171	 0.07614	 0.0	 633	 633	 633	 1.049587	 0.0	 1	 -30.0	 30.0;
	1669	 3810	 0.00167	 0.0776	 0.0	 621	 621	 621	 1.049587	 0.0	 1	 -30.0	 30.0;
	4394	 4667	 0.00168	 0.101198	 0.0	 313	 313	 313	 1.052632	 0.0	 1	 -30.0	 30.0;
	4697	 3853	 0.00062	 0.03068	 0.0	 1571	 1571	 1571	 1.015698	 0.0	 1	 -30.0	 30.0;
	4697	 7671	 0.000458	 0.027443	 0.0	 1757	 1757	 1757	 1.002506	 0.0	 1	 -30.0	 30.0;
	4697	 7671	 0.000468	 0.026875	 0.0	 1794	 1794	 1794	 1.002506	 0.0	 1	 -30.0	 30.0;
	5175	 9105	 0.001543	 0.057853	 0.0	 833	 833	 833	 0.892857	 0.0	 1	 -30.0	 30.0;
	2226	 4759	 0.00198	 0.086207	 0.0	 367	 367	 367	 1.052632	 0.0	 1	 -30.0	 30.0;
	7515	 3595	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	3365	 5964	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	1695	 6733	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	3356	 8692	 0.000667	 0.033601	 0.0	 940	 940	 940	 1.002506	 0.0	 1	 -30.0	 30.0;
	3356	 7549	 0.00168	 0.101198	 0.0	 313	 313	 313	 1.052632	 0.0	 1	 -30.0	 30.0;
	8692	 7549	 0.0016	 0.07321	 0.0	 432	 432	 432	 1.049587	 0.0	 1	 -30.0	 30.0;
	6449	 7578	 0.0019	 0.08995	 0.0	 352	 352	 352	 1.052632	 0.0	 1	 -30.0	 30.0;
	8137	 3640	 0.000746	 0.029801	 0.0	 1060	 1060	 1060	 1.002506	 0.0	 1	 -30.0	 30.0;
	7506	 3815	 0.00198	 0.086207	 0.0	 367	 367	 367	 1.052632	 0.0	 1	 -30.0	 30.0;
	5337	 3030	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	8633	 4992	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	3192	 7120	 0.000677	 0.032965	 0.0	 1462	 1462	 1462	 1.002506	 0.0	 1	 -30.0	 30.0;
	3192	 8583	 0.000667	 0.033601	 0.0	 1435	 1435	 1435	 1.002506	 0.0	 1	 -30.0	 30.0;
	3192	 1321	 0.00168	 0.101198	 0.0	 477	 477	 477	 1.052632	 0.0	 1	 -30.0	 30.0;
	3192	 4988	 0.00165	 0.093702	 0.0	 515	 515	 515	 1.052632	 0.0	 1	 -30.0	 30.0;
	7017	 4716	 0.000716	 0.031064	 0.0	 1017	 1017	 1017	 1.002506	 0.0	 1	 -30.0	 30.0;
	7017	 4716	 0.000736	 0.030437	 0.0	 1038	 1038	 1038	 1.002506	 0.0	 1	 -30.0	 30.0;
	7017	 4716	 0.000746	 0.029801	 0.0	 1060	 1060	 1060	 1.002506	 0.0	 1	 -30.0	 30.0;
	4716	 6825	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	4716	 6825	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	1540	 2092	 0.00179	 0.095578	 0.0	 331	 331	 331	 1.052632	 0.0	 1	 -30.0	 30.0;
	1540	 3921	 0.00176	 0.097446	 0.0	 325	 325	 325	 1.052632	 0.0	 1	 -30.0	 30.0;
	8166	 5231	 0.00167	 0.0776	 0.0	 407	 407	 407	 1.049587	 0.0	 1	 -30.0	 30.0;
	4990	 37	 0.00164	 0.07907	 0.0	 400	 400	 400	 1.049587	 0.0	 1	 -30.0	 30.0;
	2152	 508	 0.0016	 0.07321	 0.0	 432	 432	 432	 1.049587	 0.0	 1	 -30.0	 30.0;
	2152	 508	 0.00182	 0.07175	 0.0	 441	 441	 441	 1.049587	 0.0	 1	 -30.0	 30.0;
	3017	 7536	 0.0019	 0.08995	 0.0	 352	 352	 352	 1.052632	 0.0	 1	 -30.0	 30.0;
	3017	 7536	 0.00194	 0.088083	 0.0	 359	 359	 359	 1.052632	 0.0	 1	 -30.0	 30.0;
	403	 7536	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	7271	 7585	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	5185	 4741	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	4327	 4351	 0.00387	 0.152273	 0.0	 208	 208	 208	 1.049587	 0.0	 1	 -30.0	 30.0;
	887	 7750	 0.000667	 0.033601	 0.0	 940	 940	 940	 1.002506	 0.0	 1	 -30.0	 30.0;
	887	 3161	 0.00168	 0.101198	 0.0	 313	 313	 313	 1.052632	 0.0	 1	 -30.0	 30.0;
	887	 2645	 0.00165	 0.093702	 0.0	 338	 338	 338	 1.052632	 0.0	 1	 -30.0	 30.0;
	2251	 1053	 0.00182	 0.07175	 0.0	 441	 441	 441	 1.049587	 0.0	 1	 -30.0	 30.0;
	2251	 1053	 0.00185	 0.07028	 0.0	 450	 450	 450	 1.049587	 0.0	 1	 -30.0	 30.0;
	7225	 941	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	7225	 941	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	3915	 3679	 0.00196	 0.07015	 0.0	 451	 451	 451	 1.07438	 0.0	 1	 -30.0	 30.0;
	1127	 3679	 0.00174	 0.0795	 0.0	 398	 398	 398	 1.07438	 0.0	 1	 -30.0	 30.0;
	2904	 2706	 0.00136	 0.05901	 0.0	 536	 536	 536	 1.052632	 0.0	 1	 -30.0	 30.0;
	2904	 576	 0.00133	 0.06014	 0.0	 526	 526	 526	 1.052632	 0.0	 1	 -30.0	 30.0;
	3213	 5632	 0.00164	 0.07907	 0.0	 400	 400	 400	 1.049587	 0.0	 1	 -30.0	 30.0;
	3213	 2333	 0.0016	 0.07321	 0.0	 432	 432	 432	 1.049587	 0.0	 1	 -30.0	 30.0;
	1211	 7660	 0.000716	 0.031064	 0.0	 1552	 1552	 1552	 1.002506	 0.0	 1	 -30.0	 30.0;
	7660	 4378	 0.00185	 0.07028	 0.0	 450	 450	 450	 1.049587	 0.0	 1	 -30.0	 30.0;
	7010	 2198	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	4437	 155	 0.00158	 0.05564	 0.0	 568	 568	 568	 1.0	 0.0	 1	 -30.0	 30.0;
	4437	 7730	 0.00179	 0.0695	 0.0	 455	 455	 455	 1.0	 0.0	 1	 -30.0	 30.0;
	2939	 341	 0.00084	 0.04445	 0.0	 711	 711	 711	 1.0	 0.0	 1	 -30.0	 30.0;
	2939	 341	 0.0008	 0.04546	 0.0	 695	 695	 695	 1.0	 0.0	 1	 -30.0	 30.0;
	2939	 341	 0.00219	 0.08229	 0.0	 384	 384	 384	 1.0	 0.0	 1	 -30.0	 30.0;
	2939	 341	 0.00069	 0.04566	 0.0	 692	 692	 692	 1.047826	 0.0	 1	 -30.0	 30.0;
	9016	 3924	 0.00072	 0.04835	 0.0	 654	 654	 654	 0.999313	 0.0	 1	 -30.0	 30.0;
	9016	 3924	 0.00082	 0.04738	 0.0	 667	 667	 667	 0.999313	 0.0	 1	 -30.0	 30.0;
	5327	 2345	 0.00045	 0.03151	 0.0	 1003	 1003	 1003	 1.052632	 0.0	 1	 -30.0	 30.0;
	5327	 8470	 0.00048	 0.026419	 0.0	 1196	 1196	 1196	 1.052632	 0.0	 1	 -30.0	 30.0;
	3103	 8471	 0.0022	 0.07023	 0.0	 450	 450	 450	 1.0	 0.0	 1	 -30.0	 30.0;
	2855	 223	 0.00241	 0.0727	 0.0	 435	 435	 435	 1.052174	 0.0	 1	 -30.0	 30.0;
	2855	 223	 0.00081	 0.04644	 0.0	 681	 681	 681	 1.052174	 0.0	 1	 -30.0	 30.0;
	4361	 3026	 0.00158	 0.08045	 0.0	 393	 393	 393	 1.0	 0.0	 1	 -30.0	 30.0;
	7830	 7739	 0.00069	 0.04707	 0.0	 671	 671	 671	 1.052174	 0.0	 1	 -30.0	 30.0;
	1534	 8306	 0.00075	 0.04866	 0.0	 650	 650	 650	 1.052174	 0.0	 1	 -30.0	 30.0;
	1534	 8306	 0.00076	 0.04586	 0.0	 689	 689	 689	 1.052174	 0.0	 1	 -30.0	 30.0;
	8734	 8570	 0.00189	 0.07781	 0.0	 406	 406	 406	 1.0	 0.0	 1	 -30.0	 30.0;
	8734	 8570	 0.00205	 0.07804	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	663	 7604	 0.00207	 0.091083	 0.0	 347	 347	 347	 1.0	 0.0	 1	 -30.0	 30.0;
	663	 7604	 0.00211	 0.06802	 0.0	 465	 465	 465	 1.0	 0.0	 1	 -30.0	 30.0;
	1978	 7477	 0.0008	 0.03997	 0.0	 1206	 1206	 1206	 1.052174	 0.0	 1	 -30.0	 30.0;
	3104	 7477	 0.00159	 0.086876	 0.0	 364	 364	 364	 1.0	 0.0	 1	 -30.0	 30.0;
	3104	 7477	 0.0026	 0.07998	 0.0	 395	 395	 395	 1.0	 0.0	 1	 -30.0	 30.0;
	4861	 7528	 0.00154	 0.086488	 0.0	 366	 366	 366	 1.0	 0.0	 1	 -30.0	 30.0;
	8562	 4861	 0.00052	 0.033159	 0.0	 1454	 1454	 1454	 1.052632	 0.0	 1	 -30.0	 30.0;
	8562	 7528	 0.00072	 0.0451	 0.0	 1069	 1069	 1069	 1.052174	 0.0	 1	 -30.0	 30.0;
	8562	 7528	 0.00068	 0.04531	 0.0	 1064	 1064	 1064	 1.052174	 0.0	 1	 -30.0	 30.0;
	4801	 3372	 0.00042	 0.030281	 0.0	 1592	 1592	 1592	 1.052632	 0.0	 1	 -30.0	 30.0;
	4801	 8382	 0.00079	 0.04086	 0.0	 1180	 1180	 1180	 1.052174	 0.0	 1	 -30.0	 30.0;
	3372	 5218	 0.00168	 0.07343	 0.0	 431	 431	 431	 1.0	 0.0	 1	 -30.0	 30.0;
	7364	 1964	 0.00038	 0.033591	 0.0	 1435	 1435	 1435	 1.052632	 0.0	 1	 -30.0	 30.0;
	7364	 1964	 0.00037	 0.03405	 0.0	 1416	 1416	 1416	 1.052632	 0.0	 1	 -30.0	 30.0;
	1686	 8618	 0.00039	 0.034849	 0.0	 907	 907	 907	 1.052632	 0.0	 1	 -30.0	 30.0;
	1686	 3748	 0.00063	 0.04764	 0.0	 663	 663	 663	 1.052174	 0.0	 1	 -30.0	 30.0;
	1686	 3748	 0.00074	 0.044626	 0.0	 708	 708	 708	 1.006865	 0.0	 1	 -30.0	 30.0;
	7314	 7848	 0.00069	 0.04232	 0.0	 1139	 1139	 1139	 1.052632	 0.0	 1	 -30.0	 30.0;
	7978	 6673	 0.00228	 0.07286	 0.0	 434	 434	 434	 1.0	 0.0	 1	 -30.0	 30.0;
	7978	 6673	 0.00189	 0.07059	 0.0	 448	 448	 448	 1.0	 0.0	 1	 -30.0	 30.0;
	2349	 1714	 0.00195	 0.07374	 0.0	 429	 429	 429	 1.0	 0.0	 1	 -30.0	 30.0;
	2349	 1714	 0.00199	 0.07214	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	3688	 5629	 0.00177	 0.07931	 0.0	 399	 399	 399	 1.0	 0.0	 1	 -30.0	 30.0;
	3688	 5629	 0.00174	 0.08086	 0.0	 391	 391	 391	 1.0	 0.0	 1	 -30.0	 30.0;
	465	 4803	 0.0015	 0.08239	 0.0	 384	 384	 384	 1.0	 0.0	 1	 -30.0	 30.0;
	465	 4803	 0.00149	 0.091992	 0.0	 344	 344	 344	 1.0	 0.0	 1	 -30.0	 30.0;
	8358	 3470	 0.00066	 0.04441	 0.0	 712	 712	 712	 1.052174	 0.0	 1	 -30.0	 30.0;
	1753	 3470	 0.00171	 0.07418	 0.0	 426	 426	 426	 1.0	 0.0	 1	 -30.0	 30.0;
	1753	 3470	 0.00175	 0.07267	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	2585	 4899	 0.00053	 0.03038	 0.0	 1587	 1587	 1587	 1.052632	 0.0	 1	 -30.0	 30.0;
	4899	 591	 0.00165	 0.07003	 0.0	 451	 451	 451	 1.0	 0.0	 1	 -30.0	 30.0;
	4899	 7705	 0.00217	 0.07323	 0.0	 432	 432	 432	 1.0	 0.0	 1	 -30.0	 30.0;
	254	 1427	 0.00072	 0.0453	 0.0	 698	 698	 698	 1.052174	 0.0	 1	 -30.0	 30.0;
	7521	 1087	 0.0021	 0.08257	 0.0	 383	 383	 383	 1.0	 0.0	 1	 -30.0	 30.0;
	7521	 1087	 0.00186	 0.087719	 0.0	 361	 361	 361	 1.0	 0.0	 1	 -30.0	 30.0;
	895	 8969	 0.00076	 0.04796	 0.0	 659	 659	 659	 1.052174	 0.0	 1	 -30.0	 30.0;
	895	 3232	 0.00075	 0.04466	 0.0	 708	 708	 708	 1.052174	 0.0	 1	 -30.0	 30.0;
	3750	 7687	 0.00401	 0.10005	 0.0	 316	 316	 316	 1.0	 0.0	 1	 -30.0	 30.0;
	3750	 7687	 0.00272	 0.07842	 0.0	 403	 403	 403	 1.0	 0.0	 1	 -30.0	 30.0;
	3750	 7687	 0.00278	 0.07679	 0.0	 412	 412	 412	 1.0	 0.0	 1	 -30.0	 30.0;
	3750	 7687	 0.00283	 0.07515	 0.0	 421	 421	 421	 1.0	 0.0	 1	 -30.0	 30.0;
	2398	 5000	 0.00045	 0.029271	 0.0	 1647	 1647	 1647	 1.052632	 0.0	 1	 -30.0	 30.0;
	2398	 5000	 0.0004	 0.033169	 0.0	 1453	 1453	 1453	 1.052632	 0.0	 1	 -30.0	 30.0;
	2398	 5000	 0.00039	 0.03382	 0.0	 1426	 1426	 1426	 1.052632	 0.0	 1	 -30.0	 30.0;
	2737	 5190	 0.00064	 0.04577	 0.0	 1053	 1053	 1053	 1.052632	 0.0	 1	 -30.0	 30.0;
	694	 1960	 0.00147	 0.08395	 0.0	 377	 377	 377	 1.0	 0.0	 1	 -30.0	 30.0;
	694	 180	 0.00184	 0.07633	 0.0	 414	 414	 414	 1.0	 0.0	 1	 -30.0	 30.0;
	6098	 9193	 0.00074	 0.04352	 0.0	 1108	 1108	 1108	 1.052174	 0.0	 1	 -30.0	 30.0;
	1473	 4784	 0.00176	 0.08177	 0.0	 387	 387	 387	 1.0	 0.0	 1	 -30.0	 30.0;
	1473	 4784	 0.00242	 0.06613	 0.0	 478	 478	 478	 1.0	 0.0	 1	 -30.0	 30.0;
	1920	 3447	 0.00042	 0.030031	 0.0	 1052	 1052	 1052	 1.015038	 0.0	 1	 -30.0	 30.0;
	1920	 3447	 0.00043	 0.02938	 0.0	 1076	 1076	 1076	 1.015038	 0.0	 1	 -30.0	 30.0;
	8556	 9133	 0.00014	 0.019637	 0.0	 1609	 1609	 1609	 1.0	 0.199334	 1	 -30.0	 30.0;
	5824	 8145	 0.00037	 0.03395	 0.0	 931	 931	 931	 0.977444	 0.0	 1	 -30.0	 30.0;
	4111	 3955	 1.8e-05	 0.052587	 0.0	 601	 601	 601	 1.052632	 0.0	 1	 -30.0	 30.0;
	2846	 3955	 5.5e-05	 0.082396	 0.0	 384	 384	 384	 1.04762	 0.0	 1	 -30.0	 30.0;
	794	 4924	 0.001416	 0.043162	 0.0	 732	 732	 732	 0.92437	 0.0	 1	 -30.0	 30.0;
	794	 4924	 0.001603	 0.042296	 0.0	 747	 747	 747	 0.92437	 0.0	 1	 -30.0	 30.0;
	4190	 3940	 0.000806	 0.025741	 0.0	 1227	 1227	 1227	 1.002506	 0.0	 1	 -30.0	 30.0;
	4190	 3940	 0.000826	 0.025204	 0.0	 1253	 1253	 1253	 1.002506	 0.0	 1	 -30.0	 30.0;
	4190	 3518	 0.000107	 0.01357	 0.0	 724.0	 2328	 2328	 1.059051	 0.0	 1	 -30.0	 30.0;
	3940	 956	 0.00228	 0.07939	 0.0	 398	 398	 398	 1.0	 0.0	 1	 -30.0	 30.0;
	3518	 3940	 0.001087	 0.076556	 0.0	 413	 413	 413	 0.99449	 0.048556	 1	 -30.0	 30.0;
	3518	 3940	 0.001067	 0.077593	 0.0	 408	 408	 408	 1.00317	 -0.04898	 1	 -30.0	 30.0;
	6091	 4063	 0.001301	 0.061931	 0.0	 510	 510	 510	 0.948276	 0.0	 1	 -30.0	 30.0;
	6091	 4063	 0.001268	 0.063098	 0.0	 501	 501	 501	 0.948276	 0.0	 1	 -30.0	 30.0;
	7678	 1075	 0.002358	 0.088053	 0.0	 359	 359	 359	 0.948276	 0.0	 1	 -30.0	 30.0;
	7678	 1075	 0.00268	 0.086295	 0.0	 366	 366	 366	 0.948276	 0.0	 1	 -30.0	 30.0;
	7870	 599	 0.000779	 0.028436	 0.0	 1111	 1111	 1111	 1.048339	 -0.002864	 1	 -30.0	 30.0;
	599	 4242	 0.001565	 0.062128	 0.0	 509	 509	 509	 0.932204	 0.0	 1	 -30.0	 30.0;
	599	 4242	 0.001588	 0.060806	 0.0	 520	 520	 520	 0.932204	 0.0	 1	 -30.0	 30.0;
	5389	 8041	 0.002713	 0.092944	 0.0	 340	 340	 340	 0.916667	 0.0	 1	 -30.0	 30.0;
	5389	 8041	 0.002464	 0.122138	 0.0	 259	 259	 259	 0.916667	 0.0	 1	 -30.0	 30.0;
	5052	 446	 0.002739	 0.116189	 0.0	 272	 272	 272	 0.932204	 0.0	 1	 -30.0	 30.0;
	5052	 446	 0.002681	 0.118434	 0.0	 267	 267	 267	 0.932204	 0.0	 1	 -30.0	 30.0;
	6398	 607	 0.000212	 0.012061	 0.0	 2619	 2619	 2619	 0.956194	 -0.071507	 1	 -30.0	 30.0;
	4458	 530	 0.0	 0.04332	 0.0	 730	 730	 730	 1.041096	 0.0	 1	 -30.0	 30.0;
	4458	 530	 0.0	 0.04332	 0.0	 730	 730	 730	 1.041096	 0.0	 1	 -30.0	 30.0;
	4959	 4654	 0.0	 0.0505	 0.0	 626	 626	 626	 1.014795	 0.0	 1	 -30.0	 30.0;
	6370	 6269	 0.0	 0.044	 0.0	 718	 718	 718	 0.986875	 0.0	 1	 -30.0	 30.0;
	6370	 6269	 0.0	 0.044	 0.0	 718	 718	 718	 0.986875	 0.0	 1	 -30.0	 30.0;
	6588	 2621	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	6588	 2621	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	6588	 5840	 0.0	 0.037831	 0.0	 835	 835	 835	 0.987675	 0.0	 1	 -30.0	 30.0;
	6588	 5840	 0.0	 0.037831	 0.0	 835	 835	 835	 0.987675	 0.0	 1	 -30.0	 30.0;
	5757	 3386	 0.0	 0.045294	 0.0	 698	 698	 698	 1.001022	 0.0	 1	 -30.0	 30.0;
	5757	 3386	 0.0	 0.045294	 0.0	 698	 698	 698	 1.001022	 0.0	 1	 -30.0	 30.0;
	5757	 2001	 0.0	 0.04563	 0.0	 693	 693	 693	 1.0	 0.0	 1	 -30.0	 30.0;
	5757	 2001	 0.0	 0.04563	 0.0	 693	 693	 693	 1.0	 0.0	 1	 -30.0	 30.0;
	3628	 3402	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	3628	 3402	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	3628	 6545	 0.0	 0.049246	 0.0	 642	 642	 642	 0.987678	 0.0	 1	 -30.0	 30.0;
	3628	 6545	 0.0	 0.049246	 0.0	 642	 642	 642	 0.987678	 0.0	 1	 -30.0	 30.0;
	8390	 7962	 0.0	 0.049246	 0.0	 642	 642	 642	 0.987678	 0.0	 1	 -30.0	 30.0;
	8390	 7962	 0.0	 0.049246	 0.0	 642	 642	 642	 0.987678	 0.0	 1	 -30.0	 30.0;
	8793	 6198	 0.0	 0.046721	 0.0	 677	 677	 677	 0.974792	 0.0	 1	 -30.0	 30.0;
	8793	 5345	 0.0	 0.047975	 0.0	 659	 659	 659	 1.001022	 0.0	 1	 -30.0	 30.0;
	836	 7084	 0.0	 0.047974	 0.0	 659	 659	 659	 1.001022	 0.0	 1	 -30.0	 30.0;
	836	 7084	 0.0	 0.047974	 0.0	 659	 659	 659	 1.001022	 0.0	 1	 -30.0	 30.0;
	1941	 8122	 0.0	 0.049246	 0.0	 642	 642	 642	 0.987678	 0.0	 1	 -30.0	 30.0;
	1941	 8122	 0.0	 0.049246	 0.0	 642	 642	 642	 0.987678	 0.0	 1	 -30.0	 30.0;
	1941	 7288	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	1941	 7288	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	8089	 4769	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	8089	 4769	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	836	 1995	 0.0	 0.045482	 0.0	 695	 695	 695	 1.014736	 0.0	 1	 -30.0	 30.0;
	836	 1995	 0.0	 0.045482	 0.0	 695	 695	 695	 1.014736	 0.0	 1	 -30.0	 30.0;
	1594	 1291	 0.0	 0.048	 0.0	 659	 659	 659	 0.975	 0.0	 1	 -30.0	 30.0;
	1594	 1291	 0.0	 0.048	 0.0	 659	 659	 659	 0.975	 0.0	 1	 -30.0	 30.0;
	1594	 3783	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	1594	 3783	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	1420	 1799	 0.0	 0.049041	 0.0	 645	 645	 645	 0.95	 0.0	 1	 -30.0	 30.0;
	1420	 1799	 0.0	 0.049041	 0.0	 645	 645	 645	 0.95	 0.0	 1	 -30.0	 30.0;
	1420	 4303	 0.0	 0.047975	 0.0	 659	 659	 659	 0.95	 0.0	 1	 -30.0	 30.0;
	1420	 4303	 0.0	 0.047975	 0.0	 659	 659	 659	 0.95	 0.0	 1	 -30.0	 30.0;
	8680	 8366	 0.0	 0.049246	 0.0	 642	 642	 642	 0.962025	 0.0	 1	 -30.0	 30.0;
	8680	 8366	 0.0	 0.049246	 0.0	 642	 642	 642	 0.962025	 0.0	 1	 -30.0	 30.0;
	1827	 4292	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	1827	 4292	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	1827	 5113	 0.0	 0.049246	 0.0	 642	 642	 642	 0.962025	 0.0	 1	 -30.0	 30.0;
	1827	 5113	 0.0	 0.049246	 0.0	 642	 642	 642	 0.962025	 0.0	 1	 -30.0	 30.0;
	644	 319	 0.0	 0.05533	 0.0	 571	 571	 571	 0.975	 0.0	 1	 -30.0	 30.0;
	644	 319	 0.0	 0.05533	 0.0	 571	 571	 571	 0.975	 0.0	 1	 -30.0	 30.0;
	644	 319	 0.0	 0.05533	 0.0	 571	 571	 571	 0.975	 0.0	 1	 -30.0	 30.0;
	644	 319	 0.0	 0.05533	 0.0	 571	 571	 571	 0.975	 0.0	 1	 -30.0	 30.0;
	4888	 7888	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	4888	 7888	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	4917	 777	 0.0	 0.0505	 0.0	 626	 626	 626	 0.962289	 0.0	 1	 -30.0	 30.0;
	4917	 777	 0.0	 0.0505	 0.0	 626	 626	 626	 0.962289	 0.0	 1	 -30.0	 30.0;
	4917	 777	 0.0	 0.0505	 0.0	 626	 626	 626	 0.962289	 0.0	 1	 -30.0	 30.0;
	8657	 4628	 0.0	 0.048	 0.0	 659	 659	 659	 0.987294	 0.0	 1	 -30.0	 30.0;
	8657	 4628	 0.0	 0.04563	 0.0	 693	 693	 693	 0.987013	 0.0	 1	 -30.0	 30.0;
	8657	 1444	 0.0	 0.049141	 0.0	 643	 643	 643	 0.964134	 0.0	 1	 -30.0	 30.0;
	8657	 1444	 0.0	 0.049141	 0.0	 643	 643	 643	 0.964134	 0.0	 1	 -30.0	 30.0;
	1881	 3459	 0.0	 0.067933	 0.0	 465	 465	 465	 1.0	 0.0	 1	 -30.0	 30.0;
	1881	 3459	 0.0	 0.067933	 0.0	 465	 465	 465	 1.0	 0.0	 1	 -30.0	 30.0;
	1881	 3459	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	5293	 4955	 0.0	 0.046721	 0.0	 677	 677	 677	 0.962237	 0.0	 1	 -30.0	 30.0;
	7429	 9220	 0.0	 0.070733	 0.0	 447	 447	 447	 0.974792	 0.0	 1	 -30.0	 30.0;
	7429	 9220	 0.0	 0.07187	 0.0	 440	 440	 440	 0.97375	 0.0	 1	 -30.0	 30.0;
	7658	 1080	 0.0	 0.049246	 0.0	 642	 642	 642	 0.95	 0.0	 1	 -30.0	 30.0;
	7658	 1080	 0.0	 0.049246	 0.0	 642	 642	 642	 0.95	 0.0	 1	 -30.0	 30.0;
	7658	 1080	 0.0	 0.049246	 0.0	 642	 642	 642	 0.95	 0.0	 1	 -30.0	 30.0;
	6021	 3002	 0.0	 0.0505	 0.0	 626	 626	 626	 0.962289	 0.0	 1	 -30.0	 30.0;
	6021	 3002	 0.0	 0.0505	 0.0	 626	 626	 626	 0.962289	 0.0	 1	 -30.0	 30.0;
	6021	 4193	 0.0	 0.046807	 0.0	 675	 675	 675	 0.987013	 0.0	 1	 -30.0	 30.0;
	6021	 4193	 0.0	 0.046807	 0.0	 675	 675	 675	 0.987013	 0.0	 1	 -30.0	 30.0;
	6021	 3058	 0.0	 0.049246	 0.0	 642	 642	 642	 0.987678	 0.0	 1	 -30.0	 30.0;
	6021	 3058	 0.0	 0.049246	 0.0	 642	 642	 642	 0.987678	 0.0	 1	 -30.0	 30.0;
	4567	 2735	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	4567	 2735	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	4567	 9085	 0.0	 0.0505	 0.0	 626	 626	 626	 0.962289	 0.0	 1	 -30.0	 30.0;
	4567	 9085	 0.0	 0.0505	 0.0	 626	 626	 626	 0.962289	 0.0	 1	 -30.0	 30.0;
	2659	 2999	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	2659	 2999	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	2659	 2999	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	2659	 2999	 0.0	 0.047975	 0.0	 659	 659	 659	 0.987675	 0.0	 1	 -30.0	 30.0;
	2775	 6890	 0.0	 0.05643	 0.0	 560	 560	 560	 1.032609	 0.0	 1	 -30.0	 30.0;
	2775	 6890	 0.0	 0.040627	 0.0	 778	 778	 778	 1.032609	 0.0	 1	 -30.0	 30.0;
	2683	 409	 0.0	 0.049246	 0.0	 642	 642	 642	 0.95	 0.0	 1	 -30.0	 30.0;
	2683	 409	 0.0	 0.049246	 0.0	 642	 642	 642	 0.95	 0.0	 1	 -30.0	 30.0;
	926	 2182	 0.0	 0.092641	 0.0	 341	 341	 341	 0.987013	 0.0	 1	 -30.0	 30.0;
	926	 2182	 0.0	 0.092641	 0.0	 341	 341	 341	 0.987013	 0.0	 1	 -30.0	 30.0;
	926	 2182	 0.0	 0.05415	 0.0	 584	 584	 584	 1.0	 0.0	 1	 -30.0	 30.0;
	7728	 1800	 0.0	 0.044468	 0.0	 711	 711	 711	 1.0	 0.0	 1	 -30.0	 30.0;
	7728	 1800	 0.0	 0.044468	 0.0	 711	 711	 711	 1.0	 0.0	 1	 -30.0	 30.0;
	2455	 2791	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	2455	 2791	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	2455	 2791	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	7498	 5411	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	7498	 5411	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	7498	 5411	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	6181	 5851	 0.0	 0.06556	 0.0	 482	 482	 482	 0.97375	 0.0	 1	 -30.0	 30.0;
	6181	 5851	 0.0	 0.0472	 0.0	 670	 670	 670	 0.97375	 0.0	 1	 -30.0	 30.0;
	2436	 6821	 0.0	 0.075233	 0.0	 420	 420	 420	 0.95	 0.0	 1	 -30.0	 30.0;
	2436	 6821	 0.0	 0.043977	 0.0	 719	 719	 719	 0.962181	 0.0	 1	 -30.0	 30.0;
	2436	 6821	 0.0	 0.043977	 0.0	 719	 719	 719	 0.962181	 0.0	 1	 -30.0	 30.0;
	2436	 6821	 0.0	 0.043977	 0.0	 719	 719	 719	 0.962181	 0.0	 1	 -30.0	 30.0;
	7158	 7481	 0.0	 0.047783	 0.0	 662	 662	 662	 0.962025	 0.0	 1	 -30.0	 30.0;
	7158	 7481	 0.0	 0.046807	 0.0	 675	 675	 675	 0.962025	 0.0	 1	 -30.0	 30.0;
	7985	 4109	 0.0	 0.071122	 0.0	 445	 445	 445	 0.974792	 0.0	 1	 -30.0	 30.0;
	7985	 4109	 0.0	 0.071122	 0.0	 445	 445	 445	 0.974792	 0.0	 1	 -30.0	 30.0;
	7985	 4109	 0.0	 0.07796	 0.0	 406	 406	 406	 0.962181	 0.0	 1	 -30.0	 30.0;
	7985	 4109	 0.0	 0.07796	 0.0	 406	 406	 406	 0.962181	 0.0	 1	 -30.0	 30.0;
	5921	 2881	 0.0	 0.046721	 0.0	 677	 677	 677	 0.974792	 0.0	 1	 -30.0	 30.0;
	6518	 2499	 0.0	 0.047975	 0.0	 659	 659	 659	 0.962181	 0.0	 1	 -30.0	 30.0;
	134	 2243	 0.0	 0.046721	 0.0	 677	 677	 677	 0.974792	 0.0	 1	 -30.0	 30.0;
	1738	 9	 0.0	 0.046721	 0.0	 677	 677	 677	 0.98768	 0.0	 1	 -30.0	 30.0;
	2151	 2483	 0.0	 0.08407	 0.0	 376	 376	 376	 0.974587	 0.0	 1	 -30.0	 30.0;
	2151	 2483	 0.0	 0.08407	 0.0	 376	 376	 376	 0.974587	 0.0	 1	 -30.0	 30.0;
	2151	 2483	 0.0	 0.08407	 0.0	 376	 376	 376	 0.974587	 0.0	 1	 -30.0	 30.0;
	4920	 6044	 0.0	 0.050122	 0.0	 631	 631	 631	 0.95	 0.0	 1	 -30.0	 30.0;
	4920	 6044	 0.0	 0.050122	 0.0	 631	 631	 631	 0.95	 0.0	 1	 -30.0	 30.0;
	4920	 3564	 0.0	 0.047176	 0.0	 670	 670	 670	 0.962181	 0.0	 1	 -30.0	 30.0;
	4920	 3564	 0.0	 0.047176	 0.0	 670	 670	 670	 0.962181	 0.0	 1	 -30.0	 30.0;
	4305	 5603	 0.0	 0.046721	 0.0	 677	 677	 677	 0.974792	 0.0	 1	 -30.0	 30.0;
	4305	 4749	 0.0	 0.046721	 0.0	 677	 677	 677	 0.974792	 0.0	 1	 -30.0	 30.0;
	2325	 2324	 0.0	 0.053184	 0.0	 594	 594	 594	 0.95	 0.0	 1	 -30.0	 30.0;
	2325	 2324	 0.0	 0.053184	 0.0	 594	 594	 594	 0.95	 0.0	 1	 -30.0	 30.0;
	2325	 2324	 0.0	 0.053184	 0.0	 594	 594	 594	 0.95	 0.0	 1	 -30.0	 30.0;
	1152	 8543	 0.0	 0.0505	 0.0	 626	 626	 626	 0.914719	 0.0	 1	 -30.0	 30.0;
	1152	 8543	 0.0	 0.0505	 0.0	 626	 626	 626	 0.914719	 0.0	 1	 -30.0	 30.0;
	7928	 8259	 0.0	 0.119999	 0.0	 264	 264	 264	 0.95	 0.0	 1	 -30.0	 30.0;
	7928	 8259	 0.0	 0.119999	 0.0	 264	 264	 264	 0.95	 0.0	 1	 -30.0	 30.0;
	634	 4358	 0.0	 0.074556	 0.0	 424	 424	 424	 0.974683	 0.0	 1	 -30.0	 30.0;
	634	 4358	 0.0	 0.074556	 0.0	 424	 424	 424	 0.974683	 0.0	 1	 -30.0	 30.0;
	634	 4358	 0.0	 0.074556	 0.0	 424	 424	 424	 0.974683	 0.0	 1	 -30.0	 30.0;
	634	 4358	 0.0	 0.078311	 0.0	 404	 404	 404	 0.962025	 0.0	 1	 -30.0	 30.0;
	9022	 5287	 0.0	 0.04602	 0.0	 687	 687	 687	 0.974792	 0.0	 1	 -30.0	 30.0;
	9022	 5287	 0.0	 0.08441	 0.0	 375	 375	 375	 0.97375	 0.0	 1	 -30.0	 30.0;
	1925	 8523	 0.0	 0.06561	 0.0	 482	 482	 482	 0.97375	 0.0	 1	 -30.0	 30.0;
	1925	 8523	 0.0	 0.07333	 0.0	 431	 431	 431	 0.97375	 0.0	 1	 -30.0	 30.0;
	1515	 50	 0.0	 0.049246	 0.0	 642	 642	 642	 0.974683	 0.0	 1	 -30.0	 30.0;
	1515	 50	 0.0	 0.049246	 0.0	 642	 642	 642	 0.974683	 0.0	 1	 -30.0	 30.0;
	5934	 5040	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	5934	 5040	 0.0	 0.082076	 0.0	 385	 385	 385	 0.962025	 0.0	 1	 -30.0	 30.0;
	5934	 5040	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	8227	 6796	 0.0	 0.076827	 0.0	 412	 412	 412	 0.962025	 0.0	 1	 -30.0	 30.0;
	8227	 6796	 0.0	 0.049734	 0.0	 636	 636	 636	 0.962181	 0.0	 1	 -30.0	 30.0;
	6124	 5810	 0.0	 0.0808	 0.0	 391	 391	 391	 0.98363	 0.0	 1	 -30.0	 30.0;
	6124	 5810	 0.0	 0.073292	 0.0	 431	 431	 431	 0.962181	 0.0	 1	 -30.0	 30.0;
	6124	 5810	 0.0	 0.08451	 0.0	 374	 374	 374	 0.973754	 0.0	 1	 -30.0	 30.0;
	6124	 5810	 0.0	 0.073292	 0.0	 431	 431	 431	 0.962181	 0.0	 1	 -30.0	 30.0;
	7378	 2007	 0.0	 0.047975	 0.0	 659	 659	 659	 0.95	 0.0	 1	 -30.0	 30.0;
	7378	 2007	 0.0	 0.047975	 0.0	 659	 659	 659	 0.95	 0.0	 1	 -30.0	 30.0;
	3475	 3799	 0.0	 0.070727	 0.0	 447	 447	 447	 0.974359	 0.0	 1	 -30.0	 30.0;
	3475	 3799	 0.0	 0.072561	 0.0	 436	 436	 436	 0.974359	 0.0	 1	 -30.0	 30.0;
	6893	 7217	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	6893	 7217	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	7128	 5667	 0.0	 0.07575	 0.0	 417	 417	 417	 0.962289	 0.0	 1	 -30.0	 30.0;
	7128	 5667	 0.0	 0.049246	 0.0	 642	 642	 642	 0.974683	 0.0	 1	 -30.0	 30.0;
	7128	 5667	 0.0	 0.044468	 0.0	 711	 711	 711	 1.0	 0.0	 1	 -30.0	 30.0;
	4225	 6951	 0.0	 0.082076	 0.0	 385	 385	 385	 0.95	 0.0	 1	 -30.0	 30.0;
	4225	 6951	 0.0	 0.046721	 0.0	 677	 677	 677	 0.95	 0.0	 1	 -30.0	 30.0;
	7026	 5889	 0.0	 0.073292	 0.0	 431	 431	 431	 0.962181	 0.0	 1	 -30.0	 30.0;
	7026	 5889	 0.0	 0.07618	 0.0	 415	 415	 415	 0.974359	 0.0	 1	 -30.0	 30.0;
	320	 20	 0.0	 0.034784	 0.0	 909	 909	 909	 0.987013	 0.0	 1	 -30.0	 30.0;
	320	 20	 0.0	 0.041737	 0.0	 757	 757	 757	 0.987013	 0.0	 1	 -30.0	 30.0;
	715	 1054	 0.0	 0.0842	 0.0	 376	 376	 376	 0.97375	 0.0	 1	 -30.0	 30.0;
	715	 1054	 0.0	 0.0842	 0.0	 376	 376	 376	 0.97375	 0.0	 1	 -30.0	 30.0;
	2874	 3660	 0.0	 0.048	 0.0	 659	 659	 659	 0.9625	 0.0	 1	 -30.0	 30.0;
	2874	 3660	 0.0	 0.048	 0.0	 659	 659	 659	 0.9625	 0.0	 1	 -30.0	 30.0;
	2874	 3660	 0.0	 0.048	 0.0	 659	 659	 659	 0.9625	 0.0	 1	 -30.0	 30.0;
	2874	 3660	 0.0	 0.048	 0.0	 659	 659	 659	 0.9625	 0.0	 1	 -30.0	 30.0;
	3907	 7894	 0.0	 0.080704	 0.0	 392	 392	 392	 0.974687	 0.0	 1	 -30.0	 30.0;
	2241	 2584	 0.0	 0.033909	 0.0	 932	 932	 932	 1.0	 0.0	 1	 -30.0	 30.0;
	6008	 6326	 0.0	 0.075925	 0.0	 417	 417	 417	 0.949102	 0.0	 1	 -30.0	 30.0;
	6008	 6326	 0.0	 0.075925	 0.0	 417	 417	 417	 0.949102	 0.0	 1	 -30.0	 30.0;
	6008	 6326	 0.0	 0.08451	 0.0	 374	 374	 374	 0.987917	 0.0	 1	 -30.0	 30.0;
	9114	 5538	 0.0	 0.082076	 0.0	 385	 385	 385	 0.974683	 0.0	 1	 -30.0	 30.0;
	9114	 5538	 0.0	 0.046721	 0.0	 677	 677	 677	 0.98768	 0.0	 1	 -30.0	 30.0;
	9114	 5538	 0.0	 0.046721	 0.0	 677	 677	 677	 0.98768	 0.0	 1	 -30.0	 30.0;
	4469	 5590	 0.0	 0.046417	 0.0	 681	 681	 681	 1.0	 0.0	 1	 -30.0	 30.0;
	4469	 5590	 0.0	 0.046417	 0.0	 681	 681	 681	 1.0	 0.0	 1	 -30.0	 30.0;
	5098	 3822	 0.0	 0.077314	 0.0	 409	 409	 409	 0.974359	 0.0	 1	 -30.0	 30.0;
	5098	 3822	 0.0	 0.04639	 0.0	 681	 681	 681	 0.987013	 0.0	 1	 -30.0	 30.0;
	3194	 1559	 0.0	 0.046721	 0.0	 677	 677	 677	 1.001026	 0.0	 1	 -30.0	 30.0;
	407	 723	 0.0	 0.071508	 0.0	 442	 442	 442	 0.962025	 0.0	 1	 -30.0	 30.0;
	407	 723	 0.0	 0.071508	 0.0	 442	 442	 442	 0.962025	 0.0	 1	 -30.0	 30.0;
	407	 723	 0.0	 0.042907	 0.0	 737	 737	 737	 0.974359	 0.0	 1	 -30.0	 30.0;
	407	 723	 0.0	 0.042907	 0.0	 737	 737	 737	 0.974359	 0.0	 1	 -30.0	 30.0;
	6085	 5744	 0.0	 0.079232	 0.0	 399	 399	 399	 0.95	 0.0	 1	 -30.0	 30.0;
	6746	 6410	 0.0	 0.045483	 0.0	 695	 695	 695	 0.98776	 0.0	 1	 -30.0	 30.0;
	7642	 7950	 0.0	 0.045483	 0.0	 695	 695	 695	 0.974844	 0.0	 1	 -30.0	 30.0;
	7642	 7950	 0.0	 0.045483	 0.0	 695	 695	 695	 0.974844	 0.0	 1	 -30.0	 30.0;
	5581	 5240	 0.0	 0.045483	 0.0	 695	 695	 695	 0.98776	 0.0	 1	 -30.0	 30.0;
	8422	 3260	 0.0	 0.047975	 0.0	 659	 659	 659	 0.962181	 0.0	 1	 -30.0	 30.0;
	8422	 3260	 0.0	 0.047975	 0.0	 659	 659	 659	 0.962181	 0.0	 1	 -30.0	 30.0;
	4050	 4370	 0.0	 0.044262	 0.0	 714	 714	 714	 0.987813	 0.0	 1	 -30.0	 30.0;
	2028	 2370	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	2028	 2370	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	2028	 2370	 0.0	 0.047975	 0.0	 659	 659	 659	 0.974679	 0.0	 1	 -30.0	 30.0;
	294	 9224	 0.0	 0.046721	 0.0	 677	 677	 677	 0.98768	 0.0	 1	 -30.0	 30.0;
	294	 9224	 0.0	 0.046721	 0.0	 677	 677	 677	 0.98768	 0.0	 1	 -30.0	 30.0;
	3292	 3612	 0.0	 0.047975	 0.0	 659	 659	 659	 0.962181	 0.0	 1	 -30.0	 30.0;
	3292	 3612	 0.0	 0.047975	 0.0	 659	 659	 659	 0.962181	 0.0	 1	 -30.0	 30.0;
	1929	 5090	 0.0	 0.0505	 0.0	 626	 626	 626	 0.95	 0.0	 1	 -30.0	 30.0;
	1929	 5090	 0.0	 0.0505	 0.0	 626	 626	 626	 0.95	 0.0	 1	 -30.0	 30.0;
	1929	 5090	 0.0	 0.0505	 0.0	 626	 626	 626	 0.95	 0.0	 1	 -30.0	 30.0;
	8110	 8441	 0.0	 0.070313	 0.0	 450	 450	 450	 0.95	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Line Capacity Model:         ub
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% INFO    : Line Capacity PAB:           15.0 (deg.)
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    61  -     1.78
% INFO    : NUC    42  -    11.26
% INFO    : COW    465 -    62.69
% INFO    : NG     877 -    24.27
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.1448956438 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.7521523623 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.9445620504 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9635666936 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.5821717535 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.12337724 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4919522269 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.12193767 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4221468801 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5474786002 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.3407216342 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8478513826 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.5554690436 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3724927694 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3754215879 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.2244463473 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.8069830252 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6319643302 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1203187238 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1962912506 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 67.8932741508 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6907149871 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.756253618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5346671545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.1079414375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1054585985 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.472656307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2230298783 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.53830134706 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9572218574 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.5217142326 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5367202281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.1472091281 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.161061359 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6491349142 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.216573094 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 5.14357913861 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6084111137 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.435670538 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7228543911 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.458323483 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 62.4572559744 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3205537428 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1097694059 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7159295352 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8553608201 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.04664883791 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.293748659 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3441457946 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.7927174285 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8907521582 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7371994587 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0392918212 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7260250079 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5362012376 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0025941398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.2863231512 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6650732429 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.2654436141 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0152193155 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3309529598 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.3864874767 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.91492702 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.5145576889 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.294769645 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8074885424 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2957254044 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.589695811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.95205073592 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9540644422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.1914480298 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7114239197 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.8049775625 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0335884993 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1524132125 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3258752824 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8239979359 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.4697581757 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5932718108 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.5519311978 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1292244213 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0532507682 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.278185786 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6510279558 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 87.6174974313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1386950827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8482140578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7335654459 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4824247421 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.459702539 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5050847555 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.6702119879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9754566262 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.2426472069 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.0257042193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5569104466 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.356071974 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7749117115 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3908722841 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.0379410712 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1799034295 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5019553824 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.31638168 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9088552941 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.8142392673 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4964774663 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.731812544 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2704346479 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9305246392 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.37817113277 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.668034214 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.3595807516 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.620092501 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3375550861 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3150108651 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.2356204573 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6046012533 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3637830078 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.0005003911 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9277615569 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7341707075 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9197161739 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6330613454 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8473134842 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6896072973 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0957559134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.5907475812 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.19279124213 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3958412679 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3962388843 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1189512659 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.60769303888 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7533050647 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.03304268548 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.4327491924 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6419114691 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6012522324 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.258327953 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0830928359 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.4127662987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.081563528 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3292832287 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3297872418 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.7543644126 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4387361793 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8984894348 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.7161176753 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5516158688 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.0798804127 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0538251698 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.044824085 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.5096302206 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5695026436 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.40191768 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.4944461485 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5117240049 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.7753844798 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.8252570413 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.230335341 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1738859604 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.3730287378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.0968687177 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.927220521 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4764739037 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.0750493695 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.084274756 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9975486683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1615732666 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.83468188685 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.7154218337 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0612907981 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.2554101644 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.8928003247 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8993236328 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4215170727 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.9580132656 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1032822991 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8661961828 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3006086357 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.7999055133 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8008159537 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5574013758 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.259256616 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5576103166 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.9116112296 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.014432485 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 1.07185047773 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9820485725 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.15195513956 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1624311855 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1354414971 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.6036617017 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.220193096 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.3673804833 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1034403508 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9344036811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5506498716 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.1777378726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.358056618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9281424723 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.1308109342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.913374139 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.9320505865 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.57061158 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2607638128 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9702964111 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7223416103 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.287917499 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0783340942 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.249509834 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4804135093 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8944839849 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.659079228 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8567302748 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.7585310376 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.9654745334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2798803711 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.356619481 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8565549721 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3162549937 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3710639516 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7599798068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7120762964 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4992862012 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3618336522 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.41960665574 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3294642416 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.0573048281 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.582126402 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.2662021513 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1200993746 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.5242521783 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0396751036 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7483031966 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.589378273 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.321662574 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0394635586 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2783933283 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2838613219 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1394822053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1372727978 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8372768855 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8709786888 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.254086185 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1475866659 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1659075281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6940151714 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9530361691 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2927778703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7935057748 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2223746194 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2199977051 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.5408611068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7685553694 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.649530977 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3633921333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.8902565503 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2700913789 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0242092731 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8622329347 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6187064604 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3231261692 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.343575282 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0949582707 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.49430471545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7995531486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.9611865279 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9760548384 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6910684212 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.9638971682 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5062525816 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5328327205 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2557789923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9489911101 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.666638015 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.6494587438 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2038881628 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1078842303 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.5659801465 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2547211222 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7583627479 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6975661122 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8109884323 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3194581015 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2893341975 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4540445326 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.8717268618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.6090640559 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7339337369 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8599629686 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0914669234 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3946977006 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9024407282 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2489165876 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9009855091 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6263220902 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.9229253962 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.98607766955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.635002551 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5092798416 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7526076317 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4023603381 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1392988551 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.04131286 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1209970289 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.3059209567 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6514527336 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7325406823 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6713951442 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.305848561 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6304952487 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4667319708 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.992191962 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4820899056 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9493937856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.5168997784 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.735967991 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.1874802553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6920391224 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2640559254 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3338300018 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.7293972019 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2292442654 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2993583144 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5427500863 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.6616632003 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4413479803 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8469977045 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.161974756 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9431697702 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2813475593 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.7869182183 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2565648333 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3182468667 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.8088352148 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.6509036884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2499667706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0388238963 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5376278796 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0731835357 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.8247845269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6706024258 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9969711333 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.21753968523 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0673624489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.3945936367 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7377116583 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.9854536707 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5532880274 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9653504145 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.0272802807 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.60285525442 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.998832427 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.5036906513 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6772071698 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4454830917 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3532652549 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8277731647 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0842493909 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4632432331 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5523613252 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 64.068346903 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.4013783898 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.8582321337 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.3470555595 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2983855215 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4329118017 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1000790704 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.6651983863 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.9795520948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0835384057 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6548844934 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3213775796 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.6132135524 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.7510115912 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.313190627 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6353440596 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2745556373 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6520362968 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3886387154 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3512858002 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1155233532 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.23208191468 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2245104678 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.827946511 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6369872497 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.11933920265 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.6441793452 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.659348545 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1014172215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 7.87110287405 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6385834591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7000268282 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4586312452 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3283977846 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.2255350591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7400960274 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.8348524949 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7095820239 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6387414231 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.78463543 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.9119692703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3578562956 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.963407757 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.1068741269 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.3110625878 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.7026188176 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8544867544 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1400271128 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.0652282607 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0144631961 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.8855148609 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.8795283181 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6062464346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3846336464 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.617235879 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4068186497 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7358165179 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1663025443 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2932828302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0464885128 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.039634639 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.8938445589 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1756030388 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.3472019492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1319862066 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3788360545 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2439074119 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.4903298285 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 127.65831126 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.7374542037 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.73562979692 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.2353367721 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6977723236 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8521944965 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.5900040076 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.1702033226 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6380553858 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4235740838 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3452977873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.6608331929 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4572774432 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7142223668 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3635383801 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4141493738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.9945733617 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.5116317523 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7349582515 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8737920826 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4718057955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.0385680144 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.6357289552 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7239530945 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.9096482613 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.374374748 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4026623226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9078645533 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.9185252597 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.2961221599 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.0541735172 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.800196599 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.9707526822 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.9422383684 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5253172699 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7176630852 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2535987503 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.808574164 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3369223532 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.2917730729 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.0016283882 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.9739241486 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.9258708444 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3086355749 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9086081849 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1048410315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.685946405 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5705383436 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1105806872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.0577549883 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.2947036297 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9719451954 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.3377814674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0583963212 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2558937667 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.373475928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1661805563 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7143964644 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9275633856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2610379131 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4069452322 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9308715245 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3186114 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.4988275771 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.8709568581 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1285995794 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.968418509 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.0131138725 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.85835500847 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8361267196 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6940692846 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6841518953 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.9176712962 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5410214172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2569190761 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4983625804 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9034997744 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1599621124 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6907313126 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6695593324 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9635220925 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.089574549 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1757118278 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9972191603 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1035065816 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7371946112 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3485385174 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9584520654 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7982477219 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.1840653745 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9555105968 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5732788064 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8224156592 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.1958760787 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.0282292278 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.7792744701 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1611723447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.0787302009 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1079170121 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.767012338 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.603225615 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1020257088 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4848587621 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2871865922 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5199356818 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.6985191669 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.9798834997 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1327633621 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.4792062832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5044844208 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4820548851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6543326483 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.3892731259 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0091275914 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0706592481 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.3648572416 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8916378306 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8429548373 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.8259043796 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.046708862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.7251540306 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8068933403 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9687987431 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8476135996 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.029777217 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3627849388 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7772072827 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 1.53773982959 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2753633193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4586047377 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.9128905968 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2451758075 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1452186036 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4079984736 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7445527142 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.206807216 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9726986533 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0238545564 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0432826663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.228707643 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0606092474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0455346331 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5046250055 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 49.3892914676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.7022310268 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.322694243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0295635416 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.830975268 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6964788384 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.2679956526 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3473106198 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.0900561921 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.3290036364 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.462531785 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4672129955 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6985804259 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5890507818 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0195438908 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.894350701 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.6272047628 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.214251215 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.065244175 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5327682879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.3801481741 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9375424639 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4156665002 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2561244671 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0892580031 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3511487912 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.4219404655 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2894628396 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 5.48697873976 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.1982415929 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.3700069372 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1277898746 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1680485331 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.336866126 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.4450313433 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7725972676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5636967684 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.8092847229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7213379544 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.658198255 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.57385119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7747644748 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.6844174554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9986537738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0262773987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3754087124 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7864685628 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0097891976 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.8164769911 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1344514135 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9237036223 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.77388797605 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4185933861 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.1136084465 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2203966866 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4326325089 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.681431087 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.68435026169 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0436549182 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3095709308 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9584759953 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.6859466218 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6495087828 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4329340807 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.1520653674 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0171368976 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1354169197 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6518227594 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 44.0107265777 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2860707134 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6693394969 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.9733886337 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4349931652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8137104441 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2872720762 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.35784739195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8906260777 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6899791971 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.3488135193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0122275311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7717199546 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2965284714 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4212533389 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3818824081 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.8315990753 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.5463409834 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.3494605037 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.1292285012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.7377764997 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.04050387 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3200479583 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3411058289 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.2966533031 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.042006008 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6498383147 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5820296875 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.527655676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.6550370202 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6354421422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.7396549853 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1772753413 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4667368046 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5471675716 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2747073125 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.4225265928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1951149281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0430288275 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.163039612 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9030401741 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.8664539903 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3981738286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4875523133 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.84441236505 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6642594197 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3055633236 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3093740927 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3856997586 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9822003933 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.3135560804 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8421499551 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1141985101 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3280235587 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8173262096 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 3.60802114193 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.997396663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.0140854173 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1730404027 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3927308655 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.05902855 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.1520413892 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8894168366 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.2867888732 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6771546099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3691385988 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3803764964 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6529381082 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8639070702 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6200153577 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5700338776 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3039258114 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9224084509 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8552506313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2003139548 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1504229296 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.068272477 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.9668785116 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.91324127931 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0983989248 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.3782444501 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.4312469831 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1589857423 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.0013987241 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.08044808699 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.9765589923 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.53366567518 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.075854149 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.6619533427 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2420872683 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7973606412 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.055036483 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.8514984277 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.482917917 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1129359135 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1581591854 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.7573236609 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4645380976 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.5722545839 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0586182625 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.0666068815 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2294911337 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4866705857 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4599311025 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.945737527 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.960106323 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.964478046 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.56248563424 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.837256022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0478912541 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.327454451 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4311123746 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5972935934 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6006716363 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2232488246 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6802201601 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.63770857951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6674319834 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.3975136314 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4507272515 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.3300254594 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2389864441 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.1654751932 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8967684643 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2019214687 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7394485356 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.1853177555 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.930887728 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6752603214 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.8645622549 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.897136132 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.278803273 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1612369875 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.0390352937 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3064195413 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1034678097 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0502175621 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1723356757 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.137214472 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.53207964415 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.83490597672 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 44.0639966313 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.5447678706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.516308257 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6403188775 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6759807089 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 4.14026357986 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.826715348 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0408286642 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4421625921 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4230771091 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9422149324 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9033664563 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3432597296 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1311137032 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 65.3977998721 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0948394649 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6475005945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0490666878 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.328953675 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9935892036 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.0140265562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.553502256 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.368554522 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.0507091965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7765323526 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 4.18991189488 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8732211413 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.3674715255 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.1063219495 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.013667417 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.2677803531 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.743462284 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1946404417 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9036477536 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2707819886 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.2932380069 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7453591956 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.012929224 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2182353596 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5249162632 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7941182187 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6759595232 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5040548834 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7638091772 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.355888047 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4173074495 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9747572411 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3577673913 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.6587991519 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4799673145 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5660200068 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6611621935 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3204848908 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.575824587 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2348984417 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5630495684 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2993430525 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1728934093 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6171655269 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3013635704 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4170138536 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2675721975 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7289627979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.758792739 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3804900752 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9474317776 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.7709905869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.116815603 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8477648697 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5150141994 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0829944825 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.7490225852 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6583591141 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.6022032054 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.4475953701 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0237704855 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.8649976766 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5335706286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.9165548792 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6664121998 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.7685477399 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.0859296902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.5620986493 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2131545141 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.4440254 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.355193396 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2843235518 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.97395978 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0971757486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9068077811 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9901922981 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9344332001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3948317484 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.110469625 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7242254504 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.0518827863 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4413591627 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0748348263 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.52620597 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1329582595 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0676100401 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8295612687 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1583070088 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0513373491 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.8739027045 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0479696847 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.5775721837 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0854097229 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3897394362 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.061389786 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2632298102 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.7362070999 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8450548234 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1470589969 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.9137879081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4194182816 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.9244105035 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7914669842 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2135361753 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4446055796 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7312527018 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9685950269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5211119832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2839062947 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.1007092276 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5766722738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.6074304512 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2106594092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8903156173 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2472909142 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3666924873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3314916457 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0872286821 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0840428922 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.39297344 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.298010204 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7481083685 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.5208964919 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7897356635 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.0819020219 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0838584187 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9509460847 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2748840475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4549443257 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7179222271 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0095910506 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.8276564476 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1617068736 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7763903506 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8733819283 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9247466945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7447444146 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9760111656 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5210147844 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4283121914 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.689968992 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.721288126 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6432837253 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7087120535 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2587512726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1165817219 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.6817682855 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.7026423425 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2372272551 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.2900828558 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.53325798 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6493550628 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6419123853 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3267390599 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.4755783386 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0185575274 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.5270045556 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.223310789 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.23026314197 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8829588355 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4131902375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.0757651289 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.730659204 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9778432509 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1004811681 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.486294224 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7828350549 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.580400226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8199338108 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.55346924923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4138412856 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6471014584 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.670432622 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7062297396 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4307175124 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1782351349 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.39699620269 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.6896471929 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.28788480194 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.756499627 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.1264266901 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 5.28239428393 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 125.29071135 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.3817511302 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8587522131 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.44682039647 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.7593629359 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.5693968274 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0698786058 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.64134458849 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7326374833 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.717302868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3563129938 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4228505502 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.66145790877 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5693023573 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.7855968957 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.7717860363 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4805198141 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.368083168 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7030493283 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.7650884058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.463621615 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0876842187 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.729645743 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.4081510869 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7614205923 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.0133030714 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6724057525 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.569970923 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.68067315141 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2622890665 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9835663808 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.88814424 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1386937944 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 3.78678196363 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5079276616 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0448286832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0762480863 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0255445154 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8959619072 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1464293347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9856821078 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.375984661 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.337298275 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0253894932 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4028933886 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.5798395537 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8805072193 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0290580239 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5906856315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.3433331349 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 52.89715815 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2167378173 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.516705594 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.2565898451 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0925471303 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.90745862107 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1306409754 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8783729086 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.2336838365 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.2886501898 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.668791128 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2549763971 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9110061695 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7974762294 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4697581154 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.673093328 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.79593502816 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.5547799444 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 90.0134952361 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6974060286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2728976098 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.182295298 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.9740253752 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.424028278 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.3988879522 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.313818031 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0916955613 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3684383765 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7427715454 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.5599267359 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4554066811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0838745473 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.141197581 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6436314099 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.65211398107 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0921844133 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0425346149 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.409747936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.5721474511 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.6351840438 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6194141706 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2783613636 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.5725723488 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3354441217 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.8921305381 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.224109896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.5020439476 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.7151108488 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.477056676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2435614845 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.8391434944 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7262178486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8678851417 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.122899994 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5756868293 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0870448963 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5321681207 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.64830596408 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4368485428 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.9360678858 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.8438991684 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.698064308 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9573684014 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0098157936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6866210811 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.7236179431 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7732783759 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7292860251 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.6409180853 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7788720697 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.882266774 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0669331303 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.7253530897 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.9073347884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.37297966 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.209089581 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2507849287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9819610488 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1031884353 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4362494837 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0058239148 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1113110631 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9696418965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.0812059548 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2526075466 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6243118382 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1682416419 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.0335536131 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1891522267 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2962092965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.595975936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1520288475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2003685471 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4017061829 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4564387935 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.8218336103 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.707880731 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7799175496 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.897553942 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1306493204 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.59070297 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3604028029 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8271724798 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7631970094 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7374040447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.9347474907 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.883192332 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2643092291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9818877967 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7161559752 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2675380521 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.42798382798 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8686111006 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.8292309263 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.3172926972 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.03902067609 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4850745597 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6464870384 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3696752198 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.641340779 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5046298423 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.353961153 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 5.61487826838 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5774068699 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.5678879207 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8161098922 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2743479713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1694519148 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4338869913 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7853409712 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.794263838 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.399675443 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.9585296281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6973639172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.2467034521 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4594031539 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2790578443 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3430693048 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.31133048553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1928722389 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8664550277 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8259670618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1601366663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.6080486399 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7990440558 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5349533554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2299665307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6939732698 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.2658807462 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.6176314017 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.063566057 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9599394681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.3345427979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.943199915 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3049923948 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.0386594715 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3651017402 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.9997695873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.9408623496 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.0862841676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6542469129 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.3235464377 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2497563799 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.5166098291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5391206352 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.5679608988 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7931971302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.6417885802 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2794737935 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.40880272112 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4319721557 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.0389817138 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.115731996 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5765973865 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.355039486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5892038842 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.8092194627 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.9313755758 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.704263915 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0690410848 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3757127505 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3763371268 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.7499527686 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.4982705879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8960780041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9268556047 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.5709954382 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3231231959 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.7624939307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1345028517 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0533063702 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7777689407 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7080374312 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.1468871262 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.038240382 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3115479537 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 135.689481916 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.528363113 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 7.99466779342 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3687278894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.241873055 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0242363549 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9482344787 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4095059649 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.63338679467 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9574473794 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7580763226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.9318741287 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7832805189 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.9679547488 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4488880324 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2341155407 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.6633963402 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.218492959 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7709535438 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0570993545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1556259273 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3046478724 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.880919306 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.9769975235 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.066270775 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.1689191399 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6585788122 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8434795883 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6824842205 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1476292407 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.8118147355 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9412460341 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 4.12726795779 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3335014491 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.54476560059 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8602079064 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9771355632 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.5701559335 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1846011924 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4329421365 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.21834290954 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.7724627466 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0186438779 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6840659936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4026290381 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9338058851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3872864836 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2130386193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8675726976 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.5739495367 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.3846331351 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5861172595 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4353740281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9307220964 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4378489895 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0782366147 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4731812376 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.602773866 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0498739542 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0167229141 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0998152348 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5778395592 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6122727643 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3114154056 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4170539296 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6592988145 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9270038588 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.889352348 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0474677924 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.755501942 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.0715721079 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8638865425 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8996643001 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.7045663716 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3979867365 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2130521543 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0919650691 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.8795392052 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8917782659 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.941121562 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.4923582191 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1794979159 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.5143918538 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.719370203 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.0253899093 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6422541319 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9299403575 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8207301723 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.265734165 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4004857821 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8480340798 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.4679430988 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8225537554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.3321086281 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.6663498873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.2117210321 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.417372673 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0756973216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8683746631 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9495913557 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.0067939495 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.1498874928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8821604716 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7394599507 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.726492618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5886320237 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.4834918611 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0150505975 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.1906010419 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1445881394 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2984959386 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4343925218 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6326153859 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.5880422894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1714816204 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.7717613639 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.726985653 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.6808017588 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.6764948776 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2857497868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3070167911 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7021925236 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9325573415 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.8554587524 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.5791961333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.6923243577 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2489621243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.593725891 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7732895001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1786588457 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.081694259 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3069593603 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5790990178 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.87513895657 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7120421378 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.6490649399 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4154651775 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1441627421 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.0228673665 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9271550216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.3457323643 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4155987843 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0313450272 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.4438055601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5796643872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7348565864 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.237648554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2139980346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5511083219 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0174819986 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7326736304 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.695983641 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1421464265 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2942884489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8456789181 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.544317837 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2419212883 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0228555229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7292508991 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3478903089 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6305825007 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2050721587 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.0055906044 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8804205328 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.0715920792 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7069850935 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.9478553725 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6192023823 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.423956848 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2299600636 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2809650702 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9160249274 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3981813558 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3731693134 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.698253665 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0809516763 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7833225557 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3169782844 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3165919851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8177052121 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.2108645218 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0469468569 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5731541966 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.9766340231 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.3662819605 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.6528766871 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9573615987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9888500865 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1114670923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4621089534 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2929321421 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2718130082 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1660815551 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.602737327 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0623411711 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2688852356 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8296335017 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.40064274565 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.2520345509 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8194933754 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.72977588286 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.0345101755 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1862659733 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.81682601285 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6787433743 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1025154507 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.2288867114 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3005575279 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.2503712594 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.9323512965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.249058681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0408657171 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.8507025 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0483888965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2238825487 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2746720733 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.7377182026 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1776284463 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0779731365 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8800683749 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.3295743775 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Branch 6967-4635 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6967-4635 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2474-7141 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2474-7141 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2474-7141 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7931-4322 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7931-4322 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7931-4322 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 273-8339 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 273-8339 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6505-8826 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6505-8826 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5976-4329 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5976-4329 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5989-4625 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5989-4625 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5989-4625 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 4310-667 has a phase shift of 0.047371, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 4310-1829 has a phase shift of -0.047371, changing tap ratio 0.0 => 1.0
% WARNING : Branch 8612-5070 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2613-3801 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2613-3801 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7829-1968 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1815-792 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7829-6826 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-792 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-792 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-7279 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-8335 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-2449 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-4665 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-4495 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-7279 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-8335 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7829-5776 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-2449 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-4665 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 7637-8581 has a phase shift of -0.428189, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 5848-7526 has a phase shift of 0.178581, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 2154-5996 has a phase shift of -0.153178, changing tap ratio 0.0 => 1.0
% WARNING : Branch 3173-8768 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3173-8768 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 888-4877 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4388-1073 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4388-1073 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7790-3437 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1438-1324 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1438-1324 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1438-1324 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6006-3669 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6006-3669 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 36-1641 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6158-4518 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6158-4518 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5778-6433 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5778-6433 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 1615-381 has a phase shift of 0.432244, changing tap ratio 0.0 => 1.0
% WARNING : Branch 4079-153 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4079-153 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6375-4762 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6375-4762 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-6234 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-6234 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-6234 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-6234 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-6234 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-6234 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-6234 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-6234 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-7410 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-7410 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-7410 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-7410 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5401-2743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6284-2743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6272-2631 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6272-1144 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6272-3332 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-7786 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-7786 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-7786 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-7786 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-6212 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-6212 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-6212 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-6212 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-4012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-1029 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-3431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-4033 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-1238 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-438 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-1907 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-3330 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-1587 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-8938 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8851-1177 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-4012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-4012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-4012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-4012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-4012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-4012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-4012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-4012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7502-6171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4101-6171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2511-6171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1522-6171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4866-6171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6724-6171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8429-6171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7816-6171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5428-6171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8762-8498 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2306-182 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1667-182 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3514-182 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-7711 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-7711 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-7711 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-7711 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-7711 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-7711 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-7711 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-7711 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-7711 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-1029 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-3431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-4033 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-1238 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-438 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-1907 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-3330 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-1587 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-8938 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8553-1177 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6584-5323 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9037-5323 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6497-5323 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4766-5323 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4296-5323 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5611-5323 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4647-5323 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7483-5323 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6584-6715 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6584-5301 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6584-2237 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6584-4350 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9037-6715 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9037-5301 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9037-2237 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9037-4350 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6497-6715 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4766-6715 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4296-6715 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5611-6715 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4647-6715 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7483-6715 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 424-5439 has a phase shift of -0.157232, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 6497-2222 has a phase shift of 0.13111, changing tap ratio 0.0 => 1.0
% WARNING : Branch 6497-5301 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6497-2237 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6497-4350 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2016-8929 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8517-8929 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2016-7457 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8517-7457 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4334-2743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8421-2608 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8421-9077 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8421-7321 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-6451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-5680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-2895 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-1067 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-4789 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-7592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-6421 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-1085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 92-3913 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4766-5301 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4296-5301 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5611-5301 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4647-5301 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7483-5301 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4766-2237 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4296-2237 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5611-2237 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4647-2237 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7483-2237 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-6451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-5680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-2895 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-6718 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-4702 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-7500 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-1067 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-4789 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-7592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-5440 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-2605 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-6421 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-1971 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6848-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-6451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-5680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-2895 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-6718 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-4702 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-7500 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-1067 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-4789 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-7592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-5440 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-2605 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-6421 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-1971 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5523-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5941-2743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-1029 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-3431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-4033 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-1238 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-438 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-1907 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-3330 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-1587 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-8938 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 192-1177 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-1029 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-3431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-4033 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-1238 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-438 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-1907 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-3330 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-1587 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-8938 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3349-1177 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-1029 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-1029 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-1029 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-1029 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-1029 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-3431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-3431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-3431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-3431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-3431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6554-1242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2016-1242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8517-1242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4766-4350 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2016-7198 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2016-98 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8517-7198 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8517-98 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2306-2912 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1667-2912 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3514-2912 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5102-2788 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5102-9077 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1811-2788 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1811-9077 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-4033 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-4033 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-4033 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-4033 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-4033 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-1238 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-1238 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-1238 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-1238 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-1238 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-438 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-1907 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-3330 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-1587 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-8938 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5495-1177 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4296-4350 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5611-4350 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-6451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-6451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-6451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-6451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-6451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-6451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-5680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-5680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-5680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-5680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-5680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-5680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-2895 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-2895 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-2895 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-2895 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-2895 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-2895 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-438 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-438 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-438 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-438 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-1907 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-1907 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-1907 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-1907 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7093-3332 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7093-6130 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7093-1258 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7093-4085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7207-3332 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7207-6130 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7207-1258 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7207-4085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-3330 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-3330 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-3330 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-3330 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-3423 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-1067 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-4789 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-7592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-5440 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-2605 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-6421 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-6655 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2891-6307 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-1067 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-4789 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-7592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-5440 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-2605 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-6421 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-1085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-3913 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-6655 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4737-6307 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-1587 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-8938 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6894-1177 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-1587 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-1587 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-1587 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 491-3332 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 491-6130 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 491-1258 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 491-4085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-8938 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-8938 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-8938 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9100-1177 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5717-1177 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6222-1177 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 324-3332 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5862-3332 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4052-3332 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 324-6130 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5862-6130 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4052-6130 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-8022 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 324-2743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 324-1258 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 324-4085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-5909 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-5909 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-2828 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-2828 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-1067 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-4789 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-7592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-5440 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-2605 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-6421 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-1085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 63-3913 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-242 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-5596 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-4099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4647-4350 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-3423 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-1067 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-4789 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-7592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-5440 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-2605 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-6421 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-1085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9211-3913 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-8182 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-8182 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-6718 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-6718 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-4702 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-7500 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-5440 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-2605 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-1971 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-6655 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7082-6307 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-4702 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-7500 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-1067 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-4789 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-7592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-5440 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-2605 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-6421 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-6655 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8336-6307 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-1067 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-1067 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-3533 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-4789 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-7592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-5440 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-2605 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-6421 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-1085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2724-3913 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-4789 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-7592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-5440 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-2605 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-1971 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-1581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-6655 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1268-6307 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5862-1258 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4052-1258 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5862-4085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4052-4085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7483-4350 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7650-3606 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1663-2883 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7966-2883 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5100-2883 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1588-2883 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2890-2883 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1663-6197 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6605-7815 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8855-56 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2420-5088 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2420-5088 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1663-397 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1663-4971 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1663-1120 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4637-1675 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4637-3539 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8855-1624 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8855-7127 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8855-9165 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3835-417 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4366-417 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2385-417 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6605-5325 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6605-4167 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7966-3537 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7966-5869 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2906-1675 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7920-417 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2080-417 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7424-417 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6193-417 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5100-3537 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5100-5869 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1588-3537 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1588-5869 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4634-5622 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2138-5622 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2906-5622 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6274-5622 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2906-3539 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6605-2663 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6605-4804 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6605-7602 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6274-2901 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2890-3537 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2890-5869 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8725-5433 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6965-5433 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6906-5433 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5754-5433 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6227-2903 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3784-6418 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2409-6418 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4578-6418 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6524-7097 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5969-7097 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2429-7097 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3116-7748 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9160-7748 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1148-8113 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7116-8113 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1400-7609 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1400-4793 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8187-7609 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8187-4793 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3149-2903 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1214-2903 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1253-2903 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5528-2903 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4786-2903 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6027-2903 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4294-2903 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5380-4151 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7399-3905 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3784-158 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2409-158 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4578-158 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3784-4593 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-4593 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2409-4593 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4578-4593 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3160-4593 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3116-5779 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3116-6997 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8725-3934 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6965-3934 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1148-4793 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1148-8798 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1148-1657 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7444-4154 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-4154 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7444-8638 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7444-6336 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7444-3479 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7444-5232 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7444-8699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7444-3777 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7444-5261 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7444-7620 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3225-7451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6589-7451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 798-7451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4500-7451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6906-3934 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5754-3934 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2486-2443 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8427-309 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2176-309 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1823-309 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3583-309 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6864-309 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9160-167 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-8638 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-886 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3160-886 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1323-4151 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3655-4151 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6589-6321 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 798-6321 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4500-6321 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1214-5896 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8427-5896 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2176-5896 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1823-5896 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3583-5896 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6864-5896 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-7997 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3160-7997 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8427-6120 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2176-6120 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1823-6120 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3583-6120 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6864-6120 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8427-5152 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8427-8134 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8427-8123 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8427-8451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2176-5152 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1823-5152 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3583-5152 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6864-5152 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2176-8134 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2176-8123 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2176-8451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 829-4146 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5754-4146 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7399-4146 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4501-6155 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9088-6155 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8388-6155 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7731-417 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7731-129 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6977-8503 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4501-3617 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9088-3617 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8388-3617 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4501-296 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9088-296 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8388-296 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9080-8059 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1765-8059 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 624-8059 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1485-8059 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4718-8059 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 798-6886 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 798-7161 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6977-1949 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 584-5530 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 584-2223 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9154-4522 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7942-4522 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9154-1707 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7942-1707 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1823-8134 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1823-8123 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1823-8451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3583-8134 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6864-8134 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3583-8123 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6864-8123 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7399-540 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9080-5958 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9080-6603 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9080-1690 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1765-5958 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1765-6603 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1765-1690 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5116-5530 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5116-6981 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2260-5530 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2260-2223 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4501-4268 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9088-4268 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8388-4268 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3583-8451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3225-3261 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9154-683 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9154-7360 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9154-4557 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 330-5530 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7781-5530 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 873-5530 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6343-5530 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 624-5958 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 624-6603 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 624-1690 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1485-5958 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4718-5958 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6977-822 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6864-8451 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-6336 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3225-6336 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 79-6886 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 79-7161 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-2610 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3160-2610 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-3479 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5914-5673 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6524-8516 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6524-7655 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5969-8516 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5969-7655 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1485-6603 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4718-6603 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1485-1690 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2429-8516 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2429-7655 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-5232 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-8699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-3777 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-5261 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6083-7620 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5914-2223 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7116-4793 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7942-683 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7399-683 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7399-3854 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7116-8798 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4500-6886 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4500-7161 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9160-8639 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9160-5580 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 330-6981 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7781-6981 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7942-7360 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7942-4557 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7116-1657 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4718-1690 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 873-2223 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6343-2223 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8779-8414 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8779-6794 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1900-8944 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1900-2852 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1900-439 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1900-484 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 511-8944 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3396-8944 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7799-8198 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6956-8198 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7680-6621 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7680-4122 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6466-6621 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6466-4122 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8256-8414 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8256-6794 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2192-2418 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6900-2736 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6458-2852 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 511-2852 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 511-439 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 511-484 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8415-2852 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3396-2852 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3396-439 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6900-3759 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1601-193 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3396-484 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5986-2418 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1601-5880 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7799-5880 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6956-5880 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6900-3189 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3057-7741 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 197-7741 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2309-8414 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2309-6794 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 503-8414 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 503-6794 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6457-7514 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 549-5002 has a phase shift of 0.120551, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 3069-6115 has a phase shift of -0.096484, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 7256-4491 has a phase shift of 0.036236, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 6153-58 has a phase shift of -0.119536, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 749-4324 has a phase shift of 0.04898, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 7466-3649 has a phase shift of -0.110406, changing tap ratio 0.0 => 1.0
% WARNING : Branch 2389-8003 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2389-8003 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8375-49 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4810-2729 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1747-6998 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 593-6998 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3190-7090 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3484-7090 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3484-7844 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4059-6282 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2002-4340 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 76-5346 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6477-2478 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5295-2478 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1443-6268 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4638-6268 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1315-3848 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2997-4595 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2997-4581 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6190-977 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3676-977 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5505-977 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7625-3438 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3797-638 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-638 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4847-638 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4638-7293 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3676-7293 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5505-7293 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1443-2509 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3797-966 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3797-2604 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 248-8449 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4244-8449 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1110-8449 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4533-3219 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3147-7854 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6109-2274 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 993-2274 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4257-8387 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4257-5640 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5462-8387 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2758-8387 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2758-5640 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1110-328 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-3219 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4847-3219 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5209-4695 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5209-3515 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7625-6100 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8822-8971 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8822-3084 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7625-2771 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3368-2862 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3368-5075 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4244-8610 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1443-1492 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1443-5305 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 248-7025 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7625-6708 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8822-6708 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7089-7025 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1110-7025 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7625-3404 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8822-3404 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1110-578 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8822-5513 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3762-4468 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 499-4468 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3762-378 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 499-2250 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8685-2250 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 499-3411 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8685-3411 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 499-2539 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8685-2539 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 499-378 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 499-5386 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 993-7890 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 993-1507 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8685-378 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8685-3782 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8685-5386 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1315-3953 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4244-3326 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2948-2573 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3368-6937 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2997-8537 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1110-7298 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1110-262 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1110-6169 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2948-3782 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7625-3003 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7625-3991 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8822-5656 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5822-2553 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5822-4051 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4847-173 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4847-6601 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1315-3991 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4847-3607 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5825-702 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4437-155 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4437-7730 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2939-341 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2939-341 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2939-341 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3103-8471 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4361-3026 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8734-8570 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8734-8570 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 663-7604 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 663-7604 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3104-7477 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3104-7477 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4861-7528 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3372-5218 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7978-6673 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7978-6673 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2349-1714 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2349-1714 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3688-5629 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3688-5629 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 465-4803 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 465-4803 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1753-3470 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1753-3470 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4899-591 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4899-7705 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7521-1087 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7521-1087 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3750-7687 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3750-7687 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3750-7687 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3750-7687 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 694-1960 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 694-180 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1473-4784 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1473-4784 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 8556-9133 has a phase shift of 0.199334, changing tap ratio 0.0 => 1.0
% WARNING : Branch 3940-956 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5757-2001 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5757-2001 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1881-3459 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1881-3459 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 926-2182 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7728-1800 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7728-1800 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7128-5667 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2241-2584 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4469-5590 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4469-5590 connects two different voltage levels (400.0, 154.0), changing tap ratio 0.0 => 1.0
% INFO    : 
% INFO    : === Line Capacity UB Model Notes ===
% INFO    : Updated Thermal Rating: on line 5147-3097 : Rate B, Rate C , 0.0, 0.0 -> 5104
% INFO    : Updated Thermal Rating: on line 5147-8763 : Rate B, Rate C , 0.0, 0.0 -> 4259
% INFO    : Updated Thermal Rating: on line 2169-3124 : Rate B, Rate C , 0.0, 0.0 -> 4974
% INFO    : Updated Thermal Rating: on line 2169-3234 : Rate B, Rate C , 0.0, 0.0 -> 5678
% INFO    : Updated Thermal Rating: on line 3517-711 : Rate B, Rate C , 0.0, 0.0 -> 2013
% INFO    : Updated Thermal Rating: on line 3517-4533 : Rate B, Rate C , 0.0, 0.0 -> 2838
% INFO    : Updated Thermal Rating: on line 427-5425 : Rate B, Rate C , 0.0, 0.0 -> 55004
% INFO    : Updated Thermal Rating: on line 427-4704 : Rate B, Rate C , 0.0, 0.0 -> 56085
% INFO    : Updated Thermal Rating: on line 5960-7431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1870
% INFO    : Updated Thermal Rating: on line 5960-3186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 4481-7431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1946
% INFO    : Updated Thermal Rating: on line 4481-3186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 531-9203 : Rate B, Rate C , 0.0, 0.0 -> 1711
% INFO    : Updated Thermal Rating: on line 531-835 : Rate B, Rate C , 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 1656-118 : Rate B, Rate C , 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 1656-3449 : Rate B, Rate C , 0.0, 0.0 -> 1785
% INFO    : Updated Thermal Rating: on line 5084-1809 : Rate A, Rate B, Rate C , 2793.0, 0.0, 0.0 -> 2407
% INFO    : Updated Thermal Rating: on line 5084-6398 : Rate B, Rate C , 0.0, 0.0 -> 3236
% INFO    : Updated Thermal Rating: on line 5205-7833 : Rate B, Rate C , 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 5205-7770 : Rate B, Rate C , 0.0, 0.0 -> 1968
% INFO    : Updated Thermal Rating: on line 354-1278 : Rate B, Rate C , 0.0, 0.0 -> 12367
% INFO    : Updated Thermal Rating: on line 354-7617 : Rate B, Rate C , 0.0, 0.0 -> 12131
% INFO    : Updated Thermal Rating: on line 2611-1278 : Rate B, Rate C , 0.0, 0.0 -> 10398
% INFO    : Updated Thermal Rating: on line 2611-905 : Rate B, Rate C , 0.0, 0.0 -> 10081
% INFO    : Updated Thermal Rating: on line 1842-6542 : Rate B, Rate C , 0.0, 0.0 -> 22560
% INFO    : Updated Thermal Rating: on line 1842-7622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11969
% INFO    : Updated Thermal Rating: on line 2134-6542 : Rate B, Rate C , 0.0, 0.0 -> 23027
% INFO    : Updated Thermal Rating: on line 2134-8785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12243
% INFO    : Updated Thermal Rating: on line 6613-6542 : Rate B, Rate C , 0.0, 0.0 -> 4551
% INFO    : Updated Thermal Rating: on line 6613-1651 : Rate B, Rate C , 0.0, 0.0 -> 5317
% INFO    : Updated Thermal Rating: on line 5773-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26146
% INFO    : Updated Thermal Rating: on line 5773-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20335
% INFO    : Updated Thermal Rating: on line 5214-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6424
% INFO    : Updated Thermal Rating: on line 5214-7840 : Rate B, Rate C , 0.0, 0.0 -> 20703
% INFO    : Updated Thermal Rating: on line 8072-6542 : Rate B, Rate C , 0.0, 0.0 -> 6872
% INFO    : Updated Thermal Rating: on line 8072-2759 : Rate B, Rate C , 0.0, 0.0 -> 6500
% INFO    : Updated Thermal Rating: on line 2971-6069 : Rate B, Rate C , 0.0, 0.0 -> 7699
% INFO    : Updated Thermal Rating: on line 2971-3445 : Rate B, Rate C , 0.0, 0.0 -> 6278
% INFO    : Updated Thermal Rating: on line 7561-6069 : Rate B, Rate C , 0.0, 0.0 -> 4506
% INFO    : Updated Thermal Rating: on line 7561-8825 : Rate B, Rate C , 0.0, 0.0 -> 3909
% INFO    : Updated Thermal Rating: on line 6748-8864 : Rate B, Rate C , 0.0, 0.0 -> 6746
% INFO    : Updated Thermal Rating: on line 6748-5078 : Rate B, Rate C , 0.0, 0.0 -> 6153
% INFO    : Updated Thermal Rating: on line 4956-4785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10073
% INFO    : Updated Thermal Rating: on line 4956-7667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10284
% INFO    : Updated Thermal Rating: on line 8619-6775 : Rate B, Rate C , 0.0, 0.0 -> 5953
% INFO    : Updated Thermal Rating: on line 8619-8195 : Rate B, Rate C , 0.0, 0.0 -> 5927
% INFO    : Updated Thermal Rating: on line 3107-4785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3890
% INFO    : Updated Thermal Rating: on line 3107-7154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3600
% INFO    : Updated Thermal Rating: on line 5437-6775 : Rate B, Rate C , 0.0, 0.0 -> 5777
% INFO    : Updated Thermal Rating: on line 5437-905 : Rate B, Rate C , 0.0, 0.0 -> 6597
% INFO    : Updated Thermal Rating: on line 2282-6876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 2282-5654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 474-6876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 474-8045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 7917-7472 : Rate B, Rate C , 0.0, 0.0 -> 28833
% INFO    : Updated Thermal Rating: on line 7917-8899 : Rate B, Rate C , 0.0, 0.0 -> 29367
% INFO    : Updated Thermal Rating: on line 6225-7681 : Rate B, Rate C , 0.0, 0.0 -> 7943
% INFO    : Updated Thermal Rating: on line 6225-1508 : Rate B, Rate C , 0.0, 0.0 -> 8235
% INFO    : Updated Thermal Rating: on line 7118-6568 : Rate B, Rate C , 0.0, 0.0 -> 2844
% INFO    : Updated Thermal Rating: on line 7118-4346 : Rate B, Rate C , 0.0, 0.0 -> 2112
% INFO    : Updated Thermal Rating: on line 3469-8850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 3469-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 7556-7058 : Rate B, Rate C , 0.0, 0.0 -> 1485
% INFO    : Updated Thermal Rating: on line 7556-4324 : Rate B, Rate C , 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 1069-2867 : Rate B, Rate C , 0.0, 0.0 -> 608
% INFO    : Updated Thermal Rating: on line 1069-2588 : Rate B, Rate C , 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 3945-2867 : Rate B, Rate C , 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 3945-2588 : Rate B, Rate C , 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on line 132-2962 : Rate B, Rate C , 0.0, 0.0 -> 4401
% INFO    : Updated Thermal Rating: on line 132-4393 : Rate B, Rate C , 0.0, 0.0 -> 4403
% INFO    : Updated Thermal Rating: on line 5044-693 : Rate B, Rate C , 0.0, 0.0 -> 5671
% INFO    : Updated Thermal Rating: on line 5044-7860 : Rate B, Rate C , 0.0, 0.0 -> 5562
% INFO    : Updated Thermal Rating: on line 6883-693 : Rate B, Rate C , 0.0, 0.0 -> 6006
% INFO    : Updated Thermal Rating: on line 6883-7860 : Rate B, Rate C , 0.0, 0.0 -> 6115
% INFO    : Updated Thermal Rating: on line 1456-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2736
% INFO    : Updated Thermal Rating: on line 1456-6658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 6494-4945 : Rate B, Rate C , 0.0, 0.0 -> 10550
% INFO    : Updated Thermal Rating: on line 6494-6080 : Rate B, Rate C , 0.0, 0.0 -> 10798
% INFO    : Updated Thermal Rating: on line 1384-9010 : Rate B, Rate C , 0.0, 0.0 -> 3137
% INFO    : Updated Thermal Rating: on line 1384-3146 : Rate B, Rate C , 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 8697-8142 : Rate B, Rate C , 0.0, 0.0 -> 32406
% INFO    : Updated Thermal Rating: on line 8697-6195 : Rate B, Rate C , 0.0, 0.0 -> 32924
% INFO    : Updated Thermal Rating: on line 5665-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17103
% INFO    : Updated Thermal Rating: on line 5665-7235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10974
% INFO    : Updated Thermal Rating: on line 3852-6497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16838
% INFO    : Updated Thermal Rating: on line 3852-4779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 674-8885 : Rate B, Rate C , 0.0, 0.0 -> 2528
% INFO    : Updated Thermal Rating: on line 674-3115 : Rate B, Rate C , 0.0, 0.0 -> 1667
% INFO    : Updated Thermal Rating: on line 8126-5177 : Rate B, Rate C , 0.0, 0.0 -> 3079
% INFO    : Updated Thermal Rating: on line 8126-6007 : Rate B, Rate C , 0.0, 0.0 -> 3138
% INFO    : Updated Thermal Rating: on line 8935-5177 : Rate B, Rate C , 0.0, 0.0 -> 3205
% INFO    : Updated Thermal Rating: on line 8935-6007 : Rate B, Rate C , 0.0, 0.0 -> 3270
% INFO    : Updated Thermal Rating: on line 7146-7388 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on line 4003-8855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12075
% INFO    : Updated Thermal Rating: on line 4003-5781 : Rate B, Rate C , 0.0, 0.0 -> 10398
% INFO    : Updated Thermal Rating: on line 6996-3761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5063
% INFO    : Updated Thermal Rating: on line 6996-9108 : Rate B, Rate C , 0.0, 0.0 -> 4739
% INFO    : Updated Thermal Rating: on line 1212-8258 : Rate B, Rate C , 0.0, 0.0 -> 3438
% INFO    : Updated Thermal Rating: on line 1212-7330 : Rate B, Rate C , 0.0, 0.0 -> 2431
% INFO    : Updated Thermal Rating: on line 8644-106 : Rate B, Rate C , 0.0, 0.0 -> 10795
% INFO    : Updated Thermal Rating: on line 8644-5883 : Rate B, Rate C , 0.0, 0.0 -> 1874
% INFO    : Updated Thermal Rating: on line 97-6413 : Rate B, Rate C , 0.0, 0.0 -> 7076
% INFO    : Updated Thermal Rating: on line 97-1644 : Rate B, Rate C , 0.0, 0.0 -> 12606
% INFO    : Updated Thermal Rating: on line 4379-6413 : Rate B, Rate C , 0.0, 0.0 -> 7221
% INFO    : Updated Thermal Rating: on line 4379-3483 : Rate B, Rate C , 0.0, 0.0 -> 12360
% INFO    : Updated Thermal Rating: on line 1885-3208 : Rate B, Rate C , 0.0, 0.0 -> 3160
% INFO    : Updated Thermal Rating: on line 1885-6790 : Rate B, Rate C , 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on line 5314-3208 : Rate B, Rate C , 0.0, 0.0 -> 3102
% INFO    : Updated Thermal Rating: on line 5314-6790 : Rate B, Rate C , 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 2885-3208 : Rate B, Rate C , 0.0, 0.0 -> 2532
% INFO    : Updated Thermal Rating: on line 2885-2585 : Rate B, Rate C , 0.0, 0.0 -> 4639
% INFO    : Updated Thermal Rating: on line 3717-4848 : Rate B, Rate C , 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 3717-3688 : Rate B, Rate C , 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 6064-8640 : Rate B, Rate C , 0.0, 0.0 -> 7198
% INFO    : Updated Thermal Rating: on line 6064-7330 : Rate B, Rate C , 0.0, 0.0 -> 10203
% INFO    : Updated Thermal Rating: on line 5377-1029 : Rate B, Rate C , 0.0, 0.0 -> 2308
% INFO    : Updated Thermal Rating: on line 5377-3525 : Rate B, Rate C , 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 6870-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2193
% INFO    : Updated Thermal Rating: on line 6870-5046 : Rate B, Rate C , 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 6693-6743 : Rate B, Rate C , 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 6693-287 : Rate B, Rate C , 0.0, 0.0 -> 3581
% INFO    : Updated Thermal Rating: on line 2053-752 : Rate B, Rate C , 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 2053-3048 : Rate B, Rate C , 0.0, 0.0 -> 1646
% INFO    : Updated Thermal Rating: on line 2893-2738 : Rate B, Rate C , 0.0, 0.0 -> 2082
% INFO    : Updated Thermal Rating: on line 2893-1575 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on line 1524-8687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17442
% INFO    : Updated Thermal Rating: on line 1524-8393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12048
% INFO    : Updated Thermal Rating: on line 7369-8687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17833
% INFO    : Updated Thermal Rating: on line 7369-139 : Rate B, Rate C , 0.0, 0.0 -> 12329
% INFO    : Updated Thermal Rating: on line 1019-6176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 1019-7177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 2607-7458 : Rate B, Rate C , 0.0, 0.0 -> 7342
% INFO    : Updated Thermal Rating: on line 2607-1337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6631
% INFO    : Updated Thermal Rating: on line 4735-5239 : Rate B, Rate C , 0.0, 0.0 -> 5881
% INFO    : Updated Thermal Rating: on line 4735-3145 : Rate B, Rate C , 0.0, 0.0 -> 5341
% INFO    : Updated Thermal Rating: on line 2941-1429 : Rate B, Rate C , 0.0, 0.0 -> 1528
% INFO    : Updated Thermal Rating: on line 2941-1542 : Rate B, Rate C , 0.0, 0.0 -> 3609
% INFO    : Updated Thermal Rating: on line 3773-9183 : Rate B, Rate C , 0.0, 0.0 -> 1604
% INFO    : Updated Thermal Rating: on line 3773-1542 : Rate B, Rate C , 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 1937-7261 : Rate B, Rate C , 0.0, 0.0 -> 20667
% INFO    : Updated Thermal Rating: on line 1937-5479 : Rate B, Rate C , 0.0, 0.0 -> 19249
% INFO    : Updated Thermal Rating: on line 5473-7261 : Rate B, Rate C , 0.0, 0.0 -> 19656
% INFO    : Updated Thermal Rating: on line 5473-5479 : Rate B, Rate C , 0.0, 0.0 -> 17204
% INFO    : Updated Thermal Rating: on line 3648-3290 : Rate B, Rate C , 0.0, 0.0 -> 2208
% INFO    : Updated Thermal Rating: on line 3648-5523 : Rate B, Rate C , 0.0, 0.0 -> 2163
% INFO    : Updated Thermal Rating: on line 451-144 : Rate B, Rate C , 0.0, 0.0 -> 4327
% INFO    : Updated Thermal Rating: on line 451-1601 : Rate B, Rate C , 0.0, 0.0 -> 4285
% INFO    : Updated Thermal Rating: on line 7898-144 : Rate B, Rate C , 0.0, 0.0 -> 4412
% INFO    : Updated Thermal Rating: on line 7898-1601 : Rate B, Rate C , 0.0, 0.0 -> 4367
% INFO    : Updated Thermal Rating: on line 2105-1582 : Rate B, Rate C , 0.0, 0.0 -> 14299
% INFO    : Updated Thermal Rating: on line 2105-7416 : Rate B, Rate C , 0.0, 0.0 -> 14299
% INFO    : Updated Thermal Rating: on line 270-2046 : Rate B, Rate C , 0.0, 0.0 -> 14626
% INFO    : Updated Thermal Rating: on line 270-7416 : Rate B, Rate C , 0.0, 0.0 -> 14626
% INFO    : Updated Thermal Rating: on line 5938-8433 : Rate B, Rate C , 0.0, 0.0 -> 5342
% INFO    : Updated Thermal Rating: on line 5938-816 : Rate B, Rate C , 0.0, 0.0 -> 4669
% INFO    : Updated Thermal Rating: on line 8539-8433 : Rate B, Rate C , 0.0, 0.0 -> 5451
% INFO    : Updated Thermal Rating: on line 8539-816 : Rate B, Rate C , 0.0, 0.0 -> 5041
% INFO    : Updated Thermal Rating: on line 1654-1544 : Rate B, Rate C , 0.0, 0.0 -> 1596
% INFO    : Updated Thermal Rating: on line 1654-7674 : Rate B, Rate C , 0.0, 0.0 -> 2891
% INFO    : Updated Thermal Rating: on line 2323-4150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 2323-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 8376-6999 : Rate B, Rate C , 0.0, 0.0 -> 16279
% INFO    : Updated Thermal Rating: on line 8376-4903 : Rate B, Rate C , 0.0, 0.0 -> 2299
% INFO    : Updated Thermal Rating: on line 942-6999 : Rate B, Rate C , 0.0, 0.0 -> 16637
% INFO    : Updated Thermal Rating: on line 942-4903 : Rate B, Rate C , 0.0, 0.0 -> 2347
% INFO    : Updated Thermal Rating: on line 6754-6190 : Rate B, Rate C , 0.0, 0.0 -> 2518
% INFO    : Updated Thermal Rating: on line 6754-4055 : Rate B, Rate C , 0.0, 0.0 -> 3048
% INFO    : Updated Thermal Rating: on line 3313-6190 : Rate B, Rate C , 0.0, 0.0 -> 2471
% INFO    : Updated Thermal Rating: on line 3313-4055 : Rate B, Rate C , 0.0, 0.0 -> 3113
% INFO    : Updated Thermal Rating: on line 1383-4401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2298
% INFO    : Updated Thermal Rating: on line 1383-5145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2755
% INFO    : Updated Thermal Rating: on line 7851-5878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 7851-5145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2816
% INFO    : Updated Thermal Rating: on line 8001-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 2322-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 843-154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 843-3598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 529-5527 : Rate B, Rate C , 0.0, 0.0 -> 4672
% INFO    : Updated Thermal Rating: on line 529-4164 : Rate B, Rate C , 0.0, 0.0 -> 4777
% INFO    : Updated Thermal Rating: on line 3529-2487 : Rate B, Rate C , 0.0, 0.0 -> 5180
% INFO    : Updated Thermal Rating: on line 3529-4167 : Rate B, Rate C , 0.0, 0.0 -> 5280
% INFO    : Updated Thermal Rating: on line 1162-8598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4745
% INFO    : Updated Thermal Rating: on line 1162-5325 : Rate B, Rate C , 0.0, 0.0 -> 4657
% INFO    : Updated Thermal Rating: on line 8690-3277 : Rate B, Rate C , 0.0, 0.0 -> 40746
% INFO    : Updated Thermal Rating: on line 8690-4226 : Rate B, Rate C , 0.0, 0.0 -> 40230
% INFO    : Updated Thermal Rating: on line 4922-3277 : Rate B, Rate C , 0.0, 0.0 -> 38340
% INFO    : Updated Thermal Rating: on line 4922-7617 : Rate B, Rate C , 0.0, 0.0 -> 41334
% INFO    : Updated Thermal Rating: on line 6759-5527 : Rate B, Rate C , 0.0, 0.0 -> 42374
% INFO    : Updated Thermal Rating: on line 6759-4226 : Rate B, Rate C , 0.0, 0.0 -> 42946
% INFO    : Updated Thermal Rating: on line 4088-2487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8245
% INFO    : Updated Thermal Rating: on line 4088-782 : Rate B, Rate C , 0.0, 0.0 -> 8896
% INFO    : Updated Thermal Rating: on line 6871-8598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11227
% INFO    : Updated Thermal Rating: on line 6871-1346 : Rate B, Rate C , 0.0, 0.0 -> 11454
% INFO    : Updated Thermal Rating: on line 6813-1369 : Rate B, Rate C , 0.0, 0.0 -> 4597
% INFO    : Updated Thermal Rating: on line 6813-376 : Rate B, Rate C , 0.0, 0.0 -> 4921
% INFO    : Updated Thermal Rating: on line 6019-5527 : Rate B, Rate C , 0.0, 0.0 -> 6021
% INFO    : Updated Thermal Rating: on line 6019-8334 : Rate B, Rate C , 0.0, 0.0 -> 5207
% INFO    : Updated Thermal Rating: on line 5693-3277 : Rate B, Rate C , 0.0, 0.0 -> 13736
% INFO    : Updated Thermal Rating: on line 5693-8899 : Rate B, Rate C , 0.0, 0.0 -> 11908
% INFO    : Updated Thermal Rating: on line 3355-9230 : Rate B, Rate C , 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 3355-6287 : Rate B, Rate C , 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 5485-9230 : Rate B, Rate C , 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 5485-1481 : Rate B, Rate C , 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 6968-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6968-7774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7956-9230 : Rate B, Rate C , 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 7956-3197 : Rate B, Rate C , 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 7550-667 : Rate B, Rate C , 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on line 7550-1220 : Rate B, Rate C , 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 3615-8731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6495
% INFO    : Updated Thermal Rating: on line 3615-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7573
% INFO    : Updated Thermal Rating: on line 7031-1679 : Rate B, Rate C , 0.0, 0.0 -> 45395
% INFO    : Updated Thermal Rating: on line 7031-7420 : Rate B, Rate C , 0.0, 0.0 -> 87206
% INFO    : Updated Thermal Rating: on line 1016-2502 : Rate B, Rate C , 0.0, 0.0 -> 5526
% INFO    : Updated Thermal Rating: on line 1016-8556 : Rate B, Rate C , 0.0, 0.0 -> 4102
% INFO    : Updated Thermal Rating: on line 6077-3885 : Rate B, Rate C , 0.0, 0.0 -> 2420
% INFO    : Updated Thermal Rating: on line 2935-8322 : Rate B, Rate C , 0.0, 0.0 -> 4657
% INFO    : Updated Thermal Rating: on line 1095-3885 : Rate B, Rate C , 0.0, 0.0 -> 2100
% INFO    : Updated Thermal Rating: on line 1095-1132 : Rate B, Rate C , 0.0, 0.0 -> 2403
% INFO    : Updated Thermal Rating: on line 4048-6639 : Rate B, Rate C , 0.0, 0.0 -> 11263
% INFO    : Updated Thermal Rating: on line 4048-7317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7741
% INFO    : Updated Thermal Rating: on line 2549-7829 : Rate B, Rate C , 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 2549-4951 : Rate B, Rate C , 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 3978-3622 : Rate B, Rate C , 0.0, 0.0 -> 2871
% INFO    : Updated Thermal Rating: on line 3978-8974 : Rate B, Rate C , 0.0, 0.0 -> 2145
% INFO    : Updated Thermal Rating: on line 7004-3370 : Rate B, Rate C , 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 4325-3684 : Rate B, Rate C , 0.0, 0.0 -> 2571
% INFO    : Updated Thermal Rating: on line 4325-6710 : Rate B, Rate C , 0.0, 0.0 -> 8613
% INFO    : Updated Thermal Rating: on line 2380-1952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on line 2380-7679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 5026-7953 : Rate B, Rate C , 0.0, 0.0 -> 4343
% INFO    : Updated Thermal Rating: on line 5026-6446 : Rate B, Rate C , 0.0, 0.0 -> 3770
% INFO    : Updated Thermal Rating: on line 6575-7953 : Rate B, Rate C , 0.0, 0.0 -> 4450
% INFO    : Updated Thermal Rating: on line 6575-8401 : Rate B, Rate C , 0.0, 0.0 -> 3922
% INFO    : Updated Thermal Rating: on line 6387-5594 : Rate B, Rate C , 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on line 6387-8145 : Rate B, Rate C , 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on line 6694-8426 : Rate B, Rate C , 0.0, 0.0 -> 6733
% INFO    : Updated Thermal Rating: on line 6694-2887 : Rate B, Rate C , 0.0, 0.0 -> 6456
% INFO    : Updated Thermal Rating: on line 5206-9184 : Rate B, Rate C , 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 5206-7410 : Rate B, Rate C , 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 3087-5161 : Rate B, Rate C , 0.0, 0.0 -> 1765
% INFO    : Updated Thermal Rating: on line 3087-2887 : Rate B, Rate C , 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 253-9184 : Rate B, Rate C , 0.0, 0.0 -> 2635
% INFO    : Updated Thermal Rating: on line 253-6718 : Rate B, Rate C , 0.0, 0.0 -> 2350
% INFO    : Updated Thermal Rating: on line 4180-9184 : Rate B, Rate C , 0.0, 0.0 -> 1944
% INFO    : Updated Thermal Rating: on line 4180-4702 : Rate B, Rate C , 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on line 5912-9184 : Rate B, Rate C , 0.0, 0.0 -> 6782
% INFO    : Updated Thermal Rating: on line 5912-1971 : Rate B, Rate C , 0.0, 0.0 -> 6672
% INFO    : Updated Thermal Rating: on line 2014-4697 : Rate B, Rate C , 0.0, 0.0 -> 123677
% INFO    : Updated Thermal Rating: on line 2014-4824 : Rate B, Rate C , 0.0, 0.0 -> 123677
% INFO    : Updated Thermal Rating: on line 1434-246 : Rate B, Rate C , 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on line 1434-5733 : Rate B, Rate C , 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 2936-246 : Rate B, Rate C , 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 2936-3103 : Rate B, Rate C , 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 4893-6468 : Rate B, Rate C , 0.0, 0.0 -> 3048
% INFO    : Updated Thermal Rating: on line 4893-6848 : Rate B, Rate C , 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 2601-2613 : Rate B, Rate C , 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 2601-9073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 2118-2613 : Rate B, Rate C , 0.0, 0.0 -> 1692
% INFO    : Updated Thermal Rating: on line 2118-3198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1739
% INFO    : Updated Thermal Rating: on line 8381-4795 : Rate B, Rate C , 0.0, 0.0 -> 5360
% INFO    : Updated Thermal Rating: on line 8381-5562 : Rate B, Rate C , 0.0, 0.0 -> 4727
% INFO    : Updated Thermal Rating: on line 5763-6652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 5763-4064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2079
% INFO    : Updated Thermal Rating: on line 3409-1716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5127
% INFO    : Updated Thermal Rating: on line 3409-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7737
% INFO    : Updated Thermal Rating: on line 8028-5930 : Rate B, Rate C , 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 8028-9044 : Rate B, Rate C , 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 5035-1610 : Rate B, Rate C , 0.0, 0.0 -> 6369
% INFO    : Updated Thermal Rating: on line 5035-9133 : Rate B, Rate C , 0.0, 0.0 -> 6488
% INFO    : Updated Thermal Rating: on line 8751-147 : Rate B, Rate C , 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 8751-5885 : Rate B, Rate C , 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 6075-7896 : Rate B, Rate C , 0.0, 0.0 -> 797
% INFO    : Updated Thermal Rating: on line 6075-7473 : Rate B, Rate C , 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 8268-9122 : Rate B, Rate C , 0.0, 0.0 -> 4916
% INFO    : Updated Thermal Rating: on line 8268-7314 : Rate B, Rate C , 0.0, 0.0 -> 2029
% INFO    : Updated Thermal Rating: on line 679-147 : Rate B, Rate C , 0.0, 0.0 -> 1367
% INFO    : Updated Thermal Rating: on line 679-5677 : Rate B, Rate C , 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 7291-4830 : Rate B, Rate C , 0.0, 0.0 -> 4679
% INFO    : Updated Thermal Rating: on line 7291-1249 : Rate B, Rate C , 0.0, 0.0 -> 4591
% INFO    : Updated Thermal Rating: on line 9126-4079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2625
% INFO    : Updated Thermal Rating: on line 9126-6529 : Rate B, Rate C , 0.0, 0.0 -> 2515
% INFO    : Updated Thermal Rating: on line 2329-5169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4354
% INFO    : Updated Thermal Rating: on line 2329-4337 : Rate B, Rate C , 0.0, 0.0 -> 4242
% INFO    : Updated Thermal Rating: on line 4142-8137 : Rate B, Rate C , 0.0, 0.0 -> 3868
% INFO    : Updated Thermal Rating: on line 4142-7870 : Rate B, Rate C , 0.0, 0.0 -> 2002
% INFO    : Updated Thermal Rating: on line 8500-1586 : Rate B, Rate C , 0.0, 0.0 -> 5427
% INFO    : Updated Thermal Rating: on line 8500-2634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5895
% INFO    : Updated Thermal Rating: on line 7357-7529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23689
% INFO    : Updated Thermal Rating: on line 7357-6297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19614
% INFO    : Updated Thermal Rating: on line 6959-2290 : Rate B, Rate C , 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on line 6959-7473 : Rate B, Rate C , 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 307-8580 : Rate B, Rate C , 0.0, 0.0 -> 2487
% INFO    : Updated Thermal Rating: on line 307-1360 : Rate B, Rate C , 0.0, 0.0 -> 2440
% INFO    : Updated Thermal Rating: on line 7764-5850 : Rate B, Rate C , 0.0, 0.0 -> 1982
% INFO    : Updated Thermal Rating: on line 7764-7870 : Rate B, Rate C , 0.0, 0.0 -> 6487
% INFO    : Updated Thermal Rating: on line 3778-8172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 3778-3888 : Rate B, Rate C , 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 1000-6145 : Rate B, Rate C , 0.0, 0.0 -> 2166
% INFO    : Updated Thermal Rating: on line 1000-3186 : Rate B, Rate C , 0.0, 0.0 -> 2336
% INFO    : Updated Thermal Rating: on line 3651-8580 : Rate B, Rate C , 0.0, 0.0 -> 6182
% INFO    : Updated Thermal Rating: on line 3651-895 : Rate B, Rate C , 0.0, 0.0 -> 5294
% INFO    : Updated Thermal Rating: on line 6633-7467 : Rate B, Rate C , 0.0, 0.0 -> 3133
% INFO    : Updated Thermal Rating: on line 6633-2200 : Rate B, Rate C , 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 1976-680 : Rate B, Rate C , 0.0, 0.0 -> 10214
% INFO    : Updated Thermal Rating: on line 1976-5674 : Rate B, Rate C , 0.0, 0.0 -> 10212
% INFO    : Updated Thermal Rating: on line 2435-4208 : Rate B, Rate C , 0.0, 0.0 -> 7624
% INFO    : Updated Thermal Rating: on line 2435-2398 : Rate B, Rate C , 0.0, 0.0 -> 3397
% INFO    : Updated Thermal Rating: on line 5605-1653 : Rate B, Rate C , 0.0, 0.0 -> 3132
% INFO    : Updated Thermal Rating: on line 5605-5498 : Rate B, Rate C , 0.0, 0.0 -> 3248
% INFO    : Updated Thermal Rating: on line 7646-1884 : Rate B, Rate C , 0.0, 0.0 -> 2492
% INFO    : Updated Thermal Rating: on line 7646-5503 : Rate B, Rate C , 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 6574-1506 : Rate B, Rate C , 0.0, 0.0 -> 3467
% INFO    : Updated Thermal Rating: on line 6574-8562 : Rate B, Rate C , 0.0, 0.0 -> 3584
% INFO    : Updated Thermal Rating: on line 3286-2588 : Rate B, Rate C , 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 3286-689 : Rate B, Rate C , 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on line 2272-1884 : Rate B, Rate C , 0.0, 0.0 -> 2960
% INFO    : Updated Thermal Rating: on line 2272-2294 : Rate B, Rate C , 0.0, 0.0 -> 2969
% INFO    : Updated Thermal Rating: on line 4091-3146 : Rate B, Rate C , 0.0, 0.0 -> 2593
% INFO    : Updated Thermal Rating: on line 4091-6098 : Rate B, Rate C , 0.0, 0.0 -> 4751
% INFO    : Updated Thermal Rating: on line 6060-5289 : Rate B, Rate C , 0.0, 0.0 -> 29729
% INFO    : Updated Thermal Rating: on line 7965-5289 : Rate B, Rate C , 0.0, 0.0 -> 29329
% INFO    : Updated Thermal Rating: on line 1049-603 : Rate B, Rate C , 0.0, 0.0 -> 3508
% INFO    : Updated Thermal Rating: on line 1049-8344 : Rate B, Rate C , 0.0, 0.0 -> 3553
% INFO    : Updated Thermal Rating: on line 2363-8726 : Rate B, Rate C , 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 2363-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 5390-3859 : Rate B, Rate C , 0.0, 0.0 -> 2583
% INFO    : Updated Thermal Rating: on line 5390-4064 : Rate B, Rate C , 0.0, 0.0 -> 2686
% INFO    : Updated Thermal Rating: on line 5534-8577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 5534-7721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 2579-8577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 2579-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 6365-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1800
% INFO    : Updated Thermal Rating: on line 6365-4810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1034
% INFO    : Updated Thermal Rating: on line 8641-7285 : Rate B, Rate C , 0.0, 0.0 -> 6368
% INFO    : Updated Thermal Rating: on line 8641-7674 : Rate B, Rate C , 0.0, 0.0 -> 4536
% INFO    : Updated Thermal Rating: on line 4677-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6140
% INFO    : Updated Thermal Rating: on line 4677-6182 : Rate B, Rate C , 0.0, 0.0 -> 17774
% INFO    : Updated Thermal Rating: on line 6154-353 : Rate B, Rate C , 0.0, 0.0 -> 6245
% INFO    : Updated Thermal Rating: on line 6154-6182 : Rate B, Rate C , 0.0, 0.0 -> 17398
% INFO    : Updated Thermal Rating: on line 3046-3236 : Rate B, Rate C , 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 3046-1575 : Rate B, Rate C , 0.0, 0.0 -> 4874
% INFO    : Updated Thermal Rating: on line 681-7081 : Rate B, Rate C , 0.0, 0.0 -> 4169
% INFO    : Updated Thermal Rating: on line 681-6907 : Rate B, Rate C , 0.0, 0.0 -> 6247
% INFO    : Updated Thermal Rating: on line 567-7081 : Rate B, Rate C , 0.0, 0.0 -> 4089
% INFO    : Updated Thermal Rating: on line 567-6907 : Rate B, Rate C , 0.0, 0.0 -> 6371
% INFO    : Updated Thermal Rating: on line 2371-3343 : Rate B, Rate C , 0.0, 0.0 -> 4610
% INFO    : Updated Thermal Rating: on line 2371-8263 : Rate B, Rate C , 0.0, 0.0 -> 2771
% INFO    : Updated Thermal Rating: on line 6482-3343 : Rate B, Rate C , 0.0, 0.0 -> 4713
% INFO    : Updated Thermal Rating: on line 6482-8263 : Rate B, Rate C , 0.0, 0.0 -> 2830
% INFO    : Updated Thermal Rating: on line 6637-8894 : Rate B, Rate C , 0.0, 0.0 -> 2203
% INFO    : Updated Thermal Rating: on line 6637-3208 : Rate B, Rate C , 0.0, 0.0 -> 2585
% INFO    : Updated Thermal Rating: on line 6491-8894 : Rate B, Rate C , 0.0, 0.0 -> 4012
% INFO    : Updated Thermal Rating: on line 6491-2585 : Rate B, Rate C , 0.0, 0.0 -> 7132
% INFO    : Updated Thermal Rating: on line 8282-7455 : Rate B, Rate C , 0.0, 0.0 -> 2714
% INFO    : Updated Thermal Rating: on line 8282-3729 : Rate B, Rate C , 0.0, 0.0 -> 3012
% INFO    : Updated Thermal Rating: on line 359-9048 : Rate B, Rate C , 0.0, 0.0 -> 2336
% INFO    : Updated Thermal Rating: on line 359-96 : Rate B, Rate C , 0.0, 0.0 -> 2201
% INFO    : Updated Thermal Rating: on line 6818-743 : Rate B, Rate C , 0.0, 0.0 -> 2649
% INFO    : Updated Thermal Rating: on line 6818-8496 : Rate B, Rate C , 0.0, 0.0 -> 2090
% INFO    : Updated Thermal Rating: on line 5038-611 : Rate B, Rate C , 0.0, 0.0 -> 37509
% INFO    : Updated Thermal Rating: on line 5038-1249 : Rate B, Rate C , 0.0, 0.0 -> 34262
% INFO    : Updated Thermal Rating: on line 8428-5905 : Rate B, Rate C , 0.0, 0.0 -> 3026
% INFO    : Updated Thermal Rating: on line 8428-7464 : Rate B, Rate C , 0.0, 0.0 -> 3403
% INFO    : Updated Thermal Rating: on line 6312-5905 : Rate B, Rate C , 0.0, 0.0 -> 2973
% INFO    : Updated Thermal Rating: on line 6312-7464 : Rate B, Rate C , 0.0, 0.0 -> 3475
% INFO    : Updated Thermal Rating: on line 5852-4129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 4363-4507 : Rate B, Rate C , 0.0, 0.0 -> 4435
% INFO    : Updated Thermal Rating: on line 4363-6246 : Rate B, Rate C , 0.0, 0.0 -> 4517
% INFO    : Updated Thermal Rating: on line 8431-4122 : Rate B, Rate C , 0.0, 0.0 -> 4216
% INFO    : Updated Thermal Rating: on line 8431-4844 : Rate B, Rate C , 0.0, 0.0 -> 4305
% INFO    : Updated Thermal Rating: on line 170-4122 : Rate B, Rate C , 0.0, 0.0 -> 3812
% INFO    : Updated Thermal Rating: on line 170-4844 : Rate B, Rate C , 0.0, 0.0 -> 3741
% INFO    : Updated Thermal Rating: on line 625-3790 : Rate B, Rate C , 0.0, 0.0 -> 1870
% INFO    : Updated Thermal Rating: on line 625-7978 : Rate B, Rate C , 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 3308-1723 : Rate B, Rate C , 0.0, 0.0 -> 5018
% INFO    : Updated Thermal Rating: on line 3308-7870 : Rate B, Rate C , 0.0, 0.0 -> 3580
% INFO    : Updated Thermal Rating: on line 9042-221 : Rate B, Rate C , 0.0, 0.0 -> 7480
% INFO    : Updated Thermal Rating: on line 9042-8623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8706
% INFO    : Updated Thermal Rating: on line 425-7526 : Rate B, Rate C , 0.0, 0.0 -> 26451
% INFO    : Updated Thermal Rating: on line 425-5674 : Rate B, Rate C , 0.0, 0.0 -> 24227
% INFO    : Updated Thermal Rating: on line 4799-8581 : Rate B, Rate C , 0.0, 0.0 -> 26034
% INFO    : Updated Thermal Rating: on line 4799-4337 : Rate B, Rate C , 0.0, 0.0 -> 23508
% INFO    : Updated Thermal Rating: on line 6590-3025 : Rate B, Rate C , 0.0, 0.0 -> 2956
% INFO    : Updated Thermal Rating: on line 6590-2420 : Rate B, Rate C , 0.0, 0.0 -> 3285
% INFO    : Updated Thermal Rating: on line 7276-3887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1042
% INFO    : Updated Thermal Rating: on line 7276-5088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1131
% INFO    : Updated Thermal Rating: on line 4923-3025 : Rate B, Rate C , 0.0, 0.0 -> 4021
% INFO    : Updated Thermal Rating: on line 4923-4276 : Rate B, Rate C , 0.0, 0.0 -> 4699
% INFO    : Updated Thermal Rating: on line 5601-3887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 5601-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1057
% INFO    : Updated Thermal Rating: on line 5211-3025 : Rate B, Rate C , 0.0, 0.0 -> 3766
% INFO    : Updated Thermal Rating: on line 5211-9235 : Rate B, Rate C , 0.0, 0.0 -> 3753
% INFO    : Updated Thermal Rating: on line 5385-3025 : Rate B, Rate C , 0.0, 0.0 -> 3696
% INFO    : Updated Thermal Rating: on line 5385-9235 : Rate B, Rate C , 0.0, 0.0 -> 4052
% INFO    : Updated Thermal Rating: on line 7719-3887 : Rate B, Rate C , 0.0, 0.0 -> 3791
% INFO    : Updated Thermal Rating: on line 7719-7843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3864
% INFO    : Updated Thermal Rating: on line 2269-3887 : Rate B, Rate C , 0.0, 0.0 -> 3946
% INFO    : Updated Thermal Rating: on line 2269-7843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3515
% INFO    : Updated Thermal Rating: on line 786-3887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14104
% INFO    : Updated Thermal Rating: on line 786-5145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14411
% INFO    : Updated Thermal Rating: on line 1951-3887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14745
% INFO    : Updated Thermal Rating: on line 1951-5145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13009
% INFO    : Updated Thermal Rating: on line 4430-3887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12353
% INFO    : Updated Thermal Rating: on line 4430-5145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12591
% INFO    : Updated Thermal Rating: on line 8221-3887 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8221-2175 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1933-7992 : Rate B, Rate C , 0.0, 0.0 -> 2980
% INFO    : Updated Thermal Rating: on line 1933-7458 : Rate B, Rate C , 0.0, 0.0 -> 2925
% INFO    : Updated Thermal Rating: on line 3710-265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 3710-7679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 5183-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6219
% INFO    : Updated Thermal Rating: on line 5183-6297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19226
% INFO    : Updated Thermal Rating: on line 7686-7992 : Rate B, Rate C , 0.0, 0.0 -> 3159
% INFO    : Updated Thermal Rating: on line 7686-2368 : Rate B, Rate C , 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 4968-2154 : Rate B, Rate C , 0.0, 0.0 -> 6642
% INFO    : Updated Thermal Rating: on line 4968-1747 : Rate B, Rate C , 0.0, 0.0 -> 6733
% INFO    : Updated Thermal Rating: on line 7699-2154 : Rate B, Rate C , 0.0, 0.0 -> 5548
% INFO    : Updated Thermal Rating: on line 7699-1689 : Rate B, Rate C , 0.0, 0.0 -> 4721
% INFO    : Updated Thermal Rating: on line 4470-4417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 4470-8325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 8883-1429 : Rate B, Rate C , 0.0, 0.0 -> 1560
% INFO    : Updated Thermal Rating: on line 8883-9183 : Rate B, Rate C , 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 2495-7393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3976
% INFO    : Updated Thermal Rating: on line 2495-5911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4036
% INFO    : Updated Thermal Rating: on line 8674-7393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4110
% INFO    : Updated Thermal Rating: on line 8674-5911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4190
% INFO    : Updated Thermal Rating: on line 7931-6967 : Rate B, Rate C , 0.0, 0.0 -> 1457
% INFO    : Updated Thermal Rating: on line 7931-6967 : Rate B, Rate C , 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on line 4635-6314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 4635-1567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 5475-3472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 4322-3472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3472-5172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 7150-7131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 7517-6627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 6627-7517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 5326-2474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 4848-5326 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 7141-1649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 7141-1649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 1649-7517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 1649-7517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 1649-6023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 6314-5475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 2474-5657 : Rate B, Rate C , 0.0, 0.0 -> 10075
% INFO    : Updated Thermal Rating: on line 2474-5657 : Rate B, Rate C , 0.0, 0.0 -> 11148
% INFO    : Updated Thermal Rating: on line 2474-6505 : Rate B, Rate C , 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 5989-2474 : Rate B, Rate C , 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on line 5989-2474 : Rate B, Rate C , 0.0, 0.0 -> 899
% INFO    : Updated Thermal Rating: on line 1700-7141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 7141-3806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 8258-7313 : Rate B, Rate C , 0.0, 0.0 -> 2938
% INFO    : Updated Thermal Rating: on line 1544-8258 : Rate B, Rate C , 0.0, 0.0 -> 3939
% INFO    : Updated Thermal Rating: on line 8258-106 : Rate B, Rate C , 0.0, 0.0 -> 1937
% INFO    : Updated Thermal Rating: on line 7931-6505 : Rate B, Rate C , 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on line 7931-5976 : Rate B, Rate C , 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 4322-9171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 4322-2639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 4322-2639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 4322-833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 4322-6314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 4848-7204 : Rate B, Rate C , 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 4848-5989 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 8295-7150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 7981-4155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1926
% INFO    : Updated Thermal Rating: on line 4649-7981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 3722-1700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 9171-1567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 6023-8826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 2897-5172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 8891-2897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 6348-8339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2686
% INFO    : Updated Thermal Rating: on line 4625-6348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1218
% INFO    : Updated Thermal Rating: on line 4548-1652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4625-4548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1207
% INFO    : Updated Thermal Rating: on line 8339-8102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 8339-8102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 1544-2500 : Rate B, Rate C , 0.0, 0.0 -> 9536
% INFO    : Updated Thermal Rating: on line 7204-273 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 7204-273 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 273-5976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 5989-273 : Rate B, Rate C , 0.0, 0.0 -> 3238
% INFO    : Updated Thermal Rating: on line 7205-2639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 4329-7205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 7204-80 : Rate B, Rate C , 0.0, 0.0 -> 1643
% INFO    : Updated Thermal Rating: on line 743-80 : Rate B, Rate C , 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 4155-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 2546-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 833-8826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 7155-1652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 3806-4649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 8891-8295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on line 8102-3722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 783
% INFO    : Updated Thermal Rating: on line 40-5123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 7155-5123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 80-5989 : Rate B, Rate C , 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 80-5989 : Rate B, Rate C , 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 4625-3722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 995-7548 : Rate B, Rate C , 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 995-5594 : Rate B, Rate C , 0.0, 0.0 -> 2105
% INFO    : Updated Thermal Rating: on line 8101-4775 : Rate B, Rate C , 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 8101-9184 : Rate B, Rate C , 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 1816-5177 : Rate B, Rate C , 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 1816-7992 : Rate B, Rate C , 0.0, 0.0 -> 1857
% INFO    : Updated Thermal Rating: on line 2867-515 : Rate B, Rate C , 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on line 2867-515 : Rate B, Rate C , 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on line 2867-7597 : Rate B, Rate C , 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 2867-265 : Rate B, Rate C , 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 2867-1726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 2867-1726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 5177-2203 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 1236
% INFO    : Updated Thermal Rating: on line 5177-4681 : Rate B, Rate C , 0.0, 0.0 -> 10645
% INFO    : Updated Thermal Rating: on line 5177-5652 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on line 1363-4681 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 1457
% INFO    : Updated Thermal Rating: on line 7638-4775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 7638-9184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 7638-9184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 7638-111 : Rate B, Rate C , 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 7638-3152 : Rate B, Rate C , 0.0, 0.0 -> 1688
% INFO    : Updated Thermal Rating: on line 7638-1726 : Rate B, Rate C , 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 3826-2026 : Rate B, Rate C , 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 3826-5999 : Rate B, Rate C , 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 5069-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 5069-5594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 4775-9184 : Rate B, Rate C , 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 4775-111 : Rate B, Rate C , 0.0, 0.0 -> 3036
% INFO    : Updated Thermal Rating: on line 7548-6762 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 7548-6762 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 7548-5999 : Rate B, Rate C , 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 7548-5999 : Rate B, Rate C , 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 7548-555 : Rate B, Rate C , 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 5480-9184 : Rate B, Rate C , 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 5480-123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1639
% INFO    : Updated Thermal Rating: on line 8433-8228 : Rate B, Rate C , 0.0, 0.0 -> 2233
% INFO    : Updated Thermal Rating: on line 8433-8228 : Rate B, Rate C , 0.0, 0.0 -> 1973
% INFO    : Updated Thermal Rating: on line 8433-2933 : Rate B, Rate C , 0.0, 0.0 -> 4732
% INFO    : Updated Thermal Rating: on line 8433-2772 : Rate B, Rate C , 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 1145-3702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22677
% INFO    : Updated Thermal Rating: on line 1145-3702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35119
% INFO    : Updated Thermal Rating: on line 7597-265 : Rate B, Rate C , 0.0, 0.0 -> 23943
% INFO    : Updated Thermal Rating: on line 6962-3508 : Rate B, Rate C , 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 6962-3508 : Rate B, Rate C , 0.0, 0.0 -> 1576
% INFO    : Updated Thermal Rating: on line 1829-4207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 1829-4207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 1829-4842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 1952-265 : Rate B, Rate C , 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 5594-4842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 5594-555 : Rate B, Rate C , 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 2933-958 : Rate B, Rate C , 0.0, 0.0 -> 3233
% INFO    : Updated Thermal Rating: on line 9184-8609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1224
% INFO    : Updated Thermal Rating: on line 9184-8609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on line 9184-123 : Rate B, Rate C , 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 2026-5999 : Rate B, Rate C , 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 8609-3702 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 8609-3702 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 5652-7992 : Rate B, Rate C , 0.0, 0.0 -> 5690
% INFO    : Updated Thermal Rating: on line 2772-7992 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on line 958-7992 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1539
% INFO    : Updated Thermal Rating: on line 3508-458 : Rate B, Rate C , 0.0, 0.0 -> 2121
% INFO    : Updated Thermal Rating: on line 3508-458 : Rate B, Rate C , 0.0, 0.0 -> 2080
% INFO    : Updated Thermal Rating: on line 5847-5999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 5847-5999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 298-265 : Rate B, Rate C , 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 298-265 : Rate B, Rate C , 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 3152-1726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1163
% INFO    : Updated Thermal Rating: on line 3887-7393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3887-7393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 1904-6876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 1926-8412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 1926-3936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 5718-2613 : Rate B, Rate C , 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 730-4010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 154-4010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 4010-7187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 8850-5942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 8850-6402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 3093-8850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 3383-5168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 3383-6128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2193
% INFO    : Updated Thermal Rating: on line 5168-7768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 6128-3316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 2704-4326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1372
% INFO    : Updated Thermal Rating: on line 4326-8176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1396
% INFO    : Updated Thermal Rating: on line 2704-7589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 7589-1674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 73-7086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 7086-5551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1644
% INFO    : Updated Thermal Rating: on line 2704-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 2704-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 73-2704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2009
% INFO    : Updated Thermal Rating: on line 5551-2704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 6140-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 6184-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 3801-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 2321-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 6346-514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 4767-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 7262-2512 : Rate B, Rate C , 0.0, 0.0 -> 2239
% INFO    : Updated Thermal Rating: on line 5910-6140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on line 8622-5910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 8622-5551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 406-8622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 4038-8622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 4385-3316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1766
% INFO    : Updated Thermal Rating: on line 4385-1219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 4385-3490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 4385-136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 7390-3316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 7768-3316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 2911-3820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 974-3820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 3757-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1008
% INFO    : Updated Thermal Rating: on line 535-3105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 535-6003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 2811-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1273-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1273-5173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 2219-4307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 4307-7531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 4982-7187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 3209-4982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 5064-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 175-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 8176-1916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on line 974-7038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2192
% INFO    : Updated Thermal Rating: on line 7038-7531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 6722-5579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 6722-3467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on line 5579-5064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1283
% INFO    : Updated Thermal Rating: on line 3757-5070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 19-1219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 19-7390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 6029-19 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 19-8667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 1304-8718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 8718-3936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 7262-5625 : Rate B, Rate C , 0.0, 0.0 -> 1915
% INFO    : Updated Thermal Rating: on line 701-6216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 6216-9177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1122
% INFO    : Updated Thermal Rating: on line 6216-1290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on line 6216-2205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 1219-701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 9177-4387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1738
% INFO    : Updated Thermal Rating: on line 7713-9177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 1496-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 4356-1496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 3491-2958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 2958-4767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 7723-6602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29428
% INFO    : Updated Thermal Rating: on line 963-7723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8049
% INFO    : Updated Thermal Rating: on line 7968-4636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1459
% INFO    : Updated Thermal Rating: on line 4636-7292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7038
% INFO    : Updated Thermal Rating: on line 6431-1112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 6431-4878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 4791-2761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 2625-4791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 2994-3167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 2994-4356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 8371-3622 : Rate B, Rate C , 0.0, 0.0 -> 3353
% INFO    : Updated Thermal Rating: on line 7285-8371 : Rate B, Rate C , 0.0, 0.0 -> 2996
% INFO    : Updated Thermal Rating: on line 5942-8941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 945-2761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 2761-1388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 945-5196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 7568-4935 : Rate B, Rate C , 0.0, 0.0 -> 4172
% INFO    : Updated Thermal Rating: on line 1290-8412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 8837-7390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 3236-2738 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 6184-5207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 4172-6176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 6176-6547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 7968-4878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on line 5834-8398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12190
% INFO    : Updated Thermal Rating: on line 3936-5834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1727
% INFO    : Updated Thermal Rating: on line 5834-2823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3804
% INFO    : Updated Thermal Rating: on line 1112-4996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 4996-5173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4996-1252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4996-7292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4996-6054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23509
% INFO    : Updated Thermal Rating: on line 4996-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 1733-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 5975-5173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6209
% INFO    : Updated Thermal Rating: on line 5975-5173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4497
% INFO    : Updated Thermal Rating: on line 3405-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1412
% INFO    : Updated Thermal Rating: on line 3405-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 406-4038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 5070-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on line 406-6913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 5285-353 : Rate B, Rate C , 0.0, 0.0 -> 2088
% INFO    : Updated Thermal Rating: on line 6688-2992 : Rate B, Rate C , 0.0, 0.0 -> 53407
% INFO    : Updated Thermal Rating: on line 5930-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 5930-4935 : Rate B, Rate C , 0.0, 0.0 -> 2709
% INFO    : Updated Thermal Rating: on line 7292-6595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 6595-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 8612-2613 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 4935-8612 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 7531-5660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 5745-5660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11017
% INFO    : Updated Thermal Rating: on line 3222-154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 1916-4618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 3574-2620 : Rate B, Rate C , 0.0, 0.0 -> 6218
% INFO    : Updated Thermal Rating: on line 2620-3098 : Rate B, Rate C , 0.0, 0.0 -> 2008
% INFO    : Updated Thermal Rating: on line 7176-3179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 7176-8805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 468
% INFO    : Updated Thermal Rating: on line 3167-3856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 1382-1304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 3209-175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 7255-3222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 7255-573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 8557-7241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 4934-8557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 7187-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 5235-3105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 1674-8031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2732
% INFO    : Updated Thermal Rating: on line 8031-5207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 5235-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 7421-6938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 7768-6938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 8398-8412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 8398-8412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 8412-6866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 3467-8914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4263
% INFO    : Updated Thermal Rating: on line 2969-8914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5691
% INFO    : Updated Thermal Rating: on line 2205-4387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 6378-2205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 1451-5516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2640
% INFO    : Updated Thermal Rating: on line 5173-5516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2021
% INFO    : Updated Thermal Rating: on line 3467-8447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1738
% INFO    : Updated Thermal Rating: on line 8447-5173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 6547-3467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 1451-2969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2921
% INFO    : Updated Thermal Rating: on line 6650-5173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on line 6650-6402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 6650-8972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 6650-3398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2441
% INFO    : Updated Thermal Rating: on line 6650-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 35-8837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 963-6602 : Rate B, Rate C , 0.0, 0.0 -> 10435
% INFO    : Updated Thermal Rating: on line 963-6602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12556
% INFO    : Updated Thermal Rating: on line 4935-6602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 792
% INFO    : Updated Thermal Rating: on line 6602-1125 : Rate B, Rate C , 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 353-6602 : Rate B, Rate C , 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 353-6602 : Rate B, Rate C , 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 3622-4022 : Rate B, Rate C , 0.0, 0.0 -> 1441
% INFO    : Updated Thermal Rating: on line 7241-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 6003-2219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1688
% INFO    : Updated Thermal Rating: on line 8941-8972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 609
% INFO    : Updated Thermal Rating: on line 35-3490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 1388-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 209-1733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 6089-1252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 2613-3574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3801-4934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2287
% INFO    : Updated Thermal Rating: on line 4934-514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 3491-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 3801-2321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 573-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 4618-6029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 4596-5235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 6054-4596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 4596-2811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 5404-6899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5196-5404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 8577-3093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on line 4935-3574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on line 1125-3574 : Rate B, Rate C , 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 2682-3574 : Rate B, Rate C , 0.0, 0.0 -> 5399
% INFO    : Updated Thermal Rating: on line 7695-3574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 7292-3856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 855-7292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 2625-7292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 7292-4356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 7591-2911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2007
% INFO    : Updated Thermal Rating: on line 1068-7591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12413
% INFO    : Updated Thermal Rating: on line 3856-7591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1099
% INFO    : Updated Thermal Rating: on line 3856-2911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1734
% INFO    : Updated Thermal Rating: on line 6899-2911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 1068-4905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13528
% INFO    : Updated Thermal Rating: on line 1068-4439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 4367-3856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on line 4367-3856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 4367-226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21136
% INFO    : Updated Thermal Rating: on line 4367-6089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11787
% INFO    : Updated Thermal Rating: on line 3856-4439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 9175-4905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14970
% INFO    : Updated Thermal Rating: on line 226-9175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12458
% INFO    : Updated Thermal Rating: on line 9175-2625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1675
% INFO    : Updated Thermal Rating: on line 6089-2671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3705
% INFO    : Updated Thermal Rating: on line 2625-6089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2422
% INFO    : Updated Thermal Rating: on line 2625-2671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2448
% INFO    : Updated Thermal Rating: on line 855-2625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 7105-4022 : Rate B, Rate C , 0.0, 0.0 -> 4482
% INFO    : Updated Thermal Rating: on line 4022-5625 : Rate B, Rate C , 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on line 1453-6074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2790
% INFO    : Updated Thermal Rating: on line 7531-1453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1186
% INFO    : Updated Thermal Rating: on line 5745-1453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 136-6866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on line 8667-5207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 7258-1382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 7258-8805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 8205-7713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 4618-8205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 209-5235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 974-6074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 9229-8398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 7695-3236 : Rate B, Rate C , 0.0, 0.0 -> 7321
% INFO    : Updated Thermal Rating: on line 7695-3236 : Rate B, Rate C , 0.0, 0.0 -> 6937
% INFO    : Updated Thermal Rating: on line 8841-1428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1745
% INFO    : Updated Thermal Rating: on line 1428-6074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 8841-5070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 3179-3936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 9229-3936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 5070-6913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13702
% INFO    : Updated Thermal Rating: on line 7695-4354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7743
% INFO    : Updated Thermal Rating: on line 7695-3098 : Rate B, Rate C , 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 6688-5625 : Rate B, Rate C , 0.0, 0.0 -> 1736
% INFO    : Updated Thermal Rating: on line 2823-7421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4160
% INFO    : Updated Thermal Rating: on line 8894-5625 : Rate B, Rate C , 0.0, 0.0 -> 3335
% INFO    : Updated Thermal Rating: on line 3179-9229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 7421-9229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1655
% INFO    : Updated Thermal Rating: on line 8805-7768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 3398-8972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 977
% INFO    : Updated Thermal Rating: on line 6378-4575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 7531-6074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 6074-4575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 3097-659 : Rate B, Rate C , 0.0, 0.0 -> 3480
% INFO    : Updated Thermal Rating: on line 9024-4929 : Rate B, Rate C , 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 1815-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 6542-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 6069-6833 : Rate B, Rate C , 0.0, 0.0 -> 6748
% INFO    : Updated Thermal Rating: on line 6069-2268 : Rate B, Rate C , 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 6069-7180 : Rate B, Rate C , 0.0, 0.0 -> 5970
% INFO    : Updated Thermal Rating: on line 6069-6293 : Rate B, Rate C , 0.0, 0.0 -> 3355
% INFO    : Updated Thermal Rating: on line 1968-9192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8992
% INFO    : Updated Thermal Rating: on line 1968-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 1968-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 1968-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 1968-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1968-8964 : Rate B, Rate C , 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 1968-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 9192-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 9192-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 9192-8964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 8574-1616 : Rate B, Rate C , 0.0, 0.0 -> 8142
% INFO    : Updated Thermal Rating: on line 8574-1163 : Rate B, Rate C , 0.0, 0.0 -> 2766
% INFO    : Updated Thermal Rating: on line 8574-9064 : Rate B, Rate C , 0.0, 0.0 -> 9657
% INFO    : Updated Thermal Rating: on line 8574-8921 : Rate B, Rate C , 0.0, 0.0 -> 9284
% INFO    : Updated Thermal Rating: on line 3493-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 2299-4423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6826-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 7563-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 4427-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 8335-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5155-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 271-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 2449-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4665-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 4495-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 3493-5587 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4586-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 228-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 6826-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 7563-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 4427-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 8335-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5155-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 271-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 5776-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 2449-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 4665-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 4495-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 5587-4586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 4423-4586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1544
% INFO    : Updated Thermal Rating: on line 4929-2870 : Rate B, Rate C , 0.0, 0.0 -> 76679
% INFO    : Updated Thermal Rating: on line 4929-659 : Rate B, Rate C , 0.0, 0.0 -> 2897
% INFO    : Updated Thermal Rating: on line 4929-1037 : Rate B, Rate C , 0.0, 0.0 -> 68410
% INFO    : Updated Thermal Rating: on line 4929-659 : Rate B, Rate C , 0.0, 0.0 -> 3401
% INFO    : Updated Thermal Rating: on line 1815-5210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 1815-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 1616-7762 : Rate B, Rate C , 0.0, 0.0 -> 9780
% INFO    : Updated Thermal Rating: on line 1616-2520 : Rate B, Rate C , 0.0, 0.0 -> 6432
% INFO    : Updated Thermal Rating: on line 9064-7762 : Rate B, Rate C , 0.0, 0.0 -> 8942
% INFO    : Updated Thermal Rating: on line 9064-89 : Rate B, Rate C , 0.0, 0.0 -> 6915
% INFO    : Updated Thermal Rating: on line 1317-659 : Rate B, Rate C , 0.0, 0.0 -> 4217
% INFO    : Updated Thermal Rating: on line 1317-8605 : Rate B, Rate C , 0.0, 0.0 -> 3079
% INFO    : Updated Thermal Rating: on line 8605-1367 : Rate B, Rate C , 0.0, 0.0 -> 78577
% INFO    : Updated Thermal Rating: on line 8605-8921 : Rate B, Rate C , 0.0, 0.0 -> 4498
% INFO    : Updated Thermal Rating: on line 1163-1676 : Rate B, Rate C , 0.0, 0.0 -> 73144
% INFO    : Updated Thermal Rating: on line 1163-7051 : Rate B, Rate C , 0.0, 0.0 -> 10190
% INFO    : Updated Thermal Rating: on line 913-7762 : Rate B, Rate C , 0.0, 0.0 -> 5849
% INFO    : Updated Thermal Rating: on line 2107-7762 : Rate B, Rate C , 0.0, 0.0 -> 5744
% INFO    : Updated Thermal Rating: on line 2107-5996 : Rate B, Rate C , 0.0, 0.0 -> 18181
% INFO    : Updated Thermal Rating: on line 2107-6293 : Rate B, Rate C , 0.0, 0.0 -> 2134
% INFO    : Updated Thermal Rating: on line 913-7762 : Rate B, Rate C , 0.0, 0.0 -> 6140
% INFO    : Updated Thermal Rating: on line 6704-8921 : Rate B, Rate C , 0.0, 0.0 -> 12692
% INFO    : Updated Thermal Rating: on line 228-4586 : Rate B, Rate C , 0.0, 0.0 -> 1428
% INFO    : Updated Thermal Rating: on line 2441-6293 : Rate B, Rate C , 0.0, 0.0 -> 10893
% INFO    : Updated Thermal Rating: on line 955-3506 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 955-8964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 3506-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 228-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 228-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 8964-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 5776-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2682
% INFO    : Updated Thermal Rating: on line 659-8329 : Rate B, Rate C , 0.0, 0.0 -> 10293
% INFO    : Updated Thermal Rating: on line 659-7051 : Rate B, Rate C , 0.0, 0.0 -> 2505
% INFO    : Updated Thermal Rating: on line 659-9239 : Rate B, Rate C , 0.0, 0.0 -> 48391
% INFO    : Updated Thermal Rating: on line 659-7960 : Rate B, Rate C , 0.0, 0.0 -> 49913
% INFO    : Updated Thermal Rating: on line 659-6233 : Rate B, Rate C , 0.0, 0.0 -> 57093
% INFO    : Updated Thermal Rating: on line 659-5416 : Rate B, Rate C , 0.0, 0.0 -> 3253
% INFO    : Updated Thermal Rating: on line 659-6798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39828
% INFO    : Updated Thermal Rating: on line 792-3279 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7563-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 7279-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 8335-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 2449-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 4665-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 4495-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 5416-2267 : Rate B, Rate C , 0.0, 0.0 -> 14737
% INFO    : Updated Thermal Rating: on line 5416-7637 : Rate B, Rate C , 0.0, 0.0 -> 3554
% INFO    : Updated Thermal Rating: on line 8964-2168 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3659-5996 : Rate B, Rate C , 0.0, 0.0 -> 15425
% INFO    : Updated Thermal Rating: on line 5762-5996 : Rate B, Rate C , 0.0, 0.0 -> 15130
% INFO    : Updated Thermal Rating: on line 3242-5097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7563-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 4427-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 3242-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 271-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 3242-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 5097-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 8181-8179 : Rate B, Rate C , 0.0, 0.0 -> 9918
% INFO    : Updated Thermal Rating: on line 8181-7762 : Rate B, Rate C , 0.0, 0.0 -> 6320
% INFO    : Updated Thermal Rating: on line 9025-7762 : Rate B, Rate C , 0.0, 0.0 -> 6197
% INFO    : Updated Thermal Rating: on line 7563-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 7563-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 7563-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 7563-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 7563-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 2449-7563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4665-7563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 4495-7563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 7563-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 4427-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4427-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 4427-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 4427-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 2449-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 4665-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 4495-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 4427-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5210-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1817
% INFO    : Updated Thermal Rating: on line 8179-5509 : Rate B, Rate C , 0.0, 0.0 -> 4526
% INFO    : Updated Thermal Rating: on line 8179-7762 : Rate B, Rate C , 0.0, 0.0 -> 3935
% INFO    : Updated Thermal Rating: on line 7279-4014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8335-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on line 5155-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 271-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 2449-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 4665-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 4495-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 1611-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5509-1579 : Rate B, Rate C , 0.0, 0.0 -> 3513
% INFO    : Updated Thermal Rating: on line 8335-1531 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5155-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 2449-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4665-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 4495-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 7762-2268 : Rate B, Rate C , 0.0, 0.0 -> 4051
% INFO    : Updated Thermal Rating: on line 5155-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5155-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 4665-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4495-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 5155-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 271-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 4665-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4495-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 271-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 1579-5848 : Rate B, Rate C , 0.0, 0.0 -> 8673
% INFO    : Updated Thermal Rating: on line 7051-8847 : Rate B, Rate C , 0.0, 0.0 -> 17783
% INFO    : Updated Thermal Rating: on line 5776-8229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 317-6233 : Rate B, Rate C , 0.0, 0.0 -> 142990
% INFO    : Updated Thermal Rating: on line 4665-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 2449-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 4665-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 1611-8420 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8768-2283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 636-2283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 4388-4008 : Rate B, Rate C , 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 4008-7532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5151
% INFO    : Updated Thermal Rating: on line 4008-6006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 4008-6006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 6999-2041 : Rate B, Rate C , 0.0, 0.0 -> 2946
% INFO    : Updated Thermal Rating: on line 6999-2041 : Rate B, Rate C , 0.0, 0.0 -> 3239
% INFO    : Updated Thermal Rating: on line 6999-2041 : Rate B, Rate C , 0.0, 0.0 -> 2891
% INFO    : Updated Thermal Rating: on line 1506-6999 : Rate B, Rate C , 0.0, 0.0 -> 1993
% INFO    : Updated Thermal Rating: on line 1506-6999 : Rate B, Rate C , 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 1506-6999 : Rate B, Rate C , 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 5521-815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on line 5521-2127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 1617-3294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1034
% INFO    : Updated Thermal Rating: on line 3294-6055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 3788-4558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 7112-3788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on line 1438-3173 : Rate B, Rate C , 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 1438-3173 : Rate B, Rate C , 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on line 3173-9125 : Rate B, Rate C , 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 3173-7432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on line 3173-5497 : Rate B, Rate C , 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 3173-921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 8768-3765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 8768-3420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on line 8768-6537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on line 8768-7991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1969
% INFO    : Updated Thermal Rating: on line 8768-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1440
% INFO    : Updated Thermal Rating: on line 8768-3861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2370
% INFO    : Updated Thermal Rating: on line 8768-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 2922-5424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 3641-2922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 964
% INFO    : Updated Thermal Rating: on line 6051-2937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 6051-6367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 979-3329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 5804-3329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2182
% INFO    : Updated Thermal Rating: on line 1499-8659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 1499-7932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1499-8925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 5198-1499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 1499-4684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1404
% INFO    : Updated Thermal Rating: on line 9111-7560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 8925-7560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 8925-7560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1256
% INFO    : Updated Thermal Rating: on line 3614-7560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 7560-761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2947
% INFO    : Updated Thermal Rating: on line 4518-7560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 4518-7560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 5015-7560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1475
% INFO    : Updated Thermal Rating: on line 4570-7068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6673
% INFO    : Updated Thermal Rating: on line 7068-7823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 716-8108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 716-8108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5962-8108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 5962-8108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 6761-8408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 6942-6761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 6761-7087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3273
% INFO    : Updated Thermal Rating: on line 337-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 4184-337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1576
% INFO    : Updated Thermal Rating: on line 3534-45 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 45-915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 45-4877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 8830-3534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 6258-1681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 1681-5539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 2677-5055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 5055-921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1430
% INFO    : Updated Thermal Rating: on line 1450-9237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35373
% INFO    : Updated Thermal Rating: on line 4693-1450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 4693-1450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 9237-3683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 9237-4536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 9237-7484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 457-3572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 7336-457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10216
% INFO    : Updated Thermal Rating: on line 1698-1617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 5966-3474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 3474-8897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5424-4605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 5424-4605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4605-7181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 4605-8174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 2678-4605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 991
% INFO    : Updated Thermal Rating: on line 2678-4605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1024
% INFO    : Updated Thermal Rating: on line 2415-7744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 6033-7744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 5198-8659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 1119-1438 : Rate B, Rate C , 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 1119-1438 : Rate B, Rate C , 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 480-4280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 8978-4280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 636-3765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 5223-3614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 7793-5223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1248
% INFO    : Updated Thermal Rating: on line 3420-2776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 8319-2249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 2249-3669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1611
% INFO    : Updated Thermal Rating: on line 8360-1500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 7456-8360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 9010-6568 : Rate B, Rate C , 0.0, 0.0 -> 2976
% INFO    : Updated Thermal Rating: on line 9010-6568 : Rate B, Rate C , 0.0, 0.0 -> 2921
% INFO    : Updated Thermal Rating: on line 3641-5424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3646
% INFO    : Updated Thermal Rating: on line 5424-8272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 1143-888 : Rate B, Rate C , 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 1143-888 : Rate B, Rate C , 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 2865-888 : Rate B, Rate C , 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 665-888 : Rate B, Rate C , 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4388-6006 : Rate B, Rate C , 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 8923-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 8923-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 1073-4275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on line 1073-8446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 1073-4668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 1073-568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 1073-884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 2914-8923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 8852-2914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 2914-2127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 6502-2914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4443
% INFO    : Updated Thermal Rating: on line 6501-2914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2127
% INFO    : Updated Thermal Rating: on line 6501-2914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2158
% INFO    : Updated Thermal Rating: on line 422-2914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 996
% INFO    : Updated Thermal Rating: on line 2022-7461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 1416-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 2022-8549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 991
% INFO    : Updated Thermal Rating: on line 3421-9178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 9178-944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 9178-1981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 3415-8315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 8315-5570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4573
% INFO    : Updated Thermal Rating: on line 889-7340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 889-8173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 4558-8897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 2127-8923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 4069-8923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 815-7121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 7121-8319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 7121-4065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 3967-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 7737-3967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2533
% INFO    : Updated Thermal Rating: on line 7572-727 : Rate B, Rate C , 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 7455-7572 : Rate B, Rate C , 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 8880-5954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 8880-5954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5954-2998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 5954-6453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 5954-6453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1360
% INFO    : Updated Thermal Rating: on line 944-5954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 5954-5027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 5954-5027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on line 2813-5954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 2582-1737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 2582-4693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1427
% INFO    : Updated Thermal Rating: on line 3440-2041 : Rate B, Rate C , 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 3440-7455 : Rate B, Rate C , 0.0, 0.0 -> 1312
% INFO    : Updated Thermal Rating: on line 4599-1647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 4599-1737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 4599-1737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 4599-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 4599-93 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1402
% INFO    : Updated Thermal Rating: on line 4599-206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 797
% INFO    : Updated Thermal Rating: on line 8319-5637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1088
% INFO    : Updated Thermal Rating: on line 7340-8319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 7340-8319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 8319-3669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on line 8830-7796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 8897-8830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 8897-8830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 6780-7777 : Rate B, Rate C , 0.0, 0.0 -> 11201
% INFO    : Updated Thermal Rating: on line 5408-7246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 3746-5408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 8168-5583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 8168-8599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 4570-3151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on line 4570-4184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 4570-4184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 3309-3387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2005
% INFO    : Updated Thermal Rating: on line 3387-2763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2095
% INFO    : Updated Thermal Rating: on line 2879-1585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4204
% INFO    : Updated Thermal Rating: on line 480-2879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 751
% INFO    : Updated Thermal Rating: on line 1506-9010 : Rate B, Rate C , 0.0, 0.0 -> 3207
% INFO    : Updated Thermal Rating: on line 1506-9010 : Rate B, Rate C , 0.0, 0.0 -> 3147
% INFO    : Updated Thermal Rating: on line 9010-7777 : Rate B, Rate C , 0.0, 0.0 -> 1689
% INFO    : Updated Thermal Rating: on line 4894-2892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 1098-4894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2114
% INFO    : Updated Thermal Rating: on line 2831-7101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 6867-2831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 606
% INFO    : Updated Thermal Rating: on line 6758-5966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1217
% INFO    : Updated Thermal Rating: on line 1967-9111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 390-9111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3418
% INFO    : Updated Thermal Rating: on line 9111-4518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on line 206-1647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3429
% INFO    : Updated Thermal Rating: on line 6258-7461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 6942-7932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 1084-7101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4965
% INFO    : Updated Thermal Rating: on line 1677-8880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 9210-5456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5081-5456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 5539-5456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 7790-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52855
% INFO    : Updated Thermal Rating: on line 3437-2163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4180
% INFO    : Updated Thermal Rating: on line 2461-1585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3080
% INFO    : Updated Thermal Rating: on line 1585-5565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 8978-1585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 2461-4009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11302
% INFO    : Updated Thermal Rating: on line 8978-2461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 1843-1967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1804
% INFO    : Updated Thermal Rating: on line 2561-5467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 4069-5467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 9026-3641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 480-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 480-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 480-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 480-5159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 480-3281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 480-4009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 480-5457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 480-5457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1058
% INFO    : Updated Thermal Rating: on line 480-8910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 6599-3844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 6599-3547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 7455-8885 : Rate B, Rate C , 0.0, 0.0 -> 28455
% INFO    : Updated Thermal Rating: on line 7455-8885 : Rate B, Rate C , 0.0, 0.0 -> 22584
% INFO    : Updated Thermal Rating: on line 1263-2419 : Rate B, Rate C , 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on line 1263-4788 : Rate B, Rate C , 0.0, 0.0 -> 2577
% INFO    : Updated Thermal Rating: on line 1263-4788 : Rate B, Rate C , 0.0, 0.0 -> 2281
% INFO    : Updated Thermal Rating: on line 1263-3505 : Rate B, Rate C , 0.0, 0.0 -> 4167
% INFO    : Updated Thermal Rating: on line 1263-557 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 2211-2937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2406
% INFO    : Updated Thermal Rating: on line 1737-4693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 979-9210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 9210-7608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 9210-5081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 8020-3883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2476
% INFO    : Updated Thermal Rating: on line 8020-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1000
% INFO    : Updated Thermal Rating: on line 7554-3415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on line 5962-7554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 4536-8983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 343-8983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 4643-7181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 3421-6739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 3094-3421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 3421-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 1324-5552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 5552-5676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 7077-5443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 7340-5443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 7242-7077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1660
% INFO    : Updated Thermal Rating: on line 4028-7242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1618
% INFO    : Updated Thermal Rating: on line 8372-2763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 3683-8372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5198-2263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 877
% INFO    : Updated Thermal Rating: on line 2263-7793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 8046-5219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4668
% INFO    : Updated Thermal Rating: on line 2167-5219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4051
% INFO    : Updated Thermal Rating: on line 6133-3781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 960
% INFO    : Updated Thermal Rating: on line 6133-3781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on line 3781-3746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5639
% INFO    : Updated Thermal Rating: on line 4275-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 3006-8029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 977
% INFO    : Updated Thermal Rating: on line 8978-8029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 589-8174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 589-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2679-868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 343-2679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 1682-868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4272
% INFO    : Updated Thermal Rating: on line 1682-93 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 1682-8709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 1682-3890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 416
% INFO    : Updated Thermal Rating: on line 1682-1353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 3844-3547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 2892-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2324
% INFO    : Updated Thermal Rating: on line 8925-8746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 8925-8505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2223
% INFO    : Updated Thermal Rating: on line 2677-2419 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 2677-6046 : Rate B, Rate C , 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 2677-8551 : Rate B, Rate C , 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 2677-1922 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 2677-6971 : Rate B, Rate C , 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on line 84-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2884
% INFO    : Updated Thermal Rating: on line 884-84 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1355
% INFO    : Updated Thermal Rating: on line 2386-36 : Rate B, Rate C , 0.0, 0.0 -> 4137
% INFO    : Updated Thermal Rating: on line 7737-2068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4048
% INFO    : Updated Thermal Rating: on line 7737-2068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3606
% INFO    : Updated Thermal Rating: on line 8852-2561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 1677-1447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 3531-2415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 1084-3531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 1171-6695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2905
% INFO    : Updated Thermal Rating: on line 3141-6695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3303
% INFO    : Updated Thermal Rating: on line 3141-6695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3365
% INFO    : Updated Thermal Rating: on line 1324-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 574-7077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 4341-3730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4574
% INFO    : Updated Thermal Rating: on line 3730-3828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 1873-5563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 8797-5563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 390-5515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3350
% INFO    : Updated Thermal Rating: on line 6076-390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 8978-5159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1207
% INFO    : Updated Thermal Rating: on line 7246-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 6739-4372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 1782-6739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 2998-7296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 2776-1171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 1171-3746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 1171-7250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 1171-7250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 1324-34 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 34-7022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 34-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 5676-34 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 7077-2130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 4028-2130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1908
% INFO    : Updated Thermal Rating: on line 979-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 3576-4372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 4643-1247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 7882-4161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 4161-3094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on line 4161-1098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 4161-1098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 8269-4161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on line 6651-5275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3001
% INFO    : Updated Thermal Rating: on line 6651-4184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 756
% INFO    : Updated Thermal Rating: on line 435-8446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 8514-8219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 8514-2790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on line 5275-8514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on line 1590-8514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3867
% INFO    : Updated Thermal Rating: on line 3477-7882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on line 5086-3477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 7796-4655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 4655-4877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 5027-6453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2913
% INFO    : Updated Thermal Rating: on line 6453-6196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 7336-7608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5515-4518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2484
% INFO    : Updated Thermal Rating: on line 23-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 23-3144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 23-6002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 3151-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 3144-1517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 5962-1517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5160-557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10647
% INFO    : Updated Thermal Rating: on line 572-6196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 572-5086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 4044-572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 3572-3281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2011
% INFO    : Updated Thermal Rating: on line 1698-5368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on line 1698-5368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 950
% INFO    : Updated Thermal Rating: on line 1698-8910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 7823-5024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 1438-1143 : Rate B, Rate C , 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 1438-1143 : Rate B, Rate C , 0.0, 0.0 -> 2204
% INFO    : Updated Thermal Rating: on line 1438-36 : Rate B, Rate C , 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 1438-36 : Rate B, Rate C , 0.0, 0.0 -> 1477
% INFO    : Updated Thermal Rating: on line 1324-7077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 2167-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2122
% INFO    : Updated Thermal Rating: on line 1509-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 964
% INFO    : Updated Thermal Rating: on line 4684-8746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 915-5319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2555
% INFO    : Updated Thermal Rating: on line 5637-4065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 7203-5917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2623
% INFO    : Updated Thermal Rating: on line 7203-507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 8646-9026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 6065-3842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 3923-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1430
% INFO    : Updated Thermal Rating: on line 116-5198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 7022-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 7077-3524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 3524-4304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 7384-3842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 5917-5082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on line 5917-5082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1620
% INFO    : Updated Thermal Rating: on line 6557-5607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 5607-7796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 5730-4438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 4438-8272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 3614-2626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 2626-8797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 3883-4944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 419-3381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 3381-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 5176-7077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1543
% INFO    : Updated Thermal Rating: on line 7077-8173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 7077-498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 3141-6133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1563
% INFO    : Updated Thermal Rating: on line 3141-6133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 3006-157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 8978-3006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 8091-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 8091-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2223
% INFO    : Updated Thermal Rating: on line 7130-645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 645-4297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 6033-645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 66-1782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 1084-3309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 8782-3309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 3309-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 2211-5081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on line 3669-8821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 8821-1229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 7280-116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 2419-3505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 5804-7336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 7336-2733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1747
% INFO    : Updated Thermal Rating: on line 7336-2733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1716
% INFO    : Updated Thermal Rating: on line 7336-2733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 2256-7336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 8797-3576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 1856-5368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 1856-5368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 917
% INFO    : Updated Thermal Rating: on line 3547-5368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 6523-8978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1242
% INFO    : Updated Thermal Rating: on line 6523-7594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 944-1447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 5583-1843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 984
% INFO    : Updated Thermal Rating: on line 4877-7375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 7375-8646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 1873-1843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 1873-1843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 1843-6076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11816
% INFO    : Updated Thermal Rating: on line 5119-1270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1084
% INFO    : Updated Thermal Rating: on line 5962-5119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 944-2813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1414
% INFO    : Updated Thermal Rating: on line 1668-1506 : Rate B, Rate C , 0.0, 0.0 -> 4355
% INFO    : Updated Thermal Rating: on line 1668-3981 : Rate B, Rate C , 0.0, 0.0 -> 13785
% INFO    : Updated Thermal Rating: on line 7737-9145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2571
% INFO    : Updated Thermal Rating: on line 7737-9145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2526
% INFO    : Updated Thermal Rating: on line 7340-7782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 239-7340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on line 4668-7340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 8322-3885 : Rate B, Rate C , 0.0, 0.0 -> 7336
% INFO    : Updated Thermal Rating: on line 9194-3885 : Rate B, Rate C , 0.0, 0.0 -> 1326
% INFO    : Updated Thermal Rating: on line 3885-2942 : Rate B, Rate C , 0.0, 0.0 -> 33807
% INFO    : Updated Thermal Rating: on line 3885-1905 : Rate B, Rate C , 0.0, 0.0 -> 33102
% INFO    : Updated Thermal Rating: on line 6046-9144 : Rate B, Rate C , 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 6046-9144 : Rate B, Rate C , 0.0, 0.0 -> 1323
% INFO    : Updated Thermal Rating: on line 9144-6434 : Rate B, Rate C , 0.0, 0.0 -> 5553
% INFO    : Updated Thermal Rating: on line 9144-5497 : Rate B, Rate C , 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 1873-2790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 1873-8797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 1873-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 8322-727 : Rate B, Rate C , 0.0, 0.0 -> 5309
% INFO    : Updated Thermal Rating: on line 6046-6434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2021
% INFO    : Updated Thermal Rating: on line 6046-2110 : Rate B, Rate C , 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 6046-557 : Rate B, Rate C , 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 6046-6971 : Rate B, Rate C , 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on line 6434-6158 : Rate B, Rate C , 0.0, 0.0 -> 1141
% INFO    : Updated Thermal Rating: on line 3981-2041 : Rate B, Rate C , 0.0, 0.0 -> 1437
% INFO    : Updated Thermal Rating: on line 6006-1922 : Rate B, Rate C , 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 6006-1922 : Rate B, Rate C , 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 3669-3263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 7782-3669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 3669-6867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 6758-7054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 6758-7054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1524
% INFO    : Updated Thermal Rating: on line 6758-4304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 6758-4304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 498-6758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1711
% INFO    : Updated Thermal Rating: on line 8717-8219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 8717-1098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 8717-6732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 2813-8232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on line 8232-1981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 1084-3263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 7054-4232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1610
% INFO    : Updated Thermal Rating: on line 4028-4232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5293
% INFO    : Updated Thermal Rating: on line 2279-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1261
% INFO    : Updated Thermal Rating: on line 2279-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 3171-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1113
% INFO    : Updated Thermal Rating: on line 6258-5804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 1970-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1413
% INFO    : Updated Thermal Rating: on line 6258-190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 6258-419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3828-7384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 1270-8274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2974
% INFO    : Updated Thermal Rating: on line 9125-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on line 716-6537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 716-7991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 4184-5024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1641-1911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 5962-1911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 8797-761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 4944-2279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2248
% INFO    : Updated Thermal Rating: on line 8274-6304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 8408-8599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5319-4877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 7130-8709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 813
% INFO    : Updated Thermal Rating: on line 8897-6557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1273
% INFO    : Updated Thermal Rating: on line 8897-507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2623
% INFO    : Updated Thermal Rating: on line 5730-5706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 2602-5706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 4297-8803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 1084-8803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1414
% INFO    : Updated Thermal Rating: on line 1084-8803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 1084-8782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2826
% INFO    : Updated Thermal Rating: on line 7777-9194 : Rate B, Rate C , 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 1199-9194 : Rate B, Rate C , 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 8408-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 8408-7087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 716-6304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 5804-8527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 1353-8527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 4341-8527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4028-5176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1650
% INFO    : Updated Thermal Rating: on line 7000-4184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2628
% INFO    : Updated Thermal Rating: on line 7000-542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23331
% INFO    : Updated Thermal Rating: on line 2733-2713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 2713-4341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3890-7496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 7496-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 8978-4009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 6002-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 3746-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 5804-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1053
% INFO    : Updated Thermal Rating: on line 8272-2678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 1500-1963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 5082-8954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 8954-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2185
% INFO    : Updated Thermal Rating: on line 8890-7280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 8890-6942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 36-2369 : Rate B, Rate C , 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on line 1856-3547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 486
% INFO    : Updated Thermal Rating: on line 5539-2211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 157-7296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 1963-8269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2498
% INFO    : Updated Thermal Rating: on line 8269-3923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2943
% INFO    : Updated Thermal Rating: on line 4304-7112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 2163-8890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 8046-2167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2891
% INFO    : Updated Thermal Rating: on line 5082-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6071
% INFO    : Updated Thermal Rating: on line 5082-3646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4801
% INFO    : Updated Thermal Rating: on line 5082-6933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4891
% INFO    : Updated Thermal Rating: on line 3981-1199 : Rate B, Rate C , 0.0, 0.0 -> 2977
% INFO    : Updated Thermal Rating: on line 2865-36 : Rate B, Rate C , 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 665-36 : Rate B, Rate C , 0.0, 0.0 -> 1104
% INFO    : Updated Thermal Rating: on line 1641-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 6033-94 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on line 94-8549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 5457-6367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 1560-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3160
% INFO    : Updated Thermal Rating: on line 5570-279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 1229-279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 1590-542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30716
% INFO    : Updated Thermal Rating: on line 5565-3062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 521-1028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2471
% INFO    : Updated Thermal Rating: on line 1028-7484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 2167-3237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 1820-6971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50020
% INFO    : Updated Thermal Rating: on line 7456-6732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 6501-6502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4071
% INFO    : Updated Thermal Rating: on line 8910-8978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 8910-8978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 7594-8978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 787
% INFO    : Updated Thermal Rating: on line 568-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2218
% INFO    : Updated Thermal Rating: on line 3861-1247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 2559-2672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 3062-4044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5015-8505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2534
% INFO    : Updated Thermal Rating: on line 6501-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1377
% INFO    : Updated Thermal Rating: on line 8910-8093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3153
% INFO    : Updated Thermal Rating: on line 8144-8093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2150
% INFO    : Updated Thermal Rating: on line 6055-8144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 3646-1509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2875
% INFO    : Updated Thermal Rating: on line 6933-3237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2825
% INFO    : Updated Thermal Rating: on line 654-5807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2143
% INFO    : Updated Thermal Rating: on line 654-1924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2185
% INFO    : Updated Thermal Rating: on line 8675-6520 : Rate B, Rate C , 0.0, 0.0 -> 2312
% INFO    : Updated Thermal Rating: on line 8675-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 544
% INFO    : Updated Thermal Rating: on line 8675-1553 : Rate B, Rate C , 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 8675-3124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5143
% INFO    : Updated Thermal Rating: on line 5448-4808 : Rate B, Rate C , 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on line 4762-5448 : Rate B, Rate C , 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 6411-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2923
% INFO    : Updated Thermal Rating: on line 6411-2005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3120
% INFO    : Updated Thermal Rating: on line 1278-1557 : Rate B, Rate C , 0.0, 0.0 -> 3592
% INFO    : Updated Thermal Rating: on line 1278-5527 : Rate B, Rate C , 0.0, 0.0 -> 5745
% INFO    : Updated Thermal Rating: on line 4761-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9222
% INFO    : Updated Thermal Rating: on line 4761-2257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4558
% INFO    : Updated Thermal Rating: on line 4761-6335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20838
% INFO    : Updated Thermal Rating: on line 3278-2624 : Rate B, Rate C , 0.0, 0.0 -> 1581
% INFO    : Updated Thermal Rating: on line 3278-752 : Rate B, Rate C , 0.0, 0.0 -> 1414
% INFO    : Updated Thermal Rating: on line 3278-7239 : Rate B, Rate C , 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 4416-4553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 4416-4176 : Rate B, Rate C , 0.0, 0.0 -> 7592
% INFO    : Updated Thermal Rating: on line 6775-8905 : Rate B, Rate C , 0.0, 0.0 -> 2547
% INFO    : Updated Thermal Rating: on line 6775-5527 : Rate B, Rate C , 0.0, 0.0 -> 1782
% INFO    : Updated Thermal Rating: on line 5438-356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2695
% INFO    : Updated Thermal Rating: on line 3949-147 : Rate B, Rate C , 0.0, 0.0 -> 2685
% INFO    : Updated Thermal Rating: on line 3949-4453 : Rate B, Rate C , 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 3949-9048 : Rate B, Rate C , 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 1122-4211 : Rate B, Rate C , 0.0, 0.0 -> 11579
% INFO    : Updated Thermal Rating: on line 1122-2501 : Rate B, Rate C , 0.0, 0.0 -> 9422
% INFO    : Updated Thermal Rating: on line 3433-4201 : Rate B, Rate C , 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 3433-6666 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on line 4540-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1397
% INFO    : Updated Thermal Rating: on line 4540-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 4540-688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6268
% INFO    : Updated Thermal Rating: on line 4540-2191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 7472-3494 : Rate B, Rate C , 0.0, 0.0 -> 3906
% INFO    : Updated Thermal Rating: on line 7472-3277 : Rate B, Rate C , 0.0, 0.0 -> 10104
% INFO    : Updated Thermal Rating: on line 7472-219 : Rate B, Rate C , 0.0, 0.0 -> 15988
% INFO    : Updated Thermal Rating: on line 7681-5807 : Rate B, Rate C , 0.0, 0.0 -> 1301
% INFO    : Updated Thermal Rating: on line 7681-2257 : Rate B, Rate C , 0.0, 0.0 -> 1029
% INFO    : Updated Thermal Rating: on line 9161-8395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2570
% INFO    : Updated Thermal Rating: on line 9161-8598 : Rate B, Rate C , 0.0, 0.0 -> 3351
% INFO    : Updated Thermal Rating: on line 9161-943 : Rate B, Rate C , 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 2017-752 : Rate B, Rate C , 0.0, 0.0 -> 2550
% INFO    : Updated Thermal Rating: on line 2017-1915 : Rate B, Rate C , 0.0, 0.0 -> 59909
% INFO    : Updated Thermal Rating: on line 2017-6520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2865
% INFO    : Updated Thermal Rating: on line 8905-8742 : Rate A, Rate B, Rate C , 1843.0, 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 8905-3277 : Rate B, Rate C , 0.0, 0.0 -> 1867
% INFO    : Updated Thermal Rating: on line 4631-5898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 4631-8986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3069
% INFO    : Updated Thermal Rating: on line 4631-5844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 4631-5844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 4631-7219 : Rate B, Rate C , 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 4631-7219 : Rate B, Rate C , 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 4631-7027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1142
% INFO    : Updated Thermal Rating: on line 4631-1062 : Rate B, Rate C , 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 8395-3407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6187
% INFO    : Updated Thermal Rating: on line 8395-811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4748
% INFO    : Updated Thermal Rating: on line 5309-5898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 5309-1553 : Rate B, Rate C , 0.0, 0.0 -> 9180
% INFO    : Updated Thermal Rating: on line 3042-3494 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1330
% INFO    : Updated Thermal Rating: on line 3042-4323 : Rate B, Rate C , 0.0, 0.0 -> 7678
% INFO    : Updated Thermal Rating: on line 3042-6666 : Rate B, Rate C , 0.0, 0.0 -> 9627
% INFO    : Updated Thermal Rating: on line 3042-6666 : Rate B, Rate C , 0.0, 0.0 -> 9457
% INFO    : Updated Thermal Rating: on line 3042-2716 : Rate B, Rate C , 0.0, 0.0 -> 5475
% INFO    : Updated Thermal Rating: on line 1017-7785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8326
% INFO    : Updated Thermal Rating: on line 1017-7529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 1017-5242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2861
% INFO    : Updated Thermal Rating: on line 2498-7027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 2498-2290 : Rate B, Rate C , 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 3494-5527 : Rate B, Rate C , 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on line 3494-4323 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 3494-2716 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 5807-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2214
% INFO    : Updated Thermal Rating: on line 5807-1924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 5807-5795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5654
% INFO    : Updated Thermal Rating: on line 5807-8276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 5807-1406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5963
% INFO    : Updated Thermal Rating: on line 5807-1603 : Rate B, Rate C , 0.0, 0.0 -> 1544
% INFO    : Updated Thermal Rating: on line 5807-943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2248
% INFO    : Updated Thermal Rating: on line 153-8142 : Rate B, Rate C , 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 4808-7005 : Rate B, Rate C , 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 7005-153 : Rate B, Rate C , 0.0, 0.0 -> 5581
% INFO    : Updated Thermal Rating: on line 2624-4211 : Rate B, Rate C , 0.0, 0.0 -> 2496
% INFO    : Updated Thermal Rating: on line 4938-8742 : Rate B, Rate C , 0.0, 0.0 -> 5512
% INFO    : Updated Thermal Rating: on line 4938-1141 : Rate B, Rate C , 0.0, 0.0 -> 7038
% INFO    : Updated Thermal Rating: on line 2987-5898 : Rate B, Rate C , 0.0, 0.0 -> 1896
% INFO    : Updated Thermal Rating: on line 2987-7027 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 2987-147 : Rate B, Rate C , 0.0, 0.0 -> 13417
% INFO    : Updated Thermal Rating: on line 2987-147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11907
% INFO    : Updated Thermal Rating: on line 1487-5973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4997
% INFO    : Updated Thermal Rating: on line 1487-464 : Rate B, Rate C , 0.0, 0.0 -> 1057
% INFO    : Updated Thermal Rating: on line 1487-7896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12495
% INFO    : Updated Thermal Rating: on line 5973-5898 : Rate B, Rate C , 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 8362-4176 : Rate B, Rate C , 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 8362-4453 : Rate B, Rate C , 0.0, 0.0 -> 3300
% INFO    : Updated Thermal Rating: on line 5898-5225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1470
% INFO    : Updated Thermal Rating: on line 5898-5225 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on line 5236-4284 : Rate B, Rate C , 0.0, 0.0 -> 3964
% INFO    : Updated Thermal Rating: on line 6719-4553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3014
% INFO    : Updated Thermal Rating: on line 6719-4176 : Rate B, Rate C , 0.0, 0.0 -> 1088
% INFO    : Updated Thermal Rating: on line 2097-943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79720
% INFO    : Updated Thermal Rating: on line 5992-1924 : Rate B, Rate C , 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 7459-4342 : Rate B, Rate C , 0.0, 0.0 -> 4336
% INFO    : Updated Thermal Rating: on line 7459-227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1662
% INFO    : Updated Thermal Rating: on line 2099-1586 : Rate B, Rate C , 0.0, 0.0 -> 2397
% INFO    : Updated Thermal Rating: on line 2099-6666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7858
% INFO    : Updated Thermal Rating: on line 8986-6683 : Rate B, Rate C , 0.0, 0.0 -> 4966
% INFO    : Updated Thermal Rating: on line 8986-3569 : Rate B, Rate C , 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 8986-3569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 4553-5905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4576
% INFO    : Updated Thermal Rating: on line 4553-5905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4489
% INFO    : Updated Thermal Rating: on line 3073-5576 : Rate B, Rate C , 0.0, 0.0 -> 3819
% INFO    : Updated Thermal Rating: on line 3073-4745 : Rate B, Rate C , 0.0, 0.0 -> 1539
% INFO    : Updated Thermal Rating: on line 4284-3432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10971
% INFO    : Updated Thermal Rating: on line 4284-7027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4384
% INFO    : Updated Thermal Rating: on line 7872-5844 : Rate B, Rate C , 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 7872-135 : Rate B, Rate C , 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 1557-3277 : Rate B, Rate C , 0.0, 0.0 -> 6022
% INFO    : Updated Thermal Rating: on line 1557-4201 : Rate B, Rate C , 0.0, 0.0 -> 3217
% INFO    : Updated Thermal Rating: on line 1557-4201 : Rate B, Rate C , 0.0, 0.0 -> 3229
% INFO    : Updated Thermal Rating: on line 3569-8598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2013
% INFO    : Updated Thermal Rating: on line 3569-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 3569-4745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3323
% INFO    : Updated Thermal Rating: on line 3569-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2063
% INFO    : Updated Thermal Rating: on line 1924-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 1924-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 1924-3550 : Rate B, Rate C , 0.0, 0.0 -> 1060
% INFO    : Updated Thermal Rating: on line 1924-3550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 1924-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1312
% INFO    : Updated Thermal Rating: on line 1924-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on line 464-7027 : Rate B, Rate C , 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 1225-5844 : Rate B, Rate C , 0.0, 0.0 -> 3223
% INFO    : Updated Thermal Rating: on line 1225-5844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2976
% INFO    : Updated Thermal Rating: on line 1225-3041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2339
% INFO    : Updated Thermal Rating: on line 1225-2556 : Rate B, Rate C , 0.0, 0.0 -> 2524
% INFO    : Updated Thermal Rating: on line 2715-7027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1810
% INFO    : Updated Thermal Rating: on line 2715-2290 : Rate B, Rate C , 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 2054-5242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58632
% INFO    : Updated Thermal Rating: on line 5844-7219 : Rate B, Rate C , 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 5844-9169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 1915-3973 : Rate B, Rate C , 0.0, 0.0 -> 1510
% INFO    : Updated Thermal Rating: on line 3432-7027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6623
% INFO    : Updated Thermal Rating: on line 5576-582 : Rate B, Rate C , 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on line 3277-219 : Rate B, Rate C , 0.0, 0.0 -> 9854
% INFO    : Updated Thermal Rating: on line 2487-2926 : Rate B, Rate C , 0.0, 0.0 -> 783
% INFO    : Updated Thermal Rating: on line 2487-582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7678
% INFO    : Updated Thermal Rating: on line 2487-1062 : Rate B, Rate C , 0.0, 0.0 -> 1406
% INFO    : Updated Thermal Rating: on line 1369-4201 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on line 6520-4211 : Rate B, Rate C , 0.0, 0.0 -> 1687
% INFO    : Updated Thermal Rating: on line 2926-7027 : Rate B, Rate C , 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on line 135-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4066
% INFO    : Updated Thermal Rating: on line 5778-7239 : Rate B, Rate C , 0.0, 0.0 -> 1941
% INFO    : Updated Thermal Rating: on line 5778-7239 : Rate B, Rate C , 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 7239-3973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 1615-6433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 6433-1615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 7936-4176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1864
% INFO    : Updated Thermal Rating: on line 7936-4176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1829
% INFO    : Updated Thermal Rating: on line 7219-4876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2389
% INFO    : Updated Thermal Rating: on line 7219-4876 : Rate B, Rate C , 0.0, 0.0 -> 2321
% INFO    : Updated Thermal Rating: on line 7219-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2369
% INFO    : Updated Thermal Rating: on line 4342-7467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 4342-5225 : Rate B, Rate C , 0.0, 0.0 -> 1731
% INFO    : Updated Thermal Rating: on line 7732-6259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 7732-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3074
% INFO    : Updated Thermal Rating: on line 6259-7529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8814
% INFO    : Updated Thermal Rating: on line 7027-356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2219
% INFO    : Updated Thermal Rating: on line 7027-1789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on line 3407-4876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2302
% INFO    : Updated Thermal Rating: on line 4876-2257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on line 4876-8488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4365
% INFO    : Updated Thermal Rating: on line 1062-811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2796
% INFO    : Updated Thermal Rating: on line 7153-2963 : Rate B, Rate C , 0.0, 0.0 -> 47664
% INFO    : Updated Thermal Rating: on line 4211-2556 : Rate B, Rate C , 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 9235-6666 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1418
% INFO    : Updated Thermal Rating: on line 9235-2963 : Rate B, Rate C , 0.0, 0.0 -> 5162
% INFO    : Updated Thermal Rating: on line 2257-6335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5439
% INFO    : Updated Thermal Rating: on line 7896-2290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1643
% INFO    : Updated Thermal Rating: on line 5795-8276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 4079-2963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3010
% INFO    : Updated Thermal Rating: on line 4830-1141 : Rate B, Rate C , 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 4176-4369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4048
% INFO    : Updated Thermal Rating: on line 4176-3088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 7785-6817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1681
% INFO    : Updated Thermal Rating: on line 7529-6817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 7529-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 2290-3088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3041
% INFO    : Updated Thermal Rating: on line 2005-688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3139
% INFO    : Updated Thermal Rating: on line 7817-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2263
% INFO    : Updated Thermal Rating: on line 7817-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1980
% INFO    : Updated Thermal Rating: on line 6666-1653 : Rate B, Rate C , 0.0, 0.0 -> 2733
% INFO    : Updated Thermal Rating: on line 2191-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5275
% INFO    : Updated Thermal Rating: on line 2191-6375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2071
% INFO    : Updated Thermal Rating: on line 382-5242 : Rate B, Rate C , 0.0, 0.0 -> 3562
% INFO    : Updated Thermal Rating: on line 721-6375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3558
% INFO    : Updated Thermal Rating: on line 1406-4700 : Rate B, Rate C , 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 227-3124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3677
% INFO    : Updated Thermal Rating: on line 4369-5905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 871
% INFO    : Updated Thermal Rating: on line 1789-9169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3025
% INFO    : Updated Thermal Rating: on line 4700-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 2392-1603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 711-7953 : Rate B, Rate C , 0.0, 0.0 -> 10026
% INFO    : Updated Thermal Rating: on line 6088-9060 : Rate B, Rate C , 0.0, 0.0 -> 2758
% INFO    : Updated Thermal Rating: on line 6088-5988 : Rate B, Rate C , 0.0, 0.0 -> 4503
% INFO    : Updated Thermal Rating: on line 6088-372 : Rate B, Rate C , 0.0, 0.0 -> 2078
% INFO    : Updated Thermal Rating: on line 9060-2153 : Rate B, Rate C , 0.0, 0.0 -> 2128
% INFO    : Updated Thermal Rating: on line 9060-518 : Rate B, Rate C , 0.0, 0.0 -> 2178
% INFO    : Updated Thermal Rating: on line 6099-1387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 6099-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 1307-3446 : Rate B, Rate C , 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 1307-6007 : Rate B, Rate C , 0.0, 0.0 -> 3523
% INFO    : Updated Thermal Rating: on line 1307-1884 : Rate B, Rate C , 0.0, 0.0 -> 3800
% INFO    : Updated Thermal Rating: on line 2153-8728 : Rate B, Rate C , 0.0, 0.0 -> 4163
% INFO    : Updated Thermal Rating: on line 8728-6569 : Rate B, Rate C , 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on line 8728-4195 : Rate B, Rate C , 0.0, 0.0 -> 5234
% INFO    : Updated Thermal Rating: on line 144-5620 : Rate B, Rate C , 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 5620-6468 : Rate B, Rate C , 0.0, 0.0 -> 5269
% INFO    : Updated Thermal Rating: on line 372-3808 : Rate B, Rate C , 0.0, 0.0 -> 4608
% INFO    : Updated Thermal Rating: on line 1387-3375 : Rate B, Rate C , 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on line 2153-2465 : Rate B, Rate C , 0.0, 0.0 -> 3353
% INFO    : Updated Thermal Rating: on line 2153-372 : Rate B, Rate C , 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 6014-6373 : Rate B, Rate C , 0.0, 0.0 -> 2077
% INFO    : Updated Thermal Rating: on line 6014-6373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2110
% INFO    : Updated Thermal Rating: on line 6014-3599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 6014-7107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 6014-3375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 7114-6569 : Rate B, Rate C , 0.0, 0.0 -> 4731
% INFO    : Updated Thermal Rating: on line 7114-6569 : Rate B, Rate C , 0.0, 0.0 -> 3682
% INFO    : Updated Thermal Rating: on line 7114-6007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 2465-3920 : Rate B, Rate C , 0.0, 0.0 -> 18794
% INFO    : Updated Thermal Rating: on line 2465-2098 : Rate B, Rate C , 0.0, 0.0 -> 19133
% INFO    : Updated Thermal Rating: on line 6007-8279 : Rate B, Rate C , 0.0, 0.0 -> 67071
% INFO    : Updated Thermal Rating: on line 6007-844 : Rate B, Rate C , 0.0, 0.0 -> 65679
% INFO    : Updated Thermal Rating: on line 6251-4046 : Rate B, Rate C , 0.0, 0.0 -> 2903
% INFO    : Updated Thermal Rating: on line 6007-5855 : Rate B, Rate C , 0.0, 0.0 -> 43013
% INFO    : Updated Thermal Rating: on line 6007-4969 : Rate B, Rate C , 0.0, 0.0 -> 52184
% INFO    : Updated Thermal Rating: on line 6007-1555 : Rate B, Rate C , 0.0, 0.0 -> 46891
% INFO    : Updated Thermal Rating: on line 6007-714 : Rate B, Rate C , 0.0, 0.0 -> 47593
% INFO    : Updated Thermal Rating: on line 3599-562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4377
% INFO    : Updated Thermal Rating: on line 3599-3389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4436
% INFO    : Updated Thermal Rating: on line 372-7214 : Rate B, Rate C , 0.0, 0.0 -> 37435
% INFO    : Updated Thermal Rating: on line 372-5412 : Rate B, Rate C , 0.0, 0.0 -> 37784
% INFO    : Updated Thermal Rating: on line 372-8156 : Rate B, Rate C , 0.0, 0.0 -> 38703
% INFO    : Updated Thermal Rating: on line 3290-6366 : Rate B, Rate C , 0.0, 0.0 -> 14635
% INFO    : Updated Thermal Rating: on line 144-3910 : Rate B, Rate C , 0.0, 0.0 -> 10732
% INFO    : Updated Thermal Rating: on line 144-2084 : Rate B, Rate C , 0.0, 0.0 -> 9468
% INFO    : Updated Thermal Rating: on line 3551-4076 : Rate B, Rate C , 0.0, 0.0 -> 2262
% INFO    : Updated Thermal Rating: on line 3551-2590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 6569-2973 : Rate B, Rate C , 0.0, 0.0 -> 60566
% INFO    : Updated Thermal Rating: on line 6569-1138 : Rate B, Rate C , 0.0, 0.0 -> 58336
% INFO    : Updated Thermal Rating: on line 3551-7376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4621
% INFO    : Updated Thermal Rating: on line 3290-4400 : Rate B, Rate C , 0.0, 0.0 -> 40168
% INFO    : Updated Thermal Rating: on line 3290-1606 : Rate B, Rate C , 0.0, 0.0 -> 41134
% INFO    : Updated Thermal Rating: on line 3446-3290 : Rate A, Rate B, Rate C , 1448.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 3290-5882 : Rate B, Rate C , 0.0, 0.0 -> 12207
% INFO    : Updated Thermal Rating: on line 3290-372 : Rate B, Rate C , 0.0, 0.0 -> 3612
% INFO    : Updated Thermal Rating: on line 291-3551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 291-6995 : Rate B, Rate C , 0.0, 0.0 -> 2976
% INFO    : Updated Thermal Rating: on line 291-3551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 291-3375 : Rate B, Rate C , 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on line 144-4195 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on line 2357-6251 : Rate B, Rate C , 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 2357-7953 : Rate B, Rate C , 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 6569-6468 : Rate B, Rate C , 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 6569-4195 : Rate B, Rate C , 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 6251-518 : Rate B, Rate C , 0.0, 0.0 -> 1869
% INFO    : Updated Thermal Rating: on line 6251-5343 : Rate B, Rate C , 0.0, 0.0 -> 1681
% INFO    : Updated Thermal Rating: on line 6251-2465 : Rate B, Rate C , 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on line 9230-3340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 9230-3340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 3599-202 : Rate B, Rate C , 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 3599-5468 : Rate B, Rate C , 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 7953-5343 : Rate B, Rate C , 0.0, 0.0 -> 1932
% INFO    : Updated Thermal Rating: on line 7107-2588 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 2989-5343 : Rate B, Rate C , 0.0, 0.0 -> 3976
% INFO    : Updated Thermal Rating: on line 2989-1884 : Rate B, Rate C , 0.0, 0.0 -> 1825
% INFO    : Updated Thermal Rating: on line 202-3551 : Rate B, Rate C , 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 202-3551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 5343-4195 : Rate A, Rate B, Rate C , 889.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 3340-2588 : Rate B, Rate C , 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 3340-2588 : Rate B, Rate C , 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 6007-1884 : Rate B, Rate C , 0.0, 0.0 -> 3280
% INFO    : Updated Thermal Rating: on line 6007-1884 : Rate B, Rate C , 0.0, 0.0 -> 3473
% INFO    : Updated Thermal Rating: on line 2588-5468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 488-6995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10571
% INFO    : Updated Thermal Rating: on line 6995-3375 : Rate B, Rate C , 0.0, 0.0 -> 3350
% INFO    : Updated Thermal Rating: on line 4107-9090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18210
% INFO    : Updated Thermal Rating: on line 5021-9090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11213
% INFO    : Updated Thermal Rating: on line 2657-5514 : Rate B, Rate C , 0.0, 0.0 -> 7266
% INFO    : Updated Thermal Rating: on line 2657-6986 : Rate B, Rate C , 0.0, 0.0 -> 7122
% INFO    : Updated Thermal Rating: on line 4107-2657 : Rate B, Rate C , 0.0, 0.0 -> 7209
% INFO    : Updated Thermal Rating: on line 5514-5784 : Rate B, Rate C , 0.0, 0.0 -> 77598
% INFO    : Updated Thermal Rating: on line 6986-8528 : Rate B, Rate C , 0.0, 0.0 -> 77598
% INFO    : Updated Thermal Rating: on line 818-5784 : Rate B, Rate C , 0.0, 0.0 -> 3711
% INFO    : Updated Thermal Rating: on line 818-8528 : Rate B, Rate C , 0.0, 0.0 -> 3308
% INFO    : Updated Thermal Rating: on line 4107-7194 : Rate B, Rate C , 0.0, 0.0 -> 18617
% INFO    : Updated Thermal Rating: on line 6234-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6234-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 6451-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6234-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6234-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8022-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 260-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5909-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 2828-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 5596-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 4099-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 629-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 3423-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6234-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8182-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 6718-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 4702-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 7500-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 1067-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3533-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 5440-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 2605-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 1971-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 1971-6234 : Rate B, Rate C , 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 6234-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 6234-1581 : Rate B, Rate C , 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 6655-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6307-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6451-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7410-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7410-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8022-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 260-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5909-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 2828-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5596-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 4099-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 629-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3423-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7410-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8182-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 6718-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 4702-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 7500-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 3533-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 5440-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 2605-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 1971-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 7410-1581 : Rate B, Rate C , 0.0, 0.0 -> 821
% INFO    : Updated Thermal Rating: on line 7410-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 6655-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6307-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5401-4334 : Rate B, Rate C , 0.0, 0.0 -> 5671
% INFO    : Updated Thermal Rating: on line 5401-5941 : Rate B, Rate C , 0.0, 0.0 -> 2689
% INFO    : Updated Thermal Rating: on line 6284-4334 : Rate B, Rate C , 0.0, 0.0 -> 5021
% INFO    : Updated Thermal Rating: on line 6284-5941 : Rate B, Rate C , 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on line 5401-6284 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5401-4334 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 5401-5941 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 324-5401 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 6284-4334 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 6284-5941 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 324-6284 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 4492-5178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6768
% INFO    : Updated Thermal Rating: on line 4492-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8250
% INFO    : Updated Thermal Rating: on line 6272-7643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6913
% INFO    : Updated Thermal Rating: on line 6272-5178 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 6272-7643 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 6272-6615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8425
% INFO    : Updated Thermal Rating: on line 4472-600 : Rate B, Rate C , 0.0, 0.0 -> 9212
% INFO    : Updated Thermal Rating: on line 4023-4472 : Rate B, Rate C , 0.0, 0.0 -> 1918
% INFO    : Updated Thermal Rating: on line 7786-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7786-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 7786-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 7786-7198 : Rate B, Rate C , 0.0, 0.0 -> 1474
% INFO    : Updated Thermal Rating: on line 7786-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7786-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7786-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 7786-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 7786-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on line 7786-3913 : Rate B, Rate C , 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 6212-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 6212-98 : Rate B, Rate C , 0.0, 0.0 -> 1502
% INFO    : Updated Thermal Rating: on line 6212-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6212-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6212-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 6212-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 6212-1085 : Rate B, Rate C , 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 6212-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 3727-7971 : Rate B, Rate C , 0.0, 0.0 -> 7205
% INFO    : Updated Thermal Rating: on line 2260-7971 : Rate B, Rate C , 0.0, 0.0 -> 4403
% INFO    : Updated Thermal Rating: on line 6160-5555 : Rate B, Rate C , 0.0, 0.0 -> 7697
% INFO    : Updated Thermal Rating: on line 6965-5555 : Rate B, Rate C , 0.0, 0.0 -> 6564
% INFO    : Updated Thermal Rating: on line 8342-3727 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 2511-3727 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 1161-3727 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 3102-3727 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 2016-3727 : Rate B, Rate C , 0.0, 0.0 -> 14476
% INFO    : Updated Thermal Rating: on line 8517-3727 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 6724-3727 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 8851-8553 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 8851-192 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 8851-3349 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 5495-8851 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 8851-6894 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 8851-9100 : Rate B, Rate C , 0.0, 0.0 -> 4399
% INFO    : Updated Thermal Rating: on line 8851-9100 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 8851-5717 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 8851-6222 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 8851-8465 : Rate B, Rate C , 0.0, 0.0 -> 2389
% INFO    : Updated Thermal Rating: on line 8851-8802 : Rate B, Rate C , 0.0, 0.0 -> 2343
% INFO    : Updated Thermal Rating: on line 8851-5717 : Rate B, Rate C , 0.0, 0.0 -> 4482
% INFO    : Updated Thermal Rating: on line 4012-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 4012-1029 : Rate B, Rate C , 0.0, 0.0 -> 629
% INFO    : Updated Thermal Rating: on line 4012-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 4012-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4012-1238 : Rate B, Rate C , 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 4012-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4012-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 4012-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 4012-276 : Rate B, Rate C , 0.0, 0.0 -> 2329
% INFO    : Updated Thermal Rating: on line 4012-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 4012-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4012-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4012-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 4012-3431 : Rate B, Rate C , 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 4012-4033 : Rate B, Rate C , 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 4012-5929 : Rate B, Rate C , 0.0, 0.0 -> 2074
% INFO    : Updated Thermal Rating: on line 4827-7601 : Rate B, Rate C , 0.0, 0.0 -> 6016
% INFO    : Updated Thermal Rating: on line 4827-1238 : Rate B, Rate C , 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 7601-1854 : Rate B, Rate C , 0.0, 0.0 -> 12843
% INFO    : Updated Thermal Rating: on line 4753-6221 : Rate B, Rate C , 0.0, 0.0 -> 6108
% INFO    : Updated Thermal Rating: on line 4753-438 : Rate B, Rate C , 0.0, 0.0 -> 3283
% INFO    : Updated Thermal Rating: on line 6221-1854 : Rate B, Rate C , 0.0, 0.0 -> 13061
% INFO    : Updated Thermal Rating: on line 8693-4214 : Rate B, Rate C , 0.0, 0.0 -> 17899
% INFO    : Updated Thermal Rating: on line 8693-4214 : Rate B, Rate C , 0.0, 0.0 -> 17601
% INFO    : Updated Thermal Rating: on line 7035-1066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16638
% INFO    : Updated Thermal Rating: on line 7035-7175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16976
% INFO    : Updated Thermal Rating: on line 1066-1522 : Rate B, Rate C , 0.0, 0.0 -> 9124
% INFO    : Updated Thermal Rating: on line 7175-5716 : Rate B, Rate C , 0.0, 0.0 -> 9308
% INFO    : Updated Thermal Rating: on line 7035-8421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11473
% INFO    : Updated Thermal Rating: on line 7035-1253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7170
% INFO    : Updated Thermal Rating: on line 7035-6657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11273
% INFO    : Updated Thermal Rating: on line 6171-2788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4077
% INFO    : Updated Thermal Rating: on line 6171-2608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 6171-7321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16692
% INFO    : Updated Thermal Rating: on line 6171-2608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1521
% INFO    : Updated Thermal Rating: on line 6171-7321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17008
% INFO    : Updated Thermal Rating: on line 7502-4101 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 7502-8342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6113
% INFO    : Updated Thermal Rating: on line 7502-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 7502-1522 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 4866-7502 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 6724-7502 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7502-8429 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 7816-7502 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 1150-7502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3321
% INFO    : Updated Thermal Rating: on line 5428-7502 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 4101-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 4101-2511 : Rate B, Rate C , 0.0, 0.0 -> 6244
% INFO    : Updated Thermal Rating: on line 4101-1522 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 4866-4101 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 6724-4101 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4101-9084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14022
% INFO    : Updated Thermal Rating: on line 4101-8429 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 7816-4101 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 5428-4101 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 8019-2102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1867
% INFO    : Updated Thermal Rating: on line 252-5719 : Rate B, Rate C , 0.0, 0.0 -> 1624
% INFO    : Updated Thermal Rating: on line 252-8498 : Rate B, Rate C , 0.0, 0.0 -> 4059
% INFO    : Updated Thermal Rating: on line 5719-7240 : Rate B, Rate C , 0.0, 0.0 -> 5991
% INFO    : Updated Thermal Rating: on line 8498-2071 : Rate B, Rate C , 0.0, 0.0 -> 3984
% INFO    : Updated Thermal Rating: on line 2071-2743 : Rate B, Rate C , 0.0, 0.0 -> 1406
% INFO    : Updated Thermal Rating: on line 8342-2511 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8342-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 1161-8342 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 3102-8342 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 2016-8342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2465
% INFO    : Updated Thermal Rating: on line 8517-8342 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 6724-8342 : Rate B, Rate C , 0.0, 0.0 -> 4757
% INFO    : Updated Thermal Rating: on line 6724-8342 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 2038-8342 : Rate B, Rate C , 0.0, 0.0 -> 9373
% INFO    : Updated Thermal Rating: on line 1161-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 3102-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 2511-1522 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8517-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 8517-2511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2509
% INFO    : Updated Thermal Rating: on line 4866-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6724-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6724-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 6724-2511 : Rate B, Rate C , 0.0, 0.0 -> 4857
% INFO    : Updated Thermal Rating: on line 8429-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7816-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 1165-2511 : Rate B, Rate C , 0.0, 0.0 -> 9218
% INFO    : Updated Thermal Rating: on line 5428-2511 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 182-2912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 182-2196 : Rate B, Rate C , 0.0, 0.0 -> 3554
% INFO    : Updated Thermal Rating: on line 1946-2912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 1946-2196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3610
% INFO    : Updated Thermal Rating: on line 4023-7102 : Rate B, Rate C , 0.0, 0.0 -> 89920
% INFO    : Updated Thermal Rating: on line 4023-4645 : Rate B, Rate C , 0.0, 0.0 -> 66966
% INFO    : Updated Thermal Rating: on line 8022-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 260-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 242-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7711-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7711-1067 : Rate B, Rate C , 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 4789-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 7592-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 7711-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 1085-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 3913-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 7711-6421 : Rate B, Rate C , 0.0, 0.0 -> 9676
% INFO    : Updated Thermal Rating: on line 192-8553 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 3349-8553 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5495-8553 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8553-6894 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 9100-8553 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 5717-8553 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 6222-8553 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8693-8553 : Rate B, Rate C , 0.0, 0.0 -> 14910
% INFO    : Updated Thermal Rating: on line 8693-8553 : Rate B, Rate C , 0.0, 0.0 -> 15262
% INFO    : Updated Thermal Rating: on line 7684-3860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17789
% INFO    : Updated Thermal Rating: on line 6715-5323 : Rate B, Rate C , 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on line 6715-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 6715-5323 : Rate B, Rate C , 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on line 5301-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 2237-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5323-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 7811-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 648-7811 : Rate B, Rate C , 0.0, 0.0 -> 4898
% INFO    : Updated Thermal Rating: on line 7445-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2388
% INFO    : Updated Thermal Rating: on line 648-7445 : Rate B, Rate C , 0.0, 0.0 -> 4809
% INFO    : Updated Thermal Rating: on line 9037-6584 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 6497-6584 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 4766-6584 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 6584-4296 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 6584-5611 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 4647-6584 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7483-6584 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 6584-4296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3180
% INFO    : Updated Thermal Rating: on line 7483-6584 : Rate B, Rate C , 0.0, 0.0 -> 4769
% INFO    : Updated Thermal Rating: on line 4478-6584 : Rate B, Rate C , 0.0, 0.0 -> 4977
% INFO    : Updated Thermal Rating: on line 6497-9037 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4766-9037 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 9037-5611 : Rate B, Rate C , 0.0, 0.0 -> 3118
% INFO    : Updated Thermal Rating: on line 9037-4296 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 9037-5611 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 4647-9037 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7483-9037 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 5301-6715 : Rate B, Rate C , 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 5301-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 2237-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 6715-7240 : Rate B, Rate C , 0.0, 0.0 -> 1403
% INFO    : Updated Thermal Rating: on line 6715-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 2237-6715 : Rate B, Rate C , 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 6715-4153 : Rate B, Rate C , 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 6978-6715 : Rate B, Rate C , 0.0, 0.0 -> 1687
% INFO    : Updated Thermal Rating: on line 7505-1918 : Rate B, Rate C , 0.0, 0.0 -> 12855
% INFO    : Updated Thermal Rating: on line 7505-1918 : Rate B, Rate C , 0.0, 0.0 -> 13867
% INFO    : Updated Thermal Rating: on line 5439-4296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15058
% INFO    : Updated Thermal Rating: on line 2222-5611 : Rate B, Rate C , 0.0, 0.0 -> 14783
% INFO    : Updated Thermal Rating: on line 6753-424 : Rate B, Rate C , 0.0, 0.0 -> 12578
% INFO    : Updated Thermal Rating: on line 6497-4766 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 4647-6497 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 5774-6497 : Rate B, Rate C , 0.0, 0.0 -> 12827
% INFO    : Updated Thermal Rating: on line 6497-7483 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 4709-3102 : Rate B, Rate C , 0.0, 0.0 -> 2191
% INFO    : Updated Thermal Rating: on line 4709-1079 : Rate B, Rate C , 0.0, 0.0 -> 17313
% INFO    : Updated Thermal Rating: on line 7954-3102 : Rate B, Rate C , 0.0, 0.0 -> 2150
% INFO    : Updated Thermal Rating: on line 7954-6847 : Rate B, Rate C , 0.0, 0.0 -> 17600
% INFO    : Updated Thermal Rating: on line 1161-6160 : Rate B, Rate C , 0.0, 0.0 -> 8165
% INFO    : Updated Thermal Rating: on line 1161-2990 : Rate B, Rate C , 0.0, 0.0 -> 7779
% INFO    : Updated Thermal Rating: on line 8517-2990 : Rate B, Rate C , 0.0, 0.0 -> 13310
% INFO    : Updated Thermal Rating: on line 1161-3102 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 8517-1161 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 6724-1161 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 7346-3102 : Rate B, Rate C , 0.0, 0.0 -> 4540
% INFO    : Updated Thermal Rating: on line 6724-7346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21012
% INFO    : Updated Thermal Rating: on line 9152-3102 : Rate B, Rate C , 0.0, 0.0 -> 4637
% INFO    : Updated Thermal Rating: on line 6724-9152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21581
% INFO    : Updated Thermal Rating: on line 8517-3102 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 6724-3102 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 4886-622 : Rate B, Rate C , 0.0, 0.0 -> 21883
% INFO    : Updated Thermal Rating: on line 8693-4886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24427
% INFO    : Updated Thermal Rating: on line 1593-6611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23684
% INFO    : Updated Thermal Rating: on line 8693-1593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23875
% INFO    : Updated Thermal Rating: on line 622-8404 : Rate B, Rate C , 0.0, 0.0 -> 4653
% INFO    : Updated Thermal Rating: on line 6611-2342 : Rate B, Rate C , 0.0, 0.0 -> 4749
% INFO    : Updated Thermal Rating: on line 4334-8404 : Rate B, Rate C , 0.0, 0.0 -> 13350
% INFO    : Updated Thermal Rating: on line 4334-2342 : Rate B, Rate C , 0.0, 0.0 -> 14381
% INFO    : Updated Thermal Rating: on line 1242-8929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4124
% INFO    : Updated Thermal Rating: on line 8929-7198 : Rate B, Rate C , 0.0, 0.0 -> 5547
% INFO    : Updated Thermal Rating: on line 1242-7457 : Rate B, Rate C , 0.0, 0.0 -> 4206
% INFO    : Updated Thermal Rating: on line 7457-98 : Rate B, Rate C , 0.0, 0.0 -> 5455
% INFO    : Updated Thermal Rating: on line 1242-1790 : Rate B, Rate C , 0.0, 0.0 -> 4296
% INFO    : Updated Thermal Rating: on line 1790-7198 : Rate B, Rate C , 0.0, 0.0 -> 6224
% INFO    : Updated Thermal Rating: on line 8929-7457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 1242-8929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 8929-7198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 8929-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 1242-7457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 7457-7198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 7457-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 4334-3631 : Rate B, Rate C , 0.0, 0.0 -> 14974
% INFO    : Updated Thermal Rating: on line 3631-6538 : Rate B, Rate C , 0.0, 0.0 -> 5136
% INFO    : Updated Thermal Rating: on line 7299-6152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4966
% INFO    : Updated Thermal Rating: on line 6152-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3211
% INFO    : Updated Thermal Rating: on line 4334-8614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2301
% INFO    : Updated Thermal Rating: on line 8614-491 : Rate B, Rate C , 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 4334-6137 : Rate B, Rate C , 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 6137-7545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2488
% INFO    : Updated Thermal Rating: on line 4334-5941 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 324-4334 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on line 4334-590 : Rate B, Rate C , 0.0, 0.0 -> 6270
% INFO    : Updated Thermal Rating: on line 5005-4334 : Rate B, Rate C , 0.0, 0.0 -> 12639
% INFO    : Updated Thermal Rating: on line 4334-2394 : Rate B, Rate C , 0.0, 0.0 -> 6152
% INFO    : Updated Thermal Rating: on line 818-2743 : Rate B, Rate C , 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 818-2743 : Rate B, Rate C , 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 7299-375 : Rate B, Rate C , 0.0, 0.0 -> 14904
% INFO    : Updated Thermal Rating: on line 5021-375 : Rate B, Rate C , 0.0, 0.0 -> 10591
% INFO    : Updated Thermal Rating: on line 6657-7440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3974
% INFO    : Updated Thermal Rating: on line 8421-8006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4055
% INFO    : Updated Thermal Rating: on line 5716-4345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 1522-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4540
% INFO    : Updated Thermal Rating: on line 4866-1522 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 6724-1522 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8429-1522 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 7816-1522 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 5428-1522 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 4298-3361 : Rate B, Rate C , 0.0, 0.0 -> 25805
% INFO    : Updated Thermal Rating: on line 9211-3361 : Rate B, Rate C , 0.0, 0.0 -> 14203
% INFO    : Updated Thermal Rating: on line 92-6848 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 92-5523 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4023-92 : Rate B, Rate C , 0.0, 0.0 -> 4742
% INFO    : Updated Thermal Rating: on line 2891-92 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4737-92 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 63-92 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 9211-92 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 8336-92 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 2724-92 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 1268-92 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 630-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3995
% INFO    : Updated Thermal Rating: on line 6369-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17527
% INFO    : Updated Thermal Rating: on line 8429-4345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17922
% INFO    : Updated Thermal Rating: on line 5102-5178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7627
% INFO    : Updated Thermal Rating: on line 1811-7643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7793
% INFO    : Updated Thermal Rating: on line 5178-7643 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5301-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5301-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5301-3739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39724
% INFO    : Updated Thermal Rating: on line 5301-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 2237-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 4714-7512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28598
% INFO    : Updated Thermal Rating: on line 4921-4714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6115
% INFO    : Updated Thermal Rating: on line 8099-1452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30821
% INFO    : Updated Thermal Rating: on line 2444-8099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6257
% INFO    : Updated Thermal Rating: on line 5682-3862 : Rate B, Rate C , 0.0, 0.0 -> 7893
% INFO    : Updated Thermal Rating: on line 6848-5682 : Rate B, Rate C , 0.0, 0.0 -> 30551
% INFO    : Updated Thermal Rating: on line 3862-3976 : Rate B, Rate C , 0.0, 0.0 -> 13619
% INFO    : Updated Thermal Rating: on line 3976-2157 : Rate B, Rate C , 0.0, 0.0 -> 38340
% INFO    : Updated Thermal Rating: on line 2157-8948 : Rate B, Rate C , 0.0, 0.0 -> 15513
% INFO    : Updated Thermal Rating: on line 8948-7160 : Rate B, Rate C , 0.0, 0.0 -> 87440
% INFO    : Updated Thermal Rating: on line 63-7160 : Rate B, Rate C , 0.0, 0.0 -> 4111
% INFO    : Updated Thermal Rating: on line 6848-5523 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6848-5523 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 2891-6848 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4737-6848 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 63-6848 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 9211-6848 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 7082-6848 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8336-6848 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2724-6848 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 1268-6848 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 2891-5523 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4737-5523 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 63-5523 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 9211-5523 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 7082-5523 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8336-5523 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2724-5523 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 1268-5523 : Rate B, Rate C , 0.0, 0.0 -> 3685
% INFO    : Updated Thermal Rating: on line 1268-5523 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 6095-5941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21235
% INFO    : Updated Thermal Rating: on line 475-5941 : Rate B, Rate C , 0.0, 0.0 -> 18849
% INFO    : Updated Thermal Rating: on line 324-5941 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 6469-7941 : Rate B, Rate C , 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 4153-6469 : Rate B, Rate C , 0.0, 0.0 -> 5335
% INFO    : Updated Thermal Rating: on line 7941-2743 : Rate B, Rate C , 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 2632-6485 : Rate B, Rate C , 0.0, 0.0 -> 9748
% INFO    : Updated Thermal Rating: on line 2632-6485 : Rate B, Rate C , 0.0, 0.0 -> 9572
% INFO    : Updated Thermal Rating: on line 192-8465 : Rate B, Rate C , 0.0, 0.0 -> 48391
% INFO    : Updated Thermal Rating: on line 8465-1582 : Rate B, Rate C , 0.0, 0.0 -> 8337
% INFO    : Updated Thermal Rating: on line 3349-8802 : Rate B, Rate C , 0.0, 0.0 -> 47664
% INFO    : Updated Thermal Rating: on line 8802-2046 : Rate B, Rate C , 0.0, 0.0 -> 8516
% INFO    : Updated Thermal Rating: on line 192-3349 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 5495-192 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 192-6894 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 192-9100 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 192-5717 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 6222-192 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5495-3349 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3349-6894 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3349-9100 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 3349-5717 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 6222-3349 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1029-3431 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1029-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 1029-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1029-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1029-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 1029-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 3330-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 1029-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8938-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 1177-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 3431-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 3431-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 3431-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 3431-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 3330-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 3431-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8938-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 1177-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7690-1452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149739
% INFO    : Updated Thermal Rating: on line 7690-2074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11943
% INFO    : Updated Thermal Rating: on line 3270-7512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136820
% INFO    : Updated Thermal Rating: on line 3270-8868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11727
% INFO    : Updated Thermal Rating: on line 1242-7198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 1242-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 7924-6554 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 2440-6554 : Rate B, Rate C , 0.0, 0.0 -> 9499
% INFO    : Updated Thermal Rating: on line 4261-6554 : Rate B, Rate C , 0.0, 0.0 -> 10271
% INFO    : Updated Thermal Rating: on line 4766-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3148
% INFO    : Updated Thermal Rating: on line 4766-2277 : Rate B, Rate C , 0.0, 0.0 -> 5636
% INFO    : Updated Thermal Rating: on line 4766-4296 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4766-5611 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4647-4766 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 8762-4766 : Rate B, Rate C , 0.0, 0.0 -> 9859
% INFO    : Updated Thermal Rating: on line 7483-4766 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 4766-9003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3215
% INFO    : Updated Thermal Rating: on line 9088-9003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4888
% INFO    : Updated Thermal Rating: on line 4501-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4801
% INFO    : Updated Thermal Rating: on line 2016-8517 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 2016-7924 : Rate B, Rate C , 0.0, 0.0 -> 3446
% INFO    : Updated Thermal Rating: on line 8517-6558 : Rate B, Rate C , 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 6724-8517 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 1079-4723 : Rate B, Rate C , 0.0, 0.0 -> 14241
% INFO    : Updated Thermal Rating: on line 7924-1079 : Rate B, Rate C , 0.0, 0.0 -> 8845
% INFO    : Updated Thermal Rating: on line 1079-1148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42870
% INFO    : Updated Thermal Rating: on line 6847-600 : Rate B, Rate C , 0.0, 0.0 -> 13933
% INFO    : Updated Thermal Rating: on line 8355-6847 : Rate B, Rate C , 0.0, 0.0 -> 8539
% INFO    : Updated Thermal Rating: on line 6847-7116 : Rate B, Rate C , 0.0, 0.0 -> 8124
% INFO    : Updated Thermal Rating: on line 7198-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 2912-2196 : Rate B, Rate C , 0.0, 0.0 -> 7910
% INFO    : Updated Thermal Rating: on line 2912-7631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5429
% INFO    : Updated Thermal Rating: on line 8349-6286 : Rate B, Rate C , 0.0, 0.0 -> 5523
% INFO    : Updated Thermal Rating: on line 2196-6286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7760
% INFO    : Updated Thermal Rating: on line 6724-4866 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 4866-3267 : Rate B, Rate C , 0.0, 0.0 -> 6081
% INFO    : Updated Thermal Rating: on line 4866-8429 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 4866-7816 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 4866-5428 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 5021-7194 : Rate B, Rate C , 0.0, 0.0 -> 12118
% INFO    : Updated Thermal Rating: on line 6508-4023 : Rate B, Rate C , 0.0, 0.0 -> 47664
% INFO    : Updated Thermal Rating: on line 4023-4723 : Rate B, Rate C , 0.0, 0.0 -> 1636
% INFO    : Updated Thermal Rating: on line 4023-8336 : Rate B, Rate C , 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 4023-1918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5824
% INFO    : Updated Thermal Rating: on line 4023-8336 : Rate B, Rate C , 0.0, 0.0 -> 1978
% INFO    : Updated Thermal Rating: on line 4023-6667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3690
% INFO    : Updated Thermal Rating: on line 6508-3052 : Rate B, Rate C , 0.0, 0.0 -> 18500
% INFO    : Updated Thermal Rating: on line 1807-5102 : Rate B, Rate C , 0.0, 0.0 -> 4121
% INFO    : Updated Thermal Rating: on line 1807-491 : Rate B, Rate C , 0.0, 0.0 -> 6691
% INFO    : Updated Thermal Rating: on line 6108-1811 : Rate B, Rate C , 0.0, 0.0 -> 4202
% INFO    : Updated Thermal Rating: on line 6108-7545 : Rate B, Rate C , 0.0, 0.0 -> 6833
% INFO    : Updated Thermal Rating: on line 5102-1811 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5102-1811 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5102-3647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92545
% INFO    : Updated Thermal Rating: on line 7816-5102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6272
% INFO    : Updated Thermal Rating: on line 4041-1811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6388
% INFO    : Updated Thermal Rating: on line 241-1238 : Rate B, Rate C , 0.0, 0.0 -> 1041
% INFO    : Updated Thermal Rating: on line 241-438 : Rate B, Rate C , 0.0, 0.0 -> 3346
% INFO    : Updated Thermal Rating: on line 3118-2631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3989
% INFO    : Updated Thermal Rating: on line 3118-8934 : Rate B, Rate C , 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 4597-1144 : Rate B, Rate C , 0.0, 0.0 -> 3558
% INFO    : Updated Thermal Rating: on line 4597-6173 : Rate B, Rate C , 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 6440-7631 : Rate B, Rate C , 0.0, 0.0 -> 1256
% INFO    : Updated Thermal Rating: on line 1189-8349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1189-8349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5136
% INFO    : Updated Thermal Rating: on line 6440-1189 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on line 1238-5820 : Rate B, Rate C , 0.0, 0.0 -> 10874
% INFO    : Updated Thermal Rating: on line 1238-5820 : Rate B, Rate C , 0.0, 0.0 -> 10702
% INFO    : Updated Thermal Rating: on line 4033-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4033-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 4033-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 4033-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 3330-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4033-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 8938-4033 : Rate B, Rate C , 0.0, 0.0 -> 783
% INFO    : Updated Thermal Rating: on line 8938-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 1177-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 4033-1962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15063
% INFO    : Updated Thermal Rating: on line 1238-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 1238-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 3330-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 1238-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 8938-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 1177-1238 : Rate B, Rate C , 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 1177-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 1238-1944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14789
% INFO    : Updated Thermal Rating: on line 2631-1144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 3332-2631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 3332-1144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 1667-4119 : Rate B, Rate C , 0.0, 0.0 -> 6829
% INFO    : Updated Thermal Rating: on line 8193-4119 : Rate B, Rate C , 0.0, 0.0 -> 4653
% INFO    : Updated Thermal Rating: on line 1667-2306 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 3514-2306 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 3514-2306 : Rate B, Rate C , 0.0, 0.0 -> 6701
% INFO    : Updated Thermal Rating: on line 8193-2306 : Rate B, Rate C , 0.0, 0.0 -> 5022
% INFO    : Updated Thermal Rating: on line 1667-3514 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1667-3514 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 1667-5963 : Rate B, Rate C , 0.0, 0.0 -> 89920
% INFO    : Updated Thermal Rating: on line 9046-1667 : Rate B, Rate C , 0.0, 0.0 -> 26583
% INFO    : Updated Thermal Rating: on line 3514-7771 : Rate B, Rate C , 0.0, 0.0 -> 92545
% INFO    : Updated Thermal Rating: on line 4498-5963 : Rate B, Rate C , 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 4498-7771 : Rate B, Rate C , 0.0, 0.0 -> 3554
% INFO    : Updated Thermal Rating: on line 7440-969 : Rate B, Rate C , 0.0, 0.0 -> 33686
% INFO    : Updated Thermal Rating: on line 6946-7240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7330
% INFO    : Updated Thermal Rating: on line 9053-4153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7478
% INFO    : Updated Thermal Rating: on line 8762-6095 : Rate B, Rate C , 0.0, 0.0 -> 5187
% INFO    : Updated Thermal Rating: on line 7483-2277 : Rate B, Rate C , 0.0, 0.0 -> 5552
% INFO    : Updated Thermal Rating: on line 7483-475 : Rate B, Rate C , 0.0, 0.0 -> 5447
% INFO    : Updated Thermal Rating: on line 5495-6222 : Rate B, Rate C , 0.0, 0.0 -> 45607
% INFO    : Updated Thermal Rating: on line 5495-6894 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 5495-9100 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5495-5717 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5495-6222 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 4296-5611 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 7483-4296 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7483-5611 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6451-5598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 6451-5598 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 6451-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 6451-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 6451-4488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6451-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 6451-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 6451-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6451-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6451-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 6451-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 6451-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 6451-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 6451-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 8182-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6718-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6451-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6451-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6451-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 3533-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 5440-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 2605-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6451-1581 : Rate B, Rate C , 0.0, 0.0 -> 2135
% INFO    : Updated Thermal Rating: on line 6451-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 6451-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 6451-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 6451-1581 : Rate B, Rate C , 0.0, 0.0 -> 2178
% INFO    : Updated Thermal Rating: on line 5167-5531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20953
% INFO    : Updated Thermal Rating: on line 5167-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21506
% INFO    : Updated Thermal Rating: on line 6485-1493 : Rate B, Rate C , 0.0, 0.0 -> 1886
% INFO    : Updated Thermal Rating: on line 5680-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5680-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 4488-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8022-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 260-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5909-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 2828-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 5596-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 4099-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 629-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 3423-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 2955-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 8182-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6718-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 4702-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7500-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1067-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 3533-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5440-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2605-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1971-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5680-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 6655-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 6307-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 4488-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8022-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 260-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5909-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 2828-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5596-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 4099-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 629-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 3423-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 2955-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 8182-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6718-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 4702-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7500-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1067-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 3533-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5440-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2605-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2895-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 6655-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 6307-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 6307-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1186
% INFO    : Updated Thermal Rating: on line 6485-4811 : Rate B, Rate C , 0.0, 0.0 -> 2528
% INFO    : Updated Thermal Rating: on line 4811-4849 : Rate B, Rate C , 0.0, 0.0 -> 3233
% INFO    : Updated Thermal Rating: on line 6485-3012 : Rate B, Rate C , 0.0, 0.0 -> 2897
% INFO    : Updated Thermal Rating: on line 6485-3012 : Rate B, Rate C , 0.0, 0.0 -> 2481
% INFO    : Updated Thermal Rating: on line 3012-4849 : Rate B, Rate C , 0.0, 0.0 -> 2858
% INFO    : Updated Thermal Rating: on line 438-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 438-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 3330-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 1587-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 8938-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 1177-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7684-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3032
% INFO    : Updated Thermal Rating: on line 3330-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 1587-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 8938-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 1177-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 6558-2440 : Rate B, Rate C , 0.0, 0.0 -> 17471
% INFO    : Updated Thermal Rating: on line 8355-4261 : Rate B, Rate C , 0.0, 0.0 -> 17095
% INFO    : Updated Thermal Rating: on line 8647-2074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57093
% INFO    : Updated Thermal Rating: on line 5566-8868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61641
% INFO    : Updated Thermal Rating: on line 7093-7207 : Rate B, Rate C , 0.0, 0.0 -> 157864
% INFO    : Updated Thermal Rating: on line 7093-7207 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 7093-491 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 7093-4332 : Rate B, Rate C , 0.0, 0.0 -> 15576
% INFO    : Updated Thermal Rating: on line 7093-324 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5862-7093 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4052-7093 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7207-491 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 7207-2513 : Rate B, Rate C , 0.0, 0.0 -> 9696
% INFO    : Updated Thermal Rating: on line 7207-324 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5862-7207 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4052-7207 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 3330-276 : Rate B, Rate C , 0.0, 0.0 -> 3072
% INFO    : Updated Thermal Rating: on line 3330-7412 : Rate B, Rate C , 0.0, 0.0 -> 3132
% INFO    : Updated Thermal Rating: on line 321-7412 : Rate B, Rate C , 0.0, 0.0 -> 6926
% INFO    : Updated Thermal Rating: on line 321-5929 : Rate B, Rate C , 0.0, 0.0 -> 6170
% INFO    : Updated Thermal Rating: on line 6432-3330 : Rate B, Rate C , 0.0, 0.0 -> 3760
% INFO    : Updated Thermal Rating: on line 3330-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 8938-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 1177-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 3330-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 8193-6615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19031
% INFO    : Updated Thermal Rating: on line 8193-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18707
% INFO    : Updated Thermal Rating: on line 3052-4298 : Rate B, Rate C , 0.0, 0.0 -> 15175
% INFO    : Updated Thermal Rating: on line 7254-5878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59111
% INFO    : Updated Thermal Rating: on line 4488-4401 : Rate B, Rate C , 0.0, 0.0 -> 60231
% INFO    : Updated Thermal Rating: on line 4488-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 4488-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 4488-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 4488-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 4488-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 4488-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 4488-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 8182-4488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6718-4488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 4488-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4488-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 4488-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5878-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on line 4401-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 2891-4737 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2891-4737 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 7352-2891 : Rate B, Rate C , 0.0, 0.0 -> 50711
% INFO    : Updated Thermal Rating: on line 63-2891 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 9211-2891 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 7082-2891 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8336-2891 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 2724-2891 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1268-2891 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5566-4737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49913
% INFO    : Updated Thermal Rating: on line 63-4737 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 9211-4737 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 8336-4737 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 2724-4737 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 1268-4737 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7910-7352 : Rate B, Rate C , 0.0, 0.0 -> 13672
% INFO    : Updated Thermal Rating: on line 8244-8647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14752
% INFO    : Updated Thermal Rating: on line 8332-6894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10463
% INFO    : Updated Thermal Rating: on line 324-8332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18217
% INFO    : Updated Thermal Rating: on line 5048-6894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10673
% INFO    : Updated Thermal Rating: on line 2133-5048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18643
% INFO    : Updated Thermal Rating: on line 9100-6894 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5717-6894 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6222-6894 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 8938-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 1177-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 1587-5820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3790
% INFO    : Updated Thermal Rating: on line 2788-9077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1329
% INFO    : Updated Thermal Rating: on line 640-7099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 640-6440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 640-6440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1690
% INFO    : Updated Thermal Rating: on line 7099-6440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 7099-6440 : Rate B, Rate C , 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 491-3476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19989
% INFO    : Updated Thermal Rating: on line 324-491 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5862-491 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 4052-491 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 7545-5272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19632
% INFO    : Updated Thermal Rating: on line 7545-4332 : Rate B, Rate C , 0.0, 0.0 -> 19275
% INFO    : Updated Thermal Rating: on line 7545-3950 : Rate B, Rate C , 0.0, 0.0 -> 142990
% INFO    : Updated Thermal Rating: on line 8934-6173 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8934-6173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 6130-8934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 3780-8934 : Rate B, Rate C , 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 1623-6173 : Rate B, Rate C , 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on line 7440-3476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11319
% INFO    : Updated Thermal Rating: on line 8006-5272 : Rate B, Rate C , 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 4501-2513 : Rate B, Rate C , 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 8938-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8938-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 8938-5142 : Rate B, Rate C , 0.0, 0.0 -> 13496
% INFO    : Updated Thermal Rating: on line 3332-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3332-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 3332-6440 : Rate B, Rate C , 0.0, 0.0 -> 2690
% INFO    : Updated Thermal Rating: on line 3332-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 2196-3332 : Rate B, Rate C , 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 4085-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 6130-6440 : Rate B, Rate C , 0.0, 0.0 -> 2743
% INFO    : Updated Thermal Rating: on line 6130-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4085-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 8022-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8022-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 242-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8022-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8022-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8022-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8022-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8022-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4702-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7500-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8022-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 8022-1067 : Rate B, Rate C , 0.0, 0.0 -> 1896
% INFO    : Updated Thermal Rating: on line 3533-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 8022-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8022-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5440-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5440-8022 : Rate B, Rate C , 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 2605-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8022-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8022-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 8022-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8022-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 242-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 260-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 260-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 260-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 260-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 260-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4702-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7500-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 260-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 3533-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 260-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 260-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5440-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2605-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2605-260 : Rate B, Rate C , 0.0, 0.0 -> 811
% INFO    : Updated Thermal Rating: on line 260-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 260-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 260-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 260-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4052-2133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6746
% INFO    : Updated Thermal Rating: on line 5862-324 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 5862-324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6621
% INFO    : Updated Thermal Rating: on line 4052-324 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 8022-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 836
% INFO    : Updated Thermal Rating: on line 648-5531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9496
% INFO    : Updated Thermal Rating: on line 648-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9696
% INFO    : Updated Thermal Rating: on line 648-1484 : Rate B, Rate C , 0.0, 0.0 -> 23815
% INFO    : Updated Thermal Rating: on line 5909-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5909-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on line 5909-5596 : Rate B, Rate C , 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 5909-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 629-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 3423-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 5909-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 8182-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 6718-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 4702-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7500-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 3533-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5440-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2605-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1971-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 5909-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5909-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 5909-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 2828-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 2828-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 2828-4099 : Rate B, Rate C , 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 629-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 3423-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 2828-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 8182-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 6718-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 4702-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7500-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 3533-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5440-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1971-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 2828-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2828-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 2828-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 6724-7492 : Rate B, Rate C , 0.0, 0.0 -> 4020
% INFO    : Updated Thermal Rating: on line 6724-8429 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6724-7816 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 6724-5428 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 6724-1525 : Rate B, Rate C , 0.0, 0.0 -> 3946
% INFO    : Updated Thermal Rating: on line 8256-1525 : Rate B, Rate C , 0.0, 0.0 -> 13480
% INFO    : Updated Thermal Rating: on line 2309-7492 : Rate B, Rate C , 0.0, 0.0 -> 2243
% INFO    : Updated Thermal Rating: on line 9211-63 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 63-8336 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 63-2724 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 1268-63 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 242-316 : Rate B, Rate C , 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 242-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 3533-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 242-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 242-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 242-7592 : Rate B, Rate C , 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 5440-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2605-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 242-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 242-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 242-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 242-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 63-2724 : Rate B, Rate C , 0.0, 0.0 -> 3127
% INFO    : Updated Thermal Rating: on line 7454-7706 : Rate B, Rate C , 0.0, 0.0 -> 7523
% INFO    : Updated Thermal Rating: on line 5440-7454 : Rate B, Rate C , 0.0, 0.0 -> 942
% INFO    : Updated Thermal Rating: on line 7706-4646 : Rate B, Rate C , 0.0, 0.0 -> 1827
% INFO    : Updated Thermal Rating: on line 4646-4288 : Rate B, Rate C , 0.0, 0.0 -> 3390
% INFO    : Updated Thermal Rating: on line 4288-3935 : Rate B, Rate C , 0.0, 0.0 -> 8983
% INFO    : Updated Thermal Rating: on line 3935-6716 : Rate B, Rate C , 0.0, 0.0 -> 3528
% INFO    : Updated Thermal Rating: on line 6716-316 : Rate B, Rate C , 0.0, 0.0 -> 20179
% INFO    : Updated Thermal Rating: on line 7039-7135 : Rate B, Rate C , 0.0, 0.0 -> 9872
% INFO    : Updated Thermal Rating: on line 7039-7135 : Rate B, Rate C , 0.0, 0.0 -> 10673
% INFO    : Updated Thermal Rating: on line 8429-732 : Rate B, Rate C , 0.0, 0.0 -> 18322
% INFO    : Updated Thermal Rating: on line 4294-732 : Rate B, Rate C , 0.0, 0.0 -> 8200
% INFO    : Updated Thermal Rating: on line 6369-2545 : Rate B, Rate C , 0.0, 0.0 -> 16364
% INFO    : Updated Thermal Rating: on line 4294-2545 : Rate B, Rate C , 0.0, 0.0 -> 8178
% INFO    : Updated Thermal Rating: on line 5596-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5596-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 629-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 629-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 3423-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 5596-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 4424-5596 : Rate B, Rate C , 0.0, 0.0 -> 9565
% INFO    : Updated Thermal Rating: on line 8182-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 6718-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4702-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7500-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1067-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3533-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1971-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5596-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5596-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 5596-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 629-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 3423-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 4099-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 7189-4099 : Rate B, Rate C , 0.0, 0.0 -> 9364
% INFO    : Updated Thermal Rating: on line 8182-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 6718-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 4702-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7500-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1067-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3533-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1971-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4099-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4099-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 4099-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 4099-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 4647-5774 : Rate B, Rate C , 0.0, 0.0 -> 8135
% INFO    : Updated Thermal Rating: on line 4647-3583 : Rate B, Rate C , 0.0, 0.0 -> 8315
% INFO    : Updated Thermal Rating: on line 3578-6753 : Rate B, Rate C , 0.0, 0.0 -> 7991
% INFO    : Updated Thermal Rating: on line 3578-606 : Rate B, Rate C , 0.0, 0.0 -> 8493
% INFO    : Updated Thermal Rating: on line 4647-7483 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6485-7135 : Rate B, Rate C , 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 7135-624 : Rate B, Rate C , 0.0, 0.0 -> 3798
% INFO    : Updated Thermal Rating: on line 6485-7135 : Rate B, Rate C , 0.0, 0.0 -> 3267
% INFO    : Updated Thermal Rating: on line 7135-624 : Rate B, Rate C , 0.0, 0.0 -> 3876
% INFO    : Updated Thermal Rating: on line 629-3423 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 629-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 629-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 629-2955 : Rate B, Rate C , 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 8182-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6718-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 629-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3533-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1971-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 629-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 629-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 629-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 3423-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 3423-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1492
% INFO    : Updated Thermal Rating: on line 8182-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6718-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 3423-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3533-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1971-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3423-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 3423-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 3423-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 8182-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6718-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 1067-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3533-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1971-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2955-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6655-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 6307-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 9211-8336 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 9211-2724 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 9211-1268 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 9211-3522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8819
% INFO    : Updated Thermal Rating: on line 2440-5380 : Rate B, Rate C , 0.0, 0.0 -> 24012
% INFO    : Updated Thermal Rating: on line 8182-6718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8182-6718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 8182-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 8182-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 8182-7500 : Rate A, Rate B, Rate C , 572.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 3533-8182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5440-8182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2605-8182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8182-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 8182-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8182-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8182-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6718-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 6718-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 3533-6718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 5440-6718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2605-6718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6718-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 6718-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6718-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6718-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4849-7082 : Rate B, Rate C , 0.0, 0.0 -> 6031
% INFO    : Updated Thermal Rating: on line 1268-7082 : Rate B, Rate C , 0.0, 0.0 -> 1884
% INFO    : Updated Thermal Rating: on line 1268-7082 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 2075-4884 : Rate B, Rate C , 0.0, 0.0 -> 6787
% INFO    : Updated Thermal Rating: on line 2075-5768 : Rate B, Rate C , 0.0, 0.0 -> 4536
% INFO    : Updated Thermal Rating: on line 9100-8693 : Rate B, Rate C , 0.0, 0.0 -> 9050
% INFO    : Updated Thermal Rating: on line 5717-8693 : Rate B, Rate C , 0.0, 0.0 -> 8898
% INFO    : Updated Thermal Rating: on line 9100-5717 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 6222-9100 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6222-5717 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4702-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4702-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3533-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 5440-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 2605-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 2605-4702 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 1971-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 4702-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 3533-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 5440-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 2605-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 1971-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 7500-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 4884-1950 : Rate B, Rate C , 0.0, 0.0 -> 29997
% INFO    : Updated Thermal Rating: on line 8244-8336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16832
% INFO    : Updated Thermal Rating: on line 1067-5598 : Rate B, Rate C , 0.0, 0.0 -> 53713
% INFO    : Updated Thermal Rating: on line 7910-8336 : Rate B, Rate C , 0.0, 0.0 -> 14883
% INFO    : Updated Thermal Rating: on line 4742-8027 : Rate B, Rate C , 0.0, 0.0 -> 29439
% INFO    : Updated Thermal Rating: on line 4742-8336 : Rate B, Rate C , 0.0, 0.0 -> 157153
% INFO    : Updated Thermal Rating: on line 7717-1739 : Rate B, Rate C , 0.0, 0.0 -> 7689
% INFO    : Updated Thermal Rating: on line 7717-1067 : Rate B, Rate C , 0.0, 0.0 -> 55676
% INFO    : Updated Thermal Rating: on line 8866-2066 : Rate B, Rate C , 0.0, 0.0 -> 7858
% INFO    : Updated Thermal Rating: on line 1067-8866 : Rate B, Rate C , 0.0, 0.0 -> 56662
% INFO    : Updated Thermal Rating: on line 8336-1950 : Rate B, Rate C , 0.0, 0.0 -> 157153
% INFO    : Updated Thermal Rating: on line 8027-4860 : Rate B, Rate C , 0.0, 0.0 -> 2870
% INFO    : Updated Thermal Rating: on line 1739-2516 : Rate B, Rate C , 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 2066-8696 : Rate B, Rate C , 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on line 2724-8336 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1268-8336 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3533-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 4789-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7592-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5440-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2605-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1067-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1067-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 112-1067 : Rate B, Rate C , 0.0, 0.0 -> 25926
% INFO    : Updated Thermal Rating: on line 1067-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1067-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1493-1058 : Rate B, Rate C , 0.0, 0.0 -> 20817
% INFO    : Updated Thermal Rating: on line 4860-1893 : Rate B, Rate C , 0.0, 0.0 -> 7096
% INFO    : Updated Thermal Rating: on line 2516-6451 : Rate B, Rate C , 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 8696-6451 : Rate B, Rate C , 0.0, 0.0 -> 1480
% INFO    : Updated Thermal Rating: on line 5768-1058 : Rate B, Rate C , 0.0, 0.0 -> 7258
% INFO    : Updated Thermal Rating: on line 1893-1493 : Rate B, Rate C , 0.0, 0.0 -> 21235
% INFO    : Updated Thermal Rating: on line 3533-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3533-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5440-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 2605-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 2605-3533 : Rate B, Rate C , 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 3533-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 3533-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 3533-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 3533-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4535-6180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6437
% INFO    : Updated Thermal Rating: on line 8779-6180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7585
% INFO    : Updated Thermal Rating: on line 2724-4389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6585
% INFO    : Updated Thermal Rating: on line 8779-4389 : Rate B, Rate C , 0.0, 0.0 -> 7750
% INFO    : Updated Thermal Rating: on line 4535-7443 : Rate B, Rate C , 0.0, 0.0 -> 4274
% INFO    : Updated Thermal Rating: on line 3522-4535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8855
% INFO    : Updated Thermal Rating: on line 2444-4535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8510
% INFO    : Updated Thermal Rating: on line 2724-5650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4906
% INFO    : Updated Thermal Rating: on line 1268-2724 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 4921-2724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8387
% INFO    : Updated Thermal Rating: on line 630-2724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8545
% INFO    : Updated Thermal Rating: on line 4789-7592 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4789-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 5440-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2605-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4789-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 4789-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4789-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 4789-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5440-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2605-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7592-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 7592-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7592-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7592-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 4732-5650 : Rate B, Rate C , 0.0, 0.0 -> 9837
% INFO    : Updated Thermal Rating: on line 2932-7443 : Rate B, Rate C , 0.0, 0.0 -> 9806
% INFO    : Updated Thermal Rating: on line 3267-9084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55112
% INFO    : Updated Thermal Rating: on line 5428-3267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3963
% INFO    : Updated Thermal Rating: on line 5440-2605 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5440-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5440-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5440-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 5440-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5440-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2605-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2605-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 2605-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2605-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6421-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1085-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 3913-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 1971-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1971-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1971-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6655-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 6307-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 3780-1258 : Rate B, Rate C , 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on line 1623-1258 : Rate B, Rate C , 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 4085-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 5862-4052 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5862-4052 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 5862-8193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2307
% INFO    : Updated Thermal Rating: on line 4052-8193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2043
% INFO    : Updated Thermal Rating: on line 1918-4206 : Rate B, Rate C , 0.0, 0.0 -> 9083
% INFO    : Updated Thermal Rating: on line 1085-3913 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1085-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 1085-6049 : Rate B, Rate C , 0.0, 0.0 -> 15646
% INFO    : Updated Thermal Rating: on line 6049-7524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 7524-4411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2294
% INFO    : Updated Thermal Rating: on line 4411-7218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2462
% INFO    : Updated Thermal Rating: on line 7218-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 6369-2038 : Rate B, Rate C , 0.0, 0.0 -> 7518
% INFO    : Updated Thermal Rating: on line 7816-8429 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 8429-1165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7500
% INFO    : Updated Thermal Rating: on line 5428-8429 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 2608-9077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2608-9077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2360
% INFO    : Updated Thermal Rating: on line 9077-7321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1586
% INFO    : Updated Thermal Rating: on line 7816-1150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7780
% INFO    : Updated Thermal Rating: on line 4041-5428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6980
% INFO    : Updated Thermal Rating: on line 7816-5428 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 3264-2038 : Rate B, Rate C , 0.0, 0.0 -> 51343
% INFO    : Updated Thermal Rating: on line 779-1165 : Rate B, Rate C , 0.0, 0.0 -> 48391
% INFO    : Updated Thermal Rating: on line 4085-3780 : Rate B, Rate C , 0.0, 0.0 -> 66310
% INFO    : Updated Thermal Rating: on line 4085-1623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67437
% INFO    : Updated Thermal Rating: on line 6655-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6655-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 8593-7650 : Rate B, Rate C , 0.0, 0.0 -> 41748
% INFO    : Updated Thermal Rating: on line 8593-7490 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 8593-7490 : Rate B, Rate C , 0.0, 0.0 -> 38703
% INFO    : Updated Thermal Rating: on line 6811-7650 : Rate B, Rate C , 0.0, 0.0 -> 33415
% INFO    : Updated Thermal Rating: on line 6811-7650 : Rate B, Rate C , 0.0, 0.0 -> 29418
% INFO    : Updated Thermal Rating: on line 61-6811 : Rate B, Rate C , 0.0, 0.0 -> 37037
% INFO    : Updated Thermal Rating: on line 61-6811 : Rate B, Rate C , 0.0, 0.0 -> 38808
% INFO    : Updated Thermal Rating: on line 7650-7490 : Rate B, Rate C , 0.0, 0.0 -> 18371
% INFO    : Updated Thermal Rating: on line 61-2532 : Rate B, Rate C , 0.0, 0.0 -> 16473
% INFO    : Updated Thermal Rating: on line 61-2532 : Rate B, Rate C , 0.0, 0.0 -> 16228
% INFO    : Updated Thermal Rating: on line 61-7934 : Rate B, Rate C , 0.0, 0.0 -> 9843
% INFO    : Updated Thermal Rating: on line 61-7934 : Rate B, Rate C , 0.0, 0.0 -> 9703
% INFO    : Updated Thermal Rating: on line 7490-4349 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 7490-4349 : Rate B, Rate C , 0.0, 0.0 -> 25805
% INFO    : Updated Thermal Rating: on line 7490-4349 : Rate B, Rate C , 0.0, 0.0 -> 26451
% INFO    : Updated Thermal Rating: on line 4349-4498 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1532
% INFO    : Updated Thermal Rating: on line 4349-197 : Rate B, Rate C , 0.0, 0.0 -> 6638
% INFO    : Updated Thermal Rating: on line 3606-2094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3606-2094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 3606-7741 : Rate B, Rate C , 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 2094-7741 : Rate B, Rate C , 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on line 2883-6197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 2883-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 2883-4971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 1120-2883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 2883-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1867
% INFO    : Updated Thermal Rating: on line 2883-1627 : Rate B, Rate C , 0.0, 0.0 -> 3246
% INFO    : Updated Thermal Rating: on line 3537-2883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 2883-5869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 3716-5543 : Rate B, Rate C , 0.0, 0.0 -> 157153
% INFO    : Updated Thermal Rating: on line 3716-959 : Rate B, Rate C , 0.0, 0.0 -> 9159
% INFO    : Updated Thermal Rating: on line 3716-959 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 3716-2583 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 6274-3716 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 6274-3716 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 4637-5543 : Rate B, Rate C , 0.0, 0.0 -> 12461
% INFO    : Updated Thermal Rating: on line 6274-5543 : Rate B, Rate C , 0.0, 0.0 -> 14709
% INFO    : Updated Thermal Rating: on line 6197-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2264
% INFO    : Updated Thermal Rating: on line 6197-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 4971-6197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 1120-6197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 1120-6197 : Rate B, Rate C , 0.0, 0.0 -> 2449
% INFO    : Updated Thermal Rating: on line 5325-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 4167-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 4167-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 2663-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5739
% INFO    : Updated Thermal Rating: on line 2663-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 4804-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 7602-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 56-397 : Rate B, Rate C , 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 1624-56 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 56-7127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 56-9165 : Rate B, Rate C , 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 56-9165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 5088-6296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1137
% INFO    : Updated Thermal Rating: on line 5104-5088 : Rate B, Rate C , 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 5088-8287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3215
% INFO    : Updated Thermal Rating: on line 2300-5088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4113-2420 : Rate B, Rate C , 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 4113-2420 : Rate B, Rate C , 0.0, 0.0 -> 2361
% INFO    : Updated Thermal Rating: on line 6274-959 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 6274-959 : Rate B, Rate C , 0.0, 0.0 -> 12464
% INFO    : Updated Thermal Rating: on line 8855-1663 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1492
% INFO    : Updated Thermal Rating: on line 4226-1663 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 6777-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5422
% INFO    : Updated Thermal Rating: on line 4971-3944 : Rate B, Rate C , 0.0, 0.0 -> 3167
% INFO    : Updated Thermal Rating: on line 1120-3944 : Rate B, Rate C , 0.0, 0.0 -> 4173
% INFO    : Updated Thermal Rating: on line 853-3944 : Rate B, Rate C , 0.0, 0.0 -> 9702
% INFO    : Updated Thermal Rating: on line 8855-1663 : Rate B, Rate C , 0.0, 0.0 -> 1433
% INFO    : Updated Thermal Rating: on line 1128-1663 : Rate B, Rate C , 0.0, 0.0 -> 5203
% INFO    : Updated Thermal Rating: on line 6977-1663 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1088
% INFO    : Updated Thermal Rating: on line 7055-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20155
% INFO    : Updated Thermal Rating: on line 9086-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21833
% INFO    : Updated Thermal Rating: on line 4971-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on line 1120-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 2630-827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2630-827 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 8454-2630 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 8292-2630 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 4158-2630 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 3319-2630 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 9116-2630 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 2630-7424 : Rate B, Rate C , 0.0, 0.0 -> 3806
% INFO    : Updated Thermal Rating: on line 2630-4113 : Rate B, Rate C , 0.0, 0.0 -> 2608
% INFO    : Updated Thermal Rating: on line 2630-6193 : Rate B, Rate C , 0.0, 0.0 -> 2616
% INFO    : Updated Thermal Rating: on line 8454-827 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 8292-827 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4158-827 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 3319-827 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 9116-827 : Rate B, Rate C , 0.0, 0.0 -> 7110
% INFO    : Updated Thermal Rating: on line 9116-827 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 4718-827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10201
% INFO    : Updated Thermal Rating: on line 327-4637 : Rate B, Rate C , 0.0, 0.0 -> 12603
% INFO    : Updated Thermal Rating: on line 2906-4637 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 1624-3761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 1624-5325 : Rate B, Rate C , 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 1624-7127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 1624-7127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 1624-9165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 8855-7617 : Rate B, Rate C , 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 3761-4167 : Rate B, Rate C , 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 3761-9165 : Rate B, Rate C , 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on line 8855-4226 : Rate B, Rate C , 0.0, 0.0 -> 2289
% INFO    : Updated Thermal Rating: on line 8199-5360 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8199-5360 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3254-8199 : Rate B, Rate C , 0.0, 0.0 -> 3209
% INFO    : Updated Thermal Rating: on line 8199-4946 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 8199-4946 : Rate B, Rate C , 0.0, 0.0 -> 4863
% INFO    : Updated Thermal Rating: on line 8199-8968 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 8199-4840 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 8199-5972 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 5972-5360 : Rate B, Rate C , 0.0, 0.0 -> 4458
% INFO    : Updated Thermal Rating: on line 5360-4946 : Rate B, Rate C , 0.0, 0.0 -> 5015
% INFO    : Updated Thermal Rating: on line 5360-4946 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 5360-8968 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 5360-4840 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 5360-5972 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 7170-1425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14441
% INFO    : Updated Thermal Rating: on line 3835-4366 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 3835-2385 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 3835-7920 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 3835-7920 : Rate B, Rate C , 0.0, 0.0 -> 2997
% INFO    : Updated Thermal Rating: on line 3835-2080 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 3835-7424 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 3835-6193 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 3835-6193 : Rate B, Rate C , 0.0, 0.0 -> 8939
% INFO    : Updated Thermal Rating: on line 7957-652 : Rate B, Rate C , 0.0, 0.0 -> 3551
% INFO    : Updated Thermal Rating: on line 7957-3303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1711
% INFO    : Updated Thermal Rating: on line 4366-2385 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4366-2385 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 1588-4366 : Rate B, Rate C , 0.0, 0.0 -> 7700
% INFO    : Updated Thermal Rating: on line 4366-7920 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 4366-2080 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 4366-1425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21405
% INFO    : Updated Thermal Rating: on line 4366-7424 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 8968-4366 : Rate B, Rate C , 0.0, 0.0 -> 5364
% INFO    : Updated Thermal Rating: on line 6193-4366 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 1009-7957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7388
% INFO    : Updated Thermal Rating: on line 8113-7957 : Rate B, Rate C , 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 3005-2385 : Rate B, Rate C , 0.0, 0.0 -> 22466
% INFO    : Updated Thermal Rating: on line 1184-2385 : Rate B, Rate C , 0.0, 0.0 -> 21999
% INFO    : Updated Thermal Rating: on line 2385-7920 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on line 2385-7920 : Rate B, Rate C , 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 2385-2080 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on line 2385-7424 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 2906-2385 : Rate B, Rate C , 0.0, 0.0 -> 5785
% INFO    : Updated Thermal Rating: on line 6193-2385 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 7966-4206 : Rate B, Rate C , 0.0, 0.0 -> 2009
% INFO    : Updated Thermal Rating: on line 2080-6667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3958
% INFO    : Updated Thermal Rating: on line 8454-8292 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8454-8292 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 4158-8454 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 4158-8454 : Rate B, Rate C , 0.0, 0.0 -> 3624
% INFO    : Updated Thermal Rating: on line 3319-8454 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 9116-8454 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 4158-8292 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 3319-8292 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 9116-8292 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 8292-4113 : Rate B, Rate C , 0.0, 0.0 -> 8058
% INFO    : Updated Thermal Rating: on line 5325-4167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on line 2663-5325 : Rate B, Rate C , 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 2663-5325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 5325-4804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 5325-7602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 2663-4167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 4167-4804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 4167-7602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 8620-2493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 8620-6586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17618
% INFO    : Updated Thermal Rating: on line 2493-8916 : Rate B, Rate C , 0.0, 0.0 -> 17975
% INFO    : Updated Thermal Rating: on line 7966-5100 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 7966-1588 : Rate B, Rate C , 0.0, 0.0 -> 3684
% INFO    : Updated Thermal Rating: on line 7966-1588 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 7966-1994 : Rate B, Rate C , 0.0, 0.0 -> 2209
% INFO    : Updated Thermal Rating: on line 2890-7966 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 1675-652 : Rate B, Rate C , 0.0, 0.0 -> 3549
% INFO    : Updated Thermal Rating: on line 1675-3539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 417-3539 : Rate B, Rate C , 0.0, 0.0 -> 3691
% INFO    : Updated Thermal Rating: on line 3835-7920 : Rate B, Rate C , 0.0, 0.0 -> 2838
% INFO    : Updated Thermal Rating: on line 3835-7424 : Rate B, Rate C , 0.0, 0.0 -> 3320
% INFO    : Updated Thermal Rating: on line 4158-3319 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4158-3319 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 4158-9116 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 3319-9116 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 6066-3319 : Rate B, Rate C , 0.0, 0.0 -> 2290
% INFO    : Updated Thermal Rating: on line 8899-3319 : Rate B, Rate C , 0.0, 0.0 -> 1380
% INFO    : Updated Thermal Rating: on line 5100-1588 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5100-1588 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 5100-1994 : Rate B, Rate C , 0.0, 0.0 -> 4755
% INFO    : Updated Thermal Rating: on line 2890-5100 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 2890-1588 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 8520-8916 : Rate B, Rate C , 0.0, 0.0 -> 1429
% INFO    : Updated Thermal Rating: on line 8520-3303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6186
% INFO    : Updated Thermal Rating: on line 2145-7055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 2145-9086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 1120-2145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17303
% INFO    : Updated Thermal Rating: on line 7055-9086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 8968-6777 : Rate B, Rate C , 0.0, 0.0 -> 2285
% INFO    : Updated Thermal Rating: on line 2906-1128 : Rate B, Rate C , 0.0, 0.0 -> 2681
% INFO    : Updated Thermal Rating: on line 7920-2080 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7920-2080 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 7920-7424 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 6193-7920 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 2080-7424 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 6193-2080 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 782-4804 : Rate B, Rate C , 0.0, 0.0 -> 4972
% INFO    : Updated Thermal Rating: on line 5017-782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9029
% INFO    : Updated Thermal Rating: on line 7171-782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8889
% INFO    : Updated Thermal Rating: on line 1508-782 : Rate B, Rate C , 0.0, 0.0 -> 1934
% INFO    : Updated Thermal Rating: on line 3254-4226 : Rate B, Rate C , 0.0, 0.0 -> 2418
% INFO    : Updated Thermal Rating: on line 951-4226 : Rate B, Rate C , 0.0, 0.0 -> 27846
% INFO    : Updated Thermal Rating: on line 6020-1346 : Rate B, Rate C , 0.0, 0.0 -> 11250
% INFO    : Updated Thermal Rating: on line 1181-1346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10115
% INFO    : Updated Thermal Rating: on line 1346-7602 : Rate B, Rate C , 0.0, 0.0 -> 5659
% INFO    : Updated Thermal Rating: on line 1839-7617 : Rate B, Rate C , 0.0, 0.0 -> 28379
% INFO    : Updated Thermal Rating: on line 1120-4971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 7127-4971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 9116-6274 : Rate B, Rate C , 0.0, 0.0 -> 4267
% INFO    : Updated Thermal Rating: on line 4164-4840 : Rate B, Rate C , 0.0, 0.0 -> 157153
% INFO    : Updated Thermal Rating: on line 3254-6605 : Rate B, Rate C , 0.0, 0.0 -> 12874
% INFO    : Updated Thermal Rating: on line 6274-2583 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 6274-2583 : Rate B, Rate C , 0.0, 0.0 -> 8180
% INFO    : Updated Thermal Rating: on line 6297-8287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2694
% INFO    : Updated Thermal Rating: on line 6297-6296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2941
% INFO    : Updated Thermal Rating: on line 4634-2138 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4634-2138 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 4634-2906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9967
% INFO    : Updated Thermal Rating: on line 4634-2906 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 4634-6274 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 2138-2906 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 2138-6274 : Rate B, Rate C , 0.0, 0.0 -> 2737
% INFO    : Updated Thermal Rating: on line 2138-6274 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 327-8968 : Rate B, Rate C , 0.0, 0.0 -> 6615
% INFO    : Updated Thermal Rating: on line 2901-5622 : Rate B, Rate C , 0.0, 0.0 -> 2153
% INFO    : Updated Thermal Rating: on line 3539-652 : Rate B, Rate C , 0.0, 0.0 -> 2071
% INFO    : Updated Thermal Rating: on line 3537-8916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5329
% INFO    : Updated Thermal Rating: on line 6777-1994 : Rate B, Rate C , 0.0, 0.0 -> 8258
% INFO    : Updated Thermal Rating: on line 2890-1994 : Rate B, Rate C , 0.0, 0.0 -> 14124
% INFO    : Updated Thermal Rating: on line 5869-6586 : Rate B, Rate C , 0.0, 0.0 -> 2276
% INFO    : Updated Thermal Rating: on line 1994-7914 : Rate B, Rate C , 0.0, 0.0 -> 13375
% INFO    : Updated Thermal Rating: on line 6193-7424 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 4946-2906 : Rate B, Rate C , 0.0, 0.0 -> 3756
% INFO    : Updated Thermal Rating: on line 4946-8968 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 4946-8968 : Rate B, Rate C , 0.0, 0.0 -> 3604
% INFO    : Updated Thermal Rating: on line 4946-4840 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 4946-5972 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 6274-2906 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 7731-2906 : Rate B, Rate C , 0.0, 0.0 -> 12855
% INFO    : Updated Thermal Rating: on line 8968-4840 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 8968-5972 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 2663-4804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 2663-7602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4804-7602 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4804-7602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 4840-5972 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4840-5972 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 7767-1627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13537
% INFO    : Updated Thermal Rating: on line 5869-7767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5735
% INFO    : Updated Thermal Rating: on line 1627-8753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45102
% INFO    : Updated Thermal Rating: on line 6541-1627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 7127-9165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7127-9165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 3537-5869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 8333-8553 : Rate B, Rate C , 0.0, 0.0 -> 3396
% INFO    : Updated Thermal Rating: on line 6538-8553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3467
% INFO    : Updated Thermal Rating: on line 4859-6894 : Rate B, Rate C , 0.0, 0.0 -> 6995
% INFO    : Updated Thermal Rating: on line 6894-6458 : Rate B, Rate C , 0.0, 0.0 -> 2510
% INFO    : Updated Thermal Rating: on line 6668-6894 : Rate B, Rate C , 0.0, 0.0 -> 7135
% INFO    : Updated Thermal Rating: on line 6894-1243 : Rate B, Rate C , 0.0, 0.0 -> 1896
% INFO    : Updated Thermal Rating: on line 6538-8333 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6538-8333 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 6538-4859 : Rate B, Rate C , 0.0, 0.0 -> 5560
% INFO    : Updated Thermal Rating: on line 8333-6668 : Rate B, Rate C , 0.0, 0.0 -> 5465
% INFO    : Updated Thermal Rating: on line 4859-6668 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4859-6668 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 590-4859 : Rate B, Rate C , 0.0, 0.0 -> 6090
% INFO    : Updated Thermal Rating: on line 2394-6668 : Rate B, Rate C , 0.0, 0.0 -> 6196
% INFO    : Updated Thermal Rating: on line 590-2394 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 590-2394 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 3090-459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21143
% INFO    : Updated Thermal Rating: on line 5894-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32102
% INFO    : Updated Thermal Rating: on line 5433-3934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5433-3934 : Rate B, Rate C , 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on line 6830-5433 : Rate B, Rate C , 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 388-5433 : Rate B, Rate C , 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 5433-476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2997
% INFO    : Updated Thermal Rating: on line 4256-5896 : Rate B, Rate C , 0.0, 0.0 -> 1736
% INFO    : Updated Thermal Rating: on line 2439-4256 : Rate B, Rate C , 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 4256-8451 : Rate B, Rate C , 0.0, 0.0 -> 14273
% INFO    : Updated Thermal Rating: on line 4256-8451 : Rate B, Rate C , 0.0, 0.0 -> 14510
% INFO    : Updated Thermal Rating: on line 3149-6227 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 6227-1214 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 1253-6227 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 5528-6227 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 4786-6227 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 6027-6227 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 6027-6227 : Rate B, Rate C , 0.0, 0.0 -> 3738
% INFO    : Updated Thermal Rating: on line 4294-6227 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 5528-6227 : Rate B, Rate C , 0.0, 0.0 -> 2460
% INFO    : Updated Thermal Rating: on line 8541-1614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134762
% INFO    : Updated Thermal Rating: on line 4593-8541 : Rate B, Rate C , 0.0, 0.0 -> 3352
% INFO    : Updated Thermal Rating: on line 8541-9200 : Rate B, Rate C , 0.0, 0.0 -> 100039
% INFO    : Updated Thermal Rating: on line 4593-6418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3854
% INFO    : Updated Thermal Rating: on line 6418-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 4593-6418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 5228-1927 : Rate B, Rate C , 0.0, 0.0 -> 35618
% INFO    : Updated Thermal Rating: on line 1622-459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48510
% INFO    : Updated Thermal Rating: on line 8216-459 : Rate B, Rate C , 0.0, 0.0 -> 2838
% INFO    : Updated Thermal Rating: on line 8216-459 : Rate B, Rate C , 0.0, 0.0 -> 2787
% INFO    : Updated Thermal Rating: on line 459-853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 8073-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22316
% INFO    : Updated Thermal Rating: on line 5779-1927 : Rate B, Rate C , 0.0, 0.0 -> 4218
% INFO    : Updated Thermal Rating: on line 5779-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4121
% INFO    : Updated Thermal Rating: on line 1432-1927 : Rate B, Rate C , 0.0, 0.0 -> 1661
% INFO    : Updated Thermal Rating: on line 1160-2647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3155-1160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10528
% INFO    : Updated Thermal Rating: on line 3155-2647 : Rate B, Rate C , 0.0, 0.0 -> 10723
% INFO    : Updated Thermal Rating: on line 5673-4785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2498
% INFO    : Updated Thermal Rating: on line 5673-4785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2804
% INFO    : Updated Thermal Rating: on line 6407-4785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22903
% INFO    : Updated Thermal Rating: on line 4105-4785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23392
% INFO    : Updated Thermal Rating: on line 8516-1293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12380
% INFO    : Updated Thermal Rating: on line 4471-7097 : Rate B, Rate C , 0.0, 0.0 -> 23826
% INFO    : Updated Thermal Rating: on line 8516-7097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 7655-7097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 7748-5779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 7748-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 6997-7748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 7748-2614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1011
% INFO    : Updated Thermal Rating: on line 8639-7748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 5580-7748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 7748-5324 : Rate B, Rate C , 0.0, 0.0 -> 2750
% INFO    : Updated Thermal Rating: on line 8113-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 8113-8798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on line 1657-8113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 8778-8113 : Rate B, Rate C , 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on line 6977-1825 : Rate B, Rate C , 0.0, 0.0 -> 125947
% INFO    : Updated Thermal Rating: on line 5152-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41734
% INFO    : Updated Thermal Rating: on line 1004-6661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 1004-2413 : Rate B, Rate C , 0.0, 0.0 -> 5017
% INFO    : Updated Thermal Rating: on line 7430-9095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 7430-2413 : Rate B, Rate C , 0.0, 0.0 -> 4990
% INFO    : Updated Thermal Rating: on line 5943-571 : Rate B, Rate C , 0.0, 0.0 -> 40229
% INFO    : Updated Thermal Rating: on line 5943-6948 : Rate B, Rate C , 0.0, 0.0 -> 15386
% INFO    : Updated Thermal Rating: on line 7125-571 : Rate B, Rate C , 0.0, 0.0 -> 43585
% INFO    : Updated Thermal Rating: on line 7125-8123 : Rate B, Rate C , 0.0, 0.0 -> 5594
% INFO    : Updated Thermal Rating: on line 4474-1214 : Rate B, Rate C , 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 4466-571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3234
% INFO    : Updated Thermal Rating: on line 6321-571 : Rate B, Rate C , 0.0, 0.0 -> 6433
% INFO    : Updated Thermal Rating: on line 571-4496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14275
% INFO    : Updated Thermal Rating: on line 3655-1400 : Rate B, Rate C , 0.0, 0.0 -> 9199
% INFO    : Updated Thermal Rating: on line 7116-1400 : Rate B, Rate C , 0.0, 0.0 -> 3387
% INFO    : Updated Thermal Rating: on line 3249-1400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3967
% INFO    : Updated Thermal Rating: on line 3116-3249 : Rate B, Rate C , 0.0, 0.0 -> 18941
% INFO    : Updated Thermal Rating: on line 1400-8187 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1400-8187 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 1323-8187 : Rate B, Rate C , 0.0, 0.0 -> 9318
% INFO    : Updated Thermal Rating: on line 6830-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4600
% INFO    : Updated Thermal Rating: on line 1855-2903 : Rate B, Rate C , 0.0, 0.0 -> 4698
% INFO    : Updated Thermal Rating: on line 7220-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2791
% INFO    : Updated Thermal Rating: on line 4879-3116 : Rate B, Rate C , 0.0, 0.0 -> 16041
% INFO    : Updated Thermal Rating: on line 2755-3116 : Rate B, Rate C , 0.0, 0.0 -> 15881
% INFO    : Updated Thermal Rating: on line 1323-5380 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 1323-5380 : Rate B, Rate C , 0.0, 0.0 -> 11428
% INFO    : Updated Thermal Rating: on line 3655-5380 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 8346-8816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 8346-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 4593-8346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10872
% INFO    : Updated Thermal Rating: on line 8816-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4593-8816 : Rate B, Rate C , 0.0, 0.0 -> 11088
% INFO    : Updated Thermal Rating: on line 8602-3905 : Rate B, Rate C , 0.0, 0.0 -> 4404
% INFO    : Updated Thermal Rating: on line 8602-683 : Rate B, Rate C , 0.0, 0.0 -> 4865
% INFO    : Updated Thermal Rating: on line 7451-3905 : Rate B, Rate C , 0.0, 0.0 -> 4252
% INFO    : Updated Thermal Rating: on line 3905-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 3905-1147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87286
% INFO    : Updated Thermal Rating: on line 3905-3947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77250
% INFO    : Updated Thermal Rating: on line 3905-2655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3285
% INFO    : Updated Thermal Rating: on line 3905-540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 3905-683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 3905-3854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 3905-8624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114188
% INFO    : Updated Thermal Rating: on line 2433-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17129
% INFO    : Updated Thermal Rating: on line 4593-2433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2678
% INFO    : Updated Thermal Rating: on line 2712-2433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6948
% INFO    : Updated Thermal Rating: on line 2944-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16554
% INFO    : Updated Thermal Rating: on line 4593-2944 : Rate B, Rate C , 0.0, 0.0 -> 2728
% INFO    : Updated Thermal Rating: on line 2712-2944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7489
% INFO    : Updated Thermal Rating: on line 4593-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 4593-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 4593-7997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 4593-2610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 4593-8033 : Rate B, Rate C , 0.0, 0.0 -> 4283
% INFO    : Updated Thermal Rating: on line 8216-822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on line 8216-6452 : Rate B, Rate C , 0.0, 0.0 -> 2499
% INFO    : Updated Thermal Rating: on line 6997-5779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 6997-5779 : Rate B, Rate C , 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 5779-9225 : Rate B, Rate C , 0.0, 0.0 -> 2545
% INFO    : Updated Thermal Rating: on line 3116-7731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1642
% INFO    : Updated Thermal Rating: on line 3116-6343 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1476
% INFO    : Updated Thermal Rating: on line 3116-7731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1744
% INFO    : Updated Thermal Rating: on line 3116-9160 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1429
% INFO    : Updated Thermal Rating: on line 7116-3116 : Rate B, Rate C , 0.0, 0.0 -> 2760
% INFO    : Updated Thermal Rating: on line 3116-873 : Rate A, Rate B, Rate C , 1843.0, 0.0, 0.0 -> 1539
% INFO    : Updated Thermal Rating: on line 4466-1993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5406
% INFO    : Updated Thermal Rating: on line 4466-9198 : Rate B, Rate C , 0.0, 0.0 -> 14299
% INFO    : Updated Thermal Rating: on line 4466-2784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13990
% INFO    : Updated Thermal Rating: on line 4466-6886 : Rate B, Rate C , 0.0, 0.0 -> 5972
% INFO    : Updated Thermal Rating: on line 4466-8479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5510
% INFO    : Updated Thermal Rating: on line 4466-3321 : Rate B, Rate C , 0.0, 0.0 -> 2565
% INFO    : Updated Thermal Rating: on line 4466-7161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5366
% INFO    : Updated Thermal Rating: on line 6470-79 : Rate B, Rate C , 0.0, 0.0 -> 11436
% INFO    : Updated Thermal Rating: on line 6470-798 : Rate B, Rate C , 0.0, 0.0 -> 33771
% INFO    : Updated Thermal Rating: on line 9154-8270 : Rate B, Rate C , 0.0, 0.0 -> 18906
% INFO    : Updated Thermal Rating: on line 9154-8270 : Rate B, Rate C , 0.0, 0.0 -> 19249
% INFO    : Updated Thermal Rating: on line 3772-5491 : Rate B, Rate C , 0.0, 0.0 -> 3286
% INFO    : Updated Thermal Rating: on line 3772-7725 : Rate B, Rate C , 0.0, 0.0 -> 3151
% INFO    : Updated Thermal Rating: on line 1943-5491 : Rate B, Rate C , 0.0, 0.0 -> 3355
% INFO    : Updated Thermal Rating: on line 1943-9143 : Rate B, Rate C , 0.0, 0.0 -> 3220
% INFO    : Updated Thermal Rating: on line 3772-1943 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3772-7725 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 3772-9143 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 680-3772 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 3772-7715 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 3772-5387 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 1943-7725 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 1943-9143 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 680-1943 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 1943-7715 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 1943-5387 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 476-8955 : Rate B, Rate C , 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 476-8955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1062
% INFO    : Updated Thermal Rating: on line 6981-8955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 3934-8955 : Rate B, Rate C , 0.0, 0.0 -> 3170
% INFO    : Updated Thermal Rating: on line 3176-8955 : Rate B, Rate C , 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on line 8725-6965 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 6906-8725 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 5754-8725 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 5754-8725 : Rate B, Rate C , 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 2260-8725 : Rate B, Rate C , 0.0, 0.0 -> 3439
% INFO    : Updated Thermal Rating: on line 330-8725 : Rate B, Rate C , 0.0, 0.0 -> 2444
% INFO    : Updated Thermal Rating: on line 6906-6965 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 6906-6965 : Rate B, Rate C , 0.0, 0.0 -> 1985
% INFO    : Updated Thermal Rating: on line 5754-6965 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 7781-6965 : Rate B, Rate C , 0.0, 0.0 -> 2638
% INFO    : Updated Thermal Rating: on line 7116-1148 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 7116-1148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9468
% INFO    : Updated Thermal Rating: on line 1690-4140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2385
% INFO    : Updated Thermal Rating: on line 4140-2300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 7324-3709 : Rate B, Rate C , 0.0, 0.0 -> 8416
% INFO    : Updated Thermal Rating: on line 7324-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7435
% INFO    : Updated Thermal Rating: on line 7324-5324 : Rate B, Rate C , 0.0, 0.0 -> 2740
% INFO    : Updated Thermal Rating: on line 842-3709 : Rate B, Rate C , 0.0, 0.0 -> 9029
% INFO    : Updated Thermal Rating: on line 842-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8158
% INFO    : Updated Thermal Rating: on line 842-5324 : Rate B, Rate C , 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 3709-5184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43458
% INFO    : Updated Thermal Rating: on line 3709-1359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39503
% INFO    : Updated Thermal Rating: on line 3709-7335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128848
% INFO    : Updated Thermal Rating: on line 3709-867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123896
% INFO    : Updated Thermal Rating: on line 8639-3709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43808
% INFO    : Updated Thermal Rating: on line 5580-3709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43428
% INFO    : Updated Thermal Rating: on line 657-4154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1972
% INFO    : Updated Thermal Rating: on line 4154-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 4154-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 4154-3479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 4154-5232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 4154-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 3777-4154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 5261-4154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 4154-7620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 4154-7620 : Rate B, Rate C , 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 7444-6083 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 7444-6083 : Rate B, Rate C , 0.0, 0.0 -> 5437
% INFO    : Updated Thermal Rating: on line 4471-6973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 17-4471 : Rate B, Rate C , 0.0, 0.0 -> 4385
% INFO    : Updated Thermal Rating: on line 2112-4471 : Rate B, Rate C , 0.0, 0.0 -> 4472
% INFO    : Updated Thermal Rating: on line 4471-8516 : Rate B, Rate C , 0.0, 0.0 -> 4311
% INFO    : Updated Thermal Rating: on line 4471-8516 : Rate B, Rate C , 0.0, 0.0 -> 4385
% INFO    : Updated Thermal Rating: on line 657-8699 : Rate B, Rate C , 0.0, 0.0 -> 5970
% INFO    : Updated Thermal Rating: on line 7451-6321 : Rate B, Rate C , 0.0, 0.0 -> 3035
% INFO    : Updated Thermal Rating: on line 7451-8544 : Rate B, Rate C , 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 7451-4854 : Rate B, Rate C , 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 7451-3261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 7451-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 7451-6321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 7451-8915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3074
% INFO    : Updated Thermal Rating: on line 7451-3261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 4121-7028 : Rate B, Rate C , 0.0, 0.0 -> 8178
% INFO    : Updated Thermal Rating: on line 4121-798 : Rate B, Rate C , 0.0, 0.0 -> 13669
% INFO    : Updated Thermal Rating: on line 4121-1116 : Rate B, Rate C , 0.0, 0.0 -> 13372
% INFO    : Updated Thermal Rating: on line 4121-2429 : Rate B, Rate C , 0.0, 0.0 -> 2934
% INFO    : Updated Thermal Rating: on line 2443-8516 : Rate B, Rate C , 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 2443-8552 : Rate B, Rate C , 0.0, 0.0 -> 2553
% INFO    : Updated Thermal Rating: on line 309-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 309-5896 : Rate B, Rate C , 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 309-5149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20196
% INFO    : Updated Thermal Rating: on line 309-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 309-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 309-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 309-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 8451-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 683-309 : Rate B, Rate C , 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 7652-6808 : Rate B, Rate C , 0.0, 0.0 -> 2334
% INFO    : Updated Thermal Rating: on line 7652-6808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2381
% INFO    : Updated Thermal Rating: on line 4675-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155017
% INFO    : Updated Thermal Rating: on line 3202-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100595
% INFO    : Updated Thermal Rating: on line 3552-6864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4490
% INFO    : Updated Thermal Rating: on line 3552-5528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11595
% INFO    : Updated Thermal Rating: on line 1706-3149 : Rate B, Rate C , 0.0, 0.0 -> 11523
% INFO    : Updated Thermal Rating: on line 1706-1214 : Rate B, Rate C , 0.0, 0.0 -> 13188
% INFO    : Updated Thermal Rating: on line 1706-5528 : Rate B, Rate C , 0.0, 0.0 -> 11350
% INFO    : Updated Thermal Rating: on line 3149-1214 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 1253-3149 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 3149-5528 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 3149-4786 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 6027-3149 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 4294-3149 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 8639-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on line 5580-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 9160-6413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8255
% INFO    : Updated Thermal Rating: on line 9160-6413 : Rate B, Rate C , 0.0, 0.0 -> 8380
% INFO    : Updated Thermal Rating: on line 8638-7714 : Rate B, Rate C , 0.0, 0.0 -> 35865
% INFO    : Updated Thermal Rating: on line 6336-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 3479-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 8638-5232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 8638-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 3777-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 5261-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 7620-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 886-9190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56662
% INFO    : Updated Thermal Rating: on line 7997-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 886-2610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 3038-9190 : Rate B, Rate C , 0.0, 0.0 -> 14444
% INFO    : Updated Thermal Rating: on line 7997-7714 : Rate B, Rate C , 0.0, 0.0 -> 4953
% INFO    : Updated Thermal Rating: on line 7997-9190 : Rate B, Rate C , 0.0, 0.0 -> 6036
% INFO    : Updated Thermal Rating: on line 5812-2610 : Rate B, Rate C , 0.0, 0.0 -> 2982
% INFO    : Updated Thermal Rating: on line 532-2029 : Rate B, Rate C , 0.0, 0.0 -> 10042
% INFO    : Updated Thermal Rating: on line 532-8033 : Rate B, Rate C , 0.0, 0.0 -> 2633
% INFO    : Updated Thermal Rating: on line 6973-8516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9857
% INFO    : Updated Thermal Rating: on line 6973-8552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 7609-4151 : Rate B, Rate C , 0.0, 0.0 -> 8871
% INFO    : Updated Thermal Rating: on line 7944-1992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9047
% INFO    : Updated Thermal Rating: on line 1657-7944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1327
% INFO    : Updated Thermal Rating: on line 7652-4854 : Rate B, Rate C , 0.0, 0.0 -> 7606
% INFO    : Updated Thermal Rating: on line 7652-6438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9047
% INFO    : Updated Thermal Rating: on line 388-7652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3500
% INFO    : Updated Thermal Rating: on line 7652-8544 : Rate B, Rate C , 0.0, 0.0 -> 7439
% INFO    : Updated Thermal Rating: on line 1855-7652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3832
% INFO    : Updated Thermal Rating: on line 6336-2705 : Rate B, Rate C , 0.0, 0.0 -> 8742
% INFO    : Updated Thermal Rating: on line 2705-8699 : Rate B, Rate C , 0.0, 0.0 -> 4808
% INFO    : Updated Thermal Rating: on line 8960-7318 : Rate B, Rate C , 0.0, 0.0 -> 60345
% INFO    : Updated Thermal Rating: on line 8960-7942 : Rate B, Rate C , 0.0, 0.0 -> 6506
% INFO    : Updated Thermal Rating: on line 5528-7318 : Rate B, Rate C , 0.0, 0.0 -> 61361
% INFO    : Updated Thermal Rating: on line 7488-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134762
% INFO    : Updated Thermal Rating: on line 1318-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101652
% INFO    : Updated Thermal Rating: on line 4092-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91231
% INFO    : Updated Thermal Rating: on line 6120-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 5152-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5896-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 5896-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 83-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2004
% INFO    : Updated Thermal Rating: on line 8451-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 4557-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 2212-5896 : Rate B, Rate C , 0.0, 0.0 -> 1242
% INFO    : Updated Thermal Rating: on line 7360-5896 : Rate B, Rate C , 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 1253-1214 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 18-1214 : Rate B, Rate C , 0.0, 0.0 -> 7867
% INFO    : Updated Thermal Rating: on line 5528-1214 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 4786-1214 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 6027-1214 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 4294-1214 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 5528-1214 : Rate B, Rate C , 0.0, 0.0 -> 6955
% INFO    : Updated Thermal Rating: on line 18-1214 : Rate B, Rate C , 0.0, 0.0 -> 7166
% INFO    : Updated Thermal Rating: on line 2364-2610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4044
% INFO    : Updated Thermal Rating: on line 2364-8699 : Rate B, Rate C , 0.0, 0.0 -> 2241
% INFO    : Updated Thermal Rating: on line 5011-3160 : Rate B, Rate C , 0.0, 0.0 -> 20547
% INFO    : Updated Thermal Rating: on line 5011-6164 : Rate B, Rate C , 0.0, 0.0 -> 18011
% INFO    : Updated Thermal Rating: on line 5011-9221 : Rate B, Rate C , 0.0, 0.0 -> 11374
% INFO    : Updated Thermal Rating: on line 7997-2610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 7997-8699 : Rate B, Rate C , 0.0, 0.0 -> 2133
% INFO    : Updated Thermal Rating: on line 7997-8033 : Rate B, Rate C , 0.0, 0.0 -> 5213
% INFO    : Updated Thermal Rating: on line 5152-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 5152-6120 : Rate B, Rate C , 0.0, 0.0 -> 808
% INFO    : Updated Thermal Rating: on line 6120-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 6120-8134 : Rate A, Rate B, Rate C , 572.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 6120-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 8451-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 2176-8427 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 2176-8427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3610
% INFO    : Updated Thermal Rating: on line 8427-1823 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 8427-3583 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8427-6864 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 8687-1823 : Rate B, Rate C , 0.0, 0.0 -> 2453
% INFO    : Updated Thermal Rating: on line 17-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 17-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 17-2029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 2712-17 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 6981-17 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 3176-17 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 17-8775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4377
% INFO    : Updated Thermal Rating: on line 2112-2029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 2712-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 6981-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 3176-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 3176-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 2102-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1941
% INFO    : Updated Thermal Rating: on line 1253-5528 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on line 1253-4786 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 1253-6027 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 1253-4294 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 1253-5528 : Rate B, Rate C , 0.0, 0.0 -> 3454
% INFO    : Updated Thermal Rating: on line 3714-1765 : Rate B, Rate C , 0.0, 0.0 -> 80755
% INFO    : Updated Thermal Rating: on line 624-3714 : Rate B, Rate C , 0.0, 0.0 -> 4825
% INFO    : Updated Thermal Rating: on line 4718-3714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4154
% INFO    : Updated Thermal Rating: on line 624-3714 : Rate B, Rate C , 0.0, 0.0 -> 4927
% INFO    : Updated Thermal Rating: on line 4718-3714 : Rate B, Rate C , 0.0, 0.0 -> 3841
% INFO    : Updated Thermal Rating: on line 2439-5152 : Rate B, Rate C , 0.0, 0.0 -> 1318
% INFO    : Updated Thermal Rating: on line 5152-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5152-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8451-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 2176-1823 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 2176-3583 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 2176-606 : Rate B, Rate C , 0.0, 0.0 -> 3713
% INFO    : Updated Thermal Rating: on line 2176-6864 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 2176-6864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2884
% INFO    : Updated Thermal Rating: on line 4501-2176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2605
% INFO    : Updated Thermal Rating: on line 2176-4117 : Rate B, Rate C , 0.0, 0.0 -> 4794
% INFO    : Updated Thermal Rating: on line 2176-1823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1437
% INFO    : Updated Thermal Rating: on line 2176-7849 : Rate B, Rate C , 0.0, 0.0 -> 23215
% INFO    : Updated Thermal Rating: on line 4875-8479 : Rate B, Rate C , 0.0, 0.0 -> 17924
% INFO    : Updated Thermal Rating: on line 3479-4875 : Rate B, Rate C , 0.0, 0.0 -> 3392
% INFO    : Updated Thermal Rating: on line 2413-4875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11800
% INFO    : Updated Thermal Rating: on line 1993-8479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 4941-1993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 1993-2390 : Rate B, Rate C , 0.0, 0.0 -> 10902
% INFO    : Updated Thermal Rating: on line 2413-1993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 4941-8479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 8479-3542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11119
% INFO    : Updated Thermal Rating: on line 2413-8479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 4941-5644 : Rate B, Rate C , 0.0, 0.0 -> 2487
% INFO    : Updated Thermal Rating: on line 2665-4146 : Rate B, Rate C , 0.0, 0.0 -> 2619
% INFO    : Updated Thermal Rating: on line 540-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 540-4146 : Rate B, Rate C , 0.0, 0.0 -> 2894
% INFO    : Updated Thermal Rating: on line 4146-4425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9455
% INFO    : Updated Thermal Rating: on line 683-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 3854-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 7245-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11517
% INFO    : Updated Thermal Rating: on line 829-1116 : Rate B, Rate C , 0.0, 0.0 -> 15622
% INFO    : Updated Thermal Rating: on line 5754-829 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 829-7399 : Rate B, Rate C , 0.0, 0.0 -> 10405
% INFO    : Updated Thermal Rating: on line 6906-5754 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 6906-2429 : Rate B, Rate C , 0.0, 0.0 -> 10893
% INFO    : Updated Thermal Rating: on line 5061-9143 : Rate B, Rate C , 0.0, 0.0 -> 36999
% INFO    : Updated Thermal Rating: on line 5061-9143 : Rate B, Rate C , 0.0, 0.0 -> 36155
% INFO    : Updated Thermal Rating: on line 5061-9143 : Rate B, Rate C , 0.0, 0.0 -> 35383
% INFO    : Updated Thermal Rating: on line 3617-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 296-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 4268-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 4268-6155 : Rate B, Rate C , 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 4047-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 1508-4047 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4047-5104 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 129-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 8798-417 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 129-417 : Rate B, Rate C , 0.0, 0.0 -> 3128
% INFO    : Updated Thermal Rating: on line 7731-6066 : Rate B, Rate C , 0.0, 0.0 -> 2247
% INFO    : Updated Thermal Rating: on line 4718-7731 : Rate B, Rate C , 0.0, 0.0 -> 1614
% INFO    : Updated Thermal Rating: on line 8503-822 : Rate B, Rate C , 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 5324-8503 : Rate B, Rate C , 0.0, 0.0 -> 1825
% INFO    : Updated Thermal Rating: on line 8503-1949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 8503-822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 296-3617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 3617-4268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 3617-1497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1586
% INFO    : Updated Thermal Rating: on line 6589-798 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 6589-1955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31461
% INFO    : Updated Thermal Rating: on line 6589-6524 : Rate B, Rate C , 0.0, 0.0 -> 3334
% INFO    : Updated Thermal Rating: on line 6589-4500 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 4139-2260 : Rate B, Rate C , 0.0, 0.0 -> 29393
% INFO    : Updated Thermal Rating: on line 4139-873 : Rate B, Rate C , 0.0, 0.0 -> 3566
% INFO    : Updated Thermal Rating: on line 2439-296 : Rate B, Rate C , 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 296-4268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 296-1773 : Rate B, Rate C , 0.0, 0.0 -> 4223
% INFO    : Updated Thermal Rating: on line 5958-8059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 5958-8059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 8059-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 8059-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 1690-8059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 79-798 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 798-4500 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 3155-592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13633
% INFO    : Updated Thermal Rating: on line 7609-7332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6256
% INFO    : Updated Thermal Rating: on line 7609-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 8778-7609 : Rate B, Rate C , 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 1949-853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 1949-1432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 1949-1432 : Rate B, Rate C , 0.0, 0.0 -> 1608
% INFO    : Updated Thermal Rating: on line 1949-2614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1663
% INFO    : Updated Thermal Rating: on line 1949-822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 4754-5958 : Rate B, Rate C , 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 4754-6172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5806-3854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7112
% INFO    : Updated Thermal Rating: on line 3784-5169 : Rate B, Rate C , 0.0, 0.0 -> 7523
% INFO    : Updated Thermal Rating: on line 3784-330 : Rate B, Rate C , 0.0, 0.0 -> 12434
% INFO    : Updated Thermal Rating: on line 5492-2712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4552
% INFO    : Updated Thermal Rating: on line 3784-2409 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 3784-4578 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 2472-8479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3886-2472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 3886-8479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 584-2260 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 584-873 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 584-873 : Rate B, Rate C , 0.0, 0.0 -> 9284
% INFO    : Updated Thermal Rating: on line 584-6343 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 3655-1323 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3655-1323 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 3905-2387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76660
% INFO    : Updated Thermal Rating: on line 7245-3905 : Rate B, Rate C , 0.0, 0.0 -> 7657
% INFO    : Updated Thermal Rating: on line 4522-1707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4522-1707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 540-4522 : Rate B, Rate C , 0.0, 0.0 -> 3920
% INFO    : Updated Thermal Rating: on line 683-4522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 7360-4522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 4557-4522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 83-1707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 683-1707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 7360-1707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 4557-1707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 3655-2260 : Rate B, Rate C , 0.0, 0.0 -> 3187
% INFO    : Updated Thermal Rating: on line 3583-1823 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1823-6864 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 8134-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 8134-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8451-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 3854-8134 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 8982-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4681
% INFO    : Updated Thermal Rating: on line 8451-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 3636-1823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21329
% INFO    : Updated Thermal Rating: on line 5315-1823 : Rate B, Rate C , 0.0, 0.0 -> 12425
% INFO    : Updated Thermal Rating: on line 3789-1823 : Rate B, Rate C , 0.0, 0.0 -> 8430
% INFO    : Updated Thermal Rating: on line 7874-1823 : Rate B, Rate C , 0.0, 0.0 -> 22049
% INFO    : Updated Thermal Rating: on line 6097-1823 : Rate B, Rate C , 0.0, 0.0 -> 19511
% INFO    : Updated Thermal Rating: on line 4622-1773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8137
% INFO    : Updated Thermal Rating: on line 6336-7401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11824
% INFO    : Updated Thermal Rating: on line 6336-1901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11886
% INFO    : Updated Thermal Rating: on line 2665-683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 540-683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 540-3854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 540-3854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4184
% INFO    : Updated Thermal Rating: on line 9080-1765 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 9080-624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5796
% INFO    : Updated Thermal Rating: on line 9080-624 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 9080-1485 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 9080-1485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5285
% INFO    : Updated Thermal Rating: on line 9080-4718 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 1485-4276 : Rate B, Rate C , 0.0, 0.0 -> 2179
% INFO    : Updated Thermal Rating: on line 4718-4276 : Rate B, Rate C , 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 624-1765 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 1485-1765 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 4718-1765 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 9154-18 : Rate B, Rate C , 0.0, 0.0 -> 14703
% INFO    : Updated Thermal Rating: on line 9154-18 : Rate B, Rate C , 0.0, 0.0 -> 15881
% INFO    : Updated Thermal Rating: on line 5528-4786 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 6027-5528 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 4294-5528 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 6027-4786 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 4294-4786 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 5528-4786 : Rate B, Rate C , 0.0, 0.0 -> 131160
% INFO    : Updated Thermal Rating: on line 330-5116 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 7781-5116 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 7781-5116 : Rate B, Rate C , 0.0, 0.0 -> 5057
% INFO    : Updated Thermal Rating: on line 5116-873 : Rate B, Rate C , 0.0, 0.0 -> 3896
% INFO    : Updated Thermal Rating: on line 2429-5754 : Rate B, Rate C , 0.0, 0.0 -> 6115
% INFO    : Updated Thermal Rating: on line 873-2260 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 6343-2260 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 4268-1497 : Rate B, Rate C , 0.0, 0.0 -> 1904
% INFO    : Updated Thermal Rating: on line 4268-1497 : Rate B, Rate C , 0.0, 0.0 -> 2173
% INFO    : Updated Thermal Rating: on line 4268-1773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3069
% INFO    : Updated Thermal Rating: on line 4268-1773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2672
% INFO    : Updated Thermal Rating: on line 7332-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 3155-7332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 1432-853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 1432-853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1028
% INFO    : Updated Thermal Rating: on line 3583-7849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4651
% INFO    : Updated Thermal Rating: on line 3583-6864 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 635-4425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2117
% INFO    : Updated Thermal Rating: on line 2029-635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1889
% INFO    : Updated Thermal Rating: on line 6336-3261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 7655-3261 : Rate B, Rate C , 0.0, 0.0 -> 1352
% INFO    : Updated Thermal Rating: on line 2726-3789 : Rate B, Rate C , 0.0, 0.0 -> 29005
% INFO    : Updated Thermal Rating: on line 2726-9154 : Rate B, Rate C , 0.0, 0.0 -> 26336
% INFO    : Updated Thermal Rating: on line 1955-9154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13496
% INFO    : Updated Thermal Rating: on line 1792-1955 : Rate B, Rate C , 0.0, 0.0 -> 16231
% INFO    : Updated Thermal Rating: on line 9154-7942 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 9154-7399 : Rate B, Rate C , 0.0, 0.0 -> 7924
% INFO    : Updated Thermal Rating: on line 5530-2712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2501
% INFO    : Updated Thermal Rating: on line 5530-3155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1505
% INFO    : Updated Thermal Rating: on line 5530-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 5530-2223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 9023-6603 : Rate B, Rate C , 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 624-1485 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 4718-624 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 5958-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 5958-6172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 1690-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 1690-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 9160-6977 : Rate B, Rate C , 0.0, 0.0 -> 9632
% INFO    : Updated Thermal Rating: on line 55-2413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8495
% INFO    : Updated Thermal Rating: on line 55-5965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6583
% INFO    : Updated Thermal Rating: on line 6336-3479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 6336-5232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 6336-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 3777-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 5261-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 3886-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8500
% INFO    : Updated Thermal Rating: on line 6336-2003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 6336-2003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6362
% INFO    : Updated Thermal Rating: on line 6336-7620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 6336-7620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 6336-7620 : Rate B, Rate C , 0.0, 0.0 -> 2370
% INFO    : Updated Thermal Rating: on line 6541-1432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4276
% INFO    : Updated Thermal Rating: on line 6541-1432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4365
% INFO    : Updated Thermal Rating: on line 8033-5429 : Rate B, Rate C , 0.0, 0.0 -> 3835
% INFO    : Updated Thermal Rating: on line 2029-2606 : Rate B, Rate C , 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on line 8516-7085 : Rate B, Rate C , 0.0, 0.0 -> 1760
% INFO    : Updated Thermal Rating: on line 6164-4758 : Rate B, Rate C , 0.0, 0.0 -> 59336
% INFO    : Updated Thermal Rating: on line 5169-3922 : Rate B, Rate C , 0.0, 0.0 -> 62725
% INFO    : Updated Thermal Rating: on line 5169-5749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66966
% INFO    : Updated Thermal Rating: on line 8699-166 : Rate B, Rate C , 0.0, 0.0 -> 1902
% INFO    : Updated Thermal Rating: on line 1576-5556 : Rate B, Rate C , 0.0, 0.0 -> 16041
% INFO    : Updated Thermal Rating: on line 2429-6419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5366
% INFO    : Updated Thermal Rating: on line 1576-1720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17169
% INFO    : Updated Thermal Rating: on line 6164-2595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16904
% INFO    : Updated Thermal Rating: on line 6027-4294 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6027-4294 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 6027-5528 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 1444
% INFO    : Updated Thermal Rating: on line 6997-822 : Rate B, Rate C , 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 79-6983 : Rate B, Rate C , 0.0, 0.0 -> 12453
% INFO    : Updated Thermal Rating: on line 79-4500 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 2610-8552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15930
% INFO    : Updated Thermal Rating: on line 2610-8552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14564
% INFO    : Updated Thermal Rating: on line 4941-2787 : Rate B, Rate C , 0.0, 0.0 -> 3591
% INFO    : Updated Thermal Rating: on line 3777-4941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on line 5261-4941 : Rate B, Rate C , 0.0, 0.0 -> 1343
% INFO    : Updated Thermal Rating: on line 5965-4941 : Rate B, Rate C , 0.0, 0.0 -> 7490
% INFO    : Updated Thermal Rating: on line 4941-2413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 3479-5232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 3479-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 3777-3479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 5261-3479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 3479-4496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on line 7620-3479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 8759-3636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6059
% INFO    : Updated Thermal Rating: on line 8759-8585 : Rate B, Rate C , 0.0, 0.0 -> 13839
% INFO    : Updated Thermal Rating: on line 8759-6983 : Rate B, Rate C , 0.0, 0.0 -> 5946
% INFO    : Updated Thermal Rating: on line 8759-5403 : Rate B, Rate C , 0.0, 0.0 -> 10286
% INFO    : Updated Thermal Rating: on line 3859-5673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2104
% INFO    : Updated Thermal Rating: on line 6902-5673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2289
% INFO    : Updated Thermal Rating: on line 2223-5673 : Rate B, Rate C , 0.0, 0.0 -> 1421
% INFO    : Updated Thermal Rating: on line 6652-5673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1977
% INFO    : Updated Thermal Rating: on line 9208-5673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2432
% INFO    : Updated Thermal Rating: on line 2223-5673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 5914-5491 : Rate B, Rate C , 0.0, 0.0 -> 3601
% INFO    : Updated Thermal Rating: on line 9160-5491 : Rate B, Rate C , 0.0, 0.0 -> 2007
% INFO    : Updated Thermal Rating: on line 3668-9143 : Rate B, Rate C , 0.0, 0.0 -> 11576
% INFO    : Updated Thermal Rating: on line 7781-3668 : Rate B, Rate C , 0.0, 0.0 -> 6000
% INFO    : Updated Thermal Rating: on line 250-7725 : Rate B, Rate C , 0.0, 0.0 -> 11834
% INFO    : Updated Thermal Rating: on line 330-250 : Rate B, Rate C , 0.0, 0.0 -> 5890
% INFO    : Updated Thermal Rating: on line 7725-9143 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7725-9143 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 680-7725 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 7715-7725 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on line 3753-7725 : Rate B, Rate C , 0.0, 0.0 -> 14684
% INFO    : Updated Thermal Rating: on line 5387-7725 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 4578-9143 : Rate B, Rate C , 0.0, 0.0 -> 9517
% INFO    : Updated Thermal Rating: on line 680-9143 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 680-9143 : Rate B, Rate C , 0.0, 0.0 -> 8306
% INFO    : Updated Thermal Rating: on line 7715-9143 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 5444-9143 : Rate B, Rate C , 0.0, 0.0 -> 14423
% INFO    : Updated Thermal Rating: on line 5387-9143 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 6830-7859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1805
% INFO    : Updated Thermal Rating: on line 388-122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on line 6524-5969 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6524-5969 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 6524-2429 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 5969-2429 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 5969-3160 : Rate B, Rate C , 0.0, 0.0 -> 8315
% INFO    : Updated Thermal Rating: on line 1690-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 1690-6603 : Rate B, Rate C , 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 4718-1485 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 2029-7859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1987
% INFO    : Updated Thermal Rating: on line 2029-122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2065
% INFO    : Updated Thermal Rating: on line 2712-2029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 6981-2029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 3176-2029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 7655-8516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 5169-2429 : Rate B, Rate C , 0.0, 0.0 -> 8825
% INFO    : Updated Thermal Rating: on line 6164-2429 : Rate B, Rate C , 0.0, 0.0 -> 8800
% INFO    : Updated Thermal Rating: on line 2787-5232 : Rate B, Rate C , 0.0, 0.0 -> 8887
% INFO    : Updated Thermal Rating: on line 7620-2787 : Rate B, Rate C , 0.0, 0.0 -> 4447
% INFO    : Updated Thermal Rating: on line 5232-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 3777-5232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 5261-5232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 7620-5232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 9221-6083 : Rate B, Rate C , 0.0, 0.0 -> 44210
% INFO    : Updated Thermal Rating: on line 1576-6083 : Rate B, Rate C , 0.0, 0.0 -> 6457
% INFO    : Updated Thermal Rating: on line 3777-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5261-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 3886-8699 : Rate B, Rate C , 0.0, 0.0 -> 2522
% INFO    : Updated Thermal Rating: on line 7620-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 3160-6083 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 673-6083 : Rate B, Rate C , 0.0, 0.0 -> 11116
% INFO    : Updated Thermal Rating: on line 5914-9160 : Rate B, Rate C , 0.0, 0.0 -> 3417
% INFO    : Updated Thermal Rating: on line 2409-4578 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2409-4578 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 2409-1576 : Rate B, Rate C , 0.0, 0.0 -> 14015
% INFO    : Updated Thermal Rating: on line 7655-8552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8408
% INFO    : Updated Thermal Rating: on line 3777-5261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3777-7620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 5261-7620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 6452-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1330
% INFO    : Updated Thermal Rating: on line 9225-4793 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on line 8798-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 1657-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 1657-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1566
% INFO    : Updated Thermal Rating: on line 8778-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1668
% INFO    : Updated Thermal Rating: on line 3321-25 : Rate B, Rate C , 0.0, 0.0 -> 11761
% INFO    : Updated Thermal Rating: on line 1823-1792 : Rate B, Rate C , 0.0, 0.0 -> 18930
% INFO    : Updated Thermal Rating: on line 7874-4500 : Rate B, Rate C , 0.0, 0.0 -> 5082
% INFO    : Updated Thermal Rating: on line 6097-8713 : Rate B, Rate C , 0.0, 0.0 -> 38340
% INFO    : Updated Thermal Rating: on line 683-3854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 683-7360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 683-4557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 3854-2212 : Rate B, Rate C , 0.0, 0.0 -> 4341
% INFO    : Updated Thermal Rating: on line 5324-6652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 673-2486 : Rate B, Rate C , 0.0, 0.0 -> 13633
% INFO    : Updated Thermal Rating: on line 3225-673 : Rate B, Rate C , 0.0, 0.0 -> 20285
% INFO    : Updated Thermal Rating: on line 4557-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27397
% INFO    : Updated Thermal Rating: on line 7360-3357 : Rate B, Rate C , 0.0, 0.0 -> 28081
% INFO    : Updated Thermal Rating: on line 6452-8798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6227
% INFO    : Updated Thermal Rating: on line 9225-8798 : Rate B, Rate C , 0.0, 0.0 -> 5514
% INFO    : Updated Thermal Rating: on line 1657-8798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 7781-1576 : Rate B, Rate C , 0.0, 0.0 -> 5460
% INFO    : Updated Thermal Rating: on line 5711-6164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5573
% INFO    : Updated Thermal Rating: on line 798-4500 : Rate B, Rate C , 0.0, 0.0 -> 14489
% INFO    : Updated Thermal Rating: on line 8639-5580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 7803-3225 : Rate B, Rate C , 0.0, 0.0 -> 4543
% INFO    : Updated Thermal Rating: on line 5711-6343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3109
% INFO    : Updated Thermal Rating: on line 2712-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 2712-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2628
% INFO    : Updated Thermal Rating: on line 2712-3176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 2712-3176 : Rate B, Rate C , 0.0, 0.0 -> 2834
% INFO    : Updated Thermal Rating: on line 330-7781 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 2390-9095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39147
% INFO    : Updated Thermal Rating: on line 2413-2390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30016
% INFO    : Updated Thermal Rating: on line 3542-6661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16229
% INFO    : Updated Thermal Rating: on line 2413-3542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30857
% INFO    : Updated Thermal Rating: on line 680-7715 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on line 680-5387 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 6981-3176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 6981-8775 : Rate B, Rate C , 0.0, 0.0 -> 5867
% INFO    : Updated Thermal Rating: on line 5965-2413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3762
% INFO    : Updated Thermal Rating: on line 6886-7161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 5324-2033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10959
% INFO    : Updated Thermal Rating: on line 7620-2003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 7620-2003 : Rate B, Rate C , 0.0, 0.0 -> 2933
% INFO    : Updated Thermal Rating: on line 5528-7880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101421
% INFO    : Updated Thermal Rating: on line 5528-433 : Rate B, Rate C , 0.0, 0.0 -> 104769
% INFO    : Updated Thermal Rating: on line 7942-7399 : Rate B, Rate C , 0.0, 0.0 -> 4950
% INFO    : Updated Thermal Rating: on line 7803-5403 : Rate B, Rate C , 0.0, 0.0 -> 16551
% INFO    : Updated Thermal Rating: on line 7803-8585 : Rate B, Rate C , 0.0, 0.0 -> 11747
% INFO    : Updated Thermal Rating: on line 3753-7715 : Rate B, Rate C , 0.0, 0.0 -> 15537
% INFO    : Updated Thermal Rating: on line 7715-5387 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 7878-9208 : Rate B, Rate C , 0.0, 0.0 -> 41671
% INFO    : Updated Thermal Rating: on line 8810-9208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57781
% INFO    : Updated Thermal Rating: on line 7360-4557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 1497-1773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 842
% INFO    : Updated Thermal Rating: on line 4501-9088 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4501-9088 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 4501-8388 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 9088-1630 : Rate B, Rate C , 0.0, 0.0 -> 4984
% INFO    : Updated Thermal Rating: on line 9088-8388 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 1630-8388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7899
% INFO    : Updated Thermal Rating: on line 4117-8388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8077
% INFO    : Updated Thermal Rating: on line 7245-8698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27479
% INFO    : Updated Thermal Rating: on line 5444-5387 : Rate B, Rate C , 0.0, 0.0 -> 89920
% INFO    : Updated Thermal Rating: on line 3155-2223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on line 3724-6541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44476
% INFO    : Updated Thermal Rating: on line 873-6343 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 873-6343 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 8779-8256 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 8779-3110 : Rate B, Rate C , 0.0, 0.0 -> 20681
% INFO    : Updated Thermal Rating: on line 8779-1287 : Rate B, Rate C , 0.0, 0.0 -> 22293
% INFO    : Updated Thermal Rating: on line 8779-4732 : Rate B, Rate C , 0.0, 0.0 -> 3435
% INFO    : Updated Thermal Rating: on line 8779-2932 : Rate B, Rate C , 0.0, 0.0 -> 3502
% INFO    : Updated Thermal Rating: on line 2309-8779 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 2309-8779 : Rate B, Rate C , 0.0, 0.0 -> 2202
% INFO    : Updated Thermal Rating: on line 503-8779 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 503-8779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2162
% INFO    : Updated Thermal Rating: on line 394-4662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8354
% INFO    : Updated Thermal Rating: on line 394-5316 : Rate B, Rate C , 0.0, 0.0 -> 2787
% INFO    : Updated Thermal Rating: on line 394-4571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3537
% INFO    : Updated Thermal Rating: on line 394-4662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8534
% INFO    : Updated Thermal Rating: on line 394-2681 : Rate B, Rate C , 0.0, 0.0 -> 2735
% INFO    : Updated Thermal Rating: on line 394-938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3818
% INFO    : Updated Thermal Rating: on line 7934-4670 : Rate B, Rate C , 0.0, 0.0 -> 2005
% INFO    : Updated Thermal Rating: on line 7934-4670 : Rate B, Rate C , 0.0, 0.0 -> 1967
% INFO    : Updated Thermal Rating: on line 484-7006 : Rate B, Rate C , 0.0, 0.0 -> 1859
% INFO    : Updated Thermal Rating: on line 484-7006 : Rate B, Rate C , 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 8188-866 : Rate B, Rate C , 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 8188-866 : Rate B, Rate C , 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 4156-1900 : Rate B, Rate C , 0.0, 0.0 -> 4735
% INFO    : Updated Thermal Rating: on line 511-1900 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 511-1900 : Rate B, Rate C , 0.0, 0.0 -> 5342
% INFO    : Updated Thermal Rating: on line 511-1900 : Rate B, Rate C , 0.0, 0.0 -> 5229
% INFO    : Updated Thermal Rating: on line 6374-1900 : Rate B, Rate C , 0.0, 0.0 -> 23815
% INFO    : Updated Thermal Rating: on line 3396-1900 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 2852-8944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 2852-8944 : Rate B, Rate C , 0.0, 0.0 -> 1393
% INFO    : Updated Thermal Rating: on line 439-8944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 439-8944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on line 484-8944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 5880-8198 : Rate B, Rate C , 0.0, 0.0 -> 1786
% INFO    : Updated Thermal Rating: on line 5880-8198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 5880-8198 : Rate B, Rate C , 0.0, 0.0 -> 1819
% INFO    : Updated Thermal Rating: on line 5234-7261 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 1601-5234 : Rate B, Rate C , 0.0, 0.0 -> 2121
% INFO    : Updated Thermal Rating: on line 5234-4571 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 5234-4571 : Rate B, Rate C , 0.0, 0.0 -> 4675
% INFO    : Updated Thermal Rating: on line 5234-8370 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 5194-5234 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 5054-5234 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 7680-6466 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7680-6466 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 2463-7680 : Rate B, Rate C , 0.0, 0.0 -> 22738
% INFO    : Updated Thermal Rating: on line 4285-7680 : Rate B, Rate C , 0.0, 0.0 -> 23215
% INFO    : Updated Thermal Rating: on line 478-6466 : Rate B, Rate C , 0.0, 0.0 -> 23559
% INFO    : Updated Thermal Rating: on line 7919-6466 : Rate B, Rate C , 0.0, 0.0 -> 24093
% INFO    : Updated Thermal Rating: on line 7934-2463 : Rate B, Rate C , 0.0, 0.0 -> 2167
% INFO    : Updated Thermal Rating: on line 4285-983 : Rate B, Rate C , 0.0, 0.0 -> 4501
% INFO    : Updated Thermal Rating: on line 7934-478 : Rate B, Rate C , 0.0, 0.0 -> 2211
% INFO    : Updated Thermal Rating: on line 7919-4175 : Rate B, Rate C , 0.0, 0.0 -> 4420
% INFO    : Updated Thermal Rating: on line 2309-8256 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 2309-8256 : Rate B, Rate C , 0.0, 0.0 -> 2347
% INFO    : Updated Thermal Rating: on line 503-8256 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 5986-2192 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 5986-2192 : Rate B, Rate C , 0.0, 0.0 -> 12962
% INFO    : Updated Thermal Rating: on line 5986-2192 : Rate B, Rate C , 0.0, 0.0 -> 13206
% INFO    : Updated Thermal Rating: on line 5194-2192 : Rate B, Rate C , 0.0, 0.0 -> 2133
% INFO    : Updated Thermal Rating: on line 5054-2192 : Rate B, Rate C , 0.0, 0.0 -> 2178
% INFO    : Updated Thermal Rating: on line 8300-4218 : Rate B, Rate C , 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 1863-4218 : Rate B, Rate C , 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 5880-4218 : Rate B, Rate C , 0.0, 0.0 -> 831
% INFO    : Updated Thermal Rating: on line 2418-4218 : Rate B, Rate C , 0.0, 0.0 -> 1817
% INFO    : Updated Thermal Rating: on line 2418-4218 : Rate B, Rate C , 0.0, 0.0 -> 1786
% INFO    : Updated Thermal Rating: on line 7514-4218 : Rate B, Rate C , 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 3759-2736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 3759-2736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 3759-2736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 2736-3189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 2736-3189 : Rate B, Rate C , 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 2736-3189 : Rate B, Rate C , 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on line 6458-511 : Rate B, Rate C , 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on line 6458-8415 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 983-4662 : Rate B, Rate C , 0.0, 0.0 -> 3081
% INFO    : Updated Thermal Rating: on line 4175-4662 : Rate B, Rate C , 0.0, 0.0 -> 3146
% INFO    : Updated Thermal Rating: on line 2190-386 : Rate B, Rate C , 0.0, 0.0 -> 48875
% INFO    : Updated Thermal Rating: on line 2190-4732 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 2190-2932 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 503-2190 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 386-4732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3847
% INFO    : Updated Thermal Rating: on line 503-386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7391
% INFO    : Updated Thermal Rating: on line 3127-511 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 511-6914 : Rate B, Rate C , 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 511-3396 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 1243-511 : Rate B, Rate C , 0.0, 0.0 -> 3951
% INFO    : Updated Thermal Rating: on line 2852-1403 : Rate B, Rate C , 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 2852-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 2852-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 2852-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 2852-484 : Rate A, Rate B, Rate C , 553.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 2852-3189 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 2852-3189 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 6621-4499 : Rate B, Rate C , 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on line 4499-866 : Rate B, Rate C , 0.0, 0.0 -> 2036
% INFO    : Updated Thermal Rating: on line 8952-7514 : Rate B, Rate C , 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 8952-7514 : Rate B, Rate C , 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 7261-4571 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 7261-8370 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on line 7261-8370 : Rate B, Rate C , 0.0, 0.0 -> 3144
% INFO    : Updated Thermal Rating: on line 7261-938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3204
% INFO    : Updated Thermal Rating: on line 5194-7261 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 5054-7261 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 484-1403 : Rate B, Rate C , 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 7676-5164 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 7676-6993 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 7676-6993 : Rate B, Rate C , 0.0, 0.0 -> 4649
% INFO    : Updated Thermal Rating: on line 7676-4620 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4498-7676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1438
% INFO    : Updated Thermal Rating: on line 5316-5054 : Rate B, Rate C , 0.0, 0.0 -> 5518
% INFO    : Updated Thermal Rating: on line 2681-5194 : Rate B, Rate C , 0.0, 0.0 -> 5634
% INFO    : Updated Thermal Rating: on line 5164-6993 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 5164-4620 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5164-4620 : Rate B, Rate C , 0.0, 0.0 -> 5675
% INFO    : Updated Thermal Rating: on line 2309-5164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2152
% INFO    : Updated Thermal Rating: on line 4498-5164 : Rate A, Rate B, Rate C , 1942.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 6993-4620 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 107-6993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2761
% INFO    : Updated Thermal Rating: on line 503-6993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2324
% INFO    : Updated Thermal Rating: on line 8300-6794 : Rate B, Rate C , 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 1863-6794 : Rate B, Rate C , 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 439-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 3127-7934 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 787
% INFO    : Updated Thermal Rating: on line 3127-495 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on line 3127-3396 : Rate B, Rate C , 0.0, 0.0 -> 2998
% INFO    : Updated Thermal Rating: on line 8966-4620 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on line 8716-1426 : Rate B, Rate C , 0.0, 0.0 -> 10184
% INFO    : Updated Thermal Rating: on line 5258-1426 : Rate B, Rate C , 0.0, 0.0 -> 10371
% INFO    : Updated Thermal Rating: on line 3759-3189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3759-3189 : Rate B, Rate C , 0.0, 0.0 -> 2727
% INFO    : Updated Thermal Rating: on line 3759-3189 : Rate B, Rate C , 0.0, 0.0 -> 2679
% INFO    : Updated Thermal Rating: on line 7934-495 : Rate B, Rate C , 0.0, 0.0 -> 7528
% INFO    : Updated Thermal Rating: on line 4122-6621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 4122-6621 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 4122-6621 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 6621-866 : Rate B, Rate C , 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 5880-193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 5880-193 : Rate B, Rate C , 0.0, 0.0 -> 2791
% INFO    : Updated Thermal Rating: on line 5880-193 : Rate B, Rate C , 0.0, 0.0 -> 2743
% INFO    : Updated Thermal Rating: on line 8415-6914 : Rate B, Rate C , 0.0, 0.0 -> 5279
% INFO    : Updated Thermal Rating: on line 6900-8415 : Rate B, Rate C , 0.0, 0.0 -> 2525
% INFO    : Updated Thermal Rating: on line 983-4175 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 8966-983 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 7169-983 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 7169-983 : Rate B, Rate C , 0.0, 0.0 -> 4080
% INFO    : Updated Thermal Rating: on line 983-5194 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1508
% INFO    : Updated Thermal Rating: on line 8966-4175 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 8966-4175 : Rate B, Rate C , 0.0, 0.0 -> 4004
% INFO    : Updated Thermal Rating: on line 7169-4175 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 4175-5054 : Rate A, Rate B, Rate C , 1876.0, 0.0, 0.0 -> 1540
% INFO    : Updated Thermal Rating: on line 2309-5986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2476
% INFO    : Updated Thermal Rating: on line 503-5986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2430
% INFO    : Updated Thermal Rating: on line 8966-7169 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8966-7169 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 8966-5054 : Rate B, Rate C , 0.0, 0.0 -> 2132
% INFO    : Updated Thermal Rating: on line 107-8966 : Rate B, Rate C , 0.0, 0.0 -> 5691
% INFO    : Updated Thermal Rating: on line 8966-3057 : Rate B, Rate C , 0.0, 0.0 -> 4133
% INFO    : Updated Thermal Rating: on line 8966-4498 : Rate A, Rate B, Rate C , 1711.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 7169-5194 : Rate B, Rate C , 0.0, 0.0 -> 2177
% INFO    : Updated Thermal Rating: on line 7169-4498 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on line 7169-197 : Rate B, Rate C , 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 4732-2932 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 503-4732 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 6457-4732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3888
% INFO    : Updated Thermal Rating: on line 1601-2932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 2309-2932 : Rate B, Rate C , 0.0, 0.0 -> 2379
% INFO    : Updated Thermal Rating: on line 503-2932 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 1757-5584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1742
% INFO    : Updated Thermal Rating: on line 1601-8370 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 1601-5194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2076
% INFO    : Updated Thermal Rating: on line 1601-5054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 1601-6457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3262
% INFO    : Updated Thermal Rating: on line 1601-8716 : Rate B, Rate C , 0.0, 0.0 -> 6346
% INFO    : Updated Thermal Rating: on line 1601-5258 : Rate B, Rate C , 0.0, 0.0 -> 6235
% INFO    : Updated Thermal Rating: on line 5880-7514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 4571-8370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4571-8370 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 5194-4571 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 5054-4571 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5194-8370 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 5054-8370 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 3396-6900 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 5194-5054 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 4498-6900 : Rate B, Rate C , 0.0, 0.0 -> 4782
% INFO    : Updated Thermal Rating: on line 4498-6900 : Rate B, Rate C , 0.0, 0.0 -> 4873
% INFO    : Updated Thermal Rating: on line 3057-197 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 3057-197 : Rate B, Rate C , 0.0, 0.0 -> 3779
% INFO    : Updated Thermal Rating: on line 2309-503 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2309-503 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 8414-6794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 8414-6794 : Rate B, Rate C , 0.0, 0.0 -> 1207
% INFO    : Updated Thermal Rating: on line 8414-6794 : Rate B, Rate C , 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 4498-197 : Rate B, Rate C , 0.0, 0.0 -> 1548
% INFO    : Updated Thermal Rating: on line 7799-6956 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 8716-7799 : Rate B, Rate C , 0.0, 0.0 -> 45958
% INFO    : Updated Thermal Rating: on line 5258-6956 : Rate B, Rate C , 0.0, 0.0 -> 46629
% INFO    : Updated Thermal Rating: on line 4901-9195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 8040-4901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 7007-9195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 8040-7007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 8143-6682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 6682-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 7210-5541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 751
% INFO    : Updated Thermal Rating: on line 5541-7315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 918
% INFO    : Updated Thermal Rating: on line 4462-6720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 6720-8118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1305
% INFO    : Updated Thermal Rating: on line 4384-4937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 1395-4937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 5702-4462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 608
% INFO    : Updated Thermal Rating: on line 2530-664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4312
% INFO    : Updated Thermal Rating: on line 664-5353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 4384-8143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on line 4384-7210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 926
% INFO    : Updated Thermal Rating: on line 9195-4074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 8410-4074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 6585-4074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 9195-5445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 9195-5445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 1715-690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 916
% INFO    : Updated Thermal Rating: on line 1715-6576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 3419-1715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1552
% INFO    : Updated Thermal Rating: on line 4403-1715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 5911-7692 : Rate B, Rate C , 0.0, 0.0 -> 1877
% INFO    : Updated Thermal Rating: on line 5911-7692 : Rate B, Rate C , 0.0, 0.0 -> 2027
% INFO    : Updated Thermal Rating: on line 690-4384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4384-1180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 6576-4384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 4384-6925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1288
% INFO    : Updated Thermal Rating: on line 7315-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 6925-1180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3340
% INFO    : Updated Thermal Rating: on line 8410-4871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 7405-6585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5445-612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 5445-3988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 5445-4515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36920
% INFO    : Updated Thermal Rating: on line 5445-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37289
% INFO    : Updated Thermal Rating: on line 9212-4871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 612-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 3988-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 2307-3419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 5353-4403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 5145-8324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 5145-6865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on line 4857-8118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 9212-7405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 6159-5911 : Rate B, Rate C , 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 6159-5911 : Rate B, Rate C , 0.0, 0.0 -> 1113
% INFO    : Updated Thermal Rating: on line 8324-6159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4990
% INFO    : Updated Thermal Rating: on line 6865-6159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5081
% INFO    : Updated Thermal Rating: on line 2530-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 4857-2530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1457
% INFO    : Updated Thermal Rating: on line 4857-2530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1477
% INFO    : Updated Thermal Rating: on line 6865-4569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133194
% INFO    : Updated Thermal Rating: on line 8324-4569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128186
% INFO    : Updated Thermal Rating: on line 5702-4857 : Rate B, Rate C , 0.0, 0.0 -> 5281
% INFO    : Updated Thermal Rating: on line 208-5702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 208-5702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 8799-4857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 208-8799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 501-4857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 208-501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 5679-3158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 5679-6934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 5679-5874 : Rate B, Rate C , 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 2214-8761 : Rate B, Rate C , 0.0, 0.0 -> 1908
% INFO    : Updated Thermal Rating: on line 2214-362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35675
% INFO    : Updated Thermal Rating: on line 2214-362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35810
% INFO    : Updated Thermal Rating: on line 2214-2836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 2214-4508 : Rate B, Rate C , 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 8026-8919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 8026-5453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 814
% INFO    : Updated Thermal Rating: on line 7876-1776 : Rate B, Rate C , 0.0, 0.0 -> 2818
% INFO    : Updated Thermal Rating: on line 7876-5101 : Rate B, Rate C , 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on line 5794-7887 : Rate B, Rate C , 0.0, 0.0 -> 5837
% INFO    : Updated Thermal Rating: on line 3322-2069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 3322-4286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 848-7465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 848-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 8919-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1904
% INFO    : Updated Thermal Rating: on line 4845-1385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 4845-2569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 2351-2569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 2351-2247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 2351-2247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 4440-2247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 4440-2247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1000
% INFO    : Updated Thermal Rating: on line 5609-2662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 5609-4129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 5600-1776 : Rate B, Rate C , 0.0, 0.0 -> 5764
% INFO    : Updated Thermal Rating: on line 7708-7670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1485
% INFO    : Updated Thermal Rating: on line 7708-4286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 7708-4286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on line 5154-4286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5534
% INFO    : Updated Thermal Rating: on line 6653-6492 : Rate B, Rate C , 0.0, 0.0 -> 9952
% INFO    : Updated Thermal Rating: on line 6653-5101 : Rate B, Rate C , 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 6653-6084 : Rate B, Rate C , 0.0, 0.0 -> 1826
% INFO    : Updated Thermal Rating: on line 6653-9228 : Rate B, Rate C , 0.0, 0.0 -> 5709
% INFO    : Updated Thermal Rating: on line 8761-2836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 8761-8095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 1636-5977 : Rate B, Rate C , 0.0, 0.0 -> 10330
% INFO    : Updated Thermal Rating: on line 1636-285 : Rate B, Rate C , 0.0, 0.0 -> 3773
% INFO    : Updated Thermal Rating: on line 1636-4217 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 4228-3158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2476
% INFO    : Updated Thermal Rating: on line 4228-647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2957
% INFO    : Updated Thermal Rating: on line 4228-6934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 5374-8456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on line 5374-8129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 5374-2836 : Rate B, Rate C , 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 7449-8129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1242
% INFO    : Updated Thermal Rating: on line 7449-1385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 7449-7742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 3158-651 : Rate B, Rate C , 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 3158-647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9369
% INFO    : Updated Thermal Rating: on line 651-8032 : Rate B, Rate C , 0.0, 0.0 -> 8585
% INFO    : Updated Thermal Rating: on line 4145-7559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on line 4145-6839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3029
% INFO    : Updated Thermal Rating: on line 4145-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1016
% INFO    : Updated Thermal Rating: on line 3009-5715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 3009-7559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 3851-5115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 3851-2569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 6608-3675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 6608-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 814
% INFO    : Updated Thermal Rating: on line 2839-2519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 81-6506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 81-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 8456-7465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 8456-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2180
% INFO    : Updated Thermal Rating: on line 8456-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2222
% INFO    : Updated Thermal Rating: on line 8456-200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2740
% INFO    : Updated Thermal Rating: on line 6506-7559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1869
% INFO    : Updated Thermal Rating: on line 1953-5101 : Rate B, Rate C , 0.0, 0.0 -> 2269
% INFO    : Updated Thermal Rating: on line 8611-2569 : Rate B, Rate C , 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 8611-5273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on line 2519-4286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 2519-4286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 2519-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on line 3675-2411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4533
% INFO    : Updated Thermal Rating: on line 3675-8095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8403
% INFO    : Updated Thermal Rating: on line 7416-4217 : Rate B, Rate C , 0.0, 0.0 -> 2381
% INFO    : Updated Thermal Rating: on line 7416-1776 : Rate B, Rate C , 0.0, 0.0 -> 2422
% INFO    : Updated Thermal Rating: on line 2069-5453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 2069-7544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 2069-222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2995
% INFO    : Updated Thermal Rating: on line 2069-222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2851
% INFO    : Updated Thermal Rating: on line 285-4217 : Rate B, Rate C , 0.0, 0.0 -> 4123
% INFO    : Updated Thermal Rating: on line 1345-8129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39340
% INFO    : Updated Thermal Rating: on line 5715-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 5715-7887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 4217-8206 : Rate B, Rate C , 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 4217-9047 : Rate B, Rate C , 0.0, 0.0 -> 18555
% INFO    : Updated Thermal Rating: on line 2285-6391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 2285-4720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 9058-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1596
% INFO    : Updated Thermal Rating: on line 4286-7544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 4286-5115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 8206-6084 : Rate B, Rate C , 0.0, 0.0 -> 5059
% INFO    : Updated Thermal Rating: on line 7559-2544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5428
% INFO    : Updated Thermal Rating: on line 736-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on line 736-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2002
% INFO    : Updated Thermal Rating: on line 4200-6084 : Rate B, Rate C , 0.0, 0.0 -> 12492
% INFO    : Updated Thermal Rating: on line 4376-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 4376-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on line 4376-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 6839-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2434
% INFO    : Updated Thermal Rating: on line 1646-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 2836-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 2836-7742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 6492-9228 : Rate B, Rate C , 0.0, 0.0 -> 61747
% INFO    : Updated Thermal Rating: on line 1673-2662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 1673-4129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6721
% INFO    : Updated Thermal Rating: on line 3931-2569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2365
% INFO    : Updated Thermal Rating: on line 6391-4720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 222-5874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on line 222-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 3743-5273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1442
% INFO    : Updated Thermal Rating: on line 4720-2124 : Rate B, Rate C , 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on line 2247-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1427
% INFO    : Updated Thermal Rating: on line 2247-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1455
% INFO    : Updated Thermal Rating: on line 2247-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 2247-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 4601-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 4129-4508 : Rate B, Rate C , 0.0, 0.0 -> 2818
% INFO    : Updated Thermal Rating: on line 6561-1294 : Rate B, Rate C , 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 6561-1666 : Rate B, Rate C , 0.0, 0.0 -> 1230
% INFO    : Updated Thermal Rating: on line 6561-4096 : Rate B, Rate C , 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on line 4717-4241 : Rate B, Rate C , 0.0, 0.0 -> 1610
% INFO    : Updated Thermal Rating: on line 4241-7395 : Rate B, Rate C , 0.0, 0.0 -> 8057
% INFO    : Updated Thermal Rating: on line 4241-5873 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 1479-4241 : Rate B, Rate C , 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 4241-1475 : Rate B, Rate C , 0.0, 0.0 -> 11190
% INFO    : Updated Thermal Rating: on line 4241-1475 : Rate B, Rate C , 0.0, 0.0 -> 11000
% INFO    : Updated Thermal Rating: on line 2248-264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14703
% INFO    : Updated Thermal Rating: on line 2248-8530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10463
% INFO    : Updated Thermal Rating: on line 3744-4806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3419
% INFO    : Updated Thermal Rating: on line 3744-6239 : Rate B, Rate C , 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on line 5991-8671 : Rate B, Rate C , 0.0, 0.0 -> 5114
% INFO    : Updated Thermal Rating: on line 5991-201 : Rate B, Rate C , 0.0, 0.0 -> 1369
% INFO    : Updated Thermal Rating: on line 5991-3512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 5991-1430 : Rate B, Rate C , 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 5991-5592 : Rate B, Rate C , 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5991-4953 : Rate B, Rate C , 0.0, 0.0 -> 2193
% INFO    : Updated Thermal Rating: on line 5991-2355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2167
% INFO    : Updated Thermal Rating: on line 4510-2957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23296
% INFO    : Updated Thermal Rating: on line 4510-6936 : Rate B, Rate C , 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 5697-5933 : Rate B, Rate C , 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 5697-6040 : Rate B, Rate C , 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on line 5189-2917 : Rate B, Rate C , 0.0, 0.0 -> 26594
% INFO    : Updated Thermal Rating: on line 2917-6654 : Rate B, Rate C , 0.0, 0.0 -> 12676
% INFO    : Updated Thermal Rating: on line 6679-7139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8116
% INFO    : Updated Thermal Rating: on line 6679-6134 : Rate B, Rate C , 0.0, 0.0 -> 3780
% INFO    : Updated Thermal Rating: on line 6679-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3861
% INFO    : Updated Thermal Rating: on line 7413-6679 : Rate B, Rate C , 0.0, 0.0 -> 12252
% INFO    : Updated Thermal Rating: on line 5189-6456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31096
% INFO    : Updated Thermal Rating: on line 2358-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41388
% INFO    : Updated Thermal Rating: on line 2358-8571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8026
% INFO    : Updated Thermal Rating: on line 4717-8247 : Rate B, Rate C , 0.0, 0.0 -> 1712
% INFO    : Updated Thermal Rating: on line 5787-1393 : Rate B, Rate C , 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on line 5787-6243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 5787-8338 : Rate B, Rate C , 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 5787-751 : Rate B, Rate C , 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 8285-4293 : Rate B, Rate C , 0.0, 0.0 -> 15598
% INFO    : Updated Thermal Rating: on line 7392-4293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17534
% INFO    : Updated Thermal Rating: on line 6632-930 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1024
% INFO    : Updated Thermal Rating: on line 930-4407 : Rate B, Rate C , 0.0, 0.0 -> 2231
% INFO    : Updated Thermal Rating: on line 7834-6596 : Rate B, Rate C , 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 7834-5592 : Rate B, Rate C , 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 1418-3633 : Rate B, Rate C , 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 1418-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6356
% INFO    : Updated Thermal Rating: on line 2921-6093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4153
% INFO    : Updated Thermal Rating: on line 2921-3487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3354
% INFO    : Updated Thermal Rating: on line 8353-3633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2211
% INFO    : Updated Thermal Rating: on line 8353-3633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 8353-6904 : Rate B, Rate C , 0.0, 0.0 -> 6776
% INFO    : Updated Thermal Rating: on line 8353-6625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2952
% INFO    : Updated Thermal Rating: on line 6261-1872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3683
% INFO    : Updated Thermal Rating: on line 1872-7973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4498
% INFO    : Updated Thermal Rating: on line 1872-7973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4587
% INFO    : Updated Thermal Rating: on line 1872-4651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13186
% INFO    : Updated Thermal Rating: on line 710-6499 : Rate B, Rate C , 0.0, 0.0 -> 3316
% INFO    : Updated Thermal Rating: on line 710-3792 : Rate B, Rate C , 0.0, 0.0 -> 841
% INFO    : Updated Thermal Rating: on line 2193-6717 : Rate B, Rate C , 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 2193-4752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1770
% INFO    : Updated Thermal Rating: on line 7644-6499 : Rate B, Rate C , 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 7644-6769 : Rate B, Rate C , 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 7644-7075 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 7644-8213 : Rate B, Rate C , 0.0, 0.0 -> 6593
% INFO    : Updated Thermal Rating: on line 7644-8213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6473
% INFO    : Updated Thermal Rating: on line 6632-2507 : Rate B, Rate C , 0.0, 0.0 -> 2883
% INFO    : Updated Thermal Rating: on line 2507-6917 : Rate B, Rate C , 0.0, 0.0 -> 2864
% INFO    : Updated Thermal Rating: on line 3095-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8627
% INFO    : Updated Thermal Rating: on line 3095-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3865
% INFO    : Updated Thermal Rating: on line 5425-1898 : Rate B, Rate C , 0.0, 0.0 -> 7118
% INFO    : Updated Thermal Rating: on line 5425-1498 : Rate A, Rate B, Rate C , 1711.0, 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 5425-1280 : Rate B, Rate C , 0.0, 0.0 -> 8552
% INFO    : Updated Thermal Rating: on line 7431-4279 : Rate B, Rate C , 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 7431-4279 : Rate B, Rate C , 0.0, 0.0 -> 1868
% INFO    : Updated Thermal Rating: on line 7431-4279 : Rate B, Rate C , 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 7431-4279 : Rate B, Rate C , 0.0, 0.0 -> 2083
% INFO    : Updated Thermal Rating: on line 2343-5946 : Rate B, Rate C , 0.0, 0.0 -> 867
% INFO    : Updated Thermal Rating: on line 2236-5946 : Rate B, Rate C , 0.0, 0.0 -> 3276
% INFO    : Updated Thermal Rating: on line 3821-1173 : Rate B, Rate C , 0.0, 0.0 -> 1044
% INFO    : Updated Thermal Rating: on line 3821-6936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5357
% INFO    : Updated Thermal Rating: on line 3821-6936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4739
% INFO    : Updated Thermal Rating: on line 3821-2946 : Rate A, Rate B, Rate C , 533.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 6261-3065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7988
% INFO    : Updated Thermal Rating: on line 4124-3378 : Rate B, Rate C , 0.0, 0.0 -> 4304
% INFO    : Updated Thermal Rating: on line 4124-3378 : Rate B, Rate C , 0.0, 0.0 -> 5056
% INFO    : Updated Thermal Rating: on line 4124-4809 : Rate B, Rate C , 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 4124-4750 : Rate B, Rate C , 0.0, 0.0 -> 1706
% INFO    : Updated Thermal Rating: on line 6663-5217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9272
% INFO    : Updated Thermal Rating: on line 6663-4096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3074
% INFO    : Updated Thermal Rating: on line 6663-4096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3016
% INFO    : Updated Thermal Rating: on line 4855-509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1875
% INFO    : Updated Thermal Rating: on line 9162-509 : Rate B, Rate C , 0.0, 0.0 -> 13059
% INFO    : Updated Thermal Rating: on line 6769-6964 : Rate B, Rate C , 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 6964-7002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 6964-6879 : Rate B, Rate C , 0.0, 0.0 -> 2825
% INFO    : Updated Thermal Rating: on line 6632-6917 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 6632-8870 : Rate A, Rate B, Rate C , 1218.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 6632-8870 : Rate A, Rate B, Rate C , 1283.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 8504-6632 : Rate B, Rate C , 0.0, 0.0 -> 1854
% INFO    : Updated Thermal Rating: on line 6632-2730 : Rate A, Rate B, Rate C , 1251.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 6632-7508 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 6632-385 : Rate A, Rate B, Rate C , 1711.0, 0.0, 0.0 -> 1013
% INFO    : Updated Thermal Rating: on line 6632-385 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 3650-8858 : Rate B, Rate C , 0.0, 0.0 -> 8387
% INFO    : Updated Thermal Rating: on line 3650-8858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12492
% INFO    : Updated Thermal Rating: on line 3650-8858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12784
% INFO    : Updated Thermal Rating: on line 3650-4856 : Rate B, Rate C , 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on line 1618-1060 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 1618-8806 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 8547-6669 : Rate B, Rate C , 0.0, 0.0 -> 1429
% INFO    : Updated Thermal Rating: on line 8547-7398 : Rate B, Rate C , 0.0, 0.0 -> 1085
% INFO    : Updated Thermal Rating: on line 8124-2496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6637
% INFO    : Updated Thermal Rating: on line 8419-2496 : Rate B, Rate C , 0.0, 0.0 -> 3924
% INFO    : Updated Thermal Rating: on line 5125-2916 : Rate B, Rate C , 0.0, 0.0 -> 9690
% INFO    : Updated Thermal Rating: on line 5125-8973 : Rate B, Rate C , 0.0, 0.0 -> 3594
% INFO    : Updated Thermal Rating: on line 2471-8888 : Rate B, Rate C , 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 2471-4906 : Rate B, Rate C , 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 3076-2471 : Rate B, Rate C , 0.0, 0.0 -> 2522
% INFO    : Updated Thermal Rating: on line 4182-2235 : Rate B, Rate C , 0.0, 0.0 -> 7026
% INFO    : Updated Thermal Rating: on line 4182-5873 : Rate B, Rate C , 0.0, 0.0 -> 2795
% INFO    : Updated Thermal Rating: on line 42-5919 : Rate B, Rate C , 0.0, 0.0 -> 5067
% INFO    : Updated Thermal Rating: on line 42-2096 : Rate B, Rate C , 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 6292-6127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1668
% INFO    : Updated Thermal Rating: on line 6292-6127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 6292-2658 : Rate B, Rate C , 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 6292-5191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 929-1175 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 929-1344 : Rate B, Rate C , 0.0, 0.0 -> 2112
% INFO    : Updated Thermal Rating: on line 8671-1421 : Rate B, Rate C , 0.0, 0.0 -> 2894
% INFO    : Updated Thermal Rating: on line 709-4652 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1448
% INFO    : Updated Thermal Rating: on line 709-3587 : Rate B, Rate C , 0.0, 0.0 -> 1976
% INFO    : Updated Thermal Rating: on line 8159-3798 : Rate B, Rate C , 0.0, 0.0 -> 2602
% INFO    : Updated Thermal Rating: on line 8159-2261 : Rate B, Rate C , 0.0, 0.0 -> 1680
% INFO    : Updated Thermal Rating: on line 8159-7755 : Rate B, Rate C , 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 8159-7287 : Rate B, Rate C , 0.0, 0.0 -> 5592
% INFO    : Updated Thermal Rating: on line 8159-7287 : Rate B, Rate C , 0.0, 0.0 -> 5497
% INFO    : Updated Thermal Rating: on line 8159-6496 : Rate B, Rate C , 0.0, 0.0 -> 4783
% INFO    : Updated Thermal Rating: on line 8159-5372 : Rate B, Rate C , 0.0, 0.0 -> 3837
% INFO    : Updated Thermal Rating: on line 8159-807 : Rate B, Rate C , 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 201-8582 : Rate B, Rate C , 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 3193-7053 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 3193-2764 : Rate A, Rate B, Rate C , 1185.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 3193-2764 : Rate A, Rate B, Rate C , 1152.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 3193-1498 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1483
% INFO    : Updated Thermal Rating: on line 3193-1133 : Rate B, Rate C , 0.0, 0.0 -> 1623
% INFO    : Updated Thermal Rating: on line 3193-1133 : Rate B, Rate C , 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 2301-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6640
% INFO    : Updated Thermal Rating: on line 2301-8575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5582
% INFO    : Updated Thermal Rating: on line 4644-1086 : Rate B, Rate C , 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 4644-2849 : Rate B, Rate C , 0.0, 0.0 -> 4919
% INFO    : Updated Thermal Rating: on line 1458-2459 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 1458-477 : Rate B, Rate C , 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 1458-477 : Rate B, Rate C , 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 1458-8210 : Rate B, Rate C , 0.0, 0.0 -> 2419
% INFO    : Updated Thermal Rating: on line 1458-3113 : Rate B, Rate C , 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 1458-8987 : Rate B, Rate C , 0.0, 0.0 -> 1650
% INFO    : Updated Thermal Rating: on line 3065-4450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3617
% INFO    : Updated Thermal Rating: on line 4450-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9950
% INFO    : Updated Thermal Rating: on line 1185-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10265
% INFO    : Updated Thermal Rating: on line 1240-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 3500-8871 : Rate B, Rate C , 0.0, 0.0 -> 4628
% INFO    : Updated Thermal Rating: on line 3500-8582 : Rate B, Rate C , 0.0, 0.0 -> 2225
% INFO    : Updated Thermal Rating: on line 6359-6783 : Rate B, Rate C , 0.0, 0.0 -> 71587
% INFO    : Updated Thermal Rating: on line 6454-6359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60477
% INFO    : Updated Thermal Rating: on line 7833-8438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3823
% INFO    : Updated Thermal Rating: on line 7833-8438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3655
% INFO    : Updated Thermal Rating: on line 4253-7196 : Rate B, Rate C , 0.0, 0.0 -> 1679
% INFO    : Updated Thermal Rating: on line 4253-4651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13035
% INFO    : Updated Thermal Rating: on line 4230-1912 : Rate B, Rate C , 0.0, 0.0 -> 3747
% INFO    : Updated Thermal Rating: on line 4230-6315 : Rate B, Rate C , 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 621-4360 : Rate B, Rate C , 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 621-808 : Rate B, Rate C , 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 2962-6917 : Rate B, Rate C , 0.0, 0.0 -> 2107
% INFO    : Updated Thermal Rating: on line 2962-6917 : Rate B, Rate C , 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 4958-4906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5181
% INFO    : Updated Thermal Rating: on line 4958-4906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5289
% INFO    : Updated Thermal Rating: on line 2642-5823 : Rate B, Rate C , 0.0, 0.0 -> 1826
% INFO    : Updated Thermal Rating: on line 2642-1947 : Rate B, Rate C , 0.0, 0.0 -> 2543
% INFO    : Updated Thermal Rating: on line 2642-3966 : Rate A, Rate B, Rate C , 1349.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 2642-1074 : Rate A, Rate B, Rate C , 1218.0, 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 2642-1074 : Rate A, Rate B, Rate C , 1448.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 2642-807 : Rate B, Rate C , 0.0, 0.0 -> 1120
% INFO    : Updated Thermal Rating: on line 4165-6659 : Rate B, Rate C , 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 4165-7303 : Rate B, Rate C , 0.0, 0.0 -> 15031
% INFO    : Updated Thermal Rating: on line 1793-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6224
% INFO    : Updated Thermal Rating: on line 1793-8338 : Rate B, Rate C , 0.0, 0.0 -> 7103
% INFO    : Updated Thermal Rating: on line 1793-8338 : Rate B, Rate C , 0.0, 0.0 -> 7261
% INFO    : Updated Thermal Rating: on line 4663-6443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5655
% INFO    : Updated Thermal Rating: on line 4663-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2044
% INFO    : Updated Thermal Rating: on line 4663-595 : Rate B, Rate C , 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 4663-3291 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 6138-7504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1756
% INFO    : Updated Thermal Rating: on line 6138-2896 : Rate B, Rate C , 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 5280-2343 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 8534-5121 : Rate B, Rate C , 0.0, 0.0 -> 5999
% INFO    : Updated Thermal Rating: on line 5121-9039 : Rate B, Rate C , 0.0, 0.0 -> 3029
% INFO    : Updated Thermal Rating: on line 3961-4238 : Rate B, Rate C , 0.0, 0.0 -> 3610
% INFO    : Updated Thermal Rating: on line 3961-1411 : Rate B, Rate C , 0.0, 0.0 -> 4064
% INFO    : Updated Thermal Rating: on line 3961-5793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24666
% INFO    : Updated Thermal Rating: on line 3961-5793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21853
% INFO    : Updated Thermal Rating: on line 976-1549 : Rate B, Rate C , 0.0, 0.0 -> 2939
% INFO    : Updated Thermal Rating: on line 976-4600 : Rate B, Rate C , 0.0, 0.0 -> 4755
% INFO    : Updated Thermal Rating: on line 976-2800 : Rate B, Rate C , 0.0, 0.0 -> 7380
% INFO    : Updated Thermal Rating: on line 976-2800 : Rate B, Rate C , 0.0, 0.0 -> 4848
% INFO    : Updated Thermal Rating: on line 1600-8186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24216
% INFO    : Updated Thermal Rating: on line 1600-4011 : Rate B, Rate C , 0.0, 0.0 -> 32573
% INFO    : Updated Thermal Rating: on line 5771-2235 : Rate B, Rate C , 0.0, 0.0 -> 2448
% INFO    : Updated Thermal Rating: on line 5771-5239 : Rate B, Rate C , 0.0, 0.0 -> 5444
% INFO    : Updated Thermal Rating: on line 9216-1409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104253
% INFO    : Updated Thermal Rating: on line 9216-1409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110496
% INFO    : Updated Thermal Rating: on line 9216-6597 : Rate B, Rate C , 0.0, 0.0 -> 11548
% INFO    : Updated Thermal Rating: on line 9216-6836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14708
% INFO    : Updated Thermal Rating: on line 9216-15 : Rate B, Rate C , 0.0, 0.0 -> 21494
% INFO    : Updated Thermal Rating: on line 429-6132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1373
% INFO    : Updated Thermal Rating: on line 6660-6132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1567
% INFO    : Updated Thermal Rating: on line 1439-649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55271
% INFO    : Updated Thermal Rating: on line 649-6836 : Rate B, Rate C , 0.0, 0.0 -> 49903
% INFO    : Updated Thermal Rating: on line 8417-5435 : Rate B, Rate C , 0.0, 0.0 -> 3315
% INFO    : Updated Thermal Rating: on line 8417-5435 : Rate B, Rate C , 0.0, 0.0 -> 3470
% INFO    : Updated Thermal Rating: on line 8417-4058 : Rate B, Rate C , 0.0, 0.0 -> 82471
% INFO    : Updated Thermal Rating: on line 5617-9055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1713
% INFO    : Updated Thermal Rating: on line 5617-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7996
% INFO    : Updated Thermal Rating: on line 8396-7925 : Rate B, Rate C , 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 8806-7925 : Rate B, Rate C , 0.0, 0.0 -> 3471
% INFO    : Updated Thermal Rating: on line 4542-1947 : Rate B, Rate C , 0.0, 0.0 -> 1999
% INFO    : Updated Thermal Rating: on line 4542-8337 : Rate B, Rate C , 0.0, 0.0 -> 11456
% INFO    : Updated Thermal Rating: on line 4542-3966 : Rate B, Rate C , 0.0, 0.0 -> 5592
% INFO    : Updated Thermal Rating: on line 4542-3544 : Rate B, Rate C , 0.0, 0.0 -> 4363
% INFO    : Updated Thermal Rating: on line 7510-4806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 7510-2907 : Rate B, Rate C , 0.0, 0.0 -> 2457
% INFO    : Updated Thermal Rating: on line 7510-2907 : Rate B, Rate C , 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 7510-4338 : Rate B, Rate C , 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 7510-1282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3421
% INFO    : Updated Thermal Rating: on line 7510-7795 : Rate B, Rate C , 0.0, 0.0 -> 5450
% INFO    : Updated Thermal Rating: on line 7510-3382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3377
% INFO    : Updated Thermal Rating: on line 7510-6456 : Rate B, Rate C , 0.0, 0.0 -> 2972
% INFO    : Updated Thermal Rating: on line 5409-8352 : Rate B, Rate C , 0.0, 0.0 -> 7394
% INFO    : Updated Thermal Rating: on line 5409-797 : Rate B, Rate C , 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5409-8207 : Rate B, Rate C , 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 5409-1241 : Rate B, Rate C , 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 2416-5042 : Rate B, Rate C , 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 2416-2764 : Rate B, Rate C , 0.0, 0.0 -> 3575
% INFO    : Updated Thermal Rating: on line 2416-2764 : Rate B, Rate C , 0.0, 0.0 -> 3270
% INFO    : Updated Thermal Rating: on line 2416-179 : Rate B, Rate C , 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 9001-5463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4911
% INFO    : Updated Thermal Rating: on line 9001-445 : Rate B, Rate C , 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 4809-2538 : Rate B, Rate C , 0.0, 0.0 -> 1387
% INFO    : Updated Thermal Rating: on line 2538-6397 : Rate B, Rate C , 0.0, 0.0 -> 2303
% INFO    : Updated Thermal Rating: on line 2081-4556 : Rate B, Rate C , 0.0, 0.0 -> 2588
% INFO    : Updated Thermal Rating: on line 2081-4592 : Rate B, Rate C , 0.0, 0.0 -> 10303
% INFO    : Updated Thermal Rating: on line 3592-267 : Rate B, Rate C , 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 3592-4632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2431
% INFO    : Updated Thermal Rating: on line 3592-4632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2388
% INFO    : Updated Thermal Rating: on line 1549-579 : Rate B, Rate C , 0.0, 0.0 -> 4009
% INFO    : Updated Thermal Rating: on line 1549-9117 : Rate B, Rate C , 0.0, 0.0 -> 5144
% INFO    : Updated Thermal Rating: on line 3282-7145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3451
% INFO    : Updated Thermal Rating: on line 3282-4855 : Rate B, Rate C , 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 3282-4855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 3282-4095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2782
% INFO    : Updated Thermal Rating: on line 8285-699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3578
% INFO    : Updated Thermal Rating: on line 8285-6882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13271
% INFO    : Updated Thermal Rating: on line 8285-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5792
% INFO    : Updated Thermal Rating: on line 267-7349 : Rate B, Rate C , 0.0, 0.0 -> 1299
% INFO    : Updated Thermal Rating: on line 1200-8731 : Rate B, Rate C , 0.0, 0.0 -> 4024
% INFO    : Updated Thermal Rating: on line 1200-1716 : Rate B, Rate C , 0.0, 0.0 -> 7271
% INFO    : Updated Thermal Rating: on line 1200-3067 : Rate B, Rate C , 0.0, 0.0 -> 5104
% INFO    : Updated Thermal Rating: on line 1200-1074 : Rate B, Rate C , 0.0, 0.0 -> 2080
% INFO    : Updated Thermal Rating: on line 3549-6544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1701
% INFO    : Updated Thermal Rating: on line 3549-1503 : Rate B, Rate C , 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on line 1409-3715 : Rate B, Rate C , 0.0, 0.0 -> 22904
% INFO    : Updated Thermal Rating: on line 1409-6836 : Rate B, Rate C , 0.0, 0.0 -> 20247
% INFO    : Updated Thermal Rating: on line 1409-5892 : Rate B, Rate C , 0.0, 0.0 -> 24553
% INFO    : Updated Thermal Rating: on line 1409-5948 : Rate B, Rate C , 0.0, 0.0 -> 14593
% INFO    : Updated Thermal Rating: on line 4407-2962 : Rate B, Rate C , 0.0, 0.0 -> 3376
% INFO    : Updated Thermal Rating: on line 4407-2437 : Rate B, Rate C , 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 7058-5163 : Rate B, Rate C , 0.0, 0.0 -> 2767
% INFO    : Updated Thermal Rating: on line 236-8236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3650
% INFO    : Updated Thermal Rating: on line 236-3427 : Rate B, Rate C , 0.0, 0.0 -> 7127
% INFO    : Updated Thermal Rating: on line 2916-5884 : Rate B, Rate C , 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 2916-4315 : Rate B, Rate C , 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 2916-4315 : Rate B, Rate C , 0.0, 0.0 -> 1692
% INFO    : Updated Thermal Rating: on line 2962-2437 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 2962-2437 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1336
% INFO    : Updated Thermal Rating: on line 3747-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4036
% INFO    : Updated Thermal Rating: on line 3747-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4700
% INFO    : Updated Thermal Rating: on line 932-3728 : Rate B, Rate C , 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 932-7463 : Rate B, Rate C , 0.0, 0.0 -> 12430
% INFO    : Updated Thermal Rating: on line 8087-3342 : Rate B, Rate C , 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 8087-7659 : Rate B, Rate C , 0.0, 0.0 -> 1874
% INFO    : Updated Thermal Rating: on line 8087-3334 : Rate B, Rate C , 0.0, 0.0 -> 7317
% INFO    : Updated Thermal Rating: on line 8087-3334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7660
% INFO    : Updated Thermal Rating: on line 1639-3728 : Rate B, Rate C , 0.0, 0.0 -> 6618
% INFO    : Updated Thermal Rating: on line 1639-8936 : Rate B, Rate C , 0.0, 0.0 -> 9291
% INFO    : Updated Thermal Rating: on line 2907-481 : Rate B, Rate C , 0.0, 0.0 -> 3704
% INFO    : Updated Thermal Rating: on line 2907-481 : Rate B, Rate C , 0.0, 0.0 -> 2966
% INFO    : Updated Thermal Rating: on line 481-9057 : Rate B, Rate C , 0.0, 0.0 -> 4432
% INFO    : Updated Thermal Rating: on line 1894-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 906
% INFO    : Updated Thermal Rating: on line 4890-481 : Rate B, Rate C , 0.0, 0.0 -> 3231
% INFO    : Updated Thermal Rating: on line 5890-481 : Rate B, Rate C , 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 5391-481 : Rate B, Rate C , 0.0, 0.0 -> 5854
% INFO    : Updated Thermal Rating: on line 3544-6771 : Rate B, Rate C , 0.0, 0.0 -> 106663
% INFO    : Updated Thermal Rating: on line 1344-4806 : Rate B, Rate C , 0.0, 0.0 -> 2377
% INFO    : Updated Thermal Rating: on line 869-4806 : Rate B, Rate C , 0.0, 0.0 -> 29067
% INFO    : Updated Thermal Rating: on line 869-4806 : Rate B, Rate C , 0.0, 0.0 -> 28567
% INFO    : Updated Thermal Rating: on line 5685-2459 : Rate B, Rate C , 0.0, 0.0 -> 1837
% INFO    : Updated Thermal Rating: on line 2730-2459 : Rate B, Rate C , 0.0, 0.0 -> 1929
% INFO    : Updated Thermal Rating: on line 2730-2459 : Rate B, Rate C , 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 2730-2459 : Rate B, Rate C , 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 2459-8987 : Rate B, Rate C , 0.0, 0.0 -> 4294
% INFO    : Updated Thermal Rating: on line 1185-1240 : Rate B, Rate C , 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 1185-4016 : Rate B, Rate C , 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 2668-981 : Rate B, Rate C , 0.0, 0.0 -> 5387
% INFO    : Updated Thermal Rating: on line 2668-6344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11091
% INFO    : Updated Thermal Rating: on line 6564-1074 : Rate B, Rate C , 0.0, 0.0 -> 4227
% INFO    : Updated Thermal Rating: on line 6564-4026 : Rate B, Rate C , 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 4336-4249 : Rate B, Rate C , 0.0, 0.0 -> 6083
% INFO    : Updated Thermal Rating: on line 7196-4249 : Rate B, Rate C , 0.0, 0.0 -> 6375
% INFO    : Updated Thermal Rating: on line 4600-642 : Rate B, Rate C , 0.0, 0.0 -> 4078
% INFO    : Updated Thermal Rating: on line 7573-6186 : Rate B, Rate C , 0.0, 0.0 -> 33347
% INFO    : Updated Thermal Rating: on line 7573-8186 : Rate B, Rate C , 0.0, 0.0 -> 26429
% INFO    : Updated Thermal Rating: on line 7413-7573 : Rate B, Rate C , 0.0, 0.0 -> 13292
% INFO    : Updated Thermal Rating: on line 8719-1023 : Rate B, Rate C , 0.0, 0.0 -> 4752
% INFO    : Updated Thermal Rating: on line 8719-3063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3181
% INFO    : Updated Thermal Rating: on line 7508-7053 : Rate B, Rate C , 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 6183-6932 : Rate B, Rate C , 0.0, 0.0 -> 27867
% INFO    : Updated Thermal Rating: on line 6183-6932 : Rate B, Rate C , 0.0, 0.0 -> 25162
% INFO    : Updated Thermal Rating: on line 6183-8068 : Rate B, Rate C , 0.0, 0.0 -> 41215
% INFO    : Updated Thermal Rating: on line 6183-8068 : Rate B, Rate C , 0.0, 0.0 -> 42222
% INFO    : Updated Thermal Rating: on line 1602-4855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3447
% INFO    : Updated Thermal Rating: on line 1602-2551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 7999-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18438
% INFO    : Updated Thermal Rating: on line 7999-6597 : Rate B, Rate C , 0.0, 0.0 -> 20508
% INFO    : Updated Thermal Rating: on line 7999-8661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9625
% INFO    : Updated Thermal Rating: on line 1086-7257 : Rate B, Rate C , 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 6443-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2353
% INFO    : Updated Thermal Rating: on line 6443-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2309
% INFO    : Updated Thermal Rating: on line 2009-6443 : Rate B, Rate C , 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 6443-6749 : Rate B, Rate C , 0.0, 0.0 -> 1947
% INFO    : Updated Thermal Rating: on line 1121-4947 : Rate B, Rate C , 0.0, 0.0 -> 2818
% INFO    : Updated Thermal Rating: on line 4204-4947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 733
% INFO    : Updated Thermal Rating: on line 2907-7191 : Rate B, Rate C , 0.0, 0.0 -> 49864
% INFO    : Updated Thermal Rating: on line 2907-284 : Rate B, Rate C , 0.0, 0.0 -> 15638
% INFO    : Updated Thermal Rating: on line 477-9159 : Rate B, Rate C , 0.0, 0.0 -> 3072
% INFO    : Updated Thermal Rating: on line 1133-9159 : Rate A, Rate B, Rate C , 1152.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on line 3178-6499 : Rate B, Rate C , 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 3792-6499 : Rate B, Rate C , 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 6499-6038 : Rate B, Rate C , 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 6499-7398 : Rate B, Rate C , 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 75-2126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10113
% INFO    : Updated Thermal Rating: on line 75-6869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6507
% INFO    : Updated Thermal Rating: on line 7137-6659 : Rate B, Rate C , 0.0, 0.0 -> 2423
% INFO    : Updated Thermal Rating: on line 3673-6745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 3673-8953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2993
% INFO    : Updated Thermal Rating: on line 3673-8953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2935
% INFO    : Updated Thermal Rating: on line 5685-2849 : Rate B, Rate C , 0.0, 0.0 -> 6989
% INFO    : Updated Thermal Rating: on line 3378-6397 : Rate B, Rate C , 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 3378-1520 : Rate B, Rate C , 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on line 3378-3233 : Rate B, Rate C , 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 3378-3291 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 693-8240 : Rate B, Rate C , 0.0, 0.0 -> 2803
% INFO    : Updated Thermal Rating: on line 693-5884 : Rate B, Rate C , 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 693-3587 : Rate B, Rate C , 0.0, 0.0 -> 2405
% INFO    : Updated Thermal Rating: on line 693-3587 : Rate B, Rate C , 0.0, 0.0 -> 2356
% INFO    : Updated Thermal Rating: on line 6994-5970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5704
% INFO    : Updated Thermal Rating: on line 6994-5970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 6994-970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2922
% INFO    : Updated Thermal Rating: on line 6994-5348 : Rate B, Rate C , 0.0, 0.0 -> 1945
% INFO    : Updated Thermal Rating: on line 6994-1909 : Rate B, Rate C , 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 3843-8534 : Rate B, Rate C , 0.0, 0.0 -> 4579
% INFO    : Updated Thermal Rating: on line 3843-9039 : Rate B, Rate C , 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on line 1021-257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 1021-6936 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 1021-2946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2083
% INFO    : Updated Thermal Rating: on line 1021-172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 8138-3792 : Rate B, Rate C , 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 8138-7659 : Rate B, Rate C , 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 6669-5111 : Rate B, Rate C , 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 5511-7145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2217
% INFO    : Updated Thermal Rating: on line 4338-1894 : Rate B, Rate C , 0.0, 0.0 -> 4781
% INFO    : Updated Thermal Rating: on line 4338-1894 : Rate B, Rate C , 0.0, 0.0 -> 4879
% INFO    : Updated Thermal Rating: on line 4338-6456 : Rate B, Rate C , 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 8946-849 : Rate B, Rate C , 0.0, 0.0 -> 20189
% INFO    : Updated Thermal Rating: on line 8946-849 : Rate B, Rate C , 0.0, 0.0 -> 20572
% INFO    : Updated Thermal Rating: on line 8946-6768 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 5970-2896 : Rate B, Rate C , 0.0, 0.0 -> 822
% INFO    : Updated Thermal Rating: on line 5970-9049 : Rate B, Rate C , 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 5332-618 : Rate B, Rate C , 0.0, 0.0 -> 4037
% INFO    : Updated Thermal Rating: on line 5332-618 : Rate B, Rate C , 0.0, 0.0 -> 4120
% INFO    : Updated Thermal Rating: on line 5332-579 : Rate B, Rate C , 0.0, 0.0 -> 5216
% INFO    : Updated Thermal Rating: on line 5332-4442 : Rate B, Rate C , 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 5332-814 : Rate B, Rate C , 0.0, 0.0 -> 5398
% INFO    : Updated Thermal Rating: on line 3633-6904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4167
% INFO    : Updated Thermal Rating: on line 3633-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 3633-7632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1994
% INFO    : Updated Thermal Rating: on line 3633-7632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 3629-4112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 4112-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4769
% INFO    : Updated Thermal Rating: on line 1645-3066 : Rate B, Rate C , 0.0, 0.0 -> 26592
% INFO    : Updated Thermal Rating: on line 1645-7973 : Rate B, Rate C , 0.0, 0.0 -> 9073
% INFO    : Updated Thermal Rating: on line 4945-7508 : Rate B, Rate C , 0.0, 0.0 -> 2171
% INFO    : Updated Thermal Rating: on line 1957-5933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 1957-1769 : Rate B, Rate C , 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on line 7417-7600 : Rate B, Rate C , 0.0, 0.0 -> 6843
% INFO    : Updated Thermal Rating: on line 7417-3792 : Rate B, Rate C , 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on line 7417-6879 : Rate B, Rate C , 0.0, 0.0 -> 7276
% INFO    : Updated Thermal Rating: on line 7417-962 : Rate B, Rate C , 0.0, 0.0 -> 9758
% INFO    : Updated Thermal Rating: on line 3489-3813 : Rate B, Rate C , 0.0, 0.0 -> 15658
% INFO    : Updated Thermal Rating: on line 1347-3813 : Rate B, Rate C , 0.0, 0.0 -> 15364
% INFO    : Updated Thermal Rating: on line 3813-5500 : Rate B, Rate C , 0.0, 0.0 -> 54724
% INFO    : Updated Thermal Rating: on line 5366-869 : Rate B, Rate C , 0.0, 0.0 -> 4521
% INFO    : Updated Thermal Rating: on line 5366-3382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4283
% INFO    : Updated Thermal Rating: on line 8352-9049 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on line 1869-473 : Rate B, Rate C , 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 1869-6243 : Rate B, Rate C , 0.0, 0.0 -> 4714
% INFO    : Updated Thermal Rating: on line 5767-9057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4823
% INFO    : Updated Thermal Rating: on line 2800-3061 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 2800-618 : Rate B, Rate C , 0.0, 0.0 -> 10720
% INFO    : Updated Thermal Rating: on line 2800-618 : Rate B, Rate C , 0.0, 0.0 -> 10939
% INFO    : Updated Thermal Rating: on line 2800-5042 : Rate B, Rate C , 0.0, 0.0 -> 1666
% INFO    : Updated Thermal Rating: on line 8870-2764 : Rate B, Rate C , 0.0, 0.0 -> 5550
% INFO    : Updated Thermal Rating: on line 8870-2764 : Rate B, Rate C , 0.0, 0.0 -> 5667
% INFO    : Updated Thermal Rating: on line 7096-4290 : Rate B, Rate C , 0.0, 0.0 -> 27343
% INFO    : Updated Thermal Rating: on line 7096-6681 : Rate B, Rate C , 0.0, 0.0 -> 24957
% INFO    : Updated Thermal Rating: on line 7096-8973 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on line 7096-5060 : Rate B, Rate C , 0.0, 0.0 -> 3587
% INFO    : Updated Thermal Rating: on line 5780-6932 : Rate B, Rate C , 0.0, 0.0 -> 5766
% INFO    : Updated Thermal Rating: on line 5780-6869 : Rate B, Rate C , 0.0, 0.0 -> 4430
% INFO    : Updated Thermal Rating: on line 4291-6656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1667
% INFO    : Updated Thermal Rating: on line 4291-8729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 5512-5463 : Rate B, Rate C , 0.0, 0.0 -> 2919
% INFO    : Updated Thermal Rating: on line 7685-5463 : Rate B, Rate C , 0.0, 0.0 -> 2020
% INFO    : Updated Thermal Rating: on line 5463-4967 : Rate B, Rate C , 0.0, 0.0 -> 7002
% INFO    : Updated Thermal Rating: on line 1013-7875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 1741-7875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3468
% INFO    : Updated Thermal Rating: on line 51-5670 : Rate B, Rate C , 0.0, 0.0 -> 1919
% INFO    : Updated Thermal Rating: on line 51-6174 : Rate B, Rate C , 0.0, 0.0 -> 3573
% INFO    : Updated Thermal Rating: on line 51-2517 : Rate B, Rate C , 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 7805-3425 : Rate B, Rate C , 0.0, 0.0 -> 21536
% INFO    : Updated Thermal Rating: on line 7805-8658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 7805-4011 : Rate B, Rate C , 0.0, 0.0 -> 25801
% INFO    : Updated Thermal Rating: on line 7805-9028 : Rate B, Rate C , 0.0, 0.0 -> 2103
% INFO    : Updated Thermal Rating: on line 7805-9028 : Rate B, Rate C , 0.0, 0.0 -> 2143
% INFO    : Updated Thermal Rating: on line 6932-4274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2367
% INFO    : Updated Thermal Rating: on line 6932-8871 : Rate B, Rate C , 0.0, 0.0 -> 2875
% INFO    : Updated Thermal Rating: on line 6932-8871 : Rate B, Rate C , 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 6932-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36969
% INFO    : Updated Thermal Rating: on line 6953-2658 : Rate B, Rate C , 0.0, 0.0 -> 2547
% INFO    : Updated Thermal Rating: on line 6953-5592 : Rate B, Rate C , 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 3342-7659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1261
% INFO    : Updated Thermal Rating: on line 6186-8068 : Rate B, Rate C , 0.0, 0.0 -> 23440
% INFO    : Updated Thermal Rating: on line 8504-1898 : Rate B, Rate C , 0.0, 0.0 -> 1641
% INFO    : Updated Thermal Rating: on line 1282-869 : Rate B, Rate C , 0.0, 0.0 -> 8106
% INFO    : Updated Thermal Rating: on line 9043-7819 : Rate B, Rate C , 0.0, 0.0 -> 6878
% INFO    : Updated Thermal Rating: on line 9043-7819 : Rate B, Rate C , 0.0, 0.0 -> 7428
% INFO    : Updated Thermal Rating: on line 9043-32 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 9043-7423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 7139-8186 : Rate B, Rate C , 0.0, 0.0 -> 50961
% INFO    : Updated Thermal Rating: on line 7139-1065 : Rate B, Rate C , 0.0, 0.0 -> 9950
% INFO    : Updated Thermal Rating: on line 7139-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3621
% INFO    : Updated Thermal Rating: on line 4336-4651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4968
% INFO    : Updated Thermal Rating: on line 731-4020 : Rate B, Rate C , 0.0, 0.0 -> 3543
% INFO    : Updated Thermal Rating: on line 6769-3178 : Rate B, Rate C , 0.0, 0.0 -> 2965
% INFO    : Updated Thermal Rating: on line 6769-3178 : Rate B, Rate C , 0.0, 0.0 -> 3624
% INFO    : Updated Thermal Rating: on line 3178-2116 : Rate B, Rate C , 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on line 3178-7283 : Rate B, Rate C , 0.0, 0.0 -> 3889
% INFO    : Updated Thermal Rating: on line 3178-7283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3960
% INFO    : Updated Thermal Rating: on line 3157-916 : Rate B, Rate C , 0.0, 0.0 -> 5799
% INFO    : Updated Thermal Rating: on line 3157-1241 : Rate B, Rate C , 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 477-2437 : Rate B, Rate C , 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on line 6769-257 : Rate B, Rate C , 0.0, 0.0 -> 1470
% INFO    : Updated Thermal Rating: on line 6769-7283 : Rate B, Rate C , 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 8858-2403 : Rate B, Rate C , 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 8858-4772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 8858-4016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1741
% INFO    : Updated Thermal Rating: on line 2403-6797 : Rate B, Rate C , 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 6192-8207 : Rate B, Rate C , 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 6192-3937 : Rate B, Rate C , 0.0, 0.0 -> 4630
% INFO    : Updated Thermal Rating: on line 7669-8867 : Rate B, Rate C , 0.0, 0.0 -> 54080
% INFO    : Updated Thermal Rating: on line 7669-5948 : Rate B, Rate C , 0.0, 0.0 -> 42367
% INFO    : Updated Thermal Rating: on line 7392-8939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17273
% INFO    : Updated Thermal Rating: on line 1114-5096 : Rate B, Rate C , 0.0, 0.0 -> 2712
% INFO    : Updated Thermal Rating: on line 1114-4315 : Rate B, Rate C , 0.0, 0.0 -> 6889
% INFO    : Updated Thermal Rating: on line 3066-7973 : Rate B, Rate C , 0.0, 0.0 -> 7676
% INFO    : Updated Thermal Rating: on line 264-7064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16221
% INFO    : Updated Thermal Rating: on line 2188-4706 : Rate B, Rate C , 0.0, 0.0 -> 3060
% INFO    : Updated Thermal Rating: on line 7428-2188 : Rate B, Rate C , 0.0, 0.0 -> 9483
% INFO    : Updated Thermal Rating: on line 5170-5681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20189
% INFO    : Updated Thermal Rating: on line 5170-5681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20569
% INFO    : Updated Thermal Rating: on line 8756-2060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2188
% INFO    : Updated Thermal Rating: on line 8756-8419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9249
% INFO    : Updated Thermal Rating: on line 6009-1430 : Rate B, Rate C , 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 6009-5592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 3150-8147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 3150-4096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2487
% INFO    : Updated Thermal Rating: on line 1632-3621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21937
% INFO    : Updated Thermal Rating: on line 1632-6869 : Rate B, Rate C , 0.0, 0.0 -> 6105
% INFO    : Updated Thermal Rating: on line 3061-7460 : Rate B, Rate C , 0.0, 0.0 -> 6572
% INFO    : Updated Thermal Rating: on line 3061-7460 : Rate B, Rate C , 0.0, 0.0 -> 6529
% INFO    : Updated Thermal Rating: on line 3061-7929 : Rate B, Rate C , 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 3061-814 : Rate B, Rate C , 0.0, 0.0 -> 5729
% INFO    : Updated Thermal Rating: on line 699-6882 : Rate B, Rate C , 0.0, 0.0 -> 3930
% INFO    : Updated Thermal Rating: on line 699-947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 699-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3332
% INFO    : Updated Thermal Rating: on line 3584-4177 : Rate B, Rate C , 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 3584-5276 : Rate B, Rate C , 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on line 5034-8301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6843
% INFO    : Updated Thermal Rating: on line 5034-8582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10399
% INFO    : Updated Thermal Rating: on line 1461-3754 : Rate B, Rate C , 0.0, 0.0 -> 41268
% INFO    : Updated Thermal Rating: on line 1461-6179 : Rate B, Rate C , 0.0, 0.0 -> 1829
% INFO    : Updated Thermal Rating: on line 5823-1060 : Rate B, Rate C , 0.0, 0.0 -> 2402
% INFO    : Updated Thermal Rating: on line 5280-4954 : Rate B, Rate C , 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on line 5280-1121 : Rate B, Rate C , 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 5280-7861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 5280-7861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 7303-4690 : Rate B, Rate C , 0.0, 0.0 -> 69919
% INFO    : Updated Thermal Rating: on line 4954-8534 : Rate B, Rate C , 0.0, 0.0 -> 2902
% INFO    : Updated Thermal Rating: on line 4317-72 : Rate B, Rate C , 0.0, 0.0 -> 1791
% INFO    : Updated Thermal Rating: on line 4317-6333 : Rate B, Rate C , 0.0, 0.0 -> 13051
% INFO    : Updated Thermal Rating: on line 8702-4948 : Rate B, Rate C , 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 5163-4948 : Rate B, Rate C , 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 3489-6869 : Rate B, Rate C , 0.0, 0.0 -> 20434
% INFO    : Updated Thermal Rating: on line 1347-6869 : Rate B, Rate C , 0.0, 0.0 -> 20842
% INFO    : Updated Thermal Rating: on line 3687-5877 : Rate B, Rate C , 0.0, 0.0 -> 21883
% INFO    : Updated Thermal Rating: on line 3687-5919 : Rate B, Rate C , 0.0, 0.0 -> 14188
% INFO    : Updated Thermal Rating: on line 1232-4588 : Rate B, Rate C , 0.0, 0.0 -> 22347
% INFO    : Updated Thermal Rating: on line 1232-2764 : Rate B, Rate C , 0.0, 0.0 -> 5758
% INFO    : Updated Thermal Rating: on line 7428-5877 : Rate B, Rate C , 0.0, 0.0 -> 59086
% INFO    : Updated Thermal Rating: on line 4588-7428 : Rate B, Rate C , 0.0, 0.0 -> 52385
% INFO    : Updated Thermal Rating: on line 8939-4371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12770
% INFO    : Updated Thermal Rating: on line 8939-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4665
% INFO    : Updated Thermal Rating: on line 6209-7191 : Rate B, Rate C , 0.0, 0.0 -> 18710
% INFO    : Updated Thermal Rating: on line 519-7349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 429-7877 : Rate B, Rate C , 0.0, 0.0 -> 2302
% INFO    : Updated Thermal Rating: on line 1894-4890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 4062-1599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44749
% INFO    : Updated Thermal Rating: on line 4062-8079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7447
% INFO    : Updated Thermal Rating: on line 6841-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11554
% INFO    : Updated Thermal Rating: on line 6841-2564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10244
% INFO    : Updated Thermal Rating: on line 8710-1491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3294
% INFO    : Updated Thermal Rating: on line 8710-7406 : Rate B, Rate C , 0.0, 0.0 -> 2813
% INFO    : Updated Thermal Rating: on line 970-7504 : Rate B, Rate C , 0.0, 0.0 -> 4369
% INFO    : Updated Thermal Rating: on line 6039-8034 : Rate B, Rate C , 0.0, 0.0 -> 3717
% INFO    : Updated Thermal Rating: on line 6039-7428 : Rate B, Rate C , 0.0, 0.0 -> 9681
% INFO    : Updated Thermal Rating: on line 7973-7475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5055
% INFO    : Updated Thermal Rating: on line 7973-2740 : Rate B, Rate C , 0.0, 0.0 -> 16876
% INFO    : Updated Thermal Rating: on line 7973-2297 : Rate B, Rate C , 0.0, 0.0 -> 16532
% INFO    : Updated Thermal Rating: on line 6877-1060 : Rate B, Rate C , 0.0, 0.0 -> 3282
% INFO    : Updated Thermal Rating: on line 6877-1060 : Rate B, Rate C , 0.0, 0.0 -> 3354
% INFO    : Updated Thermal Rating: on line 8981-4428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1547
% INFO    : Updated Thermal Rating: on line 8981-4428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 1841-3728 : Rate B, Rate C , 0.0, 0.0 -> 4229
% INFO    : Updated Thermal Rating: on line 1841-7463 : Rate B, Rate C , 0.0, 0.0 -> 4410
% INFO    : Updated Thermal Rating: on line 3582-5919 : Rate B, Rate C , 0.0, 0.0 -> 2181
% INFO    : Updated Thermal Rating: on line 3582-2096 : Rate B, Rate C , 0.0, 0.0 -> 2176
% INFO    : Updated Thermal Rating: on line 2009-7349 : Rate B, Rate C , 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 8034-1399 : Rate B, Rate C , 0.0, 0.0 -> 3181
% INFO    : Updated Thermal Rating: on line 4652-8034 : Rate A, Rate B, Rate C , 1283.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 1752-7845 : Rate B, Rate C , 0.0, 0.0 -> 2772
% INFO    : Updated Thermal Rating: on line 1752-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2393
% INFO    : Updated Thermal Rating: on line 7347-1599 : Rate B, Rate C , 0.0, 0.0 -> 45315
% INFO    : Updated Thermal Rating: on line 7347-8079 : Rate B, Rate C , 0.0, 0.0 -> 46708
% INFO    : Updated Thermal Rating: on line 4896-3736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8172
% INFO    : Updated Thermal Rating: on line 4896-7632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1353
% INFO    : Updated Thermal Rating: on line 3736-6625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2689
% INFO    : Updated Thermal Rating: on line 739-8561 : Rate B, Rate C , 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 739-7395 : Rate B, Rate C , 0.0, 0.0 -> 2352
% INFO    : Updated Thermal Rating: on line 739-5873 : Rate B, Rate C , 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 739-4843 : Rate B, Rate C , 0.0, 0.0 -> 2973
% INFO    : Updated Thermal Rating: on line 6092-739 : Rate B, Rate C , 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 1393-6717 : Rate B, Rate C , 0.0, 0.0 -> 3435
% INFO    : Updated Thermal Rating: on line 1393-6717 : Rate B, Rate C , 0.0, 0.0 -> 3504
% INFO    : Updated Thermal Rating: on line 8337-807 : Rate B, Rate C , 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 2235-7395 : Rate B, Rate C , 0.0, 0.0 -> 3548
% INFO    : Updated Thermal Rating: on line 8512-5435 : Rate B, Rate C , 0.0, 0.0 -> 1088
% INFO    : Updated Thermal Rating: on line 8512-4658 : Rate B, Rate C , 0.0, 0.0 -> 4254
% INFO    : Updated Thermal Rating: on line 7929-7460 : Rate B, Rate C , 0.0, 0.0 -> 4011
% INFO    : Updated Thermal Rating: on line 7929-7460 : Rate B, Rate C , 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 299-7460 : Rate B, Rate C , 0.0, 0.0 -> 20061
% INFO    : Updated Thermal Rating: on line 299-7460 : Rate B, Rate C , 0.0, 0.0 -> 20439
% INFO    : Updated Thermal Rating: on line 5117-6456 : Rate B, Rate C , 0.0, 0.0 -> 6509
% INFO    : Updated Thermal Rating: on line 5117-6394 : Rate B, Rate C , 0.0, 0.0 -> 3497
% INFO    : Updated Thermal Rating: on line 6397-7075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 7075-6936 : Rate B, Rate C , 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 7075-2946 : Rate B, Rate C , 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 4274-1969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24058
% INFO    : Updated Thermal Rating: on line 2946-2116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 5096-5464 : Rate B, Rate C , 0.0, 0.0 -> 4440
% INFO    : Updated Thermal Rating: on line 5096-4957 : Rate B, Rate C , 0.0, 0.0 -> 15189
% INFO    : Updated Thermal Rating: on line 5096-4446 : Rate B, Rate C , 0.0, 0.0 -> 9749
% INFO    : Updated Thermal Rating: on line 1115-6090 : Rate B, Rate C , 0.0, 0.0 -> 1991
% INFO    : Updated Thermal Rating: on line 1115-4204 : Rate B, Rate C , 0.0, 0.0 -> 1474
% INFO    : Updated Thermal Rating: on line 3966-3428 : Rate B, Rate C , 0.0, 0.0 -> 3101
% INFO    : Updated Thermal Rating: on line 1439-6836 : Rate B, Rate C , 0.0, 0.0 -> 33506
% INFO    : Updated Thermal Rating: on line 1439-5892 : Rate B, Rate C , 0.0, 0.0 -> 16486
% INFO    : Updated Thermal Rating: on line 9201-3937 : Rate B, Rate C , 0.0, 0.0 -> 21333
% INFO    : Updated Thermal Rating: on line 9201-3692 : Rate B, Rate C , 0.0, 0.0 -> 4118
% INFO    : Updated Thermal Rating: on line 8561-266 : Rate B, Rate C , 0.0, 0.0 -> 2577
% INFO    : Updated Thermal Rating: on line 8561-2566 : Rate A, Rate B, Rate C , 1251.0, 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 8561-8806 : Rate B, Rate C , 0.0, 0.0 -> 2831
% INFO    : Updated Thermal Rating: on line 8561-7428 : Rate A, Rate B, Rate C , 1448.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 8561-1280 : Rate A, Rate B, Rate C , 1086.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 2730-1133 : Rate A, Rate B, Rate C , 1251.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 2730-1133 : Rate A, Rate B, Rate C , 1152.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 6127-5111 : Rate B, Rate C , 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 6127-2172 : Rate B, Rate C , 0.0, 0.0 -> 841
% INFO    : Updated Thermal Rating: on line 6127-2658 : Rate A, Rate B, Rate C , 400.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 7600-7283 : Rate B, Rate C , 0.0, 0.0 -> 14981
% INFO    : Updated Thermal Rating: on line 473-7193 : Rate B, Rate C , 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 473-5025 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 7395-5873 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1360
% INFO    : Updated Thermal Rating: on line 7395-3662 : Rate B, Rate C , 0.0, 0.0 -> 11130
% INFO    : Updated Thermal Rating: on line 7395-4931 : Rate B, Rate C , 0.0, 0.0 -> 1958
% INFO    : Updated Thermal Rating: on line 5435-489 : Rate B, Rate C , 0.0, 0.0 -> 4376
% INFO    : Updated Thermal Rating: on line 5435-489 : Rate B, Rate C , 0.0, 0.0 -> 5608
% INFO    : Updated Thermal Rating: on line 5435-8529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6766
% INFO    : Updated Thermal Rating: on line 5435-7064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6907
% INFO    : Updated Thermal Rating: on line 5435-4058 : Rate B, Rate C , 0.0, 0.0 -> 2866
% INFO    : Updated Thermal Rating: on line 5435-4658 : Rate B, Rate C , 0.0, 0.0 -> 1270
% INFO    : Updated Thermal Rating: on line 2437-7029 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 1575
% INFO    : Updated Thermal Rating: on line 2437-7029 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on line 2437-4795 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 2437-4795 : Rate A, Rate B, Rate C , 1843.0, 0.0, 0.0 -> 1221
% INFO    : Updated Thermal Rating: on line 2437-1133 : Rate A, Rate B, Rate C , 1086.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 3792-550 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 6299-3792 : Rate B, Rate C , 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 3792-6879 : Rate B, Rate C , 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 3792-4181 : Rate B, Rate C , 0.0, 0.0 -> 986
% INFO    : Updated Thermal Rating: on line 8702-5163 : Rate B, Rate C , 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 8702-7861 : Rate B, Rate C , 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on line 8702-7861 : Rate B, Rate C , 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 957-7446 : Rate B, Rate C , 0.0, 0.0 -> 2411
% INFO    : Updated Thermal Rating: on line 957-4897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3387
% INFO    : Updated Thermal Rating: on line 5239-5873 : Rate B, Rate C , 0.0, 0.0 -> 4090
% INFO    : Updated Thermal Rating: on line 8438-8147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 8438-8147 : Rate B, Rate C , 0.0, 0.0 -> 1309
% INFO    : Updated Thermal Rating: on line 4290-266 : Rate A, Rate B, Rate C , 1283.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 266-4843 : Rate B, Rate C , 0.0, 0.0 -> 3936
% INFO    : Updated Thermal Rating: on line 3275-266 : Rate B, Rate C , 0.0, 0.0 -> 3274
% INFO    : Updated Thermal Rating: on line 8247-266 : Rate B, Rate C , 0.0, 0.0 -> 3043
% INFO    : Updated Thermal Rating: on line 8374-266 : Rate B, Rate C , 0.0, 0.0 -> 1603
% INFO    : Updated Thermal Rating: on line 7193-5025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 1064-3734 : Rate B, Rate C , 0.0, 0.0 -> 23210
% INFO    : Updated Thermal Rating: on line 1064-6456 : Rate B, Rate C , 0.0, 0.0 -> 5181
% INFO    : Updated Thermal Rating: on line 1064-6456 : Rate B, Rate C , 0.0, 0.0 -> 5291
% INFO    : Updated Thermal Rating: on line 7877-3063 : Rate B, Rate C , 0.0, 0.0 -> 11413
% INFO    : Updated Thermal Rating: on line 986-3367 : Rate B, Rate C , 0.0, 0.0 -> 1607
% INFO    : Updated Thermal Rating: on line 986-4603 : Rate B, Rate C , 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 7257-6970 : Rate B, Rate C , 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 5873-6768 : Rate B, Rate C , 0.0, 0.0 -> 3884
% INFO    : Updated Thermal Rating: on line 8147-6174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 825
% INFO    : Updated Thermal Rating: on line 8147-6174 : Rate B, Rate C , 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 8147-5162 : Rate B, Rate C , 0.0, 0.0 -> 7502
% INFO    : Updated Thermal Rating: on line 6879-6038 : Rate B, Rate C , 0.0, 0.0 -> 2493
% INFO    : Updated Thermal Rating: on line 4556-4592 : Rate B, Rate C , 0.0, 0.0 -> 5863
% INFO    : Updated Thermal Rating: on line 2412-2686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2427
% INFO    : Updated Thermal Rating: on line 2412-2686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 2412-3644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 2412-3644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 4855-2551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1535
% INFO    : Updated Thermal Rating: on line 4855-6904 : Rate B, Rate C , 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 4855-1897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2304
% INFO    : Updated Thermal Rating: on line 3268-8210 : Rate B, Rate C , 0.0, 0.0 -> 4753
% INFO    : Updated Thermal Rating: on line 3268-2849 : Rate B, Rate C , 0.0, 0.0 -> 1848
% INFO    : Updated Thermal Rating: on line 6397-1173 : Rate B, Rate C , 0.0, 0.0 -> 1661
% INFO    : Updated Thermal Rating: on line 6397-6936 : Rate B, Rate C , 0.0, 0.0 -> 783
% INFO    : Updated Thermal Rating: on line 6397-6936 : Rate B, Rate C , 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 6397-4750 : Rate B, Rate C , 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3665-6544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6815
% INFO    : Updated Thermal Rating: on line 3665-6544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6686
% INFO    : Updated Thermal Rating: on line 3665-6544 : Rate B, Rate C , 0.0, 0.0 -> 9641
% INFO    : Updated Thermal Rating: on line 6436-5217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22084
% INFO    : Updated Thermal Rating: on line 6436-6717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1668
% INFO    : Updated Thermal Rating: on line 72-6093 : Rate B, Rate C , 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 1520-3233 : Rate B, Rate C , 0.0, 0.0 -> 2931
% INFO    : Updated Thermal Rating: on line 6985-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53332
% INFO    : Updated Thermal Rating: on line 6985-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on line 6985-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4327
% INFO    : Updated Thermal Rating: on line 489-4238 : Rate B, Rate C , 0.0, 0.0 -> 3610
% INFO    : Updated Thermal Rating: on line 489-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4672
% INFO    : Updated Thermal Rating: on line 4290-6681 : Rate B, Rate C , 0.0, 0.0 -> 25787
% INFO    : Updated Thermal Rating: on line 4290-3587 : Rate B, Rate C , 0.0, 0.0 -> 2537
% INFO    : Updated Thermal Rating: on line 4290-8374 : Rate B, Rate C , 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 797-7819 : Rate B, Rate C , 0.0, 0.0 -> 3767
% INFO    : Updated Thermal Rating: on line 797-8378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1599
% INFO    : Updated Thermal Rating: on line 797-1241 : Rate B, Rate C , 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 7929-7755 : Rate B, Rate C , 0.0, 0.0 -> 2548
% INFO    : Updated Thermal Rating: on line 7929-7755 : Rate B, Rate C , 0.0, 0.0 -> 2597
% INFO    : Updated Thermal Rating: on line 7929-8625 : Rate B, Rate C , 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on line 4592-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5854
% INFO    : Updated Thermal Rating: on line 4592-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5970
% INFO    : Updated Thermal Rating: on line 6040-3111 : Rate B, Rate C , 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 1175-3111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on line 3111-6239 : Rate B, Rate C , 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 3111-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 3111-6179 : Rate B, Rate C , 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 8396-5091 : Rate B, Rate C , 0.0, 0.0 -> 1967
% INFO    : Updated Thermal Rating: on line 8396-8806 : Rate A, Rate B, Rate C , 1251.0, 0.0, 0.0 -> 1217
% INFO    : Updated Thermal Rating: on line 8396-8247 : Rate B, Rate C , 0.0, 0.0 -> 2117
% INFO    : Updated Thermal Rating: on line 8396-5060 : Rate B, Rate C , 0.0, 0.0 -> 3020
% INFO    : Updated Thermal Rating: on line 8396-8012 : Rate B, Rate C , 0.0, 0.0 -> 9367
% INFO    : Updated Thermal Rating: on line 1491-4489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2494
% INFO    : Updated Thermal Rating: on line 1491-1503 : Rate B, Rate C , 0.0, 0.0 -> 791
% INFO    : Updated Thermal Rating: on line 849-1168 : Rate B, Rate C , 0.0, 0.0 -> 1866
% INFO    : Updated Thermal Rating: on line 849-1168 : Rate B, Rate C , 0.0, 0.0 -> 4637
% INFO    : Updated Thermal Rating: on line 849-1168 : Rate B, Rate C , 0.0, 0.0 -> 4545
% INFO    : Updated Thermal Rating: on line 6092-849 : Rate B, Rate C , 0.0, 0.0 -> 2065
% INFO    : Updated Thermal Rating: on line 3840-686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1309
% INFO    : Updated Thermal Rating: on line 3840-5821 : Rate B, Rate C , 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 3840-2225 : Rate B, Rate C , 0.0, 0.0 -> 4761
% INFO    : Updated Thermal Rating: on line 3840-2225 : Rate B, Rate C , 0.0, 0.0 -> 5698
% INFO    : Updated Thermal Rating: on line 5091-4390 : Rate B, Rate C , 0.0, 0.0 -> 76837
% INFO    : Updated Thermal Rating: on line 5091-4390 : Rate B, Rate C , 0.0, 0.0 -> 76837
% INFO    : Updated Thermal Rating: on line 5091-4957 : Rate B, Rate C , 0.0, 0.0 -> 9161
% INFO    : Updated Thermal Rating: on line 7446-2504 : Rate B, Rate C , 0.0, 0.0 -> 1776
% INFO    : Updated Thermal Rating: on line 1741-1912 : Rate B, Rate C , 0.0, 0.0 -> 2343
% INFO    : Updated Thermal Rating: on line 483-2658 : Rate B, Rate C , 0.0, 0.0 -> 4224
% INFO    : Updated Thermal Rating: on line 483-5592 : Rate B, Rate C , 0.0, 0.0 -> 898
% INFO    : Updated Thermal Rating: on line 5111-4360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12109
% INFO    : Updated Thermal Rating: on line 6596-3512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 8701-8207 : Rate B, Rate C , 0.0, 0.0 -> 2397
% INFO    : Updated Thermal Rating: on line 8701-1271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on line 2236-4967 : Rate B, Rate C , 0.0, 0.0 -> 3120
% INFO    : Updated Thermal Rating: on line 8575-7845 : Rate B, Rate C , 0.0, 0.0 -> 2049
% INFO    : Updated Thermal Rating: on line 8664-1399 : Rate B, Rate C , 0.0, 0.0 -> 2371
% INFO    : Updated Thermal Rating: on line 5202-8936 : Rate B, Rate C , 0.0, 0.0 -> 47279
% INFO    : Updated Thermal Rating: on line 5202-2564 : Rate B, Rate C , 0.0, 0.0 -> 48642
% INFO    : Updated Thermal Rating: on line 5202-3027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27957
% INFO    : Updated Thermal Rating: on line 6836-6209 : Rate B, Rate C , 0.0, 0.0 -> 18221
% INFO    : Updated Thermal Rating: on line 5923-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37113
% INFO    : Updated Thermal Rating: on line 7137-7310 : Rate B, Rate C , 0.0, 0.0 -> 5272
% INFO    : Updated Thermal Rating: on line 7137-6970 : Rate B, Rate C , 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 5831-7137 : Rate B, Rate C , 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 5919-2764 : Rate B, Rate C , 0.0, 0.0 -> 6753
% INFO    : Updated Thermal Rating: on line 8871-8819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4699
% INFO    : Updated Thermal Rating: on line 2504-5329 : Rate B, Rate C , 0.0, 0.0 -> 1136
% INFO    : Updated Thermal Rating: on line 3233-2844 : Rate B, Rate C , 0.0, 0.0 -> 7885
% INFO    : Updated Thermal Rating: on line 3233-3291 : Rate B, Rate C , 0.0, 0.0 -> 953
% INFO    : Updated Thermal Rating: on line 8149-2896 : Rate B, Rate C , 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 8149-1802 : Rate B, Rate C , 0.0, 0.0 -> 3627
% INFO    : Updated Thermal Rating: on line 5828-440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 5828-1391 : Rate B, Rate C , 0.0, 0.0 -> 1566
% INFO    : Updated Thermal Rating: on line 8236-3027 : Rate B, Rate C , 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 1168-6607 : Rate B, Rate C , 0.0, 0.0 -> 1691
% INFO    : Updated Thermal Rating: on line 1168-7673 : Rate B, Rate C , 0.0, 0.0 -> 5484
% INFO    : Updated Thermal Rating: on line 1168-754 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1499
% INFO    : Updated Thermal Rating: on line 2686-4773 : Rate B, Rate C , 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 2225-4177 : Rate B, Rate C , 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 3798-2913 : Rate B, Rate C , 0.0, 0.0 -> 6399
% INFO    : Updated Thermal Rating: on line 3544-2913 : Rate A, Rate B, Rate C , 1349.0, 0.0, 0.0 -> 1173
% INFO    : Updated Thermal Rating: on line 4906-550 : Rate B, Rate C , 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 3427-6949 : Rate B, Rate C , 0.0, 0.0 -> 11309
% INFO    : Updated Thermal Rating: on line 3427-9028 : Rate B, Rate C , 0.0, 0.0 -> 2325
% INFO    : Updated Thermal Rating: on line 4890-7406 : Rate B, Rate C , 0.0, 0.0 -> 2818
% INFO    : Updated Thermal Rating: on line 4890-6349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11807
% INFO    : Updated Thermal Rating: on line 8867-15 : Rate B, Rate C , 0.0, 0.0 -> 23815
% INFO    : Updated Thermal Rating: on line 8867-284 : Rate B, Rate C , 0.0, 0.0 -> 18942
% INFO    : Updated Thermal Rating: on line 4428-8534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2449
% INFO    : Updated Thermal Rating: on line 4428-8534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2500
% INFO    : Updated Thermal Rating: on line 4428-5276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3289
% INFO    : Updated Thermal Rating: on line 4428-5276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3347
% INFO    : Updated Thermal Rating: on line 3644-4428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2418
% INFO    : Updated Thermal Rating: on line 3644-4428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 6936-2957 : Rate B, Rate C , 0.0, 0.0 -> 5859
% INFO    : Updated Thermal Rating: on line 8240-8973 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 6543-3715 : Rate B, Rate C , 0.0, 0.0 -> 20595
% INFO    : Updated Thermal Rating: on line 6543-5948 : Rate B, Rate C , 0.0, 0.0 -> 27118
% INFO    : Updated Thermal Rating: on line 3275-4931 : Rate B, Rate C , 0.0, 0.0 -> 3851
% INFO    : Updated Thermal Rating: on line 8163-3425 : Rate B, Rate C , 0.0, 0.0 -> 11591
% INFO    : Updated Thermal Rating: on line 3425-6783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 2172-595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 8658-1065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23603
% INFO    : Updated Thermal Rating: on line 6090-1175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 792
% INFO    : Updated Thermal Rating: on line 3106-7673 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 3106-2096 : Rate B, Rate C , 0.0, 0.0 -> 2556
% INFO    : Updated Thermal Rating: on line 8163-5500 : Rate B, Rate C , 0.0, 0.0 -> 49392
% INFO    : Updated Thermal Rating: on line 7249-8207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9445
% INFO    : Updated Thermal Rating: on line 7249-3692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2025
% INFO    : Updated Thermal Rating: on line 6783-5923 : Rate B, Rate C , 0.0, 0.0 -> 18543
% INFO    : Updated Thermal Rating: on line 6783-8575 : Rate B, Rate C , 0.0, 0.0 -> 12501
% INFO    : Updated Thermal Rating: on line 1121-4657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 3487-1121 : Rate B, Rate C , 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on line 3442-8819 : Rate B, Rate C , 0.0, 0.0 -> 11260
% INFO    : Updated Thermal Rating: on line 4856-4906 : Rate B, Rate C , 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 3076-4906 : Rate B, Rate C , 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 5884-8973 : Rate B, Rate C , 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 8207-5961 : Rate B, Rate C , 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 8207-3629 : Rate B, Rate C , 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 8207-3692 : Rate B, Rate C , 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 8207-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on line 6877-7755 : Rate B, Rate C , 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 6877-7755 : Rate B, Rate C , 0.0, 0.0 -> 2523
% INFO    : Updated Thermal Rating: on line 5042-179 : Rate B, Rate C , 0.0, 0.0 -> 3600
% INFO    : Updated Thermal Rating: on line 5042-4442 : Rate B, Rate C , 0.0, 0.0 -> 5145
% INFO    : Updated Thermal Rating: on line 2566-6768 : Rate B, Rate C , 0.0, 0.0 -> 5190
% INFO    : Updated Thermal Rating: on line 4897-6717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2792
% INFO    : Updated Thermal Rating: on line 7475-6949 : Rate B, Rate C , 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 1294-5162 : Rate B, Rate C , 0.0, 0.0 -> 4095
% INFO    : Updated Thermal Rating: on line 6681-8806 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 6681-8806 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on line 6681-8806 : Rate A, Rate B, Rate C , 1185.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 6681-8973 : Rate A, Rate B, Rate C , 1283.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 7819-32 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 6333-5512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on line 8534-9039 : Rate B, Rate C , 0.0, 0.0 -> 1744
% INFO    : Updated Thermal Rating: on line 8534-5276 : Rate B, Rate C , 0.0, 0.0 -> 2197
% INFO    : Updated Thermal Rating: on line 4026-2261 : Rate B, Rate C , 0.0, 0.0 -> 2310
% INFO    : Updated Thermal Rating: on line 4204-4657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 731-2764 : Rate B, Rate C , 0.0, 0.0 -> 3338
% INFO    : Updated Thermal Rating: on line 731-597 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1728
% INFO    : Updated Thermal Rating: on line 731-385 : Rate B, Rate C , 0.0, 0.0 -> 9100
% INFO    : Updated Thermal Rating: on line 3728-2564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3193
% INFO    : Updated Thermal Rating: on line 2764-2622 : Rate B, Rate C , 0.0, 0.0 -> 9837
% INFO    : Updated Thermal Rating: on line 2764-7688 : Rate B, Rate C , 0.0, 0.0 -> 4632
% INFO    : Updated Thermal Rating: on line 2764-8260 : Rate B, Rate C , 0.0, 0.0 -> 7107
% INFO    : Updated Thermal Rating: on line 415-3367 : Rate B, Rate C , 0.0, 0.0 -> 1729
% INFO    : Updated Thermal Rating: on line 415-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2046
% INFO    : Updated Thermal Rating: on line 7287-7755 : Rate B, Rate C , 0.0, 0.0 -> 3416
% INFO    : Updated Thermal Rating: on line 7287-7755 : Rate B, Rate C , 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 947-2785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4351
% INFO    : Updated Thermal Rating: on line 3734-6654 : Rate B, Rate C , 0.0, 0.0 -> 9468
% INFO    : Updated Thermal Rating: on line 2551-1897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2007
% INFO    : Updated Thermal Rating: on line 8806-8664 : Rate B, Rate C , 0.0, 0.0 -> 2443
% INFO    : Updated Thermal Rating: on line 8806-7428 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on line 8806-4652 : Rate B, Rate C , 0.0, 0.0 -> 4456
% INFO    : Updated Thermal Rating: on line 249-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32723
% INFO    : Updated Thermal Rating: on line 1741-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 249-5290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 249-4467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 249-5290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 1391-32 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 32-2143 : Rate B, Rate C , 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 3008-6768 : Rate B, Rate C , 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 6174-5670 : Rate B, Rate C , 0.0, 0.0 -> 1714
% INFO    : Updated Thermal Rating: on line 8066-5961 : Rate B, Rate C , 0.0, 0.0 -> 4839
% INFO    : Updated Thermal Rating: on line 442-8066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 1271-5961 : Rate B, Rate C , 0.0, 0.0 -> 3702
% INFO    : Updated Thermal Rating: on line 869-4489 : Rate B, Rate C , 0.0, 0.0 -> 1902
% INFO    : Updated Thermal Rating: on line 869-4489 : Rate B, Rate C , 0.0, 0.0 -> 1940
% INFO    : Updated Thermal Rating: on line 602-4489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2415
% INFO    : Updated Thermal Rating: on line 602-4489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 6484-7918 : Rate B, Rate C , 0.0, 0.0 -> 2585
% INFO    : Updated Thermal Rating: on line 6484-7436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3311
% INFO    : Updated Thermal Rating: on line 7918-4690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2538
% INFO    : Updated Thermal Rating: on line 5511-1942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3295
% INFO    : Updated Thermal Rating: on line 5511-8419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 5511-8419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2227
% INFO    : Updated Thermal Rating: on line 7611-3382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36111
% INFO    : Updated Thermal Rating: on line 7611-3382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36526
% INFO    : Updated Thermal Rating: on line 7611-7869 : Rate B, Rate C , 0.0, 0.0 -> 13322
% INFO    : Updated Thermal Rating: on line 686-5171 : Rate B, Rate C , 0.0, 0.0 -> 5534
% INFO    : Updated Thermal Rating: on line 2172-5191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 1697-179 : Rate B, Rate C , 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 1697-179 : Rate B, Rate C , 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 179-2096 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1323
% INFO    : Updated Thermal Rating: on line 1728-179 : Rate B, Rate C , 0.0, 0.0 -> 3539
% INFO    : Updated Thermal Rating: on line 1850-4603 : Rate B, Rate C , 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 1850-4603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 918
% INFO    : Updated Thermal Rating: on line 3109-5726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on line 3109-5726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 5726-4773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3716
% INFO    : Updated Thermal Rating: on line 7659-6879 : Rate B, Rate C , 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 6174-5171 : Rate B, Rate C , 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 527-8242 : Rate B, Rate C , 0.0, 0.0 -> 14910
% INFO    : Updated Thermal Rating: on line 527-8529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13316
% INFO    : Updated Thermal Rating: on line 527-8530 : Rate B, Rate C , 0.0, 0.0 -> 57786
% INFO    : Updated Thermal Rating: on line 6496-6607 : Rate B, Rate C , 0.0, 0.0 -> 4045
% INFO    : Updated Thermal Rating: on line 4652-4706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8536
% INFO    : Updated Thermal Rating: on line 6656-2091 : Rate B, Rate C , 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 6656-8993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3519
% INFO    : Updated Thermal Rating: on line 6656-1241 : Rate B, Rate C , 0.0, 0.0 -> 6012
% INFO    : Updated Thermal Rating: on line 2658-808 : Rate B, Rate C , 0.0, 0.0 -> 1310
% INFO    : Updated Thermal Rating: on line 3291-6749 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 7406-4397 : Rate B, Rate C , 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 7406-1769 : Rate B, Rate C , 0.0, 0.0 -> 2586
% INFO    : Updated Thermal Rating: on line 7406-1769 : Rate B, Rate C , 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 1013-4467 : Rate B, Rate C , 0.0, 0.0 -> 8366
% INFO    : Updated Thermal Rating: on line 1013-5025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 7918-7310 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 7918-5608 : Rate B, Rate C , 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 5831-7918 : Rate B, Rate C , 0.0, 0.0 -> 2363
% INFO    : Updated Thermal Rating: on line 7918-2202 : Rate B, Rate C , 0.0, 0.0 -> 4179
% INFO    : Updated Thermal Rating: on line 77-6660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84901
% INFO    : Updated Thermal Rating: on line 8124-8419 : Rate B, Rate C , 0.0, 0.0 -> 4622
% INFO    : Updated Thermal Rating: on line 33-3334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18888
% INFO    : Updated Thermal Rating: on line 6490-8301 : Rate B, Rate C , 0.0, 0.0 -> 2625
% INFO    : Updated Thermal Rating: on line 6490-6869 : Rate B, Rate C , 0.0, 0.0 -> 2349
% INFO    : Updated Thermal Rating: on line 4371-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3745
% INFO    : Updated Thermal Rating: on line 2896-5348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2100
% INFO    : Updated Thermal Rating: on line 5767-6836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105292
% INFO    : Updated Thermal Rating: on line 2978-6836 : Rate B, Rate C , 0.0, 0.0 -> 105292
% INFO    : Updated Thermal Rating: on line 2978-5391 : Rate B, Rate C , 0.0, 0.0 -> 3954
% INFO    : Updated Thermal Rating: on line 3629-230 : Rate B, Rate C , 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on line 9039-7861 : Rate B, Rate C , 0.0, 0.0 -> 3391
% INFO    : Updated Thermal Rating: on line 1479-7343 : Rate B, Rate C , 0.0, 0.0 -> 12713
% INFO    : Updated Thermal Rating: on line 7343-4957 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 8338-981 : Rate B, Rate C , 0.0, 0.0 -> 6176
% INFO    : Updated Thermal Rating: on line 8338-751 : Rate B, Rate C , 0.0, 0.0 -> 1944
% INFO    : Updated Thermal Rating: on line 4026-5372 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 7821-642 : Rate B, Rate C , 0.0, 0.0 -> 3450
% INFO    : Updated Thermal Rating: on line 7821-5608 : Rate B, Rate C , 0.0, 0.0 -> 3603
% INFO    : Updated Thermal Rating: on line 9097-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3502
% INFO    : Updated Thermal Rating: on line 9097-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3778
% INFO    : Updated Thermal Rating: on line 9097-3125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3295
% INFO    : Updated Thermal Rating: on line 9097-3125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3236
% INFO    : Updated Thermal Rating: on line 4315-5464 : Rate B, Rate C , 0.0, 0.0 -> 4352
% INFO    : Updated Thermal Rating: on line 1942-4095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2470
% INFO    : Updated Thermal Rating: on line 3966-1074 : Rate B, Rate C , 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 3966-807 : Rate B, Rate C , 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 3966-4507 : Rate B, Rate C , 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 5890-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 8210-3113 : Rate B, Rate C , 0.0, 0.0 -> 4598
% INFO    : Updated Thermal Rating: on line 8210-2849 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 642-5608 : Rate B, Rate C , 0.0, 0.0 -> 1513
% INFO    : Updated Thermal Rating: on line 1697-642 : Rate B, Rate C , 0.0, 0.0 -> 4012
% INFO    : Updated Thermal Rating: on line 1697-642 : Rate B, Rate C , 0.0, 0.0 -> 3937
% INFO    : Updated Thermal Rating: on line 1421-3621 : Rate B, Rate C , 0.0, 0.0 -> 6468
% INFO    : Updated Thermal Rating: on line 2126-1421 : Rate B, Rate C , 0.0, 0.0 -> 7053
% INFO    : Updated Thermal Rating: on line 2844-3291 : Rate B, Rate C , 0.0, 0.0 -> 985
% INFO    : Updated Thermal Rating: on line 1638-8575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36222
% INFO    : Updated Thermal Rating: on line 3163-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 3163-5025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on line 6454-8571 : Rate B, Rate C , 0.0, 0.0 -> 20925
% INFO    : Updated Thermal Rating: on line 8571-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3326
% INFO    : Updated Thermal Rating: on line 8571-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3395
% INFO    : Updated Thermal Rating: on line 2091-440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 4953-1421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5036
% INFO    : Updated Thermal Rating: on line 2667-1969 : Rate B, Rate C , 0.0, 0.0 -> 3501
% INFO    : Updated Thermal Rating: on line 2667-9028 : Rate B, Rate C , 0.0, 0.0 -> 4810
% INFO    : Updated Thermal Rating: on line 8819-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3461
% INFO    : Updated Thermal Rating: on line 751-4493 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 751-4493 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 751-6344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20833
% INFO    : Updated Thermal Rating: on line 5289-3113 : Rate B, Rate C , 0.0, 0.0 -> 15802
% INFO    : Updated Thermal Rating: on line 3113-5289 : Rate B, Rate C , 0.0, 0.0 -> 16708
% INFO    : Updated Thermal Rating: on line 172-2946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on line 7685-6394 : Rate B, Rate C , 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 5821-5329 : Rate B, Rate C , 0.0, 0.0 -> 1403
% INFO    : Updated Thermal Rating: on line 7283-8213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6347
% INFO    : Updated Thermal Rating: on line 7283-962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6732
% INFO    : Updated Thermal Rating: on line 3468-8661 : Rate B, Rate C , 0.0, 0.0 -> 9608
% INFO    : Updated Thermal Rating: on line 3468-1769 : Rate B, Rate C , 0.0, 0.0 -> 7669
% INFO    : Updated Thermal Rating: on line 6244-9055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4105
% INFO    : Updated Thermal Rating: on line 6244-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4187
% INFO    : Updated Thermal Rating: on line 6544-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 7463-1969 : Rate B, Rate C , 0.0, 0.0 -> 80052
% INFO    : Updated Thermal Rating: on line 1030-6022 : Rate B, Rate C , 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 1030-8776 : Rate B, Rate C , 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 1030-5290 : Rate B, Rate C , 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 1030-4279 : Rate B, Rate C , 0.0, 0.0 -> 1404
% INFO    : Updated Thermal Rating: on line 3067-4507 : Rate B, Rate C , 0.0, 0.0 -> 3620
% INFO    : Updated Thermal Rating: on line 5608-9117 : Rate B, Rate C , 0.0, 0.0 -> 2668
% INFO    : Updated Thermal Rating: on line 5608-7436 : Rate B, Rate C , 0.0, 0.0 -> 5324
% INFO    : Updated Thermal Rating: on line 5608-2202 : Rate B, Rate C , 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 7002-3334 : Rate B, Rate C , 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on line 2060-3495 : Rate B, Rate C , 0.0, 0.0 -> 5124
% INFO    : Updated Thermal Rating: on line 3544-807 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 869-4910 : Rate B, Rate C , 0.0, 0.0 -> 16962
% INFO    : Updated Thermal Rating: on line 869-6456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1268
% INFO    : Updated Thermal Rating: on line 4397-1503 : Rate B, Rate C , 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 1513-6745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7010
% INFO    : Updated Thermal Rating: on line 916-4224 : Rate B, Rate C , 0.0, 0.0 -> 5932
% INFO    : Updated Thermal Rating: on line 916-1241 : Rate B, Rate C , 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 602-4910 : Rate B, Rate C , 0.0, 0.0 -> 3599
% INFO    : Updated Thermal Rating: on line 6456-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2334
% INFO    : Updated Thermal Rating: on line 4224-1909 : Rate B, Rate C , 0.0, 0.0 -> 2334
% INFO    : Updated Thermal Rating: on line 2297-2740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16272
% INFO    : Updated Thermal Rating: on line 9162-8419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3367
% INFO    : Updated Thermal Rating: on line 5391-6349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8489
% INFO    : Updated Thermal Rating: on line 2517-5163 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 5163-3754 : Rate B, Rate C , 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on line 2785-9055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4224
% INFO    : Updated Thermal Rating: on line 2785-9055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2921
% INFO    : Updated Thermal Rating: on line 4957-5464 : Rate B, Rate C , 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 807-8625 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 6299-6879 : Rate B, Rate C , 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 8247-4390 : Rate A, Rate B, Rate C , 1711.0, 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on line 8247-4390 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1351
% INFO    : Updated Thermal Rating: on line 7630-442 : Rate B, Rate C , 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on line 8993-8378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2856
% INFO    : Updated Thermal Rating: on line 6879-4181 : Rate B, Rate C , 0.0, 0.0 -> 7808
% INFO    : Updated Thermal Rating: on line 3662-1475 : Rate B, Rate C , 0.0, 0.0 -> 32126
% INFO    : Updated Thermal Rating: on line 8242-8530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12595
% INFO    : Updated Thermal Rating: on line 5494-5290 : Rate B, Rate C , 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 5494-1437 : Rate B, Rate C , 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 6145-4279 : Rate B, Rate C , 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 6145-4279 : Rate B, Rate C , 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on line 4652-597 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 3109-5329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4698
% INFO    : Updated Thermal Rating: on line 3109-5329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4612
% INFO    : Updated Thermal Rating: on line 4026-1074 : Rate B, Rate C , 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 2355-8582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2024
% INFO    : Updated Thermal Rating: on line 1666-4058 : Rate B, Rate C , 0.0, 0.0 -> 21165
% INFO    : Updated Thermal Rating: on line 4493-1513 : Rate B, Rate C , 0.0, 0.0 -> 3317
% INFO    : Updated Thermal Rating: on line 1513-6604 : Rate B, Rate C , 0.0, 0.0 -> 3324
% INFO    : Updated Thermal Rating: on line 6604-1457 : Rate B, Rate C , 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 3495-7629 : Rate B, Rate C , 0.0, 0.0 -> 3179
% INFO    : Updated Thermal Rating: on line 1985-9106 : Rate B, Rate C , 0.0, 0.0 -> 3430
% INFO    : Updated Thermal Rating: on line 4957-8012 : Rate B, Rate C , 0.0, 0.0 -> 2982
% INFO    : Updated Thermal Rating: on line 4651-5681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3182
% INFO    : Updated Thermal Rating: on line 4651-5681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 7795-445 : Rate B, Rate C , 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 2700-4446 : Rate B, Rate C , 0.0, 0.0 -> 19605
% INFO    : Updated Thermal Rating: on line 4772-8301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 4772-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 442-230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 924
% INFO    : Updated Thermal Rating: on line 4238-7312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 7366-3125 : Rate B, Rate C , 0.0, 0.0 -> 2767
% INFO    : Updated Thermal Rating: on line 7366-7423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 754-2096 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on line 1599-4096 : Rate B, Rate C , 0.0, 0.0 -> 7589
% INFO    : Updated Thermal Rating: on line 8079-4096 : Rate B, Rate C , 0.0, 0.0 -> 7754
% INFO    : Updated Thermal Rating: on line 230-1802 : Rate B, Rate C , 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 3027-4081 : Rate B, Rate C , 0.0, 0.0 -> 3458
% INFO    : Updated Thermal Rating: on line 4652-1280 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on line 6315-6022 : Rate B, Rate C , 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 6315-8729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 6315-5631 : Rate B, Rate C , 0.0, 0.0 -> 1307
% INFO    : Updated Thermal Rating: on line 2622-8260 : Rate B, Rate C , 0.0, 0.0 -> 21248
% INFO    : Updated Thermal Rating: on line 6797-8301 : Rate B, Rate C , 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 4467-5465 : Rate B, Rate C , 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on line 1728-2096 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 5793-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6585
% INFO    : Updated Thermal Rating: on line 5793-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6718
% INFO    : Updated Thermal Rating: on line 7688-385 : Rate B, Rate C , 0.0, 0.0 -> 6097
% INFO    : Updated Thermal Rating: on line 8301-6869 : Rate B, Rate C , 0.0, 0.0 -> 2691
% INFO    : Updated Thermal Rating: on line 1501-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3398
% INFO    : Updated Thermal Rating: on line 6022-695 : Rate B, Rate C , 0.0, 0.0 -> 137464
% INFO    : Updated Thermal Rating: on line 8776-695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42591
% INFO    : Updated Thermal Rating: on line 8776-5631 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 2143-5631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4276
% INFO    : Updated Thermal Rating: on line 2143-5631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6853
% INFO    : Updated Thermal Rating: on line 5465-5025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 7632-6625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2111
% INFO    : Updated Thermal Rating: on line 5290-4279 : Rate B, Rate C , 0.0, 0.0 -> 913
% INFO    : Updated Thermal Rating: on line 5290-4279 : Rate B, Rate C , 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 5025-4752 : Rate B, Rate C , 0.0, 0.0 -> 4350
% INFO    : Updated Thermal Rating: on line 5025-7312 : Rate B, Rate C , 0.0, 0.0 -> 4376
% INFO    : Updated Thermal Rating: on line 1437-4279 : Rate A, Rate B, Rate C , 572.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 6654-7869 : Rate B, Rate C , 0.0, 0.0 -> 71510
% INFO    : Updated Thermal Rating: on line 6654-7869 : Rate B, Rate C , 0.0, 0.0 -> 73159
% INFO    : Updated Thermal Rating: on line 7351-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39412
% INFO    : Updated Thermal Rating: on line 4314-7571 : Rate B, Rate C , 0.0, 0.0 -> 1864
% INFO    : Updated Thermal Rating: on line 5803-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7252
% INFO    : Updated Thermal Rating: on line 6757-6036 : Rate B, Rate C , 0.0, 0.0 -> 12799
% INFO    : Updated Thermal Rating: on line 6757-6921 : Rate B, Rate C , 0.0, 0.0 -> 8353
% INFO    : Updated Thermal Rating: on line 5019-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53817
% INFO    : Updated Thermal Rating: on line 2930-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42657
% INFO    : Updated Thermal Rating: on line 1436-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53244
% INFO    : Updated Thermal Rating: on line 1851-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48642
% INFO    : Updated Thermal Rating: on line 8331-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53416
% INFO    : Updated Thermal Rating: on line 6220-8791 : Rate B, Rate C , 0.0, 0.0 -> 6384
% INFO    : Updated Thermal Rating: on line 9203-7842 : Rate B, Rate C , 0.0, 0.0 -> 41388
% INFO    : Updated Thermal Rating: on line 9203-8997 : Rate B, Rate C , 0.0, 0.0 -> 5051
% INFO    : Updated Thermal Rating: on line 9203-2129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4190
% INFO    : Updated Thermal Rating: on line 9203-29 : Rate B, Rate C , 0.0, 0.0 -> 3577
% INFO    : Updated Thermal Rating: on line 118-8903 : Rate B, Rate C , 0.0, 0.0 -> 34578
% INFO    : Updated Thermal Rating: on line 118-4598 : Rate B, Rate C , 0.0, 0.0 -> 4380
% INFO    : Updated Thermal Rating: on line 2426-5533 : Rate B, Rate C , 0.0, 0.0 -> 14992
% INFO    : Updated Thermal Rating: on line 2426-4831 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 2426-8961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 2426-8522 : Rate B, Rate C , 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 2426-6888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 2426-3401 : Rate B, Rate C , 0.0, 0.0 -> 4685
% INFO    : Updated Thermal Rating: on line 2426-641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3433
% INFO    : Updated Thermal Rating: on line 2426-2600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9747
% INFO    : Updated Thermal Rating: on line 2426-5351 : Rate B, Rate C , 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 3051-718 : Rate B, Rate C , 0.0, 0.0 -> 124840
% INFO    : Updated Thermal Rating: on line 3036-2327 : Rate B, Rate C , 0.0, 0.0 -> 42335
% INFO    : Updated Thermal Rating: on line 8651-7473 : Rate B, Rate C , 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on line 8651-7473 : Rate B, Rate C , 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 903-3654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70101
% INFO    : Updated Thermal Rating: on line 8732-7050 : Rate B, Rate C , 0.0, 0.0 -> 21113
% INFO    : Updated Thermal Rating: on line 8732-3912 : Rate B, Rate C , 0.0, 0.0 -> 41734
% INFO    : Updated Thermal Rating: on line 2273-1973 : Rate B, Rate C , 0.0, 0.0 -> 50883
% INFO    : Updated Thermal Rating: on line 5131-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35472
% INFO    : Updated Thermal Rating: on line 6629-4918 : Rate B, Rate C , 0.0, 0.0 -> 2273
% INFO    : Updated Thermal Rating: on line 6629-7309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 413-1102 : Rate B, Rate C , 0.0, 0.0 -> 50969
% INFO    : Updated Thermal Rating: on line 413-1102 : Rate B, Rate C , 0.0, 0.0 -> 49351
% INFO    : Updated Thermal Rating: on line 3248-4918 : Rate B, Rate C , 0.0, 0.0 -> 7265
% INFO    : Updated Thermal Rating: on line 3248-4281 : Rate B, Rate C , 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 3248-7309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9162
% INFO    : Updated Thermal Rating: on line 1146-1187 : Rate B, Rate C , 0.0, 0.0 -> 2399
% INFO    : Updated Thermal Rating: on line 1146-7945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9180
% INFO    : Updated Thermal Rating: on line 8900-2421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25425
% INFO    : Updated Thermal Rating: on line 6071-2972 : Rate B, Rate C , 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 6071-6031 : Rate B, Rate C , 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 3293-7264 : Rate B, Rate C , 0.0, 0.0 -> 2816
% INFO    : Updated Thermal Rating: on line 3293-283 : Rate B, Rate C , 0.0, 0.0 -> 4036
% INFO    : Updated Thermal Rating: on line 3293-3069 : Rate B, Rate C , 0.0, 0.0 -> 939
% INFO    : Updated Thermal Rating: on line 3293-3390 : Rate B, Rate C , 0.0, 0.0 -> 3066
% INFO    : Updated Thermal Rating: on line 4689-4936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9881
% INFO    : Updated Thermal Rating: on line 4689-4936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9744
% INFO    : Updated Thermal Rating: on line 3218-7809 : Rate B, Rate C , 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 3218-5455 : Rate B, Rate C , 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 3218-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1996
% INFO    : Updated Thermal Rating: on line 6806-5410 : Rate B, Rate C , 0.0, 0.0 -> 7899
% INFO    : Updated Thermal Rating: on line 6806-5410 : Rate B, Rate C , 0.0, 0.0 -> 8381
% INFO    : Updated Thermal Rating: on line 6806-1609 : Rate B, Rate C , 0.0, 0.0 -> 4018
% INFO    : Updated Thermal Rating: on line 6806-1609 : Rate B, Rate C , 0.0, 0.0 -> 4034
% INFO    : Updated Thermal Rating: on line 6806-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 6806-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9636
% INFO    : Updated Thermal Rating: on line 6806-954 : Rate B, Rate C , 0.0, 0.0 -> 11510
% INFO    : Updated Thermal Rating: on line 9140-502 : Rate B, Rate C , 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on line 9140-3013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4315
% INFO    : Updated Thermal Rating: on line 9140-2949 : Rate B, Rate C , 0.0, 0.0 -> 3575
% INFO    : Updated Thermal Rating: on line 9140-2949 : Rate B, Rate C , 0.0, 0.0 -> 3646
% INFO    : Updated Thermal Rating: on line 9140-2949 : Rate B, Rate C , 0.0, 0.0 -> 3663
% INFO    : Updated Thermal Rating: on line 7070-2208 : Rate B, Rate C , 0.0, 0.0 -> 36421
% INFO    : Updated Thermal Rating: on line 7070-8060 : Rate B, Rate C , 0.0, 0.0 -> 25518
% INFO    : Updated Thermal Rating: on line 7070-4484 : Rate B, Rate C , 0.0, 0.0 -> 23967
% INFO    : Updated Thermal Rating: on line 7070-4239 : Rate B, Rate C , 0.0, 0.0 -> 8717
% INFO    : Updated Thermal Rating: on line 8535-7047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48244
% INFO    : Updated Thermal Rating: on line 5477-3657 : Rate B, Rate C , 0.0, 0.0 -> 25180
% INFO    : Updated Thermal Rating: on line 5477-2928 : Rate B, Rate C , 0.0, 0.0 -> 12337
% INFO    : Updated Thermal Rating: on line 3145-2918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 7770-5317 : Rate B, Rate C , 0.0, 0.0 -> 6584
% INFO    : Updated Thermal Rating: on line 7770-5317 : Rate B, Rate C , 0.0, 0.0 -> 6260
% INFO    : Updated Thermal Rating: on line 3-8676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 3-8189 : Rate B, Rate C , 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 7267-2938 : Rate B, Rate C , 0.0, 0.0 -> 3928
% INFO    : Updated Thermal Rating: on line 7267-2938 : Rate B, Rate C , 0.0, 0.0 -> 3990
% INFO    : Updated Thermal Rating: on line 7267-3918 : Rate B, Rate C , 0.0, 0.0 -> 1480
% INFO    : Updated Thermal Rating: on line 7267-3918 : Rate B, Rate C , 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 7267-6581 : Rate B, Rate C , 0.0, 0.0 -> 2201
% INFO    : Updated Thermal Rating: on line 7267-6581 : Rate B, Rate C , 0.0, 0.0 -> 2246
% INFO    : Updated Thermal Rating: on line 7267-3830 : Rate B, Rate C , 0.0, 0.0 -> 2175
% INFO    : Updated Thermal Rating: on line 7267-5648 : Rate B, Rate C , 0.0, 0.0 -> 2087
% INFO    : Updated Thermal Rating: on line 7267-5648 : Rate B, Rate C , 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 4918-4907 : Rate B, Rate C , 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 4918-5957 : Rate B, Rate C , 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 4918-5233 : Rate B, Rate C , 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 6854-7309 : Rate B, Rate C , 0.0, 0.0 -> 148968
% INFO    : Updated Thermal Rating: on line 8311-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13251
% INFO    : Updated Thermal Rating: on line 2770-8804 : Rate B, Rate C , 0.0, 0.0 -> 7291
% INFO    : Updated Thermal Rating: on line 9241-8804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7442
% INFO    : Updated Thermal Rating: on line 3083-7124 : Rate B, Rate C , 0.0, 0.0 -> 7227
% INFO    : Updated Thermal Rating: on line 3083-7124 : Rate B, Rate C , 0.0, 0.0 -> 6738
% INFO    : Updated Thermal Rating: on line 3083-8873 : Rate B, Rate C , 0.0, 0.0 -> 6103
% INFO    : Updated Thermal Rating: on line 1566-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2393
% INFO    : Updated Thermal Rating: on line 1566-3541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2443
% INFO    : Updated Thermal Rating: on line 8683-3698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32156
% INFO    : Updated Thermal Rating: on line 8683-3698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33953
% INFO    : Updated Thermal Rating: on line 8683-2801 : Rate B, Rate C , 0.0, 0.0 -> 2515
% INFO    : Updated Thermal Rating: on line 8683-8328 : Rate B, Rate C , 0.0, 0.0 -> 14927
% INFO    : Updated Thermal Rating: on line 8683-8511 : Rate B, Rate C , 0.0, 0.0 -> 20990
% INFO    : Updated Thermal Rating: on line 8683-6570 : Rate B, Rate C , 0.0, 0.0 -> 2238
% INFO    : Updated Thermal Rating: on line 8683-6570 : Rate B, Rate C , 0.0, 0.0 -> 2415
% INFO    : Updated Thermal Rating: on line 8683-8975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13028
% INFO    : Updated Thermal Rating: on line 8683-216 : Rate B, Rate C , 0.0, 0.0 -> 6209
% INFO    : Updated Thermal Rating: on line 8683-2961 : Rate B, Rate C , 0.0, 0.0 -> 43067
% INFO    : Updated Thermal Rating: on line 8683-6773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122861
% INFO    : Updated Thermal Rating: on line 8683-5278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134762
% INFO    : Updated Thermal Rating: on line 3768-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34015
% INFO    : Updated Thermal Rating: on line 2276-5546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3946
% INFO    : Updated Thermal Rating: on line 2276-6816 : Rate B, Rate C , 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 7766-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2955
% INFO    : Updated Thermal Rating: on line 7766-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3062
% INFO    : Updated Thermal Rating: on line 839-3918 : Rate B, Rate C , 0.0, 0.0 -> 14872
% INFO    : Updated Thermal Rating: on line 839-809 : Rate B, Rate C , 0.0, 0.0 -> 10058
% INFO    : Updated Thermal Rating: on line 4506-2286 : Rate B, Rate C , 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 4506-6802 : Rate B, Rate C , 0.0, 0.0 -> 4050
% INFO    : Updated Thermal Rating: on line 4506-3520 : Rate B, Rate C , 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 7273-6271 : Rate B, Rate C , 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 7273-1435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 7273-7148 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 7273-7437 : Rate B, Rate C , 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 6104-871 : Rate B, Rate C , 0.0, 0.0 -> 12175
% INFO    : Updated Thermal Rating: on line 7580-871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13128
% INFO    : Updated Thermal Rating: on line 1188-1539 : Rate B, Rate C , 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1188-8515 : Rate B, Rate C , 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 3971-4084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18252
% INFO    : Updated Thermal Rating: on line 3971-4084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18682
% INFO    : Updated Thermal Rating: on line 6845-5340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69711
% INFO    : Updated Thermal Rating: on line 8294-5814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6000
% INFO    : Updated Thermal Rating: on line 7115-6807 : Rate B, Rate C , 0.0, 0.0 -> 3309
% INFO    : Updated Thermal Rating: on line 619-6791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45348
% INFO    : Updated Thermal Rating: on line 5418-4908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37527
% INFO    : Updated Thermal Rating: on line 5120-6816 : Rate B, Rate C , 0.0, 0.0 -> 2192
% INFO    : Updated Thermal Rating: on line 6692-9158 : Rate B, Rate C , 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 6692-8035 : Rate B, Rate C , 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 3445-2848 : Rate B, Rate C , 0.0, 0.0 -> 4712
% INFO    : Updated Thermal Rating: on line 3445-7056 : Rate B, Rate C , 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 3445-7056 : Rate B, Rate C , 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 3445-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on line 3445-4594 : Rate B, Rate C , 0.0, 0.0 -> 6495
% INFO    : Updated Thermal Rating: on line 6114-1692 : Rate B, Rate C , 0.0, 0.0 -> 7400
% INFO    : Updated Thermal Rating: on line 6114-8190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7268
% INFO    : Updated Thermal Rating: on line 6114-5836 : Rate B, Rate C , 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 6114-3191 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 6114-5300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 6114-4889 : Rate B, Rate C , 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 7264-444 : Rate B, Rate C , 0.0, 0.0 -> 1912
% INFO    : Updated Thermal Rating: on line 7264-4747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 7982-9011 : Rate B, Rate C , 0.0, 0.0 -> 25490
% INFO    : Updated Thermal Rating: on line 7982-6675 : Rate B, Rate C , 0.0, 0.0 -> 19252
% INFO    : Updated Thermal Rating: on line 7982-6909 : Rate B, Rate C , 0.0, 0.0 -> 27681
% INFO    : Updated Thermal Rating: on line 7982-8835 : Rate B, Rate C , 0.0, 0.0 -> 9714
% INFO    : Updated Thermal Rating: on line 7982-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25490
% INFO    : Updated Thermal Rating: on line 1604-502 : Rate B, Rate C , 0.0, 0.0 -> 22423
% INFO    : Updated Thermal Rating: on line 2842-502 : Rate B, Rate C , 0.0, 0.0 -> 20084
% INFO    : Updated Thermal Rating: on line 1354-513 : Rate B, Rate C , 0.0, 0.0 -> 3776
% INFO    : Updated Thermal Rating: on line 1354-502 : Rate B, Rate C , 0.0, 0.0 -> 6259
% INFO    : Updated Thermal Rating: on line 891-3697 : Rate B, Rate C , 0.0, 0.0 -> 6921
% INFO    : Updated Thermal Rating: on line 891-3697 : Rate B, Rate C , 0.0, 0.0 -> 6952
% INFO    : Updated Thermal Rating: on line 8312-7541 : Rate B, Rate C , 0.0, 0.0 -> 3162
% INFO    : Updated Thermal Rating: on line 8312-7541 : Rate B, Rate C , 0.0, 0.0 -> 3103
% INFO    : Updated Thermal Rating: on line 6306-4826 : Rate B, Rate C , 0.0, 0.0 -> 70039
% INFO    : Updated Thermal Rating: on line 4826-4418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66806
% INFO    : Updated Thermal Rating: on line 4826-1605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92032
% INFO    : Updated Thermal Rating: on line 4826-6952 : Rate B, Rate C , 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 4826-7124 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 9128-217 : Rate B, Rate C , 0.0, 0.0 -> 10923
% INFO    : Updated Thermal Rating: on line 7014-217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7964
% INFO    : Updated Thermal Rating: on line 720-5350 : Rate B, Rate C , 0.0, 0.0 -> 1764
% INFO    : Updated Thermal Rating: on line 720-5350 : Rate B, Rate C , 0.0, 0.0 -> 1730
% INFO    : Updated Thermal Rating: on line 1711-639 : Rate B, Rate C , 0.0, 0.0 -> 2771
% INFO    : Updated Thermal Rating: on line 1711-639 : Rate B, Rate C , 0.0, 0.0 -> 2720
% INFO    : Updated Thermal Rating: on line 1711-9130 : Rate B, Rate C , 0.0, 0.0 -> 3013
% INFO    : Updated Thermal Rating: on line 1711-9130 : Rate B, Rate C , 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 8209-1998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37606
% INFO    : Updated Thermal Rating: on line 8209-7974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21666
% INFO    : Updated Thermal Rating: on line 1035-8180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1958
% INFO    : Updated Thermal Rating: on line 1035-7466 : Rate B, Rate C , 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 1035-305 : Rate B, Rate C , 0.0, 0.0 -> 7089
% INFO    : Updated Thermal Rating: on line 1035-305 : Rate B, Rate C , 0.0, 0.0 -> 6970
% INFO    : Updated Thermal Rating: on line 1035-5106 : Rate B, Rate C , 0.0, 0.0 -> 3531
% INFO    : Updated Thermal Rating: on line 1035-5106 : Rate B, Rate C , 0.0, 0.0 -> 4433
% INFO    : Updated Thermal Rating: on line 2527-8466 : Rate B, Rate C , 0.0, 0.0 -> 5811
% INFO    : Updated Thermal Rating: on line 8669-8893 : Rate B, Rate C , 0.0, 0.0 -> 11214
% INFO    : Updated Thermal Rating: on line 6206-7691 : Rate B, Rate C , 0.0, 0.0 -> 1676
% INFO    : Updated Thermal Rating: on line 6206-6624 : Rate B, Rate C , 0.0, 0.0 -> 2206
% INFO    : Updated Thermal Rating: on line 3240-8158 : Rate B, Rate C , 0.0, 0.0 -> 4292
% INFO    : Updated Thermal Rating: on line 3240-8795 : Rate B, Rate C , 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 3240-4143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7181
% INFO    : Updated Thermal Rating: on line 3240-2797 : Rate B, Rate C , 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 3240-6331 : Rate B, Rate C , 0.0, 0.0 -> 2673
% INFO    : Updated Thermal Rating: on line 3240-6384 : Rate B, Rate C , 0.0, 0.0 -> 2795
% INFO    : Updated Thermal Rating: on line 3240-7523 : Rate B, Rate C , 0.0, 0.0 -> 3327
% INFO    : Updated Thermal Rating: on line 3240-2889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13596
% INFO    : Updated Thermal Rating: on line 3240-6887 : Rate B, Rate C , 0.0, 0.0 -> 1729
% INFO    : Updated Thermal Rating: on line 1249-4541 : Rate B, Rate C , 0.0, 0.0 -> 4424
% INFO    : Updated Thermal Rating: on line 819-7523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9048
% INFO    : Updated Thermal Rating: on line 2304-4353 : Rate B, Rate C , 0.0, 0.0 -> 3847
% INFO    : Updated Thermal Rating: on line 2304-4816 : Rate B, Rate C , 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on line 9174-6246 : Rate B, Rate C , 0.0, 0.0 -> 3756
% INFO    : Updated Thermal Rating: on line 9174-6246 : Rate B, Rate C , 0.0, 0.0 -> 3682
% INFO    : Updated Thermal Rating: on line 9174-5658 : Rate B, Rate C , 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 9174-5658 : Rate B, Rate C , 0.0, 0.0 -> 1979
% INFO    : Updated Thermal Rating: on line 2924-3645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12101
% INFO    : Updated Thermal Rating: on line 2924-3645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12156
% INFO    : Updated Thermal Rating: on line 59-5764 : Rate B, Rate C , 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 59-2360 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 6510-9033 : Rate B, Rate C , 0.0, 0.0 -> 27118
% INFO    : Updated Thermal Rating: on line 6510-5918 : Rate B, Rate C , 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 6510-5918 : Rate B, Rate C , 0.0, 0.0 -> 2498
% INFO    : Updated Thermal Rating: on line 1275-2850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7597
% INFO    : Updated Thermal Rating: on line 6426-4110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 6426-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 1758-2816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5059
% INFO    : Updated Thermal Rating: on line 1758-352 : Rate B, Rate C , 0.0, 0.0 -> 4370
% INFO    : Updated Thermal Rating: on line 1758-6581 : Rate B, Rate C , 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 1758-1923 : Rate B, Rate C , 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 1758-5837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 1758-3830 : Rate B, Rate C , 0.0, 0.0 -> 1671
% INFO    : Updated Thermal Rating: on line 1758-3577 : Rate B, Rate C , 0.0, 0.0 -> 8198
% INFO    : Updated Thermal Rating: on line 8030-1794 : Rate B, Rate C , 0.0, 0.0 -> 4858
% INFO    : Updated Thermal Rating: on line 8030-7808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4792
% INFO    : Updated Thermal Rating: on line 8030-6581 : Rate B, Rate C , 0.0, 0.0 -> 4130
% INFO    : Updated Thermal Rating: on line 8030-1923 : Rate B, Rate C , 0.0, 0.0 -> 1968
% INFO    : Updated Thermal Rating: on line 8030-5837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2707
% INFO    : Updated Thermal Rating: on line 8030-5648 : Rate B, Rate C , 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 8030-3577 : Rate B, Rate C , 0.0, 0.0 -> 8371
% INFO    : Updated Thermal Rating: on line 4615-171 : Rate B, Rate C , 0.0, 0.0 -> 2578
% INFO    : Updated Thermal Rating: on line 3137-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84603
% INFO    : Updated Thermal Rating: on line 6271-8787 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on line 6252-9137 : Rate B, Rate C , 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 5533-7133 : Rate B, Rate C , 0.0, 0.0 -> 2183
% INFO    : Updated Thermal Rating: on line 8361-4355 : Rate B, Rate C , 0.0, 0.0 -> 67762
% INFO    : Updated Thermal Rating: on line 8361-2928 : Rate B, Rate C , 0.0, 0.0 -> 30454
% INFO    : Updated Thermal Rating: on line 609-1341 : Rate B, Rate C , 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 609-5419 : Rate B, Rate C , 0.0, 0.0 -> 7777
% INFO    : Updated Thermal Rating: on line 609-5419 : Rate B, Rate C , 0.0, 0.0 -> 7651
% INFO    : Updated Thermal Rating: on line 609-2079 : Rate B, Rate C , 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 609-772 : Rate B, Rate C , 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 3654-2928 : Rate B, Rate C , 0.0, 0.0 -> 26642
% INFO    : Updated Thermal Rating: on line 1355-7282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 1355-2197 : Rate B, Rate C , 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 1355-7640 : Rate B, Rate C , 0.0, 0.0 -> 2019
% INFO    : Updated Thermal Rating: on line 1355-1081 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 1355-1081 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on line 1355-2359 : Rate B, Rate C , 0.0, 0.0 -> 3422
% INFO    : Updated Thermal Rating: on line 1355-4196 : Rate B, Rate C , 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 5856-8546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2811
% INFO    : Updated Thermal Rating: on line 5856-5987 : Rate B, Rate C , 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 5856-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 5856-3925 : Rate B, Rate C , 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on line 5856-3324 : Rate B, Rate C , 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 5856-4748 : Rate B, Rate C , 0.0, 0.0 -> 2964
% INFO    : Updated Thermal Rating: on line 8265-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11971
% INFO    : Updated Thermal Rating: on line 6151-6313 : Rate B, Rate C , 0.0, 0.0 -> 9442
% INFO    : Updated Thermal Rating: on line 4005-6532 : Rate B, Rate C , 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 4005-2177 : Rate B, Rate C , 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 5723-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on line 5723-789 : Rate B, Rate C , 0.0, 0.0 -> 1683
% INFO    : Updated Thermal Rating: on line 2327-9189 : Rate B, Rate C , 0.0, 0.0 -> 22821
% INFO    : Updated Thermal Rating: on line 2327-3400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21440
% INFO    : Updated Thermal Rating: on line 207-4747 : Rate B, Rate C , 0.0, 0.0 -> 2328
% INFO    : Updated Thermal Rating: on line 207-7791 : Rate B, Rate C , 0.0, 0.0 -> 5519
% INFO    : Updated Thermal Rating: on line 3205-6735 : Rate B, Rate C , 0.0, 0.0 -> 75017
% INFO    : Updated Thermal Rating: on line 3205-666 : Rate B, Rate C , 0.0, 0.0 -> 3501
% INFO    : Updated Thermal Rating: on line 3205-666 : Rate B, Rate C , 0.0, 0.0 -> 3579
% INFO    : Updated Thermal Rating: on line 3205-4435 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 3205-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3991
% INFO    : Updated Thermal Rating: on line 3205-3483 : Rate B, Rate C , 0.0, 0.0 -> 3742
% INFO    : Updated Thermal Rating: on line 4683-7989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25173
% INFO    : Updated Thermal Rating: on line 4683-6516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28780
% INFO    : Updated Thermal Rating: on line 4683-7697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25191
% INFO    : Updated Thermal Rating: on line 4683-416 : Rate B, Rate C , 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 4683-2847 : Rate B, Rate C , 0.0, 0.0 -> 2810
% INFO    : Updated Thermal Rating: on line 4683-2563 : Rate B, Rate C , 0.0, 0.0 -> 2871
% INFO    : Updated Thermal Rating: on line 4683-2563 : Rate B, Rate C , 0.0, 0.0 -> 2961
% INFO    : Updated Thermal Rating: on line 4683-2995 : Rate B, Rate C , 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on line 5691-1001 : Rate A, Rate B, Rate C , 610.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5691-4426 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 5350-2721 : Rate B, Rate C , 0.0, 0.0 -> 4683
% INFO    : Updated Thermal Rating: on line 5350-2721 : Rate B, Rate C , 0.0, 0.0 -> 4773
% INFO    : Updated Thermal Rating: on line 2361-4936 : Rate B, Rate C , 0.0, 0.0 -> 3215
% INFO    : Updated Thermal Rating: on line 2361-5179 : Rate B, Rate C , 0.0, 0.0 -> 2630
% INFO    : Updated Thermal Rating: on line 2044-4748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16743
% INFO    : Updated Thermal Rating: on line 4197-5522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14024
% INFO    : Updated Thermal Rating: on line 5699-8670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12826
% INFO    : Updated Thermal Rating: on line 7809-5110 : Rate B, Rate C , 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 7222-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 4402-3817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113538
% INFO    : Updated Thermal Rating: on line 6857-2732 : Rate B, Rate C , 0.0, 0.0 -> 4391
% INFO    : Updated Thermal Rating: on line 6857-4550 : Rate B, Rate C , 0.0, 0.0 -> 4740
% INFO    : Updated Thermal Rating: on line 6857-4339 : Rate B, Rate C , 0.0, 0.0 -> 2079
% INFO    : Updated Thermal Rating: on line 6857-7513 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 5016-26 : Rate B, Rate C , 0.0, 0.0 -> 5182
% INFO    : Updated Thermal Rating: on line 5016-9213 : Rate B, Rate C , 0.0, 0.0 -> 6285
% INFO    : Updated Thermal Rating: on line 6112-9002 : Rate B, Rate C , 0.0, 0.0 -> 2344
% INFO    : Updated Thermal Rating: on line 6112-6231 : Rate B, Rate C , 0.0, 0.0 -> 2089
% INFO    : Updated Thermal Rating: on line 6112-883 : Rate B, Rate C , 0.0, 0.0 -> 1654
% INFO    : Updated Thermal Rating: on line 6112-5738 : Rate B, Rate C , 0.0, 0.0 -> 2297
% INFO    : Updated Thermal Rating: on line 8860-7700 : Rate B, Rate C , 0.0, 0.0 -> 3302
% INFO    : Updated Thermal Rating: on line 8860-9002 : Rate B, Rate C , 0.0, 0.0 -> 2693
% INFO    : Updated Thermal Rating: on line 8860-5990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 8860-6450 : Rate B, Rate C , 0.0, 0.0 -> 2234
% INFO    : Updated Thermal Rating: on line 8860-7726 : Rate B, Rate C , 0.0, 0.0 -> 4269
% INFO    : Updated Thermal Rating: on line 2489-4110 : Rate B, Rate C , 0.0, 0.0 -> 7985
% INFO    : Updated Thermal Rating: on line 3985-6376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1596
% INFO    : Updated Thermal Rating: on line 3985-4110 : Rate B, Rate C , 0.0, 0.0 -> 7062
% INFO    : Updated Thermal Rating: on line 3985-4829 : Rate B, Rate C , 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 3985-7857 : Rate B, Rate C , 0.0, 0.0 -> 6817
% INFO    : Updated Thermal Rating: on line 2806-7857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6858
% INFO    : Updated Thermal Rating: on line 2489-9012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5335
% INFO    : Updated Thermal Rating: on line 2489-2231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5728
% INFO    : Updated Thermal Rating: on line 658-3793 : Rate B, Rate C , 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 658-8497 : Rate B, Rate C , 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 658-8497 : Rate B, Rate C , 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 3502-9002 : Rate B, Rate C , 0.0, 0.0 -> 34833
% INFO    : Updated Thermal Rating: on line 3502-9002 : Rate B, Rate C , 0.0, 0.0 -> 31811
% INFO    : Updated Thermal Rating: on line 6313-44 : Rate B, Rate C , 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 6313-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1387
% INFO    : Updated Thermal Rating: on line 5944-8808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17349
% INFO    : Updated Thermal Rating: on line 3183-8515 : Rate B, Rate C , 0.0, 0.0 -> 2903
% INFO    : Updated Thermal Rating: on line 1005-8515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3155
% INFO    : Updated Thermal Rating: on line 8787-1448 : Rate B, Rate C , 0.0, 0.0 -> 2543
% INFO    : Updated Thermal Rating: on line 6636-9051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41134
% INFO    : Updated Thermal Rating: on line 9109-9051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45856
% INFO    : Updated Thermal Rating: on line 6961-6376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 6961-8818 : Rate B, Rate C , 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 5077-4353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23256
% INFO    : Updated Thermal Rating: on line 7471-5241 : Rate B, Rate C , 0.0, 0.0 -> 1935
% INFO    : Updated Thermal Rating: on line 7471-8200 : Rate B, Rate C , 0.0, 0.0 -> 50038
% INFO    : Updated Thermal Rating: on line 549-6290 : Rate B, Rate C , 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 549-2291 : Rate B, Rate C , 0.0, 0.0 -> 1410
% INFO    : Updated Thermal Rating: on line 549-3656 : Rate B, Rate C , 0.0, 0.0 -> 2991
% INFO    : Updated Thermal Rating: on line 5002-4144 : Rate B, Rate C , 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 1888-5441 : Rate B, Rate C , 0.0, 0.0 -> 10884
% INFO    : Updated Thermal Rating: on line 1888-5441 : Rate B, Rate C , 0.0, 0.0 -> 10446
% INFO    : Updated Thermal Rating: on line 5490-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4899
% INFO    : Updated Thermal Rating: on line 5490-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4772
% INFO    : Updated Thermal Rating: on line 5490-4970 : Rate B, Rate C , 0.0, 0.0 -> 4325
% INFO    : Updated Thermal Rating: on line 5490-5461 : Rate B, Rate C , 0.0, 0.0 -> 3631
% INFO    : Updated Thermal Rating: on line 5490-7778 : Rate B, Rate C , 0.0, 0.0 -> 2930
% INFO    : Updated Thermal Rating: on line 5490-6897 : Rate B, Rate C , 0.0, 0.0 -> 2877
% INFO    : Updated Thermal Rating: on line 3075-4562 : Rate B, Rate C , 0.0, 0.0 -> 6077
% INFO    : Updated Thermal Rating: on line 564-8475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 564-2252 : Rate B, Rate C , 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 564-7903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 4331-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 2877-3674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5705
% INFO    : Updated Thermal Rating: on line 2854-1081 : Rate A, Rate B, Rate C , 1020.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 2854-8267 : Rate B, Rate C , 0.0, 0.0 -> 2146
% INFO    : Updated Thermal Rating: on line 9112-9176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 9112-1422 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 9112-8515 : Rate B, Rate C , 0.0, 0.0 -> 1775
% INFO    : Updated Thermal Rating: on line 9112-8515 : Rate B, Rate C , 0.0, 0.0 -> 1879
% INFO    : Updated Thermal Rating: on line 9112-5051 : Rate B, Rate C , 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 9112-1051 : Rate B, Rate C , 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 9112-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 9112-1584 : Rate B, Rate C , 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 6168-6888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1835
% INFO    : Updated Thermal Rating: on line 7653-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 7341-7098 : Rate B, Rate C , 0.0, 0.0 -> 4392
% INFO    : Updated Thermal Rating: on line 4701-8267 : Rate B, Rate C , 0.0, 0.0 -> 31398
% INFO    : Updated Thermal Rating: on line 1672-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30565
% INFO    : Updated Thermal Rating: on line 3880-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29969
% INFO    : Updated Thermal Rating: on line 6648-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30207
% INFO    : Updated Thermal Rating: on line 3609-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31096
% INFO    : Updated Thermal Rating: on line 2782-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28500
% INFO    : Updated Thermal Rating: on line 1844-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29005
% INFO    : Updated Thermal Rating: on line 4353-6053 : Rate B, Rate C , 0.0, 0.0 -> 2550
% INFO    : Updated Thermal Rating: on line 2166-5237 : Rate B, Rate C , 0.0, 0.0 -> 16450
% INFO    : Updated Thermal Rating: on line 2166-2886 : Rate B, Rate C , 0.0, 0.0 -> 2906
% INFO    : Updated Thermal Rating: on line 1043-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157740
% INFO    : Updated Thermal Rating: on line 4049-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98903
% INFO    : Updated Thermal Rating: on line 4520-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89464
% INFO    : Updated Thermal Rating: on line 1704-5814 : Rate B, Rate C , 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 8107-1486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49257
% INFO    : Updated Thermal Rating: on line 5664-5522 : Rate B, Rate C , 0.0, 0.0 -> 7545
% INFO    : Updated Thermal Rating: on line 4482-8670 : Rate B, Rate C , 0.0, 0.0 -> 7692
% INFO    : Updated Thermal Rating: on line 8795-7523 : Rate B, Rate C , 0.0, 0.0 -> 2355
% INFO    : Updated Thermal Rating: on line 2337-6430 : Rate B, Rate C , 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 455-7775 : Rate B, Rate C , 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 455-3857 : Rate B, Rate C , 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 455-333 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 455-6940 : Rate B, Rate C , 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on line 8225-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5843
% INFO    : Updated Thermal Rating: on line 5413-7752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1699
% INFO    : Updated Thermal Rating: on line 5413-1940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 5413-4234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 2591-6828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 2591-7571 : Rate B, Rate C , 0.0, 0.0 -> 1233
% INFO    : Updated Thermal Rating: on line 2591-7571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1679
% INFO    : Updated Thermal Rating: on line 2591-7571 : Rate B, Rate C , 0.0, 0.0 -> 1437
% INFO    : Updated Thermal Rating: on line 2591-7994 : Rate B, Rate C , 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 2591-7226 : Rate B, Rate C , 0.0, 0.0 -> 1711
% INFO    : Updated Thermal Rating: on line 2591-1554 : Rate B, Rate C , 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 9011-1156 : Rate B, Rate C , 0.0, 0.0 -> 7870
% INFO    : Updated Thermal Rating: on line 8689-5502 : Rate B, Rate C , 0.0, 0.0 -> 3499
% INFO    : Updated Thermal Rating: on line 3085-8873 : Rate B, Rate C , 0.0, 0.0 -> 2346
% INFO    : Updated Thermal Rating: on line 1568-980 : Rate B, Rate C , 0.0, 0.0 -> 50801
% INFO    : Updated Thermal Rating: on line 3204-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2659
% INFO    : Updated Thermal Rating: on line 3557-639 : Rate B, Rate C , 0.0, 0.0 -> 4539
% INFO    : Updated Thermal Rating: on line 3557-4936 : Rate B, Rate C , 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 416-3492 : Rate B, Rate C , 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 416-7937 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 3255-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1762
% INFO    : Updated Thermal Rating: on line 3255-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49730
% INFO    : Updated Thermal Rating: on line 7373-367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 4251-2132 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 4251-2132 : Rate B, Rate C , 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 4251-5567 : Rate B, Rate C , 0.0, 0.0 -> 2996
% INFO    : Updated Thermal Rating: on line 6376-1808 : Rate B, Rate C , 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 6376-1808 : Rate B, Rate C , 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 6376-7857 : Rate B, Rate C , 0.0, 0.0 -> 1826
% INFO    : Updated Thermal Rating: on line 9185-7289 : Rate B, Rate C , 0.0, 0.0 -> 4058
% INFO    : Updated Thermal Rating: on line 9185-3999 : Rate B, Rate C , 0.0, 0.0 -> 45778
% INFO    : Updated Thermal Rating: on line 8653-2303 : Rate B, Rate C , 0.0, 0.0 -> 4384
% INFO    : Updated Thermal Rating: on line 908-6474 : Rate B, Rate C , 0.0, 0.0 -> 16400
% INFO    : Updated Thermal Rating: on line 7030-6474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14972
% INFO    : Updated Thermal Rating: on line 4205-6556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18862
% INFO    : Updated Thermal Rating: on line 7325-6556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18455
% INFO    : Updated Thermal Rating: on line 5857-3391 : Rate B, Rate C , 0.0, 0.0 -> 3688
% INFO    : Updated Thermal Rating: on line 5857-3760 : Rate B, Rate C , 0.0, 0.0 -> 5049
% INFO    : Updated Thermal Rating: on line 3707-8765 : Rate B, Rate C , 0.0, 0.0 -> 24790
% INFO    : Updated Thermal Rating: on line 900-6619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21835
% INFO    : Updated Thermal Rating: on line 2918-8109 : Rate A, Rate B, Rate C , 1876.0, 0.0, 0.0 -> 1755
% INFO    : Updated Thermal Rating: on line 2918-8109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 6532-2177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 6532-5317 : Rate A, Rate B, Rate C , 610.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 6532-608 : Rate B, Rate C , 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 6532-608 : Rate B, Rate C , 0.0, 0.0 -> 990
% INFO    : Updated Thermal Rating: on line 4494-8763 : Rate B, Rate C , 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on line 4494-7056 : Rate B, Rate C , 0.0, 0.0 -> 2375
% INFO    : Updated Thermal Rating: on line 6828-5814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 3670-21 : Rate B, Rate C , 0.0, 0.0 -> 22404
% INFO    : Updated Thermal Rating: on line 5137-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5156
% INFO    : Updated Thermal Rating: on line 1334-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5264
% INFO    : Updated Thermal Rating: on line 8448-7624 : Rate B, Rate C , 0.0, 0.0 -> 3961
% INFO    : Updated Thermal Rating: on line 8448-1129 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 8448-3070 : Rate B, Rate C , 0.0, 0.0 -> 1457
% INFO    : Updated Thermal Rating: on line 8448-306 : Rate B, Rate C , 0.0, 0.0 -> 3020
% INFO    : Updated Thermal Rating: on line 8448-306 : Rate B, Rate C , 0.0, 0.0 -> 2963
% INFO    : Updated Thermal Rating: on line 8448-7491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 4685-2089 : Rate B, Rate C , 0.0, 0.0 -> 35750
% INFO    : Updated Thermal Rating: on line 7485-6253 : Rate B, Rate C , 0.0, 0.0 -> 25882
% INFO    : Updated Thermal Rating: on line 7485-1562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38849
% INFO    : Updated Thermal Rating: on line 7776-1644 : Rate B, Rate C , 0.0, 0.0 -> 10592
% INFO    : Updated Thermal Rating: on line 5971-3483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10925
% INFO    : Updated Thermal Rating: on line 2786-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9741
% INFO    : Updated Thermal Rating: on line 972-3483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9474
% INFO    : Updated Thermal Rating: on line 8906-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29496
% INFO    : Updated Thermal Rating: on line 8906-4914 : Rate B, Rate C , 0.0, 0.0 -> 29418
% INFO    : Updated Thermal Rating: on line 2656-9101 : Rate B, Rate C , 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 2656-7164 : Rate A, Rate B, Rate C , 1876.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on line 3519-9101 : Rate B, Rate C , 0.0, 0.0 -> 1430
% INFO    : Updated Thermal Rating: on line 3519-7164 : Rate B, Rate C , 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 1775-9137 : Rate B, Rate C , 0.0, 0.0 -> 2649
% INFO    : Updated Thermal Rating: on line 1775-9137 : Rate B, Rate C , 0.0, 0.0 -> 3236
% INFO    : Updated Thermal Rating: on line 5641-1026 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 5641-9137 : Rate B, Rate C , 0.0, 0.0 -> 3297
% INFO    : Updated Thermal Rating: on line 1096-2889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17110
% INFO    : Updated Thermal Rating: on line 7380-2732 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on line 7380-4787 : Rate B, Rate C , 0.0, 0.0 -> 29975
% INFO    : Updated Thermal Rating: on line 3543-5308 : Rate B, Rate C , 0.0, 0.0 -> 3899
% INFO    : Updated Thermal Rating: on line 3543-3830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4697
% INFO    : Updated Thermal Rating: on line 2372-1027 : Rate B, Rate C , 0.0, 0.0 -> 4210
% INFO    : Updated Thermal Rating: on line 2372-5648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4991
% INFO    : Updated Thermal Rating: on line 367-1172 : Rate B, Rate C , 0.0, 0.0 -> 3570
% INFO    : Updated Thermal Rating: on line 367-9191 : Rate B, Rate C , 0.0, 0.0 -> 5103
% INFO    : Updated Thermal Rating: on line 367-8722 : Rate B, Rate C , 0.0, 0.0 -> 5087
% INFO    : Updated Thermal Rating: on line 1833-3610 : Rate B, Rate C , 0.0, 0.0 -> 8331
% INFO    : Updated Thermal Rating: on line 1833-3610 : Rate B, Rate C , 0.0, 0.0 -> 9649
% INFO    : Updated Thermal Rating: on line 1833-3962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3558
% INFO    : Updated Thermal Rating: on line 1833-1838 : Rate B, Rate C , 0.0, 0.0 -> 6744
% INFO    : Updated Thermal Rating: on line 1833-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6876
% INFO    : Updated Thermal Rating: on line 5388-2467 : Rate B, Rate C , 0.0, 0.0 -> 2041
% INFO    : Updated Thermal Rating: on line 5388-2467 : Rate B, Rate C , 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 6110-8853 : Rate B, Rate C , 0.0, 0.0 -> 5394
% INFO    : Updated Thermal Rating: on line 6110-1001 : Rate B, Rate C , 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 7583-1808 : Rate B, Rate C , 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 7583-2889 : Rate B, Rate C , 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on line 26-6624 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 26-2479 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 26-4598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2160
% INFO    : Updated Thermal Rating: on line 26-4231 : Rate B, Rate C , 0.0, 0.0 -> 3184
% INFO    : Updated Thermal Rating: on line 26-5144 : Rate B, Rate C , 0.0, 0.0 -> 6520
% INFO    : Updated Thermal Rating: on line 26-5144 : Rate B, Rate C , 0.0, 0.0 -> 7895
% INFO    : Updated Thermal Rating: on line 7691-2479 : Rate B, Rate C , 0.0, 0.0 -> 1827
% INFO    : Updated Thermal Rating: on line 7691-2129 : Rate B, Rate C , 0.0, 0.0 -> 2120
% INFO    : Updated Thermal Rating: on line 7691-9213 : Rate B, Rate C , 0.0, 0.0 -> 9168
% INFO    : Updated Thermal Rating: on line 7691-9213 : Rate B, Rate C , 0.0, 0.0 -> 12700
% INFO    : Updated Thermal Rating: on line 7691-4231 : Rate B, Rate C , 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 7691-3513 : Rate B, Rate C , 0.0, 0.0 -> 6651
% INFO    : Updated Thermal Rating: on line 7691-3513 : Rate B, Rate C , 0.0, 0.0 -> 7915
% INFO    : Updated Thermal Rating: on line 1876-3906 : Rate B, Rate C , 0.0, 0.0 -> 6116
% INFO    : Updated Thermal Rating: on line 113-3906 : Rate B, Rate C , 0.0, 0.0 -> 6246
% INFO    : Updated Thermal Rating: on line 7752-3758 : Rate B, Rate C , 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 7752-3758 : Rate B, Rate C , 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on line 7752-3758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1538
% INFO    : Updated Thermal Rating: on line 4952-8976 : Rate B, Rate C , 0.0, 0.0 -> 2888
% INFO    : Updated Thermal Rating: on line 4952-8189 : Rate B, Rate C , 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on line 6119-7886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 6119-4544 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 6119-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2080
% INFO    : Updated Thermal Rating: on line 7905-3697 : Rate B, Rate C , 0.0, 0.0 -> 1941
% INFO    : Updated Thermal Rating: on line 7905-7541 : Rate B, Rate C , 0.0, 0.0 -> 7052
% INFO    : Updated Thermal Rating: on line 7905-7541 : Rate B, Rate C , 0.0, 0.0 -> 8133
% INFO    : Updated Thermal Rating: on line 7905-4141 : Rate B, Rate C , 0.0, 0.0 -> 2731
% INFO    : Updated Thermal Rating: on line 7905-4141 : Rate B, Rate C , 0.0, 0.0 -> 2678
% INFO    : Updated Thermal Rating: on line 7905-3022 : Rate B, Rate C , 0.0, 0.0 -> 2102
% INFO    : Updated Thermal Rating: on line 1768-163 : Rate B, Rate C , 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 4245-2425 : Rate B, Rate C , 0.0, 0.0 -> 25068
% INFO    : Updated Thermal Rating: on line 3698-5297 : Rate B, Rate C , 0.0, 0.0 -> 45030
% INFO    : Updated Thermal Rating: on line 750-8328 : Rate B, Rate C , 0.0, 0.0 -> 25940
% INFO    : Updated Thermal Rating: on line 750-870 : Rate B, Rate C , 0.0, 0.0 -> 21222
% INFO    : Updated Thermal Rating: on line 750-2961 : Rate B, Rate C , 0.0, 0.0 -> 45595
% INFO    : Updated Thermal Rating: on line 3499-7988 : Rate B, Rate C , 0.0, 0.0 -> 4620
% INFO    : Updated Thermal Rating: on line 3499-2197 : Rate B, Rate C , 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on line 3499-7640 : Rate B, Rate C , 0.0, 0.0 -> 2652
% INFO    : Updated Thermal Rating: on line 3499-4231 : Rate B, Rate C , 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 3499-5144 : Rate B, Rate C , 0.0, 0.0 -> 2438
% INFO    : Updated Thermal Rating: on line 3499-3513 : Rate B, Rate C , 0.0, 0.0 -> 2485
% INFO    : Updated Thermal Rating: on line 7289-3999 : Rate B, Rate C , 0.0, 0.0 -> 4537
% INFO    : Updated Thermal Rating: on line 3018-1051 : Rate B, Rate C , 0.0, 0.0 -> 89200
% INFO    : Updated Thermal Rating: on line 2702-3435 : Rate B, Rate C , 0.0, 0.0 -> 43865
% INFO    : Updated Thermal Rating: on line 9131-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42767
% INFO    : Updated Thermal Rating: on line 6308-6684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29632
% INFO    : Updated Thermal Rating: on line 4831-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 837
% INFO    : Updated Thermal Rating: on line 5410-2751 : Rate B, Rate C , 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 3082-4623 : Rate B, Rate C , 0.0, 0.0 -> 2470
% INFO    : Updated Thermal Rating: on line 3082-4339 : Rate B, Rate C , 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 3082-5288 : Rate B, Rate C , 0.0, 0.0 -> 105881
% INFO    : Updated Thermal Rating: on line 3082-5421 : Rate B, Rate C , 0.0, 0.0 -> 39728
% INFO    : Updated Thermal Rating: on line 3082-6475 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1535
% INFO    : Updated Thermal Rating: on line 3082-8468 : Rate B, Rate C , 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 6224-2732 : Rate B, Rate C , 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on line 6224-7513 : Rate B, Rate C , 0.0, 0.0 -> 2808
% INFO    : Updated Thermal Rating: on line 6224-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1844
% INFO    : Updated Thermal Rating: on line 2174-4623 : Rate B, Rate C , 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 2174-4550 : Rate B, Rate C , 0.0, 0.0 -> 1809
% INFO    : Updated Thermal Rating: on line 2174-6475 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 2083-9231 : Rate B, Rate C , 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 2083-9231 : Rate B, Rate C , 0.0, 0.0 -> 2107
% INFO    : Updated Thermal Rating: on line 2083-9231 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 2083-4054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36840
% INFO    : Updated Thermal Rating: on line 2083-3481 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 2083-3602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3104
% INFO    : Updated Thermal Rating: on line 2083-2794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12197
% INFO    : Updated Thermal Rating: on line 2083-2794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13903
% INFO    : Updated Thermal Rating: on line 2083-8467 : Rate B, Rate C , 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 2083-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4796
% INFO    : Updated Thermal Rating: on line 2083-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4752
% INFO    : Updated Thermal Rating: on line 8853-1001 : Rate B, Rate C , 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 8853-4950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 8853-4410 : Rate B, Rate C , 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 8853-6697 : Rate B, Rate C , 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 8853-1159 : Rate B, Rate C , 0.0, 0.0 -> 2874
% INFO    : Updated Thermal Rating: on line 8853-7165 : Rate B, Rate C , 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 2938-2848 : Rate B, Rate C , 0.0, 0.0 -> 5758
% INFO    : Updated Thermal Rating: on line 2938-2848 : Rate B, Rate C , 0.0, 0.0 -> 5875
% INFO    : Updated Thermal Rating: on line 2938-7522 : Rate B, Rate C , 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 2938-7522 : Rate B, Rate C , 0.0, 0.0 -> 2025
% INFO    : Updated Thermal Rating: on line 2938-1642 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1418
% INFO    : Updated Thermal Rating: on line 2938-809 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1448
% INFO    : Updated Thermal Rating: on line 9189-6791 : Rate B, Rate C , 0.0, 0.0 -> 9227
% INFO    : Updated Thermal Rating: on line 9189-3400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37102
% INFO    : Updated Thermal Rating: on line 9189-7092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10077
% INFO    : Updated Thermal Rating: on line 9189-3718 : Rate B, Rate C , 0.0, 0.0 -> 12119
% INFO    : Updated Thermal Rating: on line 9189-3701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13958
% INFO    : Updated Thermal Rating: on line 9189-7507 : Rate B, Rate C , 0.0, 0.0 -> 3272
% INFO    : Updated Thermal Rating: on line 9189-7507 : Rate B, Rate C , 0.0, 0.0 -> 2926
% INFO    : Updated Thermal Rating: on line 9189-7507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3642
% INFO    : Updated Thermal Rating: on line 9189-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4517
% INFO    : Updated Thermal Rating: on line 2801-8511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37687
% INFO    : Updated Thermal Rating: on line 2801-216 : Rate B, Rate C , 0.0, 0.0 -> 4920
% INFO    : Updated Thermal Rating: on line 453-2129 : Rate B, Rate C , 0.0, 0.0 -> 11419
% INFO    : Updated Thermal Rating: on line 8691-6952 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 8691-6952 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 8691-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 8691-4410 : Rate B, Rate C , 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 8691-8743 : Rate B, Rate C , 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 2446-8763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4461
% INFO    : Updated Thermal Rating: on line 2627-8763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4501
% INFO    : Updated Thermal Rating: on line 4951-6785 : Rate B, Rate C , 0.0, 0.0 -> 1793
% INFO    : Updated Thermal Rating: on line 4951-6785 : Rate B, Rate C , 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 4623-964 : Rate B, Rate C , 0.0, 0.0 -> 3346
% INFO    : Updated Thermal Rating: on line 4623-964 : Rate B, Rate C , 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 4623-8347 : Rate B, Rate C , 0.0, 0.0 -> 5920
% INFO    : Updated Thermal Rating: on line 4623-8347 : Rate B, Rate C , 0.0, 0.0 -> 6655
% INFO    : Updated Thermal Rating: on line 4623-8347 : Rate B, Rate C , 0.0, 0.0 -> 6285
% INFO    : Updated Thermal Rating: on line 1609-6552 : Rate B, Rate C , 0.0, 0.0 -> 4907
% INFO    : Updated Thermal Rating: on line 1609-6552 : Rate B, Rate C , 0.0, 0.0 -> 4995
% INFO    : Updated Thermal Rating: on line 1609-8999 : Rate B, Rate C , 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 4368-4816 : Rate B, Rate C , 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 5481-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150246
% INFO    : Updated Thermal Rating: on line 7913-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126249
% INFO    : Updated Thermal Rating: on line 506-960 : Rate B, Rate C , 0.0, 0.0 -> 101684
% INFO    : Updated Thermal Rating: on line 2980-960 : Rate B, Rate C , 0.0, 0.0 -> 78748
% INFO    : Updated Thermal Rating: on line 4554-6382 : Rate B, Rate C , 0.0, 0.0 -> 6562
% INFO    : Updated Thermal Rating: on line 4554-6382 : Rate B, Rate C , 0.0, 0.0 -> 6397
% INFO    : Updated Thermal Rating: on line 6844-1595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 3672-5334 : Rate B, Rate C , 0.0, 0.0 -> 10281
% INFO    : Updated Thermal Rating: on line 6219-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10093
% INFO    : Updated Thermal Rating: on line 8997-6153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2955
% INFO    : Updated Thermal Rating: on line 1852-5935 : Rate B, Rate C , 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 1852-5695 : Rate B, Rate C , 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 2931-5799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1584
% INFO    : Updated Thermal Rating: on line 2931-7124 : Rate B, Rate C , 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 2598-3674 : Rate B, Rate C , 0.0, 0.0 -> 2061
% INFO    : Updated Thermal Rating: on line 2598-2132 : Rate B, Rate C , 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 2558-7571 : Rate B, Rate C , 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 8834-1129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 7377-3324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4788
% INFO    : Updated Thermal Rating: on line 1265-4426 : Rate B, Rate C , 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 1265-1965 : Rate B, Rate C , 0.0, 0.0 -> 1550
% INFO    : Updated Thermal Rating: on line 8060-7162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61700
% INFO    : Updated Thermal Rating: on line 6922-5482 : Rate B, Rate C , 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 6922-1295 : Rate B, Rate C , 0.0, 0.0 -> 21414
% INFO    : Updated Thermal Rating: on line 8369-4710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 8961-7133 : Rate B, Rate C , 0.0, 0.0 -> 4377
% INFO    : Updated Thermal Rating: on line 8961-6888 : Rate B, Rate C , 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 4185-7019 : Rate B, Rate C , 0.0, 0.0 -> 64904
% INFO    : Updated Thermal Rating: on line 4185-6253 : Rate B, Rate C , 0.0, 0.0 -> 40281
% INFO    : Updated Thermal Rating: on line 7895-3391 : Rate B, Rate C , 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 7895-1448 : Rate B, Rate C , 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 7895-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 7895-115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 5589-4306 : Rate B, Rate C , 0.0, 0.0 -> 131160
% INFO    : Updated Thermal Rating: on line 5589-1763 : Rate B, Rate C , 0.0, 0.0 -> 150246
% INFO    : Updated Thermal Rating: on line 5589-3697 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 5589-3794 : Rate B, Rate C , 0.0, 0.0 -> 2658
% INFO    : Updated Thermal Rating: on line 5589-3613 : Rate B, Rate C , 0.0, 0.0 -> 2358
% INFO    : Updated Thermal Rating: on line 5589-1502 : Rate B, Rate C , 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 5589-6555 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 5589-3608 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 1001-4134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26320
% INFO    : Updated Thermal Rating: on line 1001-1979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33184
% INFO    : Updated Thermal Rating: on line 1001-516 : Rate B, Rate C , 0.0, 0.0 -> 48317
% INFO    : Updated Thermal Rating: on line 1001-3580 : Rate B, Rate C , 0.0, 0.0 -> 37387
% INFO    : Updated Thermal Rating: on line 1001-3809 : Rate B, Rate C , 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 1001-5616 : Rate B, Rate C , 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 1001-5616 : Rate B, Rate C , 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 1001-6697 : Rate B, Rate C , 0.0, 0.0 -> 1034
% INFO    : Updated Thermal Rating: on line 1001-7165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4781
% INFO    : Updated Thermal Rating: on line 1001-892 : Rate B, Rate C , 0.0, 0.0 -> 4400
% INFO    : Updated Thermal Rating: on line 7438-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2105
% INFO    : Updated Thermal Rating: on line 7438-1526 : Rate B, Rate C , 0.0, 0.0 -> 2539
% INFO    : Updated Thermal Rating: on line 1301-6952 : Rate B, Rate C , 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 1301-6952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on line 1301-6952 : Rate B, Rate C , 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 1301-7883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10335
% INFO    : Updated Thermal Rating: on line 1301-6430 : Rate B, Rate C , 0.0, 0.0 -> 5140
% INFO    : Updated Thermal Rating: on line 778-7209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 778-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4334
% INFO    : Updated Thermal Rating: on line 778-6820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8414
% INFO    : Updated Thermal Rating: on line 778-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 5297-6267 : Rate B, Rate C , 0.0, 0.0 -> 45626
% INFO    : Updated Thermal Rating: on line 3657-3855 : Rate B, Rate C , 0.0, 0.0 -> 41622
% INFO    : Updated Thermal Rating: on line 3657-3855 : Rate B, Rate C , 0.0, 0.0 -> 45778
% INFO    : Updated Thermal Rating: on line 3657-2928 : Rate B, Rate C , 0.0, 0.0 -> 12161
% INFO    : Updated Thermal Rating: on line 3657-2928 : Rate B, Rate C , 0.0, 0.0 -> 12717
% INFO    : Updated Thermal Rating: on line 3657-1172 : Rate B, Rate C , 0.0, 0.0 -> 13211
% INFO    : Updated Thermal Rating: on line 3657-9191 : Rate B, Rate C , 0.0, 0.0 -> 4832
% INFO    : Updated Thermal Rating: on line 3657-8722 : Rate B, Rate C , 0.0, 0.0 -> 5211
% INFO    : Updated Thermal Rating: on line 6472-5362 : Rate B, Rate C , 0.0, 0.0 -> 17339
% INFO    : Updated Thermal Rating: on line 6472-3962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13063
% INFO    : Updated Thermal Rating: on line 1198-1343 : Rate B, Rate C , 0.0, 0.0 -> 4076
% INFO    : Updated Thermal Rating: on line 1198-29 : Rate B, Rate C , 0.0, 0.0 -> 1978
% INFO    : Updated Thermal Rating: on line 7473-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 7473-96 : Rate B, Rate C , 0.0, 0.0 -> 1804
% INFO    : Updated Thermal Rating: on line 7473-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2508
% INFO    : Updated Thermal Rating: on line 346-3184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6510
% INFO    : Updated Thermal Rating: on line 346-6570 : Rate B, Rate C , 0.0, 0.0 -> 6187
% INFO    : Updated Thermal Rating: on line 3184-4728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 2654-7886 : Rate B, Rate C , 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 2654-2132 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 4144-8874 : Rate B, Rate C , 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 4144-1625 : Rate B, Rate C , 0.0, 0.0 -> 5227
% INFO    : Updated Thermal Rating: on line 4144-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5276
% INFO    : Updated Thermal Rating: on line 4144-3786 : Rate B, Rate C , 0.0, 0.0 -> 2479
% INFO    : Updated Thermal Rating: on line 4144-3786 : Rate B, Rate C , 0.0, 0.0 -> 2204
% INFO    : Updated Thermal Rating: on line 3422-4100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44249
% INFO    : Updated Thermal Rating: on line 6624-4419 : Rate B, Rate C , 0.0, 0.0 -> 58406
% INFO    : Updated Thermal Rating: on line 6624-7159 : Rate B, Rate C , 0.0, 0.0 -> 57347
% INFO    : Updated Thermal Rating: on line 6624-3661 : Rate B, Rate C , 0.0, 0.0 -> 54332
% INFO    : Updated Thermal Rating: on line 6624-5486 : Rate B, Rate C , 0.0, 0.0 -> 58336
% INFO    : Updated Thermal Rating: on line 6624-4231 : Rate B, Rate C , 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 6624-4231 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 6624-6921 : Rate B, Rate C , 0.0, 0.0 -> 1794
% INFO    : Updated Thermal Rating: on line 6624-432 : Rate B, Rate C , 0.0, 0.0 -> 3336
% INFO    : Updated Thermal Rating: on line 6624-432 : Rate B, Rate C , 0.0, 0.0 -> 2840
% INFO    : Updated Thermal Rating: on line 6624-432 : Rate B, Rate C , 0.0, 0.0 -> 2788
% INFO    : Updated Thermal Rating: on line 3353-6887 : Rate B, Rate C , 0.0, 0.0 -> 5371
% INFO    : Updated Thermal Rating: on line 2479-2050 : Rate B, Rate C , 0.0, 0.0 -> 5307
% INFO    : Updated Thermal Rating: on line 2479-2050 : Rate B, Rate C , 0.0, 0.0 -> 4690
% INFO    : Updated Thermal Rating: on line 5482-8704 : Rate B, Rate C , 0.0, 0.0 -> 4888
% INFO    : Updated Thermal Rating: on line 5482-8704 : Rate B, Rate C , 0.0, 0.0 -> 4337
% INFO    : Updated Thermal Rating: on line 5482-4710 : Rate B, Rate C , 0.0, 0.0 -> 1375
% INFO    : Updated Thermal Rating: on line 5482-1295 : Rate B, Rate C , 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 5482-1910 : Rate B, Rate C , 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 5482-2985 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 5482-5853 : Rate B, Rate C , 0.0, 0.0 -> 12252
% INFO    : Updated Thermal Rating: on line 5482-7824 : Rate B, Rate C , 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 5482-3071 : Rate B, Rate C , 0.0, 0.0 -> 18399
% INFO    : Updated Thermal Rating: on line 4525-195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 9066-7367 : Rate B, Rate C , 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 9066-9155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 9066-6357 : Rate B, Rate C , 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 7886-3126 : Rate B, Rate C , 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 7886-8564 : Rate B, Rate C , 0.0, 0.0 -> 4738
% INFO    : Updated Thermal Rating: on line 7886-5567 : Rate B, Rate C , 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 6416-3069 : Rate B, Rate C , 0.0, 0.0 -> 1534
% INFO    : Updated Thermal Rating: on line 6416-3876 : Rate B, Rate C , 0.0, 0.0 -> 9976
% INFO    : Updated Thermal Rating: on line 6416-8804 : Rate B, Rate C , 0.0, 0.0 -> 2409
% INFO    : Updated Thermal Rating: on line 6416-8804 : Rate B, Rate C , 0.0, 0.0 -> 2366
% INFO    : Updated Thermal Rating: on line 7831-4550 : Rate B, Rate C , 0.0, 0.0 -> 5610
% INFO    : Updated Thermal Rating: on line 7831-4125 : Rate B, Rate C , 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on line 7831-3346 : Rate B, Rate C , 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 5525-2377 : Rate B, Rate C , 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5525-1401 : Rate B, Rate C , 0.0, 0.0 -> 1220
% INFO    : Updated Thermal Rating: on line 5525-2850 : Rate B, Rate C , 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 5525-2430 : Rate B, Rate C , 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 5525-9164 : Rate B, Rate C , 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 8511-1033 : Rate B, Rate C , 0.0, 0.0 -> 25264
% INFO    : Updated Thermal Rating: on line 8511-6178 : Rate B, Rate C , 0.0, 0.0 -> 29393
% INFO    : Updated Thermal Rating: on line 3400-980 : Rate B, Rate C , 0.0, 0.0 -> 24306
% INFO    : Updated Thermal Rating: on line 2101-4598 : Rate B, Rate C , 0.0, 0.0 -> 2637
% INFO    : Updated Thermal Rating: on line 2101-4541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2663
% INFO    : Updated Thermal Rating: on line 2101-5144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7392
% INFO    : Updated Thermal Rating: on line 3919-2129 : Rate B, Rate C , 0.0, 0.0 -> 2695
% INFO    : Updated Thermal Rating: on line 3919-4541 : Rate B, Rate C , 0.0, 0.0 -> 3010
% INFO    : Updated Thermal Rating: on line 3919-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7549
% INFO    : Updated Thermal Rating: on line 6675-1486 : Rate B, Rate C , 0.0, 0.0 -> 44610
% INFO    : Updated Thermal Rating: on line 4711-5836 : Rate B, Rate C , 0.0, 0.0 -> 6392
% INFO    : Updated Thermal Rating: on line 4711-575 : Rate B, Rate C , 0.0, 0.0 -> 6111
% INFO    : Updated Thermal Rating: on line 4711-8214 : Rate B, Rate C , 0.0, 0.0 -> 8784
% INFO    : Updated Thermal Rating: on line 4711-8214 : Rate B, Rate C , 0.0, 0.0 -> 8261
% INFO    : Updated Thermal Rating: on line 4711-3021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25671
% INFO    : Updated Thermal Rating: on line 4711-7967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25386
% INFO    : Updated Thermal Rating: on line 4711-5993 : Rate B, Rate C , 0.0, 0.0 -> 3668
% INFO    : Updated Thermal Rating: on line 4711-8804 : Rate B, Rate C , 0.0, 0.0 -> 1588
% INFO    : Updated Thermal Rating: on line 4513-6831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26216
% INFO    : Updated Thermal Rating: on line 2043-1422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48510
% INFO    : Updated Thermal Rating: on line 6714-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7088
% INFO    : Updated Thermal Rating: on line 6371-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7213
% INFO    : Updated Thermal Rating: on line 513-2866 : Rate B, Rate C , 0.0, 0.0 -> 3766
% INFO    : Updated Thermal Rating: on line 4970-9222 : Rate B, Rate C , 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 4970-9222 : Rate B, Rate C , 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 4970-2072 : Rate B, Rate C , 0.0, 0.0 -> 5202
% INFO    : Updated Thermal Rating: on line 4970-5461 : Rate B, Rate C , 0.0, 0.0 -> 11447
% INFO    : Updated Thermal Rating: on line 4970-8109 : Rate B, Rate C , 0.0, 0.0 -> 2341
% INFO    : Updated Thermal Rating: on line 4970-8109 : Rate B, Rate C , 0.0, 0.0 -> 2030
% INFO    : Updated Thermal Rating: on line 7955-707 : Rate B, Rate C , 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 7955-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3937
% INFO    : Updated Thermal Rating: on line 7955-1866 : Rate B, Rate C , 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 7955-5488 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 5093-2467 : Rate B, Rate C , 0.0, 0.0 -> 1540
% INFO    : Updated Thermal Rating: on line 2328-7178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6241
% INFO    : Updated Thermal Rating: on line 9180-195 : Rate B, Rate C , 0.0, 0.0 -> 2352
% INFO    : Updated Thermal Rating: on line 9180-3133 : Rate B, Rate C , 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 292-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3334
% INFO    : Updated Thermal Rating: on line 9002-6737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20291
% INFO    : Updated Thermal Rating: on line 8439-3758 : Rate B, Rate C , 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 8439-3758 : Rate B, Rate C , 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 4974-2940 : Rate B, Rate C , 0.0, 0.0 -> 1572
% INFO    : Updated Thermal Rating: on line 4974-163 : Rate B, Rate C , 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 747-8507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26055
% INFO    : Updated Thermal Rating: on line 6909-4914 : Rate B, Rate C , 0.0, 0.0 -> 14377
% INFO    : Updated Thermal Rating: on line 444-4747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7334
% INFO    : Updated Thermal Rating: on line 1459-6495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3289
% INFO    : Updated Thermal Rating: on line 1459-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1971
% INFO    : Updated Thermal Rating: on line 3601-4728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9924
% INFO    : Updated Thermal Rating: on line 1251-6475 : Rate B, Rate C , 0.0, 0.0 -> 76837
% INFO    : Updated Thermal Rating: on line 1093-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73380
% INFO    : Updated Thermal Rating: on line 5709-6475 : Rate B, Rate C , 0.0, 0.0 -> 80755
% INFO    : Updated Thermal Rating: on line 3825-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82867
% INFO    : Updated Thermal Rating: on line 1415-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7473
% INFO    : Updated Thermal Rating: on line 4549-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8069
% INFO    : Updated Thermal Rating: on line 3072-639 : Rate B, Rate C , 0.0, 0.0 -> 7210
% INFO    : Updated Thermal Rating: on line 3072-639 : Rate B, Rate C , 0.0, 0.0 -> 7718
% INFO    : Updated Thermal Rating: on line 5007-4541 : Rate A, Rate B, Rate C , 1152.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 5007-8195 : Rate B, Rate C , 0.0, 0.0 -> 1873
% INFO    : Updated Thermal Rating: on line 757-964 : Rate B, Rate C , 0.0, 0.0 -> 3905
% INFO    : Updated Thermal Rating: on line 757-964 : Rate B, Rate C , 0.0, 0.0 -> 3830
% INFO    : Updated Thermal Rating: on line 757-3906 : Rate B, Rate C , 0.0, 0.0 -> 2741
% INFO    : Updated Thermal Rating: on line 757-3906 : Rate B, Rate C , 0.0, 0.0 -> 2425
% INFO    : Updated Thermal Rating: on line 757-8347 : Rate B, Rate C , 0.0, 0.0 -> 1984
% INFO    : Updated Thermal Rating: on line 757-2919 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 1133
% INFO    : Updated Thermal Rating: on line 3758-188 : Rate B, Rate C , 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on line 3758-2242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 3903-4114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 5743-6990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 8626-8930 : Rate B, Rate C , 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 8626-2467 : Rate B, Rate C , 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 2161-5488 : Rate B, Rate C , 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 2161-7772 : Rate B, Rate C , 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 5003-6382 : Rate B, Rate C , 0.0, 0.0 -> 13719
% INFO    : Updated Thermal Rating: on line 6474-4084 : Rate B, Rate C , 0.0, 0.0 -> 2878
% INFO    : Updated Thermal Rating: on line 6474-4084 : Rate B, Rate C , 0.0, 0.0 -> 2504
% INFO    : Updated Thermal Rating: on line 6474-53 : Rate B, Rate C , 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 6474-7259 : Rate B, Rate C , 0.0, 0.0 -> 19023
% INFO    : Updated Thermal Rating: on line 6474-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18424
% INFO    : Updated Thermal Rating: on line 5334-7577 : Rate B, Rate C , 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 7961-2288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20686
% INFO    : Updated Thermal Rating: on line 1592-7098 : Rate B, Rate C , 0.0, 0.0 -> 5012
% INFO    : Updated Thermal Rating: on line 3187-2079 : Rate B, Rate C , 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 6041-5926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4243
% INFO    : Updated Thermal Rating: on line 3697-8486 : Rate B, Rate C , 0.0, 0.0 -> 3034
% INFO    : Updated Thermal Rating: on line 3697-7530 : Rate B, Rate C , 0.0, 0.0 -> 3094
% INFO    : Updated Thermal Rating: on line 3697-1502 : Rate B, Rate C , 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 3697-1552 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 6952-3793 : Rate B, Rate C , 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 6738-2526 : Rate B, Rate C , 0.0, 0.0 -> 2537
% INFO    : Updated Thermal Rating: on line 6738-2526 : Rate B, Rate C , 0.0, 0.0 -> 2252
% INFO    : Updated Thermal Rating: on line 6738-2365 : Rate B, Rate C , 0.0, 0.0 -> 3731
% INFO    : Updated Thermal Rating: on line 6738-2365 : Rate B, Rate C , 0.0, 0.0 -> 3662
% INFO    : Updated Thermal Rating: on line 6738-3794 : Rate B, Rate C , 0.0, 0.0 -> 2974
% INFO    : Updated Thermal Rating: on line 6738-3613 : Rate B, Rate C , 0.0, 0.0 -> 2807
% INFO    : Updated Thermal Rating: on line 6738-6901 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1218
% INFO    : Updated Thermal Rating: on line 8180-5106 : Rate B, Rate C , 0.0, 0.0 -> 3996
% INFO    : Updated Thermal Rating: on line 8180-5106 : Rate B, Rate C , 0.0, 0.0 -> 3866
% INFO    : Updated Thermal Rating: on line 6240-7165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 9222-8721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95544
% INFO    : Updated Thermal Rating: on line 9222-8872 : Rate B, Rate C , 0.0, 0.0 -> 108858
% INFO    : Updated Thermal Rating: on line 9222-8672 : Rate B, Rate C , 0.0, 0.0 -> 3531
% INFO    : Updated Thermal Rating: on line 9222-7164 : Rate B, Rate C , 0.0, 0.0 -> 2062
% INFO    : Updated Thermal Rating: on line 5935-7772 : Rate B, Rate C , 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 3134-3430 : Rate B, Rate C , 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 3134-1051 : Rate B, Rate C , 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 283-800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21921
% INFO    : Updated Thermal Rating: on line 283-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20446
% INFO    : Updated Thermal Rating: on line 283-4747 : Rate B, Rate C , 0.0, 0.0 -> 6998
% INFO    : Updated Thermal Rating: on line 3391-5213 : Rate B, Rate C , 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 3391-115 : Rate B, Rate C , 0.0, 0.0 -> 3736
% INFO    : Updated Thermal Rating: on line 3391-115 : Rate B, Rate C , 0.0, 0.0 -> 3241
% INFO    : Updated Thermal Rating: on line 4867-5753 : Rate B, Rate C , 0.0, 0.0 -> 5101
% INFO    : Updated Thermal Rating: on line 7539-6556 : Rate B, Rate C , 0.0, 0.0 -> 2477
% INFO    : Updated Thermal Rating: on line 7539-871 : Rate B, Rate C , 0.0, 0.0 -> 3278
% INFO    : Updated Thermal Rating: on line 8893-8874 : Rate B, Rate C , 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 8893-4505 : Rate B, Rate C , 0.0, 0.0 -> 3592
% INFO    : Updated Thermal Rating: on line 8893-3436 : Rate B, Rate C , 0.0, 0.0 -> 2054
% INFO    : Updated Thermal Rating: on line 8893-3436 : Rate B, Rate C , 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 8893-3436 : Rate B, Rate C , 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 8893-6556 : Rate B, Rate C , 0.0, 0.0 -> 1599
% INFO    : Updated Thermal Rating: on line 8893-8765 : Rate B, Rate C , 0.0, 0.0 -> 13522
% INFO    : Updated Thermal Rating: on line 8893-6619 : Rate B, Rate C , 0.0, 0.0 -> 11682
% INFO    : Updated Thermal Rating: on line 8165-6734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53974
% INFO    : Updated Thermal Rating: on line 1078-6734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84816
% INFO    : Updated Thermal Rating: on line 7988-4231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9642
% INFO    : Updated Thermal Rating: on line 804-2142 : Rate B, Rate C , 0.0, 0.0 -> 5557
% INFO    : Updated Thermal Rating: on line 804-2142 : Rate B, Rate C , 0.0, 0.0 -> 5672
% INFO    : Updated Thermal Rating: on line 804-7519 : Rate B, Rate C , 0.0, 0.0 -> 1593
% INFO    : Updated Thermal Rating: on line 804-6744 : Rate B, Rate C , 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 2286-6802 : Rate B, Rate C , 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 2286-769 : Rate B, Rate C , 0.0, 0.0 -> 1193
% INFO    : Updated Thermal Rating: on line 3239-1081 : Rate B, Rate C , 0.0, 0.0 -> 1501
% INFO    : Updated Thermal Rating: on line 3239-5983 : Rate B, Rate C , 0.0, 0.0 -> 1467
% INFO    : Updated Thermal Rating: on line 3239-8267 : Rate A, Rate B, Rate C , 1053.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 3239-960 : Rate B, Rate C , 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 3239-960 : Rate B, Rate C , 0.0, 0.0 -> 2061
% INFO    : Updated Thermal Rating: on line 3239-3906 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 1539-7361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 1539-6852 : Rate B, Rate C , 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 1539-8515 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 1539-3166 : Rate B, Rate C , 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 1539-2676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 1539-3793 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 1539-4529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 937
% INFO    : Updated Thermal Rating: on line 1539-4234 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 8628-44 : Rate B, Rate C , 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 8628-6630 : Rate B, Rate C , 0.0, 0.0 -> 3902
% INFO    : Updated Thermal Rating: on line 8628-6630 : Rate B, Rate C , 0.0, 0.0 -> 3982
% INFO    : Updated Thermal Rating: on line 8628-1545 : Rate B, Rate C , 0.0, 0.0 -> 10610
% INFO    : Updated Thermal Rating: on line 8628-4215 : Rate B, Rate C , 0.0, 0.0 -> 9305
% INFO    : Updated Thermal Rating: on line 7163-1917 : Rate B, Rate C , 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 7163-5519 : Rate B, Rate C , 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on line 7647-225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25736
% INFO    : Updated Thermal Rating: on line 4864-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64786
% INFO    : Updated Thermal Rating: on line 7021-7119 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 7021-3324 : Rate B, Rate C , 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 1248-163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2413
% INFO    : Updated Thermal Rating: on line 9045-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78436
% INFO    : Updated Thermal Rating: on line 8874-3786 : Rate B, Rate C , 0.0, 0.0 -> 1991
% INFO    : Updated Thermal Rating: on line 5891-5574 : Rate B, Rate C , 0.0, 0.0 -> 2510
% INFO    : Updated Thermal Rating: on line 5891-7663 : Rate B, Rate C , 0.0, 0.0 -> 1341
% INFO    : Updated Thermal Rating: on line 5891-4889 : Rate B, Rate C , 0.0, 0.0 -> 5190
% INFO    : Updated Thermal Rating: on line 3997-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35710
% INFO    : Updated Thermal Rating: on line 184-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38599
% INFO    : Updated Thermal Rating: on line 2972-2088 : Rate B, Rate C , 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 8676-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 8676-933 : Rate B, Rate C , 0.0, 0.0 -> 4562
% INFO    : Updated Thermal Rating: on line 8676-3643 : Rate B, Rate C , 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 8704-6723 : Rate B, Rate C , 0.0, 0.0 -> 2411
% INFO    : Updated Thermal Rating: on line 7047-21 : Rate B, Rate C , 0.0, 0.0 -> 31376
% INFO    : Updated Thermal Rating: on line 7047-21 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21862
% INFO    : Updated Thermal Rating: on line 7047-1551 : Rate B, Rate C , 0.0, 0.0 -> 1996
% INFO    : Updated Thermal Rating: on line 7047-4103 : Rate B, Rate C , 0.0, 0.0 -> 10244
% INFO    : Updated Thermal Rating: on line 7047-7862 : Rate B, Rate C , 0.0, 0.0 -> 3768
% INFO    : Updated Thermal Rating: on line 7047-5458 : Rate B, Rate C , 0.0, 0.0 -> 3966
% INFO    : Updated Thermal Rating: on line 5574-5666 : Rate B, Rate C , 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 6742-5458 : Rate B, Rate C , 0.0, 0.0 -> 24252
% INFO    : Updated Thermal Rating: on line 5270-7862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24653
% INFO    : Updated Thermal Rating: on line 7775-3857 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 6290-3436 : Rate B, Rate C , 0.0, 0.0 -> 3696
% INFO    : Updated Thermal Rating: on line 3430-401 : Rate B, Rate C , 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 2967-8976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20925
% INFO    : Updated Thermal Rating: on line 2967-8976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20403
% INFO    : Updated Thermal Rating: on line 8976-2481 : Rate B, Rate C , 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 8976-9108 : Rate B, Rate C , 0.0, 0.0 -> 2458
% INFO    : Updated Thermal Rating: on line 2056-7520 : Rate B, Rate C , 0.0, 0.0 -> 6825
% INFO    : Updated Thermal Rating: on line 2056-7520 : Rate B, Rate C , 0.0, 0.0 -> 6697
% INFO    : Updated Thermal Rating: on line 4084-5340 : Rate B, Rate C , 0.0, 0.0 -> 2230
% INFO    : Updated Thermal Rating: on line 4084-2319 : Rate B, Rate C , 0.0, 0.0 -> 3526
% INFO    : Updated Thermal Rating: on line 4084-2878 : Rate B, Rate C , 0.0, 0.0 -> 1136
% INFO    : Updated Thermal Rating: on line 2597-7422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3993
% INFO    : Updated Thermal Rating: on line 7183-8931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10070
% INFO    : Updated Thermal Rating: on line 5379-8931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9884
% INFO    : Updated Thermal Rating: on line 8128-8931 : Rate B, Rate C , 0.0, 0.0 -> 7250
% INFO    : Updated Thermal Rating: on line 6337-8931 : Rate B, Rate C , 0.0, 0.0 -> 7402
% INFO    : Updated Thermal Rating: on line 1237-8931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10049
% INFO    : Updated Thermal Rating: on line 4127-9173 : Rate B, Rate C , 0.0, 0.0 -> 40572
% INFO    : Updated Thermal Rating: on line 4127-7974 : Rate B, Rate C , 0.0, 0.0 -> 23949
% INFO    : Updated Thermal Rating: on line 2432-4816 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2432-1866 : Rate B, Rate C , 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 2432-8809 : Rate B, Rate C , 0.0, 0.0 -> 7955
% INFO    : Updated Thermal Rating: on line 2432-5146 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 2432-6940 : Rate B, Rate C , 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 2432-1742 : Rate B, Rate C , 0.0, 0.0 -> 7075
% INFO    : Updated Thermal Rating: on line 5213-8627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 5213-174 : Rate B, Rate C , 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 5213-7437 : Rate B, Rate C , 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 7342-5940 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 7342-7495 : Rate B, Rate C , 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 8808-4816 : Rate B, Rate C , 0.0, 0.0 -> 1450
% INFO    : Updated Thermal Rating: on line 8808-4816 : Rate B, Rate C , 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 8808-6053 : Rate B, Rate C , 0.0, 0.0 -> 1834
% INFO    : Updated Thermal Rating: on line 5764-4189 : Rate B, Rate C , 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on line 8507-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33783
% INFO    : Updated Thermal Rating: on line 1394-1973 : Rate B, Rate C , 0.0, 0.0 -> 33061
% INFO    : Updated Thermal Rating: on line 2898-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96873
% INFO    : Updated Thermal Rating: on line 4942-8255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 4942-4748 : Rate B, Rate C , 0.0, 0.0 -> 5098
% INFO    : Updated Thermal Rating: on line 3486-3594 : Rate B, Rate C , 0.0, 0.0 -> 1482
% INFO    : Updated Thermal Rating: on line 3486-4679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 4656-4235 : Rate B, Rate C , 0.0, 0.0 -> 1552
% INFO    : Updated Thermal Rating: on line 4656-4235 : Rate B, Rate C , 0.0, 0.0 -> 1584
% INFO    : Updated Thermal Rating: on line 7129-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13000
% INFO    : Updated Thermal Rating: on line 7129-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12810
% INFO    : Updated Thermal Rating: on line 8250-5720 : Rate B, Rate C , 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 8250-5720 : Rate B, Rate C , 0.0, 0.0 -> 1558
% INFO    : Updated Thermal Rating: on line 6831-6723 : Rate B, Rate C , 0.0, 0.0 -> 11064
% INFO    : Updated Thermal Rating: on line 6831-5686 : Rate B, Rate C , 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 2377-805 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 907-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78402
% INFO    : Updated Thermal Rating: on line 4056-9091 : Rate B, Rate C , 0.0, 0.0 -> 71132
% INFO    : Updated Thermal Rating: on line 6837-2142 : Rate B, Rate C , 0.0, 0.0 -> 62725
% INFO    : Updated Thermal Rating: on line 5666-2641 : Rate B, Rate C , 0.0, 0.0 -> 4421
% INFO    : Updated Thermal Rating: on line 5666-7577 : Rate B, Rate C , 0.0, 0.0 -> 9851
% INFO    : Updated Thermal Rating: on line 5666-7577 : Rate B, Rate C , 0.0, 0.0 -> 9225
% INFO    : Updated Thermal Rating: on line 5666-7577 : Rate B, Rate C , 0.0, 0.0 -> 6466
% INFO    : Updated Thermal Rating: on line 5666-1629 : Rate B, Rate C , 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 726-687 : Rate B, Rate C , 0.0, 0.0 -> 7239
% INFO    : Updated Thermal Rating: on line 3526-687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8564
% INFO    : Updated Thermal Rating: on line 6382-2425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4444
% INFO    : Updated Thermal Rating: on line 6382-2425 : Rate B, Rate C , 0.0, 0.0 -> 4533
% INFO    : Updated Thermal Rating: on line 6382-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1442
% INFO    : Updated Thermal Rating: on line 6382-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 6382-5907 : Rate B, Rate C , 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 7847-9217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 2981-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 5110-5686 : Rate B, Rate C , 0.0, 0.0 -> 3769
% INFO    : Updated Thermal Rating: on line 2968-5907 : Rate B, Rate C , 0.0, 0.0 -> 3813
% INFO    : Updated Thermal Rating: on line 5441-2155 : Rate B, Rate C , 0.0, 0.0 -> 2042
% INFO    : Updated Thermal Rating: on line 5441-8112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1956
% INFO    : Updated Thermal Rating: on line 5441-2535 : Rate B, Rate C , 0.0, 0.0 -> 11184
% INFO    : Updated Thermal Rating: on line 5441-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2530
% INFO    : Updated Thermal Rating: on line 5441-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 5441-7098 : Rate B, Rate C , 0.0, 0.0 -> 2899
% INFO    : Updated Thermal Rating: on line 5441-3737 : Rate B, Rate C , 0.0, 0.0 -> 5922
% INFO    : Updated Thermal Rating: on line 5441-5529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5818
% INFO    : Updated Thermal Rating: on line 5441-5753 : Rate B, Rate C , 0.0, 0.0 -> 2664
% INFO    : Updated Thermal Rating: on line 9019-6563 : Rate B, Rate C , 0.0, 0.0 -> 52008
% INFO    : Updated Thermal Rating: on line 1341-1101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 2797-8291 : Rate B, Rate C , 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 2797-8367 : Rate B, Rate C , 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 2797-1100 : Rate B, Rate C , 0.0, 0.0 -> 7022
% INFO    : Updated Thermal Rating: on line 2797-6887 : Rate B, Rate C , 0.0, 0.0 -> 2694
% INFO    : Updated Thermal Rating: on line 4939-6880 : Rate B, Rate C , 0.0, 0.0 -> 9486
% INFO    : Updated Thermal Rating: on line 7738-6982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 6565-3121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 8707-280 : Rate B, Rate C , 0.0, 0.0 -> 3515
% INFO    : Updated Thermal Rating: on line 8707-2510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 1625-766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20318
% INFO    : Updated Thermal Rating: on line 8411-6232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54993
% INFO    : Updated Thermal Rating: on line 3951-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 964-7282 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 964-7282 : Rate B, Rate C , 0.0, 0.0 -> 2152
% INFO    : Updated Thermal Rating: on line 964-6475 : Rate B, Rate C , 0.0, 0.0 -> 3837
% INFO    : Updated Thermal Rating: on line 964-6475 : Rate B, Rate C , 0.0, 0.0 -> 3917
% INFO    : Updated Thermal Rating: on line 5658-5420 : Rate B, Rate C , 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 5658-8267 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 5658-7328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 5658-7328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1445
% INFO    : Updated Thermal Rating: on line 5658-7164 : Rate B, Rate C , 0.0, 0.0 -> 1524
% INFO    : Updated Thermal Rating: on line 5550-410 : Rate B, Rate C , 0.0, 0.0 -> 2976
% INFO    : Updated Thermal Rating: on line 5550-7579 : Rate B, Rate C , 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 5550-7579 : Rate B, Rate C , 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 5550-4189 : Rate B, Rate C , 0.0, 0.0 -> 629
% INFO    : Updated Thermal Rating: on line 7282-4196 : Rate B, Rate C , 0.0, 0.0 -> 2639
% INFO    : Updated Thermal Rating: on line 1526-3916 : Rate B, Rate C , 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 1526-4747 : Rate B, Rate C , 0.0, 0.0 -> 2505
% INFO    : Updated Thermal Rating: on line 1526-4747 : Rate B, Rate C , 0.0, 0.0 -> 2051
% INFO    : Updated Thermal Rating: on line 4541-3346 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 4541-3346 : Rate A, Rate B, Rate C , 1020.0, 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 1343-3346 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 3680-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44610
% INFO    : Updated Thermal Rating: on line 3680-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31417
% INFO    : Updated Thermal Rating: on line 3680-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36971
% INFO    : Updated Thermal Rating: on line 3680-795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41087
% INFO    : Updated Thermal Rating: on line 3680-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1761
% INFO    : Updated Thermal Rating: on line 3680-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 7464-5564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47512
% INFO    : Updated Thermal Rating: on line 7464-7036 : Rate B, Rate C , 0.0, 0.0 -> 40125
% INFO    : Updated Thermal Rating: on line 7464-5940 : Rate B, Rate C , 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 7464-7495 : Rate B, Rate C , 0.0, 0.0 -> 969
% INFO    : Updated Thermal Rating: on line 4850-2886 : Rate B, Rate C , 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 4850-7049 : Rate B, Rate C , 0.0, 0.0 -> 1660
% INFO    : Updated Thermal Rating: on line 2510-6146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11156
% INFO    : Updated Thermal Rating: on line 90-1860 : Rate B, Rate C , 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 90-1860 : Rate B, Rate C , 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 2142-3276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20489
% INFO    : Updated Thermal Rating: on line 2142-3545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2774
% INFO    : Updated Thermal Rating: on line 2142-6842 : Rate B, Rate C , 0.0, 0.0 -> 1734
% INFO    : Updated Thermal Rating: on line 2142-6744 : Rate B, Rate C , 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 2142-7635 : Rate B, Rate C , 0.0, 0.0 -> 24993
% INFO    : Updated Thermal Rating: on line 9091-1040 : Rate B, Rate C , 0.0, 0.0 -> 1752
% INFO    : Updated Thermal Rating: on line 2457-6178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79847
% INFO    : Updated Thermal Rating: on line 1422-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5876
% INFO    : Updated Thermal Rating: on line 1422-7772 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 7881-5365 : Rate B, Rate C , 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 7881-6982 : Rate B, Rate C , 0.0, 0.0 -> 468
% INFO    : Updated Thermal Rating: on line 6926-3327 : Rate B, Rate C , 0.0, 0.0 -> 7240
% INFO    : Updated Thermal Rating: on line 1959-615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4685
% INFO    : Updated Thermal Rating: on line 6455-1262 : Rate B, Rate C , 0.0, 0.0 -> 14149
% INFO    : Updated Thermal Rating: on line 803-6982 : Rate B, Rate C , 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 803-5918 : Rate B, Rate C , 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 7624-3070 : Rate B, Rate C , 0.0, 0.0 -> 1926
% INFO    : Updated Thermal Rating: on line 500-1547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5703
% INFO    : Updated Thermal Rating: on line 500-5237 : Rate B, Rate C , 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on line 500-772 : Rate B, Rate C , 0.0, 0.0 -> 1815
% INFO    : Updated Thermal Rating: on line 500-8950 : Rate B, Rate C , 0.0, 0.0 -> 2298
% INFO    : Updated Thermal Rating: on line 2754-2079 : Rate B, Rate C , 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on line 2754-2229 : Rate B, Rate C , 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 2754-7049 : Rate B, Rate C , 0.0, 0.0 -> 3071
% INFO    : Updated Thermal Rating: on line 4118-7873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on line 4118-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5072
% INFO    : Updated Thermal Rating: on line 1754-8486 : Rate B, Rate C , 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 1754-7530 : Rate B, Rate C , 0.0, 0.0 -> 1601
% INFO    : Updated Thermal Rating: on line 1754-7778 : Rate B, Rate C , 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on line 1754-6897 : Rate B, Rate C , 0.0, 0.0 -> 2158
% INFO    : Updated Thermal Rating: on line 1754-960 : Rate B, Rate C , 0.0, 0.0 -> 1567
% INFO    : Updated Thermal Rating: on line 1754-960 : Rate B, Rate C , 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 3857-4491 : Rate B, Rate C , 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 3857-6010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6340
% INFO    : Updated Thermal Rating: on line 3857-6940 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on line 858-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20980
% INFO    : Updated Thermal Rating: on line 3028-809 : Rate B, Rate C , 0.0, 0.0 -> 21405
% INFO    : Updated Thermal Rating: on line 4819-1642 : Rate B, Rate C , 0.0, 0.0 -> 18328
% INFO    : Updated Thermal Rating: on line 2035-809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18979
% INFO    : Updated Thermal Rating: on line 3869-1642 : Rate B, Rate C , 0.0, 0.0 -> 18755
% INFO    : Updated Thermal Rating: on line 3741-809 : Rate B, Rate C , 0.0, 0.0 -> 18321
% INFO    : Updated Thermal Rating: on line 742-687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5499
% INFO    : Updated Thermal Rating: on line 2910-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6113
% INFO    : Updated Thermal Rating: on line 5688-6231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4761
% INFO    : Updated Thermal Rating: on line 5182-5455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10736
% INFO    : Updated Thermal Rating: on line 707-5695 : Rate B, Rate C , 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 3814-954 : Rate B, Rate C , 0.0, 0.0 -> 4656
% INFO    : Updated Thermal Rating: on line 2313-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4692
% INFO    : Updated Thermal Rating: on line 195-2985 : Rate B, Rate C , 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 2518-3513 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1177
% INFO    : Updated Thermal Rating: on line 2518-3346 : Rate B, Rate C , 0.0, 0.0 -> 1641
% INFO    : Updated Thermal Rating: on line 4544-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on line 4544-3241 : Rate B, Rate C , 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 4544-7338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3724
% INFO    : Updated Thermal Rating: on line 3069-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16227
% INFO    : Updated Thermal Rating: on line 3069-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16547
% INFO    : Updated Thermal Rating: on line 6115-4729 : Rate B, Rate C , 0.0, 0.0 -> 2043
% INFO    : Updated Thermal Rating: on line 3344-6616 : Rate B, Rate C , 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 3809-5616 : Rate B, Rate C , 0.0, 0.0 -> 2898
% INFO    : Updated Thermal Rating: on line 3809-6691 : Rate B, Rate C , 0.0, 0.0 -> 3753
% INFO    : Updated Thermal Rating: on line 3809-6691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 1326-892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2196
% INFO    : Updated Thermal Rating: on line 601-616 : Rate B, Rate C , 0.0, 0.0 -> 1690
% INFO    : Updated Thermal Rating: on line 3496-1551 : Rate B, Rate C , 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 4925-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8460
% INFO    : Updated Thermal Rating: on line 8057-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6577
% INFO    : Updated Thermal Rating: on line 5354-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6466
% INFO    : Updated Thermal Rating: on line 3674-616 : Rate B, Rate C , 0.0, 0.0 -> 2023
% INFO    : Updated Thermal Rating: on line 3674-7338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2076
% INFO    : Updated Thermal Rating: on line 5836-5083 : Rate B, Rate C , 0.0, 0.0 -> 7834
% INFO    : Updated Thermal Rating: on line 5836-7576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11334
% INFO    : Updated Thermal Rating: on line 5836-3191 : Rate B, Rate C , 0.0, 0.0 -> 10177
% INFO    : Updated Thermal Rating: on line 5836-3488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2635
% INFO    : Updated Thermal Rating: on line 5836-1578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2919
% INFO    : Updated Thermal Rating: on line 575-5300 : Rate B, Rate C , 0.0, 0.0 -> 8927
% INFO    : Updated Thermal Rating: on line 3929-9173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41796
% INFO    : Updated Thermal Rating: on line 2089-3818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39156
% INFO    : Updated Thermal Rating: on line 2089-6232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57521
% INFO    : Updated Thermal Rating: on line 2089-1643 : Rate B, Rate C , 0.0, 0.0 -> 23719
% INFO    : Updated Thermal Rating: on line 2089-6253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106228
% INFO    : Updated Thermal Rating: on line 2089-6684 : Rate B, Rate C , 0.0, 0.0 -> 14289
% INFO    : Updated Thermal Rating: on line 2089-8151 : Rate B, Rate C , 0.0, 0.0 -> 19583
% INFO    : Updated Thermal Rating: on line 5067-449 : Rate B, Rate C , 0.0, 0.0 -> 11368
% INFO    : Updated Thermal Rating: on line 5067-449 : Rate B, Rate C , 0.0, 0.0 -> 11607
% INFO    : Updated Thermal Rating: on line 7641-3037 : Rate B, Rate C , 0.0, 0.0 -> 15052
% INFO    : Updated Thermal Rating: on line 7641-3037 : Rate B, Rate C , 0.0, 0.0 -> 13595
% INFO    : Updated Thermal Rating: on line 3191-2340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9173
% INFO    : Updated Thermal Rating: on line 3191-8711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9061
% INFO    : Updated Thermal Rating: on line 8104-8722 : Rate B, Rate C , 0.0, 0.0 -> 14120
% INFO    : Updated Thermal Rating: on line 2644-9191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13488
% INFO    : Updated Thermal Rating: on line 4128-8522 : Rate B, Rate C , 0.0, 0.0 -> 115370
% INFO    : Updated Thermal Rating: on line 604-7522 : Rate B, Rate C , 0.0, 0.0 -> 3119
% INFO    : Updated Thermal Rating: on line 604-4000 : Rate B, Rate C , 0.0, 0.0 -> 2164
% INFO    : Updated Thermal Rating: on line 2155-9021 : Rate B, Rate C , 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 2155-9021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2817
% INFO    : Updated Thermal Rating: on line 2155-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22385
% INFO    : Updated Thermal Rating: on line 2155-687 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 2155-3520 : Rate B, Rate C , 0.0, 0.0 -> 26969
% INFO    : Updated Thermal Rating: on line 2155-4729 : Rate B, Rate C , 0.0, 0.0 -> 2300
% INFO    : Updated Thermal Rating: on line 2641-4889 : Rate B, Rate C , 0.0, 0.0 -> 2295
% INFO    : Updated Thermal Rating: on line 9067-9051 : Rate B, Rate C , 0.0, 0.0 -> 6238
% INFO    : Updated Thermal Rating: on line 6969-5573 : Rate B, Rate C , 0.0, 0.0 -> 5164
% INFO    : Updated Thermal Rating: on line 666-1494 : Rate A, Rate B, Rate C , 1448.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 666-2732 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 666-4550 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 666-1607 : Rate B, Rate C , 0.0, 0.0 -> 12537
% INFO    : Updated Thermal Rating: on line 666-2093 : Rate B, Rate C , 0.0, 0.0 -> 4833
% INFO    : Updated Thermal Rating: on line 3565-2177 : Rate B, Rate C , 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 3565-2841 : Rate B, Rate C , 0.0, 0.0 -> 5880
% INFO    : Updated Thermal Rating: on line 3611-7972 : Rate B, Rate C , 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 3611-2481 : Rate B, Rate C , 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 5420-7164 : Rate B, Rate C , 0.0, 0.0 -> 3760
% INFO    : Updated Thermal Rating: on line 7119-2078 : Rate B, Rate C , 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 7119-7873 : Rate B, Rate C , 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 7422-7519 : Rate B, Rate C , 0.0, 0.0 -> 3892
% INFO    : Updated Thermal Rating: on line 7422-6744 : Rate B, Rate C , 0.0, 0.0 -> 2101
% INFO    : Updated Thermal Rating: on line 1026-1860 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 4765-3327 : Rate B, Rate C , 0.0, 0.0 -> 5873
% INFO    : Updated Thermal Rating: on line 6036-6921 : Rate B, Rate C , 0.0, 0.0 -> 5568
% INFO    : Updated Thermal Rating: on line 8670-7069 : Rate B, Rate C , 0.0, 0.0 -> 1610
% INFO    : Updated Thermal Rating: on line 8670-7069 : Rate B, Rate C , 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 8670-2866 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on line 4032-6450 : Rate B, Rate C , 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 4032-5738 : Rate B, Rate C , 0.0, 0.0 -> 2243
% INFO    : Updated Thermal Rating: on line 7327-2481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2614
% INFO    : Updated Thermal Rating: on line 7327-8189 : Rate B, Rate C , 0.0, 0.0 -> 8692
% INFO    : Updated Thermal Rating: on line 7474-1584 : Rate B, Rate C , 0.0, 0.0 -> 31852
% INFO    : Updated Thermal Rating: on line 8947-3390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57640
% INFO    : Updated Thermal Rating: on line 1808-6384 : Rate B, Rate C , 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 4624-6031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15773
% INFO    : Updated Thermal Rating: on line 1721-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43532
% INFO    : Updated Thermal Rating: on line 7694-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46697
% INFO    : Updated Thermal Rating: on line 9181-6723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29820
% INFO    : Updated Thermal Rating: on line 8373-8748 : Rate B, Rate C , 0.0, 0.0 -> 1506
% INFO    : Updated Thermal Rating: on line 8373-8475 : Rate B, Rate C , 0.0, 0.0 -> 9896
% INFO    : Updated Thermal Rating: on line 8373-8475 : Rate B, Rate C , 0.0, 0.0 -> 9471
% INFO    : Updated Thermal Rating: on line 5630-6639 : Rate B, Rate C , 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 5630-1187 : Rate B, Rate C , 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on line 5630-7274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on line 5630-8992 : Rate B, Rate C , 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on line 5630-7266 : Rate B, Rate C , 0.0, 0.0 -> 1374
% INFO    : Updated Thermal Rating: on line 3492-6734 : Rate B, Rate C , 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 3492-1015 : Rate B, Rate C , 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 3492-8310 : Rate B, Rate C , 0.0, 0.0 -> 17314
% INFO    : Updated Thermal Rating: on line 1980-6570 : Rate B, Rate C , 0.0, 0.0 -> 4294
% INFO    : Updated Thermal Rating: on line 9137-749 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 7522-2183 : Rate A, Rate B, Rate C , 1711.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 7571-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 7571-6891 : Rate B, Rate C , 0.0, 0.0 -> 3673
% INFO    : Updated Thermal Rating: on line 2526-6199 : Rate B, Rate C , 0.0, 0.0 -> 2197
% INFO    : Updated Thermal Rating: on line 2526-6199 : Rate B, Rate C , 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 1483-3649 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 2365-6199 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 2365-6199 : Rate A, Rate B, Rate C , 1218.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 2365-4141 : Rate B, Rate C , 0.0, 0.0 -> 1534
% INFO    : Updated Thermal Rating: on line 2365-1311 : Rate B, Rate C , 0.0, 0.0 -> 2802
% INFO    : Updated Thermal Rating: on line 8316-174 : Rate B, Rate C , 0.0, 0.0 -> 3821
% INFO    : Updated Thermal Rating: on line 174-6430 : Rate B, Rate C , 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 5340-7892 : Rate B, Rate C , 0.0, 0.0 -> 4102
% INFO    : Updated Thermal Rating: on line 5340-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17232
% INFO    : Updated Thermal Rating: on line 5340-8843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155017
% INFO    : Updated Thermal Rating: on line 5340-8843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157839
% INFO    : Updated Thermal Rating: on line 5340-4239 : Rate B, Rate C , 0.0, 0.0 -> 1379
% INFO    : Updated Thermal Rating: on line 3866-1860 : Rate B, Rate C , 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 3866-5395 : Rate B, Rate C , 0.0, 0.0 -> 2178
% INFO    : Updated Thermal Rating: on line 7042-2177 : Rate B, Rate C , 0.0, 0.0 -> 1979
% INFO    : Updated Thermal Rating: on line 8672-7164 : Rate B, Rate C , 0.0, 0.0 -> 4019
% INFO    : Updated Thermal Rating: on line 1860-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 1860-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on line 4885-2928 : Rate B, Rate C , 0.0, 0.0 -> 111427
% INFO    : Updated Thermal Rating: on line 4157-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121741
% INFO    : Updated Thermal Rating: on line 4432-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121741
% INFO    : Updated Thermal Rating: on line 2072-5983 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 3450-6552 : Rate B, Rate C , 0.0, 0.0 -> 3657
% INFO    : Updated Thermal Rating: on line 3956-7507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 5286-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93122
% INFO    : Updated Thermal Rating: on line 5571-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91583
% INFO    : Updated Thermal Rating: on line 2078-8005 : Rate B, Rate C , 0.0, 0.0 -> 4017
% INFO    : Updated Thermal Rating: on line 639-6351 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 639-2749 : Rate B, Rate C , 0.0, 0.0 -> 6761
% INFO    : Updated Thermal Rating: on line 639-9130 : Rate B, Rate C , 0.0, 0.0 -> 3197
% INFO    : Updated Thermal Rating: on line 410-4189 : Rate B, Rate C , 0.0, 0.0 -> 1438
% INFO    : Updated Thermal Rating: on line 1494-5781 : Rate B, Rate C , 0.0, 0.0 -> 4206
% INFO    : Updated Thermal Rating: on line 583-6616 : Rate B, Rate C , 0.0, 0.0 -> 3384
% INFO    : Updated Thermal Rating: on line 583-6031 : Rate B, Rate C , 0.0, 0.0 -> 2386
% INFO    : Updated Thermal Rating: on line 1746-7507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2854
% INFO    : Updated Thermal Rating: on line 3276-7635 : Rate B, Rate C , 0.0, 0.0 -> 87233
% INFO    : Updated Thermal Rating: on line 1105-196 : Rate B, Rate C , 0.0, 0.0 -> 66610
% INFO    : Updated Thermal Rating: on line 8522-7132 : Rate B, Rate C , 0.0, 0.0 -> 18651
% INFO    : Updated Thermal Rating: on line 8522-5351 : Rate B, Rate C , 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 8763-7056 : Rate B, Rate C , 0.0, 0.0 -> 1307
% INFO    : Updated Thermal Rating: on line 8763-8825 : Rate B, Rate C , 0.0, 0.0 -> 1283
% INFO    : Updated Thermal Rating: on line 8763-6889 : Rate B, Rate C , 0.0, 0.0 -> 12298
% INFO    : Updated Thermal Rating: on line 8763-6889 : Rate B, Rate C , 0.0, 0.0 -> 12936
% INFO    : Updated Thermal Rating: on line 8763-8887 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 8763-8887 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1503
% INFO    : Updated Thermal Rating: on line 8763-8487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 8748-8475 : Rate B, Rate C , 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 217-6785 : Rate B, Rate C , 0.0, 0.0 -> 1505
% INFO    : Updated Thermal Rating: on line 217-6785 : Rate B, Rate C , 0.0, 0.0 -> 1688
% INFO    : Updated Thermal Rating: on line 217-1179 : Rate B, Rate C , 0.0, 0.0 -> 6680
% INFO    : Updated Thermal Rating: on line 217-2575 : Rate B, Rate C , 0.0, 0.0 -> 7921
% INFO    : Updated Thermal Rating: on line 217-7274 : Rate B, Rate C , 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 7972-8189 : Rate B, Rate C , 0.0, 0.0 -> 1508
% INFO    : Updated Thermal Rating: on line 7972-8189 : Rate B, Rate C , 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 7972-1039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2361
% INFO    : Updated Thermal Rating: on line 7253-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3594
% INFO    : Updated Thermal Rating: on line 4395-8913 : Rate B, Rate C , 0.0, 0.0 -> 7698
% INFO    : Updated Thermal Rating: on line 4395-4852 : Rate B, Rate C , 0.0, 0.0 -> 4149
% INFO    : Updated Thermal Rating: on line 2795-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5439
% INFO    : Updated Thermal Rating: on line 2795-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4811
% INFO    : Updated Thermal Rating: on line 1305-6291 : Rate B, Rate C , 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 1305-6982 : Rate B, Rate C , 0.0, 0.0 -> 1305
% INFO    : Updated Thermal Rating: on line 2732-1798 : Rate B, Rate C , 0.0, 0.0 -> 1580
% INFO    : Updated Thermal Rating: on line 2732-3346 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 4550-3346 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 4725-5738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 1083-8310 : Rate B, Rate C , 0.0, 0.0 -> 59909
% INFO    : Updated Thermal Rating: on line 1398-5567 : Rate B, Rate C , 0.0, 0.0 -> 45315
% INFO    : Updated Thermal Rating: on line 4281-4580 : Rate B, Rate C , 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 7050-4908 : Rate B, Rate C , 0.0, 0.0 -> 24666
% INFO    : Updated Thermal Rating: on line 7050-3740 : Rate B, Rate C , 0.0, 0.0 -> 42288
% INFO    : Updated Thermal Rating: on line 6563-870 : Rate B, Rate C , 0.0, 0.0 -> 31635
% INFO    : Updated Thermal Rating: on line 8999-6495 : Rate B, Rate C , 0.0, 0.0 -> 4522
% INFO    : Updated Thermal Rating: on line 6888-5994 : Rate B, Rate C , 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 5400-8005 : Rate B, Rate C , 0.0, 0.0 -> 6871
% INFO    : Updated Thermal Rating: on line 5400-8005 : Rate B, Rate C , 0.0, 0.0 -> 6583
% INFO    : Updated Thermal Rating: on line 5881-4031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3663
% INFO    : Updated Thermal Rating: on line 8195-8334 : Rate B, Rate C , 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 933-6357 : Rate B, Rate C , 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 933-6357 : Rate B, Rate C , 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 933-3775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 933-3975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3918-1642 : Rate B, Rate C , 0.0, 0.0 -> 5902
% INFO    : Updated Thermal Rating: on line 6802-1153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47123
% INFO    : Updated Thermal Rating: on line 6802-7599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50874
% INFO    : Updated Thermal Rating: on line 4025-3994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45791
% INFO    : Updated Thermal Rating: on line 1595-1414 : Rate B, Rate C , 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 3114-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3905
% INFO    : Updated Thermal Rating: on line 5237-2229 : Rate B, Rate C , 0.0, 0.0 -> 1508
% INFO    : Updated Thermal Rating: on line 5237-9108 : Rate B, Rate C , 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 5237-1478 : Rate B, Rate C , 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 2799-8515 : Rate B, Rate C , 0.0, 0.0 -> 46722
% INFO    : Updated Thermal Rating: on line 6405-7873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 6405-3894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 4435-4734 : Rate B, Rate C , 0.0, 0.0 -> 4819
% INFO    : Updated Thermal Rating: on line 4435-3483 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 2079-7052 : Rate B, Rate C , 0.0, 0.0 -> 3255
% INFO    : Updated Thermal Rating: on line 2079-7052 : Rate B, Rate C , 0.0, 0.0 -> 3175
% INFO    : Updated Thermal Rating: on line 2079-772 : Rate B, Rate C , 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 2079-772 : Rate B, Rate C , 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on line 1081-6475 : Rate B, Rate C , 0.0, 0.0 -> 1478
% INFO    : Updated Thermal Rating: on line 1081-6475 : Rate B, Rate C , 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 7361-3166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 7361-426 : Rate B, Rate C , 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 2863-1857 : Rate B, Rate C , 0.0, 0.0 -> 31275
% INFO    : Updated Thermal Rating: on line 1364-2430 : Rate B, Rate C , 0.0, 0.0 -> 3794
% INFO    : Updated Thermal Rating: on line 2177-749 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 3594-2850 : Rate B, Rate C , 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 6555-3608 : Rate B, Rate C , 0.0, 0.0 -> 1494
% INFO    : Updated Thermal Rating: on line 8475-1965 : Rate B, Rate C , 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 8475-5926 : Rate B, Rate C , 0.0, 0.0 -> 16954
% INFO    : Updated Thermal Rating: on line 5735-6053 : Rate B, Rate C , 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 5735-2341 : Rate B, Rate C , 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on line 2629-7507 : Rate B, Rate C , 0.0, 0.0 -> 7813
% INFO    : Updated Thermal Rating: on line 1137-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60973
% INFO    : Updated Thermal Rating: on line 7577-5814 : Rate B, Rate C , 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 7577-3231 : Rate B, Rate C , 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 7663-5814 : Rate B, Rate C , 0.0, 0.0 -> 5713
% INFO    : Updated Thermal Rating: on line 1183-1159 : Rate B, Rate C , 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 6852-5051 : Rate B, Rate C , 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 8307-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27156
% INFO    : Updated Thermal Rating: on line 6947-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27847
% INFO    : Updated Thermal Rating: on line 4505-4357 : Rate B, Rate C , 0.0, 0.0 -> 34015
% INFO    : Updated Thermal Rating: on line 7144-7791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7404
% INFO    : Updated Thermal Rating: on line 6889-2085 : Rate B, Rate C , 0.0, 0.0 -> 53817
% INFO    : Updated Thermal Rating: on line 6889-4024 : Rate B, Rate C , 0.0, 0.0 -> 52926
% INFO    : Updated Thermal Rating: on line 6889-9065 : Rate B, Rate C , 0.0, 0.0 -> 58932
% INFO    : Updated Thermal Rating: on line 6889-661 : Rate B, Rate C , 0.0, 0.0 -> 60039
% INFO    : Updated Thermal Rating: on line 6612-8864 : Rate B, Rate C , 0.0, 0.0 -> 20590
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 5378
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 4753
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 4662
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 4575
% INFO    : Updated Thermal Rating: on line 8931-8494 : Rate B, Rate C , 0.0, 0.0 -> 9314
% INFO    : Updated Thermal Rating: on line 8931-8494 : Rate B, Rate C , 0.0, 0.0 -> 9859
% INFO    : Updated Thermal Rating: on line 1643-4511 : Rate B, Rate C , 0.0, 0.0 -> 30359
% INFO    : Updated Thermal Rating: on line 196-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25834
% INFO    : Updated Thermal Rating: on line 2902-5573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48210
% INFO    : Updated Thermal Rating: on line 4950-4410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on line 4950-333 : Rate B, Rate C , 0.0, 0.0 -> 1329
% INFO    : Updated Thermal Rating: on line 4950-6908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 3377-7726 : Rate B, Rate C , 0.0, 0.0 -> 76413
% INFO    : Updated Thermal Rating: on line 1027-3243 : Rate B, Rate C , 0.0, 0.0 -> 30849
% INFO    : Updated Thermal Rating: on line 1027-2458 : Rate B, Rate C , 0.0, 0.0 -> 1909
% INFO    : Updated Thermal Rating: on line 1027-2919 : Rate B, Rate C , 0.0, 0.0 -> 7375
% INFO    : Updated Thermal Rating: on line 5308-8560 : Rate B, Rate C , 0.0, 0.0 -> 28859
% INFO    : Updated Thermal Rating: on line 5308-6427 : Rate B, Rate C , 0.0, 0.0 -> 1872
% INFO    : Updated Thermal Rating: on line 5308-8347 : Rate B, Rate C , 0.0, 0.0 -> 2490
% INFO    : Updated Thermal Rating: on line 7148-5610 : Rate B, Rate C , 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 7148-2421 : Rate B, Rate C , 0.0, 0.0 -> 5934
% INFO    : Updated Thermal Rating: on line 7148-2421 : Rate B, Rate C , 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 7148-2421 : Rate B, Rate C , 0.0, 0.0 -> 6164
% INFO    : Updated Thermal Rating: on line 7148-6989 : Rate B, Rate C , 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 44-1545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1566
% INFO    : Updated Thermal Rating: on line 44-3541 : Rate B, Rate C , 0.0, 0.0 -> 1338
% INFO    : Updated Thermal Rating: on line 6231-4710 : Rate B, Rate C , 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 6231-8367 : Rate B, Rate C , 0.0, 0.0 -> 1785
% INFO    : Updated Thermal Rating: on line 6231-2288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5477
% INFO    : Updated Thermal Rating: on line 8291-8473 : Rate B, Rate C , 0.0, 0.0 -> 3592
% INFO    : Updated Thermal Rating: on line 8291-5455 : Rate B, Rate C , 0.0, 0.0 -> 6500
% INFO    : Updated Thermal Rating: on line 8291-7635 : Rate B, Rate C , 0.0, 0.0 -> 2493
% INFO    : Updated Thermal Rating: on line 6842-8473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3825
% INFO    : Updated Thermal Rating: on line 6842-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 6842-2288 : Rate B, Rate C , 0.0, 0.0 -> 5255
% INFO    : Updated Thermal Rating: on line 3969-7726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3635
% INFO    : Updated Thermal Rating: on line 1090-1129 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 1090-3070 : Rate B, Rate C , 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 8515-5365 : Rate B, Rate C , 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 8515-5365 : Rate B, Rate C , 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 8515-4529 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 8515-3364 : Rate B, Rate C , 0.0, 0.0 -> 41929
% INFO    : Updated Thermal Rating: on line 935-5383 : Rate B, Rate C , 0.0, 0.0 -> 4856
% INFO    : Updated Thermal Rating: on line 920-6570 : Rate B, Rate C , 0.0, 0.0 -> 155017
% INFO    : Updated Thermal Rating: on line 6664-4426 : Rate B, Rate C , 0.0, 0.0 -> 13291
% INFO    : Updated Thermal Rating: on line 4339-2183 : Rate B, Rate C , 0.0, 0.0 -> 9586
% INFO    : Updated Thermal Rating: on line 7513-4000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9693
% INFO    : Updated Thermal Rating: on line 6570-8542 : Rate B, Rate C , 0.0, 0.0 -> 8963
% INFO    : Updated Thermal Rating: on line 6570-8542 : Rate B, Rate C , 0.0, 0.0 -> 9449
% INFO    : Updated Thermal Rating: on line 6570-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2322
% INFO    : Updated Thermal Rating: on line 6570-9119 : Rate B, Rate C , 0.0, 0.0 -> 4647
% INFO    : Updated Thermal Rating: on line 6570-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7843
% INFO    : Updated Thermal Rating: on line 502-3589 : Rate B, Rate C , 0.0, 0.0 -> 10995
% INFO    : Updated Thermal Rating: on line 8473-1040 : Rate B, Rate C , 0.0, 0.0 -> 12244
% INFO    : Updated Thermal Rating: on line 8473-145 : Rate B, Rate C , 0.0, 0.0 -> 25543
% INFO    : Updated Thermal Rating: on line 8473-4267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23628
% INFO    : Updated Thermal Rating: on line 4936-5179 : Rate B, Rate C , 0.0, 0.0 -> 3164
% INFO    : Updated Thermal Rating: on line 5317-8854 : Rate B, Rate C , 0.0, 0.0 -> 12765
% INFO    : Updated Thermal Rating: on line 9018-4 : Rate B, Rate C , 0.0, 0.0 -> 3374
% INFO    : Updated Thermal Rating: on line 9018-4829 : Rate B, Rate C , 0.0, 0.0 -> 2406
% INFO    : Updated Thermal Rating: on line 6253-5383 : Rate B, Rate C , 0.0, 0.0 -> 2604
% INFO    : Updated Thermal Rating: on line 6253-7507 : Rate B, Rate C , 0.0, 0.0 -> 2881
% INFO    : Updated Thermal Rating: on line 8887-1644 : Rate B, Rate C , 0.0, 0.0 -> 3037
% INFO    : Updated Thermal Rating: on line 8887-3483 : Rate B, Rate C , 0.0, 0.0 -> 2684
% INFO    : Updated Thermal Rating: on line 6639-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3311
% INFO    : Updated Thermal Rating: on line 6639-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3250
% INFO    : Updated Thermal Rating: on line 5461-8109 : Rate B, Rate C , 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 6291-4189 : Rate B, Rate C , 0.0, 0.0 -> 1258
% INFO    : Updated Thermal Rating: on line 8405-4747 : Rate B, Rate C , 0.0, 0.0 -> 7369
% INFO    : Updated Thermal Rating: on line 8405-4580 : Rate B, Rate C , 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 338-7824 : Rate B, Rate C , 0.0, 0.0 -> 11239
% INFO    : Updated Thermal Rating: on line 2468-7824 : Rate B, Rate C , 0.0, 0.0 -> 11053
% INFO    : Updated Thermal Rating: on line 5257-7824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13399
% INFO    : Updated Thermal Rating: on line 2189-7824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13134
% INFO    : Updated Thermal Rating: on line 8458-8267 : Rate B, Rate C , 0.0, 0.0 -> 16324
% INFO    : Updated Thermal Rating: on line 2676-5987 : Rate B, Rate C , 0.0, 0.0 -> 2085
% INFO    : Updated Thermal Rating: on line 1187-5712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2558
% INFO    : Updated Thermal Rating: on line 1187-6521 : Rate B, Rate C , 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 2360-8636 : Rate B, Rate C , 0.0, 0.0 -> 5704
% INFO    : Updated Thermal Rating: on line 2360-8829 : Rate B, Rate C , 0.0, 0.0 -> 25455
% INFO    : Updated Thermal Rating: on line 2360-4235 : Rate B, Rate C , 0.0, 0.0 -> 1801
% INFO    : Updated Thermal Rating: on line 2360-4235 : Rate B, Rate C , 0.0, 0.0 -> 1773
% INFO    : Updated Thermal Rating: on line 2360-4235 : Rate B, Rate C , 0.0, 0.0 -> 1833
% INFO    : Updated Thermal Rating: on line 8818-5099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 5781-4734 : Rate B, Rate C , 0.0, 0.0 -> 2600
% INFO    : Updated Thermal Rating: on line 5781-905 : Rate B, Rate C , 0.0, 0.0 -> 3928
% INFO    : Updated Thermal Rating: on line 5781-8334 : Rate B, Rate C , 0.0, 0.0 -> 4709
% INFO    : Updated Thermal Rating: on line 5781-2093 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on line 6772-6989 : Rate B, Rate C , 0.0, 0.0 -> 10553
% INFO    : Updated Thermal Rating: on line 7885-3912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 6730-3912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67388
% INFO    : Updated Thermal Rating: on line 4301-3912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64510
% INFO    : Updated Thermal Rating: on line 5362-5610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5841
% INFO    : Updated Thermal Rating: on line 5362-350 : Rate B, Rate C , 0.0, 0.0 -> 28553
% INFO    : Updated Thermal Rating: on line 5362-6763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28222
% INFO    : Updated Thermal Rating: on line 3855-1973 : Rate B, Rate C , 0.0, 0.0 -> 37967
% INFO    : Updated Thermal Rating: on line 3855-1973 : Rate B, Rate C , 0.0, 0.0 -> 22051
% INFO    : Updated Thermal Rating: on line 3481-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1342
% INFO    : Updated Thermal Rating: on line 5460-8222 : Rate B, Rate C , 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 5460-8222 : Rate B, Rate C , 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 5460-2721 : Rate B, Rate C , 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 5460-2721 : Rate B, Rate C , 0.0, 0.0 -> 2858
% INFO    : Updated Thermal Rating: on line 3786-8578 : Rate B, Rate C , 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 490-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46468
% INFO    : Updated Thermal Rating: on line 148-7069 : Rate B, Rate C , 0.0, 0.0 -> 25372
% INFO    : Updated Thermal Rating: on line 7256-8743 : Rate B, Rate C , 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 7256-1742 : Rate B, Rate C , 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 8930-314 : Rate B, Rate C , 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 6954-7974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93784
% INFO    : Updated Thermal Rating: on line 3325-7974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99888
% INFO    : Updated Thermal Rating: on line 5627-1742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16564
% INFO    : Updated Thermal Rating: on line 5610-6989 : Rate B, Rate C , 0.0, 0.0 -> 4733
% INFO    : Updated Thermal Rating: on line 21-6163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55892
% INFO    : Updated Thermal Rating: on line 3749-5365 : Rate B, Rate C , 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 3749-6982 : Rate B, Rate C , 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 2291-3133 : Rate B, Rate C , 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 2291-4738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 2291-3656 : Rate B, Rate C , 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 314-4300 : Rate B, Rate C , 0.0, 0.0 -> 7799
% INFO    : Updated Thermal Rating: on line 314-5789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7797
% INFO    : Updated Thermal Rating: on line 314-2467 : Rate B, Rate C , 0.0, 0.0 -> 1749
% INFO    : Updated Thermal Rating: on line 314-2467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1709
% INFO    : Updated Thermal Rating: on line 314-5256 : Rate B, Rate C , 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 3200-2653 : Rate B, Rate C , 0.0, 0.0 -> 29775
% INFO    : Updated Thermal Rating: on line 4679-4852 : Rate B, Rate C , 0.0, 0.0 -> 2496
% INFO    : Updated Thermal Rating: on line 4679-4852 : Rate B, Rate C , 0.0, 0.0 -> 3923
% INFO    : Updated Thermal Rating: on line 4679-1151 : Rate B, Rate C , 0.0, 0.0 -> 9867
% INFO    : Updated Thermal Rating: on line 8568-5215 : Rate B, Rate C , 0.0, 0.0 -> 13881
% INFO    : Updated Thermal Rating: on line 58-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8180
% INFO    : Updated Thermal Rating: on line 6807-851 : Rate B, Rate C , 0.0, 0.0 -> 3799
% INFO    : Updated Thermal Rating: on line 150-5099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 150-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6482
% INFO    : Updated Thermal Rating: on line 7209-2934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9308
% INFO    : Updated Thermal Rating: on line 1465-4787 : Rate B, Rate C , 0.0, 0.0 -> 4611
% INFO    : Updated Thermal Rating: on line 1465-3830 : Rate B, Rate C , 0.0, 0.0 -> 6274
% INFO    : Updated Thermal Rating: on line 1465-5648 : Rate B, Rate C , 0.0, 0.0 -> 6400
% INFO    : Updated Thermal Rating: on line 1465-4000 : Rate B, Rate C , 0.0, 0.0 -> 5103
% INFO    : Updated Thermal Rating: on line 7537-3485 : Rate B, Rate C , 0.0, 0.0 -> 10015
% INFO    : Updated Thermal Rating: on line 7537-3830 : Rate B, Rate C , 0.0, 0.0 -> 4715
% INFO    : Updated Thermal Rating: on line 7537-5648 : Rate B, Rate C , 0.0, 0.0 -> 4647
% INFO    : Updated Thermal Rating: on line 1262-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1832
% INFO    : Updated Thermal Rating: on line 1262-1156 : Rate B, Rate C , 0.0, 0.0 -> 2737
% INFO    : Updated Thermal Rating: on line 1262-4914 : Rate B, Rate C , 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 1262-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2821
% INFO    : Updated Thermal Rating: on line 1262-3834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11729
% INFO    : Updated Thermal Rating: on line 1262-556 : Rate B, Rate C , 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 1262-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4048
% INFO    : Updated Thermal Rating: on line 1262-7923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12172
% INFO    : Updated Thermal Rating: on line 1551-4103 : Rate B, Rate C , 0.0, 0.0 -> 2607
% INFO    : Updated Thermal Rating: on line 1551-7862 : Rate B, Rate C , 0.0, 0.0 -> 4274
% INFO    : Updated Thermal Rating: on line 1551-5458 : Rate B, Rate C , 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 1551-1838 : Rate B, Rate C , 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 3070-2888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10884
% INFO    : Updated Thermal Rating: on line 4874-4504 : Rate B, Rate C , 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 4874-3579 : Rate B, Rate C , 0.0, 0.0 -> 2469
% INFO    : Updated Thermal Rating: on line 4874-3579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2614
% INFO    : Updated Thermal Rating: on line 4874-7903 : Rate B, Rate C , 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on line 6368-1102 : Rate B, Rate C , 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on line 6368-9217 : Rate B, Rate C , 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 6368-5653 : Rate B, Rate C , 0.0, 0.0 -> 1841
% INFO    : Updated Thermal Rating: on line 8478-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 5241-6921 : Rate B, Rate C , 0.0, 0.0 -> 3877
% INFO    : Updated Thermal Rating: on line 4-1813 : Rate B, Rate C , 0.0, 0.0 -> 2021
% INFO    : Updated Thermal Rating: on line 8950-7049 : Rate B, Rate C , 0.0, 0.0 -> 9413
% INFO    : Updated Thermal Rating: on line 6846-8788 : Rate B, Rate C , 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 6846-6734 : Rate B, Rate C , 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 4426-5616 : Rate A, Rate B, Rate C , 553.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 4426-1965 : Rate B, Rate C , 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 4426-1767 : Rate B, Rate C , 0.0, 0.0 -> 684
% INFO    : Updated Thermal Rating: on line 3037-1102 : Rate B, Rate C , 0.0, 0.0 -> 7428
% INFO    : Updated Thermal Rating: on line 3037-8485 : Rate B, Rate C , 0.0, 0.0 -> 4197
% INFO    : Updated Thermal Rating: on line 3037-5653 : Rate B, Rate C , 0.0, 0.0 -> 2553
% INFO    : Updated Thermal Rating: on line 5395-4661 : Rate B, Rate C , 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 5395-520 : Rate B, Rate C , 0.0, 0.0 -> 3383
% INFO    : Updated Thermal Rating: on line 5395-6816 : Rate B, Rate C , 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 5395-5918 : Rate B, Rate C , 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on line 5395-5918 : Rate B, Rate C , 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on line 8636-1380 : Rate B, Rate C , 0.0, 0.0 -> 2291
% INFO    : Updated Thermal Rating: on line 3436-4239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2547
% INFO    : Updated Thermal Rating: on line 3436-4239 : Rate B, Rate C , 0.0, 0.0 -> 2529
% INFO    : Updated Thermal Rating: on line 3436-3656 : Rate B, Rate C , 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on line 6203-7124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on line 9059-7124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 5994-96 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 5049-306 : Rate B, Rate C , 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 718-8397 : Rate B, Rate C , 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 718-6982 : Rate B, Rate C , 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 7202-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 7202-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 8592-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5816
% INFO    : Updated Thermal Rating: on line 6581-823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95544
% INFO    : Updated Thermal Rating: on line 6581-1680 : Rate B, Rate C , 0.0, 0.0 -> 92864
% INFO    : Updated Thermal Rating: on line 6199-953 : Rate B, Rate C , 0.0, 0.0 -> 12195
% INFO    : Updated Thermal Rating: on line 6199-1817 : Rate B, Rate C , 0.0, 0.0 -> 12483
% INFO    : Updated Thermal Rating: on line 3231-1504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3602
% INFO    : Updated Thermal Rating: on line 3231-7226 : Rate B, Rate C , 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 2928-7865 : Rate B, Rate C , 0.0, 0.0 -> 37425
% INFO    : Updated Thermal Rating: on line 3916-6891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2768
% INFO    : Updated Thermal Rating: on line 6053-171 : Rate B, Rate C , 0.0, 0.0 -> 1839
% INFO    : Updated Thermal Rating: on line 6053-171 : Rate B, Rate C , 0.0, 0.0 -> 1876
% INFO    : Updated Thermal Rating: on line 8829-3044 : Rate B, Rate C , 0.0, 0.0 -> 26188
% INFO    : Updated Thermal Rating: on line 1552-1194 : Rate B, Rate C , 0.0, 0.0 -> 4405
% INFO    : Updated Thermal Rating: on line 3912-3740 : Rate B, Rate C , 0.0, 0.0 -> 6862
% INFO    : Updated Thermal Rating: on line 3912-2695 : Rate B, Rate C , 0.0, 0.0 -> 18126
% INFO    : Updated Thermal Rating: on line 3912-2695 : Rate B, Rate C , 0.0, 0.0 -> 40050
% INFO    : Updated Thermal Rating: on line 3912-8877 : Rate B, Rate C , 0.0, 0.0 -> 4693
% INFO    : Updated Thermal Rating: on line 7520-8222 : Rate B, Rate C , 0.0, 0.0 -> 3758
% INFO    : Updated Thermal Rating: on line 7520-8222 : Rate B, Rate C , 0.0, 0.0 -> 3689
% INFO    : Updated Thermal Rating: on line 2421-3610 : Rate B, Rate C , 0.0, 0.0 -> 1819
% INFO    : Updated Thermal Rating: on line 2421-1414 : Rate B, Rate C , 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 8879-3610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1615
% INFO    : Updated Thermal Rating: on line 8397-5918 : Rate B, Rate C , 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 1914-6982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11266
% INFO    : Updated Thermal Rating: on line 7873-6638 : Rate B, Rate C , 0.0, 0.0 -> 2308
% INFO    : Updated Thermal Rating: on line 4562-7702 : Rate B, Rate C , 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 4562-7702 : Rate B, Rate C , 0.0, 0.0 -> 2639
% INFO    : Updated Thermal Rating: on line 8835-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5127
% INFO    : Updated Thermal Rating: on line 8835-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5224
% INFO    : Updated Thermal Rating: on line 3390-408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39117
% INFO    : Updated Thermal Rating: on line 3390-7231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45856
% INFO    : Updated Thermal Rating: on line 3390-5993 : Rate B, Rate C , 0.0, 0.0 -> 3676
% INFO    : Updated Thermal Rating: on line 1910-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30131
% INFO    : Updated Thermal Rating: on line 3975-7353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 3126-7495 : Rate B, Rate C , 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 2689-5753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8836
% INFO    : Updated Thermal Rating: on line 1201-4235 : Rate B, Rate C , 0.0, 0.0 -> 3507
% INFO    : Updated Thermal Rating: on line 7626-7076 : Rate B, Rate C , 0.0, 0.0 -> 74627
% INFO    : Updated Thermal Rating: on line 4823-4060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5902
% INFO    : Updated Thermal Rating: on line 4141-1311 : Rate B, Rate C , 0.0, 0.0 -> 3816
% INFO    : Updated Thermal Rating: on line 7124-4566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 7124-8873 : Rate B, Rate C , 0.0, 0.0 -> 32351
% INFO    : Updated Thermal Rating: on line 6684-5383 : Rate B, Rate C , 0.0, 0.0 -> 3092
% INFO    : Updated Thermal Rating: on line 8151-5383 : Rate B, Rate C , 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 4357-6619 : Rate B, Rate C , 0.0, 0.0 -> 4605
% INFO    : Updated Thermal Rating: on line 8191-8765 : Rate B, Rate C , 0.0, 0.0 -> 5309
% INFO    : Updated Thermal Rating: on line 7466-5469 : Rate B, Rate C , 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 3401-5351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87580
% INFO    : Updated Thermal Rating: on line 3760-225 : Rate B, Rate C , 0.0, 0.0 -> 4182
% INFO    : Updated Thermal Rating: on line 53-4031 : Rate B, Rate C , 0.0, 0.0 -> 1290
% INFO    : Updated Thermal Rating: on line 8222-6921 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 8222-6921 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 6556-4239 : Rate B, Rate C , 0.0, 0.0 -> 5553
% INFO    : Updated Thermal Rating: on line 6556-4239 : Rate B, Rate C , 0.0, 0.0 -> 5069
% INFO    : Updated Thermal Rating: on line 2940-7178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3077
% INFO    : Updated Thermal Rating: on line 3928-2563 : Rate B, Rate C , 0.0, 0.0 -> 15364
% INFO    : Updated Thermal Rating: on line 3928-6521 : Rate B, Rate C , 0.0, 0.0 -> 47279
% INFO    : Updated Thermal Rating: on line 1923-3830 : Rate B, Rate C , 0.0, 0.0 -> 6234
% INFO    : Updated Thermal Rating: on line 1923-5648 : Rate B, Rate C , 0.0, 0.0 -> 6371
% INFO    : Updated Thermal Rating: on line 2815-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39182
% INFO    : Updated Thermal Rating: on line 2815-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41796
% INFO    : Updated Thermal Rating: on line 4125-1644 : Rate A, Rate B, Rate C , 1843.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 163-3498 : Rate B, Rate C , 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 163-2430 : Rate B, Rate C , 0.0, 0.0 -> 1528
% INFO    : Updated Thermal Rating: on line 7943-9108 : Rate B, Rate C , 0.0, 0.0 -> 8334
% INFO    : Updated Thermal Rating: on line 7943-1478 : Rate B, Rate C , 0.0, 0.0 -> 8174
% INFO    : Updated Thermal Rating: on line 2308-3541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5453
% INFO    : Updated Thermal Rating: on line 3535-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5552
% INFO    : Updated Thermal Rating: on line 2019-8542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21943
% INFO    : Updated Thermal Rating: on line 5174-8542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22129
% INFO    : Updated Thermal Rating: on line 7945-5215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9325
% INFO    : Updated Thermal Rating: on line 2057-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18132
% INFO    : Updated Thermal Rating: on line 2057-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18519
% INFO    : Updated Thermal Rating: on line 4661-6816 : Rate B, Rate C , 0.0, 0.0 -> 996
% INFO    : Updated Thermal Rating: on line 7519-776 : Rate B, Rate C , 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 8989-3435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65948
% INFO    : Updated Thermal Rating: on line 7797-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65948
% INFO    : Updated Thermal Rating: on line 871-4031 : Rate B, Rate C , 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 871-2878 : Rate B, Rate C , 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 7353-9164 : Rate B, Rate C , 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 7974-2012 : Rate B, Rate C , 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 7974-2012 : Rate B, Rate C , 0.0, 0.0 -> 2132
% INFO    : Updated Thermal Rating: on line 7974-1750 : Rate B, Rate C , 0.0, 0.0 -> 3105
% INFO    : Updated Thermal Rating: on line 1401-2303 : Rate B, Rate C , 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 4504-7903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1009
% INFO    : Updated Thermal Rating: on line 5837-449 : Rate B, Rate C , 0.0, 0.0 -> 3535
% INFO    : Updated Thermal Rating: on line 5837-449 : Rate B, Rate C , 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 5837-1817 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 5837-2458 : Rate B, Rate C , 0.0, 0.0 -> 3347
% INFO    : Updated Thermal Rating: on line 5837-6427 : Rate B, Rate C , 0.0, 0.0 -> 3557
% INFO    : Updated Thermal Rating: on line 5837-1730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 9217-594 : Rate B, Rate C , 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on line 6351-5393 : Rate B, Rate C , 0.0, 0.0 -> 7699
% INFO    : Updated Thermal Rating: on line 6194-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 2503-7491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 4031-2872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7474
% INFO    : Updated Thermal Rating: on line 4031-8043 : Rate B, Rate C , 0.0, 0.0 -> 1667
% INFO    : Updated Thermal Rating: on line 1813-2866 : Rate B, Rate C , 0.0, 0.0 -> 1824
% INFO    : Updated Thermal Rating: on line 5365-5417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 5365-4100 : Rate B, Rate C , 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 5365-1556 : Rate B, Rate C , 0.0, 0.0 -> 55676
% INFO    : Updated Thermal Rating: on line 3894-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1228
% INFO    : Updated Thermal Rating: on line 128-1554 : Rate B, Rate C , 0.0, 0.0 -> 19092
% INFO    : Updated Thermal Rating: on line 198-7994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2671
% INFO    : Updated Thermal Rating: on line 198-1554 : Rate B, Rate C , 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 2985-3133 : Rate B, Rate C , 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 7316-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23827
% INFO    : Updated Thermal Rating: on line 6486-8992 : Rate B, Rate C , 0.0, 0.0 -> 2371
% INFO    : Updated Thermal Rating: on line 8485-594 : Rate B, Rate C , 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 682-8477 : Rate B, Rate C , 0.0, 0.0 -> 7532
% INFO    : Updated Thermal Rating: on line 5146-5488 : Rate B, Rate C , 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 6638-776 : Rate B, Rate C , 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 8788-789 : Rate B, Rate C , 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 6332-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5705
% INFO    : Updated Thermal Rating: on line 6332-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5809
% INFO    : Updated Thermal Rating: on line 1883-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 1883-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 171-2341 : Rate B, Rate C , 0.0, 0.0 -> 2364
% INFO    : Updated Thermal Rating: on line 6630-10 : Rate B, Rate C , 0.0, 0.0 -> 16165
% INFO    : Updated Thermal Rating: on line 4484-4239 : Rate B, Rate C , 0.0, 0.0 -> 19365
% INFO    : Updated Thermal Rating: on line 3044-4235 : Rate B, Rate C , 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 851-4454 : Rate B, Rate C , 0.0, 0.0 -> 3535
% INFO    : Updated Thermal Rating: on line 3485-2183 : Rate B, Rate C , 0.0, 0.0 -> 11041
% INFO    : Updated Thermal Rating: on line 1156-7923 : Rate B, Rate C , 0.0, 0.0 -> 3479
% INFO    : Updated Thermal Rating: on line 1156-1233 : Rate B, Rate C , 0.0, 0.0 -> 80052
% INFO    : Updated Thermal Rating: on line 8913-4852 : Rate B, Rate C , 0.0, 0.0 -> 3446
% INFO    : Updated Thermal Rating: on line 4039-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70621
% INFO    : Updated Thermal Rating: on line 4914-2653 : Rate B, Rate C , 0.0, 0.0 -> 59321
% INFO    : Updated Thermal Rating: on line 4914-2653 : Rate B, Rate C , 0.0, 0.0 -> 62899
% INFO    : Updated Thermal Rating: on line 4914-556 : Rate B, Rate C , 0.0, 0.0 -> 8170
% INFO    : Updated Thermal Rating: on line 4914-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11052
% INFO    : Updated Thermal Rating: on line 7994-5256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 1709-3346 : Rate B, Rate C , 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on line 1709-8468 : Rate B, Rate C , 0.0, 0.0 -> 3639
% INFO    : Updated Thermal Rating: on line 7702-1234 : Rate B, Rate C , 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 7702-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 8677-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 8189-3643 : Rate B, Rate C , 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 3133-8477 : Rate B, Rate C , 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 6744-6101 : Rate B, Rate C , 0.0, 0.0 -> 2551
% INFO    : Updated Thermal Rating: on line 8542-4313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17353
% INFO    : Updated Thermal Rating: on line 769-5233 : Rate B, Rate C , 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 1965-5926 : Rate B, Rate C , 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 9014-3999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21842
% INFO    : Updated Thermal Rating: on line 1917-8406 : Rate B, Rate C , 0.0, 0.0 -> 11385
% INFO    : Updated Thermal Rating: on line 1917-2021 : Rate B, Rate C , 0.0, 0.0 -> 11989
% INFO    : Updated Thermal Rating: on line 1917-8293 : Rate B, Rate C , 0.0, 0.0 -> 2601
% INFO    : Updated Thermal Rating: on line 4738-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 867
% INFO    : Updated Thermal Rating: on line 4738-8477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3636
% INFO    : Updated Thermal Rating: on line 7998-1644 : Rate B, Rate C , 0.0, 0.0 -> 4432
% INFO    : Updated Thermal Rating: on line 6734-1015 : Rate B, Rate C , 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 6734-8992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 6734-789 : Rate B, Rate C , 0.0, 0.0 -> 2512
% INFO    : Updated Thermal Rating: on line 5004-5393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17113
% INFO    : Updated Thermal Rating: on line 1708-3906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73380
% INFO    : Updated Thermal Rating: on line 9150-3906 : Rate B, Rate C , 0.0, 0.0 -> 78748
% INFO    : Updated Thermal Rating: on line 280-9158 : Rate B, Rate C , 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 8043-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 5712-8992 : Rate B, Rate C , 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 5712-8466 : Rate B, Rate C , 0.0, 0.0 -> 9920
% INFO    : Updated Thermal Rating: on line 5712-6880 : Rate B, Rate C , 0.0, 0.0 -> 10368
% INFO    : Updated Thermal Rating: on line 5215-7266 : Rate B, Rate C , 0.0, 0.0 -> 5338
% INFO    : Updated Thermal Rating: on line 8807-8992 : Rate B, Rate C , 0.0, 0.0 -> 4978
% INFO    : Updated Thermal Rating: on line 8807-8992 : Rate B, Rate C , 0.0, 0.0 -> 4887
% INFO    : Updated Thermal Rating: on line 8807-8992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6219
% INFO    : Updated Thermal Rating: on line 218-2088 : Rate B, Rate C , 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on line 520-5918 : Rate B, Rate C , 0.0, 0.0 -> 1999
% INFO    : Updated Thermal Rating: on line 2653-2128 : Rate B, Rate C , 0.0, 0.0 -> 36817
% INFO    : Updated Thermal Rating: on line 1216-5233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55045
% INFO    : Updated Thermal Rating: on line 8980-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13915
% INFO    : Updated Thermal Rating: on line 5212-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14137
% INFO    : Updated Thermal Rating: on line 3656-4060 : Rate B, Rate C , 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 883-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 5144-3346 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 3498-2563 : Rate B, Rate C , 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 1896-8200 : Rate B, Rate C , 0.0, 0.0 -> 29948
% INFO    : Updated Thermal Rating: on line 9130-8864 : Rate B, Rate C , 0.0, 0.0 -> 1805
% INFO    : Updated Thermal Rating: on line 3503-2510 : Rate B, Rate C , 0.0, 0.0 -> 2962
% INFO    : Updated Thermal Rating: on line 3503-6146 : Rate B, Rate C , 0.0, 0.0 -> 4121
% INFO    : Updated Thermal Rating: on line 401-1584 : Rate B, Rate C , 0.0, 0.0 -> 102150
% INFO    : Updated Thermal Rating: on line 7328-6921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 7328-6921 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 6816-5573 : Rate B, Rate C , 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on line 7396-8564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62614
% INFO    : Updated Thermal Rating: on line 7396-8564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63968
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 3095
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 4173
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 4092
% INFO    : Updated Thermal Rating: on line 6921-8200 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 2949-3121 : Rate B, Rate C , 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 2949-3121 : Rate B, Rate C , 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 953-1730 : Rate B, Rate C , 0.0, 0.0 -> 2312
% INFO    : Updated Thermal Rating: on line 1767-892 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 4674-4889 : Rate B, Rate C , 0.0, 0.0 -> 6553
% INFO    : Updated Thermal Rating: on line 4674-7076 : Rate B, Rate C , 0.0, 0.0 -> 28567
% INFO    : Updated Thermal Rating: on line 1234-8035 : Rate B, Rate C , 0.0, 0.0 -> 5032
% INFO    : Updated Thermal Rating: on line 115-225 : Rate B, Rate C , 0.0, 0.0 -> 8039
% INFO    : Updated Thermal Rating: on line 5720-8578 : Rate B, Rate C , 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 3579-5469 : Rate B, Rate C , 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 3246-124 : Rate B, Rate C , 0.0, 0.0 -> 28416
% INFO    : Updated Thermal Rating: on line 8846-4783 : Rate B, Rate C , 0.0, 0.0 -> 28923
% INFO    : Updated Thermal Rating: on line 2393-3306 : Rate B, Rate C , 0.0, 0.0 -> 35458
% INFO    : Updated Thermal Rating: on line 1895-4480 : Rate B, Rate C , 0.0, 0.0 -> 35026
% INFO    : Updated Thermal Rating: on line 678-4454 : Rate B, Rate C , 0.0, 0.0 -> 28133
% INFO    : Updated Thermal Rating: on line 1002-4852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11613
% INFO    : Updated Thermal Rating: on line 6429-2012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8540
% INFO    : Updated Thermal Rating: on line 4889-7076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11440
% INFO    : Updated Thermal Rating: on line 5341-7491 : Rate B, Rate C , 0.0, 0.0 -> 6226
% INFO    : Updated Thermal Rating: on line 2563-6521 : Rate B, Rate C , 0.0, 0.0 -> 37622
% INFO    : Updated Thermal Rating: on line 1111-594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2494
% INFO    : Updated Thermal Rating: on line 4747-7791 : Rate B, Rate C , 0.0, 0.0 -> 4005
% INFO    : Updated Thermal Rating: on line 3906-3022 : Rate B, Rate C , 0.0, 0.0 -> 5690
% INFO    : Updated Thermal Rating: on line 3906-1194 : Rate B, Rate C , 0.0, 0.0 -> 5036
% INFO    : Updated Thermal Rating: on line 5993-8804 : Rate B, Rate C , 0.0, 0.0 -> 2911
% INFO    : Updated Thermal Rating: on line 1798-8487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5304
% INFO    : Updated Thermal Rating: on line 2467-7178 : Rate B, Rate C , 0.0, 0.0 -> 2142
% INFO    : Updated Thermal Rating: on line 2132-2303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 8992-8466 : Rate B, Rate C , 0.0, 0.0 -> 2819
% INFO    : Updated Thermal Rating: on line 8992-6880 : Rate B, Rate C , 0.0, 0.0 -> 3102
% INFO    : Updated Thermal Rating: on line 8992-2995 : Rate B, Rate C , 0.0, 0.0 -> 2211
% INFO    : Updated Thermal Rating: on line 805-3221 : Rate B, Rate C , 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 805-3327 : Rate B, Rate C , 0.0, 0.0 -> 2203
% INFO    : Updated Thermal Rating: on line 805-8310 : Rate B, Rate C , 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 805-2088 : Rate B, Rate C , 0.0, 0.0 -> 4025
% INFO    : Updated Thermal Rating: on line 5383-2021 : Rate B, Rate C , 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 5383-4114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9353
% INFO    : Updated Thermal Rating: on line 5383-5519 : Rate B, Rate C , 0.0, 0.0 -> 8632
% INFO    : Updated Thermal Rating: on line 5383-8293 : Rate B, Rate C , 0.0, 0.0 -> 7757
% INFO    : Updated Thermal Rating: on line 5383-3435 : Rate B, Rate C , 0.0, 0.0 -> 3571
% INFO    : Updated Thermal Rating: on line 7507-6990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10003
% INFO    : Updated Thermal Rating: on line 7507-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7874
% INFO    : Updated Thermal Rating: on line 7507-2020 : Rate B, Rate C , 0.0, 0.0 -> 3199
% INFO    : Updated Thermal Rating: on line 6478-6146 : Rate B, Rate C , 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 4852-2695 : Rate B, Rate C , 0.0, 0.0 -> 3390
% INFO    : Updated Thermal Rating: on line 4852-2695 : Rate B, Rate C , 0.0, 0.0 -> 3259
% INFO    : Updated Thermal Rating: on line 4852-5502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3517
% INFO    : Updated Thermal Rating: on line 4852-8877 : Rate B, Rate C , 0.0, 0.0 -> 6356
% INFO    : Updated Thermal Rating: on line 4852-9119 : Rate B, Rate C , 0.0, 0.0 -> 5658
% INFO    : Updated Thermal Rating: on line 4852-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5280
% INFO    : Updated Thermal Rating: on line 2012-1750 : Rate B, Rate C , 0.0, 0.0 -> 7030
% INFO    : Updated Thermal Rating: on line 1478-6616 : Rate B, Rate C , 0.0, 0.0 -> 2394
% INFO    : Updated Thermal Rating: on line 809-4594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2190
% INFO    : Updated Thermal Rating: on line 8656-4729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30397
% INFO    : Updated Thermal Rating: on line 4100-615 : Rate B, Rate C , 0.0, 0.0 -> 11773
% INFO    : Updated Thermal Rating: on line 4060-5393 : Rate B, Rate C , 0.0, 0.0 -> 6861
% INFO    : Updated Thermal Rating: on line 3296-4080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 176-3296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3043
% INFO    : Updated Thermal Rating: on line 1142-165 : Rate B, Rate C , 0.0, 0.0 -> 12582
% INFO    : Updated Thermal Rating: on line 1142-165 : Rate B, Rate C , 0.0, 0.0 -> 12386
% INFO    : Updated Thermal Rating: on line 4985-1142 : Rate B, Rate C , 0.0, 0.0 -> 3238
% INFO    : Updated Thermal Rating: on line 4985-1142 : Rate B, Rate C , 0.0, 0.0 -> 3307
% INFO    : Updated Thermal Rating: on line 1142-1533 : Rate B, Rate C , 0.0, 0.0 -> 10075
% INFO    : Updated Thermal Rating: on line 1059-1142 : Rate B, Rate C , 0.0, 0.0 -> 10868
% INFO    : Updated Thermal Rating: on line 914-1142 : Rate B, Rate C , 0.0, 0.0 -> 16188
% INFO    : Updated Thermal Rating: on line 6577-7621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4918
% INFO    : Updated Thermal Rating: on line 7740-7621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 6577-2382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4834
% INFO    : Updated Thermal Rating: on line 2382-8839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1721
% INFO    : Updated Thermal Rating: on line 6577-5758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2095
% INFO    : Updated Thermal Rating: on line 461-6577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 8839-6577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4020
% INFO    : Updated Thermal Rating: on line 4137-6905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2120
% INFO    : Updated Thermal Rating: on line 3849-4137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 4137-4568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8200
% INFO    : Updated Thermal Rating: on line 4137-9008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18439
% INFO    : Updated Thermal Rating: on line 6905-3247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11385
% INFO    : Updated Thermal Rating: on line 5758-627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5481
% INFO    : Updated Thermal Rating: on line 7959-1930 : Rate B, Rate C , 0.0, 0.0 -> 2318
% INFO    : Updated Thermal Rating: on line 8171-1930 : Rate B, Rate C , 0.0, 0.0 -> 1412
% INFO    : Updated Thermal Rating: on line 1930-436 : Rate B, Rate C , 0.0, 0.0 -> 3321
% INFO    : Updated Thermal Rating: on line 3448-2876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 6355-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2838
% INFO    : Updated Thermal Rating: on line 3448-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 3448-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 3448-3653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3269
% INFO    : Updated Thermal Rating: on line 3448-3653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3196
% INFO    : Updated Thermal Rating: on line 3448-3653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3234
% INFO    : Updated Thermal Rating: on line 6445-5808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 2451-6445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 6445-1877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 744
% INFO    : Updated Thermal Rating: on line 6445-1877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 6445-1877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 6445-696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1765
% INFO    : Updated Thermal Rating: on line 6445-696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 2838-6117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19790
% INFO    : Updated Thermal Rating: on line 8550-6117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3046
% INFO    : Updated Thermal Rating: on line 6117-4328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 3995-2943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115310
% INFO    : Updated Thermal Rating: on line 8536-3995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 5373-2943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 156-2943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1611
% INFO    : Updated Thermal Rating: on line 1931-8550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 6328-4258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 4258-3100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3860
% INFO    : Updated Thermal Rating: on line 7078-4258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 1014-4258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8641
% INFO    : Updated Thermal Rating: on line 4174-4258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8961
% INFO    : Updated Thermal Rating: on line 3100-5915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3186
% INFO    : Updated Thermal Rating: on line 9149-7074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 6699-3461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 7773-3763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 6606-156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 626-4475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 973-7904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 8744-4476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8963
% INFO    : Updated Thermal Rating: on line 1945-4476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 4476-6404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1418
% INFO    : Updated Thermal Rating: on line 4476-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 3320-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8135
% INFO    : Updated Thermal Rating: on line 176-3320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 8908-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8761
% INFO    : Updated Thermal Rating: on line 5939-8908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 7759-5883 : Rate B, Rate C , 0.0, 0.0 -> 14037
% INFO    : Updated Thermal Rating: on line 7759-5883 : Rate B, Rate C , 0.0, 0.0 -> 14354
% INFO    : Updated Thermal Rating: on line 603-7759 : Rate B, Rate C , 0.0, 0.0 -> 1847
% INFO    : Updated Thermal Rating: on line 603-7759 : Rate B, Rate C , 0.0, 0.0 -> 1885
% INFO    : Updated Thermal Rating: on line 7759-6072 : Rate B, Rate C , 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 7759-6072 : Rate B, Rate C , 0.0, 0.0 -> 1562
% INFO    : Updated Thermal Rating: on line 2725-8184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32762
% INFO    : Updated Thermal Rating: on line 3165-8184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2219
% INFO    : Updated Thermal Rating: on line 2725-5769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33362
% INFO    : Updated Thermal Rating: on line 7868-5769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7733
% INFO    : Updated Thermal Rating: on line 5535-3307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 3307-6875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 2125-4527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5535-2125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 2125-7034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 7605-4527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 165-2522 : Rate B, Rate C , 0.0, 0.0 -> 7941
% INFO    : Updated Thermal Rating: on line 165-2522 : Rate B, Rate C , 0.0, 0.0 -> 7785
% INFO    : Updated Thermal Rating: on line 165-2522 : Rate B, Rate C , 0.0, 0.0 -> 8716
% INFO    : Updated Thermal Rating: on line 165-2522 : Rate B, Rate C , 0.0, 0.0 -> 8908
% INFO    : Updated Thermal Rating: on line 4985-165 : Rate B, Rate C , 0.0, 0.0 -> 2601
% INFO    : Updated Thermal Rating: on line 7904-8904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 7904-7339 : Rate B, Rate C , 0.0, 0.0 -> 4224
% INFO    : Updated Thermal Rating: on line 5140-8904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 5140-4853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4300
% INFO    : Updated Thermal Rating: on line 7501-5140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on line 5140-7693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 2837-8744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2486
% INFO    : Updated Thermal Rating: on line 2860-2536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2536-8901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 3658-1379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 3658-1379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 1379-7756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3095
% INFO    : Updated Thermal Rating: on line 1379-5267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 1379-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 1379-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1766
% INFO    : Updated Thermal Rating: on line 7482-5496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33796
% INFO    : Updated Thermal Rating: on line 7482-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36412
% INFO    : Updated Thermal Rating: on line 8637-4978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4787
% INFO    : Updated Thermal Rating: on line 4978-4781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2354
% INFO    : Updated Thermal Rating: on line 6260-1818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 1818-2664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 671-1519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6260-1519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 867
% INFO    : Updated Thermal Rating: on line 1519-1210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5559
% INFO    : Updated Thermal Rating: on line 7228-8640 : Rate B, Rate C , 0.0, 0.0 -> 6876
% INFO    : Updated Thermal Rating: on line 7228-8640 : Rate B, Rate C , 0.0, 0.0 -> 6752
% INFO    : Updated Thermal Rating: on line 5133-3993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4034
% INFO    : Updated Thermal Rating: on line 1204-3993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 259-2725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 259-6779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5283
% INFO    : Updated Thermal Rating: on line 1966-259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 1966-259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1816
% INFO    : Updated Thermal Rating: on line 259-8111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70604
% INFO    : Updated Thermal Rating: on line 2725-7389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70604
% INFO    : Updated Thermal Rating: on line 7074-5915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 935
% INFO    : Updated Thermal Rating: on line 8436-7074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 6215-3461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23496
% INFO    : Updated Thermal Rating: on line 1966-6215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3094
% INFO    : Updated Thermal Rating: on line 2596-3763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24871
% INFO    : Updated Thermal Rating: on line 4590-2596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3358
% INFO    : Updated Thermal Rating: on line 6928-6102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9303
% INFO    : Updated Thermal Rating: on line 176-6928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 159-6635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18634
% INFO    : Updated Thermal Rating: on line 159-6102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9480
% INFO    : Updated Thermal Rating: on line 9079-6635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5687-6635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 156-5013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 5808-3312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 3312-1490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4866
% INFO    : Updated Thermal Rating: on line 840-8912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 840-1877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 232-840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1142
% INFO    : Updated Thermal Rating: on line 7247-2367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 2876-7247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on line 7247-3653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 4475-3581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 4475-6223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 5636-2876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2876-5304 : Rate B, Rate C , 0.0, 0.0 -> 1638
% INFO    : Updated Thermal Rating: on line 5606-2876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 5755-5304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2673
% INFO    : Updated Thermal Rating: on line 2454-5143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 6511-5143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3628
% INFO    : Updated Thermal Rating: on line 421-6318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13023
% INFO    : Updated Thermal Rating: on line 6318-1014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 8750-1987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6645-1987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 8737-1987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 1987-3831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5265-1987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 5405-4254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4254-8863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 2293-4254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 516
% INFO    : Updated Thermal Rating: on line 6005-7807 : Rate B, Rate C , 0.0, 0.0 -> 73510
% INFO    : Updated Thermal Rating: on line 1786-7807 : Rate B, Rate C , 0.0, 0.0 -> 4833
% INFO    : Updated Thermal Rating: on line 2059-6005 : Rate B, Rate C , 0.0, 0.0 -> 14360
% INFO    : Updated Thermal Rating: on line 2814-1006 : Rate B, Rate C , 0.0, 0.0 -> 47320
% INFO    : Updated Thermal Rating: on line 1786-2814 : Rate B, Rate C , 0.0, 0.0 -> 3228
% INFO    : Updated Thermal Rating: on line 1006-1650 : Rate B, Rate C , 0.0, 0.0 -> 10520
% INFO    : Updated Thermal Rating: on line 2059-4985 : Rate B, Rate C , 0.0, 0.0 -> 3675
% INFO    : Updated Thermal Rating: on line 1650-165 : Rate B, Rate C , 0.0, 0.0 -> 5012
% INFO    : Updated Thermal Rating: on line 3879-7698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12223
% INFO    : Updated Thermal Rating: on line 3879-9156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 5560-3879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 6534-4210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3889-4210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 5216-4210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 4456-4210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 4210-3101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 7698-5703 : Rate B, Rate C , 0.0, 0.0 -> 18395
% INFO    : Updated Thermal Rating: on line 110-421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8243-421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 8603-6079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3164
% INFO    : Updated Thermal Rating: on line 6079-3703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6079-300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6079-5936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2541-6157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3123
% INFO    : Updated Thermal Rating: on line 6157-7080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6157-6509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6157-1580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2541-8603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3703-7391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 4067-7080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5739-300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 365-6509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1372
% INFO    : Updated Thermal Rating: on line 5936-2528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 1580-7735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3756
% INFO    : Updated Thermal Rating: on line 8958-563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12194
% INFO    : Updated Thermal Rating: on line 563-5030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 8958-7368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12417
% INFO    : Updated Thermal Rating: on line 95-7368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1215
% INFO    : Updated Thermal Rating: on line 874-8958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3889-3223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 6676-5928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6676-7091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 277-6676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3455-5928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 6185-7091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 2742-8519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2220-6355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28225
% INFO    : Updated Thermal Rating: on line 2220-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 3603-8519 : Rate B, Rate C , 0.0, 0.0 -> 14907
% INFO    : Updated Thermal Rating: on line 6056-8519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15962
% INFO    : Updated Thermal Rating: on line 7907-6056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 396-5544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 5544-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 961-5544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 5544-5359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192276
% INFO    : Updated Thermal Rating: on line 6686-9134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1514-9134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 7001-9134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 3081-2334 : Rate B, Rate C , 0.0, 0.0 -> 2098
% INFO    : Updated Thermal Rating: on line 8385-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2917
% INFO    : Updated Thermal Rating: on line 8077-3658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14718
% INFO    : Updated Thermal Rating: on line 8077-4073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 952-6121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14973
% INFO    : Updated Thermal Rating: on line 952-8220 : Rate B, Rate C , 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 3658-3418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25454
% INFO    : Updated Thermal Rating: on line 1204-3418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 6121-3081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25060
% INFO    : Updated Thermal Rating: on line 3658-5770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23332
% INFO    : Updated Thermal Rating: on line 5770-5761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1138
% INFO    : Updated Thermal Rating: on line 4346-7228 : Rate B, Rate C , 0.0, 0.0 -> 1403
% INFO    : Updated Thermal Rating: on line 4346-7228 : Rate B, Rate C , 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 7228-5883 : Rate B, Rate C , 0.0, 0.0 -> 3952
% INFO    : Updated Thermal Rating: on line 7228-6741 : Rate B, Rate C , 0.0, 0.0 -> 3877
% INFO    : Updated Thermal Rating: on line 6121-6360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 6121-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3268
% INFO    : Updated Thermal Rating: on line 6859-4743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6859-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on line 4743-8023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 3581-5446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5375
% INFO    : Updated Thermal Rating: on line 2576-1108 : Rate B, Rate C , 0.0, 0.0 -> 16151
% INFO    : Updated Thermal Rating: on line 1108-4589 : Rate B, Rate C , 0.0, 0.0 -> 1323
% INFO    : Updated Thermal Rating: on line 2576-7907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4461
% INFO    : Updated Thermal Rating: on line 537-6012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1236
% INFO    : Updated Thermal Rating: on line 6012-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 8444-906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4986
% INFO    : Updated Thermal Rating: on line 4933-8444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 2379-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1924
% INFO    : Updated Thermal Rating: on line 4730-2379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 3555-4913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4429
% INFO    : Updated Thermal Rating: on line 5307-3555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 2470-4913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4484
% INFO    : Updated Thermal Rating: on line 2470-8590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 7322-1631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6376
% INFO    : Updated Thermal Rating: on line 2194-1631 : Rate B, Rate C , 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 6260-2820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1952
% INFO    : Updated Thermal Rating: on line 8752-2820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 4887-1276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2421
% INFO    : Updated Thermal Rating: on line 6260-1276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on line 6583-4887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4887-8970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 5307-4887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 4887-4093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 8678-6260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6260-4531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 6260-4531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 8162-6260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on line 8752-6260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 7322-6165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6288
% INFO    : Updated Thermal Rating: on line 6165-3406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1827
% INFO    : Updated Thermal Rating: on line 522-2587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7412
% INFO    : Updated Thermal Rating: on line 522-2945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3958
% INFO    : Updated Thermal Rating: on line 8340-522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 522-357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10950
% INFO    : Updated Thermal Rating: on line 8386-522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1556
% INFO    : Updated Thermal Rating: on line 4203-6377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6377-8739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10521
% INFO    : Updated Thermal Rating: on line 6377-8064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5869
% INFO    : Updated Thermal Rating: on line 5953-6377 : Rate B, Rate C , 0.0, 0.0 -> 1527
% INFO    : Updated Thermal Rating: on line 7636-5216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47405
% INFO    : Updated Thermal Rating: on line 7636-3586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46654
% INFO    : Updated Thermal Rating: on line 2378-3586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1873
% INFO    : Updated Thermal Rating: on line 6690-6713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9141-7543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6713-8833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37645
% INFO    : Updated Thermal Rating: on line 5642-7543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17716
% INFO    : Updated Thermal Rating: on line 4365-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18939
% INFO    : Updated Thermal Rating: on line 4316-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 4365-3214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19385
% INFO    : Updated Thermal Rating: on line 4531-3214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 1210-2664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 7963-5535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5535-7952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15981
% INFO    : Updated Thermal Rating: on line 3165-5535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 3165-5535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1825
% INFO    : Updated Thermal Rating: on line 4374-4531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4531-3172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 8863-2047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3741
% INFO    : Updated Thermal Rating: on line 4828-998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 998-3666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 1166-3666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2238
% INFO    : Updated Thermal Rating: on line 3455-998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1333-8340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1352
% INFO    : Updated Thermal Rating: on line 8131-1333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2564
% INFO    : Updated Thermal Rating: on line 5859-7100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 2576-5859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5801-7959 : Rate B, Rate C , 0.0, 0.0 -> 85590
% INFO    : Updated Thermal Rating: on line 3056-5801 : Rate B, Rate C , 0.0, 0.0 -> 89132
% INFO    : Updated Thermal Rating: on line 8130-8596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5014
% INFO    : Updated Thermal Rating: on line 6396-8596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42255
% INFO    : Updated Thermal Rating: on line 8130-5832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5102
% INFO    : Updated Thermal Rating: on line 7734-5832 : Rate B, Rate C , 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 4975-8130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 5802-5268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3789
% INFO    : Updated Thermal Rating: on line 8386-5802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1406
% INFO    : Updated Thermal Rating: on line 6425-5268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3724
% INFO    : Updated Thermal Rating: on line 6425-8340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 8368-5268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5995
% INFO    : Updated Thermal Rating: on line 1167-5268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8752-8536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 899
% INFO    : Updated Thermal Rating: on line 7237-8536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1986-8863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2678
% INFO    : Updated Thermal Rating: on line 8863-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 8863-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1215
% INFO    : Updated Thermal Rating: on line 8863-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 466-8863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2184-8243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15493
% INFO    : Updated Thermal Rating: on line 8435-8243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15774
% INFO    : Updated Thermal Rating: on line 1718-7190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7219
% INFO    : Updated Thermal Rating: on line 4822-1718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1791
% INFO    : Updated Thermal Rating: on line 2528-7818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1585
% INFO    : Updated Thermal Rating: on line 5358-2661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7487
% INFO    : Updated Thermal Rating: on line 5358-3181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 3829-2661 : Rate B, Rate C , 0.0, 0.0 -> 7590
% INFO    : Updated Thermal Rating: on line 7229-3829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 782
% INFO    : Updated Thermal Rating: on line 9157-2661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2576-5860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 517-5860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1572-5860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5860-5755 : Rate B, Rate C , 0.0, 0.0 -> 15384
% INFO    : Updated Thermal Rating: on line 7015-4250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1060
% INFO    : Updated Thermal Rating: on line 7462-7015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 7015-4590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 6698-7012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1952
% INFO    : Updated Thermal Rating: on line 6698-4120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 6698-4604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 7740-937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4992
% INFO    : Updated Thermal Rating: on line 3395-7740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3169
% INFO    : Updated Thermal Rating: on line 3395-3258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4418
% INFO    : Updated Thermal Rating: on line 3395-5402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2174
% INFO    : Updated Thermal Rating: on line 7735-8000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3720
% INFO    : Updated Thermal Rating: on line 1215-8000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3792
% INFO    : Updated Thermal Rating: on line 1215-2528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3333
% INFO    : Updated Thermal Rating: on line 1514-7168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1432
% INFO    : Updated Thermal Rating: on line 365-7168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1459
% INFO    : Updated Thermal Rating: on line 4731-1089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9667
% INFO    : Updated Thermal Rating: on line 4731-4120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 2244-1089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8657
% INFO    : Updated Thermal Rating: on line 2528-2244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3860
% INFO    : Updated Thermal Rating: on line 3837-1373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 1518-3837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5987
% INFO    : Updated Thermal Rating: on line 3837-5861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6093
% INFO    : Updated Thermal Rating: on line 3624-3837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1373-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26144
% INFO    : Updated Thermal Rating: on line 570-1288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 2213-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2204
% INFO    : Updated Thermal Rating: on line 4915-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2246
% INFO    : Updated Thermal Rating: on line 3735-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24221
% INFO    : Updated Thermal Rating: on line 4790-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8649-1466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2688-1300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9062-1466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14764
% INFO    : Updated Thermal Rating: on line 1300-5066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19159
% INFO    : Updated Thermal Rating: on line 3764-936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55154
% INFO    : Updated Thermal Rating: on line 2925-936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 3764-6213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59190
% INFO    : Updated Thermal Rating: on line 6213-7001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 8178-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2292-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 8435-2697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8699
% INFO    : Updated Thermal Rating: on line 9240-5446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 9240-5638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6958
% INFO    : Updated Thermal Rating: on line 5638-6389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90942
% INFO    : Updated Thermal Rating: on line 5729-6789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 6789-2783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7054
% INFO    : Updated Thermal Rating: on line 2779-5729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 2783-3040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88206
% INFO    : Updated Thermal Rating: on line 4883-6061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43152
% INFO    : Updated Thermal Rating: on line 9092-4883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 4883-7381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 1164-4963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70604
% INFO    : Updated Thermal Rating: on line 8394-4963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2002
% INFO    : Updated Thermal Rating: on line 1164-4123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72634
% INFO    : Updated Thermal Rating: on line 8745-4123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17814
% INFO    : Updated Thermal Rating: on line 631-3297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78969
% INFO    : Updated Thermal Rating: on line 3463-631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2697
% INFO    : Updated Thermal Rating: on line 6912-4456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75483
% INFO    : Updated Thermal Rating: on line 6912-8394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1855
% INFO    : Updated Thermal Rating: on line 8394-3297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1824
% INFO    : Updated Thermal Rating: on line 1875-5022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5022-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1057
% INFO    : Updated Thermal Rating: on line 5022-8745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5529
% INFO    : Updated Thermal Rating: on line 5022-5950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 8736-1164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2401-5588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11772
% INFO    : Updated Thermal Rating: on line 6301-3049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 3049-8253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8995
% INFO    : Updated Thermal Rating: on line 4194-6645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6645-1598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 6645-1598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 6645-5265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 901-8970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8970-537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 725-1202 : Rate B, Rate C , 0.0, 0.0 -> 93009
% INFO    : Updated Thermal Rating: on line 7616-1202 : Rate B, Rate C , 0.0, 0.0 -> 3618
% INFO    : Updated Thermal Rating: on line 3056-725 : Rate B, Rate C , 0.0, 0.0 -> 78334
% INFO    : Updated Thermal Rating: on line 4162-8171 : Rate B, Rate C , 0.0, 0.0 -> 15418
% INFO    : Updated Thermal Rating: on line 7547-8171 : Rate B, Rate C , 0.0, 0.0 -> 2902
% INFO    : Updated Thermal Rating: on line 4985-8171 : Rate B, Rate C , 0.0, 0.0 -> 4795
% INFO    : Updated Thermal Rating: on line 2869-8171 : Rate B, Rate C , 0.0, 0.0 -> 2905
% INFO    : Updated Thermal Rating: on line 2869-8171 : Rate B, Rate C , 0.0, 0.0 -> 3136
% INFO    : Updated Thermal Rating: on line 7616-8171 : Rate B, Rate C , 0.0, 0.0 -> 34028
% INFO    : Updated Thermal Rating: on line 7122-8171 : Rate B, Rate C , 0.0, 0.0 -> 6601
% INFO    : Updated Thermal Rating: on line 2528-4120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 8615-2528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 8727-6148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2399-6148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 544
% INFO    : Updated Thermal Rating: on line 4965-1761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1761-6853 : Rate B, Rate C , 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 3455-1761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 598
% INFO    : Updated Thermal Rating: on line 8590-2664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 5307-7062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 7062-2664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 5900-9062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9062-865 : Rate B, Rate C , 0.0, 0.0 -> 8010
% INFO    : Updated Thermal Rating: on line 9062-859 : Rate B, Rate C , 0.0, 0.0 -> 2019
% INFO    : Updated Thermal Rating: on line 7046-9062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 9062-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3806
% INFO    : Updated Thermal Rating: on line 1431-2262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2641
% INFO    : Updated Thermal Rating: on line 5553-2262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on line 2262-8712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 2045-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 2581-4528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1430
% INFO    : Updated Thermal Rating: on line 6727-8217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5553-8217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 5553-8217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 8217-2045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6211
% INFO    : Updated Thermal Rating: on line 8217-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5095
% INFO    : Updated Thermal Rating: on line 4821-3289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9045
% INFO    : Updated Thermal Rating: on line 8394-4821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4930
% INFO    : Updated Thermal Rating: on line 4821-4981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 6330-7269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110467
% INFO    : Updated Thermal Rating: on line 3165-7269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23328
% INFO    : Updated Thermal Rating: on line 4461-3074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1869
% INFO    : Updated Thermal Rating: on line 1966-4461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24622
% INFO    : Updated Thermal Rating: on line 5058-1934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10728
% INFO    : Updated Thermal Rating: on line 3165-1934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23704
% INFO    : Updated Thermal Rating: on line 414-6330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13452
% INFO    : Updated Thermal Rating: on line 5298-8042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 5298-6916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2847
% INFO    : Updated Thermal Rating: on line 3632-8042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on line 1824-6916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 2148-4236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16269
% INFO    : Updated Thermal Rating: on line 4579-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15965
% INFO    : Updated Thermal Rating: on line 3824-4962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4962-7435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16076
% INFO    : Updated Thermal Rating: on line 4962-7190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15777
% INFO    : Updated Thermal Rating: on line 8394-7435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1360
% INFO    : Updated Thermal Rating: on line 3139-3984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4299-3984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41138
% INFO    : Updated Thermal Rating: on line 4299-8591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 1510-3984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44231
% INFO    : Updated Thermal Rating: on line 2925-1510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 6042-6420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1288
% INFO    : Updated Thermal Rating: on line 4940-6420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9095
% INFO    : Updated Thermal Rating: on line 8540-5363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5363-3074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2523
% INFO    : Updated Thermal Rating: on line 5363-1879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2317
% INFO    : Updated Thermal Rating: on line 5363-5150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 5363-2397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1048
% INFO    : Updated Thermal Rating: on line 2789-5250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6372-8660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7501-5250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6827
% INFO    : Updated Thermal Rating: on line 5870-8660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13795
% INFO    : Updated Thermal Rating: on line 4619-8833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10412
% INFO    : Updated Thermal Rating: on line 1071-8833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9667
% INFO    : Updated Thermal Rating: on line 1966-1879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 1467-2587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2587-8368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15906
% INFO    : Updated Thermal Rating: on line 603-7657 : Rate B, Rate C , 0.0, 0.0 -> 70492
% INFO    : Updated Thermal Rating: on line 4782-5902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12638
% INFO    : Updated Thermal Rating: on line 4782-2469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12861
% INFO    : Updated Thermal Rating: on line 8394-5902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4746
% INFO    : Updated Thermal Rating: on line 4911-2469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 4590-4911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33551
% INFO    : Updated Thermal Rating: on line 9110-703 : Rate B, Rate C , 0.0, 0.0 -> 109748
% INFO    : Updated Thermal Rating: on line 9110-4162 : Rate B, Rate C , 0.0, 0.0 -> 112533
% INFO    : Updated Thermal Rating: on line 4985-703 : Rate B, Rate C , 0.0, 0.0 -> 6231
% INFO    : Updated Thermal Rating: on line 4659-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1902
% INFO    : Updated Thermal Rating: on line 9038-4659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110467
% INFO    : Updated Thermal Rating: on line 2586-4659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112127
% INFO    : Updated Thermal Rating: on line 8004-331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14372
% INFO    : Updated Thermal Rating: on line 7143-8257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1562
% INFO    : Updated Thermal Rating: on line 7143-8589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10998
% INFO    : Updated Thermal Rating: on line 8502-8004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1535
% INFO    : Updated Thermal Rating: on line 8004-4778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6872-740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 740-3223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8505
% INFO    : Updated Thermal Rating: on line 740-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8364
% INFO    : Updated Thermal Rating: on line 3528-6705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2617-6705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5763
% INFO    : Updated Thermal Rating: on line 2617-6705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5869
% INFO    : Updated Thermal Rating: on line 2164-6705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10673
% INFO    : Updated Thermal Rating: on line 6705-2293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2303
% INFO    : Updated Thermal Rating: on line 6705-2148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5853
% INFO    : Updated Thermal Rating: on line 6705-5053 : Rate B, Rate C , 0.0, 0.0 -> 4487
% INFO    : Updated Thermal Rating: on line 6705-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7709
% INFO    : Updated Thermal Rating: on line 6705-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26322
% INFO    : Updated Thermal Rating: on line 2714-9156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4345
% INFO    : Updated Thermal Rating: on line 1530-3101 : Rate B, Rate C , 0.0, 0.0 -> 5367
% INFO    : Updated Thermal Rating: on line 1530-3101 : Rate B, Rate C , 0.0, 0.0 -> 5113
% INFO    : Updated Thermal Rating: on line 5833-4260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 744-4260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 5833-3376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1794
% INFO    : Updated Thermal Rating: on line 3376-7682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11498
% INFO    : Updated Thermal Rating: on line 5381-2945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 462-6853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2292-6853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 2292-6853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 4346-8345 : Rate B, Rate C , 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 4346-8345 : Rate B, Rate C , 0.0, 0.0 -> 2078
% INFO    : Updated Thermal Rating: on line 1132-8345 : Rate B, Rate C , 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 1132-8345 : Rate B, Rate C , 0.0, 0.0 -> 1442
% INFO    : Updated Thermal Rating: on line 6230-5553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37132
% INFO    : Updated Thermal Rating: on line 8827-6230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 8979-7825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 8823-8979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7825-5553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40119
% INFO    : Updated Thermal Rating: on line 2739-5553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1082
% INFO    : Updated Thermal Rating: on line 8257-2739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2670
% INFO    : Updated Thermal Rating: on line 8257-5553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on line 8257-5553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 892
% INFO    : Updated Thermal Rating: on line 5553-4699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 5553-8379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5553-5548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 5553-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5553-961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 7535-5553 : Rate B, Rate C , 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 5553-8712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 5553-8712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 2964-4792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 669-4792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 669-4792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 1577-5947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7165
% INFO    : Updated Thermal Rating: on line 5947-7826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 1577-8385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 4067-3600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 825
% INFO    : Updated Thermal Rating: on line 4067-1490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 593
% INFO    : Updated Thermal Rating: on line 2451-4895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 2451-7391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 8257-8502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8257-6493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3081
% INFO    : Updated Thermal Rating: on line 3695-5330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2782
% INFO    : Updated Thermal Rating: on line 5330-8074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2590
% INFO    : Updated Thermal Rating: on line 6185-7185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1478
% INFO    : Updated Thermal Rating: on line 3695-7185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 6035-7185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 2851-3863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3464
% INFO    : Updated Thermal Rating: on line 6147-2851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3713
% INFO    : Updated Thermal Rating: on line 384-3863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3403
% INFO    : Updated Thermal Rating: on line 384-3933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3784
% INFO    : Updated Thermal Rating: on line 2234-2696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3483
% INFO    : Updated Thermal Rating: on line 2929-2696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17233
% INFO    : Updated Thermal Rating: on line 2234-5876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 5798-5876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1186
% INFO    : Updated Thermal Rating: on line 8299-2234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2399-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1506
% INFO    : Updated Thermal Rating: on line 4589-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 9172-2399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2399-7100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1462
% INFO    : Updated Thermal Rating: on line 2399-7610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 1537-7100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8462-5739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2825
% INFO    : Updated Thermal Rating: on line 7001-5739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 1217-8587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1801-5454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on line 5454-7319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 2970-8587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37519
% INFO    : Updated Thermal Rating: on line 2970-8591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 1801-8587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37904
% INFO    : Updated Thermal Rating: on line 2131-6235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1533-7547 : Rate B, Rate C , 0.0, 0.0 -> 5917
% INFO    : Updated Thermal Rating: on line 8152-2837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132626
% INFO    : Updated Thermal Rating: on line 7610-8152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 7307-7610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1637-1864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 914
% INFO    : Updated Thermal Rating: on line 12-1637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 4004-5112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8737-5112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 8737-5112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 8737-5112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 3831-5112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 5112-3588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 5112-5396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5112-443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 5112-4422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5112-7387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 517-7610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 9081-646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 887
% INFO    : Updated Thermal Rating: on line 646-7001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 1784-5402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1396-9092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 240-2292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 14-436 : Rate B, Rate C , 0.0, 0.0 -> 2416
% INFO    : Updated Thermal Rating: on line 5883-14 : Rate B, Rate C , 0.0, 0.0 -> 1676
% INFO    : Updated Thermal Rating: on line 6741-14 : Rate B, Rate C , 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 14-2869 : Rate B, Rate C , 0.0, 0.0 -> 2166
% INFO    : Updated Thermal Rating: on line 14-2869 : Rate B, Rate C , 0.0, 0.0 -> 2207
% INFO    : Updated Thermal Rating: on line 1482-2925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1007-2925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 7400-2925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on line 2925-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 3867-6347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6347-183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 3455-6347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 1533-8845 : Rate B, Rate C , 0.0, 0.0 -> 1747
% INFO    : Updated Thermal Rating: on line 1533-8845 : Rate B, Rate C , 0.0, 0.0 -> 1784
% INFO    : Updated Thermal Rating: on line 5406-8845 : Rate B, Rate C , 0.0, 0.0 -> 3455
% INFO    : Updated Thermal Rating: on line 4460-8845 : Rate B, Rate C , 0.0, 0.0 -> 3521
% INFO    : Updated Thermal Rating: on line 603-4346 : Rate B, Rate C , 0.0, 0.0 -> 9826
% INFO    : Updated Thermal Rating: on line 603-4346 : Rate B, Rate C , 0.0, 0.0 -> 10045
% INFO    : Updated Thermal Rating: on line 2859-7734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 2859-7734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 2217-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2270
% INFO    : Updated Thermal Rating: on line 6322-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8221
% INFO    : Updated Thermal Rating: on line 2859-7478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3101
% INFO    : Updated Thermal Rating: on line 2859-9076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 2859-8813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 2859-5166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 2859-1687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 6072-4985 : Rate B, Rate C , 0.0, 0.0 -> 1396
% INFO    : Updated Thermal Rating: on line 6072-4985 : Rate B, Rate C , 0.0, 0.0 -> 1236
% INFO    : Updated Thermal Rating: on line 6072-4985 : Rate B, Rate C , 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 6072-4985 : Rate B, Rate C , 0.0, 0.0 -> 1353
% INFO    : Updated Thermal Rating: on line 1972-1259 : Rate B, Rate C , 0.0, 0.0 -> 2451
% INFO    : Updated Thermal Rating: on line 1259-3056 : Rate B, Rate C , 0.0, 0.0 -> 3982
% INFO    : Updated Thermal Rating: on line 1972-4460 : Rate B, Rate C , 0.0, 0.0 -> 2170
% INFO    : Updated Thermal Rating: on line 1972-6257 : Rate B, Rate C , 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 6257-3056 : Rate B, Rate C , 0.0, 0.0 -> 4065
% INFO    : Updated Thermal Rating: on line 1972-5406 : Rate B, Rate C , 0.0, 0.0 -> 2090
% INFO    : Updated Thermal Rating: on line 4919-2617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6709
% INFO    : Updated Thermal Rating: on line 2617-1319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15280
% INFO    : Updated Thermal Rating: on line 1056-2617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5798-3779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1208
% INFO    : Updated Thermal Rating: on line 7651-5798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9196
% INFO    : Updated Thermal Rating: on line 5798-859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15462
% INFO    : Updated Thermal Rating: on line 5798-7046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6464
% INFO    : Updated Thermal Rating: on line 5798-8554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6971
% INFO    : Updated Thermal Rating: on line 3385-2580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9767
% INFO    : Updated Thermal Rating: on line 3774-3385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 1530-8904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2714-8904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5156-5696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5696-1954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3346
% INFO    : Updated Thermal Rating: on line 5967-5696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5696-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 810-1954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1954-2664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 8457-8904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4166-5281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5281-3138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17378
% INFO    : Updated Thermal Rating: on line 5281-7319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17032
% INFO    : Updated Thermal Rating: on line 3010-4619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5777-6779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8354-4604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17809
% INFO    : Updated Thermal Rating: on line 8354-8730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18064
% INFO    : Updated Thermal Rating: on line 8730-4590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4414
% INFO    : Updated Thermal Rating: on line 9226-8354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5041-272 : Rate B, Rate C , 0.0, 0.0 -> 1911
% INFO    : Updated Thermal Rating: on line 3473-5924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5924-9098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77435
% INFO    : Updated Thermal Rating: on line 5924-1012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92015
% INFO    : Updated Thermal Rating: on line 2576-9098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 517-1012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 2576-6301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 2576-7763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4548
% INFO    : Updated Thermal Rating: on line 2576-4464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7273
% INFO    : Updated Thermal Rating: on line 2576-8253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 2576-8253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5883-6072 : Rate B, Rate C , 0.0, 0.0 -> 1439
% INFO    : Updated Thermal Rating: on line 5883-6072 : Rate B, Rate C , 0.0, 0.0 -> 1412
% INFO    : Updated Thermal Rating: on line 1413-5186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8591-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32802
% INFO    : Updated Thermal Rating: on line 3911-6360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 3911-8591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1760
% INFO    : Updated Thermal Rating: on line 4796-4222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on line 4796-4222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 3632-4073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2070
% INFO    : Updated Thermal Rating: on line 3632-4080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 3632-7106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6858
% INFO    : Updated Thermal Rating: on line 3632-1824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 3632-3298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1706
% INFO    : Updated Thermal Rating: on line 3632-3298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1793
% INFO    : Updated Thermal Rating: on line 7001-5186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 6385-5186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2048
% INFO    : Updated Thermal Rating: on line 7682-881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19388
% INFO    : Updated Thermal Rating: on line 7001-881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 1877-744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on line 1864-5371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 7822-2159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 2635-2159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 3117-7826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9038-7826 : Rate B, Rate C , 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 2753-4673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3956
% INFO    : Updated Thermal Rating: on line 2779-4673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on line 6479-2194 : Rate B, Rate C , 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 8959-5687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6321
% INFO    : Updated Thermal Rating: on line 4551-8959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1557
% INFO    : Updated Thermal Rating: on line 7837-5687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6432
% INFO    : Updated Thermal Rating: on line 7837-3086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 5357-2032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8146-5687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2032-5687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 6943-4551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 2032-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 8823-2628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1166
% INFO    : Updated Thermal Rating: on line 2628-4422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 5063-8257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3627-183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22941
% INFO    : Updated Thermal Rating: on line 5937-8409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8489-5937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8409-5782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1988
% INFO    : Updated Thermal Rating: on line 7233-8489 : Rate B, Rate C , 0.0, 0.0 -> 1979
% INFO    : Updated Thermal Rating: on line 6200-3272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111124
% INFO    : Updated Thermal Rating: on line 4108-6200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3698
% INFO    : Updated Thermal Rating: on line 5245-3272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111124
% INFO    : Updated Thermal Rating: on line 5245-6935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10076
% INFO    : Updated Thermal Rating: on line 2476-3272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3406-9186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16759
% INFO    : Updated Thermal Rating: on line 2964-9186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16434
% INFO    : Updated Thermal Rating: on line 448-6885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6885-6819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 6885-8589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 8838-6404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50742
% INFO    : Updated Thermal Rating: on line 8838-614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38851
% INFO    : Updated Thermal Rating: on line 8838-8684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54140
% INFO    : Updated Thermal Rating: on line 1076-8838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8684-538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 3553-4405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4306
% INFO    : Updated Thermal Rating: on line 3553-8092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4647
% INFO    : Updated Thermal Rating: on line 768-4405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4359
% INFO    : Updated Thermal Rating: on line 768-2960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on line 3252-4405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7734-6855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 836
% INFO    : Updated Thermal Rating: on line 7734-65 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 6562-7734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 31-7734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on line 9070-3138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 8737-3831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 8080-3831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1368-6018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8752-8162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 2354-7024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13059
% INFO    : Updated Thermal Rating: on line 3165-7024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3159
% INFO    : Updated Thermal Rating: on line 2354-4707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14083
% INFO    : Updated Thermal Rating: on line 3165-4707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3216
% INFO    : Updated Thermal Rating: on line 4724-2354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4160-8752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8169-8752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1319
% INFO    : Updated Thermal Rating: on line 3339-8752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 6024-8752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1398
% INFO    : Updated Thermal Rating: on line 8752-4933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 4289-5307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1374-5307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 5307-1931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 1791-7612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8615-7612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1551
% INFO    : Updated Thermal Rating: on line 7462-7612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1580
% INFO    : Updated Thermal Rating: on line 7034-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7300-8169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3339-7858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1521-7858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3573-1061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9147-3573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1061-7172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7172-6024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 383-6875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5150-494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 383-9147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3998-1231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 318-3998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 1231-3686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3686-1374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 494-7300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8023-7470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9288
% INFO    : Updated Thermal Rating: on line 1533-310 : Rate B, Rate C , 0.0, 0.0 -> 2911
% INFO    : Updated Thermal Rating: on line 3165-5858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5422
% INFO    : Updated Thermal Rating: on line 3165-1831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35346
% INFO    : Updated Thermal Rating: on line 8769-7921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9081-7921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 3004-7921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 3004-8591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 4328-5496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36037
% INFO    : Updated Thermal Rating: on line 1840-5496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36258
% INFO    : Updated Thermal Rating: on line 8616-5496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36995
% INFO    : Updated Thermal Rating: on line 101-5496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37819
% INFO    : Updated Thermal Rating: on line 7057-5496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38616
% INFO    : Updated Thermal Rating: on line 5496-3812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34589
% INFO    : Updated Thermal Rating: on line 11-5496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3201-5496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33796
% INFO    : Updated Thermal Rating: on line 4781-1840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 8616-5867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 101-5013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2554
% INFO    : Updated Thermal Rating: on line 7712-537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1533-2000 : Rate B, Rate C , 0.0, 0.0 -> 40451
% INFO    : Updated Thermal Rating: on line 1059-2000 : Rate B, Rate C , 0.0, 0.0 -> 40968
% INFO    : Updated Thermal Rating: on line 914-2000 : Rate B, Rate C , 0.0, 0.0 -> 24570
% INFO    : Updated Thermal Rating: on line 4083-4853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4331
% INFO    : Updated Thermal Rating: on line 2542-7339 : Rate B, Rate C , 0.0, 0.0 -> 6191
% INFO    : Updated Thermal Rating: on line 5925-2391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2391-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 2391-2757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 6018-8452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7406
% INFO    : Updated Thermal Rating: on line 1166-8452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4822-6018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 3901-7088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 95-7088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 7088-5318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 4839-2612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2612-546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on line 4839-5782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2664-3678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 95-3678 : Rate B, Rate C , 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 3318-1288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7863-2217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2993
% INFO    : Updated Thermal Rating: on line 7863-4699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3223
% INFO    : Updated Thermal Rating: on line 5659-3060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4566
% INFO    : Updated Thermal Rating: on line 2593-3060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 5659-3172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4650
% INFO    : Updated Thermal Rating: on line 2593-4316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 6955-7001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7001-6078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 7001-8303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 5903-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3455-9104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on line 2753-6223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 2753-2779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 685
% INFO    : Updated Thermal Rating: on line 7587-5634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2737
% INFO    : Updated Thermal Rating: on line 5030-7587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 3181-5634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2727
% INFO    : Updated Thermal Rating: on line 8054-5634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1272-2422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1683
% INFO    : Updated Thermal Rating: on line 4621-1272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 8901-2422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 5508-2422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2422-5951 : Rate B, Rate C , 0.0, 0.0 -> 1936
% INFO    : Updated Thermal Rating: on line 3626-2422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 8901-3561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2231
% INFO    : Updated Thermal Rating: on line 9092-8901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 812-8901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8002-8901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 2292-3561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 906
% INFO    : Updated Thermal Rating: on line 5661-3561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 4621-6644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 4798-4621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9092-5951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1822
% INFO    : Updated Thermal Rating: on line 9092-2454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9675
% INFO    : Updated Thermal Rating: on line 9092-7453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 2292-6644 : Rate B, Rate C , 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 2292-9041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 8932-469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 469-1296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24990
% INFO    : Updated Thermal Rating: on line 8559-178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 178-7801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25440
% INFO    : Updated Thermal Rating: on line 6944-1166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 6944-8394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 1166-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 1166-6094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2266
% INFO    : Updated Thermal Rating: on line 3627-1166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 3185-1166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1166-2571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 1166-6364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2358
% INFO    : Updated Thermal Rating: on line 1296-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2300
% INFO    : Updated Thermal Rating: on line 6094-7095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3655
% INFO    : Updated Thermal Rating: on line 7801-7095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3963
% INFO    : Updated Thermal Rating: on line 1288-6310 : Rate B, Rate C , 0.0, 0.0 -> 2639
% INFO    : Updated Thermal Rating: on line 2522-7427 : Rate B, Rate C , 0.0, 0.0 -> 4183
% INFO    : Updated Thermal Rating: on line 2522-7427 : Rate B, Rate C , 0.0, 0.0 -> 4272
% INFO    : Updated Thermal Rating: on line 2095-7233 : Rate B, Rate C , 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1569-8340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2095-8340 : Rate B, Rate C , 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5953-8340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 6241-8340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 5030-3901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 2052-5030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6437-8655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 8655-669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14156
% INFO    : Updated Thermal Rating: on line 5371-5041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8074-2571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1255
% INFO    : Updated Thermal Rating: on line 8094-8074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1727-3992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8506-3992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59952
% INFO    : Updated Thermal Rating: on line 3795-8506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 6078-3992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54676
% INFO    : Updated Thermal Rating: on line 6765-6437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 6765-5606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 7478-3154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33551
% INFO    : Updated Thermal Rating: on line 3154-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2886
% INFO    : Updated Thermal Rating: on line 6322-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 6593-7478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3460-4287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6717
% INFO    : Updated Thermal Rating: on line 3460-3626 : Rate B, Rate C , 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on line 1735-3460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 7871-6774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6774-3588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32802
% INFO    : Updated Thermal Rating: on line 6774-6819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35346
% INFO    : Updated Thermal Rating: on line 1986-9179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21695
% INFO    : Updated Thermal Rating: on line 3175-1986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 4841-845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112127
% INFO    : Updated Thermal Rating: on line 6226-845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 4841-8002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112127
% INFO    : Updated Thermal Rating: on line 2374-4841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8436-7290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 8694-7290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1485
% INFO    : Updated Thermal Rating: on line 5950-8436 : Rate B, Rate C , 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 5827-5707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5953-5707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1263
% INFO    : Updated Thermal Rating: on line 5827-8131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1376-5827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8606-3704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6162-2542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3704-2542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 885-3704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8312
% INFO    : Updated Thermal Rating: on line 2664-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3377
% INFO    : Updated Thermal Rating: on line 2664-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3417
% INFO    : Updated Thermal Rating: on line 2664-5980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4464
% INFO    : Updated Thermal Rating: on line 2664-5980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4390
% INFO    : Updated Thermal Rating: on line 2664-5980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4728
% INFO    : Updated Thermal Rating: on line 2664-8747 : Rate B, Rate C , 0.0, 0.0 -> 8167
% INFO    : Updated Thermal Rating: on line 2664-5968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8531
% INFO    : Updated Thermal Rating: on line 2664-8154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7113
% INFO    : Updated Thermal Rating: on line 2664-2690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 791
% INFO    : Updated Thermal Rating: on line 1332-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1332-6032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 8632-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8632-8461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 5980-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11538
% INFO    : Updated Thermal Rating: on line 5980-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11357
% INFO    : Updated Thermal Rating: on line 5980-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13435
% INFO    : Updated Thermal Rating: on line 4642-8747 : Rate B, Rate C , 0.0, 0.0 -> 5199
% INFO    : Updated Thermal Rating: on line 2179-5968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4815
% INFO    : Updated Thermal Rating: on line 4093-2179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 1454-8154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9249
% INFO    : Updated Thermal Rating: on line 1454-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9410
% INFO    : Updated Thermal Rating: on line 8238-1454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4642-6125 : Rate B, Rate C , 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 5818-9170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2397-9170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9886
% INFO    : Updated Thermal Rating: on line 318-9170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10203
% INFO    : Updated Thermal Rating: on line 997-8400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24374
% INFO    : Updated Thermal Rating: on line 8842-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2525-2781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 3858-2690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8864
% INFO    : Updated Thermal Rating: on line 3858-5967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8978
% INFO    : Updated Thermal Rating: on line 6301-8253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 538-5635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 758-538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8673-5635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1902
% INFO    : Updated Thermal Rating: on line 3244-4316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7990-4316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 7990-4316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 4316-4233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 6767-6412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8944
% INFO    : Updated Thermal Rating: on line 6412-8011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45081
% INFO    : Updated Thermal Rating: on line 1687-6767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1312
% INFO    : Updated Thermal Rating: on line 9076-6042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65899
% INFO    : Updated Thermal Rating: on line 2991-2635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 4247-2635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 2635-1701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 2635-1476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 8607-517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 517-8673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2391
% INFO    : Updated Thermal Rating: on line 5072-2873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 821-5072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 6255-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1940
% INFO    : Updated Thermal Rating: on line 2873-6255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 363-4835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157564
% INFO    : Updated Thermal Rating: on line 12-2378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3303
% INFO    : Updated Thermal Rating: on line 2697-1518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7453-5861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3392-2213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5879-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on line 7381-4915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7020-3247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8160-4083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5414-1608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7846-7693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7704-5267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6804-8839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8839-6276 : Rate B, Rate C , 0.0, 0.0 -> 6761
% INFO    : Updated Thermal Rating: on line 7501-4568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2292
% INFO    : Updated Thermal Rating: on line 7939-7501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7501-103 : Rate B, Rate C , 0.0, 0.0 -> 6716
% INFO    : Updated Thermal Rating: on line 767-5066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7976-5066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39668
% INFO    : Updated Thermal Rating: on line 7546-3927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2580-3927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40031
% INFO    : Updated Thermal Rating: on line 3927-6976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14278
% INFO    : Updated Thermal Rating: on line 4404-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6531-1608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10578
% INFO    : Updated Thermal Rating: on line 1608-8686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 2825-7693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10784
% INFO    : Updated Thermal Rating: on line 6814-6531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1981
% INFO    : Updated Thermal Rating: on line 4321-2825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1953
% INFO    : Updated Thermal Rating: on line 4265-5267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 997-5267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 8445-5396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5778
% INFO    : Updated Thermal Rating: on line 8445-2960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5671
% INFO    : Updated Thermal Rating: on line 6309-357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 357-2652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6502
% INFO    : Updated Thermal Rating: on line 210-8739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2701-6013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8296-6013 : Rate B, Rate C , 0.0, 0.0 -> 6656
% INFO    : Updated Thermal Rating: on line 2210-5136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5568-5136 : Rate B, Rate C , 0.0, 0.0 -> 7028
% INFO    : Updated Thermal Rating: on line 4973-1490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2529-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8281-5858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16099
% INFO    : Updated Thermal Rating: on line 5858-7868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7700
% INFO    : Updated Thermal Rating: on line 4691-4835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 4691-7911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4714
% INFO    : Updated Thermal Rating: on line 6858-7990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1206-4730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3988
% INFO    : Updated Thermal Rating: on line 1206-906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4057
% INFO    : Updated Thermal Rating: on line 6984-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 4247-961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 606
% INFO    : Updated Thermal Rating: on line 8394-5402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2182
% INFO    : Updated Thermal Rating: on line 931-9008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7382-1598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6935-1598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 450-5939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127932
% INFO    : Updated Thermal Rating: on line 450-7106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132626
% INFO    : Updated Thermal Rating: on line 6527-4080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5326
% INFO    : Updated Thermal Rating: on line 6527-7542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107512
% INFO    : Updated Thermal Rating: on line 6527-6380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95764
% INFO    : Updated Thermal Rating: on line 7542-3298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 6380-3298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1021
% INFO    : Updated Thermal Rating: on line 5248-2929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7502
% INFO    : Updated Thermal Rating: on line 2929-997 : Rate B, Rate C , 0.0, 0.0 -> 2233
% INFO    : Updated Thermal Rating: on line 161-3779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17078
% INFO    : Updated Thermal Rating: on line 161-6235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3897
% INFO    : Updated Thermal Rating: on line 74-4919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4483-2164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1322-5642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5642-990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6093
% INFO    : Updated Thermal Rating: on line 3567-8064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8386-8686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19261
% INFO    : Updated Thermal Rating: on line 8386-5080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19482
% INFO    : Updated Thermal Rating: on line 8234-8386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1222-8386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6573
% INFO    : Updated Thermal Rating: on line 5953-2603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3898
% INFO    : Updated Thermal Rating: on line 990-5953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3834
% INFO    : Updated Thermal Rating: on line 6417-5953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1449-8686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3590
% INFO    : Updated Thermal Rating: on line 7552-5080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62994
% INFO    : Updated Thermal Rating: on line 7552-8700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2315
% INFO    : Updated Thermal Rating: on line 2603-8796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11391
% INFO    : Updated Thermal Rating: on line 8637-1660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8985-8637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8637-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5159
% INFO    : Updated Thermal Rating: on line 5382-8827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5484-6533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 6533-7911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 5484-3295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1601
% INFO    : Updated Thermal Rating: on line 1832-7057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3836
% INFO    : Updated Thermal Rating: on line 1055-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5867-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3653
% INFO    : Updated Thermal Rating: on line 6113-3040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31122
% INFO    : Updated Thermal Rating: on line 2445-6389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27835
% INFO    : Updated Thermal Rating: on line 3812-6113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17732
% INFO    : Updated Thermal Rating: on line 2445-3201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3720
% INFO    : Updated Thermal Rating: on line 7023-5867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5867-4781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6119
% INFO    : Updated Thermal Rating: on line 5867-4781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6191
% INFO    : Updated Thermal Rating: on line 3619-4781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4781-7229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16076
% INFO    : Updated Thermal Rating: on line 4781-4479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15846
% INFO    : Updated Thermal Rating: on line 4781-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 4781-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 4479-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 6935-8061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 1281-8061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3735-7710 : Rate B, Rate C , 0.0, 0.0 -> 6603
% INFO    : Updated Thermal Rating: on line 8233-1007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 8233-2158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 6385-2158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1369
% INFO    : Updated Thermal Rating: on line 1725-2652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8538-6428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7389-6428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26891
% INFO    : Updated Thermal Rating: on line 8111-2652 : Rate B, Rate C , 0.0, 0.0 -> 27470
% INFO    : Updated Thermal Rating: on line 1222-1449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8160
% INFO    : Updated Thermal Rating: on line 8379-5224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3792
% INFO    : Updated Thermal Rating: on line 8813-5224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3860
% INFO    : Updated Thermal Rating: on line 2010-5224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 598-6385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 6385-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 8712-5548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1859
% INFO    : Updated Thermal Rating: on line 2778-1891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1891-3086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26332
% INFO    : Updated Thermal Rating: on line 1891-6226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27001
% INFO    : Updated Thermal Rating: on line 8688-7651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 4222-470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1326
% INFO    : Updated Thermal Rating: on line 5151-6814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1732
% INFO    : Updated Thermal Rating: on line 1149-4321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 4473-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4473-1226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12652
% INFO    : Updated Thermal Rating: on line 3315-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12885
% INFO    : Updated Thermal Rating: on line 7763-8856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92426
% INFO    : Updated Thermal Rating: on line 8048-5265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1099-5950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2254-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8327-6276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5895-627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3408-7433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2270-8591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6514
% INFO    : Updated Thermal Rating: on line 1735-2270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2075
% INFO    : Updated Thermal Rating: on line 8591-2586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1967
% INFO    : Updated Thermal Rating: on line 119-8220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82735
% INFO    : Updated Thermal Rating: on line 8591-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8312
% INFO    : Updated Thermal Rating: on line 3298-5761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8444
% INFO    : Updated Thermal Rating: on line 6147-3690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2478
% INFO    : Updated Thermal Rating: on line 6364-6147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2409
% INFO    : Updated Thermal Rating: on line 7987-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 95-373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2833
% INFO    : Updated Thermal Rating: on line 8461-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36037
% INFO    : Updated Thermal Rating: on line 6032-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36258
% INFO    : Updated Thermal Rating: on line 9163-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 373-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36995
% INFO    : Updated Thermal Rating: on line 2757-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37819
% INFO    : Updated Thermal Rating: on line 2356-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5651-4822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2548-5870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80914
% INFO    : Updated Thermal Rating: on line 2548-8296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108472
% INFO    : Updated Thermal Rating: on line 1071-5568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108472
% INFO    : Updated Thermal Rating: on line 1389-2548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2548-1071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2227-1071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1903-8703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9015
% INFO    : Updated Thermal Rating: on line 7868-1903 : Rate B, Rate C , 0.0, 0.0 -> 3323
% INFO    : Updated Thermal Rating: on line 1749-8703 : Rate B, Rate C , 0.0, 0.0 -> 5563
% INFO    : Updated Thermal Rating: on line 2953-1749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8092-856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2665
% INFO    : Updated Thermal Rating: on line 4108-856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2620
% INFO    : Updated Thermal Rating: on line 7251-8394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8394-3933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 4940-3681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45434
% INFO    : Updated Thermal Rating: on line 7720-7409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2074
% INFO    : Updated Thermal Rating: on line 7409-1476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1336
% INFO    : Updated Thermal Rating: on line 6549-7720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 8011-6549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2172
% INFO    : Updated Thermal Rating: on line 4229-7720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157564
% INFO    : Updated Thermal Rating: on line 7720-961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 6096-3626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8848-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 5506-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 6943-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5800
% INFO    : Updated Thermal Rating: on line 470-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5706
% INFO    : Updated Thermal Rating: on line 8558-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6643-5506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157564
% INFO    : Updated Thermal Rating: on line 2293-8081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4800-5956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3464
% INFO    : Updated Thermal Rating: on line 2148-4800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3437
% INFO    : Updated Thermal Rating: on line 5956-7333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38616
% INFO    : Updated Thermal Rating: on line 3175-7333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34589
% INFO    : Updated Thermal Rating: on line 5663-8081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 100-8081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2067-7333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1745-4545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4545-5392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5582
% INFO    : Updated Thermal Rating: on line 4545-4233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5480
% INFO    : Updated Thermal Rating: on line 2856-5392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 6310-7832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 7832-1771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30844
% INFO    : Updated Thermal Rating: on line 8694-1771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8050
% INFO    : Updated Thermal Rating: on line 7566-1771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3946-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39340
% INFO    : Updated Thermal Rating: on line 3946-4265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35346
% INFO    : Updated Thermal Rating: on line 7402-3946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 4070-598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1674
% INFO    : Updated Thermal Rating: on line 4070-3795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 4932-4070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6125-391 : Rate B, Rate C , 0.0, 0.0 -> 6546
% INFO    : Updated Thermal Rating: on line 2856-3667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 3667-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6627
% INFO    : Updated Thermal Rating: on line 4018-2856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7192-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4751-3593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8700-3593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6241-3593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2339-8303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3403
% INFO    : Updated Thermal Rating: on line 2339-232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3346
% INFO    : Updated Thermal Rating: on line 9142-2339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9050-961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 1476-961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 8090-9041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 8090-5879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 28-8090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7470-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 9104-4174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 946
% INFO    : Updated Thermal Rating: on line 6620-9104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 546-8082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1678-6957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8082-821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8082-3295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8082-6957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5359-7535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 762-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18272
% INFO    : Updated Thermal Rating: on line 443-8827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 4030-865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5166-3774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69008
% INFO    : Updated Thermal Rating: on line 8231-4778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46233
% INFO    : Updated Thermal Rating: on line 2312-5053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1310-5796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60709
% INFO    : Updated Thermal Rating: on line 8631-5796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1343
% INFO    : Updated Thermal Rating: on line 912-7046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16548
% INFO    : Updated Thermal Rating: on line 8554-1226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3873
% INFO    : Updated Thermal Rating: on line 5013-8984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5752
% INFO    : Updated Thermal Rating: on line 8631-7976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8755
% INFO    : Updated Thermal Rating: on line 1319-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10739
% INFO    : Updated Thermal Rating: on line 6976-3681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47473
% INFO    : Updated Thermal Rating: on line 6976-1701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47913
% INFO    : Updated Thermal Rating: on line 3532-6976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2113-310 : Rate B, Rate C , 0.0, 0.0 -> 12987
% INFO    : Updated Thermal Rating: on line 2113-7122 : Rate B, Rate C , 0.0, 0.0 -> 11463
% INFO    : Updated Thermal Rating: on line 4981-5384 : Rate B, Rate C , 0.0, 0.0 -> 26322
% INFO    : Updated Thermal Rating: on line 1831-4981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 7912-2779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7400-9070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27116
% INFO    : Updated Thermal Rating: on line 8548-7400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7400-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 4262-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5254-4093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8745-8757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28148
% INFO    : Updated Thermal Rating: on line 6702-3933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 308-1476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198730
% INFO    : Updated Thermal Rating: on line 1386-885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3354-1222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6873-4422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 783-1931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5950-3463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 5950-5560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on line 7433-8796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41763
% INFO    : Updated Thermal Rating: on line 5318-6479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 8231-7387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2153
% INFO    : Updated Thermal Rating: on line 7387-1724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5984-2975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3274-5984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 7784-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5085-7784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 4490-7656 : Rate B, Rate C , 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on line 4490-825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 4490-825 : Rate B, Rate C , 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 1340-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3726-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 3333-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 3333-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 2809-1340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 3170-6229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 3836-3170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5507-8567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 8567-8902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 8084-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 8084-5675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on line 8084-5750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1120
% INFO    : Updated Thermal Rating: on line 8084-5750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 685
% INFO    : Updated Thermal Rating: on line 8321-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2393
% INFO    : Updated Thermal Rating: on line 8321-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 269-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 1928-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1214
% INFO    : Updated Thermal Rating: on line 3371-3942 : Rate B, Rate C , 0.0, 0.0 -> 2386
% INFO    : Updated Thermal Rating: on line 825-3942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 3942-5501 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 6598-3466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 5032-6598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 1781-3466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 2296-5786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 5545-2296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 609
% INFO    : Updated Thermal Rating: on line 8280-492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 492-2809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13405
% INFO    : Updated Thermal Rating: on line 1902-5721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 5504-1902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1228
% INFO    : Updated Thermal Rating: on line 1902-5871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on line 4382-8579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 8579-3274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 738-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 738-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1919
% INFO    : Updated Thermal Rating: on line 6059-7334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 6059-7334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 4246-2670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3457-4246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 6856-4246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 8055-4591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3248
% INFO    : Updated Thermal Rating: on line 4591-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 4591-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 3677-4591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 187-4591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 4591-8965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 4591-6435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 4382-8055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 2819-6273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 6273-235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 3092-5504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 3092-1886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 9232-4612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 9232-826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 3457-3414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2759
% INFO    : Updated Thermal Rating: on line 3457-3414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2805
% INFO    : Updated Thermal Rating: on line 6856-3414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 6856-3414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 8056-1574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 724-1574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2033
% INFO    : Updated Thermal Rating: on line 5470-4612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 5470-4583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 5871-8545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 8545-911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 5786-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 5786-1419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 781-5786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 7111-7331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 796-3836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 1419-796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 796-6856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 9153-1313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 411-1313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 852
% INFO    : Updated Thermal Rating: on line 8056-1313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 8321-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8085
% INFO    : Updated Thermal Rating: on line 825-7383 : Rate B, Rate C , 0.0, 0.0 -> 1335
% INFO    : Updated Thermal Rating: on line 825-7383 : Rate B, Rate C , 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 2637-8045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 7916-5922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 3838-5922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1467
% INFO    : Updated Thermal Rating: on line 3208-1429 : Rate A, Rate B, Rate C , 1185.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 4382-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 3471-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 3471-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 2975-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 2975-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 4648-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 2004-8965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 2004-7072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5229-3371 : Rate B, Rate C , 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 5721-5518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 9202-4539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 6641-5545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1327
% INFO    : Updated Thermal Rating: on line 6641-5545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 5504-3719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 9153-5504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on line 5504-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 7916-5504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 187-3677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 8849-1628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 8849-2326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1011
% INFO    : Updated Thermal Rating: on line 8650-7665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 131-8650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 724-1886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 9153-3719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 842
% INFO    : Updated Thermal Rating: on line 4202-7497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on line 7497-2326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on line 3333-1628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1029
% INFO    : Updated Thermal Rating: on line 1671-3726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 1671-7111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 9044-7656 : Rate B, Rate C , 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 825-7656 : Rate B, Rate C , 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 738-5654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 738-5654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 771-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 771-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 771-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 9202-3598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 3598-5085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5654-7177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 5378-5545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 1041-5378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 131-6229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 1527-8321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 756
% INFO    : Updated Thermal Rating: on line 1527-8321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5545-9196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 3926-9196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 6856-9196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 9202-7385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 7385-8781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 4202-7111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 4202-7111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on line 4202-7452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4947
% INFO    : Updated Thermal Rating: on line 4202-2326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 2178-861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on line 8902-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 2649-8974 : Rate B, Rate C , 0.0, 0.0 -> 1421
% INFO    : Updated Thermal Rating: on line 2480-825 : Rate B, Rate C , 0.0, 0.0 -> 3544
% INFO    : Updated Thermal Rating: on line 2480-825 : Rate B, Rate C , 0.0, 0.0 -> 3616
% INFO    : Updated Thermal Rating: on line 3836-2670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 879-3836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5654-3896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 8800-1041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 8800-3926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 8450-5871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on line 7665-2819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 8811-7665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 5518-9202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 411-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 8140-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 4583-8140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 3896-2673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 3838-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 3198-9073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 2819-1266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 8811-2819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2502-2649 : Rate A, Rate B, Rate C , 1251.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 7081-2502 : Rate B, Rate C , 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 5161-5229 : Rate B, Rate C , 0.0, 0.0 -> 2470
% INFO    : Updated Thermal Rating: on line 5161-5229 : Rate B, Rate C , 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 7008-5229 : Rate B, Rate C , 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 5229-6924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8493
% INFO    : Updated Thermal Rating: on line 5229-6924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8699
% INFO    : Updated Thermal Rating: on line 7916-8450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2442
% INFO    : Updated Thermal Rating: on line 7916-2543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 906
% INFO    : Updated Thermal Rating: on line 771-2637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 181-771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6805
% INFO    : Updated Thermal Rating: on line 181-771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6688
% INFO    : Updated Thermal Rating: on line 5501-3198 : Rate B, Rate C , 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 5501-3198 : Rate B, Rate C , 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 5501-4417 : Rate B, Rate C , 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on line 131-4373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 131-3457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 131-3457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 131-1366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 5750-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 1928-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 1928-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 1266-1218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 3471-4382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 6911-4382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 781-5545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on line 7334-5507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 5085-8280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 7603-8280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 8781-7603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 911-8781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 5085-5585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 5085-2809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 2673-6658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 6447-3471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2148
% INFO    : Updated Thermal Rating: on line 2975-6447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 936
% INFO    : Updated Thermal Rating: on line 4648-6447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5426
% INFO    : Updated Thermal Rating: on line 4648-3274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 1781-4698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 1781-4583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 4583-1781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 7008-5161 : Rate B, Rate C , 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 2543-3838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1144
% INFO    : Updated Thermal Rating: on line 1527-4408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1714
% INFO    : Updated Thermal Rating: on line 1527-4408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1791
% INFO    : Updated Thermal Rating: on line 3926-4408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 8920-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2852
% INFO    : Updated Thermal Rating: on line 8920-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2900
% INFO    : Updated Thermal Rating: on line 8239-8056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 2699-4698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 5032-4698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 1218-187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 1366-4373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 8811-4373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 8555-4373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1805
% INFO    : Updated Thermal Rating: on line 5700-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on line 724-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 1928-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 1928-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 1928-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 5750-3457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 6856-3457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 6530-3457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2388
% INFO    : Updated Thermal Rating: on line 8003-2699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 965-5700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 3333-2326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 826-4583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 826-8003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on line 826-8003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 235-6911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 5750-5675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 7452-2875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10030
% INFO    : Updated Thermal Rating: on line 181-2875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9303
% INFO    : Updated Thermal Rating: on line 181-2875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9464
% INFO    : Updated Thermal Rating: on line 6530-5750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2155
% INFO    : Updated Thermal Rating: on line 2389-7008 : Rate B, Rate C , 0.0, 0.0 -> 1216
% INFO    : Updated Thermal Rating: on line 2389-7008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 8555-8811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2190
% INFO    : Updated Thermal Rating: on line 7081-1429 : Rate B, Rate C , 0.0, 0.0 -> 2196
% INFO    : Updated Thermal Rating: on line 8239-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 8965-7072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 8965-6435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 8416-6743 : Rate B, Rate C , 0.0, 0.0 -> 4155
% INFO    : Updated Thermal Rating: on line 8416-6743 : Rate B, Rate C , 0.0, 0.0 -> 4144
% INFO    : Updated Thermal Rating: on line 8416-8715 : Rate B, Rate C , 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on line 8416-8715 : Rate B, Rate C , 0.0, 0.0 -> 3802
% INFO    : Updated Thermal Rating: on line 8416-569 : Rate B, Rate C , 0.0, 0.0 -> 4531
% INFO    : Updated Thermal Rating: on line 8052-6204 : Rate B, Rate C , 0.0, 0.0 -> 2865
% INFO    : Updated Thermal Rating: on line 290-6204 : Rate B, Rate C , 0.0, 0.0 -> 2919
% INFO    : Updated Thermal Rating: on line 3684-8580 : Rate B, Rate C , 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 3684-569 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 340-8065 : Rate B, Rate C , 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 8715-340 : Rate B, Rate C , 0.0, 0.0 -> 6378
% INFO    : Updated Thermal Rating: on line 6685-2858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 5199-2858 : Rate B, Rate C , 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on line 6743-8526 : Rate B, Rate C , 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 8526-5850 : Rate B, Rate C , 0.0, 0.0 -> 2156
% INFO    : Updated Thermal Rating: on line 5284-8531 : Rate B, Rate C , 0.0, 0.0 -> 9856
% INFO    : Updated Thermal Rating: on line 5284-7065 : Rate B, Rate C , 0.0, 0.0 -> 10705
% INFO    : Updated Thermal Rating: on line 5284-1402 : Rate B, Rate C , 0.0, 0.0 -> 9676
% INFO    : Updated Thermal Rating: on line 5284-2858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 5284-2858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 5284-3245 : Rate B, Rate C , 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 5284-6799 : Rate B, Rate C , 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 5284-6799 : Rate B, Rate C , 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 1648-6204 : Rate B, Rate C , 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 9004-6204 : Rate B, Rate C , 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 6204-4912 : Rate B, Rate C , 0.0, 0.0 -> 4641
% INFO    : Updated Thermal Rating: on line 6204-2144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5008
% INFO    : Updated Thermal Rating: on line 6204-7867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 6204-7867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 6204-2395 : Rate B, Rate C , 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 4909-3604 : Rate B, Rate C , 0.0, 0.0 -> 4334
% INFO    : Updated Thermal Rating: on line 4909-5850 : Rate B, Rate C , 0.0, 0.0 -> 5081
% INFO    : Updated Thermal Rating: on line 4909-5850 : Rate B, Rate C , 0.0, 0.0 -> 4993
% INFO    : Updated Thermal Rating: on line 4998-6799 : Rate B, Rate C , 0.0, 0.0 -> 2238
% INFO    : Updated Thermal Rating: on line 7458-8065 : Rate B, Rate C , 0.0, 0.0 -> 9762
% INFO    : Updated Thermal Rating: on line 7458-4817 : Rate B, Rate C , 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 7458-2368 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on line 7679-2395 : Rate B, Rate C , 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 9183-4817 : Rate B, Rate C , 0.0, 0.0 -> 1612
% INFO    : Updated Thermal Rating: on line 9183-2368 : Rate B, Rate C , 0.0, 0.0 -> 2320
% INFO    : Updated Thermal Rating: on line 9183-2368 : Rate B, Rate C , 0.0, 0.0 -> 2370
% INFO    : Updated Thermal Rating: on line 9183-5062 : Rate B, Rate C , 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 4150-2858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 4817-8715 : Rate B, Rate C , 0.0, 0.0 -> 2011
% INFO    : Updated Thermal Rating: on line 4817-7979 : Rate B, Rate C , 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 8715-7979 : Rate B, Rate C , 0.0, 0.0 -> 1683
% INFO    : Updated Thermal Rating: on line 7867-6799 : Rate B, Rate C , 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 7979-6790 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1557
% INFO    : Updated Thermal Rating: on line 7979-6790 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1681
% INFO    : Updated Thermal Rating: on line 7979-8580 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on line 7979-5062 : Rate B, Rate C , 0.0, 0.0 -> 1448
% INFO    : Updated Thermal Rating: on line 5624-7152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3388
% INFO    : Updated Thermal Rating: on line 5624-7152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3998
% INFO    : Updated Thermal Rating: on line 5624-7152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5722
% INFO    : Updated Thermal Rating: on line 5850-3130 : Rate B, Rate C , 0.0, 0.0 -> 12199
% INFO    : Updated Thermal Rating: on line 2858-3245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 2858-6103 : Rate B, Rate C , 0.0, 0.0 -> 10150
% INFO    : Updated Thermal Rating: on line 2858-2310 : Rate B, Rate C , 0.0, 0.0 -> 9967
% INFO    : Updated Thermal Rating: on line 2858-8726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 8943-3245 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 364-6528 : Rate B, Rate C , 0.0, 0.0 -> 12029
% INFO    : Updated Thermal Rating: on line 4572-364 : Rate B, Rate C , 0.0, 0.0 -> 11032
% INFO    : Updated Thermal Rating: on line 3507-364 : Rate B, Rate C , 0.0, 0.0 -> 47495
% INFO    : Updated Thermal Rating: on line 7489-1140 : Rate B, Rate C , 0.0, 0.0 -> 13986
% INFO    : Updated Thermal Rating: on line 4133-7489 : Rate B, Rate C , 0.0, 0.0 -> 19669
% INFO    : Updated Thermal Rating: on line 2694-6725 : Rate B, Rate C , 0.0, 0.0 -> 4013
% INFO    : Updated Thermal Rating: on line 2694-6725 : Rate B, Rate C , 0.0, 0.0 -> 4332
% INFO    : Updated Thermal Rating: on line 6725-8252 : Rate B, Rate C , 0.0, 0.0 -> 6742
% INFO    : Updated Thermal Rating: on line 6725-8117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 6810-6809 : Rate B, Rate C , 0.0, 0.0 -> 4335
% INFO    : Updated Thermal Rating: on line 9113-6810 : Rate B, Rate C , 0.0, 0.0 -> 31269
% INFO    : Updated Thermal Rating: on line 6810-1804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4244
% INFO    : Updated Thermal Rating: on line 5303-6327 : Rate B, Rate C , 0.0, 0.0 -> 51332
% INFO    : Updated Thermal Rating: on line 7311-8069 : Rate B, Rate C , 0.0, 0.0 -> 3701
% INFO    : Updated Thermal Rating: on line 5476-8069 : Rate B, Rate C , 0.0, 0.0 -> 4475
% INFO    : Updated Thermal Rating: on line 5109-3360 : Rate B, Rate C , 0.0, 0.0 -> 24603
% INFO    : Updated Thermal Rating: on line 4348-9075 : Rate B, Rate C , 0.0, 0.0 -> 4383
% INFO    : Updated Thermal Rating: on line 9075-7066 : Rate B, Rate C , 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 4348-9075 : Rate B, Rate C , 0.0, 0.0 -> 4039
% INFO    : Updated Thermal Rating: on line 4148-8443 : Rate B, Rate C , 0.0, 0.0 -> 946
% INFO    : Updated Thermal Rating: on line 1470-4148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 2139-4148 : Rate B, Rate C , 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 4148-7893 : Rate B, Rate C , 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 4448-4148 : Rate B, Rate C , 0.0, 0.0 -> 641
% INFO    : Updated Thermal Rating: on line 1819-899 : Rate B, Rate C , 0.0, 0.0 -> 106240
% INFO    : Updated Thermal Rating: on line 4979-899 : Rate B, Rate C , 0.0, 0.0 -> 106240
% INFO    : Updated Thermal Rating: on line 6822-899 : Rate B, Rate C , 0.0, 0.0 -> 105881
% INFO    : Updated Thermal Rating: on line 924-1279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18318
% INFO    : Updated Thermal Rating: on line 899-1193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 3123-899 : Rate B, Rate C , 0.0, 0.0 -> 3874
% INFO    : Updated Thermal Rating: on line 3123-899 : Rate B, Rate C , 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 8383-3807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16796
% INFO    : Updated Thermal Rating: on line 8383-3807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16305
% INFO    : Updated Thermal Rating: on line 2121-1977 : Rate A, Rate B, Rate C , 987.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 2121-3351 : Rate B, Rate C , 0.0, 0.0 -> 2449
% INFO    : Updated Thermal Rating: on line 1261-3605 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 1279-8443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7782
% INFO    : Updated Thermal Rating: on line 1279-3571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12953
% INFO    : Updated Thermal Rating: on line 4873-4094 : Rate B, Rate C , 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 5493-4873 : Rate B, Rate C , 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 7016-1882 : Rate B, Rate C , 0.0, 0.0 -> 6326
% INFO    : Updated Thermal Rating: on line 1882-5483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14534
% INFO    : Updated Thermal Rating: on line 526-4516 : Rate B, Rate C , 0.0, 0.0 -> 1698
% INFO    : Updated Thermal Rating: on line 526-5839 : Rate B, Rate C , 0.0, 0.0 -> 18584
% INFO    : Updated Thermal Rating: on line 7016-834 : Rate B, Rate C , 0.0, 0.0 -> 8731
% INFO    : Updated Thermal Rating: on line 7016-7494 : Rate B, Rate C , 0.0, 0.0 -> 3767
% INFO    : Updated Thermal Rating: on line 7016-7494 : Rate B, Rate C , 0.0, 0.0 -> 2552
% INFO    : Updated Thermal Rating: on line 7016-2388 : Rate B, Rate C , 0.0, 0.0 -> 8424
% INFO    : Updated Thermal Rating: on line 8399-1328 : Rate B, Rate C , 0.0, 0.0 -> 5204
% INFO    : Updated Thermal Rating: on line 8399-1328 : Rate B, Rate C , 0.0, 0.0 -> 5104
% INFO    : Updated Thermal Rating: on line 1328-660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1883
% INFO    : Updated Thermal Rating: on line 1328-5355 : Rate B, Rate C , 0.0, 0.0 -> 44419
% INFO    : Updated Thermal Rating: on line 1328-5355 : Rate B, Rate C , 0.0, 0.0 -> 38950
% INFO    : Updated Thermal Rating: on line 1328-984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20706
% INFO    : Updated Thermal Rating: on line 1328-984 : Rate B, Rate C , 0.0, 0.0 -> 21107
% INFO    : Updated Thermal Rating: on line 1328-4178 : Rate B, Rate C , 0.0, 0.0 -> 19201
% INFO    : Updated Thermal Rating: on line 1328-4178 : Rate B, Rate C , 0.0, 0.0 -> 18746
% INFO    : Updated Thermal Rating: on line 6016-4448 : Rate B, Rate C , 0.0, 0.0 -> 6130
% INFO    : Updated Thermal Rating: on line 8962-3465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92032
% INFO    : Updated Thermal Rating: on line 5885-5677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1445
% INFO    : Updated Thermal Rating: on line 5885-4035 : Rate B, Rate C , 0.0, 0.0 -> 11052
% INFO    : Updated Thermal Rating: on line 1261-54 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 2675-1261 : Rate B, Rate C , 0.0, 0.0 -> 2169
% INFO    : Updated Thermal Rating: on line 765-437 : Rate B, Rate C , 0.0, 0.0 -> 54866
% INFO    : Updated Thermal Rating: on line 6809-437 : Rate B, Rate C , 0.0, 0.0 -> 3825
% INFO    : Updated Thermal Rating: on line 1423-437 : Rate B, Rate C , 0.0, 0.0 -> 8223
% INFO    : Updated Thermal Rating: on line 7540-2578 : Rate B, Rate C , 0.0, 0.0 -> 10901
% INFO    : Updated Thermal Rating: on line 5705-4820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88533
% INFO    : Updated Thermal Rating: on line 6560-7044 : Rate B, Rate C , 0.0, 0.0 -> 11048
% INFO    : Updated Thermal Rating: on line 7044-3196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14451
% INFO    : Updated Thermal Rating: on line 2986-7044 : Rate B, Rate C , 0.0, 0.0 -> 4279
% INFO    : Updated Thermal Rating: on line 402-7855 : Rate B, Rate C , 0.0, 0.0 -> 5429
% INFO    : Updated Thermal Rating: on line 402-3337 : Rate B, Rate C , 0.0, 0.0 -> 2682
% INFO    : Updated Thermal Rating: on line 402-6107 : Rate B, Rate C , 0.0, 0.0 -> 14953
% INFO    : Updated Thermal Rating: on line 8273-6750 : Rate B, Rate C , 0.0, 0.0 -> 8417
% INFO    : Updated Thermal Rating: on line 2710-8273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6087
% INFO    : Updated Thermal Rating: on line 1990-7306 : Rate B, Rate C , 0.0, 0.0 -> 3018
% INFO    : Updated Thermal Rating: on line 8532-4037 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1513
% INFO    : Updated Thermal Rating: on line 7664-4037 : Rate B, Rate C , 0.0, 0.0 -> 13587
% INFO    : Updated Thermal Rating: on line 2204-8120 : Rate B, Rate C , 0.0, 0.0 -> 126249
% INFO    : Updated Thermal Rating: on line 9006-8120 : Rate B, Rate C , 0.0, 0.0 -> 137207
% INFO    : Updated Thermal Rating: on line 2423-8120 : Rate B, Rate C , 0.0, 0.0 -> 4614
% INFO    : Updated Thermal Rating: on line 882-8120 : Rate B, Rate C , 0.0, 0.0 -> 3671
% INFO    : Updated Thermal Rating: on line 2540-1034 : Rate B, Rate C , 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 368-2540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 4672-6863 : Rate B, Rate C , 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 4672-7841 : Rate B, Rate C , 0.0, 0.0 -> 917
% INFO    : Updated Thermal Rating: on line 565-1859 : Rate B, Rate C , 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 565-1859 : Rate B, Rate C , 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 1859-3832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 1859-3832 : Rate B, Rate C , 0.0, 0.0 -> 1608
% INFO    : Updated Thermal Rating: on line 8049-162 : Rate B, Rate C , 0.0, 0.0 -> 29652
% INFO    : Updated Thermal Rating: on line 8049-2039 : Rate B, Rate C , 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 1759-6793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10628
% INFO    : Updated Thermal Rating: on line 1759-1469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3040
% INFO    : Updated Thermal Rating: on line 3895-1264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3193
% INFO    : Updated Thermal Rating: on line 1264-8139 : Rate B, Rate C , 0.0, 0.0 -> 6171
% INFO    : Updated Thermal Rating: on line 1264-8139 : Rate B, Rate C , 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 8608-1264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2448
% INFO    : Updated Thermal Rating: on line 1264-9009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4889
% INFO    : Updated Thermal Rating: on line 3769-2320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2538
% INFO    : Updated Thermal Rating: on line 3563-5302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13933
% INFO    : Updated Thermal Rating: on line 2316-5302 : Rate B, Rate C , 0.0, 0.0 -> 9088
% INFO    : Updated Thermal Rating: on line 3196-5302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10872
% INFO    : Updated Thermal Rating: on line 5498-6750 : Rate B, Rate C , 0.0, 0.0 -> 6368
% INFO    : Updated Thermal Rating: on line 6750-2684 : Rate B, Rate C , 0.0, 0.0 -> 6334
% INFO    : Updated Thermal Rating: on line 3229-8532 : Rate B, Rate C , 0.0, 0.0 -> 13455
% INFO    : Updated Thermal Rating: on line 1977-8532 : Rate B, Rate C , 0.0, 0.0 -> 29997
% INFO    : Updated Thermal Rating: on line 1977-8532 : Rate B, Rate C , 0.0, 0.0 -> 29439
% INFO    : Updated Thermal Rating: on line 8532-7922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31487
% INFO    : Updated Thermal Rating: on line 8532-3972 : Rate B, Rate C , 0.0, 0.0 -> 3107
% INFO    : Updated Thermal Rating: on line 880-6671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5555
% INFO    : Updated Thermal Rating: on line 880-6671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4818
% INFO    : Updated Thermal Rating: on line 5114-8723 : Rate B, Rate C , 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 6528-1804 : Rate B, Rate C , 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 6528-7804 : Rate B, Rate C , 0.0, 0.0 -> 4486
% INFO    : Updated Thermal Rating: on line 3563-1684 : Rate B, Rate C , 0.0, 0.0 -> 5940
% INFO    : Updated Thermal Rating: on line 7071-6622 : Rate B, Rate C , 0.0, 0.0 -> 3440
% INFO    : Updated Thermal Rating: on line 7071-6622 : Rate B, Rate C , 0.0, 0.0 -> 4247
% INFO    : Updated Thermal Rating: on line 1327-6622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5513
% INFO    : Updated Thermal Rating: on line 3705-6622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7013
% INFO    : Updated Thermal Rating: on line 2909-6622 : Rate B, Rate C , 0.0, 0.0 -> 5027
% INFO    : Updated Thermal Rating: on line 1977-8304 : Rate B, Rate C , 0.0, 0.0 -> 13791
% INFO    : Updated Thermal Rating: on line 1977-6207 : Rate B, Rate C , 0.0, 0.0 -> 14090
% INFO    : Updated Thermal Rating: on line 1977-7940 : Rate B, Rate C , 0.0, 0.0 -> 12022
% INFO    : Updated Thermal Rating: on line 1977-1919 : Rate B, Rate C , 0.0, 0.0 -> 12064
% INFO    : Updated Thermal Rating: on line 49-6992 : Rate B, Rate C , 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 1977-2456 : Rate B, Rate C , 0.0, 0.0 -> 3423
% INFO    : Updated Thermal Rating: on line 1977-4159 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1416
% INFO    : Updated Thermal Rating: on line 3871-2821 : Rate B, Rate C , 0.0, 0.0 -> 12629
% INFO    : Updated Thermal Rating: on line 5645-2821 : Rate B, Rate C , 0.0, 0.0 -> 2555
% INFO    : Updated Thermal Rating: on line 2821-2025 : Rate B, Rate C , 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 8443-9068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 8443-684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2262
% INFO    : Updated Thermal Rating: on line 2880-8443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8018
% INFO    : Updated Thermal Rating: on line 2880-8443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7138
% INFO    : Updated Thermal Rating: on line 4516-8443 : Rate B, Rate C , 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 4516-8443 : Rate B, Rate C , 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 8443-4813 : Rate B, Rate C , 0.0, 0.0 -> 4932
% INFO    : Updated Thermal Rating: on line 7787-6327 : Rate B, Rate C , 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 6327-8933 : Rate B, Rate C , 0.0, 0.0 -> 1372
% INFO    : Updated Thermal Rating: on line 2139-3556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7374
% INFO    : Updated Thermal Rating: on line 2871-1140 : Rate B, Rate C , 0.0, 0.0 -> 7942
% INFO    : Updated Thermal Rating: on line 4574-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1561
% INFO    : Updated Thermal Rating: on line 7420-2316 : Rate B, Rate C , 0.0, 0.0 -> 8125
% INFO    : Updated Thermal Rating: on line 7420-376 : Rate B, Rate C , 0.0, 0.0 -> 5061
% INFO    : Updated Thermal Rating: on line 6809-4770 : Rate B, Rate C , 0.0, 0.0 -> 5180
% INFO    : Updated Thermal Rating: on line 4770-1804 : Rate B, Rate C , 0.0, 0.0 -> 5001
% INFO    : Updated Thermal Rating: on line 2423-405 : Rate B, Rate C , 0.0, 0.0 -> 9787
% INFO    : Updated Thermal Rating: on line 2423-4512 : Rate B, Rate C , 0.0, 0.0 -> 10272
% INFO    : Updated Thermal Rating: on line 2423-4928 : Rate B, Rate C , 0.0, 0.0 -> 3608
% INFO    : Updated Thermal Rating: on line 2423-8161 : Rate B, Rate C , 0.0, 0.0 -> 1564
% INFO    : Updated Thermal Rating: on line 9139-7311 : Rate B, Rate C , 0.0, 0.0 -> 9488
% INFO    : Updated Thermal Rating: on line 9139-7311 : Rate B, Rate C , 0.0, 0.0 -> 9403
% INFO    : Updated Thermal Rating: on line 9139-7311 : Rate B, Rate C , 0.0, 0.0 -> 9691
% INFO    : Updated Thermal Rating: on line 3068-9139 : Rate B, Rate C , 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 4865-9139 : Rate B, Rate C , 0.0, 0.0 -> 71624
% INFO    : Updated Thermal Rating: on line 3465-7538 : Rate B, Rate C , 0.0, 0.0 -> 2879
% INFO    : Updated Thermal Rating: on line 8320-3465 : Rate B, Rate C , 0.0, 0.0 -> 1690
% INFO    : Updated Thermal Rating: on line 6895-1512 : Rate B, Rate C , 0.0, 0.0 -> 3412
% INFO    : Updated Thermal Rating: on line 6895-6189 : Rate B, Rate C , 0.0, 0.0 -> 3683
% INFO    : Updated Thermal Rating: on line 3180-4576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1890
% INFO    : Updated Thermal Rating: on line 3180-830 : Rate B, Rate C , 0.0, 0.0 -> 5523
% INFO    : Updated Thermal Rating: on line 6939-3180 : Rate B, Rate C , 0.0, 0.0 -> 4942
% INFO    : Updated Thermal Rating: on line 6939-3180 : Rate B, Rate C , 0.0, 0.0 -> 4851
% INFO    : Updated Thermal Rating: on line 7891-3180 : Rate B, Rate C , 0.0, 0.0 -> 6992
% INFO    : Updated Thermal Rating: on line 8215-3892 : Rate B, Rate C , 0.0, 0.0 -> 416
% INFO    : Updated Thermal Rating: on line 8215-8600 : Rate B, Rate C , 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 8215-1423 : Rate B, Rate C , 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 2871-13 : Rate B, Rate C , 0.0, 0.0 -> 8750
% INFO    : Updated Thermal Rating: on line 2871-4516 : Rate B, Rate C , 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 4572-904 : Rate B, Rate C , 0.0, 0.0 -> 6501
% INFO    : Updated Thermal Rating: on line 88-904 : Rate B, Rate C , 0.0, 0.0 -> 20617
% INFO    : Updated Thermal Rating: on line 7718-904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8598
% INFO    : Updated Thermal Rating: on line 7718-904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8990
% INFO    : Updated Thermal Rating: on line 904-5181 : Rate B, Rate C , 0.0, 0.0 -> 11710
% INFO    : Updated Thermal Rating: on line 4526-5451 : Rate B, Rate C , 0.0, 0.0 -> 2030
% INFO    : Updated Thermal Rating: on line 4526-2484 : Rate B, Rate C , 0.0, 0.0 -> 4781
% INFO    : Updated Thermal Rating: on line 8892-5078 : Rate B, Rate C , 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 8509-8892 : Rate B, Rate C , 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 1814-3351 : Rate B, Rate C , 0.0, 0.0 -> 4074
% INFO    : Updated Thermal Rating: on line 1814-6464 : Rate B, Rate C , 0.0, 0.0 -> 6527
% INFO    : Updated Thermal Rating: on line 5945-3767 : Rate B, Rate C , 0.0, 0.0 -> 8724
% INFO    : Updated Thermal Rating: on line 1257-985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 985-8524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 6161-4576 : Rate B, Rate C , 0.0, 0.0 -> 5733
% INFO    : Updated Thermal Rating: on line 2756-3546 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1624
% INFO    : Updated Thermal Rating: on line 2756-8663 : Rate B, Rate C , 0.0, 0.0 -> 3077
% INFO    : Updated Thermal Rating: on line 7268-2756 : Rate B, Rate C , 0.0, 0.0 -> 2900
% INFO    : Updated Thermal Rating: on line 8786-1468 : Rate A, Rate B, Rate C , 533.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 8786-1468 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 1468-4089 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 4089-1468 : Rate B, Rate C , 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 3078-1034 : Rate B, Rate C , 0.0, 0.0 -> 7701
% INFO    : Updated Thermal Rating: on line 580-6529 : Rate B, Rate C , 0.0, 0.0 -> 10204
% INFO    : Updated Thermal Rating: on line 580-7108 : Rate B, Rate C , 0.0, 0.0 -> 8830
% INFO    : Updated Thermal Rating: on line 3285-3884 : Rate B, Rate C , 0.0, 0.0 -> 3418
% INFO    : Updated Thermal Rating: on line 3285-4680 : Rate B, Rate C , 0.0, 0.0 -> 17503
% INFO    : Updated Thermal Rating: on line 6070-939 : Rate B, Rate C , 0.0, 0.0 -> 3924
% INFO    : Updated Thermal Rating: on line 471-939 : Rate B, Rate C , 0.0, 0.0 -> 3832
% INFO    : Updated Thermal Rating: on line 939-5677 : Rate B, Rate C , 0.0, 0.0 -> 1409
% INFO    : Updated Thermal Rating: on line 2040-3769 : Rate B, Rate C , 0.0, 0.0 -> 1637
% INFO    : Updated Thermal Rating: on line 4516-3769 : Rate B, Rate C , 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 5532-5253 : Rate B, Rate C , 0.0, 0.0 -> 2478
% INFO    : Updated Thermal Rating: on line 1-7639 : Rate B, Rate C , 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 1-7835 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 1-7835 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 1523-5633 : Rate B, Rate C , 0.0, 0.0 -> 1509
% INFO    : Updated Thermal Rating: on line 8681-1523 : Rate B, Rate C , 0.0, 0.0 -> 3848
% INFO    : Updated Thermal Rating: on line 8724-1072 : Rate B, Rate C , 0.0, 0.0 -> 2164
% INFO    : Updated Thermal Rating: on line 3546-8724 : Rate B, Rate C , 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 2366-1470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 1470-2880 : Rate B, Rate C , 0.0, 0.0 -> 17439
% INFO    : Updated Thermal Rating: on line 1470-1257 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 5-5459 : Rate B, Rate C , 0.0, 0.0 -> 2162
% INFO    : Updated Thermal Rating: on line 5-2675 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 2905-6958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14345
% INFO    : Updated Thermal Rating: on line 1804-2905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14534
% INFO    : Updated Thermal Rating: on line 2905-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35865
% INFO    : Updated Thermal Rating: on line 763-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6342
% INFO    : Updated Thermal Rating: on line 3874-1072 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 565-6210 : Rate B, Rate C , 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 565-6210 : Rate B, Rate C , 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on line 6210-3832 : Rate B, Rate C , 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 6210-3832 : Rate B, Rate C , 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 5483-7494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3605
% INFO    : Updated Thermal Rating: on line 3195-5483 : Rate B, Rate C , 0.0, 0.0 -> 5260
% INFO    : Updated Thermal Rating: on line 9121-5747 : Rate B, Rate C , 0.0, 0.0 -> 2177
% INFO    : Updated Thermal Rating: on line 882-5747 : Rate B, Rate C , 0.0, 0.0 -> 4054
% INFO    : Updated Thermal Rating: on line 4928-5747 : Rate B, Rate C , 0.0, 0.0 -> 6409
% INFO    : Updated Thermal Rating: on line 2685-2636 : Rate B, Rate C , 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 2224-2636 : Rate B, Rate C , 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 3811-9236 : Rate B, Rate C , 0.0, 0.0 -> 2973
% INFO    : Updated Thermal Rating: on line 8237-9236 : Rate B, Rate C , 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 1613-565 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 1613-565 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 4666-565 : Rate B, Rate C , 0.0, 0.0 -> 25619
% INFO    : Updated Thermal Rating: on line 7743-565 : Rate B, Rate C , 0.0, 0.0 -> 27605
% INFO    : Updated Thermal Rating: on line 8266-2199 : Rate B, Rate C , 0.0, 0.0 -> 4037
% INFO    : Updated Thermal Rating: on line 8266-3343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2978
% INFO    : Updated Thermal Rating: on line 8588-8266 : Rate B, Rate C , 0.0, 0.0 -> 2670
% INFO    : Updated Thermal Rating: on line 7234-830 : Rate B, Rate C , 0.0, 0.0 -> 3394
% INFO    : Updated Thermal Rating: on line 149-830 : Rate B, Rate C , 0.0, 0.0 -> 34205
% INFO    : Updated Thermal Rating: on line 295-1034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36308
% INFO    : Updated Thermal Rating: on line 2384-3948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2004
% INFO    : Updated Thermal Rating: on line 2384-3948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2044
% INFO    : Updated Thermal Rating: on line 2384-1469 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 1092-2384 : Rate B, Rate C , 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 8375-5376 : Rate B, Rate C , 0.0, 0.0 -> 9136
% INFO    : Updated Thermal Rating: on line 5376-1684 : Rate B, Rate C , 0.0, 0.0 -> 4756
% INFO    : Updated Thermal Rating: on line 405-8573 : Rate B, Rate C , 0.0, 0.0 -> 31827
% INFO    : Updated Thermal Rating: on line 5510-405 : Rate B, Rate C , 0.0, 0.0 -> 15766
% INFO    : Updated Thermal Rating: on line 229-3884 : Rate B, Rate C , 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 3099-3884 : Rate B, Rate C , 0.0, 0.0 -> 4468
% INFO    : Updated Thermal Rating: on line 6863-4138 : Rate B, Rate C , 0.0, 0.0 -> 1080
% INFO    : Updated Thermal Rating: on line 6863-6594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3300
% INFO    : Updated Thermal Rating: on line 6594-6863 : Rate B, Rate C , 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 1032-6863 : Rate B, Rate C , 0.0, 0.0 -> 11078
% INFO    : Updated Thermal Rating: on line 7718-8014 : Rate B, Rate C , 0.0, 0.0 -> 4325
% INFO    : Updated Thermal Rating: on line 6649-8014 : Rate B, Rate C , 0.0, 0.0 -> 9269
% INFO    : Updated Thermal Rating: on line 2684-8375 : Rate B, Rate C , 0.0, 0.0 -> 9035
% INFO    : Updated Thermal Rating: on line 1327-49 : Rate B, Rate C , 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 1327-49 : Rate B, Rate C , 0.0, 0.0 -> 1536
% INFO    : Updated Thermal Rating: on line 49-1236 : Rate B, Rate C , 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 49-2803 : Rate B, Rate C , 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 6809-4572 : Rate B, Rate C , 0.0, 0.0 -> 4872
% INFO    : Updated Thermal Rating: on line 5459-3571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 5868-1571 : Rate B, Rate C , 0.0, 0.0 -> 2588
% INFO    : Updated Thermal Rating: on line 1571-6201 : Rate B, Rate C , 0.0, 0.0 -> 20992
% INFO    : Updated Thermal Rating: on line 1571-6460 : Rate B, Rate C , 0.0, 0.0 -> 4272
% INFO    : Updated Thermal Rating: on line 7855-5959 : Rate B, Rate C , 0.0, 0.0 -> 15726
% INFO    : Updated Thermal Rating: on line 4995-8951 : Rate B, Rate C , 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 8681-8951 : Rate B, Rate C , 0.0, 0.0 -> 1416
% INFO    : Updated Thermal Rating: on line 2909-7639 : Rate B, Rate C , 0.0, 0.0 -> 4678
% INFO    : Updated Thermal Rating: on line 3347-510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69084
% INFO    : Updated Thermal Rating: on line 510-471 : Rate B, Rate C , 0.0, 0.0 -> 4006
% INFO    : Updated Thermal Rating: on line 4035-510 : Rate B, Rate C , 0.0, 0.0 -> 3254
% INFO    : Updated Thermal Rating: on line 6156-834 : Rate B, Rate C , 0.0, 0.0 -> 19837
% INFO    : Updated Thermal Rating: on line 6156-7718 : Rate B, Rate C , 0.0, 0.0 -> 65727
% INFO    : Updated Thermal Rating: on line 7311-5471 : Rate B, Rate C , 0.0, 0.0 -> 11190
% INFO    : Updated Thermal Rating: on line 5476-7311 : Rate B, Rate C , 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 7311-8588 : Rate B, Rate C , 0.0, 0.0 -> 9289
% INFO    : Updated Thermal Rating: on line 7311-8588 : Rate B, Rate C , 0.0, 0.0 -> 7924
% INFO    : Updated Thermal Rating: on line 1320-7538 : Rate B, Rate C , 0.0, 0.0 -> 3356
% INFO    : Updated Thermal Rating: on line 7540-7538 : Rate B, Rate C , 0.0, 0.0 -> 2025
% INFO    : Updated Thermal Rating: on line 8320-7538 : Rate B, Rate C , 0.0, 0.0 -> 1414
% INFO    : Updated Thermal Rating: on line 7538-5704 : Rate B, Rate C , 0.0, 0.0 -> 3164
% INFO    : Updated Thermal Rating: on line 2669-3068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10536
% INFO    : Updated Thermal Rating: on line 3068-8635 : Rate B, Rate C , 0.0, 0.0 -> 5582
% INFO    : Updated Thermal Rating: on line 6-3068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4204
% INFO    : Updated Thermal Rating: on line 6303-708 : Rate B, Rate C , 0.0, 0.0 -> 1498
% INFO    : Updated Thermal Rating: on line 2880-708 : Rate B, Rate C , 0.0, 0.0 -> 939
% INFO    : Updated Thermal Rating: on line 708-4448 : Rate B, Rate C , 0.0, 0.0 -> 1450
% INFO    : Updated Thermal Rating: on line 708-4813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1093
% INFO    : Updated Thermal Rating: on line 1760-7197 : Rate B, Rate C , 0.0, 0.0 -> 36609
% INFO    : Updated Thermal Rating: on line 2634-4445 : Rate B, Rate C , 0.0, 0.0 -> 11293
% INFO    : Updated Thermal Rating: on line 2634-4445 : Rate B, Rate C , 0.0, 0.0 -> 9474
% INFO    : Updated Thermal Rating: on line 5692-5868 : Rate B, Rate C , 0.0, 0.0 -> 87709
% INFO    : Updated Thermal Rating: on line 5181-6631 : Rate B, Rate C , 0.0, 0.0 -> 7704
% INFO    : Updated Thermal Rating: on line 6631-7167 : Rate B, Rate C , 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 7727-7841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122178
% INFO    : Updated Thermal Rating: on line 7727-7841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117720
% INFO    : Updated Thermal Rating: on line 7841-8521 : Rate B, Rate C , 0.0, 0.0 -> 5373
% INFO    : Updated Thermal Rating: on line 8774-7841 : Rate B, Rate C , 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 5633-104 : Rate B, Rate C , 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 229-7359 : Rate B, Rate C , 0.0, 0.0 -> 3106
% INFO    : Updated Thermal Rating: on line 229-7359 : Rate B, Rate C , 0.0, 0.0 -> 2567
% INFO    : Updated Thermal Rating: on line 2685-1220 : Rate B, Rate C , 0.0, 0.0 -> 2681
% INFO    : Updated Thermal Rating: on line 1804-547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3805
% INFO    : Updated Thermal Rating: on line 8786-5766 : Rate B, Rate C , 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 8786-5766 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 1613-5997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14933
% INFO    : Updated Thermal Rating: on line 2805-4610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17319
% INFO    : Updated Thermal Rating: on line 4610-6 : Rate B, Rate C , 0.0, 0.0 -> 4279
% INFO    : Updated Thermal Rating: on line 2805-1760 : Rate B, Rate C , 0.0, 0.0 -> 2758
% INFO    : Updated Thermal Rating: on line 7234-5575 : Rate B, Rate C , 0.0, 0.0 -> 2289
% INFO    : Updated Thermal Rating: on line 7234-7182 : Rate B, Rate C , 0.0, 0.0 -> 8826
% INFO    : Updated Thermal Rating: on line 7108-7234 : Rate B, Rate C , 0.0, 0.0 -> 15308
% INFO    : Updated Thermal Rating: on line 7487-6302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20349
% INFO    : Updated Thermal Rating: on line 9121-1512 : Rate B, Rate C , 0.0, 0.0 -> 1718
% INFO    : Updated Thermal Rating: on line 1512-6189 : Rate B, Rate C , 0.0, 0.0 -> 2099
% INFO    : Updated Thermal Rating: on line 2160-1512 : Rate B, Rate C , 0.0, 0.0 -> 3358
% INFO    : Updated Thermal Rating: on line 3351-3696 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 3351-5577 : Rate B, Rate C , 0.0, 0.0 -> 9024
% INFO    : Updated Thermal Rating: on line 7664-3351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1357
% INFO    : Updated Thermal Rating: on line 3351-3895 : Rate B, Rate C , 0.0, 0.0 -> 6588
% INFO    : Updated Thermal Rating: on line 3351-6444 : Rate B, Rate C , 0.0, 0.0 -> 2692
% INFO    : Updated Thermal Rating: on line 9121-5476 : Rate B, Rate C , 0.0, 0.0 -> 1519
% INFO    : Updated Thermal Rating: on line 9121-1760 : Rate B, Rate C , 0.0, 0.0 -> 6845
% INFO    : Updated Thermal Rating: on line 1760-9121 : Rate B, Rate C , 0.0, 0.0 -> 8411
% INFO    : Updated Thermal Rating: on line 9121-2160 : Rate B, Rate C , 0.0, 0.0 -> 3563
% INFO    : Updated Thermal Rating: on line 6809-1804 : Rate B, Rate C , 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on line 6809-4904 : Rate B, Rate C , 0.0, 0.0 -> 3131
% INFO    : Updated Thermal Rating: on line 6809-1423 : Rate B, Rate C , 0.0, 0.0 -> 3159
% INFO    : Updated Thermal Rating: on line 6809-7123 : Rate B, Rate C , 0.0, 0.0 -> 6947
% INFO    : Updated Thermal Rating: on line 6809-6649 : Rate B, Rate C , 0.0, 0.0 -> 15961
% INFO    : Updated Thermal Rating: on line 2986-4836 : Rate B, Rate C , 0.0, 0.0 -> 19953
% INFO    : Updated Thermal Rating: on line 2986-4836 : Rate B, Rate C , 0.0, 0.0 -> 20864
% INFO    : Updated Thermal Rating: on line 1193-4943 : Rate B, Rate C , 0.0, 0.0 -> 73281
% INFO    : Updated Thermal Rating: on line 1193-685 : Rate B, Rate C , 0.0, 0.0 -> 5353
% INFO    : Updated Thermal Rating: on line 2039-1193 : Rate B, Rate C , 0.0, 0.0 -> 2587
% INFO    : Updated Thermal Rating: on line 6776-5766 : Rate B, Rate C , 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 6776-3832 : Rate B, Rate C , 0.0, 0.0 -> 1001
% INFO    : Updated Thermal Rating: on line 1327-2314 : Rate B, Rate C , 0.0, 0.0 -> 11714
% INFO    : Updated Thermal Rating: on line 6107-2314 : Rate B, Rate C , 0.0, 0.0 -> 22950
% INFO    : Updated Thermal Rating: on line 5959-2314 : Rate B, Rate C , 0.0, 0.0 -> 46475
% INFO    : Updated Thermal Rating: on line 837-1688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67204
% INFO    : Updated Thermal Rating: on line 1991-1688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68365
% INFO    : Updated Thermal Rating: on line 2040-4502 : Rate B, Rate C , 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 4502-4516 : Rate B, Rate C , 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 3811-8237 : Rate B, Rate C , 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 3811-1224 : Rate B, Rate C , 0.0, 0.0 -> 3481
% INFO    : Updated Thermal Rating: on line 8608-3811 : Rate B, Rate C , 0.0, 0.0 -> 6080
% INFO    : Updated Thermal Rating: on line 3811-6736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5662
% INFO    : Updated Thermal Rating: on line 7494-4719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156073
% INFO    : Updated Thermal Rating: on line 7494-6191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148114
% INFO    : Updated Thermal Rating: on line 5451-2570 : Rate B, Rate C , 0.0, 0.0 -> 2686
% INFO    : Updated Thermal Rating: on line 3699-5451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33500
% INFO    : Updated Thermal Rating: on line 3972-2456 : Rate B, Rate C , 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 748-2570 : Rate B, Rate C , 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 6529-2884 : Rate B, Rate C , 0.0, 0.0 -> 4926
% INFO    : Updated Thermal Rating: on line 6529-2684 : Rate B, Rate C , 0.0, 0.0 -> 5220
% INFO    : Updated Thermal Rating: on line 3560-4283 : Rate B, Rate C , 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 3560-7167 : Rate B, Rate C , 0.0, 0.0 -> 9343
% INFO    : Updated Thermal Rating: on line 3634-6892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48037
% INFO    : Updated Thermal Rating: on line 2594-3634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1414
% INFO    : Updated Thermal Rating: on line 3634-1236 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 3634-2317 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 3634-2317 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 704-2034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3708
% INFO    : Updated Thermal Rating: on line 6302-704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7267
% INFO    : Updated Thermal Rating: on line 704-5913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20511
% INFO    : Updated Thermal Rating: on line 3696-6444 : Rate B, Rate C , 0.0, 0.0 -> 4392
% INFO    : Updated Thermal Rating: on line 3696-5623 : Rate B, Rate C , 0.0, 0.0 -> 2622
% INFO    : Updated Thermal Rating: on line 5623-3696 : Rate B, Rate C , 0.0, 0.0 -> 3294
% INFO    : Updated Thermal Rating: on line 8663-2589 : Rate B, Rate C , 0.0, 0.0 -> 42102
% INFO    : Updated Thermal Rating: on line 7268-8663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2586
% INFO    : Updated Thermal Rating: on line 1034-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3890
% INFO    : Updated Thermal Rating: on line 4243-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4913
% INFO    : Updated Thermal Rating: on line 4433-4436 : Rate B, Rate C , 0.0, 0.0 -> 136820
% INFO    : Updated Thermal Rating: on line 4433-4436 : Rate B, Rate C , 0.0, 0.0 -> 142990
% INFO    : Updated Thermal Rating: on line 3874-4433 : Rate B, Rate C , 0.0, 0.0 -> 7980
% INFO    : Updated Thermal Rating: on line 3874-4433 : Rate B, Rate C , 0.0, 0.0 -> 7824
% INFO    : Updated Thermal Rating: on line 5945-238 : Rate B, Rate C , 0.0, 0.0 -> 6054
% INFO    : Updated Thermal Rating: on line 238-4715 : Rate B, Rate C , 0.0, 0.0 -> 13092
% INFO    : Updated Thermal Rating: on line 4715-8036 : Rate B, Rate C , 0.0, 0.0 -> 1890
% INFO    : Updated Thermal Rating: on line 7479-9135 : Rate B, Rate C , 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 7403-7479 : Rate B, Rate C , 0.0, 0.0 -> 3070
% INFO    : Updated Thermal Rating: on line 528-6303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2078
% INFO    : Updated Thermal Rating: on line 4152-528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on line 8237-2100 : Rate B, Rate C , 0.0, 0.0 -> 150246
% INFO    : Updated Thermal Rating: on line 2302-2199 : Rate B, Rate C , 0.0, 0.0 -> 4119
% INFO    : Updated Thermal Rating: on line 4036-5577 : Rate B, Rate C , 0.0, 0.0 -> 157740
% INFO    : Updated Thermal Rating: on line 5577-6444 : Rate B, Rate C , 0.0, 0.0 -> 4224
% INFO    : Updated Thermal Rating: on line 3238-3892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 3238-2650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39811
% INFO    : Updated Thermal Rating: on line 3238-893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2400
% INFO    : Updated Thermal Rating: on line 4138-8774 : Rate B, Rate C , 0.0, 0.0 -> 629
% INFO    : Updated Thermal Rating: on line 2615-1610 : Rate B, Rate C , 0.0, 0.0 -> 6728
% INFO    : Updated Thermal Rating: on line 2615-1610 : Rate B, Rate C , 0.0, 0.0 -> 5948
% INFO    : Updated Thermal Rating: on line 3343-2615 : Rate B, Rate C , 0.0, 0.0 -> 17039
% INFO    : Updated Thermal Rating: on line 3343-2615 : Rate B, Rate C , 0.0, 0.0 -> 17407
% INFO    : Updated Thermal Rating: on line 5292-7753 : Rate B, Rate C , 0.0, 0.0 -> 17430
% INFO    : Updated Thermal Rating: on line 1480-3384 : Rate B, Rate C , 0.0, 0.0 -> 13853
% INFO    : Updated Thermal Rating: on line 2766-7891 : Rate B, Rate C , 0.0, 0.0 -> 9934
% INFO    : Updated Thermal Rating: on line 1684-2766 : Rate B, Rate C , 0.0, 0.0 -> 6515
% INFO    : Updated Thermal Rating: on line 99-7248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3674
% INFO    : Updated Thermal Rating: on line 99-9009 : Rate B, Rate C , 0.0, 0.0 -> 4737
% INFO    : Updated Thermal Rating: on line 7804-3024 : Rate B, Rate C , 0.0, 0.0 -> 2524
% INFO    : Updated Thermal Rating: on line 6566-3024 : Rate B, Rate C , 0.0, 0.0 -> 5992
% INFO    : Updated Thermal Rating: on line 6189-4019 : Rate B, Rate C , 0.0, 0.0 -> 2917
% INFO    : Updated Thermal Rating: on line 2680-6189 : Rate B, Rate C , 0.0, 0.0 -> 2166
% INFO    : Updated Thermal Rating: on line 485-7248 : Rate B, Rate C , 0.0, 0.0 -> 12068
% INFO    : Updated Thermal Rating: on line 5982-8708 : Rate B, Rate C , 0.0, 0.0 -> 157740
% INFO    : Updated Thermal Rating: on line 1224-8708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5247
% INFO    : Updated Thermal Rating: on line 9009-8708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20874
% INFO    : Updated Thermal Rating: on line 4487-802 : Rate B, Rate C , 0.0, 0.0 -> 149739
% INFO    : Updated Thermal Rating: on line 8237-802 : Rate B, Rate C , 0.0, 0.0 -> 5544
% INFO    : Updated Thermal Rating: on line 660-802 : Rate B, Rate C , 0.0, 0.0 -> 5931
% INFO    : Updated Thermal Rating: on line 2669-2302 : Rate B, Rate C , 0.0, 0.0 -> 6541
% INFO    : Updated Thermal Rating: on line 2039-220 : Rate B, Rate C , 0.0, 0.0 -> 157740
% INFO    : Updated Thermal Rating: on line 7664-1131 : Rate B, Rate C , 0.0, 0.0 -> 143431
% INFO    : Updated Thermal Rating: on line 2709-8573 : Rate B, Rate C , 0.0, 0.0 -> 125947
% INFO    : Updated Thermal Rating: on line 2709-8573 : Rate B, Rate C , 0.0, 0.0 -> 121132
% INFO    : Updated Thermal Rating: on line 882-3174 : Rate B, Rate C , 0.0, 0.0 -> 5972
% INFO    : Updated Thermal Rating: on line 2923-3174 : Rate B, Rate C , 0.0, 0.0 -> 3751
% INFO    : Updated Thermal Rating: on line 6464-8139 : Rate B, Rate C , 0.0, 0.0 -> 1818
% INFO    : Updated Thermal Rating: on line 4159-6464 : Rate B, Rate C , 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 7248-8139 : Rate B, Rate C , 0.0, 0.0 -> 4638
% INFO    : Updated Thermal Rating: on line 7248-8139 : Rate B, Rate C , 0.0, 0.0 -> 5005
% INFO    : Updated Thermal Rating: on line 8139-9009 : Rate B, Rate C , 0.0, 0.0 -> 3776
% INFO    : Updated Thermal Rating: on line 7672-685 : Rate B, Rate C , 0.0, 0.0 -> 2828
% INFO    : Updated Thermal Rating: on line 2039-685 : Rate B, Rate C , 0.0, 0.0 -> 2864
% INFO    : Updated Thermal Rating: on line 3123-3159 : Rate B, Rate C , 0.0, 0.0 -> 4337
% INFO    : Updated Thermal Rating: on line 4159-3159 : Rate B, Rate C , 0.0, 0.0 -> 2672
% INFO    : Updated Thermal Rating: on line 4436-2344 : Rate B, Rate C , 0.0, 0.0 -> 15840
% INFO    : Updated Thermal Rating: on line 4436-2344 : Rate B, Rate C , 0.0, 0.0 -> 16104
% INFO    : Updated Thermal Rating: on line 6408-2344 : Rate B, Rate C , 0.0, 0.0 -> 78870
% INFO    : Updated Thermal Rating: on line 6408-2344 : Rate B, Rate C , 0.0, 0.0 -> 76951
% INFO    : Updated Thermal Rating: on line 4869-4564 : Rate B, Rate C , 0.0, 0.0 -> 115804
% INFO    : Updated Thermal Rating: on line 4564-4869 : Rate B, Rate C , 0.0, 0.0 -> 111733
% INFO    : Updated Thermal Rating: on line 4564-3228 : Rate B, Rate C , 0.0, 0.0 -> 89029
% INFO    : Updated Thermal Rating: on line 2232-5854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25020
% INFO    : Updated Thermal Rating: on line 2232-8774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2787
% INFO    : Updated Thermal Rating: on line 8524-748 : Rate B, Rate C , 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 6939-6560 : Rate B, Rate C , 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 6560-5868 : Rate B, Rate C , 0.0, 0.0 -> 2124
% INFO    : Updated Thermal Rating: on line 6560-5868 : Rate B, Rate C , 0.0, 0.0 -> 2169
% INFO    : Updated Thermal Rating: on line 7248-3123 : Rate A, Rate B, Rate C , 1942.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 7248-3123 : Rate A, Rate B, Rate C , 1942.0, 0.0, 0.0 -> 1343
% INFO    : Updated Thermal Rating: on line 4040-3123 : Rate B, Rate C , 0.0, 0.0 -> 2120
% INFO    : Updated Thermal Rating: on line 4040-3123 : Rate B, Rate C , 0.0, 0.0 -> 2029
% INFO    : Updated Thermal Rating: on line 342-759 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 7071-1269 : Rate B, Rate C , 0.0, 0.0 -> 17150
% INFO    : Updated Thermal Rating: on line 8857-2822 : Rate B, Rate C , 0.0, 0.0 -> 50626
% INFO    : Updated Thermal Rating: on line 2822-13 : Rate B, Rate C , 0.0, 0.0 -> 1349
% INFO    : Updated Thermal Rating: on line 4516-2822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 2822-9013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3573
% INFO    : Updated Thermal Rating: on line 6444-9132 : Rate B, Rate C , 0.0, 0.0 -> 12743
% INFO    : Updated Thermal Rating: on line 6444-5623 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on line 8237-660 : Rate B, Rate C , 0.0, 0.0 -> 3964
% INFO    : Updated Thermal Rating: on line 8237-5328 : Rate B, Rate C , 0.0, 0.0 -> 3988
% INFO    : Updated Thermal Rating: on line 7619-6939 : Rate B, Rate C , 0.0, 0.0 -> 75017
% INFO    : Updated Thermal Rating: on line 1748-6939 : Rate B, Rate C , 0.0, 0.0 -> 75017
% INFO    : Updated Thermal Rating: on line 8569-6939 : Rate B, Rate C , 0.0, 0.0 -> 89920
% INFO    : Updated Thermal Rating: on line 6778-6939 : Rate B, Rate C , 0.0, 0.0 -> 87440
% INFO    : Updated Thermal Rating: on line 7891-6939 : Rate B, Rate C , 0.0, 0.0 -> 7443
% INFO    : Updated Thermal Rating: on line 3099-5109 : Rate B, Rate C , 0.0, 0.0 -> 3482
% INFO    : Updated Thermal Rating: on line 5109-4680 : Rate B, Rate C , 0.0, 0.0 -> 8722
% INFO    : Updated Thermal Rating: on line 7103-6070 : Rate B, Rate C , 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 7103-2034 : Rate B, Rate C , 0.0, 0.0 -> 2455
% INFO    : Updated Thermal Rating: on line 7103-1034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2769
% INFO    : Updated Thermal Rating: on line 7103-4243 : Rate B, Rate C , 0.0, 0.0 -> 3400
% INFO    : Updated Thermal Rating: on line 7103-5677 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 817-7182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5649
% INFO    : Updated Thermal Rating: on line 817-8635 : Rate B, Rate C , 0.0, 0.0 -> 4381
% INFO    : Updated Thermal Rating: on line 7787-4574 : Rate B, Rate C , 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 1209-7787 : Rate B, Rate C , 0.0, 0.0 -> 2469
% INFO    : Updated Thermal Rating: on line 142-7835 : Rate B, Rate C , 0.0, 0.0 -> 2980
% INFO    : Updated Thermal Rating: on line 2135-2034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4131
% INFO    : Updated Thermal Rating: on line 8907-2135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 2135-8634 : Rate B, Rate C , 0.0, 0.0 -> 34135
% INFO    : Updated Thermal Rating: on line 7540-3816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6018
% INFO    : Updated Thermal Rating: on line 7540-102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7317
% INFO    : Updated Thermal Rating: on line 7540-8320 : Rate B, Rate C , 0.0, 0.0 -> 2602
% INFO    : Updated Thermal Rating: on line 4152-7540 : Rate B, Rate C , 0.0, 0.0 -> 19454
% INFO    : Updated Thermal Rating: on line 7540-5704 : Rate B, Rate C , 0.0, 0.0 -> 21767
% INFO    : Updated Thermal Rating: on line 7320-1804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38753
% INFO    : Updated Thermal Rating: on line 8484-1804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31773
% INFO    : Updated Thermal Rating: on line 3337-5089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2155
% INFO    : Updated Thermal Rating: on line 3337-2200 : Rate B, Rate C , 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 7618-8246 : Rate B, Rate C , 0.0, 0.0 -> 140617
% INFO    : Updated Thermal Rating: on line 8246-5913 : Rate B, Rate C , 0.0, 0.0 -> 27356
% INFO    : Updated Thermal Rating: on line 5746-4283 : Rate B, Rate C , 0.0, 0.0 -> 1699
% INFO    : Updated Thermal Rating: on line 5746-4283 : Rate B, Rate C , 0.0, 0.0 -> 2270
% INFO    : Updated Thermal Rating: on line 342-4283 : Rate B, Rate C , 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 1610-4381 : Rate B, Rate C , 0.0, 0.0 -> 10678
% INFO    : Updated Thermal Rating: on line 5668-8426 : Rate B, Rate C , 0.0, 0.0 -> 1224
% INFO    : Updated Thermal Rating: on line 5668-7593 : Rate B, Rate C , 0.0, 0.0 -> 2372
% INFO    : Updated Thermal Rating: on line 4168-832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152932
% INFO    : Updated Thermal Rating: on line 4168-832 : Rate B, Rate C , 0.0, 0.0 -> 97986
% INFO    : Updated Thermal Rating: on line 4168-832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138387
% INFO    : Updated Thermal Rating: on line 4168-832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158234
% INFO    : Updated Thermal Rating: on line 4168-832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143877
% INFO    : Updated Thermal Rating: on line 4168-3816 : Rate B, Rate C , 0.0, 0.0 -> 31485
% INFO    : Updated Thermal Rating: on line 4168-102 : Rate B, Rate C , 0.0, 0.0 -> 14703
% INFO    : Updated Thermal Rating: on line 4152-4168 : Rate B, Rate C , 0.0, 0.0 -> 36400
% INFO    : Updated Thermal Rating: on line 8275-4168 : Rate B, Rate C , 0.0, 0.0 -> 64904
% INFO    : Updated Thermal Rating: on line 3099-229 : Rate B, Rate C , 0.0, 0.0 -> 2753
% INFO    : Updated Thermal Rating: on line 4330-229 : Rate B, Rate C , 0.0, 0.0 -> 2183
% INFO    : Updated Thermal Rating: on line 2187-7672 : Rate B, Rate C , 0.0, 0.0 -> 4148
% INFO    : Updated Thermal Rating: on line 7672-2362 : Rate B, Rate C , 0.0, 0.0 -> 11549
% INFO    : Updated Thermal Rating: on line 8933-7564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36710
% INFO    : Updated Thermal Rating: on line 4995-8933 : Rate B, Rate C , 0.0, 0.0 -> 2416
% INFO    : Updated Thermal Rating: on line 3554-3807 : Rate B, Rate C , 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 3554-3807 : Rate B, Rate C , 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 3807-5809 : Rate B, Rate C , 0.0, 0.0 -> 9208
% INFO    : Updated Thermal Rating: on line 3807-4089 : Rate B, Rate C , 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on line 3807-4089 : Rate B, Rate C , 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 8399-8869 : Rate B, Rate C , 0.0, 0.0 -> 25219
% INFO    : Updated Thermal Rating: on line 8399-8741 : Rate B, Rate C , 0.0, 0.0 -> 24823
% INFO    : Updated Thermal Rating: on line 8399-4606 : Rate B, Rate C , 0.0, 0.0 -> 24263
% INFO    : Updated Thermal Rating: on line 8399-1488 : Rate B, Rate C , 0.0, 0.0 -> 26279
% INFO    : Updated Thermal Rating: on line 8876-5575 : Rate B, Rate C , 0.0, 0.0 -> 52464
% INFO    : Updated Thermal Rating: on line 5575-6 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6761
% INFO    : Updated Thermal Rating: on line 6594-6302 : Rate B, Rate C , 0.0, 0.0 -> 5346
% INFO    : Updated Thermal Rating: on line 6302-6594 : Rate B, Rate C , 0.0, 0.0 -> 3807
% INFO    : Updated Thermal Rating: on line 4243-6594 : Rate B, Rate C , 0.0, 0.0 -> 2245
% INFO    : Updated Thermal Rating: on line 3958-339 : Rate B, Rate C , 0.0, 0.0 -> 19191
% INFO    : Updated Thermal Rating: on line 4352-8521 : Rate B, Rate C , 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 54-8521 : Rate B, Rate C , 0.0, 0.0 -> 1256
% INFO    : Updated Thermal Rating: on line 8521-8774 : Rate B, Rate C , 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 4561-8399 : Rate A, Rate B, Rate C , 1909.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on line 8399-6316 : Rate B, Rate C , 0.0, 0.0 -> 1687
% INFO    : Updated Thermal Rating: on line 8161-8399 : Rate B, Rate C , 0.0, 0.0 -> 1466
% INFO    : Updated Thermal Rating: on line 8399-5328 : Rate B, Rate C , 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 8399-1031 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1487
% INFO    : Updated Thermal Rating: on line 2484-2139 : Rate B, Rate C , 0.0, 0.0 -> 1120
% INFO    : Updated Thermal Rating: on line 3972-4159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2498
% INFO    : Updated Thermal Rating: on line 5130-376 : Rate B, Rate C , 0.0, 0.0 -> 3706
% INFO    : Updated Thermal Rating: on line 5130-2710 : Rate B, Rate C , 0.0, 0.0 -> 5652
% INFO    : Updated Thermal Rating: on line 2694-5510 : Rate B, Rate C , 0.0, 0.0 -> 5245
% INFO    : Updated Thermal Rating: on line 2694-4512 : Rate B, Rate C , 0.0, 0.0 -> 5483
% INFO    : Updated Thermal Rating: on line 2694-8117 : Rate B, Rate C , 0.0, 0.0 -> 1950
% INFO    : Updated Thermal Rating: on line 882-6161 : Rate B, Rate C , 0.0, 0.0 -> 6693
% INFO    : Updated Thermal Rating: on line 3554-745 : Rate B, Rate C , 0.0, 0.0 -> 38643
% INFO    : Updated Thermal Rating: on line 3554-1613 : Rate B, Rate C , 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 3554-1613 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 2034-7618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5377
% INFO    : Updated Thermal Rating: on line 1871-2880 : Rate B, Rate C , 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 4147-376 : Rate B, Rate C , 0.0, 0.0 -> 95024
% INFO    : Updated Thermal Rating: on line 2332-376 : Rate B, Rate C , 0.0, 0.0 -> 89666
% INFO    : Updated Thermal Rating: on line 5124-376 : Rate B, Rate C , 0.0, 0.0 -> 104368
% INFO    : Updated Thermal Rating: on line 3348-376 : Rate B, Rate C , 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 4904-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63555
% INFO    : Updated Thermal Rating: on line 9197-3721 : Rate B, Rate C , 0.0, 0.0 -> 28081
% INFO    : Updated Thermal Rating: on line 4133-9197 : Rate B, Rate C , 0.0, 0.0 -> 1042
% INFO    : Updated Thermal Rating: on line 2634-7182 : Rate B, Rate C , 0.0, 0.0 -> 3119
% INFO    : Updated Thermal Rating: on line 2040-5839 : Rate B, Rate C , 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 5694-5746 : Rate B, Rate C , 0.0, 0.0 -> 2733
% INFO    : Updated Thermal Rating: on line 6566-5694 : Rate B, Rate C , 0.0, 0.0 -> 5647
% INFO    : Updated Thermal Rating: on line 1327-3705 : Rate B, Rate C , 0.0, 0.0 -> 32471
% INFO    : Updated Thermal Rating: on line 1327-2317 : Rate B, Rate C , 0.0, 0.0 -> 2782
% INFO    : Updated Thermal Rating: on line 1327-2317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1445
% INFO    : Updated Thermal Rating: on line 1308-5089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2467
% INFO    : Updated Thermal Rating: on line 4348-5866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3536
% INFO    : Updated Thermal Rating: on line 3721-8857 : Rate B, Rate C , 0.0, 0.0 -> 3094
% INFO    : Updated Thermal Rating: on line 2224-7403 : Rate B, Rate C , 0.0, 0.0 -> 2573
% INFO    : Updated Thermal Rating: on line 3196-105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51672
% INFO    : Updated Thermal Rating: on line 6067-191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 2923-6 : Rate B, Rate C , 0.0, 0.0 -> 14057
% INFO    : Updated Thermal Rating: on line 6107-1236 : Rate B, Rate C , 0.0, 0.0 -> 15010
% INFO    : Updated Thermal Rating: on line 7893-8857 : Rate B, Rate C , 0.0, 0.0 -> 1901
% INFO    : Updated Thermal Rating: on line 4561-5510 : Rate B, Rate C , 0.0, 0.0 -> 2700
% INFO    : Updated Thermal Rating: on line 8161-5510 : Rate B, Rate C , 0.0, 0.0 -> 1944
% INFO    : Updated Thermal Rating: on line 7494-2388 : Rate B, Rate C , 0.0, 0.0 -> 4117
% INFO    : Updated Thermal Rating: on line 7123-7494 : Rate B, Rate C , 0.0, 0.0 -> 2355
% INFO    : Updated Thermal Rating: on line 6217-8161 : Rate B, Rate C , 0.0, 0.0 -> 9155
% INFO    : Updated Thermal Rating: on line 8009-8161 : Rate B, Rate C , 0.0, 0.0 -> 10046
% INFO    : Updated Thermal Rating: on line 1822-1760 : Rate B, Rate C , 0.0, 0.0 -> 12978
% INFO    : Updated Thermal Rating: on line 1826-4832 : Rate B, Rate C , 0.0, 0.0 -> 17636
% INFO    : Updated Thermal Rating: on line 3188-4832 : Rate B, Rate C , 0.0, 0.0 -> 15996
% INFO    : Updated Thermal Rating: on line 2594-1236 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 7593-8426 : Rate B, Rate C , 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on line 4094-1688 : Rate B, Rate C , 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 105-2577 : Rate B, Rate C , 0.0, 0.0 -> 30551
% INFO    : Updated Thermal Rating: on line 105-2577 : Rate B, Rate C , 0.0, 0.0 -> 31123
% INFO    : Updated Thermal Rating: on line 2710-2577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8276
% INFO    : Updated Thermal Rating: on line 127-2034 : Rate B, Rate C , 0.0, 0.0 -> 2270
% INFO    : Updated Thermal Rating: on line 8623-3099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3511
% INFO    : Updated Thermal Rating: on line 127-6302 : Rate B, Rate C , 0.0, 0.0 -> 3309
% INFO    : Updated Thermal Rating: on line 992-2200 : Rate B, Rate C , 0.0, 0.0 -> 2570
% INFO    : Updated Thermal Rating: on line 3823-1610 : Rate B, Rate C , 0.0, 0.0 -> 6687
% INFO    : Updated Thermal Rating: on line 3823-946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2358
% INFO    : Updated Thermal Rating: on line 3035-3823 : Rate B, Rate C , 0.0, 0.0 -> 29974
% INFO    : Updated Thermal Rating: on line 3343-3823 : Rate B, Rate C , 0.0, 0.0 -> 4974
% INFO    : Updated Thermal Rating: on line 4089-2983 : Rate B, Rate C , 0.0, 0.0 -> 6305
% INFO    : Updated Thermal Rating: on line 3832-5766 : Rate B, Rate C , 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on line 3832-5766 : Rate B, Rate C , 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 2634-2884 : Rate B, Rate C , 0.0, 0.0 -> 5515
% INFO    : Updated Thermal Rating: on line 9135-5645 : Rate B, Rate C , 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 3234-992 : Rate B, Rate C , 0.0, 0.0 -> 2159
% INFO    : Updated Thermal Rating: on line 3234-992 : Rate B, Rate C , 0.0, 0.0 -> 2099
% INFO    : Updated Thermal Rating: on line 256-2650 : Rate B, Rate C , 0.0, 0.0 -> 37183
% INFO    : Updated Thermal Rating: on line 256-893 : Rate B, Rate C , 0.0, 0.0 -> 2629
% INFO    : Updated Thermal Rating: on line 256-1688 : Rate B, Rate C , 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on line 6680-6756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8329
% INFO    : Updated Thermal Rating: on line 3874-162 : Rate B, Rate C , 0.0, 0.0 -> 6508
% INFO    : Updated Thermal Rating: on line 8608-5328 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 8600-1423 : Rate B, Rate C , 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 2109-4991 : Rate B, Rate C , 0.0, 0.0 -> 3804
% INFO    : Updated Thermal Rating: on line 2109-8117 : Rate B, Rate C , 0.0, 0.0 -> 1800
% INFO    : Updated Thermal Rating: on line 2109-7891 : Rate B, Rate C , 0.0, 0.0 -> 2539
% INFO    : Updated Thermal Rating: on line 1760-5476 : Rate B, Rate C , 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on line 3874-7268 : Rate B, Rate C , 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 1269-5959 : Rate B, Rate C , 0.0, 0.0 -> 28344
% INFO    : Updated Thermal Rating: on line 6201-2986 : Rate B, Rate C , 0.0, 0.0 -> 17692
% INFO    : Updated Thermal Rating: on line 1269-1236 : Rate B, Rate C , 0.0, 0.0 -> 15233
% INFO    : Updated Thermal Rating: on line 7891-2920 : Rate B, Rate C , 0.0, 0.0 -> 34543
% INFO    : Updated Thermal Rating: on line 1939-471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52825
% INFO    : Updated Thermal Rating: on line 3228-5014 : Rate B, Rate C , 0.0, 0.0 -> 125906
% INFO    : Updated Thermal Rating: on line 2039-6408 : Rate B, Rate C , 0.0, 0.0 -> 5670
% INFO    : Updated Thermal Rating: on line 2039-6408 : Rate B, Rate C , 0.0, 0.0 -> 5781
% INFO    : Updated Thermal Rating: on line 6316-4521 : Rate B, Rate C , 0.0, 0.0 -> 6092
% INFO    : Updated Thermal Rating: on line 4521-5328 : Rate B, Rate C , 0.0, 0.0 -> 6905
% INFO    : Updated Thermal Rating: on line 5355-6316 : Rate B, Rate C , 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 7066-4348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 4348-3188 : Rate B, Rate C , 0.0, 0.0 -> 4837
% INFO    : Updated Thermal Rating: on line 1688-4348 : Rate B, Rate C , 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 660-1356 : Rate B, Rate C , 0.0, 0.0 -> 6076
% INFO    : Updated Thermal Rating: on line 1356-5355 : Rate B, Rate C , 0.0, 0.0 -> 2707
% INFO    : Updated Thermal Rating: on line 1826-5532 : Rate B, Rate C , 0.0, 0.0 -> 3028
% INFO    : Updated Thermal Rating: on line 8907-6670 : Rate B, Rate C , 0.0, 0.0 -> 1985
% INFO    : Updated Thermal Rating: on line 2710-4680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 5868-4680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8521
% INFO    : Updated Thermal Rating: on line 1034-4243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2745
% INFO    : Updated Thermal Rating: on line 9115-1034 : Rate B, Rate C , 0.0, 0.0 -> 4304
% INFO    : Updated Thermal Rating: on line 2187-4040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2095
% INFO    : Updated Thermal Rating: on line 6362-692 : Rate B, Rate C , 0.0, 0.0 -> 91030
% INFO    : Updated Thermal Rating: on line 2680-4019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4099
% INFO    : Updated Thermal Rating: on line 4991-6161 : Rate B, Rate C , 0.0, 0.0 -> 9003
% INFO    : Updated Thermal Rating: on line 3816-2574 : Rate B, Rate C , 0.0, 0.0 -> 88825
% INFO    : Updated Thermal Rating: on line 102-2574 : Rate B, Rate C , 0.0, 0.0 -> 87233
% INFO    : Updated Thermal Rating: on line 4516-2880 : Rate B, Rate C , 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 2880-5839 : Rate B, Rate C , 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 1032-6302 : Rate B, Rate C , 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 6302-6567 : Rate B, Rate C , 0.0, 0.0 -> 28038
% INFO    : Updated Thermal Rating: on line 6302-5913 : Rate B, Rate C , 0.0, 0.0 -> 16644
% INFO    : Updated Thermal Rating: on line 1257-3605 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 4516-13 : Rate B, Rate C , 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 8509-4352 : Rate B, Rate C , 0.0, 0.0 -> 7704
% INFO    : Updated Thermal Rating: on line 2709-3963 : Rate B, Rate C , 0.0, 0.0 -> 5898
% INFO    : Updated Thermal Rating: on line 3596-8320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 8774-54 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 6649-3195 : Rate B, Rate C , 0.0, 0.0 -> 8705
% INFO    : Updated Thermal Rating: on line 2025-5292 : Rate B, Rate C , 0.0, 0.0 -> 3811
% INFO    : Updated Thermal Rating: on line 1613-3850 : Rate B, Rate C , 0.0, 0.0 -> 31126
% INFO    : Updated Thermal Rating: on line 1613-3480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31749
% INFO    : Updated Thermal Rating: on line 1613-5192 : Rate B, Rate C , 0.0, 0.0 -> 20402
% INFO    : Updated Thermal Rating: on line 1613-3841 : Rate B, Rate C , 0.0, 0.0 -> 20004
% INFO    : Updated Thermal Rating: on line 893-1867 : Rate B, Rate C , 0.0, 0.0 -> 86322
% INFO    : Updated Thermal Rating: on line 893-1867 : Rate B, Rate C , 0.0, 0.0 -> 87379
% INFO    : Updated Thermal Rating: on line 2680-875 : Rate B, Rate C , 0.0, 0.0 -> 10045
% INFO    : Updated Thermal Rating: on line 399-3540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55154
% INFO    : Updated Thermal Rating: on line 1688-1561 : Rate B, Rate C , 0.0, 0.0 -> 21268
% INFO    : Updated Thermal Rating: on line 1688-1561 : Rate B, Rate C , 0.0, 0.0 -> 17625
% INFO    : Updated Thermal Rating: on line 8588-946 : Rate B, Rate C , 0.0, 0.0 -> 5061
% INFO    : Updated Thermal Rating: on line 3596-7403 : Rate B, Rate C , 0.0, 0.0 -> 1890
% INFO    : Updated Thermal Rating: on line 697-5355 : Rate B, Rate C , 0.0, 0.0 -> 26833
% INFO    : Updated Thermal Rating: on line 8413-5355 : Rate B, Rate C , 0.0, 0.0 -> 24196
% INFO    : Updated Thermal Rating: on line 7066-3020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6273
% INFO    : Updated Thermal Rating: on line 7066-3020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6767
% INFO    : Updated Thermal Rating: on line 1688-7066 : Rate B, Rate C , 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 4516-8036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on line 4516-8036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1173
% INFO    : Updated Thermal Rating: on line 4516-5839 : Rate B, Rate C , 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 1236-7574 : Rate B, Rate C , 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 2803-1236 : Rate B, Rate C , 0.0, 0.0 -> 4922
% INFO    : Updated Thermal Rating: on line 6736-4414 : Rate B, Rate C , 0.0, 0.0 -> 7401
% INFO    : Updated Thermal Rating: on line 9009-4414 : Rate B, Rate C , 0.0, 0.0 -> 13226
% INFO    : Updated Thermal Rating: on line 1082-4414 : Rate B, Rate C , 0.0, 0.0 -> 40803
% INFO    : Updated Thermal Rating: on line 4516-1209 : Rate B, Rate C , 0.0, 0.0 -> 2593
% INFO    : Updated Thermal Rating: on line 9187-4243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8733
% INFO    : Updated Thermal Rating: on line 4995-1220 : Rate B, Rate C , 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 9013-6680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4057
% INFO    : Updated Thermal Rating: on line 8117-6460 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1216
% INFO    : Updated Thermal Rating: on line 3705-191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35314
% INFO    : Updated Thermal Rating: on line 4152-8275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68555
% INFO    : Updated Thermal Rating: on line 8634-4243 : Rate B, Rate C , 0.0, 0.0 -> 18847
% INFO    : Updated Thermal Rating: on line 8161-5328 : Rate A, Rate B, Rate C , 1448.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 6566-7167 : Rate B, Rate C , 0.0, 0.0 -> 2856
% INFO    : Updated Thermal Rating: on line 9115-7306 : Rate B, Rate C , 0.0, 0.0 -> 2482
% INFO    : Updated Thermal Rating: on line 2680-5623 : Rate B, Rate C , 0.0, 0.0 -> 4287
% INFO    : Updated Thermal Rating: on line 5623-2680 : Rate B, Rate C , 0.0, 0.0 -> 4256
% INFO    : Updated Thermal Rating: on line 1031-2680 : Rate B, Rate C , 0.0, 0.0 -> 1716
% INFO    : Updated Thermal Rating: on line 4666-7743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52623
% INFO    : Updated Thermal Rating: on line 1257-7574 : Rate B, Rate C , 0.0, 0.0 -> 21150
% INFO    : Updated Thermal Rating: on line 3228-6963 : Rate B, Rate C , 0.0, 0.0 -> 3571
% INFO    : Updated Thermal Rating: on line 4869-4126 : Rate B, Rate C , 0.0, 0.0 -> 6768
% INFO    : Updated Thermal Rating: on line 4869-1303 : Rate B, Rate C , 0.0, 0.0 -> 3184
% INFO    : Updated Thermal Rating: on line 8634-6567 : Rate B, Rate C , 0.0, 0.0 -> 21246
% INFO    : Updated Thermal Rating: on line 7306-1308 : Rate B, Rate C , 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 1092-7574 : Rate B, Rate C , 0.0, 0.0 -> 14927
% INFO    : Updated Thermal Rating: on line 4330-6460 : Rate B, Rate C , 0.0, 0.0 -> 2091
% INFO    : Updated Thermal Rating: on line 2317-2909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7706
% INFO    : Updated Thermal Rating: on line 4448-8681 : Rate B, Rate C , 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on line 6670-4035 : Rate B, Rate C , 0.0, 0.0 -> 1048
% INFO    : Updated Thermal Rating: on line 7622-7362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6030
% INFO    : Updated Thermal Rating: on line 8785-9233 : Rate B, Rate C , 0.0, 0.0 -> 6553
% INFO    : Updated Thermal Rating: on line 1651-4892 : Rate B, Rate C , 0.0, 0.0 -> 29226
% INFO    : Updated Thermal Rating: on line 8125-3977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36191
% INFO    : Updated Thermal Rating: on line 8125-4892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48435
% INFO    : Updated Thermal Rating: on line 9233-8132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3709
% INFO    : Updated Thermal Rating: on line 9233-8132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3646
% INFO    : Updated Thermal Rating: on line 4064-7362 : Rate B, Rate C , 0.0, 0.0 -> 4297
% INFO    : Updated Thermal Rating: on line 7362-9233 : Rate B, Rate C , 0.0, 0.0 -> 4588
% INFO    : Updated Thermal Rating: on line 4064-7362 : Rate B, Rate C , 0.0, 0.0 -> 4634
% INFO    : Updated Thermal Rating: on line 7362-9233 : Rate B, Rate C , 0.0, 0.0 -> 4945
% INFO    : Updated Thermal Rating: on line 7667-7154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 7154-4064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3651
% INFO    : Updated Thermal Rating: on line 7154-4064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3589
% INFO    : Updated Thermal Rating: on line 9233-3977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7039
% INFO    : Updated Thermal Rating: on line 9233-4892 : Rate B, Rate C , 0.0, 0.0 -> 11587
% INFO    : Updated Thermal Rating: on line 6214-1932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 5698-1932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 6214-3089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 3089-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 3089-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 213-3089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 82-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 5201-5020 : Rate B, Rate C , 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on line 8496-5020 : Rate B, Rate C , 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 7721-213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 8496-4810 : Rate B, Rate C , 0.0, 0.0 -> 1051
% INFO    : Updated Thermal Rating: on line 2729-5752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 2729-5752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 2729-5752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 2729-4270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 2729-4270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 246-3888 : Rate B, Rate C , 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 246-3888 : Rate B, Rate C , 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 5201-246 : Rate B, Rate C , 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 5752-6862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 6862-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 9122-3262 : Rate B, Rate C , 0.0, 0.0 -> 3150
% INFO    : Updated Thermal Rating: on line 4270-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 4270-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 9122-7674 : Rate B, Rate C , 0.0, 0.0 -> 2090
% INFO    : Updated Thermal Rating: on line 5698-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 3618-2417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 5251-2417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 5901-5542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 1182-5542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 7330-8344 : Rate B, Rate C , 0.0, 0.0 -> 2241
% INFO    : Updated Thermal Rating: on line 7330-3259 : Rate B, Rate C , 0.0, 0.0 -> 1896
% INFO    : Updated Thermal Rating: on line 7033-8469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on line 7033-8469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on line 2048-8469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1355
% INFO    : Updated Thermal Rating: on line 64-8469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 6752-8469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 7033-7533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1131
% INFO    : Updated Thermal Rating: on line 2048-7033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 3516-7033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 3516-7033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 2048-7533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1395
% INFO    : Updated Thermal Rating: on line 2162-2048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 2950-3875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 1182-3875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 4713-3875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 3053-5901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 3259-8344 : Rate B, Rate C , 0.0, 0.0 -> 2100
% INFO    : Updated Thermal Rating: on line 3146-8344 : Rate B, Rate C , 0.0, 0.0 -> 4596
% INFO    : Updated Thermal Rating: on line 4760-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 4760-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on line 6500-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 909-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 909-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 8464-2950 : Rate B, Rate C , 0.0, 0.0 -> 8696
% INFO    : Updated Thermal Rating: on line 2950-7557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4760-8119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2020
% INFO    : Updated Thermal Rating: on line 6573-1283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 2073-1283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 4309-1736 : Rate B, Rate C , 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 3618-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 5197-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 8495-2727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 6392-2727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 2727-5251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 8495-6483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 6392-4559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 6392-6573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 6392-1696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19243
% INFO    : Updated Thermal Rating: on line 64-6500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 8119-6500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1166
% INFO    : Updated Thermal Rating: on line 6500-3796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 6483-4705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 6752-4705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5593-5561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5593-5561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 2280-5561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 2062-5036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 5036-6122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 2073-5036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 6721-8513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 8767-8513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 3575-6721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2175
% INFO    : Updated Thermal Rating: on line 418-6721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 6573-6721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 418-3575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1765
% INFO    : Updated Thermal Rating: on line 48-3575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 6573-3897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1731
% INFO    : Updated Thermal Rating: on line 3897-1710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 2062-4559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2280-3053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 3014-8453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2585
% INFO    : Updated Thermal Rating: on line 3516-8453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2206
% INFO    : Updated Thermal Rating: on line 2162-3014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5197-3516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 5593-4694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 7272-4694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 6122-6483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 7648-1710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 7272-7648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 4703-5524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 5524-5251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 1830-64 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4746
% INFO    : Updated Thermal Rating: on line 7286-64 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 6784-1830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2609
% INFO    : Updated Thermal Rating: on line 6784-7286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 5593-8767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 2717-1182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 1710-48 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 2073-4559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 6860-8859 : Rate B, Rate C , 0.0, 0.0 -> 593
% INFO    : Updated Thermal Rating: on line 1710-6573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 8967-6573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2122
% INFO    : Updated Thermal Rating: on line 121-6573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 6573-4309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4333
% INFO    : Updated Thermal Rating: on line 6573-4309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4420
% INFO    : Updated Thermal Rating: on line 6573-4309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4263
% INFO    : Updated Thermal Rating: on line 6573-4309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4350
% INFO    : Updated Thermal Rating: on line 1710-2073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 4208-3259 : Rate B, Rate C , 0.0, 0.0 -> 10345
% INFO    : Updated Thermal Rating: on line 3618-5251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 4713-5593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1691
% INFO    : Updated Thermal Rating: on line 909-2717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4760
% INFO    : Updated Thermal Rating: on line 909-7557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 3882-1696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 4703-3882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3476
% INFO    : Updated Thermal Rating: on line 3882-5251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 121-8967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 5499-7272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2914
% INFO    : Updated Thermal Rating: on line 5499-8425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4201
% INFO    : Updated Thermal Rating: on line 8425-7272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9036
% INFO    : Updated Thermal Rating: on line 3796-8425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 6000-1689 : Rate B, Rate C , 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 4192-8230 : Rate B, Rate C , 0.0, 0.0 -> 1788
% INFO    : Updated Thermal Rating: on line 8814-2030 : Rate B, Rate C , 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 8832-2180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12505
% INFO    : Updated Thermal Rating: on line 8832-3771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58713
% INFO    : Updated Thermal Rating: on line 6395-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 6395-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on line 5255-6395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3255
% INFO    : Updated Thermal Rating: on line 5255-6395 : Rate B, Rate C , 0.0, 0.0 -> 3323
% INFO    : Updated Thermal Rating: on line 3397-5247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33791
% INFO    : Updated Thermal Rating: on line 1207-5247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2021
% INFO    : Updated Thermal Rating: on line 3397-7958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34103
% INFO    : Updated Thermal Rating: on line 1207-7958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2176
% INFO    : Updated Thermal Rating: on line 8389-5526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 91-722 : Rate B, Rate C , 0.0, 0.0 -> 43072
% INFO    : Updated Thermal Rating: on line 1207-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2347
% INFO    : Updated Thermal Rating: on line 9083-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 3363-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4018
% INFO    : Updated Thermal Rating: on line 6539-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3459
% INFO    : Updated Thermal Rating: on line 5792-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1468
% INFO    : Updated Thermal Rating: on line 3363-8356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3557
% INFO    : Updated Thermal Rating: on line 6539-8356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3727
% INFO    : Updated Thermal Rating: on line 5792-8356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 8828-5740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 3443-8828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4191
% INFO    : Updated Thermal Rating: on line 7701-8828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20873
% INFO    : Updated Thermal Rating: on line 2619-8167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 244-2619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3749
% INFO    : Updated Thermal Rating: on line 7701-2619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21259
% INFO    : Updated Thermal Rating: on line 1810-4740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 5279-7525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2180-7374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2102
% INFO    : Updated Thermal Rating: on line 164-8490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 164-2180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27021
% INFO    : Updated Thermal Rating: on line 164-7596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9098
% INFO    : Updated Thermal Rating: on line 164-2708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9741
% INFO    : Updated Thermal Rating: on line 3119-7059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8989
% INFO    : Updated Thermal Rating: on line 3119-7059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9155
% INFO    : Updated Thermal Rating: on line 7596-2708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5690
% INFO    : Updated Thermal Rating: on line 7596-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on line 7596-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 7394-7575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on line 7394-7575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 7394-4415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 7394-4686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 5783-7575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 5783-7575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 6823-6202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7834
% INFO    : Updated Thermal Rating: on line 6823-6202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7911
% INFO    : Updated Thermal Rating: on line 2330-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 712-4272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 606
% INFO    : Updated Thermal Rating: on line 712-4272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 878-3206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on line 7090-3206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 7844-3206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 3497-6202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 3497-6202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 3497-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2636
% INFO    : Updated Thermal Rating: on line 3497-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2843
% INFO    : Updated Thermal Rating: on line 5426-9120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6611
% INFO    : Updated Thermal Rating: on line 133-9120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7317
% INFO    : Updated Thermal Rating: on line 6323-9120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on line 5426-3047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6492
% INFO    : Updated Thermal Rating: on line 275-3047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 133-3047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7404
% INFO    : Updated Thermal Rating: on line 4188-1880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2808
% INFO    : Updated Thermal Rating: on line 3898-4188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 486-5740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21658
% INFO    : Updated Thermal Rating: on line 5740-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1793
% INFO    : Updated Thermal Rating: on line 486-8167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22108
% INFO    : Updated Thermal Rating: on line 8167-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1932
% INFO    : Updated Thermal Rating: on line 9094-8463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5484
% INFO    : Updated Thermal Rating: on line 9094-8994 : Rate B, Rate C , 0.0, 0.0 -> 4279
% INFO    : Updated Thermal Rating: on line 6354-9094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2322
% INFO    : Updated Thermal Rating: on line 9094-1936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5449
% INFO    : Updated Thermal Rating: on line 3280-6423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1089
% INFO    : Updated Thermal Rating: on line 2055-6423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34727
% INFO    : Updated Thermal Rating: on line 6275-6423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2342
% INFO    : Updated Thermal Rating: on line 7138-5618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 2055-5618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31394
% INFO    : Updated Thermal Rating: on line 6275-5618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2133
% INFO    : Updated Thermal Rating: on line 6288-3456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3218
% INFO    : Updated Thermal Rating: on line 2745-3456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26113
% INFO    : Updated Thermal Rating: on line 3301-3456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4795
% INFO    : Updated Thermal Rating: on line 2745-3280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23441
% INFO    : Updated Thermal Rating: on line 3301-3280 : Rate B, Rate C , 0.0, 0.0 -> 4881
% INFO    : Updated Thermal Rating: on line 790-6600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26368
% INFO    : Updated Thermal Rating: on line 472-8889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2157
% INFO    : Updated Thermal Rating: on line 472-775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6356-3443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4737
% INFO    : Updated Thermal Rating: on line 8164-3443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22534
% INFO    : Updated Thermal Rating: on line 6356-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4654
% INFO    : Updated Thermal Rating: on line 8164-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20195
% INFO    : Updated Thermal Rating: on line 8814-5320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on line 8814-5320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 1255-143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 1255-3974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1569
% INFO    : Updated Thermal Rating: on line 8016-1255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1482
% INFO    : Updated Thermal Rating: on line 8016-1255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 1255-4362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 950-5792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1554
% INFO    : Updated Thermal Rating: on line 950-5792 : Rate B, Rate C , 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 3397-6045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6288-7138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on line 6057-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 6057-6559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1829
% INFO    : Updated Thermal Rating: on line 656-1392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 6835-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 351-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 1392-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68520
% INFO    : Updated Thermal Rating: on line 1392-2824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5635
% INFO    : Updated Thermal Rating: on line 1052-1392 : Rate B, Rate C , 0.0, 0.0 -> 1387
% INFO    : Updated Thermal Rating: on line 3538-140 : Rate B, Rate C , 0.0, 0.0 -> 5757
% INFO    : Updated Thermal Rating: on line 3878-3538 : Rate B, Rate C , 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 5001-8862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 5001-8862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 1810-6342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3361
% INFO    : Updated Thermal Rating: on line 1777-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1142
% INFO    : Updated Thermal Rating: on line 1352-6559 : Rate B, Rate C , 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 1352-643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1349
% INFO    : Updated Thermal Rating: on line 1352-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 1352-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3746
% INFO    : Updated Thermal Rating: on line 1670-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2550
% INFO    : Updated Thermal Rating: on line 1670-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2257
% INFO    : Updated Thermal Rating: on line 1352-7628 : Rate B, Rate C , 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 1352-311 : Rate B, Rate C , 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 6998-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5008-8249 : Rate B, Rate C , 0.0, 0.0 -> 10075
% INFO    : Updated Thermal Rating: on line 6068-8249 : Rate B, Rate C , 0.0, 0.0 -> 4092
% INFO    : Updated Thermal Rating: on line 6139-5450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1016
% INFO    : Updated Thermal Rating: on line 6139-5450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1033
% INFO    : Updated Thermal Rating: on line 344-6139 : Rate B, Rate C , 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 344-6139 : Rate B, Rate C , 0.0, 0.0 -> 1400
% INFO    : Updated Thermal Rating: on line 8881-7751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 8881-6559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8986
% INFO    : Updated Thermal Rating: on line 8881-5342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on line 8881-6399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2878
% INFO    : Updated Thermal Rating: on line 1670-8881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 8881-9083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 5279-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 5279-1123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 5279-1633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42268
% INFO    : Updated Thermal Rating: on line 5279-1633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43011
% INFO    : Updated Thermal Rating: on line 5279-2812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36580
% INFO    : Updated Thermal Rating: on line 5279-9029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11925
% INFO    : Updated Thermal Rating: on line 5279-6149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13827
% INFO    : Updated Thermal Rating: on line 5279-6149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12858
% INFO    : Updated Thermal Rating: on line 5279-4616 : Rate B, Rate C , 0.0, 0.0 -> 9709
% INFO    : Updated Thermal Rating: on line 1777-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 5296-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 2478-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 2478-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on line 2350-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2479
% INFO    : Updated Thermal Rating: on line 6354-8463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 6354-8994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5455
% INFO    : Updated Thermal Rating: on line 8994-7476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6446
% INFO    : Updated Thermal Rating: on line 8994-7476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6362
% INFO    : Updated Thermal Rating: on line 3023-806 : Rate B, Rate C , 0.0, 0.0 -> 4207
% INFO    : Updated Thermal Rating: on line 5674-806 : Rate B, Rate C , 0.0, 0.0 -> 2964
% INFO    : Updated Thermal Rating: on line 2240-8991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 539-2240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7313
% INFO    : Updated Thermal Rating: on line 539-2240 : Rate B, Rate C , 0.0, 0.0 -> 7397
% INFO    : Updated Thermal Rating: on line 8814-5426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2464
% INFO    : Updated Thermal Rating: on line 8814-5426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2418
% INFO    : Updated Thermal Rating: on line 5748-1046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59281
% INFO    : Updated Thermal Rating: on line 5748-1046 : Rate B, Rate C , 0.0, 0.0 -> 60257
% INFO    : Updated Thermal Rating: on line 5748-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 5748-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 5748-6824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3320
% INFO    : Updated Thermal Rating: on line 5748-6824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3271
% INFO    : Updated Thermal Rating: on line 5748-6275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3544
% INFO    : Updated Thermal Rating: on line 5748-6275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3614
% INFO    : Updated Thermal Rating: on line 2974-3301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 1670-2974 : Rate B, Rate C , 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 6998-8875 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 1747-593 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 593-8230 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 6998-8772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 6998-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 6998-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2099
% INFO    : Updated Thermal Rating: on line 6998-5031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5478
% INFO    : Updated Thermal Rating: on line 6998-5031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5390
% INFO    : Updated Thermal Rating: on line 6998-3299 : Rate B, Rate C , 0.0, 0.0 -> 4046
% INFO    : Updated Thermal Rating: on line 6998-3299 : Rate B, Rate C , 0.0, 0.0 -> 4133
% INFO    : Updated Thermal Rating: on line 6998-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 6998-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on line 6998-1464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 6998-1464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 1221-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2732
% INFO    : Updated Thermal Rating: on line 1221-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2791
% INFO    : Updated Thermal Rating: on line 2305-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2159
% INFO    : Updated Thermal Rating: on line 2305-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2205
% INFO    : Updated Thermal Rating: on line 199-7195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6757
% INFO    : Updated Thermal Rating: on line 52-199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 4964-8432 : Rate B, Rate C , 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 8432-3190 : Rate B, Rate C , 0.0, 0.0 -> 2650
% INFO    : Updated Thermal Rating: on line 8432-3352 : Rate B, Rate C , 0.0, 0.0 -> 9965
% INFO    : Updated Thermal Rating: on line 4964-3484 : Rate B, Rate C , 0.0, 0.0 -> 2708
% INFO    : Updated Thermal Rating: on line 4964-6766 : Rate B, Rate C , 0.0, 0.0 -> 9781
% INFO    : Updated Thermal Rating: on line 838-6295 : Rate B, Rate C , 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 3190-3484 : Rate B, Rate C , 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 3190-6263 : Rate B, Rate C , 0.0, 0.0 -> 9621
% INFO    : Updated Thermal Rating: on line 395-3190 : Rate B, Rate C , 0.0, 0.0 -> 10047
% INFO    : Updated Thermal Rating: on line 3484-6068 : Rate B, Rate C , 0.0, 0.0 -> 9827
% INFO    : Updated Thermal Rating: on line 5843-3484 : Rate B, Rate C , 0.0, 0.0 -> 10239
% INFO    : Updated Thermal Rating: on line 3210-4021 : Rate B, Rate C , 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on line 1670-7425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 2381-5772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2037
% INFO    : Updated Thermal Rating: on line 281-8086 : Rate B, Rate C , 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 281-6068 : Rate B, Rate C , 0.0, 0.0 -> 11190
% INFO    : Updated Thermal Rating: on line 4077-281 : Rate B, Rate C , 0.0, 0.0 -> 4456
% INFO    : Updated Thermal Rating: on line 8086-6263 : Rate B, Rate C , 0.0, 0.0 -> 12088
% INFO    : Updated Thermal Rating: on line 5888-8086 : Rate B, Rate C , 0.0, 0.0 -> 4369
% INFO    : Updated Thermal Rating: on line 1477-5255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11389
% INFO    : Updated Thermal Rating: on line 3960-5255 : Rate B, Rate C , 0.0, 0.0 -> 11593
% INFO    : Updated Thermal Rating: on line 8037-5255 : Rate B, Rate C , 0.0, 0.0 -> 11845
% INFO    : Updated Thermal Rating: on line 1989-1597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 6923-1597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 676-8706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 8706-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 8706-4362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2136
% INFO    : Updated Thermal Rating: on line 8706-4362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2177
% INFO    : Updated Thermal Rating: on line 7584-7736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 7584-5591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 7584-5364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 4774-7584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 4774-7584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 5255-2796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17383
% INFO    : Updated Thermal Rating: on line 5255-2796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17554
% INFO    : Updated Thermal Rating: on line 8642-5255 : Rate B, Rate C , 0.0, 0.0 -> 6295
% INFO    : Updated Thermal Rating: on line 5255-2703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 650-4104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 1989-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 4130-1635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6167-4130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6167-5872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2058
% INFO    : Updated Thermal Rating: on line 4130-496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1580
% INFO    : Updated Thermal Rating: on line 4130-5872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1831
% INFO    : Updated Thermal Rating: on line 6582-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2507
% INFO    : Updated Thermal Rating: on line 6582-4082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4046
% INFO    : Updated Thermal Rating: on line 6582-5246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3601
% INFO    : Updated Thermal Rating: on line 496-5872 : Rate B, Rate C , 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 6047-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2077-9063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3224-8044 : Rate B, Rate C , 0.0, 0.0 -> 19555
% INFO    : Updated Thermal Rating: on line 76-5742 : Rate B, Rate C , 0.0, 0.0 -> 32401
% INFO    : Updated Thermal Rating: on line 38-5742 : Rate B, Rate C , 0.0, 0.0 -> 34833
% INFO    : Updated Thermal Rating: on line 8814-9118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 5008-919 : Rate B, Rate C , 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 1788-5008 : Rate B, Rate C , 0.0, 0.0 -> 3038
% INFO    : Updated Thermal Rating: on line 662-5008 : Rate B, Rate C , 0.0, 0.0 -> 10643
% INFO    : Updated Thermal Rating: on line 8604-919 : Rate B, Rate C , 0.0, 0.0 -> 2984
% INFO    : Updated Thermal Rating: on line 6354-4295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 6354-5203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 6354-5203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1659
% INFO    : Updated Thermal Rating: on line 6354-472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 6354-7476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4603
% INFO    : Updated Thermal Rating: on line 6354-7476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4686
% INFO    : Updated Thermal Rating: on line 6354-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on line 6354-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 6354-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 1020-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 3182-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 4825-3023 : Rate B, Rate C , 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 4825-6345 : Rate B, Rate C , 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 4825-8114 : Rate B, Rate C , 0.0, 0.0 -> 3709
% INFO    : Updated Thermal Rating: on line 4825-3210 : Rate B, Rate C , 0.0, 0.0 -> 1806
% INFO    : Updated Thermal Rating: on line 3023-6345 : Rate B, Rate C , 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 3023-8773 : Rate B, Rate C , 0.0, 0.0 -> 3789
% INFO    : Updated Thermal Rating: on line 7884-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on line 7884-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1318
% INFO    : Updated Thermal Rating: on line 7884-6202 : Rate B, Rate C , 0.0, 0.0 -> 2119
% INFO    : Updated Thermal Rating: on line 7884-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 7884-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on line 7884-7305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7352
% INFO    : Updated Thermal Rating: on line 7884-7305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6881
% INFO    : Updated Thermal Rating: on line 7884-6987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 7884-6987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1036
% INFO    : Updated Thermal Rating: on line 7884-4774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1349
% INFO    : Updated Thermal Rating: on line 7884-3620 : Rate B, Rate C , 0.0, 0.0 -> 1509
% INFO    : Updated Thermal Rating: on line 3119-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1964
% INFO    : Updated Thermal Rating: on line 585-3148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 1106-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on line 6987-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 7275-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 8114-8773 : Rate B, Rate C , 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 8393-8114 : Rate B, Rate C , 0.0, 0.0 -> 2658
% INFO    : Updated Thermal Rating: on line 139-8773 : Rate B, Rate C , 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 676-6439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 8738-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9887
% INFO    : Updated Thermal Rating: on line 8738-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9717
% INFO    : Updated Thermal Rating: on line 676-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 8862-6915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 8862-9205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 6393-4057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 6028-6393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 4872-6393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 6393-7136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 2769-6118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 76-2769 : Rate B, Rate C , 0.0, 0.0 -> 21010
% INFO    : Updated Thermal Rating: on line 38-6118 : Rate B, Rate C , 0.0, 0.0 -> 29290
% INFO    : Updated Thermal Rating: on line 3224-7117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1763
% INFO    : Updated Thermal Rating: on line 3224-8525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on line 3224-5346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19813
% INFO    : Updated Thermal Rating: on line 4993-3335 : Rate B, Rate C , 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 6832-4797 : Rate B, Rate C , 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 6489-4797 : Rate B, Rate C , 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on line 8284-4797 : Rate B, Rate C , 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 577-1362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1982
% INFO    : Updated Thermal Rating: on line 268-1057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 2728-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 8662-8298 : Rate B, Rate C , 0.0, 0.0 -> 1094
% INFO    : Updated Thermal Rating: on line 6884-4059 : Rate B, Rate C , 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on line 3723-3335 : Rate A, Rate B, Rate C , 1876.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 1890-3335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1138
% INFO    : Updated Thermal Rating: on line 71-8141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 7295-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1515
% INFO    : Updated Thermal Rating: on line 71-7297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 4797-8298 : Rate B, Rate C , 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 4797-4059 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 4797-7388 : Rate B, Rate C , 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 4797-2002 : Rate B, Rate C , 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 2448-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 2448-1057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60629
% INFO    : Updated Thermal Rating: on line 2448-6282 : Rate B, Rate C , 0.0, 0.0 -> 59487
% INFO    : Updated Thermal Rating: on line 2448-4340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58604
% INFO    : Updated Thermal Rating: on line 3335-8298 : Rate B, Rate C , 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 3335-4059 : Rate B, Rate C , 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 3335-7388 : Rate B, Rate C , 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 3335-2002 : Rate B, Rate C , 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 326-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 326-1057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 326-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65945
% INFO    : Updated Thermal Rating: on line 326-4340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67351
% INFO    : Updated Thermal Rating: on line 4858-8298 : Rate B, Rate C , 0.0, 0.0 -> 5789
% INFO    : Updated Thermal Rating: on line 2523-5979 : Rate B, Rate C , 0.0, 0.0 -> 68520
% INFO    : Updated Thermal Rating: on line 1057-1362 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 1956-7388 : Rate B, Rate C , 0.0, 0.0 -> 5119
% INFO    : Updated Thermal Rating: on line 5299-2002 : Rate B, Rate C , 0.0, 0.0 -> 1161
% INFO    : Updated Thermal Rating: on line 4340-1052 : Rate B, Rate C , 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 6662-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5165-2722 : Rate B, Rate C , 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 5165-1689 : Rate B, Rate C , 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 5165-3210 : Rate B, Rate C , 0.0, 0.0 -> 3472
% INFO    : Updated Thermal Rating: on line 2722-1689 : Rate B, Rate C , 0.0, 0.0 -> 2699
% INFO    : Updated Thermal Rating: on line 2722-8230 : Rate B, Rate C , 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 2722-5674 : Rate B, Rate C , 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 3363-7195 : Rate B, Rate C , 0.0, 0.0 -> 3436
% INFO    : Updated Thermal Rating: on line 3363-7195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3373
% INFO    : Updated Thermal Rating: on line 7195-8977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6201
% INFO    : Updated Thermal Rating: on line 52-7195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 7195-3868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1929
% INFO    : Updated Thermal Rating: on line 3363-392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 3363-3530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 3363-3530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2401
% INFO    : Updated Thermal Rating: on line 3363-5829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 8977-6539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7117
% INFO    : Updated Thermal Rating: on line 7675-6539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 7675-6539 : Rate B, Rate C , 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 1702-2900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 6202-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2101
% INFO    : Updated Thermal Rating: on line 6202-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2145
% INFO    : Updated Thermal Rating: on line 1106-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 1106-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 5916-6342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5590
% INFO    : Updated Thermal Rating: on line 4302-6342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 733-8917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 5423-8917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 1777-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2836
% INFO    : Updated Thermal Rating: on line 548-6923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 9029-8508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 1591-5558 : Rate B, Rate C , 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 1591-8604 : Rate B, Rate C , 0.0, 0.0 -> 8585
% INFO    : Updated Thermal Rating: on line 1591-8264 : Rate B, Rate C , 0.0, 0.0 -> 4974
% INFO    : Updated Thermal Rating: on line 1124-8510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 1124-3257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2015
% INFO    : Updated Thermal Rating: on line 5311-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 5558-1788 : Rate B, Rate C , 0.0, 0.0 -> 7586
% INFO    : Updated Thermal Rating: on line 8211-5558 : Rate B, Rate C , 0.0, 0.0 -> 4875
% INFO    : Updated Thermal Rating: on line 8510-369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2057
% INFO    : Updated Thermal Rating: on line 3891-8510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 5952-784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 5952-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4099
% INFO    : Updated Thermal Rating: on line 5952-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4134
% INFO    : Updated Thermal Rating: on line 6923-5108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4417
% INFO    : Updated Thermal Rating: on line 5829-392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 1633-8389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1439
% INFO    : Updated Thermal Rating: on line 1633-8389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 8389-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2980
% INFO    : Updated Thermal Rating: on line 8389-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2552
% INFO    : Updated Thermal Rating: on line 8389-4409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 3119-2572 : Rate B, Rate C , 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 4318-7404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3405
% INFO    : Updated Thermal Rating: on line 4318-1338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7613
% INFO    : Updated Thermal Rating: on line 4318-8288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 7404-8882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25816
% INFO    : Updated Thermal Rating: on line 7404-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 1338-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4001
% INFO    : Updated Thermal Rating: on line 360-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 275-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1652
% INFO    : Updated Thermal Rating: on line 5872-7230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 8194-5872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 1020-6514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1630
% INFO    : Updated Thermal Rating: on line 1020-387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1106-6838 : Rate B, Rate C , 0.0, 0.0 -> 16802
% INFO    : Updated Thermal Rating: on line 8480-6025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24710
% INFO    : Updated Thermal Rating: on line 9029-5835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16377
% INFO    : Updated Thermal Rating: on line 3374-878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 7450-3374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 7450-3374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 6383-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 2228-6383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 2228-6383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 1010-6383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 2228-8878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 2228-8878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 2228-7117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 2228-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 8277-2228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 8277-2228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 4057-5783 : Rate B, Rate C , 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 7136-4057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 609
% INFO    : Updated Thermal Rating: on line 5549-1207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2582
% INFO    : Updated Thermal Rating: on line 5549-9083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 2745-7138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 2745-7138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 1670-2745 : Rate B, Rate C , 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 1670-2745 : Rate B, Rate C , 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 2745-8492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1728
% INFO    : Updated Thermal Rating: on line 2745-2748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3983
% INFO    : Updated Thermal Rating: on line 2745-3215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3288
% INFO    : Updated Thermal Rating: on line 6915-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 544
% INFO    : Updated Thermal Rating: on line 3177-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 1464-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 1689-8230 : Rate B, Rate C , 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 6068-1689 : Rate B, Rate C , 0.0, 0.0 -> 4597
% INFO    : Updated Thermal Rating: on line 6263-8230 : Rate B, Rate C , 0.0, 0.0 -> 4506
% INFO    : Updated Thermal Rating: on line 8814-69 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 8814-5949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 8814-5949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 8814-8613 : Rate B, Rate C , 0.0, 0.0 -> 2633
% INFO    : Updated Thermal Rating: on line 8814-9007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 8814-5188 : Rate B, Rate C , 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on line 2077-6442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7019
% INFO    : Updated Thermal Rating: on line 2077-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6477
% INFO    : Updated Thermal Rating: on line 2812-1778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2812-1633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142169
% INFO    : Updated Thermal Rating: on line 3983-1633 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7442-1633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7297
% INFO    : Updated Thermal Rating: on line 6047-5271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12650
% INFO    : Updated Thermal Rating: on line 6047-5271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11902
% INFO    : Updated Thermal Rating: on line 211-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4132-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 4132-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 2804-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 4216-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20172
% INFO    : Updated Thermal Rating: on line 6028-4872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 6028-9146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 6028-9146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 6058-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 6058-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 6028-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 6028-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 7295-5595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on line 5595-7297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 5595-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 2616-5595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on line 5595-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 1989-4104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 1889-4104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2006
% INFO    : Updated Thermal Rating: on line 312-5783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26367
% INFO    : Updated Thermal Rating: on line 8393-139 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 8393-8264 : Rate B, Rate C , 0.0, 0.0 -> 2693
% INFO    : Updated Thermal Rating: on line 139-8211 : Rate B, Rate C , 0.0, 0.0 -> 2642
% INFO    : Updated Thermal Rating: on line 6600-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4752
% INFO    : Updated Thermal Rating: on line 6600-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4829
% INFO    : Updated Thermal Rating: on line 2555-6600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24150
% INFO    : Updated Thermal Rating: on line 5783-7565 : Rate B, Rate C , 0.0, 0.0 -> 3935
% INFO    : Updated Thermal Rating: on line 5783-7565 : Rate B, Rate C , 0.0, 0.0 -> 4244
% INFO    : Updated Thermal Rating: on line 5783-2648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 5783-2648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 1989-6923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 1989-8480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2028
% INFO    : Updated Thermal Rating: on line 2478-1989 : Rate B, Rate C , 0.0, 0.0 -> 4258
% INFO    : Updated Thermal Rating: on line 523-5760 : Rate B, Rate C , 0.0, 0.0 -> 7426
% INFO    : Updated Thermal Rating: on line 523-5760 : Rate B, Rate C , 0.0, 0.0 -> 7495
% INFO    : Updated Thermal Rating: on line 523-5760 : Rate B, Rate C , 0.0, 0.0 -> 7045
% INFO    : Updated Thermal Rating: on line 523-7476 : Rate B, Rate C , 0.0, 0.0 -> 7409
% INFO    : Updated Thermal Rating: on line 69-7852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2115
% INFO    : Updated Thermal Rating: on line 1670-5342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 9206-4757 : Rate B, Rate C , 0.0, 0.0 -> 1988
% INFO    : Updated Thermal Rating: on line 9206-4757 : Rate B, Rate C , 0.0, 0.0 -> 2141
% INFO    : Updated Thermal Rating: on line 1880-4380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2157
% INFO    : Updated Thermal Rating: on line 3530-1880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9749
% INFO    : Updated Thermal Rating: on line 3530-4687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 3530-1330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 7295-8442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12376
% INFO    : Updated Thermal Rating: on line 7297-8442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12458
% INFO    : Updated Thermal Rating: on line 6399-9083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1796
% INFO    : Updated Thermal Rating: on line 898-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2525
% INFO    : Updated Thermal Rating: on line 898-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 3257-369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60629
% INFO    : Updated Thermal Rating: on line 2381-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 2381-297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 2381-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5829-4692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 5829-69 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7004
% INFO    : Updated Thermal Rating: on line 5829-3898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 5829-3898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 756
% INFO    : Updated Thermal Rating: on line 5188-5829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1234
% INFO    : Updated Thermal Rating: on line 4272-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2199
% INFO    : Updated Thermal Rating: on line 472-6131 : Rate B, Rate C , 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 8565-472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 472-5760 : Rate B, Rate C , 0.0, 0.0 -> 9746
% INFO    : Updated Thermal Rating: on line 472-5760 : Rate B, Rate C , 0.0, 0.0 -> 9916
% INFO    : Updated Thermal Rating: on line 472-5760 : Rate B, Rate C , 0.0, 0.0 -> 8979
% INFO    : Updated Thermal Rating: on line 472-7073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2042
% INFO    : Updated Thermal Rating: on line 472-349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 472-7156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 6202-7305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3263
% INFO    : Updated Thermal Rating: on line 6202-7305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3222
% INFO    : Updated Thermal Rating: on line 643-311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2416
% INFO    : Updated Thermal Rating: on line 6068-6263 : Rate B, Rate C , 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 6017-6263 : Rate B, Rate C , 0.0, 0.0 -> 2382
% INFO    : Updated Thermal Rating: on line 7450-2271 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7450-7666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2799
% INFO    : Updated Thermal Rating: on line 7450-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1041
% INFO    : Updated Thermal Rating: on line 8784-7450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3018
% INFO    : Updated Thermal Rating: on line 2271-3846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142169
% INFO    : Updated Thermal Rating: on line 2271-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 3846-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 733-5423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 4614-733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 8492-3216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3326
% INFO    : Updated Thermal Rating: on line 2748-3216 : Rate B, Rate C , 0.0, 0.0 -> 2982
% INFO    : Updated Thermal Rating: on line 3215-3216 : Rate B, Rate C , 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 8878-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 8878-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 2760-8016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2582
% INFO    : Updated Thermal Rating: on line 2760-8016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 1913-2120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8155-1913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2481
% INFO    : Updated Thermal Rating: on line 8155-1913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2527
% INFO    : Updated Thermal Rating: on line 1913-7090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on line 1913-7090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 1913-7844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on line 4413-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 4413-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 8738-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 8738-2760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 8738-2760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 8738-6218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1352
% INFO    : Updated Thermal Rating: on line 1788-8604 : Rate B, Rate C , 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 1020-2335 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1020-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 2616-1020 : Rate B, Rate C , 0.0, 0.0 -> 3569
% INFO    : Updated Thermal Rating: on line 1020-9072 : Rate B, Rate C , 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 7138-7586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 2648-8288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3086
% INFO    : Updated Thermal Rating: on line 2824-140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59487
% INFO    : Updated Thermal Rating: on line 2824-5311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1993
% INFO    : Updated Thermal Rating: on line 140-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 211-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 211-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 211-2804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1268
% INFO    : Updated Thermal Rating: on line 1670-3301 : Rate B, Rate C , 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 344-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 243-8621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3210-5674 : Rate B, Rate C , 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 3210-4337 : Rate B, Rate C , 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 1670-8204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3028
% INFO    : Updated Thermal Rating: on line 1670-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2946
% INFO    : Updated Thermal Rating: on line 5949-6480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 5949-5655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 1464-3177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2298
% INFO    : Updated Thermal Rating: on line 5949-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 5949-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 1956-4858 : Rate B, Rate C , 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 1956-8264 : Rate B, Rate C , 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 4320-4248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58604
% INFO    : Updated Thermal Rating: on line 4320-76 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2236
% INFO    : Updated Thermal Rating: on line 4858-8211 : Rate B, Rate C , 0.0, 0.0 -> 1938
% INFO    : Updated Thermal Rating: on line 4248-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1977
% INFO    : Updated Thermal Rating: on line 4302-999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 4302-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 4302-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on line 8204-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9475
% INFO    : Updated Thermal Rating: on line 5792-2428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 344-1277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 344-2117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 344-8895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 4132-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 4132-1787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 2331-8380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18078
% INFO    : Updated Thermal Rating: on line 5296-8380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6280
% INFO    : Updated Thermal Rating: on line 999-8380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 9029-7915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9029-6149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50125
% INFO    : Updated Thermal Rating: on line 3968-3370 : Rate B, Rate C , 0.0, 0.0 -> 1750
% INFO    : Updated Thermal Rating: on line 7480-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2150-6687 : Rate B, Rate C , 0.0, 0.0 -> 1789
% INFO    : Updated Thermal Rating: on line 8956-4209 : Rate B, Rate C , 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 5065-8318 : Rate A, Rate B, Rate C , 1876.0, 0.0, 0.0 -> 1614
% INFO    : Updated Thermal Rating: on line 7270-3370 : Rate B, Rate C , 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 6424-3370 : Rate B, Rate C , 0.0, 0.0 -> 1553
% INFO    : Updated Thermal Rating: on line 5888-8223 : Rate B, Rate C , 0.0, 0.0 -> 12610
% INFO    : Updated Thermal Rating: on line 4776-3370 : Rate B, Rate C , 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 1331-8318 : Rate B, Rate C , 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 8483-8318 : Rate B, Rate C , 0.0, 0.0 -> 1679
% INFO    : Updated Thermal Rating: on line 6687-4209 : Rate B, Rate C , 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 4733-6687 : Rate B, Rate C , 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 7856-4209 : Rate B, Rate C , 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 3370-5897 : Rate B, Rate C , 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 3370-420 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 3370-8898 : Rate B, Rate C , 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 8318-7856 : Rate B, Rate C , 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 8318-4733 : Rate B, Rate C , 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 8318-8898 : Rate B, Rate C , 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 5897-4087 : Rate B, Rate C , 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 4087-7856 : Rate B, Rate C , 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 4087-4077 : Rate B, Rate C , 0.0, 0.0 -> 7820
% INFO    : Updated Thermal Rating: on line 6283-4087 : Rate B, Rate C , 0.0, 0.0 -> 7966
% INFO    : Updated Thermal Rating: on line 420-2927 : Rate B, Rate C , 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 2927-4733 : Rate B, Rate C , 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 2927-5888 : Rate B, Rate C , 0.0, 0.0 -> 7996
% INFO    : Updated Thermal Rating: on line 4485-2927 : Rate B, Rate C , 0.0, 0.0 -> 7810
% INFO    : Updated Thermal Rating: on line 2720-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 243-558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8492-2748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1486
% INFO    : Updated Thermal Rating: on line 8492-3215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 5760-8392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17144
% INFO    : Updated Thermal Rating: on line 5760-8392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16976
% INFO    : Updated Thermal Rating: on line 5760-8392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18102
% INFO    : Updated Thermal Rating: on line 370-311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2362
% INFO    : Updated Thermal Rating: on line 370-311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2126
% INFO    : Updated Thermal Rating: on line 1106-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6539
% INFO    : Updated Thermal Rating: on line 1106-7275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2688
% INFO    : Updated Thermal Rating: on line 1106-6218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 9206-1936 : Rate B, Rate C , 0.0, 0.0 -> 4392
% INFO    : Updated Thermal Rating: on line 7476-1936 : Rate B, Rate C , 0.0, 0.0 -> 4473
% INFO    : Updated Thermal Rating: on line 4415-9146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 4415-9146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 7729-4415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 5591-5364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3726
% INFO    : Updated Thermal Rating: on line 6047-4431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 6047-4431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 8017-6519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7018-8017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6511
% INFO    : Updated Thermal Rating: on line 2965-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 344-5364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4845
% INFO    : Updated Thermal Rating: on line 344-5364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4307
% INFO    : Updated Thermal Rating: on line 5311-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 9205-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 8668-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 7666-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 7666-1227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 7666-4006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5872-7666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2883
% INFO    : Updated Thermal Rating: on line 6058-1889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 6058-1889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 4272-6747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 4272-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 4272-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 928
% INFO    : Updated Thermal Rating: on line 4272-7951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 4272-7951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 4272-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 4272-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1204
% INFO    : Updated Thermal Rating: on line 4272-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1228
% INFO    : Updated Thermal Rating: on line 3898-1330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1221
% INFO    : Updated Thermal Rating: on line 8613-52 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1653
% INFO    : Updated Thermal Rating: on line 662-3352 : Rate B, Rate C , 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 662-6766 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 6017-3352 : Rate B, Rate C , 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 6017-6766 : Rate B, Rate C , 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 2552-7275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32900
% INFO    : Updated Thermal Rating: on line 8792-3712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 3388-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1362-2523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 1362-1052 : Rate B, Rate C , 0.0, 0.0 -> 1396
% INFO    : Updated Thermal Rating: on line 1362-76 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2464
% INFO    : Updated Thermal Rating: on line 2523-3878 : Rate B, Rate C , 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 2523-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2514
% INFO    : Updated Thermal Rating: on line 194-7018 : Rate B, Rate C , 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 4846-7018 : Rate B, Rate C , 0.0, 0.0 -> 2289
% INFO    : Updated Thermal Rating: on line 3691-7018 : Rate B, Rate C , 0.0, 0.0 -> 2339
% INFO    : Updated Thermal Rating: on line 6323-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 6323-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 5872-6707 : Rate B, Rate C , 0.0, 0.0 -> 15892
% INFO    : Updated Thermal Rating: on line 4863-6707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17637
% INFO    : Updated Thermal Rating: on line 5872-3509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7638
% INFO    : Updated Thermal Rating: on line 5872-3509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7011
% INFO    : Updated Thermal Rating: on line 5872-3776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11524
% INFO    : Updated Thermal Rating: on line 7018-3509 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7018-5974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 8784-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5467
% INFO    : Updated Thermal Rating: on line 7018-4565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2308
% INFO    : Updated Thermal Rating: on line 8058-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6522
% INFO    : Updated Thermal Rating: on line 3509-4863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18040
% INFO    : Updated Thermal Rating: on line 3776-3509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18462
% INFO    : Updated Thermal Rating: on line 4082-6442 : Rate B, Rate C , 0.0, 0.0 -> 6902
% INFO    : Updated Thermal Rating: on line 5246-6442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6774
% INFO    : Updated Thermal Rating: on line 6526-1787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1070
% INFO    : Updated Thermal Rating: on line 4616-7260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 1221-7996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 344-1221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 344-1221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 8525-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 3215-7407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 4686-7729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 52-2494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 52-9007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4778
% INFO    : Updated Thermal Rating: on line 52-928 : Rate B, Rate C , 0.0, 0.0 -> 5704
% INFO    : Updated Thermal Rating: on line 52-928 : Rate B, Rate C , 0.0, 0.0 -> 5754
% INFO    : Updated Thermal Rating: on line 6987-4509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 6987-4509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 3119-6047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2460
% INFO    : Updated Thermal Rating: on line 3119-6047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2417
% INFO    : Updated Thermal Rating: on line 3119-7662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6149-5442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6275-3819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 344-6015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 9083-994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 9206-3169 : Rate B, Rate C , 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 9206-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 9206-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2397
% INFO    : Updated Thermal Rating: on line 9206-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on line 5423-9223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 3314-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 838-7779 : Rate B, Rate C , 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 838-4477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6320-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4774-3620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5869
% INFO    : Updated Thermal Rating: on line 3182-297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 884
% INFO    : Updated Thermal Rating: on line 7476-1463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5906
% INFO    : Updated Thermal Rating: on line 7476-1463 : Rate B, Rate C , 0.0, 0.0 -> 6314
% INFO    : Updated Thermal Rating: on line 1052-3878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65945
% INFO    : Updated Thermal Rating: on line 1052-6477 : Rate B, Rate C , 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 3878-5295 : Rate B, Rate C , 0.0, 0.0 -> 2141
% INFO    : Updated Thermal Rating: on line 8277-5887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on line 8277-9127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 76-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67351
% INFO    : Updated Thermal Rating: on line 3182-1984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 2760-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 2760-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1260
% INFO    : Updated Thermal Rating: on line 9127-5887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 4082-5246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4485-395 : Rate B, Rate C , 0.0, 0.0 -> 20958
% INFO    : Updated Thermal Rating: on line 5843-6283 : Rate B, Rate C , 0.0, 0.0 -> 20835
% INFO    : Updated Thermal Rating: on line 2478-8480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 395-5843 : Rate B, Rate C , 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 6477-5295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68520
% INFO    : Updated Thermal Rating: on line 8264-8211 : Rate B, Rate C , 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 7011-4614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5165
% INFO    : Updated Thermal Rating: on line 4614-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4920
% INFO    : Updated Thermal Rating: on line 6058-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on line 6058-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1687
% INFO    : Updated Thermal Rating: on line 6058-9223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 6058-9223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 7090-7844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2616-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59712
% INFO    : Updated Thermal Rating: on line 9072-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 2305-9072 : Rate B, Rate C , 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 2509-6268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 3039-6268 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 5148-6268 : Rate B, Rate C , 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 3909-6268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 8610-1050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 8610-1050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1001
% INFO    : Updated Thermal Rating: on line 1050-431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 1050-3953 : Rate B, Rate C , 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 1050-4805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 8610-1050 : Rate B, Rate C , 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on line 1050-4805 : Rate B, Rate C , 0.0, 0.0 -> 1207
% INFO    : Updated Thermal Rating: on line 8652-3848 : Rate B, Rate C , 0.0, 0.0 -> 2445
% INFO    : Updated Thermal Rating: on line 3991-3848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 5075-6701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6515
% INFO    : Updated Thermal Rating: on line 2862-8175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6649
% INFO    : Updated Thermal Rating: on line 4581-4595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 8537-4595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 5158-4595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2532
% INFO    : Updated Thermal Rating: on line 8537-4581 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 8758-4581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2486
% INFO    : Updated Thermal Rating: on line 7293-977 : Rate B, Rate C , 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 5310-2453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5310-2453 : Rate A, Rate B, Rate C , 572.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 3616-2453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 734-2453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 734-2453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 1481-2453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 1837-2453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 7551-2453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 4163-5310 : Rate B, Rate C , 0.0, 0.0 -> 2460
% INFO    : Updated Thermal Rating: on line 3616-5310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 734-5310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 1481-5310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 1837-5310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 7551-5310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 5863-3438 : Rate B, Rate C , 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 6100-3438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 2771-3438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 3438-6708 : Rate B, Rate C , 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 3003-3438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 4002-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 638-4002 : Rate B, Rate C , 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 173-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1857
% INFO    : Updated Thermal Rating: on line 173-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 6601-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 3607-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 6591-6287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 587-6287 : Rate B, Rate C , 0.0, 0.0 -> 4656
% INFO    : Updated Thermal Rating: on line 3616-6287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2611
% INFO    : Updated Thermal Rating: on line 9234-6287 : Rate B, Rate C , 0.0, 0.0 -> 5094
% INFO    : Updated Thermal Rating: on line 8971-4163 : Rate B, Rate C , 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 1837-4163 : Rate B, Rate C , 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 5656-4163 : Rate B, Rate C , 0.0, 0.0 -> 2304
% INFO    : Updated Thermal Rating: on line 7984-4163 : Rate B, Rate C , 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 1342-6591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1388
% INFO    : Updated Thermal Rating: on line 5656-6591 : Rate B, Rate C , 0.0, 0.0 -> 2486
% INFO    : Updated Thermal Rating: on line 7551-6591 : Rate B, Rate C , 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 6591-7511 : Rate B, Rate C , 0.0, 0.0 -> 2152
% INFO    : Updated Thermal Rating: on line 6238-3368 : Rate A, Rate B, Rate C , 1152.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 8822-6238 : Rate B, Rate C , 0.0, 0.0 -> 3894
% INFO    : Updated Thermal Rating: on line 7174-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 7174-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1551
% INFO    : Updated Thermal Rating: on line 9040-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on line 7293-6937 : Rate B, Rate C , 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 3909-7293 : Rate B, Rate C , 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 6937-7293 : Rate B, Rate C , 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 6937-7293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 2284-7293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 3039-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 3039-2509 : Rate B, Rate C , 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 2063-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 4002-3251 : Rate B, Rate C , 0.0, 0.0 -> 818
% INFO    : Updated Thermal Rating: on line 173-4002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 6601-4002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 3607-4002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 5479-3797 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1118
% INFO    : Updated Thermal Rating: on line 214-3797 : Rate B, Rate C , 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 7025-8449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 3326-8449 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 7298-8449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 262-8449 : Rate B, Rate C , 0.0, 0.0 -> 1308
% INFO    : Updated Thermal Rating: on line 262-8449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59
% INFO    : Updated Thermal Rating: on line 6169-8449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 5732-2827 : Rate B, Rate C , 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on line 2827-1837 : Rate B, Rate C , 0.0, 0.0 -> 2102
% INFO    : Updated Thermal Rating: on line 214-4533 : Rate B, Rate C , 0.0, 0.0 -> 2150
% INFO    : Updated Thermal Rating: on line 4533-1315 : Rate B, Rate C , 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 4533-8401 : Rate B, Rate C , 0.0, 0.0 -> 1682
% INFO    : Updated Thermal Rating: on line 361-5822 : Rate B, Rate C , 0.0, 0.0 -> 4865
% INFO    : Updated Thermal Rating: on line 2758-361 : Rate B, Rate C , 0.0, 0.0 -> 5432
% INFO    : Updated Thermal Rating: on line 6634-4051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5822-3147 : Rate B, Rate C , 0.0, 0.0 -> 2377
% INFO    : Updated Thermal Rating: on line 3147-3930 : Rate B, Rate C , 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 5822-3147 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on line 1315-9238 : Rate B, Rate C , 0.0, 0.0 -> 4485
% INFO    : Updated Thermal Rating: on line 7890-2274 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 1507-2274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 8764-2274 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 8764-2274 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 764-2274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 5462-4257 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5462-4257 : Rate A, Rate B, Rate C , 987.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 4257-7553 : Rate B, Rate C , 0.0, 0.0 -> 6236
% INFO    : Updated Thermal Rating: on line 4257-5209 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 993-5462 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 5462-2758 : Rate B, Rate C , 0.0, 0.0 -> 1775
% INFO    : Updated Thermal Rating: on line 5640-8387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5640-8387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 8387-7174 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 5640-4051 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 7553-2758 : Rate B, Rate C , 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 328-6829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 4844-6829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 4844-6829 : Rate B, Rate C , 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 7854-6829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 9215-6829 : Rate B, Rate C , 0.0, 0.0 -> 4418
% INFO    : Updated Thermal Rating: on line 4844-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 4844-328 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 578-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 7707-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 7707-328 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 7854-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 7298-328 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 262-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 3219-2771 : Rate B, Rate C , 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 3607-3219 : Rate B, Rate C , 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 3515-4695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3515-4695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 4695-3720 : Rate B, Rate C , 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 3515-9040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 2948-5209 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 2771-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 3616-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 1481-6100 : Rate B, Rate C , 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 1481-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 8330-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 5732-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 3003-6100 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 5863-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 3991-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 3084-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 1481-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 6708-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 7511-6100 : Rate B, Rate C , 0.0, 0.0 -> 1887
% INFO    : Updated Thermal Rating: on line 5139-8652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3555
% INFO    : Updated Thermal Rating: on line 3991-5139 : Rate B, Rate C , 0.0, 0.0 -> 8080
% INFO    : Updated Thermal Rating: on line 6708-8971 : Rate B, Rate C , 0.0, 0.0 -> 3569
% INFO    : Updated Thermal Rating: on line 3084-8971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 5656-8971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 5369-6861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5369-6861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 6861-3015 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 431-6861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 431-6861 : Rate B, Rate C , 0.0, 0.0 -> 1873
% INFO    : Updated Thermal Rating: on line 3953-6861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 8537-6861 : Rate B, Rate C , 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 4805-6861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 431-5369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 3953-5369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 5369-5158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 4805-5369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 4805-5369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 9040-7174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 9040-7174 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 7174-3326 : Rate A, Rate B, Rate C , 553.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 9040-3326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 3404-8652 : Rate B, Rate C , 0.0, 0.0 -> 1021
% INFO    : Updated Thermal Rating: on line 5158-8652 : Rate B, Rate C , 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 2013-8652 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 8758-8652 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 8652-7493 : Rate B, Rate C , 0.0, 0.0 -> 6573
% INFO    : Updated Thermal Rating: on line 2216-1315 : Rate B, Rate C , 0.0, 0.0 -> 2496
% INFO    : Updated Thermal Rating: on line 2997-2216 : Rate B, Rate C , 0.0, 0.0 -> 2443
% INFO    : Updated Thermal Rating: on line 2216-7625 : Rate B, Rate C , 0.0, 0.0 -> 2730
% INFO    : Updated Thermal Rating: on line 6708-3084 : Rate B, Rate C , 0.0, 0.0 -> 2484
% INFO    : Updated Thermal Rating: on line 5656-3084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 1481-3084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 1481-3084 : Rate B, Rate C , 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 6708-3084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 3003-2771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 2771-3003 : Rate B, Rate C , 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 3404-1342 : Rate B, Rate C , 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 6972-2013 : Rate B, Rate C , 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 6166-2013 : Rate B, Rate C , 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 2013-3404 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 3996-2013 : Rate B, Rate C , 0.0, 0.0 -> 1708
% INFO    : Updated Thermal Rating: on line 3454-791 : Rate A, Rate B, Rate C , 1185.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 5075-2862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5075-2862 : Rate A, Rate B, Rate C , 572.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 2862-6937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 2862-6937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 2862-7984 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 5075-5513 : Rate B, Rate C , 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 5075-6937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 734-3616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 734-3616 : Rate A, Rate B, Rate C , 610.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 1481-3616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 8330-3616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 5732-3616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 1837-3616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 3003-3616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 5863-3616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 1481-734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 8330-734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 1837-734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 3326-8610 : Rate B, Rate C , 0.0, 0.0 -> 9640
% INFO    : Updated Thermal Rating: on line 8610-3782 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 8610-4805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 3326-8610 : Rate B, Rate C , 0.0, 0.0 -> 9813
% INFO    : Updated Thermal Rating: on line 6708-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 3003-1481 : Rate B, Rate C , 0.0, 0.0 -> 1536
% INFO    : Updated Thermal Rating: on line 8330-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 5732-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 1837-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 3003-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 5863-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 5305-1492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5305-1492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 1492-2539 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 1492-378 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 5148-1492 : Rate B, Rate C , 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 6166-1492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 6166-1492 : Rate B, Rate C , 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 8924-1492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 5148-5305 : Rate B, Rate C , 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 6166-5305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 8924-5305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 8924-5305 : Rate B, Rate C , 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 2835-3762 : Rate B, Rate C , 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 4638-2835 : Rate B, Rate C , 0.0, 0.0 -> 1409
% INFO    : Updated Thermal Rating: on line 1443-2835 : Rate B, Rate C , 0.0, 0.0 -> 1446
% INFO    : Updated Thermal Rating: on line 3996-6972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 6166-6972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 8924-6972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 7854-4844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 7854-4844 : Rate B, Rate C , 0.0, 0.0 -> 887
% INFO    : Updated Thermal Rating: on line 3930-1103 : Rate B, Rate C , 0.0, 0.0 -> 3072
% INFO    : Updated Thermal Rating: on line 1110-1103 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on line 6190-5505 : Rate B, Rate C , 0.0, 0.0 -> 1982
% INFO    : Updated Thermal Rating: on line 6190-3368 : Rate B, Rate C , 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 248-7089 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1481
% INFO    : Updated Thermal Rating: on line 248-4244 : Rate B, Rate C , 0.0, 0.0 -> 1841
% INFO    : Updated Thermal Rating: on line 248-4244 : Rate B, Rate C , 0.0, 0.0 -> 1882
% INFO    : Updated Thermal Rating: on line 1110-248 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 1110-248 : Rate B, Rate C , 0.0, 0.0 -> 4065
% INFO    : Updated Thermal Rating: on line 1110-248 : Rate B, Rate C , 0.0, 0.0 -> 3989
% INFO    : Updated Thermal Rating: on line 3404-6708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 3991-6708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 7511-6708 : Rate B, Rate C , 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 6708-7493 : Rate B, Rate C , 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 9027-7625 : Rate B, Rate C , 0.0, 0.0 -> 3547
% INFO    : Updated Thermal Rating: on line 8822-9027 : Rate B, Rate C , 0.0, 0.0 -> 5908
% INFO    : Updated Thermal Rating: on line 262-7025 : Rate B, Rate C , 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 262-7025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 7025-3787 : Rate B, Rate C , 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 6169-7025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 5656-3404 : Rate B, Rate C , 0.0, 0.0 -> 924
% INFO    : Updated Thermal Rating: on line 3991-3404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 7707-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7707-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 578-1267 : Rate B, Rate C , 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 2604-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 578-2604 : Rate A, Rate B, Rate C , 533.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 7707-1719 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 966-7707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 2604-7707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 1837-5513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 5656-5513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 5513-5656 : Rate B, Rate C , 0.0, 0.0 -> 953
% INFO    : Updated Thermal Rating: on line 5513-5656 : Rate B, Rate C , 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on line 7551-5513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 7984-5513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 212-5513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 212-5513 : Rate B, Rate C , 0.0, 0.0 -> 2532
% INFO    : Updated Thermal Rating: on line 3787-1719 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 173-1719 : Rate A, Rate B, Rate C , 533.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 3251-1719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3251-1719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 6601-1719 : Rate A, Rate B, Rate C , 553.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 966-3251 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 5386-4468 : Rate B, Rate C , 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 2250-4468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 8764-4468 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 378-4468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 5386-4468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 3762-499 : Rate B, Rate C , 0.0, 0.0 -> 2180
% INFO    : Updated Thermal Rating: on line 3762-6109 : Rate A, Rate B, Rate C , 1283.0, 0.0, 0.0 -> 744
% INFO    : Updated Thermal Rating: on line 3762-8685 : Rate B, Rate C , 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 2284-3039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 2063-3039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2063-3039 : Rate B, Rate C , 0.0, 0.0 -> 1423
% INFO    : Updated Thermal Rating: on line 9215-7854 : Rate B, Rate C , 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on line 3411-2250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3411-2250 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 2539-2250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 2250-3015 : Rate B, Rate C , 0.0, 0.0 -> 3502
% INFO    : Updated Thermal Rating: on line 3015-2250 : Rate B, Rate C , 0.0, 0.0 -> 3305
% INFO    : Updated Thermal Rating: on line 378-2250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 5386-2250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 2539-3411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2539-3411 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 378-3411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 5386-3411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 5386-3411 : Rate B, Rate C , 0.0, 0.0 -> 4898
% INFO    : Updated Thermal Rating: on line 3015-2539 : Rate B, Rate C , 0.0, 0.0 -> 3831
% INFO    : Updated Thermal Rating: on line 378-2539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 378-2539 : Rate B, Rate C , 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 5386-2539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 5732-8330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5732-8330 : Rate A, Rate B, Rate C , 572.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 3003-8330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 5863-8330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 5863-8330 : Rate B, Rate C , 0.0, 0.0 -> 937
% INFO    : Updated Thermal Rating: on line 3003-5732 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 5863-5732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 8685-499 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 499-8685 : Rate B, Rate C , 0.0, 0.0 -> 9218
% INFO    : Updated Thermal Rating: on line 770-7890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2231
% INFO    : Updated Thermal Rating: on line 1507-7890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1507-7890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 7890-3938 : Rate A, Rate B, Rate C , 400.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 1507-764 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 2573-3015 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 3015-3782 : Rate B, Rate C , 0.0, 0.0 -> 988
% INFO    : Updated Thermal Rating: on line 8685-2997 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on line 8685-2948 : Rate B, Rate C , 0.0, 0.0 -> 1460
% INFO    : Updated Thermal Rating: on line 791-4638 : Rate B, Rate C , 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 214-7089 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 7089-214 : Rate B, Rate C , 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 7089-2997 : Rate B, Rate C , 0.0, 0.0 -> 1739
% INFO    : Updated Thermal Rating: on line 7089-1315 : Rate B, Rate C , 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 764-8764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 764-8764 : Rate A, Rate B, Rate C , 610.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 3953-431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3953-431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 5158-431 : Rate B, Rate C , 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 4805-431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 8758-3953 : Rate B, Rate C , 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 4805-3953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 4847-214 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4847-214 : Rate B, Rate C , 0.0, 0.0 -> 3543
% INFO    : Updated Thermal Rating: on line 3326-2573 : Rate A, Rate B, Rate C , 533.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 3938-3326 : Rate A, Rate B, Rate C , 553.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 3782-2573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 3996-6937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 3996-6937 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 3368-791 : Rate B, Rate C , 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 3676-791 : Rate B, Rate C , 0.0, 0.0 -> 2696
% INFO    : Updated Thermal Rating: on line 3782-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 5386-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 8758-8537 : Rate B, Rate C , 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 262-7298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 7298-262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 7298-2553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 6169-262 : Rate B, Rate C , 0.0, 0.0 -> 2364
% INFO    : Updated Thermal Rating: on line 262-966 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 6169-262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 2997-2948 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 3787-966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3787-966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 2604-966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 2604-966 : Rate B, Rate C , 0.0, 0.0 -> 1830
% INFO    : Updated Thermal Rating: on line 2604-3787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 7551-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 7984-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 8924-5148 : Rate B, Rate C , 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 6166-3996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 8924-3996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 2997-8822 : Rate B, Rate C , 0.0, 0.0 -> 1700
% INFO    : Updated Thermal Rating: on line 1315-2997 : Rate B, Rate C , 0.0, 0.0 -> 5875
% INFO    : Updated Thermal Rating: on line 7625-8401 : Rate B, Rate C , 0.0, 0.0 -> 2748
% INFO    : Updated Thermal Rating: on line 7625-8401 : Rate B, Rate C , 0.0, 0.0 -> 2995
% INFO    : Updated Thermal Rating: on line 8924-6166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8924-6166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5505-3676 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5505-3676 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 3368-3676 : Rate B, Rate C , 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 8822-3676 : Rate A, Rate B, Rate C , 987.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 212-5656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 7984-7551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7984-7551 : Rate A, Rate B, Rate C , 572.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 212-7551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 212-7551 : Rate B, Rate C , 0.0, 0.0 -> 1173
% INFO    : Updated Thermal Rating: on line 212-7984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 5386-3782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 3909-2284 : Rate B, Rate C , 0.0, 0.0 -> 3759
% INFO    : Updated Thermal Rating: on line 2063-2284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 6601-173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6601-173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 3607-173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 3607-6601 : Rate B, Rate C , 0.0, 0.0 -> 936
% INFO    : Updated Thermal Rating: on line 3607-6601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 27-4847 : Rate B, Rate C , 0.0, 0.0 -> 3502
% INFO    : Updated Thermal Rating: on line 141-3720 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 141-3720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3938-3720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 1835-3720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 3938-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 1835-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 141-1835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 5863-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5863-3003 : Rate A, Rate B, Rate C , 572.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on line 1835-3938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 1835-3938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7493-3991 : Rate B, Rate C , 0.0, 0.0 -> 6078
% INFO    : Updated Thermal Rating: on line 4051-2553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4051-2553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3341-4259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 3341-4259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 5805-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4263
% INFO    : Updated Thermal Rating: on line 5805-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4272
% INFO    : Updated Thermal Rating: on line 5805-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3920
% INFO    : Updated Thermal Rating: on line 5452-2734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 5452-5274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 7879-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 7879-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 7879-7569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 8098-2734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 8098-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 598
% INFO    : Updated Thermal Rating: on line 8098-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 8098-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 8098-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 2233-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 2233-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on line 2233-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2697
% INFO    : Updated Thermal Rating: on line 2233-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2096
% INFO    : Updated Thermal Rating: on line 2233-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3971
% INFO    : Updated Thermal Rating: on line 2233-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 2233-2954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3911
% INFO    : Updated Thermal Rating: on line 4721-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 946
% INFO    : Updated Thermal Rating: on line 4721-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 4721-6512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1049
% INFO    : Updated Thermal Rating: on line 4721-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on line 8789-2734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 8789-2734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 8789-5274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 8789-4116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 8789-4868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 8789-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 8789-6329 : Rate B, Rate C , 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 8789-2817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 702-8927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 5517-1862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 5517-8629 : Rate B, Rate C , 0.0, 0.0 -> 3523
% INFO    : Updated Thermal Rating: on line 5517-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2575
% INFO    : Updated Thermal Rating: on line 5517-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 898
% INFO    : Updated Thermal Rating: on line 5517-3791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 4344-6512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 2734-6188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 2734-6188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 2734-3413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 6188-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 5006-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 5006-5331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 5006-5927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 5006-4771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 5006-2660 : Rate B, Rate C , 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 1862-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 1862-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 1862-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 1862-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 4116-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 4868-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 1250-5927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 1250-4771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 684
% INFO    : Updated Thermal Rating: on line 1250-8278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 2407-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 2407-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1290
% INFO    : Updated Thermal Rating: on line 2407-7411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 2407-4277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2572
% INFO    : Updated Thermal Rating: on line 2407-987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 2407-2206 : Rate B, Rate C , 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 8197-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5568
% INFO    : Updated Thermal Rating: on line 8197-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 8197-7792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 8197-1685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15180
% INFO    : Updated Thermal Rating: on line 8197-2894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 8197-4277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1401
% INFO    : Updated Thermal Rating: on line 8197-987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 552-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 6504-1543 : Rate B, Rate C , 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 6504-7041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1542
% INFO    : Updated Thermal Rating: on line 6504-3585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53419
% INFO    : Updated Thermal Rating: on line 6504-780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46965
% INFO    : Updated Thermal Rating: on line 6504-3957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46430
% INFO    : Updated Thermal Rating: on line 2692-6254 : Rate B, Rate C , 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 2692-8957 : Rate B, Rate C , 0.0, 0.0 -> 50503
% INFO    : Updated Thermal Rating: on line 2692-8861 : Rate B, Rate C , 0.0, 0.0 -> 51129
% INFO    : Updated Thermal Rating: on line 2692-1734 : Rate B, Rate C , 0.0, 0.0 -> 51675
% INFO    : Updated Thermal Rating: on line 2692-3266 : Rate B, Rate C , 0.0, 0.0 -> 46965
% INFO    : Updated Thermal Rating: on line 322-1974 : Rate B, Rate C , 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 322-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8043
% INFO    : Updated Thermal Rating: on line 322-177 : Rate B, Rate C , 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on line 5662-5333 : Rate B, Rate C , 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 5662-7901 : Rate B, Rate C , 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 5662-7041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3408
% INFO    : Updated Thermal Rating: on line 5662-2006 : Rate B, Rate C , 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 5662-7761 : Rate B, Rate C , 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 5662-5559 : Rate B, Rate C , 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 5662-3211 : Rate B, Rate C , 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 5662-8963 : Rate B, Rate C , 0.0, 0.0 -> 1948
% INFO    : Updated Thermal Rating: on line 5662-1770 : Rate B, Rate C , 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on line 3186-1109 : Rate B, Rate C , 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 3186-1109 : Rate B, Rate C , 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 3186-8493 : Rate B, Rate C , 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 3186-6280 : Rate B, Rate C , 0.0, 0.0 -> 34869
% INFO    : Updated Thermal Rating: on line 3186-3987 : Rate B, Rate C , 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 1974-5825 : Rate B, Rate C , 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 1974-7252 : Rate B, Rate C , 0.0, 0.0 -> 3550
% INFO    : Updated Thermal Rating: on line 1974-7252 : Rate B, Rate C , 0.0, 0.0 -> 18766
% INFO    : Updated Thermal Rating: on line 1974-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2954
% INFO    : Updated Thermal Rating: on line 2410-2006 : Rate B, Rate C , 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 2410-2006 : Rate B, Rate C , 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 2410-315 : Rate B, Rate C , 0.0, 0.0 -> 3002
% INFO    : Updated Thermal Rating: on line 2410-1489 : Rate B, Rate C , 0.0, 0.0 -> 2956
% INFO    : Updated Thermal Rating: on line 8926-5797 : Rate B, Rate C , 0.0, 0.0 -> 3557
% INFO    : Updated Thermal Rating: on line 8926-6381 : Rate B, Rate C , 0.0, 0.0 -> 11743
% INFO    : Updated Thermal Rating: on line 8926-6381 : Rate B, Rate C , 0.0, 0.0 -> 11868
% INFO    : Updated Thermal Rating: on line 8926-1239 : Rate B, Rate C , 0.0, 0.0 -> 3867
% INFO    : Updated Thermal Rating: on line 8926-5643 : Rate B, Rate C , 0.0, 0.0 -> 123896
% INFO    : Updated Thermal Rating: on line 5672-7901 : Rate B, Rate C , 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 5672-6415 : Rate B, Rate C , 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 5672-6415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 5672-8998 : Rate B, Rate C , 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 5333-6795 : Rate B, Rate C , 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 5333-6795 : Rate B, Rate C , 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 5333-3211 : Rate B, Rate C , 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 6795-3054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 6795-3054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 6795-2562 : Rate B, Rate C , 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 3054-6254 : Rate B, Rate C , 0.0, 0.0 -> 1453
% INFO    : Updated Thermal Rating: on line 3054-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2065
% INFO    : Updated Thermal Rating: on line 3054-8957 : Rate B, Rate C , 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 3054-3266 : Rate B, Rate C , 0.0, 0.0 -> 1347
% INFO    : Updated Thermal Rating: on line 3054-7615 : Rate B, Rate C , 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 5825-177 : Rate B, Rate C , 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 5825-6415 : Rate B, Rate C , 0.0, 0.0 -> 1057
% INFO    : Updated Thermal Rating: on line 5825-4744 : Rate B, Rate C , 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 5825-5669 : Rate B, Rate C , 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 5825-3416 : Rate B, Rate C , 0.0, 0.0 -> 16463
% INFO    : Updated Thermal Rating: on line 7901-6415 : Rate B, Rate C , 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 7901-7503 : Rate B, Rate C , 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on line 8459-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3496
% INFO    : Updated Thermal Rating: on line 8459-8998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6784
% INFO    : Updated Thermal Rating: on line 8459-5361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3122
% INFO    : Updated Thermal Rating: on line 6254-5797 : Rate B, Rate C , 0.0, 0.0 -> 1922
% INFO    : Updated Thermal Rating: on line 6254-5797 : Rate B, Rate C , 0.0, 0.0 -> 2511
% INFO    : Updated Thermal Rating: on line 6254-9136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3954
% INFO    : Updated Thermal Rating: on line 6254-4650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 6254-7037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3026
% INFO    : Updated Thermal Rating: on line 6254-2497 : Rate B, Rate C , 0.0, 0.0 -> 1927
% INFO    : Updated Thermal Rating: on line 6254-8861 : Rate B, Rate C , 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on line 6254-1734 : Rate B, Rate C , 0.0, 0.0 -> 2924
% INFO    : Updated Thermal Rating: on line 3478-3211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9816
% INFO    : Updated Thermal Rating: on line 7252-7236 : Rate B, Rate C , 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 5797-3954 : Rate B, Rate C , 0.0, 0.0 -> 17448
% INFO    : Updated Thermal Rating: on line 5797-5643 : Rate B, Rate C , 0.0, 0.0 -> 5262
% INFO    : Updated Thermal Rating: on line 6960-2562 : Rate B, Rate C , 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 6960-7037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6859
% INFO    : Updated Thermal Rating: on line 6960-5643 : Rate B, Rate C , 0.0, 0.0 -> 3711
% INFO    : Updated Thermal Rating: on line 177-2460 : Rate B, Rate C , 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 177-4744 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 177-6311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5184
% INFO    : Updated Thermal Rating: on line 177-5361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5827
% INFO    : Updated Thermal Rating: on line 177-7236 : Rate B, Rate C , 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 3954-2497 : Rate B, Rate C , 0.0, 0.0 -> 20641
% INFO    : Updated Thermal Rating: on line 2460-6415 : Rate B, Rate C , 0.0, 0.0 -> 2941
% INFO    : Updated Thermal Rating: on line 380-5339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 380-5669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1682
% INFO    : Updated Thermal Rating: on line 1848-3932 : Rate B, Rate C , 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 1848-5094 : Rate B, Rate C , 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 1848-3623 : Rate B, Rate C , 0.0, 0.0 -> 2871
% INFO    : Updated Thermal Rating: on line 1848-785 : Rate B, Rate C , 0.0, 0.0 -> 2926
% INFO    : Updated Thermal Rating: on line 1848-1036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1521
% INFO    : Updated Thermal Rating: on line 8021-698 : Rate B, Rate C , 0.0, 0.0 -> 1603
% INFO    : Updated Thermal Rating: on line 8021-628 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1109-315 : Rate B, Rate C , 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 1109-1489 : Rate B, Rate C , 0.0, 0.0 -> 1503
% INFO    : Updated Thermal Rating: on line 1109-3932 : Rate B, Rate C , 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 1109-5094 : Rate B, Rate C , 0.0, 0.0 -> 2287
% INFO    : Updated Thermal Rating: on line 6415-5669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 6415-8493 : Rate B, Rate C , 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 6415-8493 : Rate B, Rate C , 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 7503-5559 : Rate B, Rate C , 0.0, 0.0 -> 5786
% INFO    : Updated Thermal Rating: on line 7041-2006 : Rate A, Rate B, Rate C , 553.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 4712-3623 : Rate B, Rate C , 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 4712-785 : Rate B, Rate C , 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 5339-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 813
% INFO    : Updated Thermal Rating: on line 4170-698 : Rate B, Rate C , 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 4170-698 : Rate B, Rate C , 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 4170-4333 : Rate B, Rate C , 0.0, 0.0 -> 1404
% INFO    : Updated Thermal Rating: on line 4170-4333 : Rate B, Rate C , 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 2006-8963 : Rate B, Rate C , 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on line 2006-7661 : Rate B, Rate C , 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on line 8493-628 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 8493-628 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 130-3080 : Rate B, Rate C , 0.0, 0.0 -> 2543
% INFO    : Updated Thermal Rating: on line 130-536 : Rate B, Rate C , 0.0, 0.0 -> 2249
% INFO    : Updated Thermal Rating: on line 130-4393 : Rate B, Rate C , 0.0, 0.0 -> 2287
% INFO    : Updated Thermal Rating: on line 7827-7969 : Rate B, Rate C , 0.0, 0.0 -> 8606
% INFO    : Updated Thermal Rating: on line 7827-6760 : Rate B, Rate C , 0.0, 0.0 -> 6190
% INFO    : Updated Thermal Rating: on line 1025-6298 : Rate B, Rate C , 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 1025-3007 : Rate B, Rate C , 0.0, 0.0 -> 8436
% INFO    : Updated Thermal Rating: on line 1025-3265 : Rate B, Rate C , 0.0, 0.0 -> 3931
% INFO    : Updated Thermal Rating: on line 1339-3265 : Rate B, Rate C , 0.0, 0.0 -> 1474
% INFO    : Updated Thermal Rating: on line 1339-1774 : Rate B, Rate C , 0.0, 0.0 -> 2582
% INFO    : Updated Thermal Rating: on line 1339-2899 : Rate B, Rate C , 0.0, 0.0 -> 1940
% INFO    : Updated Thermal Rating: on line 1339-1703 : Rate B, Rate C , 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 441-8088 : Rate B, Rate C , 0.0, 0.0 -> 6031
% INFO    : Updated Thermal Rating: on line 441-3265 : Rate B, Rate C , 0.0, 0.0 -> 1756
% INFO    : Updated Thermal Rating: on line 6298-1774 : Rate B, Rate C , 0.0, 0.0 -> 1590
% INFO    : Updated Thermal Rating: on line 6298-2899 : Rate B, Rate C , 0.0, 0.0 -> 1564
% INFO    : Updated Thermal Rating: on line 8088-3080 : Rate B, Rate C , 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 8088-544 : Rate B, Rate C , 0.0, 0.0 -> 9877
% INFO    : Updated Thermal Rating: on line 8088-7079 : Rate B, Rate C , 0.0, 0.0 -> 23777
% INFO    : Updated Thermal Rating: on line 8088-8601 : Rate B, Rate C , 0.0, 0.0 -> 20968
% INFO    : Updated Thermal Rating: on line 8088-1155 : Rate B, Rate C , 0.0, 0.0 -> 20572
% INFO    : Updated Thermal Rating: on line 8088-3256 : Rate B, Rate C , 0.0, 0.0 -> 20179
% INFO    : Updated Thermal Rating: on line 8088-5815 : Rate B, Rate C , 0.0, 0.0 -> 7008
% INFO    : Updated Thermal Rating: on line 8088-5815 : Rate B, Rate C , 0.0, 0.0 -> 7142
% INFO    : Updated Thermal Rating: on line 3080-1899 : Rate B, Rate C , 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 3080-9032 : Rate B, Rate C , 0.0, 0.0 -> 13394
% INFO    : Updated Thermal Rating: on line 3080-6004 : Rate B, Rate C , 0.0, 0.0 -> 13175
% INFO    : Updated Thermal Rating: on line 3080-7810 : Rate B, Rate C , 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 3080-8630 : Rate B, Rate C , 0.0, 0.0 -> 12430
% INFO    : Updated Thermal Rating: on line 3080-8183 : Rate B, Rate C , 0.0, 0.0 -> 12894
% INFO    : Updated Thermal Rating: on line 3080-6390 : Rate B, Rate C , 0.0, 0.0 -> 13145
% INFO    : Updated Thermal Rating: on line 8224-7969 : Rate B, Rate C , 0.0, 0.0 -> 5149
% INFO    : Updated Thermal Rating: on line 8224-7969 : Rate B, Rate C , 0.0, 0.0 -> 3733
% INFO    : Updated Thermal Rating: on line 8224-7860 : Rate B, Rate C , 0.0, 0.0 -> 2325
% INFO    : Updated Thermal Rating: on line 8224-6187 : Rate B, Rate C , 0.0, 0.0 -> 6953
% INFO    : Updated Thermal Rating: on line 3007-3265 : Rate B, Rate C , 0.0, 0.0 -> 5928
% INFO    : Updated Thermal Rating: on line 3007-544 : Rate B, Rate C , 0.0, 0.0 -> 2197
% INFO    : Updated Thermal Rating: on line 3007-7810 : Rate B, Rate C , 0.0, 0.0 -> 1853
% INFO    : Updated Thermal Rating: on line 4807-6187 : Rate B, Rate C , 0.0, 0.0 -> 3585
% INFO    : Updated Thermal Rating: on line 4807-6760 : Rate B, Rate C , 0.0, 0.0 -> 3148
% INFO    : Updated Thermal Rating: on line 4807-4926 : Rate B, Rate C , 0.0, 0.0 -> 4127
% INFO    : Updated Thermal Rating: on line 7969-1703 : Rate B, Rate C , 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 7969-2031 : Rate B, Rate C , 0.0, 0.0 -> 2520
% INFO    : Updated Thermal Rating: on line 7969-7980 : Rate B, Rate C , 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 7969-6760 : Rate B, Rate C , 0.0, 0.0 -> 3851
% INFO    : Updated Thermal Rating: on line 536-7509 : Rate B, Rate C , 0.0, 0.0 -> 3148
% INFO    : Updated Thermal Rating: on line 536-3990 : Rate B, Rate C , 0.0, 0.0 -> 4691
% INFO    : Updated Thermal Rating: on line 1774-1703 : Rate B, Rate C , 0.0, 0.0 -> 2461
% INFO    : Updated Thermal Rating: on line 1774-7980 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 1273
% INFO    : Updated Thermal Rating: on line 1774-4543 : Rate B, Rate C , 0.0, 0.0 -> 12907
% INFO    : Updated Thermal Rating: on line 1774-6340 : Rate B, Rate C , 0.0, 0.0 -> 12704
% INFO    : Updated Thermal Rating: on line 1774-261 : Rate B, Rate C , 0.0, 0.0 -> 28598
% INFO    : Updated Thermal Rating: on line 1774-2058 : Rate B, Rate C , 0.0, 0.0 -> 29098
% INFO    : Updated Thermal Rating: on line 7860-6187 : Rate B, Rate C , 0.0, 0.0 -> 3853
% INFO    : Updated Thermal Rating: on line 6080-2899 : Rate B, Rate C , 0.0, 0.0 -> 3658
% INFO    : Updated Thermal Rating: on line 6080-7509 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 2899-5263 : Rate B, Rate C , 0.0, 0.0 -> 131160
% INFO    : Updated Thermal Rating: on line 1703-138 : Rate B, Rate C , 0.0, 0.0 -> 2366
% INFO    : Updated Thermal Rating: on line 1899-5562 : Rate B, Rate C , 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 138-2031 : Rate B, Rate C , 0.0, 0.0 -> 2136
% INFO    : Updated Thermal Rating: on line 4704-2031 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 4704-1570 : Rate B, Rate C , 0.0, 0.0 -> 5503
% INFO    : Updated Thermal Rating: on line 2031-1999 : Rate B, Rate C , 0.0, 0.0 -> 150416
% INFO    : Updated Thermal Rating: on line 7509-3990 : Rate B, Rate C , 0.0, 0.0 -> 3344
% INFO    : Updated Thermal Rating: on line 7509-7935 : Rate B, Rate C , 0.0, 0.0 -> 6422
% INFO    : Updated Thermal Rating: on line 7509-7935 : Rate B, Rate C , 0.0, 0.0 -> 6547
% INFO    : Updated Thermal Rating: on line 39-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2138
% INFO    : Updated Thermal Rating: on line 1174-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 389-4259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1652
% INFO    : Updated Thermal Rating: on line 3711-7411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3711-2894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34509
% INFO    : Updated Thermal Rating: on line 8771-7792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141820
% INFO    : Updated Thermal Rating: on line 6459-7411 : Rate B, Rate C , 0.0, 0.0 -> 2134
% INFO    : Updated Thermal Rating: on line 4013-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3944
% INFO    : Updated Thermal Rating: on line 4013-4577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10566
% INFO    : Updated Thermal Rating: on line 4013-8007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95764
% INFO    : Updated Thermal Rating: on line 2853-5331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27645
% INFO    : Updated Thermal Rating: on line 6512-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2319
% INFO    : Updated Thermal Rating: on line 7569-6135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on line 5927-6540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5693
% INFO    : Updated Thermal Rating: on line 698-7104 : Rate B, Rate C , 0.0, 0.0 -> 2517
% INFO    : Updated Thermal Rating: on line 698-7104 : Rate B, Rate C , 0.0, 0.0 -> 2282
% INFO    : Updated Thermal Rating: on line 698-4333 : Rate B, Rate C , 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 8998-6311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6644
% INFO    : Updated Thermal Rating: on line 7761-1770 : Rate B, Rate C , 0.0, 0.0 -> 59725
% INFO    : Updated Thermal Rating: on line 6311-5361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73269
% INFO    : Updated Thermal Rating: on line 1770-7709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5225
% INFO    : Updated Thermal Rating: on line 1489-5790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6519
% INFO    : Updated Thermal Rating: on line 5094-5266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51867
% INFO    : Updated Thermal Rating: on line 3623-7927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18122
% INFO    : Updated Thermal Rating: on line 7236-4098 : Rate B, Rate C , 0.0, 0.0 -> 19594
% INFO    : Updated Thermal Rating: on line 5815-3990 : Rate B, Rate C , 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on line 7329-7661 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2318-5347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 6361-5347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 2798-215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 2915-2798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 4607-5313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 1762-4607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1542
% INFO    : Updated Thermal Rating: on line 512-6834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 6834-6517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 7201-7419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39833
% INFO    : Updated Thermal Rating: on line 3752-7201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 1298-7419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5619-5050 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 5050-3362 : Rate B, Rate C , 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3441-5050 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 5050-2086 : Rate B, Rate C , 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 1996-2592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1881
% INFO    : Updated Thermal Rating: on line 8645-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 1996-3752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 1996-5227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 1298-2592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1853
% INFO    : Updated Thermal Rating: on line 8645-1298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 1298-6250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 902-1424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 2744-902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3715
% INFO    : Updated Thermal Rating: on line 5811-6338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 4667-5811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 5811-4486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5811-9017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 934-5811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 934-5811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 6991-5811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 7486-62 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41563
% INFO    : Updated Thermal Rating: on line 62-4451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5135-62 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 5474-62 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 675-7486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 7486-3527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 2830-7486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 4532-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 7109-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on line 653-4653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 1192-1472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 3369-1192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 951
% INFO    : Updated Thermal Rating: on line 5849-4696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1586
% INFO    : Updated Thermal Rating: on line 4696-7930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 2857-8018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 428-2857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3128-6642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 6642-7549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 760-8235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 8235-8241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 3682-2209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2831
% INFO    : Updated Thermal Rating: on line 8720-3682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 5221-4045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2869
% INFO    : Updated Thermal Rating: on line 468-5221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 934
% INFO    : Updated Thermal Rating: on line 1360-3142 : Rate B, Rate C , 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 971-1360 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 6710-1360 : Rate B, Rate C , 0.0, 0.0 -> 4302
% INFO    : Updated Thermal Rating: on line 2537-5741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 2537-4213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 5741-8586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 8476-7518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1481
% INFO    : Updated Thermal Rating: on line 7518-7308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 8820-3120 : Rate B, Rate C , 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 8820-1695 : Rate B, Rate C , 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 991-6205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 991-6205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 6205-2744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 1583-3733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37471
% INFO    : Updated Thermal Rating: on line 2239-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1268
% INFO    : Updated Thermal Rating: on line 1583-4862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 3733-4263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 2565-2868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 4532-2565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 3030-746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3867
% INFO    : Updated Thermal Rating: on line 1375-746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6006
% INFO    : Updated Thermal Rating: on line 6614-6815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 6815-8666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 5472-8313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 125-8313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 506
% INFO    : Updated Thermal Rating: on line 4560-4833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 7221-4560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7612
% INFO    : Updated Thermal Rating: on line 2774-1988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 2442-2774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1470
% INFO    : Updated Thermal Rating: on line 3029-8062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13435
% INFO    : Updated Thermal Rating: on line 8062-2275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3457
% INFO    : Updated Thermal Rating: on line 7126-4227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6579
% INFO    : Updated Thermal Rating: on line 508-4227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 1732-67 : Rate B, Rate C , 0.0, 0.0 -> 2714
% INFO    : Updated Thermal Rating: on line 1732-6449 : Rate B, Rate C , 0.0, 0.0 -> 2339
% INFO    : Updated Thermal Rating: on line 456-6247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 456-189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3325
% INFO    : Updated Thermal Rating: on line 8643-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 6264-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 2008-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1271
% INFO    : Updated Thermal Rating: on line 2008-1158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6573
% INFO    : Updated Thermal Rating: on line 1756-4746 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4746-3640 : Rate B, Rate C , 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 4746-3640 : Rate B, Rate C , 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 4327-4746 : Rate B, Rate C , 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 8844-7067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4998
% INFO    : Updated Thermal Rating: on line 7067-6106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3652
% INFO    : Updated Thermal Rating: on line 8208-850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on line 8208-3805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5074-4682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 4682-7613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 8844-8594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4729
% INFO    : Updated Thermal Rating: on line 3630-5039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1321
% INFO    : Updated Thermal Rating: on line 5039-233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3783
% INFO    : Updated Thermal Rating: on line 3630-850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2148
% INFO    : Updated Thermal Rating: on line 1045-5447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 5447-8594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2300
% INFO    : Updated Thermal Rating: on line 5447-233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1072
% INFO    : Updated Thermal Rating: on line 5447-3952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5447-6712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 6106-850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3330
% INFO    : Updated Thermal Rating: on line 850-6592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on line 8251-4421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on line 7397-8251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 5103-5071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 5103-2723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 7109-5103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 1828-5582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on line 479-5582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 6247-5306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 8424-5646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1274-5646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 2114-5646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 1195-6614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 3444-2792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 2752-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 8884-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6305
% INFO    : Updated Thermal Rating: on line 1619-8755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8810
% INFO    : Updated Thermal Rating: on line 4183-2868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2729
% INFO    : Updated Thermal Rating: on line 2868-713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2687
% INFO    : Updated Thermal Rating: on line 4587-2868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 1849-2868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3373-3706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 4223-3373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 6513-1961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 6513-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 7889-4187 : Rate B, Rate C , 0.0, 0.0 -> 5658
% INFO    : Updated Thermal Rating: on line 2108-4187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 1245-4546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 4546-5231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 4546-5614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 4546-4764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 6265-6341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on line 3986-6341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 3731-2383 : Rate B, Rate C , 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 5175-3731 : Rate B, Rate C , 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 760-6800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 760-3893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 760-4584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 5029-5336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 9093-5336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 4837-1091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35373
% INFO    : Updated Thermal Rating: on line 4837-3393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on line 4837-3732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 5955-4837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 6803-1091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 2246-1091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 560-1091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2156-5071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 7365-6441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1753
% INFO    : Updated Thermal Rating: on line 3881-7365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3292
% INFO    : Updated Thermal Rating: on line 1446-7216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 6305-1446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 8302-4667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 8840-8302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 6515-8271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2464-6515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 2238-2773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38242
% INFO    : Updated Thermal Rating: on line 4741-2773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 2238-925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 5569-2238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 4756-9199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 6305-4756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 6305-4756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 788-2352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 2352-8127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 336-1070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 1070-8148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 620-1536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 3642-1536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 6063-4585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38997
% INFO    : Updated Thermal Rating: on line 6063-8949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2987
% INFO    : Updated Thermal Rating: on line 2567-6063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1263
% INFO    : Updated Thermal Rating: on line 4585-215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2939
% INFO    : Updated Thermal Rating: on line 2567-4585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 5725-3965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2655
% INFO    : Updated Thermal Rating: on line 5725-2318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 5728-5725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 479-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 3077-7747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 1783-4949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 8289-4949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on line 2427-7418 : Rate B, Rate C , 0.0, 0.0 -> 1396
% INFO    : Updated Thermal Rating: on line 4903-7418 : Rate A, Rate B, Rate C , 1119.0, 0.0, 0.0 -> 1081
% INFO    : Updated Thermal Rating: on line 3120-3365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5629
% INFO    : Updated Thermal Rating: on line 2152-3120 : Rate B, Rate C , 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 3120-1764 : Rate B, Rate C , 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 3120-2251 : Rate B, Rate C , 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 117-3328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39833
% INFO    : Updated Thermal Rating: on line 117-8348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 117-6353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 3328-5964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1544
% INFO    : Updated Thermal Rating: on line 3328-5964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1569
% INFO    : Updated Thermal Rating: on line 4444-3328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1446
% INFO    : Updated Thermal Rating: on line 5759-4736 : Rate B, Rate C , 0.0, 0.0 -> 8865
% INFO    : Updated Thermal Rating: on line 4282-2111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 641
% INFO    : Updated Thermal Rating: on line 3250-4282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 2111-8351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on line 8754-1297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7000
% INFO    : Updated Thermal Rating: on line 7703-1297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33525
% INFO    : Updated Thermal Rating: on line 2427-841 : Rate B, Rate C , 0.0, 0.0 -> 14595
% INFO    : Updated Thermal Rating: on line 67-2427 : Rate B, Rate C , 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 2427-3192 : Rate B, Rate C , 0.0, 0.0 -> 1393
% INFO    : Updated Thermal Rating: on line 6265-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 6265-9209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 1988-6265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 6265-2845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 753-6265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 5981-6265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 6770-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2843
% INFO    : Updated Thermal Rating: on line 6770-8705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 6770-6975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 7199-6770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 6770-3964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 4053-6849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 3338-6849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on line 841-4396 : Rate B, Rate C , 0.0, 0.0 -> 1728
% INFO    : Updated Thermal Rating: on line 6729-4396 : Rate B, Rate C , 0.0, 0.0 -> 3360
% INFO    : Updated Thermal Rating: on line 6317-3570 : Rate B, Rate C , 0.0, 0.0 -> 149704
% INFO    : Updated Thermal Rating: on line 9218-6317 : Rate B, Rate C , 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 6317-1764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 3570-9005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 3570-7271 : Rate B, Rate C , 0.0, 0.0 -> 1141
% INFO    : Updated Thermal Rating: on line 3570-2251 : Rate B, Rate C , 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on line 3434-8025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3243
% INFO    : Updated Thermal Rating: on line 7397-3434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 7344-3031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3031-677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 3452-3899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 3899-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 6729-2707 : Rate B, Rate C , 0.0, 0.0 -> 2856
% INFO    : Updated Thermal Rating: on line 2707-5009 : Rate A, Rate B, Rate C , 1185.0, 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on line 2707-2226 : Rate B, Rate C , 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on line 7017-2707 : Rate A, Rate B, Rate C , 1086.0, 0.0, 0.0 -> 744
% INFO    : Updated Thermal Rating: on line 5690-2534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144235
% INFO    : Updated Thermal Rating: on line 9218-2534 : Rate B, Rate C , 0.0, 0.0 -> 1431
% INFO    : Updated Thermal Rating: on line 2534-9005 : Rate B, Rate C , 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 2534-204 : Rate B, Rate C , 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 2534-545 : Rate B, Rate C , 0.0, 0.0 -> 5848
% INFO    : Updated Thermal Rating: on line 3029-2275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5835
% INFO    : Updated Thermal Rating: on line 8918-3029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 3029-7048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1709
% INFO    : Updated Thermal Rating: on line 1176-4669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 7909-1176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1295
% INFO    : Updated Thermal Rating: on line 5978-4443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 3847-5978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 3833-3043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 6571-3833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 4989-7588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1221
% INFO    : Updated Thermal Rating: on line 4989-3700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 6144-6805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 8377-8754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 8377-4617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3187
% INFO    : Updated Thermal Rating: on line 3033-1797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on line 1412-1797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4509
% INFO    : Updated Thermal Rating: on line 7703-1797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3134
% INFO    : Updated Thermal Rating: on line 400-8024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11752
% INFO    : Updated Thermal Rating: on line 3559-400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4214
% INFO    : Updated Thermal Rating: on line 677-2207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30252
% INFO    : Updated Thermal Rating: on line 677-2207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30614
% INFO    : Updated Thermal Rating: on line 7216-7598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 7598-6339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 3310-447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on line 447-1849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 447-1849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 8572-6177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on line 1878-8572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 6792-5621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on line 6792-9020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1058
% INFO    : Updated Thermal Rating: on line 6792-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 6792-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 5621-3639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 5076-1306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 5076-5249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 3639-5076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3575
% INFO    : Updated Thermal Rating: on line 5813-5076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3840
% INFO    : Updated Thermal Rating: on line 5076-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 5076-3908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 1306-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 588-8735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 8735-2311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 1405-991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5283-991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 7142-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11228
% INFO    : Updated Thermal Rating: on line 7142-6105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 7142-4984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 8363-7142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 7142-9078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1290
% INFO    : Updated Thermal Rating: on line 5407-3453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 5018-3453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1527
% INFO    : Updated Thermal Rating: on line 4311-463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 463-5045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 463-4759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1232
% INFO    : Updated Thermal Rating: on line 463-1532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 6105-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 8018-8533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2961
% INFO    : Updated Thermal Rating: on line 8018-8482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 3034-8018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 8533-8922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 609
% INFO    : Updated Thermal Rating: on line 7506-3142 : Rate B, Rate C , 0.0, 0.0 -> 23086
% INFO    : Updated Thermal Rating: on line 1195-9035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 4391-1195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 4960-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 2198-4960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 3965-2318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 6706-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2854
% INFO    : Updated Thermal Rating: on line 4741-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3723
% INFO    : Updated Thermal Rating: on line 6881-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 3079-7469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 2115-3079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 2560-1472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 508-2560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 1412-6037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on line 3902-6037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6869
% INFO    : Updated Thermal Rating: on line 8754-6919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 5724-6919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6151
% INFO    : Updated Thermal Rating: on line 3805-5074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3006
% INFO    : Updated Thermal Rating: on line 5578-7216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 1424-1834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1971
% INFO    : Updated Thermal Rating: on line 6245-282 : Rate B, Rate C , 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 5009-282 : Rate B, Rate C , 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on line 5009-282 : Rate B, Rate C , 0.0, 0.0 -> 2260
% INFO    : Updated Thermal Rating: on line 282-3729 : Rate B, Rate C , 0.0, 0.0 -> 7890
% INFO    : Updated Thermal Rating: on line 2226-282 : Rate B, Rate C , 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 7109-6801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1703
% INFO    : Updated Thermal Rating: on line 6801-4102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2537
% INFO    : Updated Thermal Rating: on line 8586-4213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1342
% INFO    : Updated Thermal Rating: on line 7166-4421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 7585-7166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on line 1988-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3061
% INFO    : Updated Thermal Rating: on line 831-6580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3087
% INFO    : Updated Thermal Rating: on line 596-8815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1729
% INFO    : Updated Thermal Rating: on line 5906-8815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 6733-1361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1542
% INFO    : Updated Thermal Rating: on line 1361-508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on line 1361-508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1081
% INFO    : Updated Thermal Rating: on line 675-2515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 7899-2515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 2515-4930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1499
% INFO    : Updated Thermal Rating: on line 6242-7909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2733
% INFO    : Updated Thermal Rating: on line 6242-8918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on line 4443-4179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 4443-4179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 7040-4179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 7536-4179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 1669-1821 : Rate B, Rate C , 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 3853-1821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 2156-4359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 2723-2156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 2156-4441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 6571-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1738
% INFO    : Updated Thermal Rating: on line 3161-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 8922-3132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2526
% INFO    : Updated Thermal Rating: on line 8482-3132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1499
% INFO    : Updated Thermal Rating: on line 7993-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1756
% INFO    : Updated Thermal Rating: on line 3059-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 189-2691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 6285-5126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 3033-6285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2520
% INFO    : Updated Thermal Rating: on line 6285-3902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on line 5126-5724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 2984-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 2984-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 2333-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2051
% INFO    : Updated Thermal Rating: on line 4838-4780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1373
% INFO    : Updated Thermal Rating: on line 4780-5335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4273-224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3066
% INFO    : Updated Thermal Rating: on line 4391-4273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 7549-224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 1135-6711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 6711-6672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 3452-949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 3452-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5249-1316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3733
% INFO    : Updated Thermal Rating: on line 4364-8402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 8402-8812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 7902-2258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2085
% INFO    : Updated Thermal Rating: on line 5472-6786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 60-7265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 1321-7265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 4988-7265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 7211-8780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 8780-7549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 47-2221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 47-2609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 1285-6800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5472
% INFO    : Updated Thermal Rating: on line 3510-4335 : Rate B, Rate C , 0.0, 0.0 -> 7420
% INFO    : Updated Thermal Rating: on line 5849-8777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2863
% INFO    : Updated Thermal Rating: on line 5849-3350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3115
% INFO    : Updated Thermal Rating: on line 6339-5849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 7930-3804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 7930-617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 7930-6105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 7930-9078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 8777-4976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2883
% INFO    : Updated Thermal Rating: on line 4976-1048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2906
% INFO    : Updated Thermal Rating: on line 1048-3804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 7838-3804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 3350-1048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 1865-5619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 5619-4375 : Rate B, Rate C , 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 5619-4327 : Rate B, Rate C , 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 9209-1796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 5578-2404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 6305-2404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 3904-596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1051
% INFO    : Updated Thermal Rating: on line 4726-1455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 1455-857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 949-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 744
% INFO    : Updated Thermal Rating: on line 8940-4443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1062
% INFO    : Updated Thermal Rating: on line 7040-4443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 2651-5816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 1796-2651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 8705-3986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2239
% INFO    : Updated Thermal Rating: on line 1550-6245 : Rate B, Rate C , 0.0, 0.0 -> 2077
% INFO    : Updated Thermal Rating: on line 5813-9020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1652
% INFO    : Updated Thermal Rating: on line 7224-215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 2691-7224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 951
% INFO    : Updated Thermal Rating: on line 5713-1740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 1740-5068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 1858-8071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36730
% INFO    : Updated Thermal Rating: on line 1858-8499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 1858-967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 2431-1858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 3034-8071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 4881-3970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 3970-2993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2281
% INFO    : Updated Thermal Rating: on line 1755-2747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 8922-6974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 741-6974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 7294-6082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 6082-6788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 7866-8314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 3451-7866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 9227-6787 : Rate B, Rate C , 0.0, 0.0 -> 144235
% INFO    : Updated Thermal Rating: on line 9227-5487 : Rate B, Rate C , 0.0, 0.0 -> 3658
% INFO    : Updated Thermal Rating: on line 4716-9227 : Rate B, Rate C , 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 9227-7225 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 6787-5487 : Rate B, Rate C , 0.0, 0.0 -> 4163
% INFO    : Updated Thermal Rating: on line 6787-8633 : Rate B, Rate C , 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 4716-6787 : Rate B, Rate C , 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 2834-8115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1338
% INFO    : Updated Thermal Rating: on line 4102-8115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 7649-2996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2554
% INFO    : Updated Thermal Rating: on line 7649-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1889
% INFO    : Updated Thermal Rating: on line 3873-7109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 928
% INFO    : Updated Thermal Rating: on line 4708-3873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on line 922-2061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36059
% INFO    : Updated Thermal Rating: on line 7806-2061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 4708-2061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3765
% INFO    : Updated Thermal Rating: on line 4708-2061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3829
% INFO    : Updated Thermal Rating: on line 922-4532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5489-922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 922-1961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 7372-1828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 68-4881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 8831-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 7211-5540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 5540-4391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 5012-4660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 4029-5012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 782
% INFO    : Updated Thermal Rating: on line 8666-7516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3451-7516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 3877-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35373
% INFO    : Updated Thermal Rating: on line 6236-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 87-5955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 6803-3877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 3877-5193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 3877-4149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 913
% INFO    : Updated Thermal Rating: on line 3877-7798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 4359-4441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5639-5736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 7798-5639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 1756-1865 : Rate B, Rate C , 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 8476-741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 8476-2506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 7426-1256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 1256-4223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 7760-428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 967-7760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 2431-7760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 6463-301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1028
% INFO    : Updated Thermal Rating: on line 7186-301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 4833-3562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 3562-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 1713-7696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 6361-1713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 8645-2592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 7356-4726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5578-617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 9199-5578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 5578-6712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5578-9214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 677-4219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 4219-5908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1556
% INFO    : Updated Thermal Rating: on line 2767-588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 6546-108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 108-3595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 7812-6011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 479-7812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 811
% INFO    : Updated Thermal Rating: on line 6011-3595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 2996-7806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38242
% INFO    : Updated Thermal Rating: on line 2996-2834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9654
% INFO    : Updated Thermal Rating: on line 2996-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 7806-1022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9482
% INFO    : Updated Thermal Rating: on line 6177-1988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 1988-6062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1564
% INFO    : Updated Thermal Rating: on line 1988-6062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1431
% INFO    : Updated Thermal Rating: on line 1988-6580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4125
% INFO    : Updated Thermal Rating: on line 1988-6580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3727
% INFO    : Updated Thermal Rating: on line 1764-719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2629
% INFO    : Updated Thermal Rating: on line 2251-3536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2436
% INFO    : Updated Thermal Rating: on line 2209-4045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38997
% INFO    : Updated Thermal Rating: on line 2209-5628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 4045-1104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 4045-1053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 4802-5710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5710-2318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1211-6729 : Rate A, Rate B, Rate C , 1152.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 5713-8754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 2221-8754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 1412-3504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 598
% INFO    : Updated Thermal Rating: on line 247-6487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 2531-247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 3847-7696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 7836-8922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 8922-1274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 7933-8922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 8922-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 8424-7813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on line 2506-8424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 7993-4563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 6319-7017 : Rate B, Rate C , 0.0, 0.0 -> 4685
% INFO    : Updated Thermal Rating: on line 1853-4311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 6406-78 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 6406-2531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 3679-2018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 3706-4534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 4669-717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 5157-7048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1807
% INFO    : Updated Thermal Rating: on line 8153-5157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 964
% INFO    : Updated Thermal Rating: on line 7946-3802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 3802-8166 : Rate B, Rate C , 0.0, 0.0 -> 1089
% INFO    : Updated Thermal Rating: on line 5313-2959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 3161-3043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 404-9056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1452
% INFO    : Updated Thermal Rating: on line 9056-1505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 9056-4987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1586
% INFO    : Updated Thermal Rating: on line 9056-2011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 5736-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 1022-8455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 1834-2239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 6851-460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3045
% INFO    : Updated Thermal Rating: on line 6851-4930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3570
% INFO    : Updated Thermal Rating: on line 125-7441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 3235-7441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 1197-5647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 4838-5647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 7946-4977 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 7828-4977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 4977-403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 7344-6465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40653
% INFO    : Updated Thermal Rating: on line 7344-8403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 7344-7864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on line 6465-8403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 871
% INFO    : Updated Thermal Rating: on line 6465-1744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 6465-7606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 8271-8283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 3131-8283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 4802-7040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 4802-7304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 5306-2915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 1038-336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 4534-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 717-4312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41563
% INFO    : Updated Thermal Rating: on line 8153-4312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1470
% INFO    : Updated Thermal Rating: on line 1532-620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 6689-1104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 6689-1104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 1104-5628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 3050-7889 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 5252-3153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 3921-5252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 1190-3153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1305
% INFO    : Updated Thermal Rating: on line 1634-4532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 4532-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 1196-2170 : Rate B, Rate C , 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 2170-3213 : Rate B, Rate C , 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 335-4881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 4881-864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 4881-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 8501-4881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 4881-2466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4881-2466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 1048-617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1273
% INFO    : Updated Thermal Rating: on line 617-6517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 8836-8050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 8050-7588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 2108-7946 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 9015-7853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1323
% INFO    : Updated Thermal Rating: on line 9015-7853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on line 9015-6647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 8076-9015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 7853-1712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 1766-6081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on line 3815-6081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on line 2311-6579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1163
% INFO    : Updated Thermal Rating: on line 2311-5047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 2311-5614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 9204-1766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 884
% INFO    : Updated Thermal Rating: on line 2431-7836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 3129-8755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8696
% INFO    : Updated Thermal Rating: on line 8038-3129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 3685-3207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36059
% INFO    : Updated Thermal Rating: on line 6256-3510 : Rate B, Rate C , 0.0, 0.0 -> 3790
% INFO    : Updated Thermal Rating: on line 3510-8137 : Rate B, Rate C , 0.0, 0.0 -> 1144
% INFO    : Updated Thermal Rating: on line 4660-1053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 3921-1190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 7800-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 7800-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 7469-398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 8166-1196 : Rate B, Rate C , 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 4838-1197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 5335-1197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1819
% INFO    : Updated Thermal Rating: on line 8643-6764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1011
% INFO    : Updated Thermal Rating: on line 8643-6264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20628
% INFO    : Updated Thermal Rating: on line 890-8643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 890-8643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 8643-6144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 1785-5489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3147
% INFO    : Updated Thermal Rating: on line 6339-2338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 9214-2338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 5816-6975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 204-545 : Rate B, Rate C , 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 204-7225 : Rate B, Rate C , 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 675-2488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38242
% INFO    : Updated Thermal Rating: on line 675-7899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 675-460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 675-3527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 675-3366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 5068-675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 2609-675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 857-6764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 2376-460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 1417-1655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 925-1417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 1417-4739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 1908-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 898
% INFO    : Updated Thermal Rating: on line 5009-4736 : Rate B, Rate C , 0.0, 0.0 -> 1801
% INFO    : Updated Thermal Rating: on line 2027-5487 : Rate B, Rate C , 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on line 4716-2027 : Rate B, Rate C , 0.0, 0.0 -> 1692
% INFO    : Updated Thermal Rating: on line 8351-7426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 6279-5737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38997
% INFO    : Updated Thermal Rating: on line 6279-7703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5413
% INFO    : Updated Thermal Rating: on line 4441-3310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on line 4617-5737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5448
% INFO    : Updated Thermal Rating: on line 3642-1853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 3642-3751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3642-1751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 7045-4223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 1540-67 : Rate A, Rate B, Rate C , 1251.0, 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on line 5537-7828 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 8949-215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40653
% INFO    : Updated Thermal Rating: on line 215-6647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 2024-215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 2024-215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 215-1254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 215-8076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 2383-3441 : Rate B, Rate C , 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 2383-7515 : Rate B, Rate C , 0.0, 0.0 -> 2418
% INFO    : Updated Thermal Rating: on line 2383-2185 : Rate B, Rate C , 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on line 8010-7745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 8010-7578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 1921-5029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 1921-9093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5029-7902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 5029-5259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 3250-8351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 788-2830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5193-7043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 4916-7043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 4641-2845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 335-864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 677-7800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 677-7800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 2318-4068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 6338-512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 7040-6579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4537-2146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4537-2146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 3131-2146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 5370-4587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 4764-2767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 7813-2114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 677-8024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1728
% INFO    : Updated Thermal Rating: on line 677-3559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3055
% INFO    : Updated Thermal Rating: on line 677-2643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 1158-7864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 8692-6481 : Rate B, Rate C , 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 8692-1563 : Rate B, Rate C , 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on line 7549-9035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 8740-5791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 8740-5671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2526
% INFO    : Updated Thermal Rating: on line 3192-6256 : Rate B, Rate C , 0.0, 0.0 -> 2344
% INFO    : Updated Thermal Rating: on line 3213-1756 : Rate B, Rate C , 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 3213-1756 : Rate B, Rate C , 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 6105-4984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 7948-3504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1807
% INFO    : Updated Thermal Rating: on line 7415-7555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 7555-3815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 6550-7045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 6062-7294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 6696-6647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 5671-6696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 508-3059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 3115-4736 : Rate B, Rate C , 0.0, 0.0 -> 2023
% INFO    : Updated Thermal Rating: on line 3115-1540 : Rate B, Rate C , 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 3115-1540 : Rate B, Rate C , 0.0, 0.0 -> 2353
% INFO    : Updated Thermal Rating: on line 1550-3115 : Rate B, Rate C , 0.0, 0.0 -> 2572
% INFO    : Updated Thermal Rating: on line 2904-3115 : Rate B, Rate C , 0.0, 0.0 -> 4674
% INFO    : Updated Thermal Rating: on line 6116-5487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149704
% INFO    : Updated Thermal Rating: on line 4716-5487 : Rate B, Rate C , 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 7109-8455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41563
% INFO    : Updated Thermal Rating: on line 8940-5842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1528
% INFO    : Updated Thermal Rating: on line 6706-6363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 7933-8499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 9166-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 1532-4664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 4664-3751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 6463-5886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 608
% INFO    : Updated Thermal Rating: on line 6463-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on line 3030-7439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 7439-4351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1749
% INFO    : Updated Thermal Rating: on line 7948-1847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2370
% INFO    : Updated Thermal Rating: on line 2376-7948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5713-1847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2551
% INFO    : Updated Thermal Rating: on line 925-4271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4271-4497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 4271-4992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 4271-4992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4736-1540 : Rate B, Rate C , 0.0, 0.0 -> 4415
% INFO    : Updated Thermal Rating: on line 8351-6550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 8351-8148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 508-3369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 8097-3671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3185
% INFO    : Updated Thermal Rating: on line 8884-8097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10709
% INFO    : Updated Thermal Rating: on line 6487-4364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 6487-4364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 1047-5791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 2993-6422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2430
% INFO    : Updated Thermal Rating: on line 4584-4794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 4794-9148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 3511-7120 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 3511-8583 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 1783-8289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 928
% INFO    : Updated Thermal Rating: on line 6803-8794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 8801-3893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5526
% INFO    : Updated Thermal Rating: on line 6503-8801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1085
% INFO    : Updated Thermal Rating: on line 1655-5370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 1135-7975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1552
% INFO    : Updated Thermal Rating: on line 2966-6672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1575
% INFO    : Updated Thermal Rating: on line 3964-4641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 737-2882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 2882-2752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 4563-7126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on line 278-8290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 934-8290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1265
% INFO    : Updated Thermal Rating: on line 890-2024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37471
% INFO    : Updated Thermal Rating: on line 46-1286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 1286-1053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 1550-3729 : Rate B, Rate C , 0.0, 0.0 -> 1779
% INFO    : Updated Thermal Rating: on line 5193-4252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on line 5193-7215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 969
% INFO    : Updated Thermal Rating: on line 5193-4916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 7215-3393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 942
% INFO    : Updated Thermal Rating: on line 4252-3732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 6236-4252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 2466-7221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 6522-5436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on line 4862-5436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2530
% INFO    : Updated Thermal Rating: on line 7838-8363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2545
% INFO    : Updated Thermal Rating: on line 7003-2557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 8794-2557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 773-741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 971-3192 : Rate B, Rate C , 0.0, 0.0 -> 1738
% INFO    : Updated Thermal Rating: on line 7515-7278 : Rate B, Rate C , 0.0, 0.0 -> 1803
% INFO    : Updated Thermal Rating: on line 7278-7750 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 7515-3441 : Rate B, Rate C , 0.0, 0.0 -> 1944
% INFO    : Updated Thermal Rating: on line 479-6546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1625
% INFO    : Updated Thermal Rating: on line 8836-1405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36059
% INFO    : Updated Thermal Rating: on line 8348-8836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 8836-6353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 1405-5283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5045-4759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2381
% INFO    : Updated Thermal Rating: on line 8127-7151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 2609-7151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 60-6786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 7345-1008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 1008-6361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 37-5132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 700-5132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 1961-4653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 857-6048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 8314-7211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 8314-7211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 8314-3128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 1053-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 633-6689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 633-6689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 6665-545 : Rate B, Rate C , 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 4364-8812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 5370-4497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 5370-1634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5370-4739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 4537-7232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 4537-4902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3394
% INFO    : Updated Thermal Rating: on line 4537-4902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3401
% INFO    : Updated Thermal Rating: on line 5908-4537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3082
% INFO    : Updated Thermal Rating: on line 5908-4537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2883
% INFO    : Updated Thermal Rating: on line 6338-4486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 2645-9204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 6710-4394 : Rate B, Rate C , 0.0, 0.0 -> 2213
% INFO    : Updated Thermal Rating: on line 4149-7061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 821
% INFO    : Updated Thermal Rating: on line 8794-7061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 3881-8025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 7232-1744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 5037-6592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on line 3566-5037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 8212-737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 8212-3908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 756-8286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 8831-8501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 4667-278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 751
% INFO    : Updated Thermal Rating: on line 4667-278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 4667-6991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 8840-4667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 278-8070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 8137-4394 : Rate A, Rate B, Rate C , 987.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 3815-5407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 1285-5087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 8038-3671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5896
% INFO    : Updated Thermal Rating: on line 3356-4697 : Rate B, Rate C , 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 4697-7017 : Rate B, Rate C , 0.0, 0.0 -> 1236
% INFO    : Updated Thermal Rating: on line 1211-4697 : Rate B, Rate C , 0.0, 0.0 -> 2149
% INFO    : Updated Thermal Rating: on line 3853-1669 : Rate B, Rate C , 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 7671-3853 : Rate B, Rate C , 0.0, 0.0 -> 149704
% INFO    : Updated Thermal Rating: on line 3853-8692 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 3853-8692 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 3853-3915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2672
% INFO    : Updated Thermal Rating: on line 3853-1127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2625
% INFO    : Updated Thermal Rating: on line 4171-9166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1263
% INFO    : Updated Thermal Rating: on line 2462-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 2036-2462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 818
% INFO    : Updated Thermal Rating: on line 2645-7415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2607
% INFO    : Updated Thermal Rating: on line 5955-2246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3231
% INFO    : Updated Thermal Rating: on line 5955-7798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35373
% INFO    : Updated Thermal Rating: on line 5185-5175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 9105-6503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1082
% INFO    : Updated Thermal Rating: on line 9105-7348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5495
% INFO    : Updated Thermal Rating: on line 9105-9148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 7897-7745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 1316-737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 8286-560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 2777-7757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 2777-8241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9509
% INFO    : Updated Thermal Rating: on line 7757-7348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 3366-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 6881-7613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 4538-2011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2431
% INFO    : Updated Thermal Rating: on line 4538-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1448
% INFO    : Updated Thermal Rating: on line 925-1351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 4992-1351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on line 6522-355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38242
% INFO    : Updated Thermal Rating: on line 7588-355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2523
% INFO    : Updated Thermal Rating: on line 3700-355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 6522-4444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 7397-4851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 4851-7585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 7397-4053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38997
% INFO    : Updated Thermal Rating: on line 5626-7397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 5095-4053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 4053-5906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 4053-6918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 6441-3904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 7585-3338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1315
% INFO    : Updated Thermal Rating: on line 2792-5626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 3273-5095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1550
% INFO    : Updated Thermal Rating: on line 2752-3273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 1245-5231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 1284-753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 4191-6548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 6548-1375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2852
% INFO    : Updated Thermal Rating: on line 2780-5474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 46-4029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on line 1284-7199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 506
% INFO    : Updated Thermal Rating: on line 6250-7975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 5227-2966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 6048-6144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 5141-3847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 5141-5047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 7536-5141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 5886-6733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2235
% INFO    : Updated Thermal Rating: on line 6733-508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 4902-2464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 8501-1693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5632-1693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 2333-1693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 9017-4486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 3356-887 : Rate B, Rate C , 0.0, 0.0 -> 1686
% INFO    : Updated Thermal Rating: on line 7549-4391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39833
% INFO    : Updated Thermal Rating: on line 7839-7345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 1695-2152 : Rate B, Rate C , 0.0, 0.0 -> 2874
% INFO    : Updated Thermal Rating: on line 6409-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 508-7186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 925-4378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 925-4378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 6449-3017 : Rate B, Rate C , 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 7578-1505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3130
% INFO    : Updated Thermal Rating: on line 3359-7578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2864
% INFO    : Updated Thermal Rating: on line 3359-1505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40653
% INFO    : Updated Thermal Rating: on line 7897-1505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 3640-7010 : Rate B, Rate C , 0.0, 0.0 -> 1062
% INFO    : Updated Thermal Rating: on line 482-1309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 1309-4451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1722
% INFO    : Updated Thermal Rating: on line 2747-4987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1475
% INFO    : Updated Thermal Rating: on line 7536-5842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on line 3941-3566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 2198-3941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 887-7506 : Rate B, Rate C , 0.0, 0.0 -> 5093
% INFO    : Updated Thermal Rating: on line 3815-1511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41563
% INFO    : Updated Thermal Rating: on line 3815-5018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 1511-6571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 7003-8794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 4327-5337 : Rate B, Rate C , 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on line 3030-4351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 1375-3030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5417
% INFO    : Updated Thermal Rating: on line 978-4171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 2036-2011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 7660-8633 : Rate B, Rate C , 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 8749-934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 566-8749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 3952-6726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 6726-2198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 941-482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 6788-5981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 4903-3192 : Rate A, Rate B, Rate C , 1086.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 1762-1321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 877
% INFO    : Updated Thermal Rating: on line 1321-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 1762-4988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 864
% INFO    : Updated Thermal Rating: on line 4988-3235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 934-4191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 1878-2442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1706
% INFO    : Updated Thermal Rating: on line 4903-7017 : Rate B, Rate C , 0.0, 0.0 -> 2614
% INFO    : Updated Thermal Rating: on line 6825-7308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36730
% INFO    : Updated Thermal Rating: on line 1853-78 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36059
% INFO    : Updated Thermal Rating: on line 398-78 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1416
% INFO    : Updated Thermal Rating: on line 1751-1853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 4741-4072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3793
% INFO    : Updated Thermal Rating: on line 4072-5569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 7304-5231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 6208-5231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 7271-4990 : Rate B, Rate C , 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 4068-7839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 7040-7536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38242
% INFO    : Updated Thermal Rating: on line 6208-7536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 7536-5728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on line 934-8070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 6703-4903 : Rate B, Rate C , 0.0, 0.0 -> 19319
% INFO    : Updated Thermal Rating: on line 6703-4903 : Rate B, Rate C , 0.0, 0.0 -> 19749
% INFO    : Updated Thermal Rating: on line 4903-1211 : Rate B, Rate C , 0.0, 0.0 -> 2933
% INFO    : Updated Thermal Rating: on line 1550-2904 : Rate B, Rate C , 0.0, 0.0 -> 2242
% INFO    : Updated Thermal Rating: on line 1047-1712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 7585-3881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38997
% INFO    : Updated Thermal Rating: on line 3881-6918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 7660-5185 : Rate B, Rate C , 0.0, 0.0 -> 1993
% INFO    : Updated Thermal Rating: on line 6363-5569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39833
% INFO    : Updated Thermal Rating: on line 5569-4378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on line 1254-7356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 3161-2645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40653
% INFO    : Updated Thermal Rating: on line 8720-1053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 4029-1053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 468-1053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 6422-5632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on line 6422-2333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1927
% INFO    : Updated Thermal Rating: on line 5135-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 7606-2643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 2706-576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 4676-1211 : Rate B, Rate C , 0.0, 0.0 -> 13351
% INFO    : Updated Thermal Rating: on line 4676-1211 : Rate B, Rate C , 0.0, 0.0 -> 13621
% INFO    : Updated Thermal Rating: on line 5906-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 7372-7747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 4862-3700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36059
% INFO    : Updated Thermal Rating: on line 4263-3700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 8013-8192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 6141-8013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 7604-3914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 24-3914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 3748-6572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 2149-6572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 6878-5727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 6878-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 4763-5554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 1410-4763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 4763-5865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 7765-7534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 7765-6673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 7722-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 8969-7722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 5733-4437 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5733-3103 : Rate B, Rate C , 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 5733-5043 : Rate B, Rate C , 0.0, 0.0 -> 4557
% INFO    : Updated Thermal Rating: on line 5733-2402 : Rate B, Rate C , 0.0, 0.0 -> 2775
% INFO    : Updated Thermal Rating: on line 1964-5733 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 7978-5733 : Rate B, Rate C , 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 5733-9168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4876
% INFO    : Updated Thermal Rating: on line 5733-1390 : Rate B, Rate C , 0.0, 0.0 -> 4789
% INFO    : Updated Thermal Rating: on line 5733-4899 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 5733-694 : Rate B, Rate C , 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 5153-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 1087-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 3548-1289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 4784-1289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 186-4406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 186-4671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 6352-1299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 7705-1299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 8430-7590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 8430-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3628
% INFO    : Updated Thermal Rating: on line 7590-2106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2886
% INFO    : Updated Thermal Rating: on line 2977-7590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 3399-7590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 5931-155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 155-3924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 155-877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3795
% INFO    : Updated Thermal Rating: on line 155-3394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 155-8418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 155-8051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 7730-940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 7730-7970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 1964-2939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 1964-2939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on line 1964-2939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1331
% INFO    : Updated Thermal Rating: on line 1964-2939 : Rate B, Rate C , 0.0, 0.0 -> 1357
% INFO    : Updated Thermal Rating: on line 341-918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1080
% INFO    : Updated Thermal Rating: on line 341-918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on line 341-918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 341-1795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4559
% INFO    : Updated Thermal Rating: on line 341-5057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6436
% INFO    : Updated Thermal Rating: on line 341-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on line 341-5397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2634
% INFO    : Updated Thermal Rating: on line 341-5397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2583
% INFO    : Updated Thermal Rating: on line 918-1377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 918-2864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 2977-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2775
% INFO    : Updated Thermal Rating: on line 8617-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 1795-5057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6550
% INFO    : Updated Thermal Rating: on line 2106-5931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5749
% INFO    : Updated Thermal Rating: on line 8470-303 : Rate B, Rate C , 0.0, 0.0 -> 3859
% INFO    : Updated Thermal Rating: on line 8470-303 : Rate B, Rate C , 0.0, 0.0 -> 3926
% INFO    : Updated Thermal Rating: on line 940-3924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4599
% INFO    : Updated Thermal Rating: on line 5327-9016 : Rate B, Rate C , 0.0, 0.0 -> 14483
% INFO    : Updated Thermal Rating: on line 1686-9016 : Rate B, Rate C , 0.0, 0.0 -> 4369
% INFO    : Updated Thermal Rating: on line 2568-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 1964-4437 : Rate B, Rate C , 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 2345-4437 : Rate B, Rate C , 0.0, 0.0 -> 3245
% INFO    : Updated Thermal Rating: on line 8470-4437 : Rate B, Rate C , 0.0, 0.0 -> 3280
% INFO    : Updated Thermal Rating: on line 7364-5327 : Rate B, Rate C , 0.0, 0.0 -> 4182
% INFO    : Updated Thermal Rating: on line 5327-8358 : Rate B, Rate C , 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 2345-1753 : Rate B, Rate C , 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 8470-6350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2713
% INFO    : Updated Thermal Rating: on line 3103-7978 : Rate B, Rate C , 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 3900-3103 : Rate B, Rate C , 0.0, 0.0 -> 5129
% INFO    : Updated Thermal Rating: on line 9036-8471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 8471-4399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 6262-8471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 3745-379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 4803-379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 4824-2855 : Rate B, Rate C , 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on line 2855-8562 : Rate B, Rate C , 0.0, 0.0 -> 2187
% INFO    : Updated Thermal Rating: on line 223-2023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3426
% INFO    : Updated Thermal Rating: on line 8308-2023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 223-3864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3250
% INFO    : Updated Thermal Rating: on line 3864-6150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 223-3162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 223-4678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 223-3203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 223-9124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 989-8783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1251
% INFO    : Updated Thermal Rating: on line 8969-8783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 1087-989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 1699-4406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1029
% INFO    : Updated Thermal Rating: on line 4406-1495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 3026-7301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 7301-6988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3994
% INFO    : Updated Thermal Rating: on line 4169-6988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8079
% INFO    : Updated Thermal Rating: on line 4169-4465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 3026-4547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 5344-3026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 8734-4361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 4361-7978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1233
% INFO    : Updated Thermal Rating: on line 7604-2638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 3122-2638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 2554-3548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 1665-6755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 6755-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 7243-1178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 7243-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 2976-6988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1965
% INFO    : Updated Thermal Rating: on line 4547-2976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 6673-2976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 2123-5547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 801-2123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 2473-2123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 7-8407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 7-7208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 8407-975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 8407-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 975-2037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 975-5629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 975-5629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 4136-3839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 4136-8357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4136-8357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 7900-4639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 7528-4639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 4727-8617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 1410-4727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 7604-8192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 8990-2947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 7477-8990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 5875-6843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on line 4814-5875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 2687-5557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76418
% INFO    : Updated Thermal Rating: on line 591-2687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 2568-877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 3637-1699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1082
% INFO    : Updated Thermal Rating: on line 1246-862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 1960-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 2802-7323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 6262-7323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 393-6461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16502
% INFO    : Updated Thermal Rating: on line 393-6461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17624
% INFO    : Updated Thermal Rating: on line 8382-5269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 8382-5269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 5269-6628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 6461-3688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 6461-5000 : Rate B, Rate C , 0.0, 0.0 -> 2565
% INFO    : Updated Thermal Rating: on line 6461-5000 : Rate B, Rate C , 0.0, 0.0 -> 2480
% INFO    : Updated Thermal Rating: on line 8942-2861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1983
% INFO    : Updated Thermal Rating: on line 8942-4671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2523
% INFO    : Updated Thermal Rating: on line 2861-4671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2278
% INFO    : Updated Thermal Rating: on line 4671-3839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 4671-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4671-5190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 6673-4465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 593
% INFO    : Updated Thermal Rating: on line 8474-4824 : Rate B, Rate C , 0.0, 0.0 -> 1352
% INFO    : Updated Thermal Rating: on line 4678-7607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1323
% INFO    : Updated Thermal Rating: on line 7149-7607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 3203-7607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 7607-9124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 6448-2195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 8618-6350 : Rate B, Rate C , 0.0, 0.0 -> 1774
% INFO    : Updated Thermal Rating: on line 586-9036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 2015-2982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10473
% INFO    : Updated Thermal Rating: on line 6626-586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 3136-6626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 8096-4986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2186
% INFO    : Updated Thermal Rating: on line 2947-8096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 2947-4986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 7477-2947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 2947-6610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 2947-9193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 2947-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 245-8481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 8481-4343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 8481-329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 4269-9219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 2864-9219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 1731-7848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on line 1731-6827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 1731-2195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 6673-7534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 7739-7354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 8306-7354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 1534-7830 : Rate B, Rate C , 0.0, 0.0 -> 2744
% INFO    : Updated Thermal Rating: on line 8562-7830 : Rate B, Rate C , 0.0, 0.0 -> 2055
% INFO    : Updated Thermal Rating: on line 7604-7739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 7739-5830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 6843-7739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 3748-5547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 3394-8418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on line 3523-1372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 8969-3523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 2554-3011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 4784-3011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5153-2554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2037-7848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 591-5557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 2218-4034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 3713-4034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5000-4997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32943
% INFO    : Updated Thermal Rating: on line 2802-3300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 8261-3300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 1534-9054 : Rate B, Rate C , 0.0, 0.0 -> 2353
% INFO    : Updated Thermal Rating: on line 8306-8423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 8306-1661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 8306-5865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 8306-7414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 8423-7414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1944
% INFO    : Updated Thermal Rating: on line 7595-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 8570-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on line 8570-7595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 3770-7595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on line 8570-3770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1512
% INFO    : Updated Thermal Rating: on line 8570-1806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 8570-1018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 663-8734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 8734-7978 : Rate B, Rate C , 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 4861-663 : Rate B, Rate C , 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 663-4392 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 7604-2201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 1087-1665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 1665-8437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 8343-24 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 6843-1661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 797
% INFO    : Updated Thermal Rating: on line 862-2568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 8562-1978 : Rate B, Rate C , 0.0, 0.0 -> 5156
% INFO    : Updated Thermal Rating: on line 1978-6098 : Rate B, Rate C , 0.0, 0.0 -> 2949
% INFO    : Updated Thermal Rating: on line 4861-3104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 7477-7900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 7900-7528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4803-245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 1228-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 1228-7938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 4343-1960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 3162-6150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2516
% INFO    : Updated Thermal Rating: on line 3162-2633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1553
% INFO    : Updated Thermal Rating: on line 8308-2633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 551-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 551-5195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 6709-1408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1103
% INFO    : Updated Thermal Rating: on line 6709-2195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1215
% INFO    : Updated Thermal Rating: on line 5554-8665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 3745-7705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 994
% INFO    : Updated Thermal Rating: on line 4784-5153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 4678-7149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 6141-7528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 6141-7528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 7528-6141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 6141-8015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2640
% INFO    : Updated Thermal Rating: on line 6141-8343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 8015-7528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 7528-2015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 7528-2218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 8562-2398 : Rate B, Rate C , 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 2864-1377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 6043-8364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 8364-2195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 1806-6043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 6043-3136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 4555-8382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 4555-4269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 960
% INFO    : Updated Thermal Rating: on line 3738-6352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 8382-6471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 6471-6278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1451
% INFO    : Updated Thermal Rating: on line 5684-4801 : Rate B, Rate C , 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 5684-4801 : Rate B, Rate C , 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on line 4801-895 : Rate B, Rate C , 0.0, 0.0 -> 2351
% INFO    : Updated Thermal Rating: on line 1964-3372 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 7521-3372 : Rate B, Rate C , 0.0, 0.0 -> 1248
% INFO    : Updated Thermal Rating: on line 3372-1473 : Rate B, Rate C , 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 8382-3410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 8382-3756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 6278-8382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2019
% INFO    : Updated Thermal Rating: on line 5218-1087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 5218-7200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 3410-7200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 7200-3756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2906
% INFO    : Updated Thermal Rating: on line 7364-5684 : Rate B, Rate C , 0.0, 0.0 -> 35464
% INFO    : Updated Thermal Rating: on line 7364-4447 : Rate B, Rate C , 0.0, 0.0 -> 162401
% INFO    : Updated Thermal Rating: on line 7364-6248 : Rate B, Rate C , 0.0, 0.0 -> 209139
% INFO    : Updated Thermal Rating: on line 7364-5684 : Rate B, Rate C , 0.0, 0.0 -> 33059
% INFO    : Updated Thermal Rating: on line 7364-9054 : Rate B, Rate C , 0.0, 0.0 -> 6332
% INFO    : Updated Thermal Rating: on line 1964-465 : Rate B, Rate C , 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 1964-3597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47437
% INFO    : Updated Thermal Rating: on line 1964-1139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28868
% INFO    : Updated Thermal Rating: on line 1964-3288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29690
% INFO    : Updated Thermal Rating: on line 1964-894 : Rate B, Rate C , 0.0, 0.0 -> 36317
% INFO    : Updated Thermal Rating: on line 1964-7627 : Rate B, Rate C , 0.0, 0.0 -> 35909
% INFO    : Updated Thermal Rating: on line 1964-5731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2479
% INFO    : Updated Thermal Rating: on line 1964-694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on line 8437-1178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 180-329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 6628-7468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3267
% INFO    : Updated Thermal Rating: on line 1087-7468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 3748-8418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 3748-8418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on line 8474-1686 : Rate B, Rate C , 0.0, 0.0 -> 2806
% INFO    : Updated Thermal Rating: on line 1473-8618 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 5830-3122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3659
% INFO    : Updated Thermal Rating: on line 7208-6827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on line 2398-7314 : Rate B, Rate C , 0.0, 0.0 -> 2963
% INFO    : Updated Thermal Rating: on line 7848-6827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4803-3917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 504-3917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 801-4784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 1063-8308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 1063-8308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 8308-6843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 876-2015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on line 2218-876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4392-5000 : Rate B, Rate C , 0.0, 0.0 -> 1041
% INFO    : Updated Thermal Rating: on line 4131-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 813
% INFO    : Updated Thermal Rating: on line 4131-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 825
% INFO    : Updated Thermal Rating: on line 6673-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 6673-8865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 9193-1495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 5127-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 5127-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1577
% INFO    : Updated Thermal Rating: on line 5127-7687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 5127-7687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1072
% INFO    : Updated Thermal Rating: on line 5312-3725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 914
% INFO    : Updated Thermal Rating: on line 5312-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1554
% INFO    : Updated Thermal Rating: on line 3725-7687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 2349-5000 : Rate B, Rate C , 0.0, 0.0 -> 1850
% INFO    : Updated Thermal Rating: on line 2349-5000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2015
% INFO    : Updated Thermal Rating: on line 1714-8357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 1358-5629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2994
% INFO    : Updated Thermal Rating: on line 1358-2505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2153
% INFO    : Updated Thermal Rating: on line 5629-2505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 2505-5195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 8051-7970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 5684-2585 : Rate B, Rate C , 0.0, 0.0 -> 3360
% INFO    : Updated Thermal Rating: on line 4602-5684 : Rate B, Rate C , 0.0, 0.0 -> 22518
% INFO    : Updated Thermal Rating: on line 5985-5684 : Rate B, Rate C , 0.0, 0.0 -> 22985
% INFO    : Updated Thermal Rating: on line 4815-3016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1510
% INFO    : Updated Thermal Rating: on line 4131-3016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 6034-4815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3595
% INFO    : Updated Thermal Rating: on line 493-3738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 504-493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 4803-5238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2403
% INFO    : Updated Thermal Rating: on line 5995-5238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19462
% INFO    : Updated Thermal Rating: on line 4803-5775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1581
% INFO    : Updated Thermal Rating: on line 7783-5775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 4803-5995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2442
% INFO    : Updated Thermal Rating: on line 4803-7783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 1087-1372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2802-4015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 7938-5195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 7938-4240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1347
% INFO    : Updated Thermal Rating: on line 8051-8566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5372
% INFO    : Updated Thermal Rating: on line 274-8566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5000
% INFO    : Updated Thermal Rating: on line 8566-2295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3309
% INFO    : Updated Thermal Rating: on line 8566-4131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 274-3470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 274-3470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 8358-8474 : Rate B, Rate C , 0.0, 0.0 -> 3949
% INFO    : Updated Thermal Rating: on line 3470-8665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 3470-4131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 3470-4131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 4131-2295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 591-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on line 7705-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 4899-7521 : Rate B, Rate C , 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 591-6898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2367
% INFO    : Updated Thermal Rating: on line 7705-6898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2095
% INFO    : Updated Thermal Rating: on line 8665-4814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 5727-5208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 822
% INFO    : Updated Thermal Rating: on line 5208-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2823
% INFO    : Updated Thermal Rating: on line 5208-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 895-254 : Rate B, Rate C , 0.0, 0.0 -> 2376
% INFO    : Updated Thermal Rating: on line 1087-8437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 1087-1003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on line 2568-3399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 8969-3232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 1408-4220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 4383-2568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 1960-4383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 4131-6034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 3750-5000 : Rate B, Rate C , 0.0, 0.0 -> 10143
% INFO    : Updated Thermal Rating: on line 3750-5000 : Rate B, Rate C , 0.0, 0.0 -> 10731
% INFO    : Updated Thermal Rating: on line 7687-8357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 7687-2195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5678-7687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 7687-4220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 2398-2253 : Rate B, Rate C , 0.0, 0.0 -> 175910
% INFO    : Updated Thermal Rating: on line 2398-2253 : Rate B, Rate C , 0.0, 0.0 -> 169185
% INFO    : Updated Thermal Rating: on line 2253-2737 : Rate B, Rate C , 0.0, 0.0 -> 5341
% INFO    : Updated Thermal Rating: on line 2201-1018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on line 4784-6358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 6358-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28177
% INFO    : Updated Thermal Rating: on line 4240-8357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 5190-8357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21858
% INFO    : Updated Thermal Rating: on line 5190-8357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21475
% INFO    : Updated Thermal Rating: on line 8865-4015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1993
% INFO    : Updated Thermal Rating: on line 1960-8261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3714
% INFO    : Updated Thermal Rating: on line 180-8261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3177
% INFO    : Updated Thermal Rating: on line 6610-3637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 3637-9193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2811
% INFO    : Updated Thermal Rating: on line 3637-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 430-9193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2884
% INFO    : Updated Thermal Rating: on line 1003-8437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 2149-2473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3917
% INFO    : Updated Thermal Rating: on line 5678-4220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5487
% INFO    : Updated Thermal Rating: on line 9124-3713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 4784-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 821
% INFO    : Updated Thermal Rating: on line 8556-1920 : Rate B, Rate C , 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 1920-6907 : Rate B, Rate C , 0.0, 0.0 -> 1866
% INFO    : Updated Thermal Rating: on line 1920-6907 : Rate B, Rate C , 0.0, 0.0 -> 1831
% INFO    : Updated Thermal Rating: on line 8263-1920 : Rate B, Rate C , 0.0, 0.0 -> 4878
% INFO    : Updated Thermal Rating: on line 8263-1920 : Rate B, Rate C , 0.0, 0.0 -> 4985
% INFO    : Updated Thermal Rating: on line 1920-5824 : Rate B, Rate C , 0.0, 0.0 -> 2953
% INFO    : Updated Thermal Rating: on line 3447-4966 : Rate B, Rate C , 0.0, 0.0 -> 2715
% INFO    : Updated Thermal Rating: on line 8145-3447 : Rate B, Rate C , 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 1542-6907 : Rate B, Rate C , 0.0, 0.0 -> 2495
% INFO    : Updated Thermal Rating: on line 816-1542 : Rate B, Rate C , 0.0, 0.0 -> 7692
% INFO    : Updated Thermal Rating: on line 816-1542 : Rate B, Rate C , 0.0, 0.0 -> 7547
% INFO    : Updated Thermal Rating: on line 1542-5824 : Rate B, Rate C , 0.0, 0.0 -> 2804
% INFO    : Updated Thermal Rating: on line 8145-8325 : Rate B, Rate C , 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 2887-4966 : Rate B, Rate C , 0.0, 0.0 -> 544
% INFO    : Updated Thermal Rating: on line 5092-2646 : Rate B, Rate C , 0.0, 0.0 -> 3708
% INFO    : Updated Thermal Rating: on line 2646-5503 : Rate B, Rate C , 0.0, 0.0 -> 2671
% INFO    : Updated Thermal Rating: on line 2646-6446 : Rate B, Rate C , 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 4961-2492 : Rate B, Rate C , 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 4961-3197 : Rate B, Rate C , 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 4961-2846 : Rate B, Rate C , 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 6930-9030 : Rate B, Rate C , 0.0, 0.0 -> 4408
% INFO    : Updated Thermal Rating: on line 5262-5503 : Rate B, Rate C , 0.0, 0.0 -> 9112
% INFO    : Updated Thermal Rating: on line 7448-7063 : Rate B, Rate C , 0.0, 0.0 -> 24570
% INFO    : Updated Thermal Rating: on line 7448-255 : Rate B, Rate C , 0.0, 0.0 -> 25560
% INFO    : Updated Thermal Rating: on line 1723-2051 : Rate B, Rate C , 0.0, 0.0 -> 28113
% INFO    : Updated Thermal Rating: on line 1337-846 : Rate B, Rate C , 0.0, 0.0 -> 3639
% INFO    : Updated Thermal Rating: on line 7448-1337 : Rate B, Rate C , 0.0, 0.0 -> 1948
% INFO    : Updated Thermal Rating: on line 7448-1337 : Rate B, Rate C , 0.0, 0.0 -> 1722
% INFO    : Updated Thermal Rating: on line 287-2807 : Rate B, Rate C , 0.0, 0.0 -> 3906
% INFO    : Updated Thermal Rating: on line 2807-4111 : Rate B, Rate C , 0.0, 0.0 -> 2209
% INFO    : Updated Thermal Rating: on line 7758-5503 : Rate B, Rate C , 0.0, 0.0 -> 11122
% INFO    : Updated Thermal Rating: on line 5503-846 : Rate B, Rate C , 0.0, 0.0 -> 3629
% INFO    : Updated Thermal Rating: on line 7448-5503 : Rate B, Rate C , 0.0, 0.0 -> 2209
% INFO    : Updated Thermal Rating: on line 2492-689 : Rate B, Rate C , 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 4055-5107 : Rate B, Rate C , 0.0, 0.0 -> 4869
% INFO    : Updated Thermal Rating: on line 4055-5819 : Rate B, Rate C , 0.0, 0.0 -> 2456
% INFO    : Updated Thermal Rating: on line 4055-9107 : Rate B, Rate C , 0.0, 0.0 -> 6334
% INFO    : Updated Thermal Rating: on line 4055-1118 : Rate B, Rate C , 0.0, 0.0 -> 3556
% INFO    : Updated Thermal Rating: on line 4055-1118 : Rate B, Rate C , 0.0, 0.0 -> 3627
% INFO    : Updated Thermal Rating: on line 287-8245 : Rate B, Rate C , 0.0, 0.0 -> 1248
% INFO    : Updated Thermal Rating: on line 7448-287 : Rate B, Rate C , 0.0, 0.0 -> 10341
% INFO    : Updated Thermal Rating: on line 7448-287 : Rate B, Rate C , 0.0, 0.0 -> 10267
% INFO    : Updated Thermal Rating: on line 7448-287 : Rate B, Rate C , 0.0, 0.0 -> 10247
% INFO    : Updated Thermal Rating: on line 9030-7562 : Rate B, Rate C , 0.0, 0.0 -> 3246
% INFO    : Updated Thermal Rating: on line 9030-5819 : Rate B, Rate C , 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 9030-6446 : Rate B, Rate C , 0.0, 0.0 -> 2734
% INFO    : Updated Thermal Rating: on line 7562-4111 : Rate B, Rate C , 0.0, 0.0 -> 2892
% INFO    : Updated Thermal Rating: on line 5107-8245 : Rate B, Rate C , 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 9107-5107 : Rate B, Rate C , 0.0, 0.0 -> 6891
% INFO    : Updated Thermal Rating: on line 5107-1723 : Rate B, Rate C , 0.0, 0.0 -> 1585
% INFO    : Updated Thermal Rating: on line 846-2294 : Rate B, Rate C , 0.0, 0.0 -> 3211
% INFO    : Updated Thermal Rating: on line 8760-2846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 8760-2846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 4111-6446 : Rate B, Rate C , 0.0, 0.0 -> 8045
% INFO    : Updated Thermal Rating: on line 1118-1723 : Rate B, Rate C , 0.0, 0.0 -> 3206
% INFO    : Updated Thermal Rating: on line 1118-1723 : Rate B, Rate C , 0.0, 0.0 -> 3269
% INFO    : Updated Thermal Rating: on line 5389-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 855
% INFO    : Updated Thermal Rating: on line 7724-4924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 8041-4924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 7870-4190 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 3940-6091 : Rate B, Rate C , 0.0, 0.0 -> 1178
% INFO    : Updated Thermal Rating: on line 3940-6091 : Rate B, Rate C , 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 3940-5389 : Rate B, Rate C , 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 3940-5389 : Rate B, Rate C , 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 956-8067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 3518-607 : Rate B, Rate C , 0.0, 0.0 -> 2455
% INFO    : Updated Thermal Rating: on line 7678-6091 : Rate B, Rate C , 0.0, 0.0 -> 5210
% INFO    : Updated Thermal Rating: on line 7678-6091 : Rate B, Rate C , 0.0, 0.0 -> 5294
% INFO    : Updated Thermal Rating: on line 1075-4063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 4063-8067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 8041-4063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 599-1683 : Rate B, Rate C , 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 599-1683 : Rate B, Rate C , 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 4242-7724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 446-4242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 5389-1683 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 5389-1683 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 5052-1683 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 5052-1683 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 446-7724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 4458-3464 : Rate B, Rate C , 0.0, 0.0 -> 11147
% INFO    : Updated Thermal Rating: on line 4458-5920 : Rate B, Rate C , 0.0, 0.0 -> 13517
% INFO    : Updated Thermal Rating: on line 813-5466 : Rate B, Rate C , 0.0, 0.0 -> 78577
% INFO    : Updated Thermal Rating: on line 813-5757 : Rate B, Rate C , 0.0, 0.0 -> 1806
% INFO    : Updated Thermal Rating: on line 813-5920 : Rate B, Rate C , 0.0, 0.0 -> 2561
% INFO    : Updated Thermal Rating: on line 813-2028 : Rate B, Rate C , 0.0, 0.0 -> 4344
% INFO    : Updated Thermal Rating: on line 4959-5466 : Rate B, Rate C , 0.0, 0.0 -> 1736
% INFO    : Updated Thermal Rating: on line 4959-6929 : Rate B, Rate C , 0.0, 0.0 -> 6226
% INFO    : Updated Thermal Rating: on line 4959-6588 : Rate A, Rate B, Rate C , 1905.0, 0.0, 0.0 -> 1243
% INFO    : Updated Thermal Rating: on line 4959-3464 : Rate B, Rate C , 0.0, 0.0 -> 12989
% INFO    : Updated Thermal Rating: on line 530-4654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 530-6324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 530-8648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 530-5734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 8-3212 : Rate B, Rate C , 0.0, 0.0 -> 46208
% INFO    : Updated Thermal Rating: on line 8-6237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 8-8472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 8-423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 3212-1664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 3212-8472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 1664-581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 1664-581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 1664-2370 : Rate B, Rate C , 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 9034-6237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 9034-151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on line 9034-4654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 9034-7363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19369
% INFO    : Updated Thermal Rating: on line 6237-151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on line 6237-8105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 6237-8770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19369
% INFO    : Updated Thermal Rating: on line 151-8472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 151-8472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 151-4090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 151-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 7326-2171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 7326-6324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 836
% INFO    : Updated Thermal Rating: on line 2171-6266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 3305-7733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 3305-6388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 4654-6536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 4654-4090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 4654-8218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 2408-6388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 2408-5734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 6266-8648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 6266-8218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on line 234-8105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 6536-7363 : Rate B, Rate C , 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 6388-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 6388-5734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 8472-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 423-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 6370-5757 : Rate B, Rate C , 0.0, 0.0 -> 7097
% INFO    : Updated Thermal Rating: on line 6588-1941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39374
% INFO    : Updated Thermal Rating: on line 6588-836 : Rate B, Rate C , 0.0, 0.0 -> 8604
% INFO    : Updated Thermal Rating: on line 6588-644 : Rate B, Rate C , 0.0, 0.0 -> 4898
% INFO    : Updated Thermal Rating: on line 6588-6300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7428
% INFO    : Updated Thermal Rating: on line 5757-3628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7290
% INFO    : Updated Thermal Rating: on line 5757-8793 : Rate B, Rate C , 0.0, 0.0 -> 21698
% INFO    : Updated Thermal Rating: on line 5757-836 : Rate B, Rate C , 0.0, 0.0 -> 13517
% INFO    : Updated Thermal Rating: on line 3628-8089 : Rate B, Rate C , 0.0, 0.0 -> 7290
% INFO    : Updated Thermal Rating: on line 3628-4455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on line 3628-7408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1184
% INFO    : Updated Thermal Rating: on line 3628-2028 : Rate B, Rate C , 0.0, 0.0 -> 4344
% INFO    : Updated Thermal Rating: on line 7962-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20154
% INFO    : Updated Thermal Rating: on line 7962-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20154
% INFO    : Updated Thermal Rating: on line 8793-836 : Rate B, Rate C , 0.0, 0.0 -> 35349
% INFO    : Updated Thermal Rating: on line 8793-8390 : Rate B, Rate C , 0.0, 0.0 -> 46958
% INFO    : Updated Thermal Rating: on line 6269-5427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2195
% INFO    : Updated Thermal Rating: on line 6269-5427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2195
% INFO    : Updated Thermal Rating: on line 6269-3045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 6269-8988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 6270-3386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 6270-3386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 6270-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1951
% INFO    : Updated Thermal Rating: on line 6270-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1951
% INFO    : Updated Thermal Rating: on line 6270-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 6270-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 7084-852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4908
% INFO    : Updated Thermal Rating: on line 4983-2001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3416
% INFO    : Updated Thermal Rating: on line 4983-2001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3416
% INFO    : Updated Thermal Rating: on line 4983-1983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11912
% INFO    : Updated Thermal Rating: on line 4983-1983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15411
% INFO    : Updated Thermal Rating: on line 4983-852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9949
% INFO    : Updated Thermal Rating: on line 4983-4061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9949
% INFO    : Updated Thermal Rating: on line 5427-2266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2737
% INFO    : Updated Thermal Rating: on line 5427-8928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2809
% INFO    : Updated Thermal Rating: on line 6198-7802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8755
% INFO    : Updated Thermal Rating: on line 6198-7802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8755
% INFO    : Updated Thermal Rating: on line 2266-8928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6050
% INFO    : Updated Thermal Rating: on line 120-5840 : Rate B, Rate C , 0.0, 0.0 -> 6338
% INFO    : Updated Thermal Rating: on line 120-2373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10624
% INFO    : Updated Thermal Rating: on line 120-6678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10347
% INFO    : Updated Thermal Rating: on line 2621-3386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 2621-3403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5981
% INFO    : Updated Thermal Rating: on line 2621-3403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5981
% INFO    : Updated Thermal Rating: on line 5840-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 5840-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 3045-3402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 3045-3402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 3045-8988 : Rate B, Rate C , 0.0, 0.0 -> 9714
% INFO    : Updated Thermal Rating: on line 3402-8928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 3402-8928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 3402-6731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 3402-6731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 2375-8122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11775
% INFO    : Updated Thermal Rating: on line 2375-8563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14040
% INFO    : Updated Thermal Rating: on line 3403-6545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2296
% INFO    : Updated Thermal Rating: on line 3403-6545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2296
% INFO    : Updated Thermal Rating: on line 2373-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7844
% INFO    : Updated Thermal Rating: on line 2373-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7844
% INFO    : Updated Thermal Rating: on line 872-4769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4226
% INFO    : Updated Thermal Rating: on line 872-4769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4226
% INFO    : Updated Thermal Rating: on line 6277-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9559
% INFO    : Updated Thermal Rating: on line 6277-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12377
% INFO    : Updated Thermal Rating: on line 6277-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10139
% INFO    : Updated Thermal Rating: on line 6277-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10139
% INFO    : Updated Thermal Rating: on line 6126-7288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27898
% INFO    : Updated Thermal Rating: on line 9129-7288 : Rate B, Rate C , 0.0, 0.0 -> 7005
% INFO    : Updated Thermal Rating: on line 9129-8563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12673
% INFO    : Updated Thermal Rating: on line 5282-7281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2616
% INFO    : Updated Thermal Rating: on line 5282-7281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2616
% INFO    : Updated Thermal Rating: on line 5282-7802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9218
% INFO    : Updated Thermal Rating: on line 5282-7802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9218
% INFO    : Updated Thermal Rating: on line 5122-5345 : Rate B, Rate C , 0.0, 0.0 -> 8525
% INFO    : Updated Thermal Rating: on line 8122-8563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5528
% INFO    : Updated Thermal Rating: on line 8122-4061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1933
% INFO    : Updated Thermal Rating: on line 7281-2298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 7281-2298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 4212-7277 : Rate B, Rate C , 0.0, 0.0 -> 4007
% INFO    : Updated Thermal Rating: on line 4212-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3385
% INFO    : Updated Thermal Rating: on line 7277-5200 : Rate B, Rate C , 0.0, 0.0 -> 7844
% INFO    : Updated Thermal Rating: on line 1941-8390 : Rate B, Rate C , 0.0, 0.0 -> 23479
% INFO    : Updated Thermal Rating: on line 8089-1827 : Rate B, Rate C , 0.0, 0.0 -> 10569
% INFO    : Updated Thermal Rating: on line 1594-1420 : Rate B, Rate C , 0.0, 0.0 -> 2201
% INFO    : Updated Thermal Rating: on line 1594-1420 : Rate B, Rate C , 0.0, 0.0 -> 2167
% INFO    : Updated Thermal Rating: on line 1594-8680 : Rate B, Rate C , 0.0, 0.0 -> 2305
% INFO    : Updated Thermal Rating: on line 1594-4917 : Rate B, Rate C , 0.0, 0.0 -> 4881
% INFO    : Updated Thermal Rating: on line 1594-7408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9721
% INFO    : Updated Thermal Rating: on line 1594-8714 : Rate A, Rate B, Rate C , 1282.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 1594-1738 : Rate A, Rate B, Rate C , 1490.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 1594-366 : Rate B, Rate C , 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 1594-4305 : Rate A, Rate B, Rate C , 935.0, 0.0, 0.0 -> 831
% INFO    : Updated Thermal Rating: on line 1420-1827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9155
% INFO    : Updated Thermal Rating: on line 1420-644 : Rate B, Rate C , 0.0, 0.0 -> 5995
% INFO    : Updated Thermal Rating: on line 1420-4917 : Rate B, Rate C , 0.0, 0.0 -> 3113
% INFO    : Updated Thermal Rating: on line 1420-4888 : Rate B, Rate C , 0.0, 0.0 -> 11301
% INFO    : Updated Thermal Rating: on line 8680-4455 : Rate B, Rate C , 0.0, 0.0 -> 2561
% INFO    : Updated Thermal Rating: on line 8680-4920 : Rate A, Rate B, Rate C , 2009.0, 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on line 8680-1152 : Rate A, Rate B, Rate C , 2044.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 8680-7378 : Rate B, Rate C , 0.0, 0.0 -> 3202
% INFO    : Updated Thermal Rating: on line 1827-7408 : Rate B, Rate C , 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 1827-6300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8971
% INFO    : Updated Thermal Rating: on line 644-4888 : Rate B, Rate C , 0.0, 0.0 -> 11301
% INFO    : Updated Thermal Rating: on line 3591-1291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2334
% INFO    : Updated Thermal Rating: on line 3591-2287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 1291-6674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 1291-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 1291-6123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 1291-6903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 6386-8366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 6386-2007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 467-1223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 467-1659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 467-2287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 1223-4078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3272
% INFO    : Updated Thermal Rating: on line 3135-4066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 3135-2336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 2693-1799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 2693-4777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on line 2693-8116 : Rate B, Rate C , 0.0, 0.0 -> 10078
% INFO    : Updated Thermal Rating: on line 2693-4303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 897-4292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7243
% INFO    : Updated Thermal Rating: on line 897-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 1799-8078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2127
% INFO    : Updated Thermal Rating: on line 1799-8078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2127
% INFO    : Updated Thermal Rating: on line 1799-2336 : Rate B, Rate C , 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 6674-8366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 9188-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 9188-777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 1312-8366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 258-5129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 946
% INFO    : Updated Thermal Rating: on line 258-5230 : Rate B, Rate C , 0.0, 0.0 -> 5179
% INFO    : Updated Thermal Rating: on line 258-4777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2106
% INFO    : Updated Thermal Rating: on line 258-5785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5071
% INFO    : Updated Thermal Rating: on line 258-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8683
% INFO    : Updated Thermal Rating: on line 6111-5291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 1659-8366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 8597-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 8597-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 8597-1244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3827
% INFO    : Updated Thermal Rating: on line 8597-2818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 8597-2818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 8597-777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 8597-777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 7888-4007 : Rate B, Rate C , 0.0, 0.0 -> 6329
% INFO    : Updated Thermal Rating: on line 4066-5129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16667
% INFO    : Updated Thermal Rating: on line 5128-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 5128-2287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 4221-8116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 4221-4303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 1169-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6329
% INFO    : Updated Thermal Rating: on line 1169-7263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8736
% INFO    : Updated Thermal Rating: on line 4630-4303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 608
% INFO    : Updated Thermal Rating: on line 4630-3140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1367
% INFO    : Updated Thermal Rating: on line 3143-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13107
% INFO    : Updated Thermal Rating: on line 3143-1230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11940
% INFO    : Updated Thermal Rating: on line 319-4086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7132
% INFO    : Updated Thermal Rating: on line 319-4086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7132
% INFO    : Updated Thermal Rating: on line 319-7263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10139
% INFO    : Updated Thermal Rating: on line 319-3168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 9103-43 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 9103-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 6646-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 6646-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 4007-7263 : Rate B, Rate C , 0.0, 0.0 -> 8736
% INFO    : Updated Thermal Rating: on line 5230-5113 : Rate B, Rate C , 0.0, 0.0 -> 8905
% INFO    : Updated Thermal Rating: on line 5230-5113 : Rate B, Rate C , 0.0, 0.0 -> 8905
% INFO    : Updated Thermal Rating: on line 9099-777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3025
% INFO    : Updated Thermal Rating: on line 4455-7408 : Rate B, Rate C , 0.0, 0.0 -> 158282
% INFO    : Updated Thermal Rating: on line 43-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 3783-5291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 4303-3140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 4303-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 3939-2818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33513
% INFO    : Updated Thermal Rating: on line 4078-8518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 4917-8714 : Rate A, Rate B, Rate C , 1386.0, 0.0, 0.0 -> 1319
% INFO    : Updated Thermal Rating: on line 2818-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 2818-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 7408-4305 : Rate A, Rate B, Rate C , 970.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 8657-8714 : Rate B, Rate C , 0.0, 0.0 -> 9644
% INFO    : Updated Thermal Rating: on line 8657-1881 : Rate B, Rate C , 0.0, 0.0 -> 1429
% INFO    : Updated Thermal Rating: on line 8657-7429 : Rate B, Rate C , 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 5434-8654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 5434-4173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 5434-4420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 4927-543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2700
% INFO    : Updated Thermal Rating: on line 4927-7032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 9052-8440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3841
% INFO    : Updated Thermal Rating: on line 9052-1134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2855
% INFO    : Updated Thermal Rating: on line 9052-1444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 8440-1444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 4628-5134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 4628-6175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 4628-2741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7652
% INFO    : Updated Thermal Rating: on line 4628-8654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 4628-8654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 7558-7964 : Rate B, Rate C , 0.0, 0.0 -> 5883
% INFO    : Updated Thermal Rating: on line 7558-7964 : Rate B, Rate C , 0.0, 0.0 -> 5883
% INFO    : Updated Thermal Rating: on line 7558-7032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1816
% INFO    : Updated Thermal Rating: on line 7558-3345 : Rate B, Rate C , 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 543-3989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 543-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 543-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 543-7032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 543-6123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 3989-7032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on line 109-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 109-4043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 109-5134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5899-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 2746-5134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 4043-6640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 4043-6175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 4043-1134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 4573-5134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4573-2281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 818
% INFO    : Updated Thermal Rating: on line 5134-2741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 5134-2281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 6640-6123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 8714-5846 : Rate A, Rate B, Rate C , 1801.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 6175-1134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on line 6175-1134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on line 8654-4420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 4173-2281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 1881-2775 : Rate B, Rate C , 0.0, 0.0 -> 2404
% INFO    : Updated Thermal Rating: on line 3459-1558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 3459-9182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 3459-2281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 3459-7188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 3459-1975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 1558-3336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 1558-2833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 3336-6890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 3336-6890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4633-6941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 4633-2281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 4633-7188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 4633-6850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 6941-1772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 2087-9182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 2087-1772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 9182-3590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 9182-2533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 9182-7188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 9182-3979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2350
% INFO    : Updated Thermal Rating: on line 9182-3979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2350
% INFO    : Updated Thermal Rating: on line 3590-185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 3590-7337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 3590-7337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 2533-185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 9061-2833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 9061-185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 2833-3501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 2833-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5846-2775 : Rate A, Rate B, Rate C , 1836.0, 0.0, 0.0 -> 1024
% INFO    : Updated Thermal Rating: on line 5293-7429 : Rate B, Rate C , 0.0, 0.0 -> 3721
% INFO    : Updated Thermal Rating: on line 5293-4567 : Rate A, Rate B, Rate C , 1143.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 5293-5934 : Rate B, Rate C , 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 5293-7658 : Rate B, Rate C , 0.0, 0.0 -> 3113
% INFO    : Updated Thermal Rating: on line 2793-5033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 2793-7926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 6728-5826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 6728-5040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 1975-5817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 9082-6123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 9082-4629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 8341-4955 : Rate B, Rate C , 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 8341-4891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 8341-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 8341-7238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8311
% INFO    : Updated Thermal Rating: on line 8341-7238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8311
% INFO    : Updated Thermal Rating: on line 5033-4042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 4627-8309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 5817-9220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 8584-9220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 8584-4768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 5431-7926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 7926-4629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 7926-2289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 7926-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 7926-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 4042-4955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 5826-5932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2876
% INFO    : Updated Thermal Rating: on line 5826-5932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2876
% INFO    : Updated Thermal Rating: on line 5826-5932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2876
% INFO    : Updated Thermal Rating: on line 5826-4955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 5826-4955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 5826-9220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5826-9220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 6123-4891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 6123-4629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 6123-6903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 7113-4629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 7113-9220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7970
% INFO    : Updated Thermal Rating: on line 7113-9220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7970
% INFO    : Updated Thermal Rating: on line 4629-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 4768-8309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 4768-4999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 6021-4567 : Rate B, Rate C , 0.0, 0.0 -> 3282
% INFO    : Updated Thermal Rating: on line 6021-2659 : Rate B, Rate C , 0.0, 0.0 -> 2746
% INFO    : Updated Thermal Rating: on line 6021-8317 : Rate B, Rate C , 0.0, 0.0 -> 121132
% INFO    : Updated Thermal Rating: on line 6021-8317 : Rate B, Rate C , 0.0, 0.0 -> 121132
% INFO    : Updated Thermal Rating: on line 6021-2775 : Rate B, Rate C , 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on line 6021-2683 : Rate B, Rate C , 0.0, 0.0 -> 4919
% INFO    : Updated Thermal Rating: on line 4567-2683 : Rate B, Rate C , 0.0, 0.0 -> 7102
% INFO    : Updated Thermal Rating: on line 4567-926 : Rate A, Rate B, Rate C , 1247.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 4567-926 : Rate A, Rate B, Rate C , 1940.0, 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on line 2659-2455 : Rate B, Rate C , 0.0, 0.0 -> 2631
% INFO    : Updated Thermal Rating: on line 2659-294 : Rate B, Rate C , 0.0, 0.0 -> 2893
% INFO    : Updated Thermal Rating: on line 1948-5367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 1948-5367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 787-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12773
% INFO    : Updated Thermal Rating: on line 787-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12773
% INFO    : Updated Thermal Rating: on line 787-2711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15360
% INFO    : Updated Thermal Rating: on line 787-2711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15360
% INFO    : Updated Thermal Rating: on line 3002-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4663
% INFO    : Updated Thermal Rating: on line 3002-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4663
% INFO    : Updated Thermal Rating: on line 3002-2711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8683
% INFO    : Updated Thermal Rating: on line 3002-2711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8683
% INFO    : Updated Thermal Rating: on line 4193-7654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 4193-7654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 7794-5028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 7794-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 9207-2735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3444
% INFO    : Updated Thermal Rating: on line 9207-1203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18789
% INFO    : Updated Thermal Rating: on line 9207-1958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3570
% INFO    : Updated Thermal Rating: on line 9207-334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 9207-7060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6765
% INFO    : Updated Thermal Rating: on line 5056-4980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15192
% INFO    : Updated Thermal Rating: on line 5056-3226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10347
% INFO    : Updated Thermal Rating: on line 1845-6073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18789
% INFO    : Updated Thermal Rating: on line 1845-9031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20832
% INFO    : Updated Thermal Rating: on line 1845-5118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14562
% INFO    : Updated Thermal Rating: on line 1845-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8450
% INFO    : Updated Thermal Rating: on line 1694-5118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4513
% INFO    : Updated Thermal Rating: on line 1694-5415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19656
% INFO    : Updated Thermal Rating: on line 2353-7654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3244
% INFO    : Updated Thermal Rating: on line 2353-7654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3244
% INFO    : Updated Thermal Rating: on line 3652-9031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11502
% INFO    : Updated Thermal Rating: on line 3652-8106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 3652-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3385
% INFO    : Updated Thermal Rating: on line 2711-7983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19369
% INFO    : Updated Thermal Rating: on line 2711-7983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19369
% INFO    : Updated Thermal Rating: on line 4319-3058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10624
% INFO    : Updated Thermal Rating: on line 4319-3058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10624
% INFO    : Updated Thermal Rating: on line 7689-2735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4975
% INFO    : Updated Thermal Rating: on line 7689-2735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4975
% INFO    : Updated Thermal Rating: on line 7689-334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 8106-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1722
% INFO    : Updated Thermal Rating: on line 4980-7654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 4980-9085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 5118-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18068
% INFO    : Updated Thermal Rating: on line 5118-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18068
% INFO    : Updated Thermal Rating: on line 5118-7677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5857
% INFO    : Updated Thermal Rating: on line 3156-1958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1081
% INFO    : Updated Thermal Rating: on line 3156-409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 3156-3253 : Rate B, Rate C , 0.0, 0.0 -> 13107
% INFO    : Updated Thermal Rating: on line 6170-5028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on line 6170-2808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 8203-3058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3752
% INFO    : Updated Thermal Rating: on line 8203-3058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3752
% INFO    : Updated Thermal Rating: on line 3226-7654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 3226-9085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 7814-5367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 7814-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 818
% INFO    : Updated Thermal Rating: on line 5028-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 5367-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 5367-9224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23121
% INFO    : Updated Thermal Rating: on line 9071-3058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 9071-5073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 1958-9085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 1958-9085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 8576-2514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 8576-4429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 6143-4609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 6143-2666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 6143-1097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 3501-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 2104-6890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 2104-5073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 4609-2215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 7754-409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1933
% INFO    : Updated Thermal Rating: on line 7754-409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1994
% INFO    : Updated Thermal Rating: on line 7754-7447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 7754-2514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 409-7060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 2215-7447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 6890-4429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19959
% INFO    : Updated Thermal Rating: on line 4999-5615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 4999-6525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 2666-5040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 2666-6525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 7227-926 : Rate B, Rate C , 0.0, 0.0 -> 3289
% INFO    : Updated Thermal Rating: on line 7227-7728 : Rate B, Rate C , 0.0, 0.0 -> 12187
% INFO    : Updated Thermal Rating: on line 926-7728 : Rate B, Rate C , 0.0, 0.0 -> 3730
% INFO    : Updated Thermal Rating: on line 926-7498 : Rate A, Rate B, Rate C , 1871.0, 0.0, 0.0 -> 1585
% INFO    : Updated Thermal Rating: on line 7728-2455 : Rate A, Rate B, Rate C , 1975.0, 0.0, 0.0 -> 1698
% INFO    : Updated Thermal Rating: on line 4308-4972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 4308-5411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 4106-8824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 4106-1442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 4524-325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 2808-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 2808-4266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 2808-1982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 5613-325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 5613-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 8008-8824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 8008-1213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 8008-4972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 8008-6945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 8824-6979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 3096-1474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 3096-1348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 3096-1440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 910-1042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 910-1042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 1213-1442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 1213-5411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 1442-1691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2349
% INFO    : Updated Thermal Rating: on line 1442-1529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 1442-5411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 1442-5411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 1691-3694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 1474-1440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 1474-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 1474-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 1474-41 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 2791-755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 2791-5536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1103
% INFO    : Updated Thermal Rating: on line 2791-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 1097-4266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 1097-1529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1517
% INFO    : Updated Thermal Rating: on line 4755-1348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 4755-8254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 5520-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1356
% INFO    : Updated Thermal Rating: on line 5520-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1356
% INFO    : Updated Thermal Rating: on line 5222-4972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 5222-6821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 755-5536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1232
% INFO    : Updated Thermal Rating: on line 1042-1348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 1042-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 1042-5204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 325-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 325-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on line 1348-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 4266-8254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 2182-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 2182-3694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 2182-1982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 7498-8248 : Rate B, Rate C , 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 6181-2436 : Rate B, Rate C , 0.0, 0.0 -> 2061
% INFO    : Updated Thermal Rating: on line 6181-2436 : Rate B, Rate C , 0.0, 0.0 -> 2492
% INFO    : Updated Thermal Rating: on line 6181-1925 : Rate B, Rate C , 0.0, 0.0 -> 1836
% INFO    : Updated Thermal Rating: on line 6181-3292 : Rate A, Rate B, Rate C , 2009.0, 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 2436-1925 : Rate B, Rate C , 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 2436-8248 : Rate A, Rate B, Rate C , 1593.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 1336-8135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on line 1336-5904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 8063-7179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 8063-1292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 8063-605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 8911-1589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 8911-6821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 8911-5105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 8911-8053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83913
% INFO    : Updated Thermal Rating: on line 8365-8177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 8365-8177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 8365-8177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 8365-1589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on line 8365-6821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 8365-6821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 8177-8682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 8177-8682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 8177-8682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 8135-5851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 8135-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 8135-8150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 7213-1589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3149
% INFO    : Updated Thermal Rating: on line 8682-41 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 6950-1292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 6950-1292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 1589-6821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2034
% INFO    : Updated Thermal Rating: on line 1589-1208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 1589-1208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 7179-5851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 7179-5851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 7179-5851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 7179-605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 7179-8150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on line 7179-347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 5851-1292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5851-7769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 6821-5904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 6821-5904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 5904-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 7158-7985 : Rate B, Rate C , 0.0, 0.0 -> 2331
% INFO    : Updated Thermal Rating: on line 7158-6518 : Rate B, Rate C , 0.0, 0.0 -> 4085
% INFO    : Updated Thermal Rating: on line 7158-4097 : Rate A, Rate B, Rate C , 1351.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 7985-6518 : Rate B, Rate C , 0.0, 0.0 -> 5121
% INFO    : Updated Thermal Rating: on line 7985-5921 : Rate B, Rate C , 0.0, 0.0 -> 5121
% INFO    : Updated Thermal Rating: on line 7985-7026 : Rate B, Rate C , 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on line 7985-2874 : Rate A, Rate B, Rate C , 1697.0, 0.0, 0.0 -> 1589
% INFO    : Updated Thermal Rating: on line 3317-6587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 3317-6507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 3317-3982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 3317-5090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 6782-6507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 6782-4278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 6782-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 6782-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 7173-1088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 7173-1088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 7173-2243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3188
% INFO    : Updated Thermal Rating: on line 1088-4514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 1088-6966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 774-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 774-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 1812-1938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 1812-1938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 1812-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 1812-7370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 1938-9151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 1938-302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 1938-6623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 1938-2810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 593
% INFO    : Updated Thermal Rating: on line 1938-2810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 593
% INFO    : Updated Thermal Rating: on line 1938-7567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 1938-5602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 7350-7379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 7350-7379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 2136-8226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 2136-6623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 2136-8202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 2136-5375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 8226-7614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 8226-6623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on line 8226-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 8226-5722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 8226-5602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 4449-4552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 4449-7623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4449-7623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4449-6623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 4449-6623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 4449-7481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27344
% INFO    : Updated Thermal Rating: on line 4449-7481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27344
% INFO    : Updated Thermal Rating: on line 4449-6473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 4449-8896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 4449-8790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 7140-6507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 7140-3982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 7140-3982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 7140-7223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 7140-7223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 7140-5090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 4109-6966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 4109-6966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 4109-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1952
% INFO    : Updated Thermal Rating: on line 4109-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1952
% INFO    : Updated Thermal Rating: on line 4109-8083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 4109-8083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 2881-8083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15411
% INFO    : Updated Thermal Rating: on line 2881-8083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15411
% INFO    : Updated Thermal Rating: on line 9151-4552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 9151-4552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 9151-8083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 9151-8202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 9151-7567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1595
% INFO    : Updated Thermal Rating: on line 4552-6473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 4552-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 4514-8083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1341
% INFO    : Updated Thermal Rating: on line 6966-6618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 6966-8083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3310
% INFO    : Updated Thermal Rating: on line 6966-1404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 6618-2243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 3426-6587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 3426-2082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 3426-6462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 6587-2082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 302-7614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 7623-7788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 7623-5722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on line 7623-2082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 7623-6142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 7623-534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3827
% INFO    : Updated Thermal Rating: on line 7623-534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3827
% INFO    : Updated Thermal Rating: on line 1378-2082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 1378-1935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 1378-6086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1933
% INFO    : Updated Thermal Rating: on line 7379-2082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3169
% INFO    : Updated Thermal Rating: on line 7379-5294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 7379-534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 7379-534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 7379-5090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 7379-5090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 1640-4452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16672
% INFO    : Updated Thermal Rating: on line 8083-1349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4172
% INFO    : Updated Thermal Rating: on line 8083-3230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6653
% INFO    : Updated Thermal Rating: on line 5722-6142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 5722-5375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 2810-5889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 2810-5889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 2810-5998 : Rate B, Rate C , 0.0, 0.0 -> 787
% INFO    : Updated Thermal Rating: on line 2082-6142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 6507-896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27898
% INFO    : Updated Thermal Rating: on line 6507-4278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 6462-2490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 5294-1935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 8202-6473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 8202-6473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 8202-2499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2895
% INFO    : Updated Thermal Rating: on line 8202-2499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2895
% INFO    : Updated Thermal Rating: on line 6142-4198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2855
% INFO    : Updated Thermal Rating: on line 6142-4198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2855
% INFO    : Updated Thermal Rating: on line 6518-1929 : Rate A, Rate B, Rate C , 1940.0, 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 2243-9069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 2243-9069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 3982-5090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 934
% INFO    : Updated Thermal Rating: on line 3982-5090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 3982-6086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 134-5921 : Rate B, Rate C , 0.0, 0.0 -> 2960
% INFO    : Updated Thermal Rating: on line 134-2874 : Rate A, Rate B, Rate C , 1697.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 1738-4920 : Rate B, Rate C , 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 366-2151 : Rate A, Rate B, Rate C , 1351.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 366-7658 : Rate B, Rate C , 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 2151-4920 : Rate B, Rate C , 0.0, 0.0 -> 4720
% INFO    : Updated Thermal Rating: on line 2151-8679 : Rate A, Rate B, Rate C , 1282.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 2151-5243 : Rate A, Rate B, Rate C , 1282.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 4920-4305 : Rate B, Rate C , 0.0, 0.0 -> 7562
% INFO    : Updated Thermal Rating: on line 4920-2325 : Rate B, Rate C , 0.0, 0.0 -> 6772
% INFO    : Updated Thermal Rating: on line 4920-6050 : Rate A, Rate B, Rate C , 2009.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 4920-4237 : Rate A, Rate B, Rate C , 2044.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 4305-7157 : Rate B, Rate C , 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 4305-2165 : Rate B, Rate C , 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 8434-2065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6338
% INFO    : Updated Thermal Rating: on line 8434-3269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2855
% INFO    : Updated Thermal Rating: on line 8434-2521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9559
% INFO    : Updated Thermal Rating: on line 8434-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 8434-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 8434-3564 : Rate B, Rate C , 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 8434-5321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5607
% INFO    : Updated Thermal Rating: on line 3872-3269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 3872-3269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2855
% INFO    : Updated Thermal Rating: on line 3872-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1561
% INFO    : Updated Thermal Rating: on line 3872-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 3872-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1561
% INFO    : Updated Thermal Rating: on line 3872-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 2065-3269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1367
% INFO    : Updated Thermal Rating: on line 2065-5708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9559
% INFO    : Updated Thermal Rating: on line 2065-3564 : Rate B, Rate C , 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 2768-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 2768-9102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 4255-4626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 4255-8695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4172
% INFO    : Updated Thermal Rating: on line 4255-8766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 8817-9 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 8817-3564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 8909-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 8909-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 9-2287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 8995-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 8995-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 7645-1235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 7645-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 7645-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 2325-5478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 2483-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 2483-5603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 2483-4530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 1892-6403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11918
% INFO    : Updated Thermal Rating: on line 1892-7746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1439
% INFO    : Updated Thermal Rating: on line 1892-7302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 1235-7746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 1235-824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 7746-9102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 7746-9102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 7746-6289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3269-5422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1586
% INFO    : Updated Thermal Rating: on line 3269-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 2137-5604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 2137-5321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9828
% INFO    : Updated Thermal Rating: on line 5422-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3767
% INFO    : Updated Thermal Rating: on line 4626-4749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 6044-8047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 6044-8047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 6044-3766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9570
% INFO    : Updated Thermal Rating: on line 6379-3564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 6379-3564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 6379-4749 : Rate B, Rate C , 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 6379-4749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 6379-6488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2409
% INFO    : Updated Thermal Rating: on line 6379-6488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2409
% INFO    : Updated Thermal Rating: on line 8047-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 5603-4530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 2324-6840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 2324-70 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 8695-9096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 9102-5604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 6840-5321 : Rate B, Rate C , 0.0, 0.0 -> 13107
% INFO    : Updated Thermal Rating: on line 70-5321 : Rate B, Rate C , 0.0, 0.0 -> 13107
% INFO    : Updated Thermal Rating: on line 3220-1152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 3220-7928 : Rate B, Rate C , 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 5478-7928 : Rate B, Rate C , 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 8305-7928 : Rate B, Rate C , 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 8305-4519 : Rate A, Rate B, Rate C , 1905.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on line 7928-8227 : Rate B, Rate C , 0.0, 0.0 -> 1553
% INFO    : Updated Thermal Rating: on line 7928-6124 : Rate A, Rate B, Rate C , 1455.0, 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 4582-434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 4582-5756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 8491-8039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 8491-6325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 1626-8733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 1626-7134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 1626-16 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 9087-8259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 9087-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 1113-6467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 1113-4071 : Rate B, Rate C , 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 1113-6700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 824-6400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 824-8543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 824-2405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 6400-8039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 6400-8259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 6400-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 6400-3625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 6400-3625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 8039-8259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 8733-5810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 8259-3708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 7134-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 8543-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 8543-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5356-434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 5356-3379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 434-4358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 6467-6325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 16-3708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 16-5756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1589
% INFO    : Updated Thermal Rating: on line 16-4199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 4412-7244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 4412-6087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 7244-6325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on line 4071-2141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 4688-7157 : Rate B, Rate C , 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 4688-9022 : Rate B, Rate C , 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 8945-2165 : Rate B, Rate C , 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 8945-9022 : Rate B, Rate C , 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 323-6740 : Rate B, Rate C , 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 323-6050 : Rate B, Rate C , 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 1126-4237 : Rate B, Rate C , 0.0, 0.0 -> 1374
% INFO    : Updated Thermal Rating: on line 1126-6781 : Rate B, Rate C , 0.0, 0.0 -> 1374
% INFO    : Updated Thermal Rating: on line 6740-715 : Rate A, Rate B, Rate C , 2009.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 6781-5432 : Rate A, Rate B, Rate C , 2044.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 8679-634 : Rate B, Rate C , 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 5243-634 : Rate B, Rate C , 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 634-715 : Rate A, Rate B, Rate C , 1247.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 634-6008 : Rate A, Rate B, Rate C , 1282.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 634-6008 : Rate A, Rate B, Rate C , 1282.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 9022-968 : Rate B, Rate C , 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 9022-5079 : Rate B, Rate C , 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 9022-3064 : Rate B, Rate C , 0.0, 0.0 -> 1918
% INFO    : Updated Thermal Rating: on line 9022-7083 : Rate A, Rate B, Rate C , 1975.0, 0.0, 0.0 -> 842
% INFO    : Updated Thermal Rating: on line 6551-2141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 6551-6700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 6551-4358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 6551-6535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 6551-6535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 6551-2547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 6551-7184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 2490-7581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 2490-668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 2141-160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 2141-6476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on line 2141-6476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on line 2141-3283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 3870-6087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 3870-3980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 3870-7302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 3870-6289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 3870-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 4358-160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1561
% INFO    : Updated Thermal Rating: on line 4358-160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 4358-160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 2952-160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 160-6476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 160-6476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 6476-1371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 6476-1371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 8297-7302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7652
% INFO    : Updated Thermal Rating: on line 8297-6289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7652
% INFO    : Updated Thermal Rating: on line 6087-2547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1875
% INFO    : Updated Thermal Rating: on line 820-7581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 820-7184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 7581-5287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 5845-3283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 5845-5287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 3980-668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5287-7949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 5287-7949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 5287-7184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 4097-1925 : Rate B, Rate C , 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 1925-1515 : Rate B, Rate C , 0.0, 0.0 -> 1590
% INFO    : Updated Thermal Rating: on line 1925-5934 : Rate B, Rate C , 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 7769-8523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 2119-2070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 2119-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 8996-8937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 8996-2070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 4812-1130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4812-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 4812-7749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 4812-4611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1451
% INFO    : Updated Thermal Rating: on line 4278-6578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 4278-6868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 1130-5788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on line 1130-6578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 1130-5838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 3439-2640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 3439-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 1460-863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 1460-863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 1460-8523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 1460-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 863-8937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 8937-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 8937-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 2640-5788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 8523-5244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 8523-4611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 1515-7083 : Rate B, Rate C , 0.0, 0.0 -> 1825
% INFO    : Updated Thermal Rating: on line 50-4459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 5244-6931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 5765-4611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 5615-5040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3700
% INFO    : Updated Thermal Rating: on line 5615-2477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5040-3803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5040-6979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 6931-3803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 6931-9138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 6931-7634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 2477-5599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 506
% INFO    : Updated Thermal Rating: on line 2477-6617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 2064-57 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 2064-3091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 2064-1433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 2064-5105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 57-8075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on line 57-6945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 3803-8766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3803-6979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5599-1433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 5599-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 8075-6617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1816
% INFO    : Updated Thermal Rating: on line 8075-1191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4172
% INFO    : Updated Thermal Rating: on line 3091-5864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on line 6617-6979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 9138-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 6401-2718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 6401-7570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on line 8227-6124 : Rate B, Rate C , 0.0, 0.0 -> 1995
% INFO    : Updated Thermal Rating: on line 6124-3304 : Rate B, Rate C , 0.0, 0.0 -> 8405
% INFO    : Updated Thermal Rating: on line 6124-3304 : Rate B, Rate C , 0.0, 0.0 -> 8405
% INFO    : Updated Thermal Rating: on line 6124-3475 : Rate B, Rate C , 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on line 6796-2718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 6796-3959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 2090-7094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 2090-5187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 2718-3959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 2718-7094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 6211-8262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 6211-3638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 7850-2524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 7850-4386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5810-5277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 5810-524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5564
% INFO    : Updated Thermal Rating: on line 5810-7355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 5810-2485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 5810-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 5810-5449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 8136-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 8136-3638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 8262-3424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 2-2447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 2-4898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12773
% INFO    : Updated Thermal Rating: on line 2007-4347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 2007-1024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 2007-2447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7652
% INFO    : Updated Thermal Rating: on line 2007-4898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12563
% INFO    : Updated Thermal Rating: on line 2007-8350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 2265-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 2265-8518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 152-8384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 8384-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1143
% INFO    : Updated Thermal Rating: on line 7906-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 7906-2405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 3785-2524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 3785-2405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 3785-6553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 3424-6553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 3424-5187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2607
% INFO    : Updated Thermal Rating: on line 8133-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 8133-7570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 623-7570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 623-4386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 7570-5277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 7570-7355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1148
% INFO    : Updated Thermal Rating: on line 7570-2485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1243
% INFO    : Updated Thermal Rating: on line 5277-7355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13672
% INFO    : Updated Thermal Rating: on line 5277-8326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13672
% INFO    : Updated Thermal Rating: on line 3638-4347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 3638-8350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 8326-2485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2734
% INFO    : Updated Thermal Rating: on line 3475-6893 : Rate A, Rate B, Rate C , 797.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 85-1906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 85-847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 85-847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 85-4377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 2414-3323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 2414-3799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 2414-7908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on line 2414-9074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 9123-5399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 9123-7217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 9123-5701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 9123-5023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 5399-847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 1906-3323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 3800-3799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 5597-3217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 5597-3217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 5597-3799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 5597-3799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 1573-3217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 1573-7995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 847-1846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 847-1846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 847-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 3323-4377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on line 3323-7908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3635-3799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 3635-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 655-4882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 655-2255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 655-9089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 486
% INFO    : Updated Thermal Rating: on line 3217-3799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3217-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 3217-5449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 3217-7995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 4377-4001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 3799-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 3799-7908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3799-9074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 4882-9089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 2452-7908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 2452-7908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 6893-2181 : Rate B, Rate C , 0.0, 0.0 -> 7570
% INFO    : Updated Thermal Rating: on line 1846-7217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 1846-4264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 7217-5023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 7217-4264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 7128-4225 : Rate A, Rate B, Rate C , 2009.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 7128-6085 : Rate A, Rate B, Rate C , 1871.0, 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 7128-2181 : Rate A, Rate B, Rate C , 1940.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 6951-2765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 6951-4722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 6951-2396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 5701-7206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 793-4001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 793-5667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 793-8323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 793-1157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41957
% INFO    : Updated Thermal Rating: on line 4001-5338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 7206-2255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 2765-5689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 3287-3521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 3287-5338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 3287-3055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 3287-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 6980-5264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1517
% INFO    : Updated Thermal Rating: on line 2599-5667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 2599-5667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 2599-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 2599-4722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 2599-4608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 5667-637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 3521-3458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 412-2826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 4722-2255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4722-4608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 5689-2255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5264-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 5264-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 3055-8323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 3055-168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 3458-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 203-5349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 4225-7642 : Rate A, Rate B, Rate C , 1905.0, 0.0, 0.0 -> 1053
% INFO    : Updated Thermal Rating: on line 7026-5432 : Rate B, Rate C , 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 320-5432 : Rate A, Rate B, Rate C , 1593.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 320-7780 : Rate B, Rate C , 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 320-7434 : Rate B, Rate C , 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 320-2874 : Rate A, Rate B, Rate C , 1905.0, 0.0, 0.0 -> 1851
% INFO    : Updated Thermal Rating: on line 320-4469 : Rate B, Rate C , 0.0, 0.0 -> 2960
% INFO    : Updated Thermal Rating: on line 320-5098 : Rate B, Rate C , 0.0, 0.0 -> 2480
% INFO    : Updated Thermal Rating: on line 320-3194 : Rate B, Rate C , 0.0, 0.0 -> 2338
% INFO    : Updated Thermal Rating: on line 715-5432 : Rate B, Rate C , 0.0, 0.0 -> 13607
% INFO    : Updated Thermal Rating: on line 715-6008 : Rate A, Rate B, Rate C , 1282.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 5432-4613 : Rate B, Rate C , 0.0, 0.0 -> 13043
% INFO    : Updated Thermal Rating: on line 5432-4613 : Rate B, Rate C , 0.0, 0.0 -> 13043
% INFO    : Updated Thermal Rating: on line 5432-4613 : Rate B, Rate C , 0.0, 0.0 -> 13043
% INFO    : Updated Thermal Rating: on line 5432-4613 : Rate B, Rate C , 0.0, 0.0 -> 13043
% INFO    : Updated Thermal Rating: on line 5432-3064 : Rate B, Rate C , 0.0, 0.0 -> 2558
% INFO    : Updated Thermal Rating: on line 7780-968 : Rate B, Rate C , 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 7434-5079 : Rate B, Rate C , 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 2874-5751 : Rate B, Rate C , 0.0, 0.0 -> 95327
% INFO    : Updated Thermal Rating: on line 3907-6008 : Rate A, Rate B, Rate C , 1767.0, 0.0, 0.0 -> 1360
% INFO    : Updated Thermal Rating: on line 3907-4519 : Rate B, Rate C , 0.0, 0.0 -> 3055
% INFO    : Updated Thermal Rating: on line 2241-6008 : Rate B, Rate C , 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 2241-6008 : Rate B, Rate C , 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 2241-3194 : Rate B, Rate C , 0.0, 0.0 -> 2506
% INFO    : Updated Thermal Rating: on line 2241-407 : Rate A, Rate B, Rate C , 2009.0, 0.0, 0.0 -> 1976
% INFO    : Updated Thermal Rating: on line 2241-407 : Rate A, Rate B, Rate C , 2009.0, 0.0, 0.0 -> 1976
% INFO    : Updated Thermal Rating: on line 6008-1117 : Rate B, Rate C , 0.0, 0.0 -> 22611
% INFO    : Updated Thermal Rating: on line 6008-1117 : Rate B, Rate C , 0.0, 0.0 -> 22611
% INFO    : Updated Thermal Rating: on line 6008-1117 : Rate B, Rate C , 0.0, 0.0 -> 22611
% INFO    : Updated Thermal Rating: on line 6008-6085 : Rate A, Rate B, Rate C , 1940.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 1044-5220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 1044-20 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 1044-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 5220-2979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 5220-5180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 5220-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 6228-8595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 6228-6751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 6228-8196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 5889-7683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on line 5889-4834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 20-2979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 20-3943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 20-8460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 2186-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 2186-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 2186-5430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 2186-5430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 2186-7147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 2186-7147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 3943-1329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 3943-8595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 3943-6498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 3943-6498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 3943-3822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2774
% INFO    : Updated Thermal Rating: on line 3943-3822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2774
% INFO    : Updated Thermal Rating: on line 1565-5538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 1565-7716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 1565-8121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 5800-1054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5800-7009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 454-7894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 454-6326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 454-5349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 1054-3379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 1054-7147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 1054-7147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 1054-3271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3336
% INFO    : Updated Thermal Rating: on line 1054-3271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3336
% INFO    : Updated Thermal Rating: on line 7370-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 4523-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 4523-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 4523-1329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 4523-3845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 5010-3271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5010-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 3660-4818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 3660-4818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 3660-5430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 3660-5430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 3660-4640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 4818-1329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on line 4818-1329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on line 1329-8100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 7009-7894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 7009-7894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 7009-5649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 5180-2584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 7894-4199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 7894-1612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 2584-4135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 2584-2346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 6326-7371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 6326-7013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 6326-2346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 6326-497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 5998-7386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1994
% INFO    : Updated Thermal Rating: on line 5998-5430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 5998-7977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 5538-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 5538-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 5538-1887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 5538-263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 286-7386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 286-5430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 286-7977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3444
% INFO    : Updated Thermal Rating: on line 5649-7371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 5649-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 5649-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 7386-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1517
% INFO    : Updated Thermal Rating: on line 5430-4640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 8391-5612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 8391-6136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 1357-3845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 4199-5349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 4199-1612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2391
% INFO    : Updated Thermal Rating: on line 4135-6136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 8595-6498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on line 8595-1186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 6294-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 6294-6751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 6294-5590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1525
% INFO    : Updated Thermal Rating: on line 6294-1186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 7716-8196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 2762-3693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 5612-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 5612-8121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 5612-5394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 5590-1186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 5590-8196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5590-5394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 4469-7789 : Rate B, Rate C , 0.0, 0.0 -> 2106
% INFO    : Updated Thermal Rating: on line 5098-5751 : Rate B, Rate C , 0.0, 0.0 -> 3267
% INFO    : Updated Thermal Rating: on line 9114-5683 : Rate B, Rate C , 0.0, 0.0 -> 2914
% INFO    : Updated Thermal Rating: on line 9114-7789 : Rate B, Rate C , 0.0, 0.0 -> 2669
% INFO    : Updated Thermal Rating: on line 1559-6136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 1559-6136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 313-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 2315-5394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16672
% INFO    : Updated Thermal Rating: on line 7013-3032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 407-8422 : Rate B, Rate C , 0.0, 0.0 -> 2037
% INFO    : Updated Thermal Rating: on line 3302-2396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3302-6812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 3302-2826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3302-2826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 7986-3568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 7986-4370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 1805-4457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 1805-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 1805-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10515
% INFO    : Updated Thermal Rating: on line 1805-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10515
% INFO    : Updated Thermal Rating: on line 2245-6812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2245-2491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1094
% INFO    : Updated Thermal Rating: on line 2245-541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 6030-251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 6030-2508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 6030-4870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 6030-735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 6030-735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 505-8085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 505-8085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 7527-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 7527-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 7527-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 7527-6281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 7527-3663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 723-982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 723-8085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 723-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 723-613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 723-613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 4517-6927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 4517-6812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 2346-251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 2346-251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 2346-705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on line 2346-497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 2346-3032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 2346-728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 3568-6812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 3568-7950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 2396-7950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 982-8085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 982-2076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on line 6281-1887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 251-4900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 705-2076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 705-5352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5564
% INFO    : Updated Thermal Rating: on line 2508-2491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 1887-3663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 6001-2400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 4870-6812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5744-5260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 5744-5260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 5744-2278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 5744-2278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 5744-4900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 5744-735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19959
% INFO    : Updated Thermal Rating: on line 5744-735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19959
% INFO    : Updated Thermal Rating: on line 6410-5240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 6410-828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76679
% INFO    : Updated Thermal Rating: on line 6410-3199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 6410-3199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 8359-3663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 8359-5240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 3663-263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 6927-4457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 6927-3199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 168-2400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 168-2400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 168-728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 3827-4370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 3827-3199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 5240-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 8422-7642 : Rate A, Rate B, Rate C , 1767.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 8422-5683 : Rate B, Rate C , 0.0, 0.0 -> 4736
% INFO    : Updated Thermal Rating: on line 3260-541 : Rate B, Rate C , 0.0, 0.0 -> 9980
% INFO    : Updated Thermal Rating: on line 358-3032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 7642-4050 : Rate A, Rate B, Rate C , 1767.0, 0.0, 0.0 -> 1184
% INFO    : Updated Thermal Rating: on line 5683-5581 : Rate B, Rate C , 0.0, 0.0 -> 2368
% INFO    : Updated Thermal Rating: on line 3292-1929 : Rate A, Rate B, Rate C , 1767.0, 0.0, 0.0 -> 1307
% INFO    : Updated Thermal Rating: on line 8110-7789 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4050-5581 : Rate A, Rate B, Rate C , 1593.0, 0.0, 0.0 -> 1263
% INFO    : Updated Thermal Rating: on line 5581-6746 : Rate B, Rate C , 0.0, 0.0 -> 7290
% INFO    : Updated Thermal Rating: on line 5785-7668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4610
% INFO    : Updated Thermal Rating: on line 7668-1230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13107
% INFO    : Updated Thermal Rating: on line 7677-5415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1477
% INFO    : Updated Thermal Rating: on line 6677-8254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157801
% INFO    : Updated Thermal Rating: on line 5023-9089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 5023-9089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 3693-8460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 8441-8121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83913
% INFO    : Updated Thermal Rating: on transformer 6077-6929 : Rate B, Rate C , 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on transformer 2935-4959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3879
% INFO    : Updated Thermal Rating: on transformer 436-4458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4516
% INFO    : Updated Thermal Rating: on transformer 6967-4635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on transformer 6967-4635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on transformer 1335-7131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 2474-7141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on transformer 2474-7141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 2474-7141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on transformer 8258-5657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on transformer 8258-5657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on transformer 7313-7931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on transformer 7931-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on transformer 7931-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on transformer 7931-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on transformer 273-8339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on transformer 273-8339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 1544-273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on transformer 1544-273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on transformer 6505-8826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on transformer 6505-8826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on transformer 5976-4329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on transformer 5976-4329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5989-4625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 5989-4625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on transformer 5989-4625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on transformer 106-2546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on transformer 5177-515 : Rate B, Rate C , 0.0, 0.0 -> 1000
% INFO    : Updated Thermal Rating: on transformer 5177-515 : Rate B, Rate C , 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on transformer 2203-7638 : Rate B, Rate C , 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on transformer 1363-7638 : Rate B, Rate C , 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on transformer 4463-7638 : Rate B, Rate C , 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 4463-3826 : Rate B, Rate C , 0.0, 0.0 -> 2250
% INFO    : Updated Thermal Rating: on transformer 6962-1829 : Rate B, Rate C , 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on transformer 6962-1829 : Rate B, Rate C , 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on transformer 4310-667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on transformer 4310-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1217
% INFO    : Updated Thermal Rating: on transformer 8228-5594 : Rate B, Rate C , 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 8228-5594 : Rate A, Rate B, Rate C , 724.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on transformer 3508-5847 : Rate B, Rate C , 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on transformer 3508-5847 : Rate B, Rate C , 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 4115-5847 : Rate B, Rate C , 0.0, 0.0 -> 2017
% INFO    : Updated Thermal Rating: on line 4115-3702 : Rate B, Rate C , 0.0, 0.0 -> 2179
% INFO    : Updated Thermal Rating: on transformer 345-298 : Rate B, Rate C , 0.0, 0.0 -> 2135
% INFO    : Updated Thermal Rating: on line 345-6762 : Rate B, Rate C , 0.0, 0.0 -> 2269
% INFO    : Updated Thermal Rating: on transformer 3025-3887 : Rate B, Rate C , 0.0, 0.0 -> 2419
% INFO    : Updated Thermal Rating: on transformer 7992-265 : Rate B, Rate C , 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on transformer 7992-265 : Rate B, Rate C , 0.0, 0.0 -> 1042
% INFO    : Updated Thermal Rating: on transformer 458-7393 : Rate B, Rate C , 0.0, 0.0 -> 2038
% INFO    : Updated Thermal Rating: on transformer 5718-4010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 2512-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on transformer 2512-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on transformer 7262-9177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on transformer 2738-7390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on transformer 2738-7390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on transformer 8612-5070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on transformer 963-3467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on transformer 963-3467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 3622-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on transformer 3622-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on transformer 2613-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on transformer 2613-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 353-8577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on transformer 353-8577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on transformer 4022-3856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on transformer 7105-2625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 871
% INFO    : Updated Thermal Rating: on transformer 7105-8172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 969
% INFO    : Updated Thermal Rating: on transformer 2682-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on transformer 3236-8398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 7285-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on transformer 7695-3936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 7695-3936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on transformer 5625-7695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on transformer 5625-7695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on transformer 6688-3790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on transformer 6688-5196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on transformer 8894-7768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on transformer 3098-7531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 3098-7531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 9024-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on transformer 9024-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on transformer 6069-9192 : Rate A, Rate B, Rate C , 691.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 6069-1968 : Rate B, Rate C , 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on transformer 7829-1968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8574-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 8574-5587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 4929-1815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on transformer 1815-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 6704-4586 : Rate A, Rate B, Rate C , 658.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 2441-3506 : Rate B, Rate C , 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on transformer 1367-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on transformer 1676-228 : Rate A, Rate B, Rate C , 658.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on transformer 7829-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on transformer 659-3279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on transformer 5210-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on transformer 1445-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on transformer 7180-2168 : Rate B, Rate C , 0.0, 0.0 -> 733
% INFO    : Updated Thermal Rating: on transformer 6833-8964 : Rate B, Rate C , 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on transformer 3659-3242 : Rate A, Rate B, Rate C , 691.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 8181-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on transformer 9025-7563 : Rate A, Rate B, Rate C , 658.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on transformer 2267-5210 : Rate B, Rate C , 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 5210-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 5210-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on transformer 5210-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 5210-4665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 5210-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8179-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on transformer 1445-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 5509-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 5509-1531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on transformer 1445-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 7762-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on transformer 7762-271 : Rate A, Rate B, Rate C , 691.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on transformer 7829-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on transformer 8329-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on transformer 8329-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on transformer 1445-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 1445-4665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 2268-2908 : Rate A, Rate B, Rate C , 724.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on transformer 8847-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on transformer 8847-8103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on transformer 317-2449 : Rate A, Rate B, Rate C , 658.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on transformer 7637-8581 : Rate B, Rate C , 0.0, 0.0 -> 2038
% INFO    : Updated Thermal Rating: on transformer 5848-7526 : Rate B, Rate C , 0.0, 0.0 -> 3280
% INFO    : Updated Thermal Rating: on transformer 89-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 2520-4665 : Rate B, Rate C , 0.0, 0.0 -> 705
% INFO    : Updated Thermal Rating: on transformer 5996-8420 : Rate B, Rate C , 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 2154-5996 : Rate B, Rate C , 0.0, 0.0 -> 3191
% INFO    : Updated Thermal Rating: on transformer 6999-4008 : Rate B, Rate C , 0.0, 0.0 -> 1800
% INFO    : Updated Thermal Rating: on transformer 4008-5521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on transformer 4008-5521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on transformer 3173-8768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on transformer 3173-8768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on transformer 5055-1450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on transformer 5055-9237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on transformer 6568-5424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on transformer 6568-5424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on transformer 888-4877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 4388-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on transformer 4388-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on transformer 7572-5954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on transformer 7572-5954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on transformer 3440-4599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on transformer 3440-4599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on transformer 9010-8830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 9010-8830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on transformer 921-4570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on transformer 7790-3437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 8885-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on transformer 1263-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 1263-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on transformer 2677-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on transformer 2677-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on transformer 2386-2068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on transformer 5160-572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 1438-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on transformer 1438-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 1438-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on transformer 2419-7336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on transformer 2419-7336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on transformer 1668-9145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on transformer 3885-9144 : Rate B, Rate C , 0.0, 0.0 -> 2528
% INFO    : Updated Thermal Rating: on transformer 9144-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 9144-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on transformer 6046-1098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on transformer 8322-6434 : Rate B, Rate C , 0.0, 0.0 -> 3363
% INFO    : Updated Thermal Rating: on transformer 2041-6006 : Rate B, Rate C , 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on transformer 6006-3669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on transformer 6006-3669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on transformer 8551-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on transformer 8551-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on transformer 1922-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on transformer 9194-3141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on transformer 9194-3141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 5497-8408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on transformer 5497-8408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on transformer 1143-5082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 1143-5082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on transformer 1506-4304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on transformer 1506-4304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on transformer 3981-36 : Rate B, Rate C , 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on transformer 3981-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on transformer 36-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on transformer 2110-4184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on transformer 665-4028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 1820-7456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on transformer 4788-8978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on transformer 6158-4518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on transformer 6158-4518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 797
% INFO    : Updated Thermal Rating: on transformer 7455-3505 : Rate B, Rate C , 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on transformer 1199-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on transformer 6775-5438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on transformer 6775-5438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on transformer 3433-4540 : Rate B, Rate C , 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on transformer 8905-4631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on transformer 3494-5807 : Rate B, Rate C , 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on transformer 4938-2987 : Rate B, Rate C , 0.0, 0.0 -> 1216
% INFO    : Updated Thermal Rating: on transformer 1557-3569 : Rate B, Rate C , 0.0, 0.0 -> 1896
% INFO    : Updated Thermal Rating: on transformer 3277-2487 : Rate B, Rate C , 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on transformer 1369-6520 : Rate B, Rate C , 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on transformer 5778-6433 : Rate B, Rate C , 0.0, 0.0 -> 1141
% INFO    : Updated Thermal Rating: on transformer 5778-6433 : Rate B, Rate C , 0.0, 0.0 -> 1166
% INFO    : Updated Thermal Rating: on transformer 1679-381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on transformer 1615-381 : Rate A, Rate B, Rate C , 468.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on transformer 4201-7219 : Rate B, Rate C , 0.0, 0.0 -> 1515
% INFO    : Updated Thermal Rating: on transformer 4079-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2874
% INFO    : Updated Thermal Rating: on transformer 4079-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2820
% INFO    : Updated Thermal Rating: on transformer 4830-4176 : Rate B, Rate C , 0.0, 0.0 -> 1683
% INFO    : Updated Thermal Rating: on transformer 6666-2191 : Rate B, Rate C , 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on transformer 6666-2191 : Rate B, Rate C , 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 1653-3973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on transformer 1653-3973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 913
% INFO    : Updated Thermal Rating: on transformer 2716-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1204
% INFO    : Updated Thermal Rating: on transformer 2716-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on transformer 6375-4762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 6375-4762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 611-5905 : Rate B, Rate C , 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on transformer 2153-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on transformer 3290-291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on transformer 5343-3340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on transformer 1884-2588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1409
% INFO    : Updated Thermal Rating: on transformer 6848-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 5523-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 2891-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 4737-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 63-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 7082-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on transformer 8336-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 1268-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 6848-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 5523-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 7082-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 1268-7410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 5401-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 6284-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 6272-2631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 6272-1144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 6272-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 92-7786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 4737-7786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9211-7786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2724-7786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 92-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 4737-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9211-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2724-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8851-4012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 8851-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 8851-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 8851-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 8851-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 8851-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 8851-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 8851-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 8851-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 8851-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 8851-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 8553-4012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 192-4012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 3349-4012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 5495-4012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 6894-4012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 9100-4012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 5717-4012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 6222-4012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 7035-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on transformer 7035-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on transformer 7035-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on transformer 7502-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 4101-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2511-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 1522-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 4866-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 6724-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8429-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 7816-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 5428-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 8762-8498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 2306-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 1667-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 3514-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 7102-7711 : Rate B, Rate C , 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on transformer 4645-7711 : Rate B, Rate C , 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on transformer 92-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 6848-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5523-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2891-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 4737-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 63-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 9211-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 8336-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2724-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 8553-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 8553-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 8553-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 8553-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 8553-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 8553-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on transformer 8553-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 8553-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 8553-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8553-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8553-3860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on transformer 6584-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 9037-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 6497-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 4766-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 4296-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 5611-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 4647-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 7483-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 6584-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on transformer 6584-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on transformer 6584-5301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 6584-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 6584-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 9037-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on transformer 9037-6715 : Rate B, Rate C , 0.0, 0.0 -> 2467
% INFO    : Updated Thermal Rating: on transformer 9037-5301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 9037-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 9037-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on transformer 6497-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 4766-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 4296-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 5611-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 4647-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 7483-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 424-5439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3621
% INFO    : Updated Thermal Rating: on transformer 6497-2222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3818
% INFO    : Updated Thermal Rating: on transformer 6497-5301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6497-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6497-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2016-8929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 8517-8929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 2016-7457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 8517-7457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 4334-818 : Rate A, Rate B, Rate C , 954.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on transformer 4334-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 4334-7299 : Rate B, Rate C , 0.0, 0.0 -> 2955
% INFO    : Updated Thermal Rating: on transformer 8421-2608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 8421-9077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 8421-7321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on transformer 92-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 92-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 92-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 92-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 92-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 92-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 92-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 92-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 92-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 92-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 92-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 92-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 92-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 92-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 4766-5301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 4296-5301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on transformer 5611-5301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on transformer 4647-5301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 7483-5301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 4766-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 4296-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 5611-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 4647-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 7483-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 6848-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6848-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6848-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6848-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 6848-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6848-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 6848-6718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6848-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 6848-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 6848-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6848-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 6848-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 6848-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 6848-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 6848-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 6848-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6848-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6848-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 5523-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5523-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5523-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5523-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5523-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5523-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 5523-6718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5523-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 5523-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 5523-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5523-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 5523-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 5523-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 5523-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 5523-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 5523-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5523-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5523-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 5941-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 192-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 192-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 192-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 192-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 192-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 192-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 192-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 192-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 192-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 192-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 3349-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 3349-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 3349-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 3349-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 3349-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 3349-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 3349-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 3349-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 3349-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 3349-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 5495-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 6894-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 9100-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 5717-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 6222-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 5495-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 6894-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 9100-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 5717-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 6222-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 6554-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on transformer 2016-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 8517-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 4766-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 2016-7198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 2016-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 8517-7198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 8517-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 1079-7198 : Rate B, Rate C , 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on transformer 6847-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 6847-98 : Rate B, Rate C , 0.0, 0.0 -> 818
% INFO    : Updated Thermal Rating: on transformer 2306-2912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 1667-2912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 3514-2912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 5102-2788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 5102-9077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 1811-2788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 1811-9077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 5495-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 6894-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 9100-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 5717-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 6222-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 5495-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 6894-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 9100-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 5717-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 6222-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 5495-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 5495-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 5495-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 5495-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 5495-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on transformer 5495-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 4296-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 5611-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on transformer 2891-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 4737-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 9211-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 7082-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8336-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 1268-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 1493-2895 : Rate B, Rate C , 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on transformer 2891-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 4737-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 9211-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 7082-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8336-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 1268-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2891-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 4737-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 9211-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 7082-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8336-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 1268-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 6894-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 9100-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 5717-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 6222-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 6894-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 9100-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 5717-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 6222-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 7093-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 7093-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 7093-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 7093-4085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 7207-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 7207-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 7207-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 7207-4085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59
% INFO    : Updated Thermal Rating: on transformer 6894-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 9100-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 5717-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 6222-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 2891-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 2891-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 2891-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2891-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2891-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2891-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 2891-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 2891-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 2891-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 2891-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2891-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2891-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2891-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 2891-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2891-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 4737-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 4737-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 4737-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 4737-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 4737-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 4737-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 4737-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 4737-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 4737-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 4737-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 4737-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 4737-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 4737-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 4737-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 4737-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6894-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 6894-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 6894-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 9100-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 5717-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 6222-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 491-8934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 994
% INFO    : Updated Thermal Rating: on transformer 491-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 491-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 491-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 491-4085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 7545-6173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on transformer 9100-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5717-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6222-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 9100-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 5717-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6222-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on transformer 324-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 5862-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 4052-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 324-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 5862-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 4052-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 63-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 9211-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 7082-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8336-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 2724-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 1268-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 63-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 9211-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 7082-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8336-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 2724-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 1268-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 324-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 324-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 324-4085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 7082-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 1268-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 7082-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 1268-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 63-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 63-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 63-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 63-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 63-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on transformer 63-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 63-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 63-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 63-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 63-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 63-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9211-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 8336-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2724-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 1268-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 7082-5596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 7082-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 4647-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 6538-1944 : Rate B, Rate C , 0.0, 0.0 -> 2462
% INFO    : Updated Thermal Rating: on transformer 8333-1962 : Rate B, Rate C , 0.0, 0.0 -> 2659
% INFO    : Updated Thermal Rating: on transformer 7135-629 : Rate B, Rate C , 0.0, 0.0 -> 916
% INFO    : Updated Thermal Rating: on transformer 8336-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8336-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9211-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 9211-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 9211-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 9211-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 9211-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9211-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9211-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 9211-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 9211-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 9211-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 6485-4424 : Rate B, Rate C , 0.0, 0.0 -> 1000
% INFO    : Updated Thermal Rating: on transformer 6485-7189 : Rate B, Rate C , 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on transformer 7082-8182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 1268-8182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 7082-6718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 1268-6718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 7082-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 7082-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 7082-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 7082-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 7082-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 7082-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 7082-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 7082-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 7082-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 4849-7500 : Rate B, Rate C , 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on transformer 4849-4702 : Rate B, Rate C , 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on transformer 1268-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 1268-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 8336-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 8336-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8336-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8336-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8336-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8336-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8336-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8336-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 8336-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8336-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8336-1067 : Rate B, Rate C , 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on transformer 2724-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 1268-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2724-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 1268-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 4535-4789 : Rate B, Rate C , 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on transformer 2724-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 2724-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 2724-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2724-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2724-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 2724-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2724-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2724-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 1268-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 1268-7592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 1268-5440 : Rate B, Rate C , 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on transformer 1268-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 1268-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 1268-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 1268-1581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 1268-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 1268-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6222-5142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on transformer 5862-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 4052-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 5862-4085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 4052-4085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 7483-6978 : Rate B, Rate C , 0.0, 0.0 -> 1709
% INFO    : Updated Thermal Rating: on transformer 7483-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 8193-2196 : Rate B, Rate C , 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on transformer 8193-2196 : Rate B, Rate C , 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on transformer 7650-3606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 2532-3606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on transformer 1663-2883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 7966-2883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 5100-2883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 1588-2883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 2890-2883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on transformer 1663-6197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 6605-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 8855-56 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 2420-5088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on transformer 2420-5088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on transformer 1663-3944 : Rate B, Rate C , 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on transformer 1663-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on transformer 1663-4971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 1663-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on transformer 1663-397 : Rate B, Rate C , 0.0, 0.0 -> 2063
% INFO    : Updated Thermal Rating: on transformer 4637-1675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 4637-3539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 8855-1624 : Rate B, Rate C , 0.0, 0.0 -> 1666
% INFO    : Updated Thermal Rating: on transformer 8855-1624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 8855-7127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 8855-9165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on transformer 3835-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 4366-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 2385-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 6605-5325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 6605-4167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 7966-3537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 7966-5869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 2906-1675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 7920-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 2080-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 7424-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 6193-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on transformer 5100-3537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 5100-5869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 1588-3537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on transformer 1588-5869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 7617-1346 : Rate B, Rate C , 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on transformer 4634-5622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 2138-5622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on transformer 2906-5622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 6274-5622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 1994-8916 : Rate B, Rate C , 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on transformer 1994-6586 : Rate B, Rate C , 0.0, 0.0 -> 1818
% INFO    : Updated Thermal Rating: on transformer 2906-3539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on transformer 6605-2663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on transformer 6605-4804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 6605-7602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 6274-2901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on transformer 7914-1627 : Rate B, Rate C , 0.0, 0.0 -> 831
% INFO    : Updated Thermal Rating: on transformer 7914-1627 : Rate B, Rate C , 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on transformer 2890-3537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 2890-5869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 8725-5433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on transformer 6965-5433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 6906-5433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 5754-5433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 6227-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on transformer 3784-6418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 2409-6418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 4578-6418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 6524-7097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 5969-7097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 2429-7097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 3116-7748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 9160-7748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 1148-8113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 7116-8113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 1400-7609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 1400-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 8187-7609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 8187-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 3149-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 1214-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 1253-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on transformer 5528-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 4786-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 6027-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 4294-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 5380-4151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on transformer 7399-3905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 3784-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 2409-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 4578-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 3784-4593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on transformer 6083-4593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 2409-4593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 4578-4593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 3160-4593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 3116-8216 : Rate A, Rate B, Rate C , 1185.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on transformer 3116-5779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on transformer 3116-5779 : Rate B, Rate C , 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on transformer 3116-6997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 6470-4466 : Rate B, Rate C , 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on transformer 6965-8955 : Rate B, Rate C , 0.0, 0.0 -> 2006
% INFO    : Updated Thermal Rating: on transformer 8725-3934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on transformer 6965-3934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on transformer 1148-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 1148-8798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 1148-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 7444-4154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 6083-4154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 7444-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 7444-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on transformer 7444-3479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 7444-5232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 7444-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 7444-3777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 7444-5261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 7444-7620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 3225-7451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 4121-7451 : Rate B, Rate C , 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on transformer 6589-7451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 798-7451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 4500-7451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 6906-3934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 5754-3934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 2486-2443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 8427-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 2176-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 1823-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 3583-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 6864-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 6413-167 : Rate B, Rate C , 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on transformer 9160-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on transformer 6083-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 6083-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 3160-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 1323-4151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on transformer 3655-4151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 6589-6321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on transformer 798-6321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 4500-6321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 1214-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on transformer 8427-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 2176-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 1823-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 3583-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 6864-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 6083-7997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 3160-7997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 8427-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 2176-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 1823-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 3583-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 6864-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 8687-8427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14864
% INFO    : Updated Thermal Rating: on transformer 8427-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 8427-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 8427-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 8427-8451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 2176-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on transformer 2176-5152 : Rate B, Rate C , 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on transformer 1823-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 3583-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on transformer 6864-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 2176-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2176-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2176-8451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 829-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on transformer 5754-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 7399-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on transformer 4501-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 9088-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 8388-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 7731-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 7731-417 : Rate B, Rate C , 0.0, 0.0 -> 1835
% INFO    : Updated Thermal Rating: on transformer 7731-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on transformer 6977-8503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on transformer 4501-3617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 9088-3617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 8388-3617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 4501-296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 9088-296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 8388-296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 9080-8059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 1765-8059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 624-8059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 1485-8059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 4718-8059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 798-6886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 798-7161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 6977-1949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 584-5530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 584-2223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 9154-4522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on transformer 7942-4522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 9154-1707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 7942-1707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 1823-8123 : Rate B, Rate C , 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on transformer 1823-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 1823-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 1823-8451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 3583-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6864-8134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 3583-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6864-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 7399-540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 9080-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 9080-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on transformer 9080-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 1765-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 1765-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 1765-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 5116-5530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 5116-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 2260-5530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 2260-2223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 4501-4268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 9088-4268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 8388-4268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 3583-8451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 3225-3261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 9154-683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 9154-7360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 9154-4557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 330-5530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on transformer 7781-5530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 873-5530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 6343-5530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 624-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 624-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 624-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 1485-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 4718-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 6977-822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 6864-8451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 6083-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 3225-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 79-6886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 79-7161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 6083-2610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 3160-2610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 8759-3479 : Rate B, Rate C , 0.0, 0.0 -> 1602
% INFO    : Updated Thermal Rating: on transformer 6083-3479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 5491-5673 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on transformer 5491-5673 : Rate B, Rate C , 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on transformer 5914-5673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 6524-8516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 6524-7655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 5969-8516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 5969-7655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 1485-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 1485-6603 : Rate B, Rate C , 0.0, 0.0 -> 1906
% INFO    : Updated Thermal Rating: on transformer 4718-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 1485-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 2429-8516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 2429-8516 : Rate B, Rate C , 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on transformer 2429-7655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 6083-5232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 6083-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on transformer 6083-3777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 6083-5261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 6083-7620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 5914-2223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on transformer 3160-8552 : Rate B, Rate C , 0.0, 0.0 -> 1909
% INFO    : Updated Thermal Rating: on transformer 7116-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on transformer 7942-683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 7399-683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 7399-3854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 7116-8798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 6164-8033 : Rate B, Rate C , 0.0, 0.0 -> 1686
% INFO    : Updated Thermal Rating: on transformer 4500-6886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 4500-7161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 9160-8639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 9160-5580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 330-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 7781-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on transformer 8899-1508 : Rate B, Rate C , 0.0, 0.0 -> 1858
% INFO    : Updated Thermal Rating: on transformer 9160-5324 : Rate B, Rate C , 0.0, 0.0 -> 2040
% INFO    : Updated Thermal Rating: on transformer 7942-7360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 7942-4557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 7116-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 7116-1657 : Rate B, Rate C , 0.0, 0.0 -> 1753
% INFO    : Updated Thermal Rating: on transformer 7116-8778 : Rate B, Rate C , 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on transformer 7803-7620 : Rate B, Rate C , 0.0, 0.0 -> 1825
% INFO    : Updated Thermal Rating: on transformer 7803-7620 : Rate B, Rate C , 0.0, 0.0 -> 1887
% INFO    : Updated Thermal Rating: on transformer 4718-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on transformer 4501-1497 : Rate B, Rate C , 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on transformer 8388-1773 : Rate B, Rate C , 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on transformer 873-2223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 6343-2223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 6343-3155 : Rate A, Rate B, Rate C , 1185.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on transformer 8779-8414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 8779-6794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 4670-7006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on transformer 4670-7006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on transformer 1900-8944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1900-2852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 1900-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 1900-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 511-8944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 3396-8944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 7799-8198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 6956-8198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 7680-6621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 7680-4122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 6466-6621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 6466-4122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 8256-8414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on transformer 8256-6794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 2192-4218 : Rate B, Rate C , 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on transformer 2192-2418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on transformer 6900-2736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 6458-2852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 511-2852 : Rate B, Rate C , 0.0, 0.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 511-2852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on transformer 511-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 511-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 8415-2852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 3396-2852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 3396-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 6900-3759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on transformer 7934-6621 : Rate B, Rate C , 0.0, 0.0 -> 1379
% INFO    : Updated Thermal Rating: on transformer 7934-6621 : Rate B, Rate C , 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on transformer 1601-193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on transformer 3396-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on transformer 5986-2418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on transformer 4732-5584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on transformer 2932-5584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on transformer 1601-5880 : Rate B, Rate C , 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on transformer 1601-5880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 1601-5880 : Rate B, Rate C , 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on transformer 7799-5880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on transformer 6956-5880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 6900-3189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on transformer 3057-7741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on transformer 3057-7741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on transformer 197-7741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 2309-8414 : Rate B, Rate C , 0.0, 0.0 -> 3099
% INFO    : Updated Thermal Rating: on transformer 2309-8414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 2309-6794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 503-8414 : Rate B, Rate C , 0.0, 0.0 -> 2451
% INFO    : Updated Thermal Rating: on transformer 503-8414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on transformer 503-6794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 6457-7514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on transformer 4498-3189 : Rate B, Rate C , 0.0, 0.0 -> 2729
% INFO    : Updated Thermal Rating: on transformer 4498-3189 : Rate B, Rate C , 0.0, 0.0 -> 2788
% INFO    : Updated Thermal Rating: on transformer 197-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 197-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1015
% INFO    : Updated Thermal Rating: on transformer 7692-4384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 7692-4384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on transformer 7843-4871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on transformer 6159-2530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 6159-2530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4569-5702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on transformer 4569-5702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on transformer 2175-4515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 2175-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 7876-5794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on transformer 5600-7708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1171
% INFO    : Updated Thermal Rating: on transformer 6653-8761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on transformer 1636-4228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on transformer 1636-4228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on transformer 1953-8611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on transformer 7416-2069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on transformer 7416-2069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on transformer 5046-2069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2368
% INFO    : Updated Thermal Rating: on transformer 285-8032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on transformer 4217-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on transformer 4217-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 8206-7559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on transformer 6492-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on transformer 3525-222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on transformer 5101-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1205
% INFO    : Updated Thermal Rating: on transformer 6084-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on transformer 4241-2248 : Rate B, Rate C , 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on transformer 4717-5787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on transformer 5425-7431 : Rate B, Rate C , 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on transformer 5425-7431 : Rate B, Rate C , 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on transformer 6632-3650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on transformer 6632-3650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1242
% INFO    : Updated Thermal Rating: on transformer 6917-4958 : Rate B, Rate C , 0.0, 0.0 -> 1521
% INFO    : Updated Thermal Rating: on transformer 2962-8888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on transformer 2962-8888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on transformer 4542-7510 : Rate B, Rate C , 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on transformer 4542-7510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 1549-3282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 1549-3282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on transformer 1549-3282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on transformer 1200-3549 : Rate B, Rate C , 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on transformer 6771-4806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on transformer 1086-6443 : Rate B, Rate C , 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on transformer 1086-6443 : Rate B, Rate C , 0.0, 0.0 -> 1591
% INFO    : Updated Thermal Rating: on transformer 9159-6499 : Rate B, Rate C , 0.0, 0.0 -> 1640
% INFO    : Updated Thermal Rating: on transformer 9159-6499 : Rate B, Rate C , 0.0, 0.0 -> 1706
% INFO    : Updated Thermal Rating: on transformer 5685-3378 : Rate B, Rate C , 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on transformer 693-6994 : Rate B, Rate C , 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on transformer 693-6994 : Rate B, Rate C , 0.0, 0.0 -> 1919
% INFO    : Updated Thermal Rating: on transformer 5332-3633 : Rate B, Rate C , 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on transformer 5332-3633 : Rate B, Rate C , 0.0, 0.0 -> 1258
% INFO    : Updated Thermal Rating: on line 8034-4020 : Rate B, Rate C , 0.0, 0.0 -> 5702
% INFO    : Updated Thermal Rating: on transformer 1985-1023 : Rate B, Rate C , 0.0, 0.0 -> 5110
% INFO    : Updated Thermal Rating: on transformer 477-6769 : Rate B, Rate C , 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on transformer 477-6769 : Rate B, Rate C , 0.0, 0.0 -> 1855
% INFO    : Updated Thermal Rating: on transformer 477-6769 : Rate B, Rate C , 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on transformer 2188-5170 : Rate B, Rate C , 0.0, 0.0 -> 1717
% INFO    : Updated Thermal Rating: on transformer 3061-699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 3061-699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on transformer 5823-7110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on transformer 5823-7110 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 5280-7110 : Rate B, Rate C , 0.0, 0.0 -> 16487
% INFO    : Updated Thermal Rating: on transformer 1947-4317 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on transformer 7303-429 : Rate B, Rate C , 0.0, 0.0 -> 1678
% INFO    : Updated Thermal Rating: on transformer 6039-7973 : Rate B, Rate C , 0.0, 0.0 -> 1710
% INFO    : Updated Thermal Rating: on transformer 6039-7973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 1060-8981 : Rate B, Rate C , 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on transformer 8034-1752 : Rate B, Rate C , 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on transformer 739-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on transformer 2235-8512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on transformer 3428-1439 : Rate B, Rate C , 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 2730-6127 : Rate B, Rate C , 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on transformer 2730-6127 : Rate B, Rate C , 0.0, 0.0 -> 1556
% INFO    : Updated Thermal Rating: on transformer 7395-5435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1036
% INFO    : Updated Thermal Rating: on transformer 7395-5435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on transformer 2437-3792 : Rate B, Rate C , 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on transformer 2437-3792 : Rate B, Rate C , 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 5239-8438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on transformer 5873-8147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on transformer 5873-8147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on transformer 5873-8147 : Rate B, Rate C , 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on transformer 7508-1240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on transformer 7508-1240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on transformer 3268-6397 : Rate B, Rate C , 0.0, 0.0 -> 1776
% INFO    : Updated Thermal Rating: on transformer 4290-797 : Rate B, Rate C , 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on transformer 7929-4592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1291
% INFO    : Updated Thermal Rating: on transformer 7929-4592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1138
% INFO    : Updated Thermal Rating: on transformer 849-3840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 849-3840 : Rate B, Rate C , 0.0, 0.0 -> 1310
% INFO    : Updated Thermal Rating: on transformer 5919-8871 : Rate B, Rate C , 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on transformer 5919-8871 : Rate B, Rate C , 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on transformer 5919-8871 : Rate B, Rate C , 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on transformer 1168-2686 : Rate B, Rate C , 0.0, 0.0 -> 1682
% INFO    : Updated Thermal Rating: on transformer 1168-2686 : Rate B, Rate C , 0.0, 0.0 -> 1718
% INFO    : Updated Thermal Rating: on transformer 3275-6243 : Rate B, Rate C , 0.0, 0.0 -> 1678
% INFO    : Updated Thermal Rating: on transformer 3798-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on transformer 5884-8207 : Rate B, Rate C , 0.0, 0.0 -> 1684
% INFO    : Updated Thermal Rating: on transformer 5884-8207 : Rate B, Rate C , 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on transformer 5884-8207 : Rate B, Rate C , 0.0, 0.0 -> 1621
% INFO    : Updated Thermal Rating: on transformer 6681-7819 : Rate B, Rate C , 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on transformer 6681-7819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 821
% INFO    : Updated Thermal Rating: on transformer 2261-4204 : Rate B, Rate C , 0.0, 0.0 -> 1553
% INFO    : Updated Thermal Rating: on transformer 731-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on transformer 731-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1015
% INFO    : Updated Thermal Rating: on transformer 731-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on transformer 2764-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1161
% INFO    : Updated Thermal Rating: on transformer 2764-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on transformer 299-947 : Rate B, Rate C , 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on transformer 299-947 : Rate B, Rate C , 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on transformer 8806-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on transformer 3008-5670 : Rate B, Rate C , 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on transformer 179-1850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on transformer 7918-6660 : Rate B, Rate C , 0.0, 0.0 -> 1678
% INFO    : Updated Thermal Rating: on transformer 7918-77 : Rate B, Rate C , 0.0, 0.0 -> 1713
% INFO    : Updated Thermal Rating: on transformer 7029-33 : Rate B, Rate C , 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on transformer 7029-33 : Rate B, Rate C , 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on transformer 6607-9039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on transformer 6607-9039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on transformer 7343-8338 : Rate B, Rate C , 0.0, 0.0 -> 1644
% INFO    : Updated Thermal Rating: on transformer 3966-5890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on transformer 8210-6936 : Rate B, Rate C , 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on transformer 8210-6936 : Rate B, Rate C , 0.0, 0.0 -> 1804
% INFO    : Updated Thermal Rating: on transformer 1716-6544 : Rate B, Rate C , 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on transformer 1716-6544 : Rate B, Rate C , 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on transformer 3544-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on transformer 3544-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 3662-8242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 985
% INFO    : Updated Thermal Rating: on transformer 6092-3109 : Rate B, Rate C , 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on transformer 1074-1769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1084
% INFO    : Updated Thermal Rating: on transformer 1074-1769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 1074-1769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on transformer 4957-1513 : Rate B, Rate C , 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on transformer 7428-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on transformer 7428-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 7428-4651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on transformer 6970-4632 : Rate B, Rate C , 0.0, 0.0 -> 1698
% INFO    : Updated Thermal Rating: on transformer 2700-8953 : Rate B, Rate C , 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on transformer 2700-8953 : Rate B, Rate C , 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 2849-3291 : Rate B, Rate C , 0.0, 0.0 -> 1602
% INFO    : Updated Thermal Rating: on transformer 4446-1457 : Rate B, Rate C , 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on transformer 814-7820 : Rate B, Rate C , 0.0, 0.0 -> 1442
% INFO    : Updated Thermal Rating: on transformer 7436-7629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on transformer 7436-9106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 3587-1241 : Rate B, Rate C , 0.0, 0.0 -> 1727
% INFO    : Updated Thermal Rating: on transformer 3587-1241 : Rate B, Rate C , 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on transformer 7688-8301 : Rate B, Rate C , 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on transformer 7688-8301 : Rate B, Rate C , 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on transformer 4507-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on transformer 4507-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on transformer 4507-1503 : Rate B, Rate C , 0.0, 0.0 -> 1775
% INFO    : Updated Thermal Rating: on transformer 4507-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 8260-4081 : Rate B, Rate C , 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on transformer 8260-4081 : Rate B, Rate C , 0.0, 0.0 -> 1723
% INFO    : Updated Thermal Rating: on transformer 1280-4279 : Rate B, Rate C , 0.0, 0.0 -> 1708
% INFO    : Updated Thermal Rating: on transformer 1280-4279 : Rate B, Rate C , 0.0, 0.0 -> 1603
% INFO    : Updated Thermal Rating: on transformer 385-9028 : Rate B, Rate C , 0.0, 0.0 -> 1917
% INFO    : Updated Thermal Rating: on transformer 385-9028 : Rate B, Rate C , 0.0, 0.0 -> 1409
% INFO    : Updated Thermal Rating: on transformer 6768-4096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on transformer 9203-2426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on transformer 9203-2426 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 118-2426 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 3145-7770 : Rate B, Rate C , 0.0, 0.0 -> 1336
% INFO    : Updated Thermal Rating: on transformer 7267-4918 : Rate B, Rate C , 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 7267-4918 : Rate B, Rate C , 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on transformer 839-4506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on transformer 839-4506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on transformer 3445-6114 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3445-6114 : Rate B, Rate C , 0.0, 0.0 -> 1215
% INFO    : Updated Thermal Rating: on transformer 3445-7264 : Rate B, Rate C , 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 891-6306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on transformer 720-1711 : Rate B, Rate C , 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 720-1711 : Rate B, Rate C , 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on transformer 6206-3240 : Rate B, Rate C , 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on transformer 6206-3240 : Rate B, Rate C , 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on transformer 9174-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 9174-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 1355-5856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on transformer 1355-5856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on transformer 1355-5856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on transformer 3205-4683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on transformer 3205-4683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on transformer 5350-2361 : Rate B, Rate C , 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on transformer 5350-2361 : Rate B, Rate C , 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on transformer 5016-6112 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 5016-8860 : Rate B, Rate C , 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on transformer 7471-549 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 7471-549 : Rate B, Rate C , 0.0, 0.0 -> 1122
% INFO    : Updated Thermal Rating: on transformer 549-5002 : Rate B, Rate C , 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on transformer 5490-3817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on transformer 2854-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on transformer 2918-6532 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 2918-6532 : Rate B, Rate C , 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 4494-7284 : Rate B, Rate C , 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 2656-1775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on transformer 3519-5641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on transformer 3543-367 : Rate B, Rate C , 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 3543-1833 : Rate B, Rate C , 0.0, 0.0 -> 1410
% INFO    : Updated Thermal Rating: on transformer 2372-367 : Rate B, Rate C , 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on transformer 2372-367 : Rate B, Rate C , 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 1876-7752 : Rate B, Rate C , 0.0, 0.0 -> 1283
% INFO    : Updated Thermal Rating: on transformer 113-7752 : Rate B, Rate C , 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on transformer 3499-7289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on transformer 3499-7289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on transformer 3082-2083 : Rate B, Rate C , 0.0, 0.0 -> 1099
% INFO    : Updated Thermal Rating: on transformer 6224-2083 : Rate B, Rate C , 0.0, 0.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 2174-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 4623-1609 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 4623-1609 : Rate B, Rate C , 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on transformer 4623-1609 : Rate B, Rate C , 0.0, 0.0 -> 1230
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate B, Rate C , 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on transformer 1198-7473 : Rate B, Rate C , 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on transformer 1198-7473 : Rate B, Rate C , 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on transformer 2479-5482 : Rate B, Rate C , 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 2479-5482 : Rate B, Rate C , 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 7831-5525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on transformer 7831-5525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on transformer 7831-5525 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 4970-7955 : Rate B, Rate C , 0.0, 0.0 -> 1308
% INFO    : Updated Thermal Rating: on transformer 4970-7955 : Rate B, Rate C , 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 5007-7367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on transformer 757-3758 : Rate B, Rate C , 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate B, Rate C , 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on transformer 6738-8180 : Rate B, Rate C , 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 6738-8180 : Rate B, Rate C , 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on transformer 9222-5935 : Rate B, Rate C , 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on transformer 7988-804 : Rate B, Rate C , 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on transformer 7988-804 : Rate B, Rate C , 0.0, 0.0 -> 1234
% INFO    : Updated Thermal Rating: on transformer 3239-1539 : Rate B, Rate C , 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on transformer 3239-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on transformer 2056-4084 : Rate B, Rate C , 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on transformer 2056-4084 : Rate B, Rate C , 0.0, 0.0 -> 1154
% INFO    : Updated Thermal Rating: on transformer 4598-5110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on transformer 2129-5110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on transformer 5658-5550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on transformer 5658-5550 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 2848-1526 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 4541-7464 : Rate B, Rate C , 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on transformer 4541-7464 : Rate B, Rate C , 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on transformer 1754-3857 : Rate B, Rate C , 0.0, 0.0 -> 1080
% INFO    : Updated Thermal Rating: on transformer 1754-3857 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 1754-3857 : Rate B, Rate C , 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on transformer 2518-4544 : Rate B, Rate C , 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on transformer 2518-4544 : Rate B, Rate C , 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on transformer 3069-6115 : Rate B, Rate C , 0.0, 0.0 -> 3286
% INFO    : Updated Thermal Rating: on transformer 5067-7641 : Rate B, Rate C , 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on transformer 6036-8670 : Rate B, Rate C , 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on transformer 6036-5522 : Rate B, Rate C , 0.0, 0.0 -> 1179
% INFO    : Updated Thermal Rating: on transformer 8486-8791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on transformer 7530-8791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on transformer 7522-7571 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 7522-7571 : Rate B, Rate C , 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on transformer 7522-7571 : Rate B, Rate C , 0.0, 0.0 -> 1124
% INFO    : Updated Thermal Rating: on transformer 2526-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on transformer 2365-8316 : Rate B, Rate C , 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 8672-1860 : Rate B, Rate C , 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 8672-1860 : Rate B, Rate C , 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on transformer 1494-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on transformer 1494-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on transformer 1502-2795 : Rate B, Rate C , 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 8195-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on transformer 8195-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on transformer 8195-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 3918-6802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 3918-4025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 721
% INFO    : Updated Thermal Rating: on transformer 4435-2079 : Rate B, Rate C , 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 4435-2079 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 4435-2079 : Rate B, Rate C , 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on transformer 1081-7361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on transformer 9101-2177 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 6555-8475 : Rate B, Rate C , 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on transformer 6555-8475 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 7056-7577 : Rate B, Rate C , 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on transformer 7056-7577 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 7056-9051 : Rate B, Rate C , 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on transformer 6889-6785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on transformer 6889-6785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on transformer 6889-6785 : Rate B, Rate C , 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on transformer 1027-7148 : Rate B, Rate C , 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 1027-44 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 5308-7148 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 5308-44 : Rate B, Rate C , 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on transformer 9213-6231 : Rate B, Rate C , 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on transformer 9213-8291 : Rate B, Rate C , 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on transformer 9213-6842 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on transformer 3608-6664 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 4339-6570 : Rate B, Rate C , 0.0, 0.0 -> 1339
% INFO    : Updated Thermal Rating: on transformer 4339-6570 : Rate B, Rate C , 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on transformer 7513-6570 : Rate B, Rate C , 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 7513-6570 : Rate B, Rate C , 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on transformer 8887-6639 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 8887-6639 : Rate B, Rate C , 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on transformer 5461-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 5461-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on transformer 5461-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on transformer 5460-3786 : Rate B, Rate C , 0.0, 0.0 -> 1214
% INFO    : Updated Thermal Rating: on transformer 5460-3786 : Rate B, Rate C , 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 7256-4491 : Rate B, Rate C , 0.0, 0.0 -> 3170
% INFO    : Updated Thermal Rating: on transformer 6153-58 : Rate B, Rate C , 0.0, 0.0 -> 4050
% INFO    : Updated Thermal Rating: on transformer 6153-6807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on transformer 1465-1262 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1465-1262 : Rate B, Rate C , 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on transformer 1465-1551 : Rate B, Rate C , 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 7537-1551 : Rate B, Rate C , 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on transformer 7537-1551 : Rate B, Rate C , 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on transformer 6901-4874 : Rate B, Rate C , 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on transformer 5241-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on transformer 7520-561 : Rate B, Rate C , 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on transformer 749-4324 : Rate B, Rate C , 0.0, 0.0 -> 1382
% INFO    : Updated Thermal Rating: on transformer 4141-7124 : Rate B, Rate C , 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on transformer 4141-7124 : Rate B, Rate C , 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on transformer 7466-3649 : Rate B, Rate C , 0.0, 0.0 -> 2496
% INFO    : Updated Thermal Rating: on transformer 8222-6556 : Rate B, Rate C , 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on transformer 8222-6556 : Rate B, Rate C , 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on transformer 8222-6556 : Rate B, Rate C , 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on transformer 4125-163 : Rate B, Rate C , 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 4125-163 : Rate B, Rate C , 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on transformer 4125-163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on transformer 5837-9217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 5837-1448 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 5837-1448 : Rate B, Rate C , 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on transformer 8267-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on transformer 8267-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 2359-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on transformer 2359-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on transformer 8109-171 : Rate B, Rate C , 0.0, 0.0 -> 1204
% INFO    : Updated Thermal Rating: on transformer 8109-171 : Rate B, Rate C , 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on transformer 3485-1156 : Rate B, Rate C , 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on transformer 4734-2229 : Rate B, Rate C , 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 1709-7702 : Rate B, Rate C , 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on transformer 1709-7702 : Rate B, Rate C , 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 905-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on transformer 8334-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on transformer 8334-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 7998-6734 : Rate B, Rate C , 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 4196-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on transformer 4196-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on transformer 6475-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 6475-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 7328-4235 : Rate B, Rate C , 0.0, 0.0 -> 1137
% INFO    : Updated Thermal Rating: on transformer 7328-4235 : Rate B, Rate C , 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on transformer 7328-4235 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on transformer 6921-2949 : Rate B, Rate C , 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on transformer 6921-2949 : Rate B, Rate C , 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on transformer 3830-306 : Rate B, Rate C , 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on transformer 5648-306 : Rate B, Rate C , 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on transformer 1730-115 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 1730-115 : Rate B, Rate C , 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on transformer 2721-5720 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 2721-5720 : Rate B, Rate C , 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on transformer 432-3246 : Rate B, Rate C , 0.0, 0.0 -> 2432
% INFO    : Updated Thermal Rating: on transformer 432-8846 : Rate B, Rate C , 0.0, 0.0 -> 2483
% INFO    : Updated Thermal Rating: on transformer 432-2393 : Rate B, Rate C , 0.0, 0.0 -> 2533
% INFO    : Updated Thermal Rating: on transformer 432-1895 : Rate B, Rate C , 0.0, 0.0 -> 2588
% INFO    : Updated Thermal Rating: on transformer 432-3412 : Rate B, Rate C , 0.0, 0.0 -> 2447
% INFO    : Updated Thermal Rating: on transformer 432-5586 : Rate B, Rate C , 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on transformer 432-3112 : Rate B, Rate C , 0.0, 0.0 -> 2207
% INFO    : Updated Thermal Rating: on transformer 432-3112 : Rate B, Rate C , 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on transformer 432-7857 : Rate B, Rate C , 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on transformer 960-8497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 960-8497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 3577-5907 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 3577-5907 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on transformer 3577-5907 : Rate B, Rate C , 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 7164-5918 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 7164-5918 : Rate B, Rate C , 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on transformer 1798-2467 : Rate B, Rate C , 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on transformer 1798-2467 : Rate B, Rate C , 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on transformer 3346-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 3346-2132 : Rate B, Rate C , 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on transformer 3346-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 792
% INFO    : Updated Thermal Rating: on transformer 3483-8992 : Rate B, Rate C , 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on transformer 8886-8992 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 2093-805 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 2093-805 : Rate B, Rate C , 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on transformer 221-1541 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 8347-5383 : Rate B, Rate C , 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on transformer 8347-5383 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 8347-5383 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8347-7507 : Rate B, Rate C , 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on transformer 8347-7507 : Rate B, Rate C , 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on transformer 8347-7507 : Rate B, Rate C , 0.0, 0.0 -> 1256
% INFO    : Updated Thermal Rating: on transformer 4000-4852 : Rate B, Rate C , 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 4000-2012 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 2183-4852 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 2183-2012 : Rate B, Rate C , 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on transformer 1642-7098 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 1642-687 : Rate B, Rate C , 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on transformer 809-7098 : Rate B, Rate C , 0.0, 0.0 -> 1144
% INFO    : Updated Thermal Rating: on transformer 809-687 : Rate B, Rate C , 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on transformer 4594-8804 : Rate B, Rate C , 0.0, 0.0 -> 1220
% INFO    : Updated Thermal Rating: on transformer 4594-8804 : Rate B, Rate C , 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on transformer 2919-4215 : Rate B, Rate C , 0.0, 0.0 -> 1178
% INFO    : Updated Thermal Rating: on transformer 1142-6577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on transformer 1142-4137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on transformer 1930-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on transformer 1930-6445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 165-7904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on transformer 165-5140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 1786-3879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on transformer 1786-4210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on transformer 7228-6121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on transformer 8171-2528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on transformer 8345-5553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on transformer 14-2925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on transformer 4346-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on transformer 4346-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on transformer 4985-1166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on transformer 4985-1166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on transformer 1972-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on transformer 1132-8445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on transformer 603-2617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on transformer 603-2617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on transformer 603-5798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on transformer 603-5798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on transformer 603-5798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on transformer 436-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 609
% INFO    : Updated Thermal Rating: on transformer 5883-3911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on transformer 5883-4796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on transformer 5883-3632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 8845-8752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 1533-1966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on transformer 1533-3165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on transformer 1533-1966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on transformer 1533-4590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on transformer 1533-3165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 1533-4590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on transformer 3056-5496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 516
% INFO    : Updated Thermal Rating: on transformer 2000-2548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on transformer 2000-1071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on transformer 2869-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on transformer 6072-9092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on transformer 6072-2292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on transformer 5226-8340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on transformer 2522-8386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 2522-5953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on transformer 2522-5953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 4490-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on transformer 4490-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on transformer 4490-2829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on transformer 1575-4591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on transformer 1575-4591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 3208-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on transformer 3208-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on transformer 3208-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on transformer 3371-5721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 7656-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on transformer 8974-825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on transformer 8974-825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on transformer 825-7111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on transformer 825-7111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on transformer 9073-2819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 2502-5229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on transformer 2502-5229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 892
% INFO    : Updated Thermal Rating: on transformer 5229-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 5229-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 5501-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on transformer 5501-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on transformer 5501-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on transformer 2649-5585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on transformer 5161-3838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 5161-3838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 6182-861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on transformer 3198-8811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on transformer 7008-4583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 7008-4583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 7081-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on transformer 7081-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on transformer 7081-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on transformer 2389-8003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on transformer 2389-8003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 2480-181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on transformer 2480-181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 1429-4417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on transformer 1429-6856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 1429-6856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 1809-8416 : Rate B, Rate C , 0.0, 0.0 -> 3906
% INFO    : Updated Thermal Rating: on transformer 1809-8416 : Rate B, Rate C , 0.0, 0.0 -> 3950
% INFO    : Updated Thermal Rating: on transformer 8526-2840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 8526-2840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 5284-2840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on transformer 5284-2840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 6743-6609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on transformer 6743-6609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on transformer 6743-6609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on transformer 4998-6609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on transformer 7458-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on transformer 7458-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on transformer 7679-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on transformer 7679-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on transformer 8715-4912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 8715-2144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 8580-5624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on transformer 8580-5624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on transformer 5850-2858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on transformer 8943-7152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on transformer 569-146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on transformer 569-146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on transformer 3245-146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 756
% INFO    : Updated Thermal Rating: on transformer 3245-146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 3360-5138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3518
% INFO    : Updated Thermal Rating: on line 2578-6334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7295
% INFO    : Updated Thermal Rating: on transformer 6334-4820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on transformer 7044-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on transformer 7044-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 2204-672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 9006-7212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 1759-8170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 8532-6671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on transformer 8532-8723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on transformer 3563-6622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on transformer 3563-6622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on transformer 9139-3465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1364
% INFO    : Updated Thermal Rating: on transformer 2756-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on transformer 2756-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on transformer 2316-1 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1388
% INFO    : Updated Thermal Rating: on transformer 1072-6210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1081
% INFO    : Updated Thermal Rating: on transformer 5747-9068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on transformer 3884-6863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on transformer 8375-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 7639-5714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 7311-7538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on transformer 3068-708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 7922-6129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 7922-2956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3595
% INFO    : Updated Thermal Rating: on line 7922-6874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3597
% INFO    : Updated Thermal Rating: on line 7197-5398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3563
% INFO    : Updated Thermal Rating: on line 7197-6249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3552
% INFO    : Updated Thermal Rating: on line 4610-9000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4130
% INFO    : Updated Thermal Rating: on line 4610-1546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4223
% INFO    : Updated Thermal Rating: on line 7359-9167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5590
% INFO    : Updated Thermal Rating: on line 7359-4027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4891
% INFO    : Updated Thermal Rating: on line 7359-5841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4802
% INFO    : Updated Thermal Rating: on line 7359-4398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6016
% INFO    : Updated Thermal Rating: on line 4836-348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 4836-3227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3895
% INFO    : Updated Thermal Rating: on line 4836-4994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3424
% INFO    : Updated Thermal Rating: on transformer 2615-7753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on transformer 2615-3384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on transformer 99-3024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1563
% INFO    : Updated Thermal Rating: on line 4564-1743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 4564-5572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 4564-4075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 1469-289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 3123-759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on transformer 5109-7103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on line 3699-927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1604
% INFO    : Updated Thermal Rating: on transformer 7248-4283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on transformer 7248-4283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 7564-1170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2119
% INFO    : Updated Thermal Rating: on line 8876-8157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3656
% INFO    : Updated Thermal Rating: on line 8876-1365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3586
% INFO    : Updated Thermal Rating: on transformer 7182-2040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on transformer 3196-6067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1260
% INFO    : Updated Thermal Rating: on transformer 1224-7494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on transformer 1224-7494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1556
% INFO    : Updated Thermal Rating: on transformer 1224-7494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on transformer 3099-127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on transformer 1610-7593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on transformer 1610-7593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on transformer 6316-4348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1233
% INFO    : Updated Thermal Rating: on transformer 6316-4348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 660-5532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1466
% INFO    : Updated Thermal Rating: on transformer 660-5532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 835-4680 : Rate B, Rate C , 0.0, 0.0 -> 4171
% INFO    : Updated Thermal Rating: on line 3449-4680 : Rate B, Rate C , 0.0, 0.0 -> 4273
% INFO    : Updated Thermal Rating: on transformer 4680-1034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 4147-3284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4263
% INFO    : Updated Thermal Rating: on line 2332-5059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4357
% INFO    : Updated Thermal Rating: on line 5124-1620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 3348-7947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3930
% INFO    : Updated Thermal Rating: on transformer 8252-6362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on transformer 3963-5493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 2634-8185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 2634-6910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73459
% INFO    : Updated Thermal Rating: on transformer 875-1867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 946-7403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1564
% INFO    : Updated Thermal Rating: on transformer 5355-7066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on transformer 4414-1423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on transformer 8117-2675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on transformer 3874-1613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1427
% INFO    : Updated Thermal Rating: on transformer 3874-1613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on transformer 3874-1613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on transformer 9009-7320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on transformer 9009-8484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1369
% INFO    : Updated Thermal Rating: on transformer 2710-368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1388
% INFO    : Updated Thermal Rating: on transformer 2680-339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1024
% INFO    : Updated Thermal Rating: on transformer 3972-6963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on transformer 3972-4126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on transformer 3972-1303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on transformer 3972-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on transformer 1684-7574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on transformer 4330-8509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1398
% INFO    : Updated Thermal Rating: on transformer 4330-8509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1372
% INFO    : Updated Thermal Rating: on transformer 8524-4017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on transformer 6195-4017 : Rate A, Rate B, Rate C , 377.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on transformer 2684-2317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1661
% INFO    : Updated Thermal Rating: on transformer 6460-8774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on transformer 5623-7633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on transformer 1031-1688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on transformer 4810-2729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on transformer 3262-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1413
% INFO    : Updated Thermal Rating: on transformer 3262-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on transformer 8496-4270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on transformer 8496-4270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on transformer 7674-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on transformer 7674-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on transformer 7330-7033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on transformer 7330-7033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on transformer 8344-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on transformer 8344-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on transformer 6860-6573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on transformer 4208-6573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on transformer 4208-6573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on transformer 3259-1710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on transformer 3259-1710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1099
% INFO    : Updated Thermal Rating: on transformer 3146-5593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 8859-5251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 1392-5001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on transformer 3538-5001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on transformer 8249-6139 : Rate A, Rate B, Rate C , 921.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 806-91 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 1747-6998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on transformer 593-6998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on transformer 8432-6295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on transformer 8432-6295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 8432-6295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 3190-7090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 3484-7090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 3484-7844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 281-3960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 8086-1477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 8086-8037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 5008-6354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 5008-6354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 919-6354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 919-6354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 4825-7884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 3023-7884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 6345-7884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 8114-8738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 8773-8738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 4059-6282 : Rate B, Rate C , 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on transformer 2002-4340 : Rate B, Rate C , 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on transformer 5165-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 5165-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 2722-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 2722-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 1591-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on transformer 5558-8510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on transformer 5558-8510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on transformer 1689-8814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 8230-8814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 8393-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on transformer 8393-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on transformer 139-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on transformer 3257-6058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on transformer 369-6058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 705
% INFO    : Updated Thermal Rating: on transformer 369-6058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on transformer 6068-7450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 6068-2271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 6263-3846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 1788-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 2824-211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 140-211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on transformer 3210-1670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 5674-1670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 4337-1670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on line 4779-1956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4861
% INFO    : Updated Thermal Rating: on transformer 4320-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on transformer 4858-4248 : Rate B, Rate C , 0.0, 0.0 -> 1549
% INFO    : Updated Thermal Rating: on transformer 7235-4858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4200
% INFO    : Updated Thermal Rating: on transformer 4248-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on transformer 5897-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 420-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 8898-6052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 5311-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 3891-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on transformer 662-7073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 6017-349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on transformer 6766-7156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 4077-7442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 1052-8277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3878-8277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 76-5346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on transformer 4485-3000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 4485-3000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 6283-3000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 395-4082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 5843-5246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 5843-5246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 6477-2478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on transformer 5295-2478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1443-6268 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 4638-6268 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 1315-3848 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on transformer 2997-4595 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 2997-4581 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on transformer 6190-977 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 3676-977 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on transformer 5505-977 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 7625-3438 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 3797-638 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 214-638 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 4847-638 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 6238-4163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1258
% INFO    : Updated Thermal Rating: on transformer 4638-7293 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 3676-7293 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 5505-7293 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 1443-2509 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 3797-966 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 3797-2604 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 248-8449 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 4244-8449 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 1110-8449 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 4533-3219 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on transformer 3147-6634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1474
% INFO    : Updated Thermal Rating: on transformer 3147-7854 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 6109-2274 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 993-2274 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 4257-8387 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 4257-5640 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 5462-8387 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 7553-8387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on transformer 2758-8387 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 2758-5640 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 1110-328 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 214-3219 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 4847-3219 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 5209-4695 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on transformer 5209-4695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on transformer 5209-3515 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 7625-6100 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on transformer 8822-8971 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 2216-8652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on transformer 2216-8652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1851
% INFO    : Updated Thermal Rating: on transformer 8822-3084 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 7625-2771 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 3454-2013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 3368-2862 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 3368-5075 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 4244-8610 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 2835-1492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on transformer 1443-1492 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 1443-5305 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 1103-4844 : Rate B, Rate C , 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on transformer 248-7025 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 7625-6708 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 8822-6708 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on transformer 7089-7025 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 1110-7025 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on transformer 7625-3404 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 8822-3404 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 1110-578 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 8822-5513 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 5479-1719 : Rate B, Rate C , 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on transformer 5479-3251 : Rate B, Rate C , 0.0, 0.0 -> 1085
% INFO    : Updated Thermal Rating: on transformer 3762-4468 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on transformer 3762-4468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on transformer 499-4468 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 3762-378 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 3930-7854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on transformer 499-2250 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 8685-2250 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 499-3411 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 8685-3411 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 499-2539 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 8685-2539 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 499-378 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on transformer 499-5386 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 993-770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on transformer 993-7890 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 993-1507 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 8685-3015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on transformer 8685-378 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 8685-3782 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 8685-5386 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 1315-3953 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 4244-3326 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on transformer 4244-3326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on transformer 2948-2573 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 791-6937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on transformer 3368-6937 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 2997-8537 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 1110-7298 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 1110-262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on transformer 1110-262 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 1110-6169 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 2948-3782 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 2997-5158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on transformer 2997-8758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1644
% INFO    : Updated Thermal Rating: on transformer 7625-3003 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 7625-3991 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 8822-5656 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 5822-2553 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on transformer 5822-4051 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on transformer 27-173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1505
% INFO    : Updated Thermal Rating: on transformer 4847-173 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 4847-6601 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 1315-3991 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 8401-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1001
% INFO    : Updated Thermal Rating: on transformer 4847-3607 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 6504-3341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on transformer 130-5452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on transformer 130-5452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on transformer 441-2233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on transformer 8088-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 8088-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 3080-8789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on transformer 3080-8789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1089
% INFO    : Updated Thermal Rating: on transformer 5825-702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 8224-5517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on transformer 8224-5517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on transformer 536-4344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on transformer 6080-5006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on transformer 6080-5006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on transformer 1899-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on transformer 4712-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on transformer 4712-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on transformer 6187-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on transformer 6187-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on transformer 5562-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on transformer 7827-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on transformer 1025-8926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on transformer 6298-6795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on transformer 6298-6795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on transformer 3007-6254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on transformer 7969-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on transformer 7969-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on transformer 1703-7503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on transformer 1703-7503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on transformer 4704-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on transformer 4704-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on transformer 4704-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on transformer 2031-8493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1213
% INFO    : Updated Thermal Rating: on transformer 1025-1239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on transformer 3007-9136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on transformer 3007-4650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on transformer 5050-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 5050-1298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 1360-5741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on transformer 1360-5741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 8820-6205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on transformer 8820-6205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 1732-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on transformer 4746-5447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 4746-850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 4187-7499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 3731-760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 5537-6063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on transformer 7418-3120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on transformer 7418-3120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on transformer 3120-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 3120-3328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 2427-6265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on transformer 2427-6770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on transformer 3570-6849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 4396-6317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on transformer 6317-3434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 2707-2534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on transformer 2707-2534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on transformer 2534-3029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on transformer 2534-1176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on transformer 4335-5849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on transformer 5619-3804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 5619-617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 6245-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 6245-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 9227-2061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 6787-922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on transformer 841-1988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on transformer 6729-8754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on transformer 6729-1412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 6319-8922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on transformer 3802-9056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 3802-9056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 4977-7344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 4977-6465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 7889-3153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 2170-4881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on transformer 2108-7853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on transformer 9218-3129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on transformer 9005-3207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on transformer 1196-1197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 1196-1197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 204-675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 204-2488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 5009-3642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 5009-3642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on transformer 2027-1274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on transformer 2027-1274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on transformer 67-5537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on transformer 67-7946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on transformer 7946-8949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 7946-215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 2383-1921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 2383-1921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 6481-9035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 1563-5322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 6256-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on transformer 1756-2984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 5487-7109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on transformer 6116-8455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on transformer 4736-3050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on transformer 4736-3050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on transformer 3050-8351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 3050-6550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 3511-1783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on transformer 3729-3393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 3729-3732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on transformer 971-7278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on transformer 971-3441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on transformer 3441-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 3441-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 6665-4364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 7828-4537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 1669-3810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on transformer 1669-3810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on transformer 4394-4667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 4697-3853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on transformer 4697-7671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on transformer 4697-7671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1794
% INFO    : Updated Thermal Rating: on transformer 5175-9105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on transformer 2226-4759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on transformer 7515-3595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 3365-5964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 1695-6733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 3356-8692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on transformer 3356-7549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 8692-7549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 6449-7578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on transformer 8137-3640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1060
% INFO    : Updated Thermal Rating: on transformer 7506-3815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on transformer 5337-3030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 8633-4992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 3192-7120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1462
% INFO    : Updated Thermal Rating: on transformer 3192-8583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on transformer 3192-1321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on transformer 3192-4988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on transformer 7017-4716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on transformer 7017-4716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on transformer 7017-4716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1060
% INFO    : Updated Thermal Rating: on transformer 4716-6825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 4716-6825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 1540-2092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 1540-3921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on transformer 8166-5231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on transformer 4990-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on transformer 2152-508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 2152-508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 3017-7536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on transformer 3017-7536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 403-7536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 7271-7585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 5185-4741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 4327-4351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on transformer 887-7750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on transformer 887-3161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 887-2645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on transformer 2251-1053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 2251-1053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 7225-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 7225-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 3915-3679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on transformer 1127-3679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on transformer 2904-2706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on transformer 2904-576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on transformer 3213-5632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on transformer 3213-2333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 1211-7660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1552
% INFO    : Updated Thermal Rating: on transformer 7660-4378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 7010-2198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 4437-155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on transformer 4437-7730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on transformer 2939-341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 2939-341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 2939-341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on transformer 2939-341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 9016-3924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on transformer 9016-3924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on transformer 5327-2345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on transformer 5327-8470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on transformer 3103-8471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 2855-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 2855-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on transformer 4361-3026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on transformer 7830-7739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on transformer 1534-8306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on transformer 1534-8306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on transformer 8734-8570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 8734-8570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 663-7604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on transformer 663-7604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on transformer 1978-7477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on transformer 3104-7477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on transformer 3104-7477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on transformer 4861-7528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 8562-4861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1454
% INFO    : Updated Thermal Rating: on transformer 8562-7528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on transformer 8562-7528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on transformer 4801-3372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on transformer 4801-8382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on transformer 3372-5218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 7364-1964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on transformer 7364-1964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1416
% INFO    : Updated Thermal Rating: on transformer 1686-8618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on transformer 1686-3748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on transformer 1686-3748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on transformer 7314-7848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on transformer 7978-6673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on transformer 7978-6673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 2349-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on transformer 2349-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 3688-5629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on transformer 3688-5629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on transformer 465-4803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on transformer 465-4803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 8358-3470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on transformer 1753-3470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on transformer 1753-3470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 2585-4899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on transformer 4899-591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on transformer 4899-7705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 254-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 7521-1087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on transformer 7521-1087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on transformer 895-8969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 895-3232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on transformer 3750-7687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 3750-7687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 3750-7687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 3750-7687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on transformer 2398-5000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1647
% INFO    : Updated Thermal Rating: on transformer 2398-5000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1453
% INFO    : Updated Thermal Rating: on transformer 2398-5000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on transformer 2737-5190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1053
% INFO    : Updated Thermal Rating: on transformer 694-1960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on transformer 694-180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on transformer 6098-9193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on transformer 1473-4784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 1473-4784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on transformer 1920-3447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on transformer 1920-3447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on transformer 8556-9133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on transformer 5824-8145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on transformer 4111-3955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on transformer 2846-3955 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on transformer 794-4924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 794-4924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on transformer 4190-3940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on transformer 4190-3940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on transformer 4190-3518 : Rate B, Rate C , 0.0, 0.0 -> 2328
% INFO    : Updated Thermal Rating: on transformer 3940-956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on transformer 3518-3940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on transformer 3518-3940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on transformer 6091-4063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on transformer 6091-4063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on transformer 7678-1075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 7678-1075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 7870-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on transformer 599-4242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on transformer 599-4242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on transformer 5389-8041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on transformer 5389-8041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 5052-446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 5052-446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 6398-607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2619
% INFO    : Updated Thermal Rating: on transformer 4458-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on transformer 4458-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on transformer 4959-4654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 6370-6269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 6370-6269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 6588-2621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 6588-2621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 6588-5840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on transformer 6588-5840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on transformer 5757-3386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 5757-3386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 5757-2001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 5757-2001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 3628-3402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 3628-3402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 3628-6545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 3628-6545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 8390-7962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 8390-7962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 8793-6198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 8793-5345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 836-7084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 836-7084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1941-8122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 1941-8122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 1941-7288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1941-7288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 8089-4769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 8089-4769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 836-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 836-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 1594-1291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1594-1291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1594-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1594-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1420-1799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 1420-1799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 1420-4303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1420-4303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 8680-8366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 8680-8366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 1827-4292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1827-4292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1827-5113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 1827-5113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 644-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on transformer 644-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on transformer 644-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on transformer 644-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on transformer 4888-7888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4888-7888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4917-777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 4917-777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 4917-777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 8657-4628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 8657-4628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 8657-1444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on transformer 8657-1444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on transformer 1881-3459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on transformer 1881-3459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on transformer 1881-3459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 5293-4955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 7429-9220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on transformer 7429-9220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on transformer 7658-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 7658-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 7658-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 6021-3002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 6021-3002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 6021-4193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 6021-4193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 6021-3058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 6021-3058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 4567-2735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4567-2735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4567-9085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 4567-9085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 2659-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2659-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2659-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2659-2999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2775-6890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on transformer 2775-6890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on transformer 2683-409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 2683-409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 926-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 926-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 926-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on transformer 7728-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 7728-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 2455-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2455-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2455-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 7498-5411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 7498-5411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 7498-5411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 6181-5851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on transformer 6181-5851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on transformer 2436-6821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on transformer 2436-6821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on transformer 2436-6821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on transformer 2436-6821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on transformer 7158-7481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on transformer 7158-7481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 7985-4109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on transformer 7985-4109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on transformer 7985-4109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 7985-4109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 5921-2881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 6518-2499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 134-2243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 1738-9 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 2151-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 2151-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 2151-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 4920-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on transformer 4920-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on transformer 4920-3564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on transformer 4920-3564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on transformer 4305-5603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 4305-4749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 2325-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on transformer 2325-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on transformer 2325-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on transformer 1152-8543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 1152-8543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 7928-8259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 7928-8259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 634-4358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on transformer 634-4358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on transformer 634-4358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on transformer 634-4358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on transformer 9022-5287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on transformer 9022-5287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 1925-8523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on transformer 1925-8523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 1515-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 1515-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 5934-5040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 5934-5040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on transformer 5934-5040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 8227-6796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 8227-6796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on transformer 6124-5810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on transformer 6124-5810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 6124-5810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on transformer 6124-5810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 7378-2007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 7378-2007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 3475-3799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on transformer 3475-3799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on transformer 6893-7217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 6893-7217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 7128-5667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on transformer 7128-5667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 7128-5667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 4225-6951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on transformer 4225-6951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 7026-5889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 7026-5889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 320-20 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on transformer 320-20 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on transformer 715-1054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 715-1054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 2874-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2874-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2874-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2874-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 3907-7894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on transformer 2241-2584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on transformer 6008-6326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on transformer 6008-6326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on transformer 6008-6326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on transformer 9114-5538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on transformer 9114-5538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 9114-5538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 4469-5590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on transformer 4469-5590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on transformer 5098-3822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on transformer 5098-3822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on transformer 3194-1559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 407-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 407-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 407-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on transformer 407-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on transformer 6085-5744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on transformer 6746-6410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 7642-7950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 7642-7950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 5581-5240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 8422-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 8422-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4050-4370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on transformer 2028-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2028-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2028-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 294-9224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 294-9224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 3292-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 3292-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1929-5090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 1929-5090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 1929-5090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 8110-8441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=1.007206, theta=-36.856998 -> V=1.0, theta=0.0
% INFO    : Bus 2	: V=1.031734, theta=-12.028001 -> V=1.0, theta=0.0
% INFO    : Bus 3	: V=1.017843, theta=-21.794234 -> V=1.0, theta=0.0
% INFO    : Bus 4	: V=1.020147, theta=-7.224254 -> V=1.0, theta=0.0
% INFO    : Bus 5	: V=0.989775, theta=-49.871783 -> V=1.0, theta=0.0
% INFO    : Bus 6	: V=1.038476, theta=-42.240491 -> V=1.0, theta=0.0
% INFO    : Bus 7	: V=0.96914, theta=-36.181195 -> V=1.0, theta=0.0
% INFO    : Bus 8	: V=1.023005, theta=-20.771666 -> V=1.0, theta=0.0
% INFO    : Bus 9	: V=1.032658, theta=-3.651312 -> V=1.0, theta=0.0
% INFO    : Bus 10	: V=1.033477, theta=-24.645036 -> V=1.0, theta=0.0
% INFO    : Bus 11	: V=0.965112, theta=-31.467815 -> V=1.0, theta=0.0
% INFO    : Bus 12	: V=1.034508, theta=-26.383988 -> V=1.0, theta=0.0
% INFO    : Bus 13	: V=1.013859, theta=-48.74904 -> V=1.0, theta=0.0
% INFO    : Bus 14	: V=1.14146, theta=-21.558785 -> V=1.0, theta=0.0
% INFO    : Bus 15	: V=1.02165, theta=-48.932223 -> V=1.0, theta=0.0
% INFO    : Bus 16	: V=1.032431, theta=6.063256 -> V=1.0, theta=0.0
% INFO    : Bus 17	: V=1.010381, theta=6.154063 -> V=1.0, theta=0.0
% INFO    : Bus 18	: V=1.026728, theta=18.107815 -> V=1.0, theta=0.0
% INFO    : Bus 19	: V=1.005109, theta=-38.460832 -> V=1.0, theta=0.0
% INFO    : Bus 20	: V=1.024517, theta=6.675769 -> V=1.0, theta=0.0
% INFO    : Bus 21	: V=1.031479, theta=-22.305911 -> V=1.0, theta=0.0
% INFO    : Bus 22	: V=1.031644, theta=-18.751971 -> V=1.0, theta=0.0
% INFO    : Bus 23	: V=1.024755, theta=-25.628654 -> V=1.0, theta=0.0
% INFO    : Bus 24	: V=0.960802, theta=-32.296073 -> V=1.0, theta=0.0
% INFO    : Bus 25	: V=1.028526, theta=12.404601 -> V=1.0, theta=0.0
% INFO    : Bus 26	: V=1.029582, theta=-3.339851 -> V=1.0, theta=0.0
% INFO    : Bus 27	: V=1.085434, theta=13.448823 -> V=1.0, theta=0.0
% INFO    : Bus 28	: V=1.004931, theta=-31.840868 -> V=1.0, theta=0.0
% INFO    : Bus 29	: V=1.004602, theta=-13.569928 -> V=1.0, theta=0.0
% INFO    : Bus 30	: V=1.023518, theta=-29.715225 -> V=1.0, theta=0.0
% INFO    : Bus 31	: V=0.905716, theta=-35.509144 -> V=1.0, theta=0.0
% INFO    : Bus 32	: V=1.003223, theta=-43.014699 -> V=1.0, theta=0.0
% INFO    : Bus 33	: V=1.026534, theta=-38.549418 -> V=1.0, theta=0.0
% INFO    : Bus 34	: V=1.028523, theta=-24.559588 -> V=1.0, theta=0.0
% INFO    : Bus 35	: V=1.026497, theta=-36.721451 -> V=1.0, theta=0.0
% INFO    : Bus 36	: V=1.045193, theta=-21.272765 -> V=1.0, theta=0.0
% INFO    : Bus 37	: V=0.972198, theta=-29.508765 -> V=1.0, theta=0.0
% INFO    : Bus 38	: V=1.022868, theta=25.558732 -> V=1.0, theta=0.0
% INFO    : Bus 39	: V=1.003511, theta=-38.297997 -> V=1.0, theta=0.0
% INFO    : Bus 40	: V=0.999097, theta=-31.840826 -> V=1.0, theta=0.0
% INFO    : Bus 41	: V=1.008625, theta=-8.828964 -> V=1.0, theta=0.0
% INFO    : Bus 42	: V=1.042404, theta=-49.184531 -> V=1.0, theta=0.0
% INFO    : Bus 43	: V=1.028739, theta=-15.907171 -> V=1.0, theta=0.0
% INFO    : Bus 44	: V=1.040868, theta=-22.52467 -> V=1.0, theta=0.0
% INFO    : Bus 45	: V=1.048003, theta=-25.286846 -> V=1.0, theta=0.0
% INFO    : Bus 46	: V=0.958698, theta=-29.319698 -> V=1.0, theta=0.0
% INFO    : Bus 47	: V=0.985859, theta=-27.824727 -> V=1.0, theta=0.0
% INFO    : Bus 48	: V=1.045484, theta=-26.609146 -> V=1.0, theta=0.0
% INFO    : Bus 49	: V=1.020323, theta=-36.088357 -> V=1.0, theta=0.0
% INFO    : Bus 50	: V=1.025009, theta=-4.460831 -> V=1.0, theta=0.0
% INFO    : Bus 51	: V=1.006665, theta=-48.120109 -> V=1.0, theta=0.0
% INFO    : Bus 52	: V=1.017252, theta=0.511391 -> V=1.0, theta=0.0
% INFO    : Bus 53	: V=1.053406, theta=-9.368997 -> V=1.0, theta=0.0
% INFO    : Bus 54	: V=1.023883, theta=-35.660013 -> V=1.0, theta=0.0
% INFO    : Bus 55	: V=0.99682, theta=9.004928 -> V=1.0, theta=0.0
% INFO    : Bus 56	: V=1.010606, theta=-16.919749 -> V=1.0, theta=0.0
% INFO    : Bus 57	: V=1.006533, theta=-9.693767 -> V=1.0, theta=0.0
% INFO    : Bus 58	: V=1.027113, theta=-22.181789 -> V=1.0, theta=0.0
% INFO    : Bus 59	: V=1.026698, theta=-24.169412 -> V=1.0, theta=0.0
% INFO    : Bus 60	: V=1.024291, theta=-19.933148 -> V=1.0, theta=0.0
% INFO    : Bus 61	: V=1.092743, theta=45.900184 -> V=1.0, theta=0.0
% INFO    : Bus 62	: V=0.970166, theta=-27.705319 -> V=1.0, theta=0.0
% INFO    : Bus 63	: V=1.020254, theta=5.462635 -> V=1.0, theta=0.0
% INFO    : Bus 64	: V=1.058218, theta=-24.075639 -> V=1.0, theta=0.0
% INFO    : Bus 65	: V=0.920443, theta=-33.979065 -> V=1.0, theta=0.0
% INFO    : Bus 66	: V=1.07583, theta=-17.389672 -> V=1.0, theta=0.0
% INFO    : Bus 67	: V=1.076797, theta=-22.668386 -> V=1.0, theta=0.0
% INFO    : Bus 68	: V=0.932272, theta=-32.555245 -> V=1.0, theta=0.0
% INFO    : Bus 69	: V=1.016399, theta=-0.749163 -> V=1.0, theta=0.0
% INFO    : Bus 70	: V=1.021842, theta=-7.278252 -> V=1.0, theta=0.0
% INFO    : Bus 71	: V=1.045653, theta=2.671707 -> V=1.0, theta=0.0
% INFO    : Bus 72	: V=1.007342, theta=-41.162683 -> V=1.0, theta=0.0
% INFO    : Bus 73	: V=1.011319, theta=-38.957605 -> V=1.0, theta=0.0
% INFO    : Bus 74	: V=1.048486, theta=-29.24882 -> V=1.0, theta=0.0
% INFO    : Bus 75	: V=1.019038, theta=-53.244715 -> V=1.0, theta=0.0
% INFO    : Bus 76	: V=1.022914, theta=25.568654 -> V=1.0, theta=0.0
% INFO    : Bus 77	: V=1.006664, theta=-49.599091 -> V=1.0, theta=0.0
% INFO    : Bus 78	: V=0.981839, theta=-20.873081 -> V=1.0, theta=0.0
% INFO    : Bus 79	: V=1.014386, theta=13.838092 -> V=1.0, theta=0.0
% INFO    : Bus 80	: V=1.068393, theta=-26.943073 -> V=1.0, theta=0.0
% INFO    : Bus 81	: V=1.010926, theta=61.408155 -> V=1.0, theta=0.0
% INFO    : Bus 82	: V=1.03239, theta=-34.385172 -> V=1.0, theta=0.0
% INFO    : Bus 83	: V=0.980327, theta=13.445474 -> V=1.0, theta=0.0
% INFO    : Bus 84	: V=1.018715, theta=-30.235601 -> V=1.0, theta=0.0
% INFO    : Bus 85	: V=1.022071, theta=16.413645 -> V=1.0, theta=0.0
% INFO    : Bus 86	: V=1.051084, theta=-24.673587 -> V=1.0, theta=0.0
% INFO    : Bus 87	: V=1.01789, theta=-15.037836 -> V=1.0, theta=0.0
% INFO    : Bus 88	: V=1.006747, theta=-37.071358 -> V=1.0, theta=0.0
% INFO    : Bus 89	: V=0.991009, theta=-5.004163 -> V=1.0, theta=0.0
% INFO    : Bus 90	: V=1.042035, theta=-27.99494 -> V=1.0, theta=0.0
% INFO    : Bus 91	: V=1.027005, theta=0.21051 -> V=1.0, theta=0.0
% INFO    : Bus 92	: V=1.022158, theta=3.828439 -> V=1.0, theta=0.0
% INFO    : Bus 93	: V=1.059099, theta=-21.280687 -> V=1.0, theta=0.0
% INFO    : Bus 94	: V=1.007744, theta=-25.49367 -> V=1.0, theta=0.0
% INFO    : Bus 95	: V=0.980011, theta=-30.352301 -> V=1.0, theta=0.0
% INFO    : Bus 96	: V=1.036787, theta=-15.459067 -> V=1.0, theta=0.0
% INFO    : Bus 97	: V=1.053303, theta=2.669719 -> V=1.0, theta=0.0
% INFO    : Bus 98	: V=1.048113, theta=-2.631892 -> V=1.0, theta=0.0
% INFO    : Bus 99	: V=1.02505, theta=-33.267073 -> V=1.0, theta=0.0
% INFO    : Bus 100	: V=1.033873, theta=-29.927627 -> V=1.0, theta=0.0
% INFO    : Bus 101	: V=0.964847, theta=-31.479281 -> V=1.0, theta=0.0
% INFO    : Bus 102	: V=1.004007, theta=-50.623198 -> V=1.0, theta=0.0
% INFO    : Bus 103	: V=0.992015, theta=-34.266143 -> V=1.0, theta=0.0
% INFO    : Bus 104	: V=0.965443, theta=-55.943839 -> V=1.0, theta=0.0
% INFO    : Bus 105	: V=1.036504, theta=-34.250878 -> V=1.0, theta=0.0
% INFO    : Bus 106	: V=1.162506, theta=-22.492638 -> V=1.0, theta=0.0
% INFO    : Bus 107	: V=1.083135, theta=41.615508 -> V=1.0, theta=0.0
% INFO    : Bus 108	: V=1.005191, theta=-17.950996 -> V=1.0, theta=0.0
% INFO    : Bus 109	: V=1.004858, theta=-11.902933 -> V=1.0, theta=0.0
% INFO    : Bus 110	: V=0.994253, theta=-32.082481 -> V=1.0, theta=0.0
% INFO    : Bus 111	: V=1.049848, theta=-22.296332 -> V=1.0, theta=0.0
% INFO    : Bus 112	: V=1.030495, theta=-9.592049 -> V=1.0, theta=0.0
% INFO    : Bus 113	: V=1.027407, theta=-14.491581 -> V=1.0, theta=0.0
% INFO    : Bus 114	: V=1.026508, theta=9.781802 -> V=1.0, theta=0.0
% INFO    : Bus 115	: V=1.062005, theta=-20.086677 -> V=1.0, theta=0.0
% INFO    : Bus 116	: V=1.037818, theta=-21.171048 -> V=1.0, theta=0.0
% INFO    : Bus 117	: V=1.002542, theta=-24.312333 -> V=1.0, theta=0.0
% INFO    : Bus 118	: V=1.023863, theta=-11.320452 -> V=1.0, theta=0.0
% INFO    : Bus 119	: V=1.066627, theta=-21.228028 -> V=1.0, theta=0.0
% INFO    : Bus 120	: V=1.017689, theta=-24.512143 -> V=1.0, theta=0.0
% INFO    : Bus 121	: V=1.061687, theta=-25.751773 -> V=1.0, theta=0.0
% INFO    : Bus 122	: V=1.002609, theta=8.035022 -> V=1.0, theta=0.0
% INFO    : Bus 123	: V=1.041503, theta=-19.868767 -> V=1.0, theta=0.0
% INFO    : Bus 124	: V=1.077112, theta=8.310105 -> V=1.0, theta=0.0
% INFO    : Bus 125	: V=1.022215, theta=-19.969192 -> V=1.0, theta=0.0
% INFO    : Bus 126	: V=1.009839, theta=3.639019 -> V=1.0, theta=0.0
% INFO    : Bus 127	: V=1.021779, theta=-28.832789 -> V=1.0, theta=0.0
% INFO    : Bus 128	: V=1.015182, theta=-16.413952 -> V=1.0, theta=0.0
% INFO    : Bus 129	: V=1.019572, theta=-12.355618 -> V=1.0, theta=0.0
% INFO    : Bus 130	: V=1.057946, theta=-47.3148 -> V=1.0, theta=0.0
% INFO    : Bus 131	: V=1.03239, theta=-40.262984 -> V=1.0, theta=0.0
% INFO    : Bus 132	: V=1.062408, theta=-43.935749 -> V=1.0, theta=0.0
% INFO    : Bus 133	: V=1.020783, theta=2.35489 -> V=1.0, theta=0.0
% INFO    : Bus 134	: V=1.012932, theta=6.186446 -> V=1.0, theta=0.0
% INFO    : Bus 135	: V=1.021481, theta=-22.444323 -> V=1.0, theta=0.0
% INFO    : Bus 136	: V=1.006509, theta=-36.386405 -> V=1.0, theta=0.0
% INFO    : Bus 137	: V=1.003064, theta=61.688917 -> V=1.0, theta=0.0
% INFO    : Bus 138	: V=1.067481, theta=-41.992026 -> V=1.0, theta=0.0
% INFO    : Bus 139	: V=1.013268, theta=16.764642 -> V=1.0, theta=0.0
% INFO    : Bus 140	: V=1.027453, theta=17.039361 -> V=1.0, theta=0.0
% INFO    : Bus 141	: V=1.050716, theta=-2.165585 -> V=1.0, theta=0.0
% INFO    : Bus 142	: V=1.042299, theta=-30.404497 -> V=1.0, theta=0.0
% INFO    : Bus 143	: V=1.022343, theta=3.87531 -> V=1.0, theta=0.0
% INFO    : Bus 144	: V=1.063798, theta=18.932224 -> V=1.0, theta=0.0
% INFO    : Bus 145	: V=1.038236, theta=-8.964288 -> V=1.0, theta=0.0
% INFO    : Bus 146	: V=1.085135, theta=-25.638373 -> V=1.0, theta=0.0
% INFO    : Bus 147	: V=1.058041, theta=-13.496004 -> V=1.0, theta=0.0
% INFO    : Bus 148	: V=1.034625, theta=-8.217967 -> V=1.0, theta=0.0
% INFO    : Bus 149	: V=1.021632, theta=-40.902503 -> V=1.0, theta=0.0
% INFO    : Bus 150	: V=1.062129, theta=2.399597 -> V=1.0, theta=0.0
% INFO    : Bus 151	: V=1.013748, theta=-24.076149 -> V=1.0, theta=0.0
% INFO    : Bus 152	: V=1.050332, theta=-5.822456 -> V=1.0, theta=0.0
% INFO    : Bus 153	: V=1.020345, theta=-28.197731 -> V=1.0, theta=0.0
% INFO    : Bus 154	: V=1.016529, theta=-40.246021 -> V=1.0, theta=0.0
% INFO    : Bus 155	: V=1.019829, theta=-29.30153 -> V=1.0, theta=0.0
% INFO    : Bus 156	: V=0.953098, theta=-31.912298 -> V=1.0, theta=0.0
% INFO    : Bus 157	: V=1.01451, theta=-13.069704 -> V=1.0, theta=0.0
% INFO    : Bus 158	: V=1.01467, theta=6.148661 -> V=1.0, theta=0.0
% INFO    : Bus 159	: V=1.021326, theta=-29.687582 -> V=1.0, theta=0.0
% INFO    : Bus 160	: V=1.031014, theta=0.809761 -> V=1.0, theta=0.0
% INFO    : Bus 161	: V=1.091016, theta=-27.88035 -> V=1.0, theta=0.0
% INFO    : Bus 162	: V=1.052312, theta=-15.685671 -> V=1.0, theta=0.0
% INFO    : Bus 163	: V=1.045445, theta=-10.873592 -> V=1.0, theta=0.0
% INFO    : Bus 164	: V=1.02082, theta=-1.152459 -> V=1.0, theta=0.0
% INFO    : Bus 165	: V=1.073155, theta=-24.141412 -> V=1.0, theta=0.0
% INFO    : Bus 166	: V=1.040747, theta=11.781552 -> V=1.0, theta=0.0
% INFO    : Bus 167	: V=1.031121, theta=-4.856472 -> V=1.0, theta=0.0
% INFO    : Bus 168	: V=1.033177, theta=12.044899 -> V=1.0, theta=0.0
% INFO    : Bus 169	: V=1.045543, theta=-29.415558 -> V=1.0, theta=0.0
% INFO    : Bus 170	: V=1.011462, theta=34.762397 -> V=1.0, theta=0.0
% INFO    : Bus 171	: V=1.061976, theta=-25.502124 -> V=1.0, theta=0.0
% INFO    : Bus 172	: V=1.010114, theta=-47.141199 -> V=1.0, theta=0.0
% INFO    : Bus 173	: V=1.054447, theta=14.634452 -> V=1.0, theta=0.0
% INFO    : Bus 174	: V=1.071451, theta=-28.241418 -> V=1.0, theta=0.0
% INFO    : Bus 175	: V=1.003654, theta=-41.36559 -> V=1.0, theta=0.0
% INFO    : Bus 176	: V=1.040842, theta=-28.533618 -> V=1.0, theta=0.0
% INFO    : Bus 177	: V=0.969767, theta=-43.357076 -> V=1.0, theta=0.0
% INFO    : Bus 178	: V=1.013199, theta=-30.419221 -> V=1.0, theta=0.0
% INFO    : Bus 179	: V=1.043661, theta=-50.052119 -> V=1.0, theta=0.0
% INFO    : Bus 180	: V=1.02953, theta=-28.102331 -> V=1.0, theta=0.0
% INFO    : Bus 181	: V=1.040515, theta=-39.643018 -> V=1.0, theta=0.0
% INFO    : Bus 182	: V=1.03553, theta=39.324365 -> V=1.0, theta=0.0
% INFO    : Bus 183	: V=1.031452, theta=-29.237157 -> V=1.0, theta=0.0
% INFO    : Bus 184	: V=1.037524, theta=-12.250638 -> V=1.0, theta=0.0
% INFO    : Bus 185	: V=1.007995, theta=-7.232267 -> V=1.0, theta=0.0
% INFO    : Bus 186	: V=1.009472, theta=-30.519212 -> V=1.0, theta=0.0
% INFO    : Bus 187	: V=1.002263, theta=-38.456187 -> V=1.0, theta=0.0
% INFO    : Bus 188	: V=1.015193, theta=-19.834342 -> V=1.0, theta=0.0
% INFO    : Bus 189	: V=1.001228, theta=-27.784349 -> V=1.0, theta=0.0
% INFO    : Bus 190	: V=1.025544, theta=-21.44389 -> V=1.0, theta=0.0
% INFO    : Bus 191	: V=1.016435, theta=-36.476155 -> V=1.0, theta=0.0
% INFO    : Bus 192	: V=1.048355, theta=66.012239 -> V=1.0, theta=0.0
% INFO    : Bus 193	: V=1.031896, theta=24.418857 -> V=1.0, theta=0.0
% INFO    : Bus 194	: V=1.02931, theta=13.231568 -> V=1.0, theta=0.0
% INFO    : Bus 195	: V=1.048915, theta=-9.187839 -> V=1.0, theta=0.0
% INFO    : Bus 196	: V=1.069098, theta=-26.717314 -> V=1.0, theta=0.0
% INFO    : Bus 197	: V=1.099985, theta=44.827022 -> V=1.0, theta=0.0
% INFO    : Bus 198	: V=1.011257, theta=-16.658556 -> V=1.0, theta=0.0
% INFO    : Bus 199	: V=1.017154, theta=0.540558 -> V=1.0, theta=0.0
% INFO    : Bus 200	: V=1.010977, theta=61.566699 -> V=1.0, theta=0.0
% INFO    : Bus 201	: V=1.01914, theta=-51.449761 -> V=1.0, theta=0.0
% INFO    : Bus 202	: V=1.028758, theta=-0.941811 -> V=1.0, theta=0.0
% INFO    : Bus 203	: V=1.034855, theta=13.22078 -> V=1.0, theta=0.0
% INFO    : Bus 204	: V=1.054685, theta=-23.538774 -> V=1.0, theta=0.0
% INFO    : Bus 205	: V=1.017882, theta=4.444704 -> V=1.0, theta=0.0
% INFO    : Bus 206	: V=1.062901, theta=-21.256948 -> V=1.0, theta=0.0
% INFO    : Bus 207	: V=1.021352, theta=-13.765901 -> V=1.0, theta=0.0
% INFO    : Bus 208	: V=1.041988, theta=-26.978403 -> V=1.0, theta=0.0
% INFO    : Bus 209	: V=1.026832, theta=-36.641167 -> V=1.0, theta=0.0
% INFO    : Bus 210	: V=0.959797, theta=-37.411141 -> V=1.0, theta=0.0
% INFO    : Bus 211	: V=1.031002, theta=12.816647 -> V=1.0, theta=0.0
% INFO    : Bus 212	: V=1.026845, theta=-5.374895 -> V=1.0, theta=0.0
% INFO    : Bus 213	: V=1.00854, theta=-35.282646 -> V=1.0, theta=0.0
% INFO    : Bus 214	: V=1.079765, theta=13.260236 -> V=1.0, theta=0.0
% INFO    : Bus 215	: V=1.002239, theta=-27.62245 -> V=1.0, theta=0.0
% INFO    : Bus 216	: V=1.036932, theta=-24.918537 -> V=1.0, theta=0.0
% INFO    : Bus 217	: V=1.032041, theta=-2.878371 -> V=1.0, theta=0.0
% INFO    : Bus 218	: V=1.048352, theta=-13.235694 -> V=1.0, theta=0.0
% INFO    : Bus 219	: V=1.056623, theta=-15.858282 -> V=1.0, theta=0.0
% INFO    : Bus 220	: V=1.047116, theta=-15.263985 -> V=1.0, theta=0.0
% INFO    : Bus 221	: V=1.030636, theta=-22.725319 -> V=1.0, theta=0.0
% INFO    : Bus 222	: V=1.030494, theta=64.590215 -> V=1.0, theta=0.0
% INFO    : Bus 223	: V=1.02935, theta=-21.253236 -> V=1.0, theta=0.0
% INFO    : Bus 224	: V=0.999483, theta=-19.779007 -> V=1.0, theta=0.0
% INFO    : Bus 225	: V=1.058955, theta=-20.480408 -> V=1.0, theta=0.0
% INFO    : Bus 226	: V=1.025663, theta=-34.219329 -> V=1.0, theta=0.0
% INFO    : Bus 227	: V=1.036575, theta=-23.032139 -> V=1.0, theta=0.0
% INFO    : Bus 228	: V=1.039157, theta=-8.583492 -> V=1.0, theta=0.0
% INFO    : Bus 229	: V=1.043175, theta=-27.471657 -> V=1.0, theta=0.0
% INFO    : Bus 230	: V=1.004938, theta=-47.015596 -> V=1.0, theta=0.0
% INFO    : Bus 231	: V=1.013236, theta=22.32882 -> V=1.0, theta=0.0
% INFO    : Bus 232	: V=1.012704, theta=-24.275333 -> V=1.0, theta=0.0
% INFO    : Bus 233	: V=0.951324, theta=-30.509004 -> V=1.0, theta=0.0
% INFO    : Bus 234	: V=1.011539, theta=-24.669443 -> V=1.0, theta=0.0
% INFO    : Bus 235	: V=0.988571, theta=-41.615405 -> V=1.0, theta=0.0
% INFO    : Bus 236	: V=1.023549, theta=-54.30395 -> V=1.0, theta=0.0
% INFO    : Bus 237	: V=1.032098, theta=38.584994 -> V=1.0, theta=0.0
% INFO    : Bus 238	: V=1.042719, theta=-48.730173 -> V=1.0, theta=0.0
% INFO    : Bus 239	: V=1.018711, theta=-30.200516 -> V=1.0, theta=0.0
% INFO    : Bus 240	: V=1.024081, theta=-30.555303 -> V=1.0, theta=0.0
% INFO    : Bus 241	: V=1.035656, theta=58.992416 -> V=1.0, theta=0.0
% INFO    : Bus 242	: V=1.03642, theta=-2.810922 -> V=1.0, theta=0.0
% INFO    : Bus 243	: V=1.017401, theta=17.219052 -> V=1.0, theta=0.0
% INFO    : Bus 244	: V=1.017943, theta=6.456763 -> V=1.0, theta=0.0
% INFO    : Bus 245	: V=1.011096, theta=-30.247505 -> V=1.0, theta=0.0
% INFO    : Bus 246	: V=1.06685, theta=-23.368108 -> V=1.0, theta=0.0
% INFO    : Bus 247	: V=0.988152, theta=-23.780097 -> V=1.0, theta=0.0
% INFO    : Bus 248	: V=1.043991, theta=11.30228 -> V=1.0, theta=0.0
% INFO    : Bus 249	: V=1.002426, theta=-43.012777 -> V=1.0, theta=0.0
% INFO    : Bus 250	: V=1.052918, theta=9.637659 -> V=1.0, theta=0.0
% INFO    : Bus 251	: V=1.014818, theta=9.078327 -> V=1.0, theta=0.0
% INFO    : Bus 252	: V=1.042194, theta=46.417078 -> V=1.0, theta=0.0
% INFO    : Bus 253	: V=1.031397, theta=-20.282601 -> V=1.0, theta=0.0
% INFO    : Bus 254	: V=1.067521, theta=-27.715246 -> V=1.0, theta=0.0
% INFO    : Bus 255	: V=1.059597, theta=-15.459412 -> V=1.0, theta=0.0
% INFO    : Bus 256	: V=1.036026, theta=-36.417261 -> V=1.0, theta=0.0
% INFO    : Bus 257	: V=1.027099, theta=-46.196068 -> V=1.0, theta=0.0
% INFO    : Bus 258	: V=1.035501, theta=-24.710337 -> V=1.0, theta=0.0
% INFO    : Bus 259	: V=1.014986, theta=-32.538711 -> V=1.0, theta=0.0
% INFO    : Bus 260	: V=1.026451, theta=-11.789492 -> V=1.0, theta=0.0
% INFO    : Bus 261	: V=1.052684, theta=-45.804706 -> V=1.0, theta=0.0
% INFO    : Bus 262	: V=1.033795, theta=9.17742 -> V=1.0, theta=0.0
% INFO    : Bus 263	: V=1.028681, theta=0.052818 -> V=1.0, theta=0.0
% INFO    : Bus 264	: V=1.010447, theta=-47.085784 -> V=1.0, theta=0.0
% INFO    : Bus 265	: V=1.051094, theta=-26.879001 -> V=1.0, theta=0.0
% INFO    : Bus 266	: V=1.05561, theta=-42.525923 -> V=1.0, theta=0.0
% INFO    : Bus 267	: V=1.008959, theta=-51.29783 -> V=1.0, theta=0.0
% INFO    : Bus 268	: V=1.040854, theta=25.721966 -> V=1.0, theta=0.0
% INFO    : Bus 269	: V=1.016247, theta=-41.093097 -> V=1.0, theta=0.0
% INFO    : Bus 270	: V=1.038383, theta=66.520284 -> V=1.0, theta=0.0
% INFO    : Bus 271	: V=1.034099, theta=-10.123925 -> V=1.0, theta=0.0
% INFO    : Bus 272	: V=1.051, theta=-31.736282 -> V=1.0, theta=0.0
% INFO    : Bus 273	: V=1.055045, theta=-27.649778 -> V=1.0, theta=0.0
% INFO    : Bus 274	: V=1.016203, theta=-27.399119 -> V=1.0, theta=0.0
% INFO    : Bus 275	: V=1.014295, theta=1.916687 -> V=1.0, theta=0.0
% INFO    : Bus 276	: V=1.046151, theta=63.617689 -> V=1.0, theta=0.0
% INFO    : Bus 277	: V=1.017147, theta=-28.974177 -> V=1.0, theta=0.0
% INFO    : Bus 278	: V=1.014153, theta=-29.26945 -> V=1.0, theta=0.0
% INFO    : Bus 279	: V=1.005219, theta=-28.673064 -> V=1.0, theta=0.0
% INFO    : Bus 280	: V=1.031588, theta=-11.381836 -> V=1.0, theta=0.0
% INFO    : Bus 281	: V=1.034886, theta=13.450704 -> V=1.0, theta=0.0
% INFO    : Bus 282	: V=1.077605, theta=-12.395364 -> V=1.0, theta=0.0
% INFO    : Bus 283	: V=1.030144, theta=-12.380018 -> V=1.0, theta=0.0
% INFO    : Bus 284	: V=1.021258, theta=-48.983591 -> V=1.0, theta=0.0
% INFO    : Bus 285	: V=1.033022, theta=66.384978 -> V=1.0, theta=0.0
% INFO    : Bus 286	: V=1.01692, theta=4.101949 -> V=1.0, theta=0.0
% INFO    : Bus 287	: V=1.05842, theta=-16.180765 -> V=1.0, theta=0.0
% INFO    : Bus 288	: V=1.064689, theta=-21.139278 -> V=1.0, theta=0.0
% INFO    : Bus 289	: V=1.046783, theta=-31.796612 -> V=1.0, theta=0.0
% INFO    : Bus 290	: V=1.026894, theta=-21.57601 -> V=1.0, theta=0.0
% INFO    : Bus 291	: V=1.037913, theta=3.647073 -> V=1.0, theta=0.0
% INFO    : Bus 292	: V=1.044729, theta=-14.863031 -> V=1.0, theta=0.0
% INFO    : Bus 293	: V=1.071967, theta=-22.394634 -> V=1.0, theta=0.0
% INFO    : Bus 294	: V=1.003375, theta=-3.704358 -> V=1.0, theta=0.0
% INFO    : Bus 295	: V=1.019298, theta=-29.061846 -> V=1.0, theta=0.0
% INFO    : Bus 296	: V=0.991132, theta=26.598199 -> V=1.0, theta=0.0
% INFO    : Bus 297	: V=1.032348, theta=3.967517 -> V=1.0, theta=0.0
% INFO    : Bus 298	: V=1.033157, theta=-31.091365 -> V=1.0, theta=0.0
% INFO    : Bus 299	: V=1.039248, theta=-46.484496 -> V=1.0, theta=0.0
% INFO    : Bus 300	: V=1.019085, theta=-22.661128 -> V=1.0, theta=0.0
% INFO    : Bus 301	: V=1.016739, theta=-24.050737 -> V=1.0, theta=0.0
% INFO    : Bus 302	: V=1.024624, theta=7.719367 -> V=1.0, theta=0.0
% INFO    : Bus 303	: V=1.008577, theta=-28.714495 -> V=1.0, theta=0.0
% INFO    : Bus 304	: V=0.989535, theta=-54.483262 -> V=1.0, theta=0.0
% INFO    : Bus 305	: V=1.065982, theta=-32.480519 -> V=1.0, theta=0.0
% INFO    : Bus 306	: V=1.024949, theta=-19.155495 -> V=1.0, theta=0.0
% INFO    : Bus 307	: V=1.078101, theta=-24.185519 -> V=1.0, theta=0.0
% INFO    : Bus 308	: V=0.858822, theta=-39.292558 -> V=1.0, theta=0.0
% INFO    : Bus 309	: V=0.989085, theta=12.894426 -> V=1.0, theta=0.0
% INFO    : Bus 310	: V=1.155322, theta=-21.430019 -> V=1.0, theta=0.0
% INFO    : Bus 311	: V=1.018788, theta=-2.280144 -> V=1.0, theta=0.0
% INFO    : Bus 312	: V=1.064463, theta=10.943215 -> V=1.0, theta=0.0
% INFO    : Bus 313	: V=1.025259, theta=6.096505 -> V=1.0, theta=0.0
% INFO    : Bus 314	: V=0.998939, theta=-16.361138 -> V=1.0, theta=0.0
% INFO    : Bus 315	: V=1.024288, theta=-36.514525 -> V=1.0, theta=0.0
% INFO    : Bus 316	: V=1.039789, theta=-4.974442 -> V=1.0, theta=0.0
% INFO    : Bus 317	: V=1.017314, theta=6.026115 -> V=1.0, theta=0.0
% INFO    : Bus 318	: V=0.995147, theta=-31.240936 -> V=1.0, theta=0.0
% INFO    : Bus 319	: V=1.018898, theta=-22.375931 -> V=1.0, theta=0.0
% INFO    : Bus 320	: V=1.013336, theta=8.731823 -> V=1.0, theta=0.0
% INFO    : Bus 321	: V=1.047108, theta=63.391695 -> V=1.0, theta=0.0
% INFO    : Bus 322	: V=0.960285, theta=-44.896787 -> V=1.0, theta=0.0
% INFO    : Bus 323	: V=1.021536, theta=4.254199 -> V=1.0, theta=0.0
% INFO    : Bus 324	: V=1.063285, theta=52.392117 -> V=1.0, theta=0.0
% INFO    : Bus 325	: V=1.009625, theta=-3.505565 -> V=1.0, theta=0.0
% INFO    : Bus 326	: V=1.040967, theta=25.768951 -> V=1.0, theta=0.0
% INFO    : Bus 327	: V=1.021761, theta=-12.621738 -> V=1.0, theta=0.0
% INFO    : Bus 328	: V=1.017618, theta=23.471214 -> V=1.0, theta=0.0
% INFO    : Bus 329	: V=1.019588, theta=-29.061157 -> V=1.0, theta=0.0
% INFO    : Bus 330	: V=1.05407, theta=10.188241 -> V=1.0, theta=0.0
% INFO    : Bus 331	: V=0.97496, theta=-31.995773 -> V=1.0, theta=0.0
% INFO    : Bus 332	: V=1.03175, theta=-25.481871 -> V=1.0, theta=0.0
% INFO    : Bus 333	: V=1.008335, theta=-42.644766 -> V=1.0, theta=0.0
% INFO    : Bus 334	: V=1.021555, theta=-8.102376 -> V=1.0, theta=0.0
% INFO    : Bus 335	: V=0.956257, theta=-31.167466 -> V=1.0, theta=0.0
% INFO    : Bus 336	: V=1.00793, theta=-20.199223 -> V=1.0, theta=0.0
% INFO    : Bus 337	: V=1.07406, theta=-19.162915 -> V=1.0, theta=0.0
% INFO    : Bus 338	: V=1.046957, theta=-6.228603 -> V=1.0, theta=0.0
% INFO    : Bus 339	: V=1.034126, theta=-34.903603 -> V=1.0, theta=0.0
% INFO    : Bus 340	: V=1.066043, theta=-22.461372 -> V=1.0, theta=0.0
% INFO    : Bus 341	: V=1.017154, theta=-29.141612 -> V=1.0, theta=0.0
% INFO    : Bus 342	: V=1.008599, theta=-32.559855 -> V=1.0, theta=0.0
% INFO    : Bus 343	: V=1.044421, theta=-22.619481 -> V=1.0, theta=0.0
% INFO    : Bus 344	: V=1.02817, theta=-1.864435 -> V=1.0, theta=0.0
% INFO    : Bus 345	: V=1.029033, theta=-30.721414 -> V=1.0, theta=0.0
% INFO    : Bus 346	: V=1.037587, theta=-21.605967 -> V=1.0, theta=0.0
% INFO    : Bus 347	: V=1.020949, theta=-4.447906 -> V=1.0, theta=0.0
% INFO    : Bus 348	: V=1.057894, theta=-25.029783 -> V=1.0, theta=0.0
% INFO    : Bus 349	: V=1.046687, theta=8.496714 -> V=1.0, theta=0.0
% INFO    : Bus 350	: V=1.038713, theta=-24.658174 -> V=1.0, theta=0.0
% INFO    : Bus 351	: V=1.025813, theta=17.762925 -> V=1.0, theta=0.0
% INFO    : Bus 352	: V=1.048835, theta=0.123472 -> V=1.0, theta=0.0
% INFO    : Bus 353	: V=1.053404, theta=-29.839213 -> V=1.0, theta=0.0
% INFO    : Bus 354	: V=1.046845, theta=-16.150037 -> V=1.0, theta=0.0
% INFO    : Bus 355	: V=0.994856, theta=-24.893606 -> V=1.0, theta=0.0
% INFO    : Bus 356	: V=1.046664, theta=-18.978177 -> V=1.0, theta=0.0
% INFO    : Bus 357	: V=1.014078, theta=-32.864305 -> V=1.0, theta=0.0
% INFO    : Bus 358	: V=1.03286, theta=8.494459 -> V=1.0, theta=0.0
% INFO    : Bus 359	: V=1.043241, theta=-13.963134 -> V=1.0, theta=0.0
% INFO    : Bus 360	: V=1.057579, theta=10.664154 -> V=1.0, theta=0.0
% INFO    : Bus 361	: V=1.05949, theta=16.125446 -> V=1.0, theta=0.0
% INFO    : Bus 362	: V=1.012713, theta=61.825927 -> V=1.0, theta=0.0
% INFO    : Bus 363	: V=1.084924, theta=-36.917309 -> V=1.0, theta=0.0
% INFO    : Bus 364	: V=1.009235, theta=-36.457276 -> V=1.0, theta=0.0
% INFO    : Bus 365	: V=1.011415, theta=-22.836999 -> V=1.0, theta=0.0
% INFO    : Bus 366	: V=1.008853, theta=-6.356964 -> V=1.0, theta=0.0
% INFO    : Bus 367	: V=1.06614, theta=-23.969395 -> V=1.0, theta=0.0
% INFO    : Bus 368	: V=1.017336, theta=-32.97169 -> V=1.0, theta=0.0
% INFO    : Bus 369	: V=1.047259, theta=12.873199 -> V=1.0, theta=0.0
% INFO    : Bus 370	: V=1.016126, theta=-2.465828 -> V=1.0, theta=0.0
% INFO    : Bus 371	: V=1.04061, theta=-20.694247 -> V=1.0, theta=0.0
% INFO    : Bus 372	: V=1.074991, theta=8.745956 -> V=1.0, theta=0.0
% INFO    : Bus 373	: V=0.9775, theta=-30.407675 -> V=1.0, theta=0.0
% INFO    : Bus 374	: V=1.035025, theta=-24.898686 -> V=1.0, theta=0.0
% INFO    : Bus 375	: V=1.013524, theta=52.440501 -> V=1.0, theta=0.0
% INFO    : Bus 376	: V=1.028991, theta=-31.53336 -> V=1.0, theta=0.0
% INFO    : Bus 377	: V=1.021561, theta=10.573296 -> V=1.0, theta=0.0
% INFO    : Bus 378	: V=1.017306, theta=-8.141276 -> V=1.0, theta=0.0
% INFO    : Bus 379	: V=0.995571, theta=-31.453181 -> V=1.0, theta=0.0
% INFO    : Bus 380	: V=1.00126, theta=-33.303602 -> V=1.0, theta=0.0
% INFO    : Bus 381	: V=0.935262, theta=-28.688114 -> V=1.0, theta=0.0
% INFO    : Bus 382	: V=1.060853, theta=-23.782062 -> V=1.0, theta=0.0
% INFO    : Bus 383	: V=0.991245, theta=-30.816553 -> V=1.0, theta=0.0
% INFO    : Bus 384	: V=1.006323, theta=-30.008109 -> V=1.0, theta=0.0
% INFO    : Bus 385	: V=1.039766, theta=-49.86378 -> V=1.0, theta=0.0
% INFO    : Bus 386	: V=1.064436, theta=21.11405 -> V=1.0, theta=0.0
% INFO    : Bus 387	: V=1.043626, theta=6.058475 -> V=1.0, theta=0.0
% INFO    : Bus 388	: V=0.988589, theta=6.832917 -> V=1.0, theta=0.0
% INFO    : Bus 389	: V=1.017731, theta=-41.302632 -> V=1.0, theta=0.0
% INFO    : Bus 390	: V=1.071096, theta=-17.869204 -> V=1.0, theta=0.0
% INFO    : Bus 391	: V=0.979313, theta=-27.16062 -> V=1.0, theta=0.0
% INFO    : Bus 392	: V=1.011308, theta=-0.952791 -> V=1.0, theta=0.0
% INFO    : Bus 393	: V=1.062143, theta=-27.065705 -> V=1.0, theta=0.0
% INFO    : Bus 394	: V=1.063147, theta=41.896073 -> V=1.0, theta=0.0
% INFO    : Bus 395	: V=1.033317, theta=14.723689 -> V=1.0, theta=0.0
% INFO    : Bus 396	: V=0.90329, theta=-35.996951 -> V=1.0, theta=0.0
% INFO    : Bus 397	: V=1.034394, theta=-13.831084 -> V=1.0, theta=0.0
% INFO    : Bus 398	: V=0.977257, theta=-21.273325 -> V=1.0, theta=0.0
% INFO    : Bus 399	: V=1.013866, theta=-36.125837 -> V=1.0, theta=0.0
% INFO    : Bus 400	: V=1.007695, theta=-30.151396 -> V=1.0, theta=0.0
% INFO    : Bus 401	: V=1.03497, theta=-14.683133 -> V=1.0, theta=0.0
% INFO    : Bus 402	: V=1.008743, theta=-36.11448 -> V=1.0, theta=0.0
% INFO    : Bus 403	: V=1.061673, theta=-28.767097 -> V=1.0, theta=0.0
% INFO    : Bus 404	: V=1.014378, theta=-26.354271 -> V=1.0, theta=0.0
% INFO    : Bus 405	: V=1.017423, theta=-46.712396 -> V=1.0, theta=0.0
% INFO    : Bus 406	: V=1.012399, theta=-36.269005 -> V=1.0, theta=0.0
% INFO    : Bus 407	: V=1.007216, theta=7.794515 -> V=1.0, theta=0.0
% INFO    : Bus 408	: V=1.03515, theta=-11.827186 -> V=1.0, theta=0.0
% INFO    : Bus 409	: V=1.032831, theta=-6.435889 -> V=1.0, theta=0.0
% INFO    : Bus 410	: V=1.031489, theta=-27.031073 -> V=1.0, theta=0.0
% INFO    : Bus 411	: V=1.03248, theta=-38.941809 -> V=1.0, theta=0.0
% INFO    : Bus 412	: V=1.022685, theta=13.654268 -> V=1.0, theta=0.0
% INFO    : Bus 413	: V=1.048421, theta=-6.81908 -> V=1.0, theta=0.0
% INFO    : Bus 414	: V=1.017694, theta=-32.178003 -> V=1.0, theta=0.0
% INFO    : Bus 415	: V=1.024129, theta=-52.284525 -> V=1.0, theta=0.0
% INFO    : Bus 416	: V=1.04501, theta=-6.926272 -> V=1.0, theta=0.0
% INFO    : Bus 417	: V=1.021927, theta=-11.809092 -> V=1.0, theta=0.0
% INFO    : Bus 418	: V=1.030169, theta=-27.397466 -> V=1.0, theta=0.0
% INFO    : Bus 419	: V=0.992991, theta=-23.021888 -> V=1.0, theta=0.0
% INFO    : Bus 420	: V=1.047945, theta=18.027026 -> V=1.0, theta=0.0
% INFO    : Bus 421	: V=0.994253, theta=-32.082481 -> V=1.0, theta=0.0
% INFO    : Bus 422	: V=0.99831, theta=-31.51274 -> V=1.0, theta=0.0
% INFO    : Bus 423	: V=1.030299, theta=-21.488115 -> V=1.0, theta=0.0
% INFO    : Bus 424	: V=1.051241, theta=41.066677 -> V=1.0, theta=0.0
% INFO    : Bus 425	: V=1.023036, theta=6.329808 -> V=1.0, theta=0.0
% INFO    : Bus 426	: V=1.038618, theta=-18.666777 -> V=1.0, theta=0.0
% INFO    : Bus 427	: V=1.074924, theta=-36.064337 -> V=1.0, theta=0.0
% INFO    : Bus 428	: V=0.98973, theta=-21.739403 -> V=1.0, theta=0.0
% INFO    : Bus 429	: V=1.011621, theta=-45.861365 -> V=1.0, theta=0.0
% INFO    : Bus 430	: V=1.045487, theta=-26.661671 -> V=1.0, theta=0.0
% INFO    : Bus 431	: V=1.031863, theta=6.601988 -> V=1.0, theta=0.0
% INFO    : Bus 432	: V=1.041598, theta=2.324897 -> V=1.0, theta=0.0
% INFO    : Bus 433	: V=1.024885, theta=20.046114 -> V=1.0, theta=0.0
% INFO    : Bus 434	: V=1.037999, theta=2.03991 -> V=1.0, theta=0.0
% INFO    : Bus 435	: V=1.018336, theta=-30.666235 -> V=1.0, theta=0.0
% INFO    : Bus 436	: V=1.120535, theta=-21.925748 -> V=1.0, theta=0.0
% INFO    : Bus 437	: V=1.016926, theta=-35.872023 -> V=1.0, theta=0.0
% INFO    : Bus 438	: V=1.038705, theta=59.611786 -> V=1.0, theta=0.0
% INFO    : Bus 439	: V=1.072491, theta=59.186166 -> V=1.0, theta=0.0
% INFO    : Bus 440	: V=1.028093, theta=-36.715425 -> V=1.0, theta=0.0
% INFO    : Bus 441	: V=1.032136, theta=-52.444714 -> V=1.0, theta=0.0
% INFO    : Bus 442	: V=1.011727, theta=-46.67987 -> V=1.0, theta=0.0
% INFO    : Bus 443	: V=1.001838, theta=-30.170359 -> V=1.0, theta=0.0
% INFO    : Bus 444	: V=1.031001, theta=-12.498392 -> V=1.0, theta=0.0
% INFO    : Bus 445	: V=1.019699, theta=-45.007189 -> V=1.0, theta=0.0
% INFO    : Bus 446	: V=1.014581, theta=-26.856538 -> V=1.0, theta=0.0
% INFO    : Bus 447	: V=1.035215, theta=-9.864665 -> V=1.0, theta=0.0
% INFO    : Bus 448	: V=0.96795, theta=-32.435222 -> V=1.0, theta=0.0
% INFO    : Bus 449	: V=1.016584, theta=-8.707775 -> V=1.0, theta=0.0
% INFO    : Bus 450	: V=1.070059, theta=-26.574071 -> V=1.0, theta=0.0
% INFO    : Bus 451	: V=1.063642, theta=22.363908 -> V=1.0, theta=0.0
% INFO    : Bus 452	: V=1.013382, theta=-41.604993 -> V=1.0, theta=0.0
% INFO    : Bus 453	: V=1.024712, theta=-7.790435 -> V=1.0, theta=0.0
% INFO    : Bus 454	: V=1.040257, theta=8.958679 -> V=1.0, theta=0.0
% INFO    : Bus 455	: V=1.038782, theta=-31.177998 -> V=1.0, theta=0.0
% INFO    : Bus 456	: V=0.999847, theta=-27.865709 -> V=1.0, theta=0.0
% INFO    : Bus 457	: V=0.993243, theta=-17.575552 -> V=1.0, theta=0.0
% INFO    : Bus 458	: V=1.035934, theta=-24.857043 -> V=1.0, theta=0.0
% INFO    : Bus 459	: V=1.003397, theta=-8.906619 -> V=1.0, theta=0.0
% INFO    : Bus 460	: V=0.997299, theta=-26.104521 -> V=1.0, theta=0.0
% INFO    : Bus 461	: V=1.010475, theta=-33.979657 -> V=1.0, theta=0.0
% INFO    : Bus 462	: V=1.01029, theta=-30.963324 -> V=1.0, theta=0.0
% INFO    : Bus 463	: V=0.985095, theta=-20.318385 -> V=1.0, theta=0.0
% INFO    : Bus 464	: V=1.04845, theta=-14.940147 -> V=1.0, theta=0.0
% INFO    : Bus 465	: V=1.026607, theta=-27.324978 -> V=1.0, theta=0.0
% INFO    : Bus 466	: V=1.03086, theta=-29.325776 -> V=1.0, theta=0.0
% INFO    : Bus 467	: V=1.023193, theta=-9.366271 -> V=1.0, theta=0.0
% INFO    : Bus 468	: V=0.967757, theta=-28.631796 -> V=1.0, theta=0.0
% INFO    : Bus 469	: V=1.014501, theta=-30.270983 -> V=1.0, theta=0.0
% INFO    : Bus 470	: V=1.045753, theta=-28.152812 -> V=1.0, theta=0.0
% INFO    : Bus 471	: V=1.024955, theta=-22.608823 -> V=1.0, theta=0.0
% INFO    : Bus 472	: V=1.048833, theta=7.3045 -> V=1.0, theta=0.0
% INFO    : Bus 473	: V=1.023798, theta=-46.331002 -> V=1.0, theta=0.0
% INFO    : Bus 474	: V=1.02207, theta=-39.273576 -> V=1.0, theta=0.0
% INFO    : Bus 475	: V=1.051128, theta=49.661516 -> V=1.0, theta=0.0
% INFO    : Bus 476	: V=0.992868, theta=5.766625 -> V=1.0, theta=0.0
% INFO    : Bus 477	: V=1.042365, theta=-42.331272 -> V=1.0, theta=0.0
% INFO    : Bus 478	: V=1.086063, theta=45.381505 -> V=1.0, theta=0.0
% INFO    : Bus 479	: V=1.006931, theta=-18.033449 -> V=1.0, theta=0.0
% INFO    : Bus 480	: V=1.04546, theta=-9.596128 -> V=1.0, theta=0.0
% INFO    : Bus 481	: V=1.021457, theta=-48.478236 -> V=1.0, theta=0.0
% INFO    : Bus 482	: V=0.984082, theta=-25.263297 -> V=1.0, theta=0.0
% INFO    : Bus 483	: V=1.017211, theta=-50.081883 -> V=1.0, theta=0.0
% INFO    : Bus 484	: V=1.054091, theta=53.806047 -> V=1.0, theta=0.0
% INFO    : Bus 485	: V=1.024648, theta=-30.843672 -> V=1.0, theta=0.0
% INFO    : Bus 486	: V=1.014868, theta=4.502664 -> V=1.0, theta=0.0
% INFO    : Bus 487	: V=1.014589, theta=-4.325752 -> V=1.0, theta=0.0
% INFO    : Bus 488	: V=1.036419, theta=2.841859 -> V=1.0, theta=0.0
% INFO    : Bus 489	: V=1.008032, theta=-47.898933 -> V=1.0, theta=0.0
% INFO    : Bus 490	: V=1.032528, theta=-23.365945 -> V=1.0, theta=0.0
% INFO    : Bus 491	: V=1.033193, theta=34.821441 -> V=1.0, theta=0.0
% INFO    : Bus 492	: V=0.9761, theta=-43.380627 -> V=1.0, theta=0.0
% INFO    : Bus 493	: V=0.977456, theta=-32.668095 -> V=1.0, theta=0.0
% INFO    : Bus 494	: V=0.994103, theta=-30.581336 -> V=1.0, theta=0.0
% INFO    : Bus 495	: V=1.091084, theta=47.134014 -> V=1.0, theta=0.0
% INFO    : Bus 496	: V=1.01836, theta=10.70214 -> V=1.0, theta=0.0
% INFO    : Bus 497	: V=1.025576, theta=8.402387 -> V=1.0, theta=0.0
% INFO    : Bus 498	: V=1.022852, theta=-28.519454 -> V=1.0, theta=0.0
% INFO    : Bus 499	: V=1.019259, theta=-5.089216 -> V=1.0, theta=0.0
% INFO    : Bus 500	: V=1.043162, theta=-15.091023 -> V=1.0, theta=0.0
% INFO    : Bus 501	: V=1.045916, theta=-27.133616 -> V=1.0, theta=0.0
% INFO    : Bus 502	: V=1.036985, theta=-6.888217 -> V=1.0, theta=0.0
% INFO    : Bus 503	: V=1.069204, theta=23.217465 -> V=1.0, theta=0.0
% INFO    : Bus 504	: V=0.996555, theta=-31.485081 -> V=1.0, theta=0.0
% INFO    : Bus 505	: V=1.022173, theta=10.007127 -> V=1.0, theta=0.0
% INFO    : Bus 506	: V=1.057858, theta=-9.331318 -> V=1.0, theta=0.0
% INFO    : Bus 507	: V=1.047975, theta=-25.997094 -> V=1.0, theta=0.0
% INFO    : Bus 508	: V=1.004689, theta=-24.87385 -> V=1.0, theta=0.0
% INFO    : Bus 509	: V=1.00895, theta=-61.098444 -> V=1.0, theta=0.0
% INFO    : Bus 510	: V=1.02625, theta=-22.233434 -> V=1.0, theta=0.0
% INFO    : Bus 511	: V=1.081589, theta=57.979622 -> V=1.0, theta=0.0
% INFO    : Bus 512	: V=1.005897, theta=-27.826195 -> V=1.0, theta=0.0
% INFO    : Bus 513	: V=1.031868, theta=-7.665769 -> V=1.0, theta=0.0
% INFO    : Bus 514	: V=1.017141, theta=-38.705949 -> V=1.0, theta=0.0
% INFO    : Bus 515	: V=1.045162, theta=-17.494553 -> V=1.0, theta=0.0
% INFO    : Bus 516	: V=1.07129, theta=-33.728741 -> V=1.0, theta=0.0
% INFO    : Bus 517	: V=0.9901, theta=-34.700265 -> V=1.0, theta=0.0
% INFO    : Bus 518	: V=1.067615, theta=-2.738928 -> V=1.0, theta=0.0
% INFO    : Bus 519	: V=1.019722, theta=-50.589759 -> V=1.0, theta=0.0
% INFO    : Bus 520	: V=1.049911, theta=-27.592982 -> V=1.0, theta=0.0
% INFO    : Bus 521	: V=1.003457, theta=-27.851665 -> V=1.0, theta=0.0
% INFO    : Bus 522	: V=1.014941, theta=-32.902975 -> V=1.0, theta=0.0
% INFO    : Bus 523	: V=1.042367, theta=6.642635 -> V=1.0, theta=0.0
% INFO    : Bus 524	: V=1.046979, theta=10.752972 -> V=1.0, theta=0.0
% INFO    : Bus 525	: V=0.969544, theta=13.480361 -> V=1.0, theta=0.0
% INFO    : Bus 526	: V=1.012916, theta=-48.291617 -> V=1.0, theta=0.0
% INFO    : Bus 527	: V=1.010053, theta=-46.915974 -> V=1.0, theta=0.0
% INFO    : Bus 528	: V=0.99921, theta=-50.924813 -> V=1.0, theta=0.0
% INFO    : Bus 529	: V=1.030762, theta=-16.275798 -> V=1.0, theta=0.0
% INFO    : Bus 530	: V=1.014401, theta=-22.258328 -> V=1.0, theta=0.0
% INFO    : Bus 531	: V=1.022093, theta=-18.724236 -> V=1.0, theta=0.0
% INFO    : Bus 532	: V=1.018038, theta=9.201002 -> V=1.0, theta=0.0
% INFO    : Bus 533	: V=0.959418, theta=-29.583188 -> V=1.0, theta=0.0
% INFO    : Bus 534	: V=1.009193, theta=1.409034 -> V=1.0, theta=0.0
% INFO    : Bus 535	: V=1.011587, theta=-36.72714 -> V=1.0, theta=0.0
% INFO    : Bus 536	: V=1.054738, theta=-48.67568 -> V=1.0, theta=0.0
% INFO    : Bus 537	: V=0.949809, theta=-29.215766 -> V=1.0, theta=0.0
% INFO    : Bus 538	: V=0.972441, theta=-36.764788 -> V=1.0, theta=0.0
% INFO    : Bus 539	: V=1.013931, theta=3.297995 -> V=1.0, theta=0.0
% INFO    : Bus 540	: V=0.973758, theta=10.352992 -> V=1.0, theta=0.0
% INFO    : Bus 541	: V=1.03819, theta=4.193683 -> V=1.0, theta=0.0
% INFO    : Bus 542	: V=1.067645, theta=-19.587155 -> V=1.0, theta=0.0
% INFO    : Bus 543	: V=0.995488, theta=-22.770476 -> V=1.0, theta=0.0
% INFO    : Bus 544	: V=1.034016, theta=-52.177549 -> V=1.0, theta=0.0
% INFO    : Bus 545	: V=1.065316, theta=-22.090019 -> V=1.0, theta=0.0
% INFO    : Bus 546	: V=1.081778, theta=-35.986218 -> V=1.0, theta=0.0
% INFO    : Bus 547	: V=1.012961, theta=-36.218409 -> V=1.0, theta=0.0
% INFO    : Bus 548	: V=1.029939, theta=15.35829 -> V=1.0, theta=0.0
% INFO    : Bus 549	: V=1.066337, theta=-11.605789 -> V=1.0, theta=0.0
% INFO    : Bus 550	: V=1.034222, theta=-45.869511 -> V=1.0, theta=0.0
% INFO    : Bus 551	: V=0.972889, theta=-36.288819 -> V=1.0, theta=0.0
% INFO    : Bus 552	: V=0.966453, theta=-43.582462 -> V=1.0, theta=0.0
% INFO    : Bus 553	: V=1.02741, theta=19.17319 -> V=1.0, theta=0.0
% INFO    : Bus 554	: V=1.020599, theta=-21.077132 -> V=1.0, theta=0.0
% INFO    : Bus 555	: V=1.036218, theta=-34.48522 -> V=1.0, theta=0.0
% INFO    : Bus 556	: V=1.032971, theta=-23.112249 -> V=1.0, theta=0.0
% INFO    : Bus 557	: V=1.042172, theta=-12.78196 -> V=1.0, theta=0.0
% INFO    : Bus 558	: V=1.017408, theta=17.219074 -> V=1.0, theta=0.0
% INFO    : Bus 559	: V=1.038823, theta=4.926964 -> V=1.0, theta=0.0
% INFO    : Bus 560	: V=1.001206, theta=-16.24915 -> V=1.0, theta=0.0
% INFO    : Bus 561	: V=1.045371, theta=-11.322037 -> V=1.0, theta=0.0
% INFO    : Bus 562	: V=1.035608, theta=-4.32039 -> V=1.0, theta=0.0
% INFO    : Bus 563	: V=0.967338, theta=-31.490411 -> V=1.0, theta=0.0
% INFO    : Bus 564	: V=1.06702, theta=-47.265609 -> V=1.0, theta=0.0
% INFO    : Bus 565	: V=1.01065, theta=-21.146836 -> V=1.0, theta=0.0
% INFO    : Bus 566	: V=0.966543, theta=-30.57403 -> V=1.0, theta=0.0
% INFO    : Bus 567	: V=1.062189, theta=-37.391032 -> V=1.0, theta=0.0
% INFO    : Bus 568	: V=1.018032, theta=-30.296337 -> V=1.0, theta=0.0
% INFO    : Bus 569	: V=1.076066, theta=-22.926788 -> V=1.0, theta=0.0
% INFO    : Bus 570	: V=0.993761, theta=-32.641501 -> V=1.0, theta=0.0
% INFO    : Bus 571	: V=1.004642, theta=11.297784 -> V=1.0, theta=0.0
% INFO    : Bus 572	: V=1.055676, theta=-15.620867 -> V=1.0, theta=0.0
% INFO    : Bus 573	: V=1.008172, theta=-39.537536 -> V=1.0, theta=0.0
% INFO    : Bus 574	: V=1.003792, theta=-28.302462 -> V=1.0, theta=0.0
% INFO    : Bus 575	: V=1.038739, theta=-11.457881 -> V=1.0, theta=0.0
% INFO    : Bus 576	: V=0.998317, theta=-18.957058 -> V=1.0, theta=0.0
% INFO    : Bus 577	: V=1.040133, theta=25.638278 -> V=1.0, theta=0.0
% INFO    : Bus 578	: V=1.042146, theta=18.799313 -> V=1.0, theta=0.0
% INFO    : Bus 579	: V=1.015454, theta=-52.416993 -> V=1.0, theta=0.0
% INFO    : Bus 580	: V=1.015167, theta=-40.787165 -> V=1.0, theta=0.0
% INFO    : Bus 581	: V=1.018271, theta=-23.574905 -> V=1.0, theta=0.0
% INFO    : Bus 582	: V=1.047477, theta=-20.544217 -> V=1.0, theta=0.0
% INFO    : Bus 583	: V=1.048595, theta=-15.609378 -> V=1.0, theta=0.0
% INFO    : Bus 584	: V=1.02646, theta=4.847775 -> V=1.0, theta=0.0
% INFO    : Bus 585	: V=1.040818, theta=3.328266 -> V=1.0, theta=0.0
% INFO    : Bus 586	: V=1.047762, theta=-26.908605 -> V=1.0, theta=0.0
% INFO    : Bus 587	: V=1.040079, theta=0.128428 -> V=1.0, theta=0.0
% INFO    : Bus 588	: V=0.987706, theta=-29.52887 -> V=1.0, theta=0.0
% INFO    : Bus 589	: V=1.051226, theta=-26.821071 -> V=1.0, theta=0.0
% INFO    : Bus 590	: V=1.065004, theta=54.658978 -> V=1.0, theta=0.0
% INFO    : Bus 591	: V=1.003047, theta=-31.096767 -> V=1.0, theta=0.0
% INFO    : Bus 592	: V=1.002326, theta=-0.228479 -> V=1.0, theta=0.0
% INFO    : Bus 593	: V=1.052806, theta=12.32779 -> V=1.0, theta=0.0
% INFO    : Bus 594	: V=1.03434, theta=-9.08879 -> V=1.0, theta=0.0
% INFO    : Bus 595	: V=1.021721, theta=-50.65158 -> V=1.0, theta=0.0
% INFO    : Bus 596	: V=0.967588, theta=-29.094022 -> V=1.0, theta=0.0
% INFO    : Bus 597	: V=1.054276, theta=-48.235591 -> V=1.0, theta=0.0
% INFO    : Bus 598	: V=0.988306, theta=-27.745722 -> V=1.0, theta=0.0
% INFO    : Bus 599	: V=0.984741, theta=-22.697595 -> V=1.0, theta=0.0
% INFO    : Bus 600	: V=1.020642, theta=2.766315 -> V=1.0, theta=0.0
% INFO    : Bus 601	: V=1.03709, theta=-14.510851 -> V=1.0, theta=0.0
% INFO    : Bus 602	: V=1.02089, theta=-47.482432 -> V=1.0, theta=0.0
% INFO    : Bus 603	: V=1.127591, theta=-22.048561 -> V=1.0, theta=0.0
% INFO    : Bus 604	: V=0.992921, theta=-13.224894 -> V=1.0, theta=0.0
% INFO    : Bus 605	: V=1.019051, theta=-5.534776 -> V=1.0, theta=0.0
% INFO    : Bus 606	: V=1.030805, theta=35.094114 -> V=1.0, theta=0.0
% INFO    : Bus 607	: V=1.030222, theta=-13.978729 -> V=1.0, theta=0.0
% INFO    : Bus 608	: V=1.063579, theta=-33.089502 -> V=1.0, theta=0.0
% INFO    : Bus 609	: V=1.028257, theta=-14.839583 -> V=1.0, theta=0.0
% INFO    : Bus 610	: V=0.985271, theta=-56.195761 -> V=1.0, theta=0.0
% INFO    : Bus 611	: V=1.019174, theta=-11.543717 -> V=1.0, theta=0.0
% INFO    : Bus 612	: V=1.035466, theta=-26.190388 -> V=1.0, theta=0.0
% INFO    : Bus 613	: V=1.020502, theta=3.815144 -> V=1.0, theta=0.0
% INFO    : Bus 614	: V=0.968407, theta=-37.402489 -> V=1.0, theta=0.0
% INFO    : Bus 615	: V=1.068592, theta=-11.049558 -> V=1.0, theta=0.0
% INFO    : Bus 616	: V=1.04484, theta=-13.078255 -> V=1.0, theta=0.0
% INFO    : Bus 617	: V=0.989164, theta=-28.084869 -> V=1.0, theta=0.0
% INFO    : Bus 618	: V=1.022784, theta=-49.328375 -> V=1.0, theta=0.0
% INFO    : Bus 619	: V=1.042351, theta=-25.58584 -> V=1.0, theta=0.0
% INFO    : Bus 620	: V=0.994999, theta=-19.07911 -> V=1.0, theta=0.0
% INFO    : Bus 621	: V=1.012924, theta=-52.128422 -> V=1.0, theta=0.0
% INFO    : Bus 622	: V=1.069133, theta=59.203598 -> V=1.0, theta=0.0
% INFO    : Bus 623	: V=1.029213, theta=1.427637 -> V=1.0, theta=0.0
% INFO    : Bus 624	: V=1.032738, theta=-10.941054 -> V=1.0, theta=0.0
% INFO    : Bus 625	: V=1.038541, theta=-27.690568 -> V=1.0, theta=0.0
% INFO    : Bus 626	: V=0.934086, theta=-33.42388 -> V=1.0, theta=0.0
% INFO    : Bus 627	: V=0.995326, theta=-35.195598 -> V=1.0, theta=0.0
% INFO    : Bus 628	: V=0.982057, theta=-35.15289 -> V=1.0, theta=0.0
% INFO    : Bus 629	: V=1.026049, theta=-18.858201 -> V=1.0, theta=0.0
% INFO    : Bus 630	: V=1.027499, theta=7.42553 -> V=1.0, theta=0.0
% INFO    : Bus 631	: V=0.996483, theta=-30.702079 -> V=1.0, theta=0.0
% INFO    : Bus 632	: V=1.088191, theta=-27.818441 -> V=1.0, theta=0.0
% INFO    : Bus 633	: V=0.958685, theta=-29.55312 -> V=1.0, theta=0.0
% INFO    : Bus 634	: V=1.018563, theta=3.431688 -> V=1.0, theta=0.0
% INFO    : Bus 635	: V=0.999819, theta=9.215641 -> V=1.0, theta=0.0
% INFO    : Bus 636	: V=1.04241, theta=-22.994363 -> V=1.0, theta=0.0
% INFO    : Bus 637	: V=1.031148, theta=16.262667 -> V=1.0, theta=0.0
% INFO    : Bus 638	: V=1.052719, theta=14.597739 -> V=1.0, theta=0.0
% INFO    : Bus 639	: V=1.033532, theta=-30.756579 -> V=1.0, theta=0.0
% INFO    : Bus 640	: V=1.015643, theta=36.723091 -> V=1.0, theta=0.0
% INFO    : Bus 641	: V=1.04342, theta=-13.738863 -> V=1.0, theta=0.0
% INFO    : Bus 642	: V=1.031368, theta=-50.812889 -> V=1.0, theta=0.0
% INFO    : Bus 643	: V=1.022609, theta=-2.01817 -> V=1.0, theta=0.0
% INFO    : Bus 644	: V=1.001275, theta=-19.482697 -> V=1.0, theta=0.0
% INFO    : Bus 645	: V=1.011105, theta=-26.132773 -> V=1.0, theta=0.0
% INFO    : Bus 646	: V=1.046449, theta=-22.474118 -> V=1.0, theta=0.0
% INFO    : Bus 647	: V=1.05839, theta=63.82172 -> V=1.0, theta=0.0
% INFO    : Bus 648	: V=1.02749, theta=49.995344 -> V=1.0, theta=0.0
% INFO    : Bus 649	: V=1.022389, theta=-48.793894 -> V=1.0, theta=0.0
% INFO    : Bus 650	: V=1.019857, theta=11.645411 -> V=1.0, theta=0.0
% INFO    : Bus 651	: V=1.046751, theta=64.301034 -> V=1.0, theta=0.0
% INFO    : Bus 652	: V=1.022847, theta=-11.260237 -> V=1.0, theta=0.0
% INFO    : Bus 653	: V=0.989505, theta=-17.821652 -> V=1.0, theta=0.0
% INFO    : Bus 654	: V=1.016548, theta=-25.008561 -> V=1.0, theta=0.0
% INFO    : Bus 655	: V=1.023447, theta=16.49929 -> V=1.0, theta=0.0
% INFO    : Bus 656	: V=1.025785, theta=17.764591 -> V=1.0, theta=0.0
% INFO    : Bus 657	: V=1.013809, theta=9.026926 -> V=1.0, theta=0.0
% INFO    : Bus 658	: V=1.029318, theta=-17.741053 -> V=1.0, theta=0.0
% INFO    : Bus 659	: V=1.016665, theta=5.978239 -> V=1.0, theta=0.0
% INFO    : Bus 660	: V=1.019972, theta=-41.903867 -> V=1.0, theta=0.0
% INFO    : Bus 661	: V=1.02925, theta=2.262276 -> V=1.0, theta=0.0
% INFO    : Bus 662	: V=1.024506, theta=11.339798 -> V=1.0, theta=0.0
% INFO    : Bus 663	: V=1.010876, theta=-28.859495 -> V=1.0, theta=0.0
% INFO    : Bus 664	: V=1.056439, theta=-27.160166 -> V=1.0, theta=0.0
% INFO    : Bus 665	: V=1.034079, theta=-22.397922 -> V=1.0, theta=0.0
% INFO    : Bus 666	: V=1.032739, theta=-5.56264 -> V=1.0, theta=0.0
% INFO    : Bus 667	: V=1.000555, theta=-32.932525 -> V=1.0, theta=0.0
% INFO    : Bus 668	: V=1.000234, theta=-4.191624 -> V=1.0, theta=0.0
% INFO    : Bus 669	: V=1.035809, theta=-30.822173 -> V=1.0, theta=0.0
% INFO    : Bus 670	: V=0.947855, theta=-29.361997 -> V=1.0, theta=0.0
% INFO    : Bus 671	: V=1.007092, theta=-26.93445 -> V=1.0, theta=0.0
% INFO    : Bus 672	: V=1.02121, theta=-44.373291 -> V=1.0, theta=0.0
% INFO    : Bus 673	: V=1.041688, theta=12.036915 -> V=1.0, theta=0.0
% INFO    : Bus 674	: V=1.093453, theta=-14.521151 -> V=1.0, theta=0.0
% INFO    : Bus 675	: V=0.997831, theta=-25.825725 -> V=1.0, theta=0.0
% INFO    : Bus 676	: V=1.023634, theta=5.250321 -> V=1.0, theta=0.0
% INFO    : Bus 677	: V=1.006126, theta=-30.215816 -> V=1.0, theta=0.0
% INFO    : Bus 678	: V=1.005243, theta=-17.794843 -> V=1.0, theta=0.0
% INFO    : Bus 679	: V=1.043895, theta=-17.188316 -> V=1.0, theta=0.0
% INFO    : Bus 680	: V=1.040164, theta=8.217594 -> V=1.0, theta=0.0
% INFO    : Bus 681	: V=1.062258, theta=-37.395143 -> V=1.0, theta=0.0
% INFO    : Bus 682	: V=1.060787, theta=-10.546299 -> V=1.0, theta=0.0
% INFO    : Bus 683	: V=0.981733, theta=10.278584 -> V=1.0, theta=0.0
% INFO    : Bus 684	: V=0.991967, theta=-50.700151 -> V=1.0, theta=0.0
% INFO    : Bus 685	: V=1.045493, theta=-14.845324 -> V=1.0, theta=0.0
% INFO    : Bus 686	: V=1.013903, theta=-47.02336 -> V=1.0, theta=0.0
% INFO    : Bus 687	: V=1.053586, theta=-4.477068 -> V=1.0, theta=0.0
% INFO    : Bus 688	: V=1.024501, theta=-24.443107 -> V=1.0, theta=0.0
% INFO    : Bus 689	: V=0.982084, theta=-19.04446 -> V=1.0, theta=0.0
% INFO    : Bus 690	: V=1.056369, theta=-29.885233 -> V=1.0, theta=0.0
% INFO    : Bus 691	: V=1.021389, theta=2.425783 -> V=1.0, theta=0.0
% INFO    : Bus 692	: V=1.059006, theta=-37.997965 -> V=1.0, theta=0.0
% INFO    : Bus 693	: V=1.058173, theta=-40.548699 -> V=1.0, theta=0.0
% INFO    : Bus 694	: V=1.044245, theta=-24.486833 -> V=1.0, theta=0.0
% INFO    : Bus 695	: V=0.999388, theta=-38.384235 -> V=1.0, theta=0.0
% INFO    : Bus 696	: V=1.055967, theta=-22.074281 -> V=1.0, theta=0.0
% INFO    : Bus 697	: V=1.031719, theta=-38.113646 -> V=1.0, theta=0.0
% INFO    : Bus 698	: V=0.999662, theta=-29.934873 -> V=1.0, theta=0.0
% INFO    : Bus 699	: V=1.009348, theta=-53.274369 -> V=1.0, theta=0.0
% INFO    : Bus 700	: V=0.966856, theta=-29.467501 -> V=1.0, theta=0.0
% INFO    : Bus 701	: V=1.00342, theta=-37.061425 -> V=1.0, theta=0.0
% INFO    : Bus 702	: V=1.004138, theta=-35.804254 -> V=1.0, theta=0.0
% INFO    : Bus 703	: V=1.126072, theta=-21.917059 -> V=1.0, theta=0.0
% INFO    : Bus 704	: V=1.01824, theta=-29.261283 -> V=1.0, theta=0.0
% INFO    : Bus 705	: V=1.021944, theta=8.392464 -> V=1.0, theta=0.0
% INFO    : Bus 706	: V=1.009578, theta=-44.478532 -> V=1.0, theta=0.0
% INFO    : Bus 707	: V=1.049779, theta=-25.989404 -> V=1.0, theta=0.0
% INFO    : Bus 708	: V=0.995859, theta=-50.724378 -> V=1.0, theta=0.0
% INFO    : Bus 709	: V=1.068875, theta=-42.494144 -> V=1.0, theta=0.0
% INFO    : Bus 710	: V=1.043988, theta=-45.482724 -> V=1.0, theta=0.0
% INFO    : Bus 711	: V=1.070147, theta=-1.338091 -> V=1.0, theta=0.0
% INFO    : Bus 712	: V=1.009004, theta=0.655932 -> V=1.0, theta=0.0
% INFO    : Bus 713	: V=1.034791, theta=-10.09141 -> V=1.0, theta=0.0
% INFO    : Bus 714	: V=1.065017, theta=-9.000082 -> V=1.0, theta=0.0
% INFO    : Bus 715	: V=1.021604, theta=6.902749 -> V=1.0, theta=0.0
% INFO    : Bus 716	: V=1.033505, theta=-24.40114 -> V=1.0, theta=0.0
% INFO    : Bus 717	: V=1.013062, theta=-23.916209 -> V=1.0, theta=0.0
% INFO    : Bus 718	: V=1.033036, theta=-25.366125 -> V=1.0, theta=0.0
% INFO    : Bus 719	: V=1.061862, theta=-23.123981 -> V=1.0, theta=0.0
% INFO    : Bus 720	: V=0.96634, theta=-27.364834 -> V=1.0, theta=0.0
% INFO    : Bus 721	: V=1.022542, theta=-25.272598 -> V=1.0, theta=0.0
% INFO    : Bus 722	: V=1.026617, theta=0.095694 -> V=1.0, theta=0.0
% INFO    : Bus 723	: V=1.026037, theta=4.930819 -> V=1.0, theta=0.0
% INFO    : Bus 724	: V=1.008661, theta=-41.52775 -> V=1.0, theta=0.0
% INFO    : Bus 725	: V=1.1296, theta=-23.424903 -> V=1.0, theta=0.0
% INFO    : Bus 726	: V=1.044199, theta=-5.348266 -> V=1.0, theta=0.0
% INFO    : Bus 727	: V=1.070143, theta=-13.948739 -> V=1.0, theta=0.0
% INFO    : Bus 728	: V=1.030375, theta=12.049558 -> V=1.0, theta=0.0
% INFO    : Bus 729	: V=0.972249, theta=-27.155352 -> V=1.0, theta=0.0
% INFO    : Bus 730	: V=1.007561, theta=-41.217125 -> V=1.0, theta=0.0
% INFO    : Bus 731	: V=1.041231, theta=-50.286139 -> V=1.0, theta=0.0
% INFO    : Bus 732	: V=1.030738, theta=18.834742 -> V=1.0, theta=0.0
% INFO    : Bus 733	: V=1.007989, theta=6.004639 -> V=1.0, theta=0.0
% INFO    : Bus 734	: V=1.027653, theta=-1.875847 -> V=1.0, theta=0.0
% INFO    : Bus 735	: V=1.026593, theta=15.765814 -> V=1.0, theta=0.0
% INFO    : Bus 736	: V=1.007191, theta=61.64009 -> V=1.0, theta=0.0
% INFO    : Bus 737	: V=0.991402, theta=-28.695305 -> V=1.0, theta=0.0
% INFO    : Bus 738	: V=1.033376, theta=-38.980898 -> V=1.0, theta=0.0
% INFO    : Bus 739	: V=1.035442, theta=-42.803605 -> V=1.0, theta=0.0
% INFO    : Bus 740	: V=0.999884, theta=-29.224674 -> V=1.0, theta=0.0
% INFO    : Bus 741	: V=0.98413, theta=-21.448945 -> V=1.0, theta=0.0
% INFO    : Bus 742	: V=1.053755, theta=-4.478576 -> V=1.0, theta=0.0
% INFO    : Bus 743	: V=1.067428, theta=-28.110496 -> V=1.0, theta=0.0
% INFO    : Bus 744	: V=1.032223, theta=-22.075222 -> V=1.0, theta=0.0
% INFO    : Bus 745	: V=1.010505, theta=-19.123791 -> V=1.0, theta=0.0
% INFO    : Bus 746	: V=0.955236, theta=-31.252302 -> V=1.0, theta=0.0
% INFO    : Bus 747	: V=1.068191, theta=-26.778671 -> V=1.0, theta=0.0
% INFO    : Bus 748	: V=1.083131, theta=-48.121049 -> V=1.0, theta=0.0
% INFO    : Bus 749	: V=1.053546, theta=-29.4801 -> V=1.0, theta=0.0
% INFO    : Bus 750	: V=1.038715, theta=-24.772095 -> V=1.0, theta=0.0
% INFO    : Bus 751	: V=1.020488, theta=-44.20282 -> V=1.0, theta=0.0
% INFO    : Bus 752	: V=1.036686, theta=-27.828072 -> V=1.0, theta=0.0
% INFO    : Bus 753	: V=0.998712, theta=-26.728595 -> V=1.0, theta=0.0
% INFO    : Bus 754	: V=1.044981, theta=-45.303749 -> V=1.0, theta=0.0
% INFO    : Bus 755	: V=1.011893, theta=-7.18658 -> V=1.0, theta=0.0
% INFO    : Bus 756	: V=0.9931, theta=-16.99482 -> V=1.0, theta=0.0
% INFO    : Bus 757	: V=1.013994, theta=-14.009904 -> V=1.0, theta=0.0
% INFO    : Bus 758	: V=0.972441, theta=-36.764788 -> V=1.0, theta=0.0
% INFO    : Bus 759	: V=1.027334, theta=-24.007216 -> V=1.0, theta=0.0
% INFO    : Bus 760	: V=1.04271, theta=-16.194539 -> V=1.0, theta=0.0
% INFO    : Bus 761	: V=1.055841, theta=-19.131647 -> V=1.0, theta=0.0
% INFO    : Bus 762	: V=1.044236, theta=-29.495612 -> V=1.0, theta=0.0
% INFO    : Bus 763	: V=1.042899, theta=-30.310969 -> V=1.0, theta=0.0
% INFO    : Bus 764	: V=1.048246, theta=-3.309099 -> V=1.0, theta=0.0
% INFO    : Bus 765	: V=1.017174, theta=-35.819032 -> V=1.0, theta=0.0
% INFO    : Bus 766	: V=1.037046, theta=-19.904905 -> V=1.0, theta=0.0
% INFO    : Bus 767	: V=0.915156, theta=-35.96451 -> V=1.0, theta=0.0
% INFO    : Bus 768	: V=0.986644, theta=-23.658422 -> V=1.0, theta=0.0
% INFO    : Bus 769	: V=1.020205, theta=-11.261996 -> V=1.0, theta=0.0
% INFO    : Bus 770	: V=1.061647, theta=-0.922147 -> V=1.0, theta=0.0
% INFO    : Bus 771	: V=1.038724, theta=-39.6443 -> V=1.0, theta=0.0
% INFO    : Bus 772	: V=1.037471, theta=-14.231744 -> V=1.0, theta=0.0
% INFO    : Bus 773	: V=0.992021, theta=-20.861422 -> V=1.0, theta=0.0
% INFO    : Bus 774	: V=1.038992, theta=8.899765 -> V=1.0, theta=0.0
% INFO    : Bus 775	: V=1.048905, theta=7.312541 -> V=1.0, theta=0.0
% INFO    : Bus 776	: V=1.023986, theta=-13.449737 -> V=1.0, theta=0.0
% INFO    : Bus 777	: V=1.029983, theta=-16.451254 -> V=1.0, theta=0.0
% INFO    : Bus 778	: V=1.047837, theta=-6.746098 -> V=1.0, theta=0.0
% INFO    : Bus 779	: V=1.039304, theta=17.406318 -> V=1.0, theta=0.0
% INFO    : Bus 780	: V=1.001975, theta=-45.135804 -> V=1.0, theta=0.0
% INFO    : Bus 781	: V=1.000347, theta=-44.894504 -> V=1.0, theta=0.0
% INFO    : Bus 782	: V=1.044993, theta=-20.921382 -> V=1.0, theta=0.0
% INFO    : Bus 783	: V=0.982732, theta=-29.85688 -> V=1.0, theta=0.0
% INFO    : Bus 784	: V=1.033901, theta=4.031176 -> V=1.0, theta=0.0
% INFO    : Bus 785	: V=1.030881, theta=-34.012074 -> V=1.0, theta=0.0
% INFO    : Bus 786	: V=1.048812, theta=-20.86338 -> V=1.0, theta=0.0
% INFO    : Bus 787	: V=1.014445, theta=-4.315582 -> V=1.0, theta=0.0
% INFO    : Bus 788	: V=0.954883, theta=-29.560185 -> V=1.0, theta=0.0
% INFO    : Bus 789	: V=1.052564, theta=-6.129951 -> V=1.0, theta=0.0
% INFO    : Bus 790	: V=1.066475, theta=11.763458 -> V=1.0, theta=0.0
% INFO    : Bus 791	: V=1.052091, theta=-6.530683 -> V=1.0, theta=0.0
% INFO    : Bus 792	: V=1.003673, theta=-3.167772 -> V=1.0, theta=0.0
% INFO    : Bus 793	: V=1.031031, theta=13.743552 -> V=1.0, theta=0.0
% INFO    : Bus 794	: V=0.984037, theta=-18.179598 -> V=1.0, theta=0.0
% INFO    : Bus 795	: V=1.041931, theta=-15.251585 -> V=1.0, theta=0.0
% INFO    : Bus 796	: V=1.01604, theta=-43.685946 -> V=1.0, theta=0.0
% INFO    : Bus 797	: V=1.017294, theta=-40.077949 -> V=1.0, theta=0.0
% INFO    : Bus 798	: V=1.015334, theta=14.085955 -> V=1.0, theta=0.0
% INFO    : Bus 799	: V=0.999312, theta=-30.615831 -> V=1.0, theta=0.0
% INFO    : Bus 800	: V=1.029716, theta=-12.414305 -> V=1.0, theta=0.0
% INFO    : Bus 801	: V=0.980529, theta=-33.119841 -> V=1.0, theta=0.0
% INFO    : Bus 802	: V=1.021496, theta=-41.492157 -> V=1.0, theta=0.0
% INFO    : Bus 803	: V=1.04662, theta=-25.280535 -> V=1.0, theta=0.0
% INFO    : Bus 804	: V=1.052624, theta=-7.620343 -> V=1.0, theta=0.0
% INFO    : Bus 805	: V=1.059049, theta=-11.263382 -> V=1.0, theta=0.0
% INFO    : Bus 806	: V=1.013023, theta=6.715226 -> V=1.0, theta=0.0
% INFO    : Bus 807	: V=1.053518, theta=-38.514381 -> V=1.0, theta=0.0
% INFO    : Bus 808	: V=1.016881, theta=-50.527441 -> V=1.0, theta=0.0
% INFO    : Bus 809	: V=1.024607, theta=-0.360983 -> V=1.0, theta=0.0
% INFO    : Bus 810	: V=1.014711, theta=-27.065473 -> V=1.0, theta=0.0
% INFO    : Bus 811	: V=1.030392, theta=-22.540776 -> V=1.0, theta=0.0
% INFO    : Bus 812	: V=1.008755, theta=-31.096175 -> V=1.0, theta=0.0
% INFO    : Bus 813	: V=1.037003, theta=-19.089875 -> V=1.0, theta=0.0
% INFO    : Bus 814	: V=1.017789, theta=-50.853491 -> V=1.0, theta=0.0
% INFO    : Bus 815	: V=1.016118, theta=-28.086312 -> V=1.0, theta=0.0
% INFO    : Bus 816	: V=1.056996, theta=-35.266904 -> V=1.0, theta=0.0
% INFO    : Bus 817	: V=1.01358, theta=-45.581795 -> V=1.0, theta=0.0
% INFO    : Bus 818	: V=1.030395, theta=51.296143 -> V=1.0, theta=0.0
% INFO    : Bus 819	: V=1.05081, theta=-0.785035 -> V=1.0, theta=0.0
% INFO    : Bus 820	: V=1.025873, theta=-0.511882 -> V=1.0, theta=0.0
% INFO    : Bus 821	: V=1.082078, theta=-36.000114 -> V=1.0, theta=0.0
% INFO    : Bus 822	: V=1.003485, theta=-8.072973 -> V=1.0, theta=0.0
% INFO    : Bus 823	: V=1.039055, theta=-2.419223 -> V=1.0, theta=0.0
% INFO    : Bus 824	: V=1.046857, theta=-2.975489 -> V=1.0, theta=0.0
% INFO    : Bus 825	: V=1.007201, theta=-36.665305 -> V=1.0, theta=0.0
% INFO    : Bus 826	: V=1.035423, theta=-32.770026 -> V=1.0, theta=0.0
% INFO    : Bus 827	: V=1.018231, theta=-13.13917 -> V=1.0, theta=0.0
% INFO    : Bus 828	: V=1.044382, theta=2.077536 -> V=1.0, theta=0.0
% INFO    : Bus 829	: V=1.018129, theta=15.42687 -> V=1.0, theta=0.0
% INFO    : Bus 830	: V=1.022107, theta=-40.853901 -> V=1.0, theta=0.0
% INFO    : Bus 831	: V=1.003271, theta=-26.364611 -> V=1.0, theta=0.0
% INFO    : Bus 832	: V=1.004583, theta=-50.562152 -> V=1.0, theta=0.0
% INFO    : Bus 833	: V=1.046835, theta=-26.285018 -> V=1.0, theta=0.0
% INFO    : Bus 834	: V=1.008384, theta=-37.145585 -> V=1.0, theta=0.0
% INFO    : Bus 835	: V=1.034014, theta=-24.956153 -> V=1.0, theta=0.0
% INFO    : Bus 836	: V=1.012335, theta=-21.59407 -> V=1.0, theta=0.0
% INFO    : Bus 837	: V=1.022737, theta=-40.410086 -> V=1.0, theta=0.0
% INFO    : Bus 838	: V=1.030987, theta=3.606486 -> V=1.0, theta=0.0
% INFO    : Bus 839	: V=1.02122, theta=-1.687736 -> V=1.0, theta=0.0
% INFO    : Bus 840	: V=1.022301, theta=-23.5857 -> V=1.0, theta=0.0
% INFO    : Bus 841	: V=1.08276, theta=-21.360294 -> V=1.0, theta=0.0
% INFO    : Bus 842	: V=1.025785, theta=-5.013219 -> V=1.0, theta=0.0
% INFO    : Bus 843	: V=1.017591, theta=-40.075365 -> V=1.0, theta=0.0
% INFO    : Bus 844	: V=1.064419, theta=-9.125625 -> V=1.0, theta=0.0
% INFO    : Bus 845	: V=1.003306, theta=-31.349574 -> V=1.0, theta=0.0
% INFO    : Bus 846	: V=1.056518, theta=-14.954697 -> V=1.0, theta=0.0
% INFO    : Bus 847	: V=1.027274, theta=19.174428 -> V=1.0, theta=0.0
% INFO    : Bus 848	: V=1.011431, theta=61.818191 -> V=1.0, theta=0.0
% INFO    : Bus 849	: V=1.037264, theta=-42.024951 -> V=1.0, theta=0.0
% INFO    : Bus 850	: V=0.956219, theta=-30.232358 -> V=1.0, theta=0.0
% INFO    : Bus 851	: V=1.018845, theta=-16.616591 -> V=1.0, theta=0.0
% INFO    : Bus 852	: V=1.007493, theta=-25.256407 -> V=1.0, theta=0.0
% INFO    : Bus 853	: V=1.023268, theta=-12.714531 -> V=1.0, theta=0.0
% INFO    : Bus 854	: V=1.023709, theta=-54.456583 -> V=1.0, theta=0.0
% INFO    : Bus 855	: V=1.027869, theta=-34.087073 -> V=1.0, theta=0.0
% INFO    : Bus 856	: V=0.976644, theta=-23.667349 -> V=1.0, theta=0.0
% INFO    : Bus 857	: V=0.96854, theta=-30.940544 -> V=1.0, theta=0.0
% INFO    : Bus 858	: V=1.028813, theta=0.822714 -> V=1.0, theta=0.0
% INFO    : Bus 859	: V=1.093242, theta=-27.533273 -> V=1.0, theta=0.0
% INFO    : Bus 860	: V=1.033912, theta=1.449836 -> V=1.0, theta=0.0
% INFO    : Bus 861	: V=1.050818, theta=-30.333474 -> V=1.0, theta=0.0
% INFO    : Bus 862	: V=1.011149, theta=-30.106886 -> V=1.0, theta=0.0
% INFO    : Bus 863	: V=1.00914, theta=-7.642598 -> V=1.0, theta=0.0
% INFO    : Bus 864	: V=0.95494, theta=-31.154654 -> V=1.0, theta=0.0
% INFO    : Bus 865	: V=1.08382, theta=-28.028856 -> V=1.0, theta=0.0
% INFO    : Bus 866	: V=1.055959, theta=43.766007 -> V=1.0, theta=0.0
% INFO    : Bus 867	: V=1.020409, theta=-5.272998 -> V=1.0, theta=0.0
% INFO    : Bus 868	: V=1.050793, theta=-21.666498 -> V=1.0, theta=0.0
% INFO    : Bus 869	: V=1.021539, theta=-47.087083 -> V=1.0, theta=0.0
% INFO    : Bus 870	: V=1.038333, theta=-24.930069 -> V=1.0, theta=0.0
% INFO    : Bus 871	: V=1.047396, theta=-12.310945 -> V=1.0, theta=0.0
% INFO    : Bus 872	: V=1.018555, theta=-24.221949 -> V=1.0, theta=0.0
% INFO    : Bus 873	: V=1.029121, theta=5.127443 -> V=1.0, theta=0.0
% INFO    : Bus 874	: V=0.967758, theta=-31.427129 -> V=1.0, theta=0.0
% INFO    : Bus 875	: V=1.038959, theta=-35.716579 -> V=1.0, theta=0.0
% INFO    : Bus 876	: V=1.012126, theta=-26.966924 -> V=1.0, theta=0.0
% INFO    : Bus 877	: V=1.019785, theta=-29.346446 -> V=1.0, theta=0.0
% INFO    : Bus 878	: V=1.032189, theta=9.787383 -> V=1.0, theta=0.0
% INFO    : Bus 879	: V=1.003179, theta=-44.618548 -> V=1.0, theta=0.0
% INFO    : Bus 880	: V=1.026334, theta=-13.567049 -> V=1.0, theta=0.0
% INFO    : Bus 881	: V=1.01993, theta=-22.777984 -> V=1.0, theta=0.0
% INFO    : Bus 882	: V=1.022697, theta=-46.380115 -> V=1.0, theta=0.0
% INFO    : Bus 883	: V=1.015357, theta=-10.191051 -> V=1.0, theta=0.0
% INFO    : Bus 884	: V=1.018802, theta=-30.29798 -> V=1.0, theta=0.0
% INFO    : Bus 885	: V=0.990763, theta=-30.757298 -> V=1.0, theta=0.0
% INFO    : Bus 886	: V=1.038441, theta=10.699656 -> V=1.0, theta=0.0
% INFO    : Bus 887	: V=1.068754, theta=-21.629845 -> V=1.0, theta=0.0
% INFO    : Bus 888	: V=1.037604, theta=-21.604862 -> V=1.0, theta=0.0
% INFO    : Bus 889	: V=1.014037, theta=-29.373377 -> V=1.0, theta=0.0
% INFO    : Bus 890	: V=0.992571, theta=-28.524136 -> V=1.0, theta=0.0
% INFO    : Bus 891	: V=1.062964, theta=-19.250317 -> V=1.0, theta=0.0
% INFO    : Bus 892	: V=1.06496, theta=-35.278849 -> V=1.0, theta=0.0
% INFO    : Bus 893	: V=1.035537, theta=-36.23179 -> V=1.0, theta=0.0
% INFO    : Bus 894	: V=1.054199, theta=-24.304132 -> V=1.0, theta=0.0
% INFO    : Bus 895	: V=1.07469, theta=-26.738864 -> V=1.0, theta=0.0
% INFO    : Bus 896	: V=1.021987, theta=2.509919 -> V=1.0, theta=0.0
% INFO    : Bus 897	: V=1.034443, theta=-20.896007 -> V=1.0, theta=0.0
% INFO    : Bus 898	: V=1.016315, theta=12.999579 -> V=1.0, theta=0.0
% INFO    : Bus 899	: V=1.038888, theta=-19.131057 -> V=1.0, theta=0.0
% INFO    : Bus 900	: V=1.041667, theta=-15.788508 -> V=1.0, theta=0.0
% INFO    : Bus 901	: V=0.959473, theta=-28.847628 -> V=1.0, theta=0.0
% INFO    : Bus 902	: V=1.015036, theta=-23.101701 -> V=1.0, theta=0.0
% INFO    : Bus 903	: V=1.068153, theta=-26.804113 -> V=1.0, theta=0.0
% INFO    : Bus 904	: V=1.007247, theta=-37.013111 -> V=1.0, theta=0.0
% INFO    : Bus 905	: V=1.04044, theta=-15.095745 -> V=1.0, theta=0.0
% INFO    : Bus 906	: V=0.960197, theta=-29.959435 -> V=1.0, theta=0.0
% INFO    : Bus 907	: V=1.038463, theta=-9.834075 -> V=1.0, theta=0.0
% INFO    : Bus 908	: V=1.054939, theta=-8.182367 -> V=1.0, theta=0.0
% INFO    : Bus 909	: V=1.05269, theta=-24.666613 -> V=1.0, theta=0.0
% INFO    : Bus 910	: V=1.013902, theta=-5.883269 -> V=1.0, theta=0.0
% INFO    : Bus 911	: V=1.021752, theta=-41.209614 -> V=1.0, theta=0.0
% INFO    : Bus 912	: V=1.091269, theta=-27.621559 -> V=1.0, theta=0.0
% INFO    : Bus 913	: V=1.026545, theta=-2.255482 -> V=1.0, theta=0.0
% INFO    : Bus 914	: V=1.077351, theta=-24.737334 -> V=1.0, theta=0.0
% INFO    : Bus 915	: V=1.037609, theta=-26.120005 -> V=1.0, theta=0.0
% INFO    : Bus 916	: V=1.022135, theta=-38.115322 -> V=1.0, theta=0.0
% INFO    : Bus 917	: V=1.061631, theta=-20.525158 -> V=1.0, theta=0.0
% INFO    : Bus 918	: V=1.006154, theta=-30.037871 -> V=1.0, theta=0.0
% INFO    : Bus 919	: V=1.016781, theta=11.540968 -> V=1.0, theta=0.0
% INFO    : Bus 920	: V=1.042446, theta=-21.074337 -> V=1.0, theta=0.0
% INFO    : Bus 921	: V=1.027687, theta=-21.517935 -> V=1.0, theta=0.0
% INFO    : Bus 922	: V=0.995692, theta=-17.550034 -> V=1.0, theta=0.0
% INFO    : Bus 923	: V=1.031651, theta=-23.442192 -> V=1.0, theta=0.0
% INFO    : Bus 924	: V=0.997399, theta=-50.006382 -> V=1.0, theta=0.0
% INFO    : Bus 925	: V=0.979496, theta=-16.132225 -> V=1.0, theta=0.0
% INFO    : Bus 926	: V=1.008066, theta=-0.465497 -> V=1.0, theta=0.0
% INFO    : Bus 927	: V=1.067901, theta=-48.107874 -> V=1.0, theta=0.0
% INFO    : Bus 928	: V=1.015527, theta=0.368562 -> V=1.0, theta=0.0
% INFO    : Bus 929	: V=1.021929, theta=-46.228732 -> V=1.0, theta=0.0
% INFO    : Bus 930	: V=1.058189, theta=-37.830017 -> V=1.0, theta=0.0
% INFO    : Bus 931	: V=1.00554, theta=-33.793222 -> V=1.0, theta=0.0
% INFO    : Bus 932	: V=1.025765, theta=-53.984442 -> V=1.0, theta=0.0
% INFO    : Bus 933	: V=1.020036, theta=-21.567564 -> V=1.0, theta=0.0
% INFO    : Bus 934	: V=0.999076, theta=-29.319835 -> V=1.0, theta=0.0
% INFO    : Bus 935	: V=1.044831, theta=-24.797521 -> V=1.0, theta=0.0
% INFO    : Bus 936	: V=0.999872, theta=-27.063751 -> V=1.0, theta=0.0
% INFO    : Bus 937	: V=0.998116, theta=-32.130798 -> V=1.0, theta=0.0
% INFO    : Bus 938	: V=1.054487, theta=36.893694 -> V=1.0, theta=0.0
% INFO    : Bus 939	: V=1.022797, theta=-23.045862 -> V=1.0, theta=0.0
% INFO    : Bus 940	: V=1.045541, theta=-28.687115 -> V=1.0, theta=0.0
% INFO    : Bus 941	: V=0.990209, theta=-24.492637 -> V=1.0, theta=0.0
% INFO    : Bus 942	: V=1.084754, theta=-14.407963 -> V=1.0, theta=0.0
% INFO    : Bus 943	: V=1.02621, theta=-23.16922 -> V=1.0, theta=0.0
% INFO    : Bus 944	: V=1.032883, theta=-20.178508 -> V=1.0, theta=0.0
% INFO    : Bus 945	: V=1.034208, theta=-32.420002 -> V=1.0, theta=0.0
% INFO    : Bus 946	: V=1.020348, theta=-48.526559 -> V=1.0, theta=0.0
% INFO    : Bus 947	: V=0.983073, theta=-49.782659 -> V=1.0, theta=0.0
% INFO    : Bus 948	: V=0.985851, theta=-55.797711 -> V=1.0, theta=0.0
% INFO    : Bus 949	: V=0.956304, theta=-29.76252 -> V=1.0, theta=0.0
% INFO    : Bus 950	: V=1.020914, theta=-0.217378 -> V=1.0, theta=0.0
% INFO    : Bus 951	: V=1.047979, theta=-16.169837 -> V=1.0, theta=0.0
% INFO    : Bus 952	: V=1.078738, theta=-22.026301 -> V=1.0, theta=0.0
% INFO    : Bus 953	: V=1.062501, theta=-13.250544 -> V=1.0, theta=0.0
% INFO    : Bus 954	: V=1.040885, theta=-21.822155 -> V=1.0, theta=0.0
% INFO    : Bus 955	: V=1.003862, theta=-11.442937 -> V=1.0, theta=0.0
% INFO    : Bus 956	: V=1.013505, theta=-13.078642 -> V=1.0, theta=0.0
% INFO    : Bus 957	: V=1.010333, theta=-46.607879 -> V=1.0, theta=0.0
% INFO    : Bus 958	: V=1.052882, theta=-31.072147 -> V=1.0, theta=0.0
% INFO    : Bus 959	: V=1.015348, theta=-14.224034 -> V=1.0, theta=0.0
% INFO    : Bus 960	: V=1.057857, theta=-9.331313 -> V=1.0, theta=0.0
% INFO    : Bus 961	: V=0.87466, theta=-38.032264 -> V=1.0, theta=0.0
% INFO    : Bus 962	: V=1.03371, theta=-46.108222 -> V=1.0, theta=0.0
% INFO    : Bus 963	: V=1.036965, theta=-32.220515 -> V=1.0, theta=0.0
% INFO    : Bus 964	: V=1.011961, theta=-11.884786 -> V=1.0, theta=0.0
% INFO    : Bus 965	: V=1.008014, theta=-41.589049 -> V=1.0, theta=0.0
% INFO    : Bus 966	: V=1.031333, theta=13.632899 -> V=1.0, theta=0.0
% INFO    : Bus 967	: V=0.990771, theta=-21.703522 -> V=1.0, theta=0.0
% INFO    : Bus 968	: V=1.007664, theta=8.988419 -> V=1.0, theta=0.0
% INFO    : Bus 969	: V=1.02364, theta=31.655804 -> V=1.0, theta=0.0
% INFO    : Bus 970	: V=1.01672, theta=-42.68566 -> V=1.0, theta=0.0
% INFO    : Bus 971	: V=1.0784, theta=-18.292644 -> V=1.0, theta=0.0
% INFO    : Bus 972	: V=1.078612, theta=5.133314 -> V=1.0, theta=0.0
% INFO    : Bus 973	: V=1.006917, theta=-29.683321 -> V=1.0, theta=0.0
% INFO    : Bus 974	: V=1.033045, theta=-33.938069 -> V=1.0, theta=0.0
% INFO    : Bus 975	: V=0.983715, theta=-35.520739 -> V=1.0, theta=0.0
% INFO    : Bus 976	: V=1.024328, theta=-50.054572 -> V=1.0, theta=0.0
% INFO    : Bus 977	: V=1.037866, theta=-11.661106 -> V=1.0, theta=0.0
% INFO    : Bus 978	: V=1.017319, theta=-26.107578 -> V=1.0, theta=0.0
% INFO    : Bus 979	: V=0.966427, theta=-22.917522 -> V=1.0, theta=0.0
% INFO    : Bus 980	: V=1.042778, theta=-25.471141 -> V=1.0, theta=0.0
% INFO    : Bus 981	: V=1.019705, theta=-44.544584 -> V=1.0, theta=0.0
% INFO    : Bus 982	: V=1.019431, theta=7.055187 -> V=1.0, theta=0.0
% INFO    : Bus 983	: V=1.078039, theta=44.244769 -> V=1.0, theta=0.0
% INFO    : Bus 984	: V=1.031963, theta=-38.021587 -> V=1.0, theta=0.0
% INFO    : Bus 985	: V=1.053659, theta=-42.273928 -> V=1.0, theta=0.0
% INFO    : Bus 986	: V=1.016651, theta=-52.854277 -> V=1.0, theta=0.0
% INFO    : Bus 987	: V=0.998791, theta=-39.118465 -> V=1.0, theta=0.0
% INFO    : Bus 988	: V=1.02316, theta=-53.019946 -> V=1.0, theta=0.0
% INFO    : Bus 989	: V=0.974921, theta=-32.236537 -> V=1.0, theta=0.0
% INFO    : Bus 990	: V=0.982837, theta=-34.864842 -> V=1.0, theta=0.0
% INFO    : Bus 991	: V=1.001634, theta=-23.735457 -> V=1.0, theta=0.0
% INFO    : Bus 992	: V=1.030255, theta=-25.800054 -> V=1.0, theta=0.0
% INFO    : Bus 993	: V=1.037248, theta=2.05329 -> V=1.0, theta=0.0
% INFO    : Bus 994	: V=1.025373, theta=-1.14671 -> V=1.0, theta=0.0
% INFO    : Bus 995	: V=1.045457, theta=-33.794469 -> V=1.0, theta=0.0
% INFO    : Bus 996	: V=0.984075, theta=-16.065522 -> V=1.0, theta=0.0
% INFO    : Bus 997	: V=1.036677, theta=-29.848168 -> V=1.0, theta=0.0
% INFO    : Bus 998	: V=1.027792, theta=-29.418146 -> V=1.0, theta=0.0
% INFO    : Bus 999	: V=1.013381, theta=19.8472 -> V=1.0, theta=0.0
% INFO    : Bus 1000	: V=1.018423, theta=-33.552172 -> V=1.0, theta=0.0
% INFO    : Bus 1001	: V=1.069874, theta=-33.89876 -> V=1.0, theta=0.0
% INFO    : Bus 1002	: V=1.03837, theta=-20.387948 -> V=1.0, theta=0.0
% INFO    : Bus 1003	: V=0.974669, theta=-32.950245 -> V=1.0, theta=0.0
% INFO    : Bus 1004	: V=0.99944, theta=9.540224 -> V=1.0, theta=0.0
% INFO    : Bus 1005	: V=1.059735, theta=-12.798107 -> V=1.0, theta=0.0
% INFO    : Bus 1006	: V=1.082777, theta=-21.788125 -> V=1.0, theta=0.0
% INFO    : Bus 1007	: V=1.017117, theta=-26.990387 -> V=1.0, theta=0.0
% INFO    : Bus 1008	: V=0.976559, theta=-32.083934 -> V=1.0, theta=0.0
% INFO    : Bus 1009	: V=1.021136, theta=-10.635216 -> V=1.0, theta=0.0
% INFO    : Bus 1010	: V=1.019454, theta=22.573664 -> V=1.0, theta=0.0
% INFO    : Bus 1011	: V=1.028562, theta=-1.860402 -> V=1.0, theta=0.0
% INFO    : Bus 1012	: V=1.004772, theta=-32.945011 -> V=1.0, theta=0.0
% INFO    : Bus 1013	: V=0.992433, theta=-47.062443 -> V=1.0, theta=0.0
% INFO    : Bus 1014	: V=1.009412, theta=-30.80973 -> V=1.0, theta=0.0
% INFO    : Bus 1015	: V=1.056717, theta=-5.590237 -> V=1.0, theta=0.0
% INFO    : Bus 1016	: V=1.054952, theta=-41.035126 -> V=1.0, theta=0.0
% INFO    : Bus 1017	: V=1.04868, theta=-23.788662 -> V=1.0, theta=0.0
% INFO    : Bus 1018	: V=0.978355, theta=-32.342729 -> V=1.0, theta=0.0
% INFO    : Bus 1019	: V=1.019661, theta=-37.5747 -> V=1.0, theta=0.0
% INFO    : Bus 1020	: V=1.043617, theta=6.058453 -> V=1.0, theta=0.0
% INFO    : Bus 1021	: V=1.012345, theta=-46.728053 -> V=1.0, theta=0.0
% INFO    : Bus 1022	: V=0.992408, theta=-17.735225 -> V=1.0, theta=0.0
% INFO    : Bus 1023	: V=1.012791, theta=-44.581771 -> V=1.0, theta=0.0
% INFO    : Bus 1024	: V=1.03027, theta=-12.097523 -> V=1.0, theta=0.0
% INFO    : Bus 1025	: V=1.023682, theta=-52.453183 -> V=1.0, theta=0.0
% INFO    : Bus 1026	: V=1.027568, theta=-29.827138 -> V=1.0, theta=0.0
% INFO    : Bus 1027	: V=0.985955, theta=-18.490902 -> V=1.0, theta=0.0
% INFO    : Bus 1028	: V=1.003783, theta=-27.631688 -> V=1.0, theta=0.0
% INFO    : Bus 1029	: V=1.037886, theta=65.155421 -> V=1.0, theta=0.0
% INFO    : Bus 1030	: V=1.007808, theta=-36.442619 -> V=1.0, theta=0.0
% INFO    : Bus 1031	: V=1.037625, theta=-39.011568 -> V=1.0, theta=0.0
% INFO    : Bus 1032	: V=1.02192, theta=-29.453136 -> V=1.0, theta=0.0
% INFO    : Bus 1033	: V=1.038506, theta=-24.849537 -> V=1.0, theta=0.0
% INFO    : Bus 1034	: V=1.019297, theta=-29.061837 -> V=1.0, theta=0.0
% INFO    : Bus 1035	: V=1.066609, theta=-32.368109 -> V=1.0, theta=0.0
% INFO    : Bus 1036	: V=1.037074, theta=-31.532599 -> V=1.0, theta=0.0
% INFO    : Bus 1037	: V=1.018031, theta=4.736977 -> V=1.0, theta=0.0
% INFO    : Bus 1038	: V=1.008041, theta=-20.370492 -> V=1.0, theta=0.0
% INFO    : Bus 1039	: V=1.037717, theta=-19.559946 -> V=1.0, theta=0.0
% INFO    : Bus 1040	: V=1.038149, theta=-9.088994 -> V=1.0, theta=0.0
% INFO    : Bus 1041	: V=0.996584, theta=-44.290466 -> V=1.0, theta=0.0
% INFO    : Bus 1042	: V=1.013159, theta=-5.711376 -> V=1.0, theta=0.0
% INFO    : Bus 1043	: V=1.027465, theta=-3.716213 -> V=1.0, theta=0.0
% INFO    : Bus 1044	: V=1.015463, theta=4.567787 -> V=1.0, theta=0.0
% INFO    : Bus 1045	: V=0.939467, theta=-31.301987 -> V=1.0, theta=0.0
% INFO    : Bus 1046	: V=1.013503, theta=-4.847615 -> V=1.0, theta=0.0
% INFO    : Bus 1047	: V=0.989534, theta=-28.010272 -> V=1.0, theta=0.0
% INFO    : Bus 1048	: V=0.985687, theta=-28.380151 -> V=1.0, theta=0.0
% INFO    : Bus 1049	: V=1.135903, theta=-22.296959 -> V=1.0, theta=0.0
% INFO    : Bus 1050	: V=1.055375, theta=7.398452 -> V=1.0, theta=0.0
% INFO    : Bus 1051	: V=1.049425, theta=-13.263849 -> V=1.0, theta=0.0
% INFO    : Bus 1052	: V=1.032925, theta=21.769886 -> V=1.0, theta=0.0
% INFO    : Bus 1053	: V=0.973855, theta=-28.223475 -> V=1.0, theta=0.0
% INFO    : Bus 1054	: V=1.038498, theta=3.951777 -> V=1.0, theta=0.0
% INFO    : Bus 1055	: V=0.961777, theta=-31.641638 -> V=1.0, theta=0.0
% INFO    : Bus 1056	: V=1.048731, theta=-29.212214 -> V=1.0, theta=0.0
% INFO    : Bus 1057	: V=1.040602, theta=25.720393 -> V=1.0, theta=0.0
% INFO    : Bus 1058	: V=1.011927, theta=-4.94966 -> V=1.0, theta=0.0
% INFO    : Bus 1059	: V=1.077115, theta=-24.805028 -> V=1.0, theta=0.0
% INFO    : Bus 1060	: V=1.063056, theta=-42.078575 -> V=1.0, theta=0.0
% INFO    : Bus 1061	: V=0.991146, theta=-30.797621 -> V=1.0, theta=0.0
% INFO    : Bus 1062	: V=1.034796, theta=-21.679472 -> V=1.0, theta=0.0
% INFO    : Bus 1063	: V=1.02324, theta=-26.441023 -> V=1.0, theta=0.0
% INFO    : Bus 1064	: V=1.020517, theta=-47.401359 -> V=1.0, theta=0.0
% INFO    : Bus 1065	: V=1.025911, theta=-54.439585 -> V=1.0, theta=0.0
% INFO    : Bus 1066	: V=1.014112, theta=22.983748 -> V=1.0, theta=0.0
% INFO    : Bus 1067	: V=1.030938, theta=-9.616423 -> V=1.0, theta=0.0
% INFO    : Bus 1068	: V=1.024401, theta=-34.284548 -> V=1.0, theta=0.0
% INFO    : Bus 1069	: V=1.037185, theta=-17.757679 -> V=1.0, theta=0.0
% INFO    : Bus 1070	: V=1.008505, theta=-19.977089 -> V=1.0, theta=0.0
% INFO    : Bus 1071	: V=1.003174, theta=-36.685975 -> V=1.0, theta=0.0
% INFO    : Bus 1072	: V=1.039691, theta=-19.16149 -> V=1.0, theta=0.0
% INFO    : Bus 1073	: V=1.026076, theta=-29.884032 -> V=1.0, theta=0.0
% INFO    : Bus 1074	: V=1.04095, theta=-43.559156 -> V=1.0, theta=0.0
% INFO    : Bus 1075	: V=1.064906, theta=-12.957107 -> V=1.0, theta=0.0
% INFO    : Bus 1076	: V=0.968504, theta=-37.395062 -> V=1.0, theta=0.0
% INFO    : Bus 1077	: V=1.030146, theta=-12.380039 -> V=1.0, theta=0.0
% INFO    : Bus 1078	: V=1.061677, theta=-3.667956 -> V=1.0, theta=0.0
% INFO    : Bus 1079	: V=1.015897, theta=3.296097 -> V=1.0, theta=0.0
% INFO    : Bus 1080	: V=1.048144, theta=-9.51724 -> V=1.0, theta=0.0
% INFO    : Bus 1081	: V=1.035902, theta=-10.739144 -> V=1.0, theta=0.0
% INFO    : Bus 1082	: V=1.027941, theta=-33.928194 -> V=1.0, theta=0.0
% INFO    : Bus 1083	: V=1.050507, theta=-8.794066 -> V=1.0, theta=0.0
% INFO    : Bus 1084	: V=1.028976, theta=-28.282323 -> V=1.0, theta=0.0
% INFO    : Bus 1085	: V=1.00298, theta=-8.37152 -> V=1.0, theta=0.0
% INFO    : Bus 1086	: V=1.023093, theta=-47.400901 -> V=1.0, theta=0.0
% INFO    : Bus 1087	: V=0.984572, theta=-32.181246 -> V=1.0, theta=0.0
% INFO    : Bus 1088	: V=1.025882, theta=4.447559 -> V=1.0, theta=0.0
% INFO    : Bus 1089	: V=1.038058, theta=-23.070431 -> V=1.0, theta=0.0
% INFO    : Bus 1090	: V=1.004865, theta=-22.053504 -> V=1.0, theta=0.0
% INFO    : Bus 1091	: V=1.018617, theta=-14.616679 -> V=1.0, theta=0.0
% INFO    : Bus 1092	: V=1.032023, theta=-38.196172 -> V=1.0, theta=0.0
% INFO    : Bus 1093	: V=1.024587, theta=-8.719591 -> V=1.0, theta=0.0
% INFO    : Bus 1094	: V=1.039718, theta=5.490813 -> V=1.0, theta=0.0
% INFO    : Bus 1095	: V=1.070027, theta=-18.934012 -> V=1.0, theta=0.0
% INFO    : Bus 1096	: V=1.048892, theta=-1.184862 -> V=1.0, theta=0.0
% INFO    : Bus 1097	: V=1.013606, theta=-7.316502 -> V=1.0, theta=0.0
% INFO    : Bus 1098	: V=1.104358, theta=-15.215621 -> V=1.0, theta=0.0
% INFO    : Bus 1099	: V=0.998984, theta=-30.306116 -> V=1.0, theta=0.0
% INFO    : Bus 1100	: V=1.042301, theta=-4.415824 -> V=1.0, theta=0.0
% INFO    : Bus 1101	: V=1.035848, theta=-14.267458 -> V=1.0, theta=0.0
% INFO    : Bus 1102	: V=1.048163, theta=-6.85459 -> V=1.0, theta=0.0
% INFO    : Bus 1103	: V=1.043526, theta=28.251143 -> V=1.0, theta=0.0
% INFO    : Bus 1104	: V=0.964886, theta=-28.982903 -> V=1.0, theta=0.0
% INFO    : Bus 1105	: V=1.069031, theta=-26.723445 -> V=1.0, theta=0.0
% INFO    : Bus 1106	: V=1.046946, theta=4.257387 -> V=1.0, theta=0.0
% INFO    : Bus 1107	: V=0.973029, theta=-23.099573 -> V=1.0, theta=0.0
% INFO    : Bus 1108	: V=1.052123, theta=-29.359334 -> V=1.0, theta=0.0
% INFO    : Bus 1109	: V=1.024606, theta=-35.185395 -> V=1.0, theta=0.0
% INFO    : Bus 1110	: V=1.035989, theta=11.686414 -> V=1.0, theta=0.0
% INFO    : Bus 1111	: V=1.03448, theta=-9.0907 -> V=1.0, theta=0.0
% INFO    : Bus 1112	: V=1.033389, theta=-33.610217 -> V=1.0, theta=0.0
% INFO    : Bus 1113	: V=1.020325, theta=-0.47106 -> V=1.0, theta=0.0
% INFO    : Bus 1114	: V=1.047194, theta=-39.000121 -> V=1.0, theta=0.0
% INFO    : Bus 1115	: V=1.023643, theta=-39.410745 -> V=1.0, theta=0.0
% INFO    : Bus 1116	: V=1.018934, theta=14.925452 -> V=1.0, theta=0.0
% INFO    : Bus 1117	: V=1.009173, theta=11.392662 -> V=1.0, theta=0.0
% INFO    : Bus 1118	: V=1.045067, theta=-18.777768 -> V=1.0, theta=0.0
% INFO    : Bus 1119	: V=1.044725, theta=-17.505101 -> V=1.0, theta=0.0
% INFO    : Bus 1120	: V=1.01817, theta=-14.430025 -> V=1.0, theta=0.0
% INFO    : Bus 1121	: V=1.017488, theta=-39.332774 -> V=1.0, theta=0.0
% INFO    : Bus 1122	: V=1.043868, theta=-23.808841 -> V=1.0, theta=0.0
% INFO    : Bus 1123	: V=1.025795, theta=16.953171 -> V=1.0, theta=0.0
% INFO    : Bus 1124	: V=1.063307, theta=14.826169 -> V=1.0, theta=0.0
% INFO    : Bus 1125	: V=1.04319, theta=-30.889362 -> V=1.0, theta=0.0
% INFO    : Bus 1126	: V=1.021722, theta=4.402401 -> V=1.0, theta=0.0
% INFO    : Bus 1127	: V=1.079314, theta=-12.470313 -> V=1.0, theta=0.0
% INFO    : Bus 1128	: V=1.048934, theta=-7.971599 -> V=1.0, theta=0.0
% INFO    : Bus 1129	: V=0.99805, theta=-22.902706 -> V=1.0, theta=0.0
% INFO    : Bus 1130	: V=1.029873, theta=-0.92219 -> V=1.0, theta=0.0
% INFO    : Bus 1131	: V=1.036981, theta=-19.775059 -> V=1.0, theta=0.0
% INFO    : Bus 1132	: V=1.08516, theta=-20.849986 -> V=1.0, theta=0.0
% INFO    : Bus 1133	: V=1.054793, theta=-43.968979 -> V=1.0, theta=0.0
% INFO    : Bus 1134	: V=1.018158, theta=-9.960622 -> V=1.0, theta=0.0
% INFO    : Bus 1135	: V=0.966502, theta=-25.233439 -> V=1.0, theta=0.0
% INFO    : Bus 1136	: V=1.031372, theta=-18.80801 -> V=1.0, theta=0.0
% INFO    : Bus 1137	: V=1.04431, theta=-24.755071 -> V=1.0, theta=0.0
% INFO    : Bus 1138	: V=1.088765, theta=7.13698 -> V=1.0, theta=0.0
% INFO    : Bus 1139	: V=1.054186, theta=-24.325848 -> V=1.0, theta=0.0
% INFO    : Bus 1140	: V=1.009072, theta=-49.276824 -> V=1.0, theta=0.0
% INFO    : Bus 1141	: V=1.031688, theta=-8.571048 -> V=1.0, theta=0.0
% INFO    : Bus 1142	: V=1.0762, theta=-24.508279 -> V=1.0, theta=0.0
% INFO    : Bus 1143	: V=1.030916, theta=-22.356332 -> V=1.0, theta=0.0
% INFO    : Bus 1144	: V=1.009634, theta=36.656414 -> V=1.0, theta=0.0
% INFO    : Bus 1145	: V=1.040382, theta=-21.673882 -> V=1.0, theta=0.0
% INFO    : Bus 1146	: V=1.028294, theta=-5.941826 -> V=1.0, theta=0.0
% INFO    : Bus 1147	: V=0.982943, theta=9.189194 -> V=1.0, theta=0.0
% INFO    : Bus 1148	: V=1.015023, theta=2.923453 -> V=1.0, theta=0.0
% INFO    : Bus 1149	: V=1.029066, theta=-32.126057 -> V=1.0, theta=0.0
% INFO    : Bus 1150	: V=1.032236, theta=26.297269 -> V=1.0, theta=0.0
% INFO    : Bus 1151	: V=1.040253, theta=-20.910202 -> V=1.0, theta=0.0
% INFO    : Bus 1152	: V=0.992231, theta=1.048056 -> V=1.0, theta=0.0
% INFO    : Bus 1153	: V=1.031173, theta=-6.442651 -> V=1.0, theta=0.0
% INFO    : Bus 1154	: V=1.011472, theta=-24.564525 -> V=1.0, theta=0.0
% INFO    : Bus 1155	: V=1.036534, theta=-51.990549 -> V=1.0, theta=0.0
% INFO    : Bus 1156	: V=1.03401, theta=-22.848019 -> V=1.0, theta=0.0
% INFO    : Bus 1157	: V=1.031019, theta=13.742187 -> V=1.0, theta=0.0
% INFO    : Bus 1158	: V=0.995578, theta=-30.941271 -> V=1.0, theta=0.0
% INFO    : Bus 1159	: V=1.047767, theta=-36.539593 -> V=1.0, theta=0.0
% INFO    : Bus 1160	: V=1.0023, theta=-0.229629 -> V=1.0, theta=0.0
% INFO    : Bus 1161	: V=1.034371, theta=8.031714 -> V=1.0, theta=0.0
% INFO    : Bus 1162	: V=1.031404, theta=-21.894084 -> V=1.0, theta=0.0
% INFO    : Bus 1163	: V=0.991015, theta=-1.71751 -> V=1.0, theta=0.0
% INFO    : Bus 1164	: V=0.989655, theta=-30.821299 -> V=1.0, theta=0.0
% INFO    : Bus 1165	: V=1.0392, theta=17.393702 -> V=1.0, theta=0.0
% INFO    : Bus 1166	: V=1.031803, theta=-29.22026 -> V=1.0, theta=0.0
% INFO    : Bus 1167	: V=1.012986, theta=-32.963293 -> V=1.0, theta=0.0
% INFO    : Bus 1168	: V=1.040823, theta=-42.711663 -> V=1.0, theta=0.0
% INFO    : Bus 1169	: V=1.017798, theta=-22.591387 -> V=1.0, theta=0.0
% INFO    : Bus 1170	: V=0.991448, theta=-50.487819 -> V=1.0, theta=0.0
% INFO    : Bus 1171	: V=1.038903, theta=-25.783048 -> V=1.0, theta=0.0
% INFO    : Bus 1172	: V=1.068801, theta=-25.946983 -> V=1.0, theta=0.0
% INFO    : Bus 1173	: V=1.018544, theta=-41.818492 -> V=1.0, theta=0.0
% INFO    : Bus 1174	: V=1.002801, theta=-38.484166 -> V=1.0, theta=0.0
% INFO    : Bus 1175	: V=1.038334, theta=-39.844005 -> V=1.0, theta=0.0
% INFO    : Bus 1176	: V=1.016193, theta=-23.120961 -> V=1.0, theta=0.0
% INFO    : Bus 1177	: V=1.033879, theta=55.816196 -> V=1.0, theta=0.0
% INFO    : Bus 1178	: V=0.962008, theta=-33.719546 -> V=1.0, theta=0.0
% INFO    : Bus 1179	: V=1.030155, theta=-3.081468 -> V=1.0, theta=0.0
% INFO    : Bus 1180	: V=1.070081, theta=-31.060886 -> V=1.0, theta=0.0
% INFO    : Bus 1181	: V=1.02568, theta=-22.276087 -> V=1.0, theta=0.0
% INFO    : Bus 1182	: V=1.04827, theta=-25.28647 -> V=1.0, theta=0.0
% INFO    : Bus 1183	: V=1.061746, theta=-33.326648 -> V=1.0, theta=0.0
% INFO    : Bus 1184	: V=1.037371, theta=-8.714789 -> V=1.0, theta=0.0
% INFO    : Bus 1185	: V=1.00989, theta=-44.51992 -> V=1.0, theta=0.0
% INFO    : Bus 1186	: V=1.002628, theta=1.72414 -> V=1.0, theta=0.0
% INFO    : Bus 1187	: V=1.036168, theta=-5.245571 -> V=1.0, theta=0.0
% INFO    : Bus 1188	: V=1.057273, theta=-14.570559 -> V=1.0, theta=0.0
% INFO    : Bus 1189	: V=1.030652, theta=38.417935 -> V=1.0, theta=0.0
% INFO    : Bus 1190	: V=0.997527, theta=-20.480441 -> V=1.0, theta=0.0
% INFO    : Bus 1191	: V=1.002819, theta=-10.814831 -> V=1.0, theta=0.0
% INFO    : Bus 1192	: V=0.991994, theta=-25.39883 -> V=1.0, theta=0.0
% INFO    : Bus 1193	: V=1.045756, theta=-16.022 -> V=1.0, theta=0.0
% INFO    : Bus 1194	: V=1.035804, theta=-15.379297 -> V=1.0, theta=0.0
% INFO    : Bus 1195	: V=0.999088, theta=-19.554899 -> V=1.0, theta=0.0
% INFO    : Bus 1196	: V=1.039052, theta=-27.709316 -> V=1.0, theta=0.0
% INFO    : Bus 1197	: V=0.983134, theta=-28.838212 -> V=1.0, theta=0.0
% INFO    : Bus 1198	: V=0.994534, theta=-14.439072 -> V=1.0, theta=0.0
% INFO    : Bus 1199	: V=1.056094, theta=-20.556173 -> V=1.0, theta=0.0
% INFO    : Bus 1200	: V=1.024898, theta=-41.828092 -> V=1.0, theta=0.0
% INFO    : Bus 1201	: V=1.039435, theta=-20.087821 -> V=1.0, theta=0.0
% INFO    : Bus 1202	: V=1.130115, theta=-23.379521 -> V=1.0, theta=0.0
% INFO    : Bus 1203	: V=1.022216, theta=-7.938516 -> V=1.0, theta=0.0
% INFO    : Bus 1204	: V=1.055433, theta=-27.399177 -> V=1.0, theta=0.0
% INFO    : Bus 1205	: V=1.02364, theta=2.132033 -> V=1.0, theta=0.0
% INFO    : Bus 1206	: V=0.95719, theta=-29.999812 -> V=1.0, theta=0.0
% INFO    : Bus 1207	: V=1.018095, theta=-0.737711 -> V=1.0, theta=0.0
% INFO    : Bus 1208	: V=1.023218, theta=-7.257963 -> V=1.0, theta=0.0
% INFO    : Bus 1209	: V=1.009976, theta=-49.306917 -> V=1.0, theta=0.0
% INFO    : Bus 1210	: V=1.009864, theta=-26.733179 -> V=1.0, theta=0.0
% INFO    : Bus 1211	: V=1.08863, theta=-12.305489 -> V=1.0, theta=0.0
% INFO    : Bus 1212	: V=1.157605, theta=-23.088872 -> V=1.0, theta=0.0
% INFO    : Bus 1213	: V=1.020277, theta=-6.570021 -> V=1.0, theta=0.0
% INFO    : Bus 1214	: V=1.019583, theta=18.757001 -> V=1.0, theta=0.0
% INFO    : Bus 1215	: V=1.030983, theta=-22.83689 -> V=1.0, theta=0.0
% INFO    : Bus 1216	: V=1.036556, theta=-11.314369 -> V=1.0, theta=0.0
% INFO    : Bus 1217	: V=1.025557, theta=-24.888109 -> V=1.0, theta=0.0
% INFO    : Bus 1218	: V=0.983512, theta=-40.888328 -> V=1.0, theta=0.0
% INFO    : Bus 1219	: V=1.003651, theta=-37.515353 -> V=1.0, theta=0.0
% INFO    : Bus 1220	: V=1.008655, theta=-45.569202 -> V=1.0, theta=0.0
% INFO    : Bus 1221	: V=1.026404, theta=-1.946494 -> V=1.0, theta=0.0
% INFO    : Bus 1222	: V=1.023094, theta=-32.476655 -> V=1.0, theta=0.0
% INFO    : Bus 1223	: V=1.023062, theta=-9.030036 -> V=1.0, theta=0.0
% INFO    : Bus 1224	: V=1.025025, theta=-35.945148 -> V=1.0, theta=0.0
% INFO    : Bus 1225	: V=1.051668, theta=-17.803045 -> V=1.0, theta=0.0
% INFO    : Bus 1226	: V=1.089904, theta=-27.716794 -> V=1.0, theta=0.0
% INFO    : Bus 1227	: V=1.021578, theta=10.573494 -> V=1.0, theta=0.0
% INFO    : Bus 1228	: V=1.013857, theta=-32.136875 -> V=1.0, theta=0.0
% INFO    : Bus 1229	: V=1.018322, theta=-28.501754 -> V=1.0, theta=0.0
% INFO    : Bus 1230	: V=1.035275, theta=-25.036832 -> V=1.0, theta=0.0
% INFO    : Bus 1231	: V=0.997535, theta=-29.534575 -> V=1.0, theta=0.0
% INFO    : Bus 1232	: V=1.045457, theta=-50.275568 -> V=1.0, theta=0.0
% INFO    : Bus 1233	: V=1.033936, theta=-22.873061 -> V=1.0, theta=0.0
% INFO    : Bus 1234	: V=1.019897, theta=-16.703598 -> V=1.0, theta=0.0
% INFO    : Bus 1235	: V=1.028466, theta=-5.275021 -> V=1.0, theta=0.0
% INFO    : Bus 1236	: V=1.013549, theta=-36.608631 -> V=1.0, theta=0.0
% INFO    : Bus 1237	: V=1.103909, theta=-6.473548 -> V=1.0, theta=0.0
% INFO    : Bus 1238	: V=1.02547, theta=56.988426 -> V=1.0, theta=0.0
% INFO    : Bus 1239	: V=0.995239, theta=-55.63816 -> V=1.0, theta=0.0
% INFO    : Bus 1240	: V=1.019502, theta=-41.971456 -> V=1.0, theta=0.0
% INFO    : Bus 1241	: V=1.019582, theta=-38.531665 -> V=1.0, theta=0.0
% INFO    : Bus 1242	: V=1.0386, theta=-3.405307 -> V=1.0, theta=0.0
% INFO    : Bus 1243	: V=1.080005, theta=57.148478 -> V=1.0, theta=0.0
% INFO    : Bus 1244	: V=1.026736, theta=-16.807919 -> V=1.0, theta=0.0
% INFO    : Bus 1245	: V=1.018361, theta=-26.287159 -> V=1.0, theta=0.0
% INFO    : Bus 1246	: V=1.020056, theta=-29.074246 -> V=1.0, theta=0.0
% INFO    : Bus 1247	: V=1.031845, theta=-25.386197 -> V=1.0, theta=0.0
% INFO    : Bus 1248	: V=1.045602, theta=-10.875135 -> V=1.0, theta=0.0
% INFO    : Bus 1249	: V=1.020424, theta=-11.314118 -> V=1.0, theta=0.0
% INFO    : Bus 1250	: V=0.99043, theta=-35.622409 -> V=1.0, theta=0.0
% INFO    : Bus 1251	: V=1.024626, theta=-8.729171 -> V=1.0, theta=0.0
% INFO    : Bus 1252	: V=1.031473, theta=-33.940798 -> V=1.0, theta=0.0
% INFO    : Bus 1253	: V=1.011465, theta=22.066796 -> V=1.0, theta=0.0
% INFO    : Bus 1254	: V=0.989117, theta=-29.091224 -> V=1.0, theta=0.0
% INFO    : Bus 1255	: V=1.022343, theta=3.87531 -> V=1.0, theta=0.0
% INFO    : Bus 1256	: V=1.011916, theta=-19.513814 -> V=1.0, theta=0.0
% INFO    : Bus 1257	: V=1.031007, theta=-38.451986 -> V=1.0, theta=0.0
% INFO    : Bus 1258	: V=1.032962, theta=38.774006 -> V=1.0, theta=0.0
% INFO    : Bus 1259	: V=1.127902, theta=-23.797785 -> V=1.0, theta=0.0
% INFO    : Bus 1260	: V=1.008042, theta=15.734617 -> V=1.0, theta=0.0
% INFO    : Bus 1261	: V=1.020831, theta=-42.985197 -> V=1.0, theta=0.0
% INFO    : Bus 1262	: V=1.034553, theta=-22.377589 -> V=1.0, theta=0.0
% INFO    : Bus 1263	: V=1.002702, theta=-10.318584 -> V=1.0, theta=0.0
% INFO    : Bus 1264	: V=1.029039, theta=-32.320569 -> V=1.0, theta=0.0
% INFO    : Bus 1265	: V=1.063, theta=-50.383849 -> V=1.0, theta=0.0
% INFO    : Bus 1266	: V=0.998744, theta=-41.577791 -> V=1.0, theta=0.0
% INFO    : Bus 1267	: V=1.04637, theta=20.205348 -> V=1.0, theta=0.0
% INFO    : Bus 1268	: V=1.005562, theta=-3.438926 -> V=1.0, theta=0.0
% INFO    : Bus 1269	: V=1.012761, theta=-36.678237 -> V=1.0, theta=0.0
% INFO    : Bus 1270	: V=1.032879, theta=-24.788382 -> V=1.0, theta=0.0
% INFO    : Bus 1271	: V=1.0139, theta=-46.721298 -> V=1.0, theta=0.0
% INFO    : Bus 1272	: V=1.016359, theta=-30.703637 -> V=1.0, theta=0.0
% INFO    : Bus 1273	: V=1.014097, theta=-35.942112 -> V=1.0, theta=0.0
% INFO    : Bus 1274	: V=0.966937, theta=-22.699804 -> V=1.0, theta=0.0
% INFO    : Bus 1275	: V=1.03039, theta=-19.090541 -> V=1.0, theta=0.0
% INFO    : Bus 1276	: V=0.986046, theta=-28.634033 -> V=1.0, theta=0.0
% INFO    : Bus 1277	: V=1.028701, theta=-1.858875 -> V=1.0, theta=0.0
% INFO    : Bus 1278	: V=1.043988, theta=-16.189968 -> V=1.0, theta=0.0
% INFO    : Bus 1279	: V=0.997512, theta=-49.997395 -> V=1.0, theta=0.0
% INFO    : Bus 1280	: V=1.07141, theta=-37.162106 -> V=1.0, theta=0.0
% INFO    : Bus 1281	: V=0.969655, theta=-24.039484 -> V=1.0, theta=0.0
% INFO    : Bus 1282	: V=1.019897, theta=-47.387129 -> V=1.0, theta=0.0
% INFO    : Bus 1283	: V=1.052742, theta=-25.899364 -> V=1.0, theta=0.0
% INFO    : Bus 1284	: V=0.994045, theta=-26.972979 -> V=1.0, theta=0.0
% INFO    : Bus 1285	: V=1.052292, theta=-15.194946 -> V=1.0, theta=0.0
% INFO    : Bus 1286	: V=0.963744, theta=-29.059591 -> V=1.0, theta=0.0
% INFO    : Bus 1287	: V=1.052037, theta=15.399435 -> V=1.0, theta=0.0
% INFO    : Bus 1288	: V=1.009022, theta=-33.106438 -> V=1.0, theta=0.0
% INFO    : Bus 1289	: V=0.959518, theta=-35.091886 -> V=1.0, theta=0.0
% INFO    : Bus 1290	: V=1.00796, theta=-36.438787 -> V=1.0, theta=0.0
% INFO    : Bus 1291	: V=1.021764, theta=-12.699538 -> V=1.0, theta=0.0
% INFO    : Bus 1292	: V=1.020624, theta=-5.696232 -> V=1.0, theta=0.0
% INFO    : Bus 1293	: V=1.017813, theta=7.842015 -> V=1.0, theta=0.0
% INFO    : Bus 1294	: V=1.007318, theta=-48.846534 -> V=1.0, theta=0.0
% INFO    : Bus 1295	: V=1.035594, theta=-8.717281 -> V=1.0, theta=0.0
% INFO    : Bus 1296	: V=1.015257, theta=-30.22365 -> V=1.0, theta=0.0
% INFO    : Bus 1297	: V=1.007222, theta=-26.340503 -> V=1.0, theta=0.0
% INFO    : Bus 1298	: V=0.981434, theta=-23.900611 -> V=1.0, theta=0.0
% INFO    : Bus 1299	: V=0.977286, theta=-33.204156 -> V=1.0, theta=0.0
% INFO    : Bus 1300	: V=0.91444, theta=-35.99744 -> V=1.0, theta=0.0
% INFO    : Bus 1301	: V=1.048311, theta=-29.017601 -> V=1.0, theta=0.0
% INFO    : Bus 1302	: V=1.012848, theta=-24.260593 -> V=1.0, theta=0.0
% INFO    : Bus 1303	: V=1.02404, theta=-14.144099 -> V=1.0, theta=0.0
% INFO    : Bus 1304	: V=1.01767, theta=-35.316915 -> V=1.0, theta=0.0
% INFO    : Bus 1305	: V=1.038105, theta=-22.77658 -> V=1.0, theta=0.0
% INFO    : Bus 1306	: V=0.969711, theta=-29.75829 -> V=1.0, theta=0.0
% INFO    : Bus 1307	: V=1.062062, theta=-10.130363 -> V=1.0, theta=0.0
% INFO    : Bus 1308	: V=1.000909, theta=-33.917468 -> V=1.0, theta=0.0
% INFO    : Bus 1309	: V=0.960873, theta=-27.498074 -> V=1.0, theta=0.0
% INFO    : Bus 1310	: V=0.934082, theta=-34.726012 -> V=1.0, theta=0.0
% INFO    : Bus 1311	: V=1.03134, theta=-21.905259 -> V=1.0, theta=0.0
% INFO    : Bus 1312	: V=1.030628, theta=-11.136572 -> V=1.0, theta=0.0
% INFO    : Bus 1313	: V=1.031257, theta=-39.135224 -> V=1.0, theta=0.0
% INFO    : Bus 1314	: V=1.043789, theta=-20.817719 -> V=1.0, theta=0.0
% INFO    : Bus 1315	: V=1.091975, theta=11.599735 -> V=1.0, theta=0.0
% INFO    : Bus 1316	: V=0.976277, theta=-29.618371 -> V=1.0, theta=0.0
% INFO    : Bus 1317	: V=1.010954, theta=2.893831 -> V=1.0, theta=0.0
% INFO    : Bus 1318	: V=0.986341, theta=14.700503 -> V=1.0, theta=0.0
% INFO    : Bus 1319	: V=1.047415, theta=-29.296022 -> V=1.0, theta=0.0
% INFO    : Bus 1320	: V=1.01339, theta=-48.941694 -> V=1.0, theta=0.0
% INFO    : Bus 1321	: V=1.0176, theta=-20.137212 -> V=1.0, theta=0.0
% INFO    : Bus 1322	: V=0.977041, theta=-35.24252 -> V=1.0, theta=0.0
% INFO    : Bus 1323	: V=1.018452, theta=2.80416 -> V=1.0, theta=0.0
% INFO    : Bus 1324	: V=1.029565, theta=-25.266254 -> V=1.0, theta=0.0
% INFO    : Bus 1325	: V=1.031959, theta=-26.292195 -> V=1.0, theta=0.0
% INFO    : Bus 1326	: V=1.065109, theta=-35.279844 -> V=1.0, theta=0.0
% INFO    : Bus 1327	: V=1.015199, theta=-36.525423 -> V=1.0, theta=0.0
% INFO    : Bus 1328	: V=1.031228, theta=-38.438089 -> V=1.0, theta=0.0
% INFO    : Bus 1329	: V=1.019261, theta=2.862212 -> V=1.0, theta=0.0
% INFO    : Bus 1330	: V=0.998944, theta=-2.086057 -> V=1.0, theta=0.0
% INFO    : Bus 1331	: V=1.048144, theta=18.207633 -> V=1.0, theta=0.0
% INFO    : Bus 1332	: V=1.050721, theta=-24.766219 -> V=1.0, theta=0.0
% INFO    : Bus 1333	: V=1.00264, theta=-33.181209 -> V=1.0, theta=0.0
% INFO    : Bus 1334	: V=1.022554, theta=-16.489068 -> V=1.0, theta=0.0
% INFO    : Bus 1335	: V=1.085035, theta=-23.705838 -> V=1.0, theta=0.0
% INFO    : Bus 1336	: V=1.022258, theta=-6.988685 -> V=1.0, theta=0.0
% INFO    : Bus 1337	: V=1.05919, theta=-17.318411 -> V=1.0, theta=0.0
% INFO    : Bus 1338	: V=1.056547, theta=10.591015 -> V=1.0, theta=0.0
% INFO    : Bus 1339	: V=1.050471, theta=-46.710084 -> V=1.0, theta=0.0
% INFO    : Bus 1340	: V=0.991895, theta=-42.420238 -> V=1.0, theta=0.0
% INFO    : Bus 1341	: V=1.035237, theta=-14.263308 -> V=1.0, theta=0.0
% INFO    : Bus 1342	: V=1.039269, theta=-0.842292 -> V=1.0, theta=0.0
% INFO    : Bus 1343	: V=1.001607, theta=-14.057721 -> V=1.0, theta=0.0
% INFO    : Bus 1344	: V=1.021828, theta=-46.679878 -> V=1.0, theta=0.0
% INFO    : Bus 1345	: V=1.015627, theta=61.512423 -> V=1.0, theta=0.0
% INFO    : Bus 1346	: V=1.025101, theta=-22.268256 -> V=1.0, theta=0.0
% INFO    : Bus 1347	: V=1.021862, theta=-53.734293 -> V=1.0, theta=0.0
% INFO    : Bus 1348	: V=1.01292, theta=-5.059564 -> V=1.0, theta=0.0
% INFO    : Bus 1349	: V=1.024668, theta=5.632836 -> V=1.0, theta=0.0
% INFO    : Bus 1350	: V=1.026189, theta=-1.244991 -> V=1.0, theta=0.0
% INFO    : Bus 1351	: V=0.964633, theta=-17.068916 -> V=1.0, theta=0.0
% INFO    : Bus 1352	: V=1.031938, theta=-1.392462 -> V=1.0, theta=0.0
% INFO    : Bus 1353	: V=1.022221, theta=-22.0039 -> V=1.0, theta=0.0
% INFO    : Bus 1354	: V=1.034497, theta=-7.597033 -> V=1.0, theta=0.0
% INFO    : Bus 1355	: V=1.029327, theta=-8.7153 -> V=1.0, theta=0.0
% INFO    : Bus 1356	: V=1.018699, theta=-41.899667 -> V=1.0, theta=0.0
% INFO    : Bus 1357	: V=1.016995, theta=3.722869 -> V=1.0, theta=0.0
% INFO    : Bus 1358	: V=0.9993, theta=-35.047873 -> V=1.0, theta=0.0
% INFO    : Bus 1359	: V=1.020143, theta=-5.293872 -> V=1.0, theta=0.0
% INFO    : Bus 1360	: V=1.076714, theta=-23.212938 -> V=1.0, theta=0.0
% INFO    : Bus 1361	: V=1.001499, theta=-25.274364 -> V=1.0, theta=0.0
% INFO    : Bus 1362	: V=1.03998, theta=25.637281 -> V=1.0, theta=0.0
% INFO    : Bus 1363	: V=1.008673, theta=-20.061722 -> V=1.0, theta=0.0
% INFO    : Bus 1364	: V=1.038263, theta=-12.28852 -> V=1.0, theta=0.0
% INFO    : Bus 1365	: V=1.045092, theta=-39.45932 -> V=1.0, theta=0.0
% INFO    : Bus 1366	: V=1.028168, theta=-40.869549 -> V=1.0, theta=0.0
% INFO    : Bus 1367	: V=1.005561, theta=-0.569839 -> V=1.0, theta=0.0
% INFO    : Bus 1368	: V=1.00266, theta=-30.532747 -> V=1.0, theta=0.0
% INFO    : Bus 1369	: V=1.033686, theta=-25.315586 -> V=1.0, theta=0.0
% INFO    : Bus 1370	: V=1.020241, theta=-29.747583 -> V=1.0, theta=0.0
% INFO    : Bus 1371	: V=1.02639, theta=0.926583 -> V=1.0, theta=0.0
% INFO    : Bus 1372	: V=0.95916, theta=-33.882239 -> V=1.0, theta=0.0
% INFO    : Bus 1373	: V=0.993927, theta=-32.619243 -> V=1.0, theta=0.0
% INFO    : Bus 1374	: V=0.997482, theta=-29.519121 -> V=1.0, theta=0.0
% INFO    : Bus 1375	: V=0.955338, theta=-31.250238 -> V=1.0, theta=0.0
% INFO    : Bus 1376	: V=0.993711, theta=-33.877317 -> V=1.0, theta=0.0
% INFO    : Bus 1377	: V=0.99069, theta=-31.192636 -> V=1.0, theta=0.0
% INFO    : Bus 1378	: V=1.015715, theta=1.870619 -> V=1.0, theta=0.0
% INFO    : Bus 1379	: V=1.025837, theta=-29.429882 -> V=1.0, theta=0.0
% INFO    : Bus 1380	: V=1.022758, theta=-23.095174 -> V=1.0, theta=0.0
% INFO    : Bus 1381	: V=1.001682, theta=1.388839 -> V=1.0, theta=0.0
% INFO    : Bus 1382	: V=1.010507, theta=-35.86105 -> V=1.0, theta=0.0
% INFO    : Bus 1383	: V=1.045942, theta=-20.988282 -> V=1.0, theta=0.0
% INFO    : Bus 1384	: V=1.109629, theta=-21.96249 -> V=1.0, theta=0.0
% INFO    : Bus 1385	: V=1.019767, theta=61.573327 -> V=1.0, theta=0.0
% INFO    : Bus 1386	: V=0.990763, theta=-30.757298 -> V=1.0, theta=0.0
% INFO    : Bus 1387	: V=1.029614, theta=-0.841353 -> V=1.0, theta=0.0
% INFO    : Bus 1388	: V=1.019538, theta=-34.270193 -> V=1.0, theta=0.0
% INFO    : Bus 1389	: V=1.0032, theta=-36.682256 -> V=1.0, theta=0.0
% INFO    : Bus 1390	: V=1.076512, theta=-19.376155 -> V=1.0, theta=0.0
% INFO    : Bus 1391	: V=1.027192, theta=-37.784565 -> V=1.0, theta=0.0
% INFO    : Bus 1392	: V=1.025265, theta=17.7628 -> V=1.0, theta=0.0
% INFO    : Bus 1393	: V=1.021752, theta=-46.013798 -> V=1.0, theta=0.0
% INFO    : Bus 1394	: V=1.068933, theta=-26.711668 -> V=1.0, theta=0.0
% INFO    : Bus 1395	: V=1.053899, theta=-32.549685 -> V=1.0, theta=0.0
% INFO    : Bus 1396	: V=1.027929, theta=-30.435624 -> V=1.0, theta=0.0
% INFO    : Bus 1397	: V=1.044833, theta=-13.244455 -> V=1.0, theta=0.0
% INFO    : Bus 1398	: V=1.014695, theta=-19.132196 -> V=1.0, theta=0.0
% INFO    : Bus 1399	: V=1.04788, theta=-49.397615 -> V=1.0, theta=0.0
% INFO    : Bus 1400	: V=1.021319, theta=2.297921 -> V=1.0, theta=0.0
% INFO    : Bus 1401	: V=1.036953, theta=-14.926159 -> V=1.0, theta=0.0
% INFO    : Bus 1402	: V=1.019959, theta=-20.19317 -> V=1.0, theta=0.0
% INFO    : Bus 1403	: V=1.062912, theta=54.514608 -> V=1.0, theta=0.0
% INFO    : Bus 1404	: V=1.022946, theta=4.97524 -> V=1.0, theta=0.0
% INFO    : Bus 1405	: V=0.989062, theta=-25.178694 -> V=1.0, theta=0.0
% INFO    : Bus 1406	: V=1.018175, theta=-24.811382 -> V=1.0, theta=0.0
% INFO    : Bus 1407	: V=0.991705, theta=-49.889604 -> V=1.0, theta=0.0
% INFO    : Bus 1408	: V=1.00208, theta=-32.664202 -> V=1.0, theta=0.0
% INFO    : Bus 1409	: V=1.022303, theta=-48.78594 -> V=1.0, theta=0.0
% INFO    : Bus 1410	: V=0.973115, theta=-32.084772 -> V=1.0, theta=0.0
% INFO    : Bus 1411	: V=1.007407, theta=-48.005426 -> V=1.0, theta=0.0
% INFO    : Bus 1412	: V=1.005546, theta=-26.152557 -> V=1.0, theta=0.0
% INFO    : Bus 1413	: V=0.992915, theta=-27.541743 -> V=1.0, theta=0.0
% INFO    : Bus 1414	: V=1.01828, theta=-28.289267 -> V=1.0, theta=0.0
% INFO    : Bus 1415	: V=1.029195, theta=-11.729083 -> V=1.0, theta=0.0
% INFO    : Bus 1416	: V=1.020594, theta=-23.616181 -> V=1.0, theta=0.0
% INFO    : Bus 1417	: V=1.009035, theta=-13.438457 -> V=1.0, theta=0.0
% INFO    : Bus 1418	: V=1.015411, theta=-55.166319 -> V=1.0, theta=0.0
% INFO    : Bus 1419	: V=1.010045, theta=-44.226167 -> V=1.0, theta=0.0
% INFO    : Bus 1420	: V=1.001444, theta=-17.527123 -> V=1.0, theta=0.0
% INFO    : Bus 1421	: V=1.016209, theta=-52.437506 -> V=1.0, theta=0.0
% INFO    : Bus 1422	: V=1.047835, theta=-21.372401 -> V=1.0, theta=0.0
% INFO    : Bus 1423	: V=1.01922, theta=-35.759714 -> V=1.0, theta=0.0
% INFO    : Bus 1424	: V=1.013545, theta=-23.28693 -> V=1.0, theta=0.0
% INFO    : Bus 1425	: V=1.042357, theta=-8.099866 -> V=1.0, theta=0.0
% INFO    : Bus 1426	: V=1.072946, theta=26.386805 -> V=1.0, theta=0.0
% INFO    : Bus 1427	: V=0.989682, theta=-31.598298 -> V=1.0, theta=0.0
% INFO    : Bus 1428	: V=1.006042, theta=-36.807516 -> V=1.0, theta=0.0
% INFO    : Bus 1429	: V=1.062953, theta=-35.924835 -> V=1.0, theta=0.0
% INFO    : Bus 1430	: V=1.009939, theta=-51.103497 -> V=1.0, theta=0.0
% INFO    : Bus 1431	: V=0.973207, theta=-32.072306 -> V=1.0, theta=0.0
% INFO    : Bus 1432	: V=1.016823, theta=-9.538924 -> V=1.0, theta=0.0
% INFO    : Bus 1433	: V=1.01442, theta=-7.183674 -> V=1.0, theta=0.0
% INFO    : Bus 1434	: V=1.06933, theta=-22.158284 -> V=1.0, theta=0.0
% INFO    : Bus 1435	: V=1.039832, theta=-24.69425 -> V=1.0, theta=0.0
% INFO    : Bus 1436	: V=1.054052, theta=-13.334937 -> V=1.0, theta=0.0
% INFO    : Bus 1437	: V=0.987496, theta=-38.559416 -> V=1.0, theta=0.0
% INFO    : Bus 1438	: V=1.035796, theta=-21.856758 -> V=1.0, theta=0.0
% INFO    : Bus 1439	: V=1.022676, theta=-48.766148 -> V=1.0, theta=0.0
% INFO    : Bus 1440	: V=1.011268, theta=-4.465895 -> V=1.0, theta=0.0
% INFO    : Bus 1441	: V=0.986338, theta=-31.835513 -> V=1.0, theta=0.0
% INFO    : Bus 1442	: V=1.01826, theta=-6.508131 -> V=1.0, theta=0.0
% INFO    : Bus 1443	: V=1.032827, theta=-7.541273 -> V=1.0, theta=0.0
% INFO    : Bus 1444	: V=1.023146, theta=-8.694857 -> V=1.0, theta=0.0
% INFO    : Bus 1445	: V=1.000392, theta=-0.646604 -> V=1.0, theta=0.0
% INFO    : Bus 1446	: V=0.929681, theta=-34.552406 -> V=1.0, theta=0.0
% INFO    : Bus 1447	: V=1.033304, theta=-20.116521 -> V=1.0, theta=0.0
% INFO    : Bus 1448	: V=1.069974, theta=-15.594879 -> V=1.0, theta=0.0
% INFO    : Bus 1449	: V=1.023427, theta=-32.472976 -> V=1.0, theta=0.0
% INFO    : Bus 1450	: V=1.047849, theta=-23.198799 -> V=1.0, theta=0.0
% INFO    : Bus 1451	: V=1.032216, theta=-34.275921 -> V=1.0, theta=0.0
% INFO    : Bus 1452	: V=1.021465, theta=3.898083 -> V=1.0, theta=0.0
% INFO    : Bus 1453	: V=1.01588, theta=-36.12599 -> V=1.0, theta=0.0
% INFO    : Bus 1454	: V=1.050287, theta=-24.708967 -> V=1.0, theta=0.0
% INFO    : Bus 1455	: V=0.964588, theta=-31.478302 -> V=1.0, theta=0.0
% INFO    : Bus 1456	: V=0.998629, theta=-37.756444 -> V=1.0, theta=0.0
% INFO    : Bus 1457	: V=1.013965, theta=-39.959399 -> V=1.0, theta=0.0
% INFO    : Bus 1458	: V=1.045766, theta=-38.603093 -> V=1.0, theta=0.0
% INFO    : Bus 1459	: V=1.039481, theta=-22.115895 -> V=1.0, theta=0.0
% INFO    : Bus 1460	: V=1.010427, theta=-7.350669 -> V=1.0, theta=0.0
% INFO    : Bus 1461	: V=1.035843, theta=-39.417888 -> V=1.0, theta=0.0
% INFO    : Bus 1462	: V=1.047856, theta=-21.372911 -> V=1.0, theta=0.0
% INFO    : Bus 1463	: V=1.035408, theta=5.827943 -> V=1.0, theta=0.0
% INFO    : Bus 1464	: V=1.019811, theta=7.461504 -> V=1.0, theta=0.0
% INFO    : Bus 1465	: V=0.984287, theta=-15.629121 -> V=1.0, theta=0.0
% INFO    : Bus 1466	: V=1.084595, theta=-28.010738 -> V=1.0, theta=0.0
% INFO    : Bus 1467	: V=1.013679, theta=-32.975234 -> V=1.0, theta=0.0
% INFO    : Bus 1468	: V=1.00405, theta=-18.486305 -> V=1.0, theta=0.0
% INFO    : Bus 1469	: V=1.048685, theta=-33.084852 -> V=1.0, theta=0.0
% INFO    : Bus 1470	: V=1.000122, theta=-49.871341 -> V=1.0, theta=0.0
% INFO    : Bus 1471	: V=0.97509, theta=-49.690385 -> V=1.0, theta=0.0
% INFO    : Bus 1472	: V=0.997982, theta=-25.220001 -> V=1.0, theta=0.0
% INFO    : Bus 1473	: V=1.001303, theta=-29.93877 -> V=1.0, theta=0.0
% INFO    : Bus 1474	: V=1.010259, theta=-6.19747 -> V=1.0, theta=0.0
% INFO    : Bus 1475	: V=1.020467, theta=-43.69136 -> V=1.0, theta=0.0
% INFO    : Bus 1476	: V=0.858822, theta=-39.292558 -> V=1.0, theta=0.0
% INFO    : Bus 1477	: V=1.034469, theta=9.039884 -> V=1.0, theta=0.0
% INFO    : Bus 1478	: V=1.048923, theta=-15.833833 -> V=1.0, theta=0.0
% INFO    : Bus 1479	: V=1.02528, theta=-43.676962 -> V=1.0, theta=0.0
% INFO    : Bus 1480	: V=1.007945, theta=-46.699134 -> V=1.0, theta=0.0
% INFO    : Bus 1481	: V=1.040265, theta=1.809268 -> V=1.0, theta=0.0
% INFO    : Bus 1482	: V=1.02447, theta=-26.749332 -> V=1.0, theta=0.0
% INFO    : Bus 1483	: V=1.067484, theta=-27.680579 -> V=1.0, theta=0.0
% INFO    : Bus 1484	: V=1.027385, theta=50.204439 -> V=1.0, theta=0.0
% INFO    : Bus 1485	: V=1.010367, theta=-15.445846 -> V=1.0, theta=0.0
% INFO    : Bus 1486	: V=1.030936, theta=-23.69577 -> V=1.0, theta=0.0
% INFO    : Bus 1487	: V=1.055167, theta=-12.534271 -> V=1.0, theta=0.0
% INFO    : Bus 1488	: V=1.033835, theta=-39.750272 -> V=1.0, theta=0.0
% INFO    : Bus 1489	: V=1.024224, theta=-36.529588 -> V=1.0, theta=0.0
% INFO    : Bus 1490	: V=1.029241, theta=-22.185994 -> V=1.0, theta=0.0
% INFO    : Bus 1491	: V=1.020793, theta=-47.723054 -> V=1.0, theta=0.0
% INFO    : Bus 1492	: V=1.02928, theta=-5.798772 -> V=1.0, theta=0.0
% INFO    : Bus 1493	: V=1.010911, theta=-5.35042 -> V=1.0, theta=0.0
% INFO    : Bus 1494	: V=1.039428, theta=-11.596451 -> V=1.0, theta=0.0
% INFO    : Bus 1495	: V=1.023957, theta=-28.318674 -> V=1.0, theta=0.0
% INFO    : Bus 1496	: V=1.030854, theta=-34.139697 -> V=1.0, theta=0.0
% INFO    : Bus 1497	: V=0.990307, theta=29.776271 -> V=1.0, theta=0.0
% INFO    : Bus 1498	: V=1.073955, theta=-40.297354 -> V=1.0, theta=0.0
% INFO    : Bus 1499	: V=1.043221, theta=-20.703725 -> V=1.0, theta=0.0
% INFO    : Bus 1500	: V=1.044168, theta=-19.427331 -> V=1.0, theta=0.0
% INFO    : Bus 1501	: V=1.024669, theta=-54.354073 -> V=1.0, theta=0.0
% INFO    : Bus 1502	: V=1.024544, theta=-26.951039 -> V=1.0, theta=0.0
% INFO    : Bus 1503	: V=1.019373, theta=-44.17804 -> V=1.0, theta=0.0
% INFO    : Bus 1504	: V=1.019788, theta=-14.640739 -> V=1.0, theta=0.0
% INFO    : Bus 1505	: V=1.0029, theta=-27.795475 -> V=1.0, theta=0.0
% INFO    : Bus 1506	: V=1.079345, theta=-19.716256 -> V=1.0, theta=0.0
% INFO    : Bus 1507	: V=1.057885, theta=-2.186886 -> V=1.0, theta=0.0
% INFO    : Bus 1508	: V=1.062401, theta=-20.441537 -> V=1.0, theta=0.0
% INFO    : Bus 1509	: V=1.029556, theta=-25.986341 -> V=1.0, theta=0.0
% INFO    : Bus 1510	: V=1.023208, theta=-26.047466 -> V=1.0, theta=0.0
% INFO    : Bus 1511	: V=0.990901, theta=-26.21194 -> V=1.0, theta=0.0
% INFO    : Bus 1512	: V=1.028466, theta=-44.106028 -> V=1.0, theta=0.0
% INFO    : Bus 1513	: V=1.016487, theta=-40.160602 -> V=1.0, theta=0.0
% INFO    : Bus 1514	: V=1.004779, theta=-23.508252 -> V=1.0, theta=0.0
% INFO    : Bus 1515	: V=1.008712, theta=-1.107611 -> V=1.0, theta=0.0
% INFO    : Bus 1516	: V=1.037153, theta=-0.734936 -> V=1.0, theta=0.0
% INFO    : Bus 1517	: V=1.027855, theta=-25.555887 -> V=1.0, theta=0.0
% INFO    : Bus 1518	: V=0.997056, theta=-32.275189 -> V=1.0, theta=0.0
% INFO    : Bus 1519	: V=1.007092, theta=-26.93445 -> V=1.0, theta=0.0
% INFO    : Bus 1520	: V=1.002285, theta=-46.811043 -> V=1.0, theta=0.0
% INFO    : Bus 1521	: V=0.988659, theta=-30.981824 -> V=1.0, theta=0.0
% INFO    : Bus 1522	: V=1.017448, theta=21.68548 -> V=1.0, theta=0.0
% INFO    : Bus 1523	: V=0.969123, theta=-54.141921 -> V=1.0, theta=0.0
% INFO    : Bus 1524	: V=1.014749, theta=17.834529 -> V=1.0, theta=0.0
% INFO    : Bus 1525	: V=1.055481, theta=17.939827 -> V=1.0, theta=0.0
% INFO    : Bus 1526	: V=1.037506, theta=-12.250028 -> V=1.0, theta=0.0
% INFO    : Bus 1527	: V=1.011733, theta=-41.237748 -> V=1.0, theta=0.0
% INFO    : Bus 1528	: V=1.005085, theta=-30.239128 -> V=1.0, theta=0.0
% INFO    : Bus 1529	: V=1.01463, theta=-7.159648 -> V=1.0, theta=0.0
% INFO    : Bus 1530	: V=1.021998, theta=-28.21235 -> V=1.0, theta=0.0
% INFO    : Bus 1531	: V=1.008004, theta=-11.969038 -> V=1.0, theta=0.0
% INFO    : Bus 1532	: V=0.994007, theta=-19.269916 -> V=1.0, theta=0.0
% INFO    : Bus 1533	: V=1.077949, theta=-24.835265 -> V=1.0, theta=0.0
% INFO    : Bus 1534	: V=1.096164, theta=-25.47435 -> V=1.0, theta=0.0
% INFO    : Bus 1535	: V=0.968445, theta=-29.191236 -> V=1.0, theta=0.0
% INFO    : Bus 1536	: V=1.002229, theta=-18.476273 -> V=1.0, theta=0.0
% INFO    : Bus 1537	: V=0.973184, theta=-34.115427 -> V=1.0, theta=0.0
% INFO    : Bus 1538	: V=1.031337, theta=-8.832961 -> V=1.0, theta=0.0
% INFO    : Bus 1539	: V=1.058457, theta=-15.584872 -> V=1.0, theta=0.0
% INFO    : Bus 1540	: V=1.078257, theta=-16.229346 -> V=1.0, theta=0.0
% INFO    : Bus 1541	: V=1.088981, theta=-24.30323 -> V=1.0, theta=0.0
% INFO    : Bus 1542	: V=1.056958, theta=-35.340331 -> V=1.0, theta=0.0
% INFO    : Bus 1543	: V=0.989265, theta=-49.989138 -> V=1.0, theta=0.0
% INFO    : Bus 1544	: V=1.136307, theta=-25.930375 -> V=1.0, theta=0.0
% INFO    : Bus 1545	: V=1.037202, theta=-23.828385 -> V=1.0, theta=0.0
% INFO    : Bus 1546	: V=1.042059, theta=-40.600898 -> V=1.0, theta=0.0
% INFO    : Bus 1547	: V=1.04322, theta=-15.091566 -> V=1.0, theta=0.0
% INFO    : Bus 1548	: V=0.984792, theta=-17.582107 -> V=1.0, theta=0.0
% INFO    : Bus 1549	: V=1.015193, theta=-53.632592 -> V=1.0, theta=0.0
% INFO    : Bus 1550	: V=1.082656, theta=-13.662784 -> V=1.0, theta=0.0
% INFO    : Bus 1551	: V=1.038512, theta=-20.752173 -> V=1.0, theta=0.0
% INFO    : Bus 1552	: V=1.039612, theta=-16.879714 -> V=1.0, theta=0.0
% INFO    : Bus 1553	: V=1.04217, theta=-18.228454 -> V=1.0, theta=0.0
% INFO    : Bus 1554	: V=1.01543, theta=-16.393806 -> V=1.0, theta=0.0
% INFO    : Bus 1555	: V=1.065019, theta=-8.997774 -> V=1.0, theta=0.0
% INFO    : Bus 1556	: V=1.065387, theta=-11.818883 -> V=1.0, theta=0.0
% INFO    : Bus 1557	: V=1.039811, theta=-17.614282 -> V=1.0, theta=0.0
% INFO    : Bus 1558	: V=1.01534, theta=-6.08835 -> V=1.0, theta=0.0
% INFO    : Bus 1559	: V=1.016899, theta=7.153568 -> V=1.0, theta=0.0
% INFO    : Bus 1560	: V=1.043962, theta=-20.817307 -> V=1.0, theta=0.0
% INFO    : Bus 1561	: V=1.021846, theta=-40.493768 -> V=1.0, theta=0.0
% INFO    : Bus 1562	: V=1.03782, theta=-26.193252 -> V=1.0, theta=0.0
% INFO    : Bus 1563	: V=1.043985, theta=-17.54442 -> V=1.0, theta=0.0
% INFO    : Bus 1564	: V=1.017601, theta=7.024488 -> V=1.0, theta=0.0
% INFO    : Bus 1565	: V=1.030949, theta=1.556549 -> V=1.0, theta=0.0
% INFO    : Bus 1566	: V=1.03118, theta=-25.125175 -> V=1.0, theta=0.0
% INFO    : Bus 1567	: V=1.037796, theta=-25.98792 -> V=1.0, theta=0.0
% INFO    : Bus 1568	: V=1.04247, theta=-25.487545 -> V=1.0, theta=0.0
% INFO    : Bus 1569	: V=1.020459, theta=-32.098619 -> V=1.0, theta=0.0
% INFO    : Bus 1570	: V=1.076277, theta=-35.646842 -> V=1.0, theta=0.0
% INFO    : Bus 1571	: V=1.048068, theta=-30.588257 -> V=1.0, theta=0.0
% INFO    : Bus 1572	: V=1.034403, theta=-30.610144 -> V=1.0, theta=0.0
% INFO    : Bus 1573	: V=1.024026, theta=12.428625 -> V=1.0, theta=0.0
% INFO    : Bus 1574	: V=1.008241, theta=-41.563979 -> V=1.0, theta=0.0
% INFO    : Bus 1575	: V=0.999328, theta=-33.899863 -> V=1.0, theta=0.0
% INFO    : Bus 1576	: V=1.061908, theta=11.541998 -> V=1.0, theta=0.0
% INFO    : Bus 1577	: V=1.053931, theta=-22.761984 -> V=1.0, theta=0.0
% INFO    : Bus 1578	: V=1.034689, theta=-12.335494 -> V=1.0, theta=0.0
% INFO    : Bus 1579	: V=1.006977, theta=-5.494028 -> V=1.0, theta=0.0
% INFO    : Bus 1580	: V=1.01471, theta=-22.608554 -> V=1.0, theta=0.0
% INFO    : Bus 1581	: V=1.019111, theta=-14.760439 -> V=1.0, theta=0.0
% INFO    : Bus 1582	: V=1.042602, theta=66.589497 -> V=1.0, theta=0.0
% INFO    : Bus 1583	: V=1.007978, theta=-23.85957 -> V=1.0, theta=0.0
% INFO    : Bus 1584	: V=1.035277, theta=-14.661089 -> V=1.0, theta=0.0
% INFO    : Bus 1585	: V=1.040379, theta=-8.600339 -> V=1.0, theta=0.0
% INFO    : Bus 1586	: V=1.025666, theta=-32.943705 -> V=1.0, theta=0.0
% INFO    : Bus 1587	: V=1.013425, theta=55.443139 -> V=1.0, theta=0.0
% INFO    : Bus 1588	: V=1.040313, theta=-8.413966 -> V=1.0, theta=0.0
% INFO    : Bus 1589	: V=1.023343, theta=-7.228521 -> V=1.0, theta=0.0
% INFO    : Bus 1590	: V=1.067508, theta=-19.594255 -> V=1.0, theta=0.0
% INFO    : Bus 1591	: V=1.016882, theta=16.592812 -> V=1.0, theta=0.0
% INFO    : Bus 1592	: V=1.033424, theta=-2.728211 -> V=1.0, theta=0.0
% INFO    : Bus 1593	: V=1.07124, theta=59.977227 -> V=1.0, theta=0.0
% INFO    : Bus 1594	: V=1.005975, theta=-10.923264 -> V=1.0, theta=0.0
% INFO    : Bus 1595	: V=1.011389, theta=-29.689157 -> V=1.0, theta=0.0
% INFO    : Bus 1596	: V=1.048407, theta=40.876809 -> V=1.0, theta=0.0
% INFO    : Bus 1597	: V=1.019934, theta=13.471194 -> V=1.0, theta=0.0
% INFO    : Bus 1598	: V=0.945608, theta=-29.541812 -> V=1.0, theta=0.0
% INFO    : Bus 1599	: V=1.008649, theta=-48.901836 -> V=1.0, theta=0.0
% INFO    : Bus 1600	: V=1.025641, theta=-54.321174 -> V=1.0, theta=0.0
% INFO    : Bus 1601	: V=1.065707, theta=25.831984 -> V=1.0, theta=0.0
% INFO    : Bus 1602	: V=1.009154, theta=-60.6735 -> V=1.0, theta=0.0
% INFO    : Bus 1603	: V=1.018692, theta=-25.570995 -> V=1.0, theta=0.0
% INFO    : Bus 1604	: V=1.037285, theta=-6.852465 -> V=1.0, theta=0.0
% INFO    : Bus 1605	: V=1.074227, theta=-24.63652 -> V=1.0, theta=0.0
% INFO    : Bus 1606	: V=1.077423, theta=8.098604 -> V=1.0, theta=0.0
% INFO    : Bus 1607	: V=1.03265, theta=-5.662474 -> V=1.0, theta=0.0
% INFO    : Bus 1608	: V=1.036655, theta=-33.030803 -> V=1.0, theta=0.0
% INFO    : Bus 1609	: V=1.046745, theta=-20.967096 -> V=1.0, theta=0.0
% INFO    : Bus 1610	: V=1.031536, theta=-44.292075 -> V=1.0, theta=0.0
% INFO    : Bus 1611	: V=1.044123, theta=-9.607803 -> V=1.0, theta=0.0
% INFO    : Bus 1612	: V=1.035831, theta=7.678301 -> V=1.0, theta=0.0
% INFO    : Bus 1613	: V=1.039635, theta=-15.151261 -> V=1.0, theta=0.0
% INFO    : Bus 1614	: V=1.040496, theta=9.279654 -> V=1.0, theta=0.0
% INFO    : Bus 1615	: V=0.963899, theta=-38.948121 -> V=1.0, theta=0.0
% INFO    : Bus 1616	: V=0.998365, theta=-4.338847 -> V=1.0, theta=0.0
% INFO    : Bus 1617	: V=1.040886, theta=-3.895078 -> V=1.0, theta=0.0
% INFO    : Bus 1618	: V=1.075715, theta=-44.205199 -> V=1.0, theta=0.0
% INFO    : Bus 1619	: V=0.927137, theta=-30.621268 -> V=1.0, theta=0.0
% INFO    : Bus 1620	: V=1.028994, theta=-31.533375 -> V=1.0, theta=0.0
% INFO    : Bus 1621	: V=1.022327, theta=-2.896696 -> V=1.0, theta=0.0
% INFO    : Bus 1622	: V=1.003443, theta=-8.907025 -> V=1.0, theta=0.0
% INFO    : Bus 1623	: V=1.028598, theta=38.481363 -> V=1.0, theta=0.0
% INFO    : Bus 1624	: V=1.049136, theta=-17.188943 -> V=1.0, theta=0.0
% INFO    : Bus 1625	: V=1.036923, theta=-19.90324 -> V=1.0, theta=0.0
% INFO    : Bus 1626	: V=1.038045, theta=9.540137 -> V=1.0, theta=0.0
% INFO    : Bus 1627	: V=1.028749, theta=-11.339861 -> V=1.0, theta=0.0
% INFO    : Bus 1628	: V=1.039685, theta=-39.992757 -> V=1.0, theta=0.0
% INFO    : Bus 1629	: V=1.038022, theta=-11.387442 -> V=1.0, theta=0.0
% INFO    : Bus 1630	: V=1.013313, theta=32.823189 -> V=1.0, theta=0.0
% INFO    : Bus 1631	: V=0.986199, theta=-31.336551 -> V=1.0, theta=0.0
% INFO    : Bus 1632	: V=1.01941, theta=-52.813876 -> V=1.0, theta=0.0
% INFO    : Bus 1633	: V=1.014774, theta=16.434066 -> V=1.0, theta=0.0
% INFO    : Bus 1634	: V=0.992605, theta=-15.913829 -> V=1.0, theta=0.0
% INFO    : Bus 1635	: V=1.01531, theta=10.365883 -> V=1.0, theta=0.0
% INFO    : Bus 1636	: V=1.030825, theta=66.746693 -> V=1.0, theta=0.0
% INFO    : Bus 1637	: V=1.036281, theta=-26.892501 -> V=1.0, theta=0.0
% INFO    : Bus 1638	: V=1.023765, theta=-54.46458 -> V=1.0, theta=0.0
% INFO    : Bus 1639	: V=1.026818, theta=-53.620086 -> V=1.0, theta=0.0
% INFO    : Bus 1640	: V=1.031823, theta=7.264228 -> V=1.0, theta=0.0
% INFO    : Bus 1641	: V=1.054985, theta=-22.038982 -> V=1.0, theta=0.0
% INFO    : Bus 1642	: V=1.025423, theta=0.137212 -> V=1.0, theta=0.0
% INFO    : Bus 1643	: V=1.037859, theta=-26.226981 -> V=1.0, theta=0.0
% INFO    : Bus 1644	: V=1.057845, theta=3.249165 -> V=1.0, theta=0.0
% INFO    : Bus 1645	: V=1.02376, theta=-54.677814 -> V=1.0, theta=0.0
% INFO    : Bus 1646	: V=1.016807, theta=62.601043 -> V=1.0, theta=0.0
% INFO    : Bus 1647	: V=1.063498, theta=-21.203305 -> V=1.0, theta=0.0
% INFO    : Bus 1648	: V=1.017786, theta=-23.764488 -> V=1.0, theta=0.0
% INFO    : Bus 1649	: V=1.047211, theta=-27.566054 -> V=1.0, theta=0.0
% INFO    : Bus 1650	: V=1.079674, theta=-22.543807 -> V=1.0, theta=0.0
% INFO    : Bus 1651	: V=1.033452, theta=-2.878595 -> V=1.0, theta=0.0
% INFO    : Bus 1652	: V=0.996997, theta=-31.783413 -> V=1.0, theta=0.0
% INFO    : Bus 1653	: V=1.012766, theta=-29.645206 -> V=1.0, theta=0.0
% INFO    : Bus 1654	: V=1.124052, theta=-27.861245 -> V=1.0, theta=0.0
% INFO    : Bus 1655	: V=0.995368, theta=-14.148154 -> V=1.0, theta=0.0
% INFO    : Bus 1656	: V=1.026893, theta=-18.16833 -> V=1.0, theta=0.0
% INFO    : Bus 1657	: V=1.01455, theta=-2.583627 -> V=1.0, theta=0.0
% INFO    : Bus 1658	: V=0.989399, theta=-26.321497 -> V=1.0, theta=0.0
% INFO    : Bus 1659	: V=1.02733, theta=-10.20009 -> V=1.0, theta=0.0
% INFO    : Bus 1660	: V=0.963852, theta=-31.39049 -> V=1.0, theta=0.0
% INFO    : Bus 1661	: V=1.013429, theta=-28.621721 -> V=1.0, theta=0.0
% INFO    : Bus 1662	: V=1.043136, theta=-21.106513 -> V=1.0, theta=0.0
% INFO    : Bus 1663	: V=1.039738, theta=-9.360278 -> V=1.0, theta=0.0
% INFO    : Bus 1664	: V=1.018662, theta=-23.52823 -> V=1.0, theta=0.0
% INFO    : Bus 1665	: V=0.972263, theta=-33.025045 -> V=1.0, theta=0.0
% INFO    : Bus 1666	: V=1.004945, theta=-48.385165 -> V=1.0, theta=0.0
% INFO    : Bus 1667	: V=1.070751, theta=44.286932 -> V=1.0, theta=0.0
% INFO    : Bus 1668	: V=1.066902, theta=-19.957089 -> V=1.0, theta=0.0
% INFO    : Bus 1669	: V=1.090065, theta=-10.670345 -> V=1.0, theta=0.0
% INFO    : Bus 1670	: V=1.037909, theta=-0.671739 -> V=1.0, theta=0.0
% INFO    : Bus 1671	: V=1.0457, theta=-39.672452 -> V=1.0, theta=0.0
% INFO    : Bus 1672	: V=1.065391, theta=-11.831936 -> V=1.0, theta=0.0
% INFO    : Bus 1673	: V=1.011939, theta=61.912631 -> V=1.0, theta=0.0
% INFO    : Bus 1674	: V=1.002491, theta=-39.764239 -> V=1.0, theta=0.0
% INFO    : Bus 1675	: V=1.022736, theta=-11.560606 -> V=1.0, theta=0.0
% INFO    : Bus 1676	: V=0.990679, theta=-1.778952 -> V=1.0, theta=0.0
% INFO    : Bus 1677	: V=1.038167, theta=-19.740289 -> V=1.0, theta=0.0
% INFO    : Bus 1678	: V=1.081736, theta=-35.98421 -> V=1.0, theta=0.0
% INFO    : Bus 1679	: V=1.02663, theta=-33.818605 -> V=1.0, theta=0.0
% INFO    : Bus 1680	: V=1.038879, theta=-2.415061 -> V=1.0, theta=0.0
% INFO    : Bus 1681	: V=0.986682, theta=-22.832577 -> V=1.0, theta=0.0
% INFO    : Bus 1682	: V=1.053188, theta=-21.492028 -> V=1.0, theta=0.0
% INFO    : Bus 1683	: V=0.994877, theta=-21.000973 -> V=1.0, theta=0.0
% INFO    : Bus 1684	: V=1.033747, theta=-36.434239 -> V=1.0, theta=0.0
% INFO    : Bus 1685	: V=1.003785, theta=-38.263404 -> V=1.0, theta=0.0
% INFO    : Bus 1686	: V=1.078664, theta=-24.703926 -> V=1.0, theta=0.0
% INFO    : Bus 1687	: V=0.931358, theta=-34.914023 -> V=1.0, theta=0.0
% INFO    : Bus 1688	: V=1.022677, theta=-40.421217 -> V=1.0, theta=0.0
% INFO    : Bus 1689	: V=1.035394, theta=10.980925 -> V=1.0, theta=0.0
% INFO    : Bus 1690	: V=1.009017, theta=-21.244805 -> V=1.0, theta=0.0
% INFO    : Bus 1691	: V=1.015921, theta=-6.634268 -> V=1.0, theta=0.0
% INFO    : Bus 1692	: V=1.04113, theta=-10.778443 -> V=1.0, theta=0.0
% INFO    : Bus 1693	: V=0.954353, theta=-30.847547 -> V=1.0, theta=0.0
% INFO    : Bus 1694	: V=1.00883, theta=-7.890285 -> V=1.0, theta=0.0
% INFO    : Bus 1695	: V=1.058966, theta=-23.450892 -> V=1.0, theta=0.0
% INFO    : Bus 1696	: V=1.023756, theta=-25.893009 -> V=1.0, theta=0.0
% INFO    : Bus 1697	: V=1.036203, theta=-50.835684 -> V=1.0, theta=0.0
% INFO    : Bus 1698	: V=1.051898, theta=-1.832565 -> V=1.0, theta=0.0
% INFO    : Bus 1699	: V=1.032709, theta=-27.758645 -> V=1.0, theta=0.0
% INFO    : Bus 1700	: V=1.028049, theta=-29.769175 -> V=1.0, theta=0.0
% INFO    : Bus 1701	: V=0.916056, theta=-35.870283 -> V=1.0, theta=0.0
% INFO    : Bus 1702	: V=1.04402, theta=3.726033 -> V=1.0, theta=0.0
% INFO    : Bus 1703	: V=1.055276, theta=-44.181014 -> V=1.0, theta=0.0
% INFO    : Bus 1704	: V=1.035555, theta=-13.41017 -> V=1.0, theta=0.0
% INFO    : Bus 1705	: V=0.936445, theta=-32.358787 -> V=1.0, theta=0.0
% INFO    : Bus 1706	: V=1.021774, theta=19.260146 -> V=1.0, theta=0.0
% INFO    : Bus 1707	: V=0.971488, theta=10.615995 -> V=1.0, theta=0.0
% INFO    : Bus 1708	: V=1.034651, theta=-13.427998 -> V=1.0, theta=0.0
% INFO    : Bus 1709	: V=1.005023, theta=-14.903001 -> V=1.0, theta=0.0
% INFO    : Bus 1710	: V=1.063034, theta=-25.548982 -> V=1.0, theta=0.0
% INFO    : Bus 1711	: V=1.034881, theta=-30.510188 -> V=1.0, theta=0.0
% INFO    : Bus 1712	: V=0.99131, theta=-27.546404 -> V=1.0, theta=0.0
% INFO    : Bus 1713	: V=0.974081, theta=-31.959491 -> V=1.0, theta=0.0
% INFO    : Bus 1714	: V=1.034594, theta=-30.63887 -> V=1.0, theta=0.0
% INFO    : Bus 1715	: V=1.054322, theta=-29.131045 -> V=1.0, theta=0.0
% INFO    : Bus 1716	: V=1.021736, theta=-41.185279 -> V=1.0, theta=0.0
% INFO    : Bus 1717	: V=1.022926, theta=-23.513094 -> V=1.0, theta=0.0
% INFO    : Bus 1718	: V=0.98164, theta=-31.464689 -> V=1.0, theta=0.0
% INFO    : Bus 1719	: V=1.085028, theta=23.495781 -> V=1.0, theta=0.0
% INFO    : Bus 1720	: V=1.072226, theta=12.409229 -> V=1.0, theta=0.0
% INFO    : Bus 1721	: V=1.061454, theta=2.336614 -> V=1.0, theta=0.0
% INFO    : Bus 1722	: V=1.023597, theta=8.989728 -> V=1.0, theta=0.0
% INFO    : Bus 1723	: V=1.047966, theta=-18.896383 -> V=1.0, theta=0.0
% INFO    : Bus 1724	: V=0.981732, theta=-31.651599 -> V=1.0, theta=0.0
% INFO    : Bus 1725	: V=1.013967, theta=-32.66926 -> V=1.0, theta=0.0
% INFO    : Bus 1726	: V=1.067726, theta=-21.121183 -> V=1.0, theta=0.0
% INFO    : Bus 1727	: V=0.98201, theta=-27.314622 -> V=1.0, theta=0.0
% INFO    : Bus 1728	: V=1.046184, theta=-49.192379 -> V=1.0, theta=0.0
% INFO    : Bus 1729	: V=1.010534, theta=-27.286436 -> V=1.0, theta=0.0
% INFO    : Bus 1730	: V=1.02153, theta=-14.768844 -> V=1.0, theta=0.0
% INFO    : Bus 1731	: V=1.022153, theta=-31.82525 -> V=1.0, theta=0.0
% INFO    : Bus 1732	: V=1.075682, theta=-23.981258 -> V=1.0, theta=0.0
% INFO    : Bus 1733	: V=1.023671, theta=-36.810876 -> V=1.0, theta=0.0
% INFO    : Bus 1734	: V=0.98465, theta=-54.840874 -> V=1.0, theta=0.0
% INFO    : Bus 1735	: V=1.061667, theta=-21.904088 -> V=1.0, theta=0.0
% INFO    : Bus 1736	: V=1.06645, theta=-25.241726 -> V=1.0, theta=0.0
% INFO    : Bus 1737	: V=1.058816, theta=-21.952753 -> V=1.0, theta=0.0
% INFO    : Bus 1738	: V=1.015757, theta=-1.685819 -> V=1.0, theta=0.0
% INFO    : Bus 1739	: V=1.030659, theta=-9.889594 -> V=1.0, theta=0.0
% INFO    : Bus 1740	: V=0.999208, theta=-27.007192 -> V=1.0, theta=0.0
% INFO    : Bus 1741	: V=0.983117, theta=-45.853217 -> V=1.0, theta=0.0
% INFO    : Bus 1742	: V=1.021131, theta=-32.671209 -> V=1.0, theta=0.0
% INFO    : Bus 1743	: V=1.033701, theta=-10.940576 -> V=1.0, theta=0.0
% INFO    : Bus 1744	: V=0.996895, theta=-31.540434 -> V=1.0, theta=0.0
% INFO    : Bus 1745	: V=0.962682, theta=-27.37169 -> V=1.0, theta=0.0
% INFO    : Bus 1746	: V=1.045012, theta=-24.413457 -> V=1.0, theta=0.0
% INFO    : Bus 1747	: V=1.053359, theta=12.399441 -> V=1.0, theta=0.0
% INFO    : Bus 1748	: V=1.038042, theta=-36.808013 -> V=1.0, theta=0.0
% INFO    : Bus 1749	: V=1.008824, theta=-32.768968 -> V=1.0, theta=0.0
% INFO    : Bus 1750	: V=1.032786, theta=-19.499518 -> V=1.0, theta=0.0
% INFO    : Bus 1751	: V=1.00013, theta=-18.836576 -> V=1.0, theta=0.0
% INFO    : Bus 1752	: V=1.030479, theta=-53.459772 -> V=1.0, theta=0.0
% INFO    : Bus 1753	: V=1.022441, theta=-26.752782 -> V=1.0, theta=0.0
% INFO    : Bus 1754	: V=1.037047, theta=-17.515273 -> V=1.0, theta=0.0
% INFO    : Bus 1755	: V=1.022734, theta=-25.736039 -> V=1.0, theta=0.0
% INFO    : Bus 1756	: V=1.037533, theta=-24.549182 -> V=1.0, theta=0.0
% INFO    : Bus 1757	: V=1.019224, theta=15.628173 -> V=1.0, theta=0.0
% INFO    : Bus 1758	: V=1.029582, theta=-4.620703 -> V=1.0, theta=0.0
% INFO    : Bus 1759	: V=1.049716, theta=-32.849576 -> V=1.0, theta=0.0
% INFO    : Bus 1760	: V=1.041544, theta=-43.844942 -> V=1.0, theta=0.0
% INFO    : Bus 1761	: V=1.020634, theta=-29.934806 -> V=1.0, theta=0.0
% INFO    : Bus 1762	: V=1.009911, theta=-20.721314 -> V=1.0, theta=0.0
% INFO    : Bus 1763	: V=1.031495, theta=-31.068516 -> V=1.0, theta=0.0
% INFO    : Bus 1764	: V=1.061599, theta=-23.124487 -> V=1.0, theta=0.0
% INFO    : Bus 1765	: V=1.048441, theta=-9.044258 -> V=1.0, theta=0.0
% INFO    : Bus 1766	: V=0.985394, theta=-26.614731 -> V=1.0, theta=0.0
% INFO    : Bus 1767	: V=1.045464, theta=-45.911677 -> V=1.0, theta=0.0
% INFO    : Bus 1768	: V=1.041318, theta=-11.34023 -> V=1.0, theta=0.0
% INFO    : Bus 1769	: V=1.02889, theta=-47.198347 -> V=1.0, theta=0.0
% INFO    : Bus 1770	: V=1.012291, theta=-41.848384 -> V=1.0, theta=0.0
% INFO    : Bus 1771	: V=1.014086, theta=-33.092664 -> V=1.0, theta=0.0
% INFO    : Bus 1772	: V=1.004091, theta=-8.612218 -> V=1.0, theta=0.0
% INFO    : Bus 1773	: V=0.99209, theta=27.973102 -> V=1.0, theta=0.0
% INFO    : Bus 1774	: V=1.05267, theta=-45.804632 -> V=1.0, theta=0.0
% INFO    : Bus 1775	: V=1.050004, theta=-26.478626 -> V=1.0, theta=0.0
% INFO    : Bus 1776	: V=0.967759, theta=68.850675 -> V=1.0, theta=0.0
% INFO    : Bus 1777	: V=1.030583, theta=15.68913 -> V=1.0, theta=0.0
% INFO    : Bus 1778	: V=1.014711, theta=16.417794 -> V=1.0, theta=0.0
% INFO    : Bus 1779	: V=1.03145, theta=-24.87137 -> V=1.0, theta=0.0
% INFO    : Bus 1780	: V=1.050808, theta=-24.75612 -> V=1.0, theta=0.0
% INFO    : Bus 1781	: V=1.029294, theta=-34.011025 -> V=1.0, theta=0.0
% INFO    : Bus 1782	: V=1.063284, theta=-17.401778 -> V=1.0, theta=0.0
% INFO    : Bus 1783	: V=1.039054, theta=1.697583 -> V=1.0, theta=0.0
% INFO    : Bus 1784	: V=0.99228, theta=-31.5665 -> V=1.0, theta=0.0
% INFO    : Bus 1785	: V=0.998, theta=-17.23253 -> V=1.0, theta=0.0
% INFO    : Bus 1786	: V=1.083767, theta=-19.098158 -> V=1.0, theta=0.0
% INFO    : Bus 1787	: V=1.016217, theta=11.837997 -> V=1.0, theta=0.0
% INFO    : Bus 1788	: V=1.021039, theta=15.216998 -> V=1.0, theta=0.0
% INFO    : Bus 1789	: V=1.041516, theta=-18.666736 -> V=1.0, theta=0.0
% INFO    : Bus 1790	: V=1.040536, theta=-3.329522 -> V=1.0, theta=0.0
% INFO    : Bus 1791	: V=1.041225, theta=-23.215191 -> V=1.0, theta=0.0
% INFO    : Bus 1792	: V=1.022722, theta=16.726688 -> V=1.0, theta=0.0
% INFO    : Bus 1793	: V=1.020092, theta=-44.591103 -> V=1.0, theta=0.0
% INFO    : Bus 1794	: V=1.04708, theta=-0.386636 -> V=1.0, theta=0.0
% INFO    : Bus 1795	: V=1.015327, theta=-29.275104 -> V=1.0, theta=0.0
% INFO    : Bus 1796	: V=0.98894, theta=-27.541031 -> V=1.0, theta=0.0
% INFO    : Bus 1797	: V=1.005885, theta=-26.295127 -> V=1.0, theta=0.0
% INFO    : Bus 1798	: V=0.980384, theta=-7.672562 -> V=1.0, theta=0.0
% INFO    : Bus 1799	: V=1.039206, theta=-21.602027 -> V=1.0, theta=0.0
% INFO    : Bus 1800	: V=1.009802, theta=-2.151969 -> V=1.0, theta=0.0
% INFO    : Bus 1801	: V=1.025453, theta=-24.903774 -> V=1.0, theta=0.0
% INFO    : Bus 1802	: V=1.002389, theta=-46.706656 -> V=1.0, theta=0.0
% INFO    : Bus 1803	: V=1.034827, theta=-22.379623 -> V=1.0, theta=0.0
% INFO    : Bus 1804	: V=1.014351, theta=-36.087944 -> V=1.0, theta=0.0
% INFO    : Bus 1805	: V=1.038865, theta=3.663556 -> V=1.0, theta=0.0
% INFO    : Bus 1806	: V=0.961839, theta=-33.975737 -> V=1.0, theta=0.0
% INFO    : Bus 1807	: V=1.037678, theta=34.179925 -> V=1.0, theta=0.0
% INFO    : Bus 1808	: V=1.04521, theta=-0.934819 -> V=1.0, theta=0.0
% INFO    : Bus 1809	: V=0.962067, theta=-19.96531 -> V=1.0, theta=0.0
% INFO    : Bus 1810	: V=1.033529, theta=16.621587 -> V=1.0, theta=0.0
% INFO    : Bus 1811	: V=1.042994, theta=33.135037 -> V=1.0, theta=0.0
% INFO    : Bus 1812	: V=1.03994, theta=10.217163 -> V=1.0, theta=0.0
% INFO    : Bus 1813	: V=1.02257, theta=-7.742655 -> V=1.0, theta=0.0
% INFO    : Bus 1814	: V=1.039354, theta=-25.863952 -> V=1.0, theta=0.0
% INFO    : Bus 1815	: V=1.02229, theta=-0.315036 -> V=1.0, theta=0.0
% INFO    : Bus 1816	: V=1.047931, theta=-23.126225 -> V=1.0, theta=0.0
% INFO    : Bus 1817	: V=1.066116, theta=-12.800258 -> V=1.0, theta=0.0
% INFO    : Bus 1818	: V=1.006291, theta=-26.865863 -> V=1.0, theta=0.0
% INFO    : Bus 1819	: V=1.039397, theta=-19.104141 -> V=1.0, theta=0.0
% INFO    : Bus 1820	: V=1.05875, theta=-15.920541 -> V=1.0, theta=0.0
% INFO    : Bus 1821	: V=1.088441, theta=-11.783927 -> V=1.0, theta=0.0
% INFO    : Bus 1822	: V=1.043084, theta=-43.003837 -> V=1.0, theta=0.0
% INFO    : Bus 1823	: V=1.020728, theta=16.810237 -> V=1.0, theta=0.0
% INFO    : Bus 1824	: V=1.075908, theta=-26.411443 -> V=1.0, theta=0.0
% INFO    : Bus 1825	: V=1.032866, theta=-0.69082 -> V=1.0, theta=0.0
% INFO    : Bus 1826	: V=1.023046, theta=-43.116686 -> V=1.0, theta=0.0
% INFO    : Bus 1827	: V=1.003664, theta=-18.891929 -> V=1.0, theta=0.0
% INFO    : Bus 1828	: V=1.005228, theta=-18.994194 -> V=1.0, theta=0.0
% INFO    : Bus 1829	: V=1.001907, theta=-31.052208 -> V=1.0, theta=0.0
% INFO    : Bus 1830	: V=1.057162, theta=-24.158999 -> V=1.0, theta=0.0
% INFO    : Bus 1831	: V=1.017814, theta=-32.141888 -> V=1.0, theta=0.0
% INFO    : Bus 1832	: V=0.961777, theta=-31.641638 -> V=1.0, theta=0.0
% INFO    : Bus 1833	: V=1.031879, theta=-22.829129 -> V=1.0, theta=0.0
% INFO    : Bus 1834	: V=1.011612, theta=-23.487852 -> V=1.0, theta=0.0
% INFO    : Bus 1835	: V=1.049216, theta=-0.351418 -> V=1.0, theta=0.0
% INFO    : Bus 1836	: V=1.027825, theta=-1.944004 -> V=1.0, theta=0.0
% INFO    : Bus 1837	: V=1.032886, theta=-1.726797 -> V=1.0, theta=0.0
% INFO    : Bus 1838	: V=1.032898, theta=-22.509058 -> V=1.0, theta=0.0
% INFO    : Bus 1839	: V=1.051337, theta=-16.123433 -> V=1.0, theta=0.0
% INFO    : Bus 1840	: V=0.965003, theta=-31.473703 -> V=1.0, theta=0.0
% INFO    : Bus 1841	: V=1.026713, theta=-53.753885 -> V=1.0, theta=0.0
% INFO    : Bus 1842	: V=1.033955, theta=-3.107877 -> V=1.0, theta=0.0
% INFO    : Bus 1843	: V=1.080669, theta=-17.696231 -> V=1.0, theta=0.0
% INFO    : Bus 1844	: V=1.065409, theta=-11.831386 -> V=1.0, theta=0.0
% INFO    : Bus 1845	: V=1.008717, theta=-7.820464 -> V=1.0, theta=0.0
% INFO    : Bus 1846	: V=1.028122, theta=20.986392 -> V=1.0, theta=0.0
% INFO    : Bus 1847	: V=1.002793, theta=-26.99395 -> V=1.0, theta=0.0
% INFO    : Bus 1848	: V=1.030639, theta=-33.753117 -> V=1.0, theta=0.0
% INFO    : Bus 1849	: V=1.032778, theta=-10.179852 -> V=1.0, theta=0.0
% INFO    : Bus 1850	: V=1.014744, theta=-51.762708 -> V=1.0, theta=0.0
% INFO    : Bus 1851	: V=1.053982, theta=-13.344252 -> V=1.0, theta=0.0
% INFO    : Bus 1852	: V=1.054605, theta=-26.16781 -> V=1.0, theta=0.0
% INFO    : Bus 1853	: V=0.981852, theta=-20.846506 -> V=1.0, theta=0.0
% INFO    : Bus 1854	: V=1.034977, theta=58.80321 -> V=1.0, theta=0.0
% INFO    : Bus 1855	: V=0.982802, theta=6.963882 -> V=1.0, theta=0.0
% INFO    : Bus 1856	: V=1.058825, theta=-0.684818 -> V=1.0, theta=0.0
% INFO    : Bus 1857	: V=1.029881, theta=-11.083766 -> V=1.0, theta=0.0
% INFO    : Bus 1858	: V=0.992973, theta=-21.379419 -> V=1.0, theta=0.0
% INFO    : Bus 1859	: V=0.993828, theta=-26.242893 -> V=1.0, theta=0.0
% INFO    : Bus 1860	: V=1.060709, theta=-25.980643 -> V=1.0, theta=0.0
% INFO    : Bus 1861	: V=1.02821, theta=19.339657 -> V=1.0, theta=0.0
% INFO    : Bus 1862	: V=0.985152, theta=-40.901374 -> V=1.0, theta=0.0
% INFO    : Bus 1863	: V=1.084436, theta=25.639895 -> V=1.0, theta=0.0
% INFO    : Bus 1864	: V=1.04085, theta=-28.072064 -> V=1.0, theta=0.0
% INFO    : Bus 1865	: V=1.031858, theta=-26.08876 -> V=1.0, theta=0.0
% INFO    : Bus 1866	: V=1.037512, theta=-28.611495 -> V=1.0, theta=0.0
% INFO    : Bus 1867	: V=1.035531, theta=-36.227274 -> V=1.0, theta=0.0
% INFO    : Bus 1868	: V=1.041623, theta=-15.644277 -> V=1.0, theta=0.0
% INFO    : Bus 1869	: V=1.031966, theta=-44.755675 -> V=1.0, theta=0.0
% INFO    : Bus 1870	: V=1.021635, theta=0.879281 -> V=1.0, theta=0.0
% INFO    : Bus 1871	: V=1.000876, theta=-50.907624 -> V=1.0, theta=0.0
% INFO    : Bus 1872	: V=1.024147, theta=-54.574191 -> V=1.0, theta=0.0
% INFO    : Bus 1873	: V=1.109647, theta=-16.333961 -> V=1.0, theta=0.0
% INFO    : Bus 1874	: V=1.063601, theta=-32.225677 -> V=1.0, theta=0.0
% INFO    : Bus 1875	: V=0.990784, theta=-30.586521 -> V=1.0, theta=0.0
% INFO    : Bus 1876	: V=1.027486, theta=-14.490891 -> V=1.0, theta=0.0
% INFO    : Bus 1877	: V=1.050568, theta=-21.692469 -> V=1.0, theta=0.0
% INFO    : Bus 1878	: V=0.998257, theta=-26.891995 -> V=1.0, theta=0.0
% INFO    : Bus 1879	: V=1.013756, theta=-31.743428 -> V=1.0, theta=0.0
% INFO    : Bus 1880	: V=1.015921, theta=0.245944 -> V=1.0, theta=0.0
% INFO    : Bus 1881	: V=1.020701, theta=-4.60248 -> V=1.0, theta=0.0
% INFO    : Bus 1882	: V=1.005906, theta=-37.450211 -> V=1.0, theta=0.0
% INFO    : Bus 1883	: V=1.027298, theta=-16.582215 -> V=1.0, theta=0.0
% INFO    : Bus 1884	: V=1.062468, theta=-10.688115 -> V=1.0, theta=0.0
% INFO    : Bus 1885	: V=1.081635, theta=-27.637697 -> V=1.0, theta=0.0
% INFO    : Bus 1886	: V=1.014141, theta=-40.707847 -> V=1.0, theta=0.0
% INFO    : Bus 1887	: V=1.02578, theta=0.474928 -> V=1.0, theta=0.0
% INFO    : Bus 1888	: V=1.034904, theta=-2.790789 -> V=1.0, theta=0.0
% INFO    : Bus 1889	: V=1.025428, theta=9.639663 -> V=1.0, theta=0.0
% INFO    : Bus 1890	: V=1.04228, theta=53.799976 -> V=1.0, theta=0.0
% INFO    : Bus 1891	: V=1.001273, theta=-31.157699 -> V=1.0, theta=0.0
% INFO    : Bus 1892	: V=1.020022, theta=-4.163834 -> V=1.0, theta=0.0
% INFO    : Bus 1893	: V=1.011913, theta=-4.946377 -> V=1.0, theta=0.0
% INFO    : Bus 1894	: V=1.021165, theta=-48.218676 -> V=1.0, theta=0.0
% INFO    : Bus 1895	: V=1.063985, theta=7.571984 -> V=1.0, theta=0.0
% INFO    : Bus 1896	: V=1.01324, theta=-6.532403 -> V=1.0, theta=0.0
% INFO    : Bus 1897	: V=1.007691, theta=-60.940761 -> V=1.0, theta=0.0
% INFO    : Bus 1898	: V=1.074634, theta=-36.208422 -> V=1.0, theta=0.0
% INFO    : Bus 1899	: V=1.065172, theta=-47.315755 -> V=1.0, theta=0.0
% INFO    : Bus 1900	: V=1.077688, theta=59.124475 -> V=1.0, theta=0.0
% INFO    : Bus 1901	: V=1.01412, theta=8.984855 -> V=1.0, theta=0.0
% INFO    : Bus 1902	: V=1.034198, theta=-38.764899 -> V=1.0, theta=0.0
% INFO    : Bus 1903	: V=1.012188, theta=-32.632231 -> V=1.0, theta=0.0
% INFO    : Bus 1904	: V=1.017157, theta=-38.533775 -> V=1.0, theta=0.0
% INFO    : Bus 1905	: V=1.049117, theta=-16.463578 -> V=1.0, theta=0.0
% INFO    : Bus 1906	: V=1.020081, theta=15.34146 -> V=1.0, theta=0.0
% INFO    : Bus 1907	: V=1.038735, theta=59.621829 -> V=1.0, theta=0.0
% INFO    : Bus 1908	: V=1.025798, theta=-23.331651 -> V=1.0, theta=0.0
% INFO    : Bus 1909	: V=1.019677, theta=-40.082212 -> V=1.0, theta=0.0
% INFO    : Bus 1910	: V=1.047725, theta=-6.761314 -> V=1.0, theta=0.0
% INFO    : Bus 1911	: V=1.04019, theta=-24.253147 -> V=1.0, theta=0.0
% INFO    : Bus 1912	: V=0.980263, theta=-45.621958 -> V=1.0, theta=0.0
% INFO    : Bus 1913	: V=1.023393, theta=9.328465 -> V=1.0, theta=0.0
% INFO    : Bus 1914	: V=1.038898, theta=-21.122268 -> V=1.0, theta=0.0
% INFO    : Bus 1915	: V=1.042728, theta=-27.029592 -> V=1.0, theta=0.0
% INFO    : Bus 1916	: V=1.000045, theta=-39.384612 -> V=1.0, theta=0.0
% INFO    : Bus 1917	: V=1.046127, theta=-25.465701 -> V=1.0, theta=0.0
% INFO    : Bus 1918	: V=1.032995, theta=-0.176302 -> V=1.0, theta=0.0
% INFO    : Bus 1919	: V=1.036866, theta=-12.936294 -> V=1.0, theta=0.0
% INFO    : Bus 1920	: V=1.043475, theta=-40.018739 -> V=1.0, theta=0.0
% INFO    : Bus 1921	: V=1.006265, theta=-16.469593 -> V=1.0, theta=0.0
% INFO    : Bus 1922	: V=1.044766, theta=-25.117213 -> V=1.0, theta=0.0
% INFO    : Bus 1923	: V=0.997765, theta=-11.91036 -> V=1.0, theta=0.0
% INFO    : Bus 1924	: V=1.02624, theta=-24.378735 -> V=1.0, theta=0.0
% INFO    : Bus 1925	: V=1.003974, theta=-2.389073 -> V=1.0, theta=0.0
% INFO    : Bus 1926	: V=1.026522, theta=-34.620402 -> V=1.0, theta=0.0
% INFO    : Bus 1927	: V=1.0345, theta=-5.60456 -> V=1.0, theta=0.0
% INFO    : Bus 1928	: V=1.018472, theta=-39.815703 -> V=1.0, theta=0.0
% INFO    : Bus 1929	: V=0.990914, theta=4.410433 -> V=1.0, theta=0.0
% INFO    : Bus 1930	: V=1.121369, theta=-22.847507 -> V=1.0, theta=0.0
% INFO    : Bus 1931	: V=0.982732, theta=-29.85688 -> V=1.0, theta=0.0
% INFO    : Bus 1932	: V=1.000503, theta=-36.252297 -> V=1.0, theta=0.0
% INFO    : Bus 1933	: V=1.05258, theta=-24.478973 -> V=1.0, theta=0.0
% INFO    : Bus 1934	: V=1.018297, theta=-32.149517 -> V=1.0, theta=0.0
% INFO    : Bus 1935	: V=1.014926, theta=1.628294 -> V=1.0, theta=0.0
% INFO    : Bus 1936	: V=1.035286, theta=5.018235 -> V=1.0, theta=0.0
% INFO    : Bus 1937	: V=1.050442, theta=30.272156 -> V=1.0, theta=0.0
% INFO    : Bus 1938	: V=1.038487, theta=11.052176 -> V=1.0, theta=0.0
% INFO    : Bus 1939	: V=1.024984, theta=-22.605301 -> V=1.0, theta=0.0
% INFO    : Bus 1940	: V=1.033019, theta=-18.314754 -> V=1.0, theta=0.0
% INFO    : Bus 1941	: V=1.009718, theta=-21.601854 -> V=1.0, theta=0.0
% INFO    : Bus 1942	: V=1.010513, theta=-59.671487 -> V=1.0, theta=0.0
% INFO    : Bus 1943	: V=1.041345, theta=6.510491 -> V=1.0, theta=0.0
% INFO    : Bus 1944	: V=1.026355, theta=56.907195 -> V=1.0, theta=0.0
% INFO    : Bus 1945	: V=0.97125, theta=-37.361789 -> V=1.0, theta=0.0
% INFO    : Bus 1946	: V=1.036261, theta=39.10102 -> V=1.0, theta=0.0
% INFO    : Bus 1947	: V=1.053959, theta=-40.521126 -> V=1.0, theta=0.0
% INFO    : Bus 1948	: V=1.013181, theta=-6.395894 -> V=1.0, theta=0.0
% INFO    : Bus 1949	: V=1.009215, theta=-9.573534 -> V=1.0, theta=0.0
% INFO    : Bus 1950	: V=1.019523, theta=-0.457298 -> V=1.0, theta=0.0
% INFO    : Bus 1951	: V=1.048768, theta=-20.861454 -> V=1.0, theta=0.0
% INFO    : Bus 1952	: V=1.035674, theta=-28.381537 -> V=1.0, theta=0.0
% INFO    : Bus 1953	: V=1.007258, theta=65.035316 -> V=1.0, theta=0.0
% INFO    : Bus 1954	: V=1.014711, theta=-27.065473 -> V=1.0, theta=0.0
% INFO    : Bus 1955	: V=1.02487, theta=16.627166 -> V=1.0, theta=0.0
% INFO    : Bus 1956	: V=1.06386, theta=29.988306 -> V=1.0, theta=0.0
% INFO    : Bus 1957	: V=1.01632, theta=-48.919694 -> V=1.0, theta=0.0
% INFO    : Bus 1958	: V=1.022554, theta=-7.505209 -> V=1.0, theta=0.0
% INFO    : Bus 1959	: V=1.069553, theta=-10.957516 -> V=1.0, theta=0.0
% INFO    : Bus 1960	: V=1.027615, theta=-28.365664 -> V=1.0, theta=0.0
% INFO    : Bus 1961	: V=0.988109, theta=-17.936842 -> V=1.0, theta=0.0
% INFO    : Bus 1962	: V=1.026482, theta=56.912845 -> V=1.0, theta=0.0
% INFO    : Bus 1963	: V=1.039808, theta=-19.664121 -> V=1.0, theta=0.0
% INFO    : Bus 1964	: V=1.053304, theta=-24.416889 -> V=1.0, theta=0.0
% INFO    : Bus 1965	: V=1.062912, theta=-50.015895 -> V=1.0, theta=0.0
% INFO    : Bus 1966	: V=1.023293, theta=-31.684433 -> V=1.0, theta=0.0
% INFO    : Bus 1967	: V=1.075382, theta=-18.046502 -> V=1.0, theta=0.0
% INFO    : Bus 1968	: V=1.025488, theta=-11.380774 -> V=1.0, theta=0.0
% INFO    : Bus 1969	: V=1.025648, theta=-54.021474 -> V=1.0, theta=0.0
% INFO    : Bus 1970	: V=1.026295, theta=-21.249181 -> V=1.0, theta=0.0
% INFO    : Bus 1971	: V=1.027477, theta=-20.372496 -> V=1.0, theta=0.0
% INFO    : Bus 1972	: V=1.118085, theta=-24.261644 -> V=1.0, theta=0.0
% INFO    : Bus 1973	: V=1.069016, theta=-26.697489 -> V=1.0, theta=0.0
% INFO    : Bus 1974	: V=0.963101, theta=-44.62521 -> V=1.0, theta=0.0
% INFO    : Bus 1975	: V=1.024667, theta=-6.601257 -> V=1.0, theta=0.0
% INFO    : Bus 1976	: V=1.032693, theta=7.341385 -> V=1.0, theta=0.0
% INFO    : Bus 1977	: V=1.034395, theta=-13.50295 -> V=1.0, theta=0.0
% INFO    : Bus 1978	: V=1.102201, theta=-24.077627 -> V=1.0, theta=0.0
% INFO    : Bus 1979	: V=1.069875, theta=-33.898765 -> V=1.0, theta=0.0
% INFO    : Bus 1980	: V=1.037878, theta=-21.73005 -> V=1.0, theta=0.0
% INFO    : Bus 1981	: V=1.030042, theta=-20.651221 -> V=1.0, theta=0.0
% INFO    : Bus 1982	: V=1.008845, theta=-5.393338 -> V=1.0, theta=0.0
% INFO    : Bus 1983	: V=1.007467, theta=-25.426976 -> V=1.0, theta=0.0
% INFO    : Bus 1984	: V=1.031492, theta=3.864128 -> V=1.0, theta=0.0
% INFO    : Bus 1985	: V=0.982099, theta=-58.088778 -> V=1.0, theta=0.0
% INFO    : Bus 1986	: V=1.031924, theta=-29.387901 -> V=1.0, theta=0.0
% INFO    : Bus 1987	: V=0.994461, theta=-30.251812 -> V=1.0, theta=0.0
% INFO    : Bus 1988	: V=1.002741, theta=-26.468764 -> V=1.0, theta=0.0
% INFO    : Bus 1989	: V=1.026746, theta=14.187408 -> V=1.0, theta=0.0
% INFO    : Bus 1990	: V=1.008358, theta=-32.735877 -> V=1.0, theta=0.0
% INFO    : Bus 1991	: V=1.022737, theta=-40.410279 -> V=1.0, theta=0.0
% INFO    : Bus 1992	: V=1.015068, theta=-2.593229 -> V=1.0, theta=0.0
% INFO    : Bus 1993	: V=0.995414, theta=9.386988 -> V=1.0, theta=0.0
% INFO    : Bus 1994	: V=1.051045, theta=-8.039112 -> V=1.0, theta=0.0
% INFO    : Bus 1995	: V=1.009394, theta=-23.403987 -> V=1.0, theta=0.0
% INFO    : Bus 1996	: V=0.980315, theta=-24.014608 -> V=1.0, theta=0.0
% INFO    : Bus 1997	: V=1.041222, theta=-31.995411 -> V=1.0, theta=0.0
% INFO    : Bus 1998	: V=1.029465, theta=-20.456335 -> V=1.0, theta=0.0
% INFO    : Bus 1999	: V=1.076837, theta=-40.120222 -> V=1.0, theta=0.0
% INFO    : Bus 2000	: V=1.076756, theta=-24.879698 -> V=1.0, theta=0.0
% INFO    : Bus 2001	: V=1.009625, theta=-24.792399 -> V=1.0, theta=0.0
% INFO    : Bus 2002	: V=1.079208, theta=31.615158 -> V=1.0, theta=0.0
% INFO    : Bus 2003	: V=1.009595, theta=8.946599 -> V=1.0, theta=0.0
% INFO    : Bus 2004	: V=1.043992, theta=-32.878294 -> V=1.0, theta=0.0
% INFO    : Bus 2005	: V=1.022518, theta=-24.292442 -> V=1.0, theta=0.0
% INFO    : Bus 2006	: V=1.019749, theta=-38.778573 -> V=1.0, theta=0.0
% INFO    : Bus 2007	: V=1.032277, theta=-11.857866 -> V=1.0, theta=0.0
% INFO    : Bus 2008	: V=0.995998, theta=-30.915861 -> V=1.0, theta=0.0
% INFO    : Bus 2009	: V=1.022468, theta=-51.350991 -> V=1.0, theta=0.0
% INFO    : Bus 2010	: V=0.948815, theta=-33.811513 -> V=1.0, theta=0.0
% INFO    : Bus 2011	: V=1.017349, theta=-26.22025 -> V=1.0, theta=0.0
% INFO    : Bus 2012	: V=1.034735, theta=-18.980386 -> V=1.0, theta=0.0
% INFO    : Bus 2013	: V=1.03859, theta=-5.132662 -> V=1.0, theta=0.0
% INFO    : Bus 2014	: V=1.089513, theta=-14.472191 -> V=1.0, theta=0.0
% INFO    : Bus 2015	: V=1.019267, theta=-26.382886 -> V=1.0, theta=0.0
% INFO    : Bus 2016	: V=1.03604, theta=7.540805 -> V=1.0, theta=0.0
% INFO    : Bus 2017	: V=1.042851, theta=-26.988688 -> V=1.0, theta=0.0
% INFO    : Bus 2018	: V=1.00366, theta=-11.898419 -> V=1.0, theta=0.0
% INFO    : Bus 2019	: V=1.041426, theta=-21.3851 -> V=1.0, theta=0.0
% INFO    : Bus 2020	: V=1.046724, theta=-24.420828 -> V=1.0, theta=0.0
% INFO    : Bus 2021	: V=1.04574, theta=-25.29705 -> V=1.0, theta=0.0
% INFO    : Bus 2022	: V=1.016664, theta=-23.914148 -> V=1.0, theta=0.0
% INFO    : Bus 2023	: V=1.026831, theta=-21.556685 -> V=1.0, theta=0.0
% INFO    : Bus 2024	: V=0.992581, theta=-28.519503 -> V=1.0, theta=0.0
% INFO    : Bus 2025	: V=1.006782, theta=-49.35595 -> V=1.0, theta=0.0
% INFO    : Bus 2026	: V=1.025828, theta=-33.804307 -> V=1.0, theta=0.0
% INFO    : Bus 2027	: V=1.033824, theta=-19.844839 -> V=1.0, theta=0.0
% INFO    : Bus 2028	: V=1.020802, theta=-19.70646 -> V=1.0, theta=0.0
% INFO    : Bus 2029	: V=1.014611, theta=9.090578 -> V=1.0, theta=0.0
% INFO    : Bus 2030	: V=1.067534, theta=15.50451 -> V=1.0, theta=0.0
% INFO    : Bus 2031	: V=1.076819, theta=-40.134915 -> V=1.0, theta=0.0
% INFO    : Bus 2032	: V=1.010431, theta=-30.336741 -> V=1.0, theta=0.0
% INFO    : Bus 2033	: V=1.026288, theta=-4.598874 -> V=1.0, theta=0.0
% INFO    : Bus 2034	: V=1.017325, theta=-29.183978 -> V=1.0, theta=0.0
% INFO    : Bus 2035	: V=1.028122, theta=0.401 -> V=1.0, theta=0.0
% INFO    : Bus 2036	: V=1.014301, theta=-26.609181 -> V=1.0, theta=0.0
% INFO    : Bus 2037	: V=1.008938, theta=-32.979344 -> V=1.0, theta=0.0
% INFO    : Bus 2038	: V=1.039244, theta=17.342907 -> V=1.0, theta=0.0
% INFO    : Bus 2039	: V=1.047273, theta=-15.334462 -> V=1.0, theta=0.0
% INFO    : Bus 2040	: V=1.013224, theta=-46.005069 -> V=1.0, theta=0.0
% INFO    : Bus 2041	: V=1.078629, theta=-16.00504 -> V=1.0, theta=0.0
% INFO    : Bus 2042	: V=1.033024, theta=-6.443506 -> V=1.0, theta=0.0
% INFO    : Bus 2043	: V=1.047821, theta=-21.373368 -> V=1.0, theta=0.0
% INFO    : Bus 2044	: V=1.029887, theta=-12.614951 -> V=1.0, theta=0.0
% INFO    : Bus 2045	: V=0.961784, theta=-32.465814 -> V=1.0, theta=0.0
% INFO    : Bus 2046	: V=1.042366, theta=66.456328 -> V=1.0, theta=0.0
% INFO    : Bus 2047	: V=1.031001, theta=-29.324914 -> V=1.0, theta=0.0
% INFO    : Bus 2048	: V=1.087553, theta=-21.787548 -> V=1.0, theta=0.0
% INFO    : Bus 2049	: V=1.052423, theta=-6.622476 -> V=1.0, theta=0.0
% INFO    : Bus 2050	: V=1.004886, theta=-1.149277 -> V=1.0, theta=0.0
% INFO    : Bus 2051	: V=1.047683, theta=-18.853377 -> V=1.0, theta=0.0
% INFO    : Bus 2052	: V=0.962887, theta=-32.243935 -> V=1.0, theta=0.0
% INFO    : Bus 2053	: V=1.037116, theta=-28.920314 -> V=1.0, theta=0.0
% INFO    : Bus 2054	: V=1.055574, theta=-23.781333 -> V=1.0, theta=0.0
% INFO    : Bus 2055	: V=1.014543, theta=-4.866032 -> V=1.0, theta=0.0
% INFO    : Bus 2056	: V=1.027846, theta=-9.315749 -> V=1.0, theta=0.0
% INFO    : Bus 2057	: V=1.031313, theta=-31.559763 -> V=1.0, theta=0.0
% INFO    : Bus 2058	: V=1.052684, theta=-45.804715 -> V=1.0, theta=0.0
% INFO    : Bus 2059	: V=1.104065, theta=-21.087887 -> V=1.0, theta=0.0
% INFO    : Bus 2060	: V=1.009599, theta=-58.910148 -> V=1.0, theta=0.0
% INFO    : Bus 2061	: V=0.995781, theta=-17.545532 -> V=1.0, theta=0.0
% INFO    : Bus 2062	: V=1.05583, theta=-23.414928 -> V=1.0, theta=0.0
% INFO    : Bus 2063	: V=1.027043, theta=-12.729431 -> V=1.0, theta=0.0
% INFO    : Bus 2064	: V=1.013124, theta=-7.475327 -> V=1.0, theta=0.0
% INFO    : Bus 2065	: V=1.021047, theta=-7.188533 -> V=1.0, theta=0.0
% INFO    : Bus 2066	: V=1.030635, theta=-9.878496 -> V=1.0, theta=0.0
% INFO    : Bus 2067	: V=1.036075, theta=-29.78924 -> V=1.0, theta=0.0
% INFO    : Bus 2068	: V=1.061101, theta=-22.058249 -> V=1.0, theta=0.0
% INFO    : Bus 2069	: V=1.028411, theta=65.082435 -> V=1.0, theta=0.0
% INFO    : Bus 2070	: V=1.01757, theta=-5.507258 -> V=1.0, theta=0.0
% INFO    : Bus 2071	: V=1.042789, theta=47.058431 -> V=1.0, theta=0.0
% INFO    : Bus 2072	: V=1.059961, theta=-17.698679 -> V=1.0, theta=0.0
% INFO    : Bus 2073	: V=1.046226, theta=-25.564376 -> V=1.0, theta=0.0
% INFO    : Bus 2074	: V=1.020506, theta=2.243727 -> V=1.0, theta=0.0
% INFO    : Bus 2075	: V=1.017699, theta=-1.963235 -> V=1.0, theta=0.0
% INFO    : Bus 2076	: V=1.019808, theta=7.364672 -> V=1.0, theta=0.0
% INFO    : Bus 2077	: V=1.025776, theta=11.372538 -> V=1.0, theta=0.0
% INFO    : Bus 2078	: V=1.018119, theta=-14.911286 -> V=1.0, theta=0.0
% INFO    : Bus 2079	: V=1.053582, theta=-12.209929 -> V=1.0, theta=0.0
% INFO    : Bus 2080	: V=1.014009, theta=-8.703475 -> V=1.0, theta=0.0
% INFO    : Bus 2081	: V=0.975157, theta=-49.400861 -> V=1.0, theta=0.0
% INFO    : Bus 2082	: V=1.014544, theta=1.61216 -> V=1.0, theta=0.0
% INFO    : Bus 2083	: V=1.031586, theta=-18.751547 -> V=1.0, theta=0.0
% INFO    : Bus 2084	: V=1.06401, theta=18.931087 -> V=1.0, theta=0.0
% INFO    : Bus 2085	: V=1.029587, theta=2.315883 -> V=1.0, theta=0.0
% INFO    : Bus 2086	: V=1.058532, theta=-19.958565 -> V=1.0, theta=0.0
% INFO    : Bus 2087	: V=1.013497, theta=-5.459814 -> V=1.0, theta=0.0
% INFO    : Bus 2088	: V=1.054586, theta=-12.178402 -> V=1.0, theta=0.0
% INFO    : Bus 2089	: V=1.038708, theta=-26.108581 -> V=1.0, theta=0.0
% INFO    : Bus 2090	: V=1.01105, theta=-1.774887 -> V=1.0, theta=0.0
% INFO    : Bus 2091	: V=1.02498, theta=-37.030652 -> V=1.0, theta=0.0
% INFO    : Bus 2092	: V=0.963686, theta=-22.292553 -> V=1.0, theta=0.0
% INFO    : Bus 2093	: V=1.019357, theta=-8.221102 -> V=1.0, theta=0.0
% INFO    : Bus 2094	: V=1.060812, theta=42.767804 -> V=1.0, theta=0.0
% INFO    : Bus 2095	: V=1.021064, theta=-32.110852 -> V=1.0, theta=0.0
% INFO    : Bus 2096	: V=1.046008, theta=-46.580961 -> V=1.0, theta=0.0
% INFO    : Bus 2097	: V=1.026099, theta=-23.179994 -> V=1.0, theta=0.0
% INFO    : Bus 2098	: V=1.064541, theta=1.202606 -> V=1.0, theta=0.0
% INFO    : Bus 2099	: V=1.029049, theta=-27.094361 -> V=1.0, theta=0.0
% INFO    : Bus 2100	: V=1.022492, theta=-41.032214 -> V=1.0, theta=0.0
% INFO    : Bus 2101	: V=1.028647, theta=-5.56639 -> V=1.0, theta=0.0
% INFO    : Bus 2102	: V=0.971407, theta=27.718442 -> V=1.0, theta=0.0
% INFO    : Bus 2103	: V=1.017917, theta=-29.06054 -> V=1.0, theta=0.0
% INFO    : Bus 2104	: V=1.005555, theta=-6.627974 -> V=1.0, theta=0.0
% INFO    : Bus 2105	: V=1.038502, theta=66.587145 -> V=1.0, theta=0.0
% INFO    : Bus 2106	: V=1.007207, theta=-30.247885 -> V=1.0, theta=0.0
% INFO    : Bus 2107	: V=1.040878, theta=-0.384592 -> V=1.0, theta=0.0
% INFO    : Bus 2108	: V=1.052816, theta=-23.539802 -> V=1.0, theta=0.0
% INFO    : Bus 2109	: V=1.026732, theta=-43.345577 -> V=1.0, theta=0.0
% INFO    : Bus 2110	: V=1.068667, theta=-14.718056 -> V=1.0, theta=0.0
% INFO    : Bus 2111	: V=1.007865, theta=-19.47523 -> V=1.0, theta=0.0
% INFO    : Bus 2112	: V=1.010405, theta=6.151511 -> V=1.0, theta=0.0
% INFO    : Bus 2113	: V=1.151426, theta=-21.184015 -> V=1.0, theta=0.0
% INFO    : Bus 2114	: V=0.962004, theta=-23.15021 -> V=1.0, theta=0.0
% INFO    : Bus 2115	: V=0.947883, theta=-23.815387 -> V=1.0, theta=0.0
% INFO    : Bus 2116	: V=1.020733, theta=-46.651247 -> V=1.0, theta=0.0
% INFO    : Bus 2117	: V=1.028711, theta=-1.85876 -> V=1.0, theta=0.0
% INFO    : Bus 2118	: V=1.009604, theta=-37.776887 -> V=1.0, theta=0.0
% INFO    : Bus 2119	: V=1.020215, theta=-4.334775 -> V=1.0, theta=0.0
% INFO    : Bus 2120	: V=1.023401, theta=9.328488 -> V=1.0, theta=0.0
% INFO    : Bus 2121	: V=1.037057, theta=-24.297839 -> V=1.0, theta=0.0
% INFO    : Bus 2122	: V=1.025212, theta=6.076546 -> V=1.0, theta=0.0
% INFO    : Bus 2123	: V=0.984147, theta=-32.500513 -> V=1.0, theta=0.0
% INFO    : Bus 2124	: V=1.022575, theta=63.259259 -> V=1.0, theta=0.0
% INFO    : Bus 2125	: V=0.988682, theta=-30.998911 -> V=1.0, theta=0.0
% INFO    : Bus 2126	: V=1.017186, theta=-53.006723 -> V=1.0, theta=0.0
% INFO    : Bus 2127	: V=1.002297, theta=-30.614179 -> V=1.0, theta=0.0
% INFO    : Bus 2128	: V=1.032035, theta=-23.414596 -> V=1.0, theta=0.0
% INFO    : Bus 2129	: V=1.021988, theta=-8.169627 -> V=1.0, theta=0.0
% INFO    : Bus 2130	: V=1.019587, theta=-28.587769 -> V=1.0, theta=0.0
% INFO    : Bus 2131	: V=1.089688, theta=-27.991218 -> V=1.0, theta=0.0
% INFO    : Bus 2132	: V=1.037463, theta=-15.904235 -> V=1.0, theta=0.0
% INFO    : Bus 2133	: V=1.062625, theta=52.356991 -> V=1.0, theta=0.0
% INFO    : Bus 2134	: V=1.03408, theta=-3.064497 -> V=1.0, theta=0.0
% INFO    : Bus 2135	: V=1.017173, theta=-29.076524 -> V=1.0, theta=0.0
% INFO    : Bus 2136	: V=1.019583, theta=4.657853 -> V=1.0, theta=0.0
% INFO    : Bus 2137	: V=1.019436, theta=-7.612871 -> V=1.0, theta=0.0
% INFO    : Bus 2138	: V=1.016838, theta=-11.821955 -> V=1.0, theta=0.0
% INFO    : Bus 2139	: V=1.038846, theta=-49.571529 -> V=1.0, theta=0.0
% INFO    : Bus 2140	: V=0.986532, theta=-53.437129 -> V=1.0, theta=0.0
% INFO    : Bus 2141	: V=1.02688, theta=0.763636 -> V=1.0, theta=0.0
% INFO    : Bus 2142	: V=1.047615, theta=-7.960845 -> V=1.0, theta=0.0
% INFO    : Bus 2143	: V=0.987085, theta=-43.801071 -> V=1.0, theta=0.0
% INFO    : Bus 2144	: V=1.035938, theta=-21.477095 -> V=1.0, theta=0.0
% INFO    : Bus 2145	: V=1.017308, theta=-14.54311 -> V=1.0, theta=0.0
% INFO    : Bus 2146	: V=0.983114, theta=-33.088115 -> V=1.0, theta=0.0
% INFO    : Bus 2147	: V=1.006915, theta=-48.167882 -> V=1.0, theta=0.0
% INFO    : Bus 2148	: V=1.042373, theta=-29.571563 -> V=1.0, theta=0.0
% INFO    : Bus 2149	: V=0.94437, theta=-35.315794 -> V=1.0, theta=0.0
% INFO    : Bus 2150	: V=1.061614, theta=22.717219 -> V=1.0, theta=0.0
% INFO    : Bus 2151	: V=1.005592, theta=-0.822806 -> V=1.0, theta=0.0
% INFO    : Bus 2152	: V=1.058488, theta=-23.628759 -> V=1.0, theta=0.0
% INFO    : Bus 2153	: V=1.065758, theta=1.843264 -> V=1.0, theta=0.0
% INFO    : Bus 2154	: V=1.045554, theta=10.761812 -> V=1.0, theta=0.0
% INFO    : Bus 2155	: V=1.033134, theta=-6.433546 -> V=1.0, theta=0.0
% INFO    : Bus 2156	: V=1.011365, theta=-13.272881 -> V=1.0, theta=0.0
% INFO    : Bus 2157	: V=1.024695, theta=3.308464 -> V=1.0, theta=0.0
% INFO    : Bus 2158	: V=1.000737, theta=-27.441243 -> V=1.0, theta=0.0
% INFO    : Bus 2159	: V=0.823843, theta=-41.5372 -> V=1.0, theta=0.0
% INFO    : Bus 2160	: V=1.027602, theta=-45.178171 -> V=1.0, theta=0.0
% INFO    : Bus 2161	: V=1.045411, theta=-29.058113 -> V=1.0, theta=0.0
% INFO    : Bus 2162	: V=1.074568, theta=-22.625366 -> V=1.0, theta=0.0
% INFO    : Bus 2163	: V=1.042967, theta=-20.417491 -> V=1.0, theta=0.0
% INFO    : Bus 2164	: V=1.044395, theta=-29.479203 -> V=1.0, theta=0.0
% INFO    : Bus 2165	: V=1.027513, theta=5.388751 -> V=1.0, theta=0.0
% INFO    : Bus 2166	: V=1.054425, theta=-14.69511 -> V=1.0, theta=0.0
% INFO    : Bus 2167	: V=1.027081, theta=-25.732231 -> V=1.0, theta=0.0
% INFO    : Bus 2168	: V=1.019587, theta=-13.276745 -> V=1.0, theta=0.0
% INFO    : Bus 2169	: V=1.035649, theta=-24.356152 -> V=1.0, theta=0.0
% INFO    : Bus 2170	: V=1.025415, theta=-27.249576 -> V=1.0, theta=0.0
% INFO    : Bus 2171	: V=0.99897, theta=-24.971014 -> V=1.0, theta=0.0
% INFO    : Bus 2172	: V=1.027481, theta=-50.091836 -> V=1.0, theta=0.0
% INFO    : Bus 2173	: V=1.063497, theta=-27.847436 -> V=1.0, theta=0.0
% INFO    : Bus 2174	: V=1.00905, theta=-13.428183 -> V=1.0, theta=0.0
% INFO    : Bus 2175	: V=1.048436, theta=-20.851948 -> V=1.0, theta=0.0
% INFO    : Bus 2176	: V=1.0196, theta=29.887392 -> V=1.0, theta=0.0
% INFO    : Bus 2177	: V=1.068942, theta=-28.881725 -> V=1.0, theta=0.0
% INFO    : Bus 2178	: V=1.04338, theta=-31.73289 -> V=1.0, theta=0.0
% INFO    : Bus 2179	: V=1.042701, theta=-25.03242 -> V=1.0, theta=0.0
% INFO    : Bus 2180	: V=1.020728, theta=-1.17428 -> V=1.0, theta=0.0
% INFO    : Bus 2181	: V=1.00154, theta=23.885802 -> V=1.0, theta=0.0
% INFO    : Bus 2182	: V=1.015192, theta=-3.517904 -> V=1.0, theta=0.0
% INFO    : Bus 2183	: V=0.9922, theta=-16.467929 -> V=1.0, theta=0.0
% INFO    : Bus 2184	: V=0.997829, theta=-32.179648 -> V=1.0, theta=0.0
% INFO    : Bus 2185	: V=1.056295, theta=-15.15523 -> V=1.0, theta=0.0
% INFO    : Bus 2186	: V=1.022218, theta=2.694959 -> V=1.0, theta=0.0
% INFO    : Bus 2187	: V=1.036364, theta=-12.86827 -> V=1.0, theta=0.0
% INFO    : Bus 2188	: V=1.044948, theta=-50.067985 -> V=1.0, theta=0.0
% INFO    : Bus 2189	: V=1.046449, theta=-6.348503 -> V=1.0, theta=0.0
% INFO    : Bus 2190	: V=1.064499, theta=21.115751 -> V=1.0, theta=0.0
% INFO    : Bus 2191	: V=1.022139, theta=-25.253741 -> V=1.0, theta=0.0
% INFO    : Bus 2192	: V=1.096122, theta=33.377912 -> V=1.0, theta=0.0
% INFO    : Bus 2193	: V=1.009622, theta=-47.671613 -> V=1.0, theta=0.0
% INFO    : Bus 2194	: V=0.992066, theta=-32.011375 -> V=1.0, theta=0.0
% INFO    : Bus 2195	: V=0.997154, theta=-32.953214 -> V=1.0, theta=0.0
% INFO    : Bus 2196	: V=1.036544, theta=39.19365 -> V=1.0, theta=0.0
% INFO    : Bus 2197	: V=1.031798, theta=-6.111419 -> V=1.0, theta=0.0
% INFO    : Bus 2198	: V=0.961565, theta=-30.257046 -> V=1.0, theta=0.0
% INFO    : Bus 2199	: V=1.00662, theta=-50.639854 -> V=1.0, theta=0.0
% INFO    : Bus 2200	: V=1.02289, theta=-27.575099 -> V=1.0, theta=0.0
% INFO    : Bus 2201	: V=0.976169, theta=-32.476732 -> V=1.0, theta=0.0
% INFO    : Bus 2202	: V=1.021647, theta=-49.803988 -> V=1.0, theta=0.0
% INFO    : Bus 2203	: V=1.007242, theta=-20.041451 -> V=1.0, theta=0.0
% INFO    : Bus 2204	: V=1.021705, theta=-46.279718 -> V=1.0, theta=0.0
% INFO    : Bus 2205	: V=1.005586, theta=-36.686458 -> V=1.0, theta=0.0
% INFO    : Bus 2206	: V=1.018916, theta=-34.656516 -> V=1.0, theta=0.0
% INFO    : Bus 2207	: V=1.006198, theta=-30.213114 -> V=1.0, theta=0.0
% INFO    : Bus 2208	: V=1.042053, theta=-13.792922 -> V=1.0, theta=0.0
% INFO    : Bus 2209	: V=0.967888, theta=-28.721386 -> V=1.0, theta=0.0
% INFO    : Bus 2210	: V=1.001006, theta=-36.77408 -> V=1.0, theta=0.0
% INFO    : Bus 2211	: V=0.944699, theta=-22.597549 -> V=1.0, theta=0.0
% INFO    : Bus 2212	: V=0.976643, theta=11.936659 -> V=1.0, theta=0.0
% INFO    : Bus 2213	: V=0.99713, theta=-32.416337 -> V=1.0, theta=0.0
% INFO    : Bus 2214	: V=1.012833, theta=61.836316 -> V=1.0, theta=0.0
% INFO    : Bus 2215	: V=1.016427, theta=-7.76953 -> V=1.0, theta=0.0
% INFO    : Bus 2216	: V=1.086968, theta=7.721123 -> V=1.0, theta=0.0
% INFO    : Bus 2217	: V=0.954628, theta=-33.459831 -> V=1.0, theta=0.0
% INFO    : Bus 2218	: V=1.010599, theta=-27.081656 -> V=1.0, theta=0.0
% INFO    : Bus 2219	: V=1.01223, theta=-36.67689 -> V=1.0, theta=0.0
% INFO    : Bus 2220	: V=1.066623, theta=-28.071251 -> V=1.0, theta=0.0
% INFO    : Bus 2221	: V=0.997341, theta=-27.133263 -> V=1.0, theta=0.0
% INFO    : Bus 2222	: V=1.075928, theta=43.452293 -> V=1.0, theta=0.0
% INFO    : Bus 2223	: V=1.026839, theta=-2.340482 -> V=1.0, theta=0.0
% INFO    : Bus 2224	: V=0.999481, theta=-50.559153 -> V=1.0, theta=0.0
% INFO    : Bus 2225	: V=1.025903, theta=-44.775248 -> V=1.0, theta=0.0
% INFO    : Bus 2226	: V=1.06687, theta=-16.553003 -> V=1.0, theta=0.0
% INFO    : Bus 2227	: V=1.003174, theta=-36.685975 -> V=1.0, theta=0.0
% INFO    : Bus 2228	: V=1.011206, theta=22.467426 -> V=1.0, theta=0.0
% INFO    : Bus 2229	: V=1.065909, theta=-13.135319 -> V=1.0, theta=0.0
% INFO    : Bus 2230	: V=1.032021, theta=-22.83036 -> V=1.0, theta=0.0
% INFO    : Bus 2231	: V=1.046057, theta=1.068739 -> V=1.0, theta=0.0
% INFO    : Bus 2232	: V=1.023898, theta=-33.498353 -> V=1.0, theta=0.0
% INFO    : Bus 2233	: V=0.985171, theta=-56.435749 -> V=1.0, theta=0.0
% INFO    : Bus 2234	: V=1.052737, theta=-29.321529 -> V=1.0, theta=0.0
% INFO    : Bus 2235	: V=1.008042, theta=-45.226775 -> V=1.0, theta=0.0
% INFO    : Bus 2236	: V=1.020813, theta=-42.798155 -> V=1.0, theta=0.0
% INFO    : Bus 2237	: V=1.034951, theta=49.087288 -> V=1.0, theta=0.0
% INFO    : Bus 2238	: V=0.982791, theta=-16.125162 -> V=1.0, theta=0.0
% INFO    : Bus 2239	: V=1.01042, theta=-23.606 -> V=1.0, theta=0.0
% INFO    : Bus 2240	: V=1.013461, theta=3.23261 -> V=1.0, theta=0.0
% INFO    : Bus 2241	: V=1.005014, theta=11.382833 -> V=1.0, theta=0.0
% INFO    : Bus 2242	: V=1.021353, theta=-19.301242 -> V=1.0, theta=0.0
% INFO    : Bus 2243	: V=1.029391, theta=4.137431 -> V=1.0, theta=0.0
% INFO    : Bus 2244	: V=1.037731, theta=-23.018246 -> V=1.0, theta=0.0
% INFO    : Bus 2245	: V=1.010255, theta=7.628832 -> V=1.0, theta=0.0
% INFO    : Bus 2246	: V=1.015845, theta=-15.009168 -> V=1.0, theta=0.0
% INFO    : Bus 2247	: V=1.014007, theta=62.665561 -> V=1.0, theta=0.0
% INFO    : Bus 2248	: V=1.011098, theta=-46.870246 -> V=1.0, theta=0.0
% INFO    : Bus 2249	: V=1.037294, theta=-28.117592 -> V=1.0, theta=0.0
% INFO    : Bus 2250	: V=1.024801, theta=-7.262701 -> V=1.0, theta=0.0
% INFO    : Bus 2251	: V=1.043241, theta=-24.893094 -> V=1.0, theta=0.0
% INFO    : Bus 2252	: V=1.06522, theta=-48.109558 -> V=1.0, theta=0.0
% INFO    : Bus 2253	: V=1.147706, theta=-23.576587 -> V=1.0, theta=0.0
% INFO    : Bus 2254	: V=0.992038, theta=-34.266143 -> V=1.0, theta=0.0
% INFO    : Bus 2255	: V=1.012904, theta=10.266561 -> V=1.0, theta=0.0
% INFO    : Bus 2256	: V=0.977764, theta=-21.60905 -> V=1.0, theta=0.0
% INFO    : Bus 2257	: V=1.023136, theta=-25.121398 -> V=1.0, theta=0.0
% INFO    : Bus 2258	: V=1.023856, theta=-15.0105 -> V=1.0, theta=0.0
% INFO    : Bus 2259	: V=0.986832, theta=-28.686147 -> V=1.0, theta=0.0
% INFO    : Bus 2260	: V=1.024811, theta=5.411327 -> V=1.0, theta=0.0
% INFO    : Bus 2261	: V=1.062649, theta=-41.012513 -> V=1.0, theta=0.0
% INFO    : Bus 2262	: V=0.973298, theta=-32.13493 -> V=1.0, theta=0.0
% INFO    : Bus 2263	: V=1.041323, theta=-20.80661 -> V=1.0, theta=0.0
% INFO    : Bus 2264	: V=1.010553, theta=-23.522211 -> V=1.0, theta=0.0
% INFO    : Bus 2265	: V=1.036318, theta=-7.096598 -> V=1.0, theta=0.0
% INFO    : Bus 2266	: V=1.013425, theta=-21.770998 -> V=1.0, theta=0.0
% INFO    : Bus 2267	: V=1.003207, theta=11.579452 -> V=1.0, theta=0.0
% INFO    : Bus 2268	: V=0.992327, theta=-5.514567 -> V=1.0, theta=0.0
% INFO    : Bus 2269	: V=1.05231, theta=-20.182035 -> V=1.0, theta=0.0
% INFO    : Bus 2270	: V=1.063847, theta=-21.310503 -> V=1.0, theta=0.0
% INFO    : Bus 2271	: V=1.021336, theta=10.866719 -> V=1.0, theta=0.0
% INFO    : Bus 2272	: V=1.060674, theta=-12.270379 -> V=1.0, theta=0.0
% INFO    : Bus 2273	: V=1.068632, theta=-26.737078 -> V=1.0, theta=0.0
% INFO    : Bus 2274	: V=1.004956, theta=-10.486485 -> V=1.0, theta=0.0
% INFO    : Bus 2275	: V=1.009846, theta=-24.207712 -> V=1.0, theta=0.0
% INFO    : Bus 2276	: V=1.062473, theta=-24.368144 -> V=1.0, theta=0.0
% INFO    : Bus 2277	: V=1.043887, theta=46.693183 -> V=1.0, theta=0.0
% INFO    : Bus 2278	: V=1.030091, theta=17.647967 -> V=1.0, theta=0.0
% INFO    : Bus 2279	: V=1.014308, theta=-22.801606 -> V=1.0, theta=0.0
% INFO    : Bus 2280	: V=1.030143, theta=-26.749909 -> V=1.0, theta=0.0
% INFO    : Bus 2281	: V=1.015438, theta=-8.763494 -> V=1.0, theta=0.0
% INFO    : Bus 2282	: V=1.021275, theta=-38.931447 -> V=1.0, theta=0.0
% INFO    : Bus 2283	: V=1.0389, theta=-23.599279 -> V=1.0, theta=0.0
% INFO    : Bus 2284	: V=1.030581, theta=-10.972604 -> V=1.0, theta=0.0
% INFO    : Bus 2285	: V=1.019024, theta=63.028088 -> V=1.0, theta=0.0
% INFO    : Bus 2286	: V=1.019611, theta=-9.10866 -> V=1.0, theta=0.0
% INFO    : Bus 2287	: V=1.034619, theta=-5.128401 -> V=1.0, theta=0.0
% INFO    : Bus 2288	: V=1.032863, theta=-8.632598 -> V=1.0, theta=0.0
% INFO    : Bus 2289	: V=1.036649, theta=-10.586065 -> V=1.0, theta=0.0
% INFO    : Bus 2290	: V=1.047189, theta=-14.164277 -> V=1.0, theta=0.0
% INFO    : Bus 2291	: V=1.063998, theta=-11.16215 -> V=1.0, theta=0.0
% INFO    : Bus 2292	: V=1.024081, theta=-30.555303 -> V=1.0, theta=0.0
% INFO    : Bus 2293	: V=1.034016, theta=-29.914798 -> V=1.0, theta=0.0
% INFO    : Bus 2294	: V=1.056839, theta=-13.846532 -> V=1.0, theta=0.0
% INFO    : Bus 2295	: V=1.017204, theta=-27.379016 -> V=1.0, theta=0.0
% INFO    : Bus 2296	: V=1.002026, theta=-44.832563 -> V=1.0, theta=0.0
% INFO    : Bus 2297	: V=1.024492, theta=-54.583126 -> V=1.0, theta=0.0
% INFO    : Bus 2298	: V=1.009365, theta=-25.785602 -> V=1.0, theta=0.0
% INFO    : Bus 2299	: V=1.031467, theta=-11.576168 -> V=1.0, theta=0.0
% INFO    : Bus 2300	: V=1.030534, theta=-22.214833 -> V=1.0, theta=0.0
% INFO    : Bus 2301	: V=1.023834, theta=-54.421813 -> V=1.0, theta=0.0
% INFO    : Bus 2302	: V=1.004747, theta=-50.97031 -> V=1.0, theta=0.0
% INFO    : Bus 2303	: V=1.035492, theta=-16.004196 -> V=1.0, theta=0.0
% INFO    : Bus 2304	: V=1.051368, theta=-26.192039 -> V=1.0, theta=0.0
% INFO    : Bus 2305	: V=1.027261, theta=-0.244746 -> V=1.0, theta=0.0
% INFO    : Bus 2306	: V=1.062445, theta=43.303305 -> V=1.0, theta=0.0
% INFO    : Bus 2307	: V=1.051906, theta=-28.111468 -> V=1.0, theta=0.0
% INFO    : Bus 2308	: V=1.03359, theta=-24.440454 -> V=1.0, theta=0.0
% INFO    : Bus 2309	: V=1.068248, theta=23.198789 -> V=1.0, theta=0.0
% INFO    : Bus 2310	: V=1.013414, theta=-21.713391 -> V=1.0, theta=0.0
% INFO    : Bus 2311	: V=0.992324, theta=-29.260501 -> V=1.0, theta=0.0
% INFO    : Bus 2312	: V=1.04204, theta=-29.563033 -> V=1.0, theta=0.0
% INFO    : Bus 2313	: V=1.043224, theta=-21.560168 -> V=1.0, theta=0.0
% INFO    : Bus 2314	: V=1.012324, theta=-36.615338 -> V=1.0, theta=0.0
% INFO    : Bus 2315	: V=1.027446, theta=2.280769 -> V=1.0, theta=0.0
% INFO    : Bus 2316	: V=1.025936, theta=-35.138462 -> V=1.0, theta=0.0
% INFO    : Bus 2317	: V=1.017334, theta=-36.081183 -> V=1.0, theta=0.0
% INFO    : Bus 2318	: V=0.977049, theta=-31.54394 -> V=1.0, theta=0.0
% INFO    : Bus 2319	: V=1.050919, theta=-9.227171 -> V=1.0, theta=0.0
% INFO    : Bus 2320	: V=1.025327, theta=-45.259588 -> V=1.0, theta=0.0
% INFO    : Bus 2321	: V=1.020279, theta=-38.57031 -> V=1.0, theta=0.0
% INFO    : Bus 2322	: V=1.011753, theta=63.312472 -> V=1.0, theta=0.0
% INFO    : Bus 2323	: V=0.989214, theta=-22.621975 -> V=1.0, theta=0.0
% INFO    : Bus 2324	: V=1.029735, theta=-5.984451 -> V=1.0, theta=0.0
% INFO    : Bus 2325	: V=0.996292, theta=-0.946019 -> V=1.0, theta=0.0
% INFO    : Bus 2326	: V=1.039189, theta=-39.946279 -> V=1.0, theta=0.0
% INFO    : Bus 2327	: V=1.042809, theta=-25.466491 -> V=1.0, theta=0.0
% INFO    : Bus 2328	: V=1.01174, theta=-14.547426 -> V=1.0, theta=0.0
% INFO    : Bus 2329	: V=1.048968, theta=9.559465 -> V=1.0, theta=0.0
% INFO    : Bus 2330	: V=1.009007, theta=0.655964 -> V=1.0, theta=0.0
% INFO    : Bus 2331	: V=1.011436, theta=18.739489 -> V=1.0, theta=0.0
% INFO    : Bus 2332	: V=1.029158, theta=-31.509433 -> V=1.0, theta=0.0
% INFO    : Bus 2333	: V=0.968039, theta=-29.31337 -> V=1.0, theta=0.0
% INFO    : Bus 2334	: V=1.074572, theta=-22.21578 -> V=1.0, theta=0.0
% INFO    : Bus 2335	: V=1.044074, theta=6.10879 -> V=1.0, theta=0.0
% INFO    : Bus 2336	: V=1.035535, theta=-22.479197 -> V=1.0, theta=0.0
% INFO    : Bus 2337	: V=1.042097, theta=-30.086837 -> V=1.0, theta=0.0
% INFO    : Bus 2338	: V=0.952295, theta=-31.710735 -> V=1.0, theta=0.0
% INFO    : Bus 2339	: V=1.009593, theta=-24.521036 -> V=1.0, theta=0.0
% INFO    : Bus 2340	: V=1.033768, theta=-12.546175 -> V=1.0, theta=0.0
% INFO    : Bus 2341	: V=1.057467, theta=-26.432568 -> V=1.0, theta=0.0
% INFO    : Bus 2342	: V=1.059396, theta=55.280716 -> V=1.0, theta=0.0
% INFO    : Bus 2343	: V=1.020785, theta=-42.957173 -> V=1.0, theta=0.0
% INFO    : Bus 2344	: V=1.054222, theta=-15.775316 -> V=1.0, theta=0.0
% INFO    : Bus 2345	: V=1.027493, theta=-26.383948 -> V=1.0, theta=0.0
% INFO    : Bus 2346	: V=1.022957, theta=8.75295 -> V=1.0, theta=0.0
% INFO    : Bus 2347	: V=0.998838, theta=-29.376014 -> V=1.0, theta=0.0
% INFO    : Bus 2348	: V=0.968417, theta=-36.688676 -> V=1.0, theta=0.0
% INFO    : Bus 2349	: V=1.05949, theta=-27.313076 -> V=1.0, theta=0.0
% INFO    : Bus 2350	: V=1.01017, theta=15.884565 -> V=1.0, theta=0.0
% INFO    : Bus 2351	: V=1.019563, theta=62.181667 -> V=1.0, theta=0.0
% INFO    : Bus 2352	: V=0.958373, theta=-29.424716 -> V=1.0, theta=0.0
% INFO    : Bus 2353	: V=1.010677, theta=-8.11857 -> V=1.0, theta=0.0
% INFO    : Bus 2354	: V=1.014721, theta=-32.352939 -> V=1.0, theta=0.0
% INFO    : Bus 2355	: V=1.015354, theta=-51.394188 -> V=1.0, theta=0.0
% INFO    : Bus 2356	: V=0.977313, theta=-30.412799 -> V=1.0, theta=0.0
% INFO    : Bus 2357	: V=1.072612, theta=-3.82962 -> V=1.0, theta=0.0
% INFO    : Bus 2358	: V=1.023813, theta=-54.443138 -> V=1.0, theta=0.0
% INFO    : Bus 2359	: V=1.021762, theta=-10.091408 -> V=1.0, theta=0.0
% INFO    : Bus 2360	: V=1.033789, theta=-21.574385 -> V=1.0, theta=0.0
% INFO    : Bus 2361	: V=1.035677, theta=-29.682934 -> V=1.0, theta=0.0
% INFO    : Bus 2362	: V=1.038978, theta=-11.117228 -> V=1.0, theta=0.0
% INFO    : Bus 2363	: V=0.99184, theta=-22.926815 -> V=1.0, theta=0.0
% INFO    : Bus 2364	: V=1.01739, theta=8.973438 -> V=1.0, theta=0.0
% INFO    : Bus 2365	: V=1.031058, theta=-22.416671 -> V=1.0, theta=0.0
% INFO    : Bus 2366	: V=1.003879, theta=-49.924326 -> V=1.0, theta=0.0
% INFO    : Bus 2367	: V=1.053354, theta=-28.800199 -> V=1.0, theta=0.0
% INFO    : Bus 2368	: V=1.059005, theta=-27.635733 -> V=1.0, theta=0.0
% INFO    : Bus 2369	: V=1.055918, theta=-17.345679 -> V=1.0, theta=0.0
% INFO    : Bus 2370	: V=1.034832, theta=-21.563669 -> V=1.0, theta=0.0
% INFO    : Bus 2371	: V=1.032872, theta=-43.818915 -> V=1.0, theta=0.0
% INFO    : Bus 2372	: V=0.986562, theta=-17.792777 -> V=1.0, theta=0.0
% INFO    : Bus 2373	: V=1.017902, theta=-24.439685 -> V=1.0, theta=0.0
% INFO    : Bus 2374	: V=1.003311, theta=-31.350195 -> V=1.0, theta=0.0
% INFO    : Bus 2375	: V=1.009953, theta=-25.950012 -> V=1.0, theta=0.0
% INFO    : Bus 2376	: V=0.993399, theta=-27.237978 -> V=1.0, theta=0.0
% INFO    : Bus 2377	: V=1.036778, theta=-15.052217 -> V=1.0, theta=0.0
% INFO    : Bus 2378	: V=1.03349, theta=-26.129447 -> V=1.0, theta=0.0
% INFO    : Bus 2379	: V=0.950151, theta=-29.473578 -> V=1.0, theta=0.0
% INFO    : Bus 2380	: V=1.031315, theta=-27.715521 -> V=1.0, theta=0.0
% INFO    : Bus 2381	: V=1.038031, theta=4.576831 -> V=1.0, theta=0.0
% INFO    : Bus 2382	: V=1.009187, theta=-34.100259 -> V=1.0, theta=0.0
% INFO    : Bus 2383	: V=1.054816, theta=-16.31655 -> V=1.0, theta=0.0
% INFO    : Bus 2384	: V=1.036527, theta=-37.386634 -> V=1.0, theta=0.0
% INFO    : Bus 2385	: V=1.034739, theta=-8.954845 -> V=1.0, theta=0.0
% INFO    : Bus 2386	: V=1.043705, theta=-21.418464 -> V=1.0, theta=0.0
% INFO    : Bus 2387	: V=0.983017, theta=9.191644 -> V=1.0, theta=0.0
% INFO    : Bus 2388	: V=1.007494, theta=-37.291444 -> V=1.0, theta=0.0
% INFO    : Bus 2389	: V=1.043727, theta=-30.375841 -> V=1.0, theta=0.0
% INFO    : Bus 2390	: V=0.995225, theta=9.248959 -> V=1.0, theta=0.0
% INFO    : Bus 2391	: V=0.97801, theta=-29.767009 -> V=1.0, theta=0.0
% INFO    : Bus 2392	: V=1.021881, theta=-25.503771 -> V=1.0, theta=0.0
% INFO    : Bus 2393	: V=1.064029, theta=7.685859 -> V=1.0, theta=0.0
% INFO    : Bus 2394	: V=1.065017, theta=54.664187 -> V=1.0, theta=0.0
% INFO    : Bus 2395	: V=1.020043, theta=-25.439807 -> V=1.0, theta=0.0
% INFO    : Bus 2396	: V=1.034233, theta=5.35921 -> V=1.0, theta=0.0
% INFO    : Bus 2397	: V=0.996094, theta=-31.3955 -> V=1.0, theta=0.0
% INFO    : Bus 2398	: V=1.147454, theta=-23.601459 -> V=1.0, theta=0.0
% INFO    : Bus 2399	: V=0.971529, theta=-34.186542 -> V=1.0, theta=0.0
% INFO    : Bus 2400	: V=1.035877, theta=12.455059 -> V=1.0, theta=0.0
% INFO    : Bus 2401	: V=0.962213, theta=-32.513726 -> V=1.0, theta=0.0
% INFO    : Bus 2402	: V=1.076661, theta=-19.339734 -> V=1.0, theta=0.0
% INFO    : Bus 2403	: V=1.022768, theta=-48.115052 -> V=1.0, theta=0.0
% INFO    : Bus 2404	: V=0.927417, theta=-34.766043 -> V=1.0, theta=0.0
% INFO    : Bus 2405	: V=1.026531, theta=-3.69527 -> V=1.0, theta=0.0
% INFO    : Bus 2406	: V=1.04431, theta=-24.755069 -> V=1.0, theta=0.0
% INFO    : Bus 2407	: V=0.993264, theta=-39.922258 -> V=1.0, theta=0.0
% INFO    : Bus 2408	: V=1.005765, theta=-26.282357 -> V=1.0, theta=0.0
% INFO    : Bus 2409	: V=1.055461, theta=10.594296 -> V=1.0, theta=0.0
% INFO    : Bus 2410	: V=1.024241, theta=-37.185757 -> V=1.0, theta=0.0
% INFO    : Bus 2411	: V=1.01792, theta=62.34921 -> V=1.0, theta=0.0
% INFO    : Bus 2412	: V=1.013238, theta=-43.156083 -> V=1.0, theta=0.0
% INFO    : Bus 2413	: V=0.996424, theta=9.258591 -> V=1.0, theta=0.0
% INFO    : Bus 2414	: V=1.022771, theta=14.280372 -> V=1.0, theta=0.0
% INFO    : Bus 2415	: V=1.017323, theta=-27.549298 -> V=1.0, theta=0.0
% INFO    : Bus 2416	: V=1.0474, theta=-49.767877 -> V=1.0, theta=0.0
% INFO    : Bus 2417	: V=1.054261, theta=-20.876656 -> V=1.0, theta=0.0
% INFO    : Bus 2418	: V=1.058347, theta=27.795826 -> V=1.0, theta=0.0
% INFO    : Bus 2419	: V=0.994664, theta=-13.92369 -> V=1.0, theta=0.0
% INFO    : Bus 2420	: V=1.020157, theta=-18.290136 -> V=1.0, theta=0.0
% INFO    : Bus 2421	: V=1.043537, theta=-24.060562 -> V=1.0, theta=0.0
% INFO    : Bus 2422	: V=1.012924, theta=-30.696006 -> V=1.0, theta=0.0
% INFO    : Bus 2423	: V=1.01892, theta=-46.711961 -> V=1.0, theta=0.0
% INFO    : Bus 2424	: V=1.030907, theta=-22.76203 -> V=1.0, theta=0.0
% INFO    : Bus 2425	: V=1.037815, theta=-10.136554 -> V=1.0, theta=0.0
% INFO    : Bus 2426	: V=1.045936, theta=-13.54825 -> V=1.0, theta=0.0
% INFO    : Bus 2427	: V=1.082868, theta=-21.362734 -> V=1.0, theta=0.0
% INFO    : Bus 2428	: V=1.024706, theta=0.110381 -> V=1.0, theta=0.0
% INFO    : Bus 2429	: V=1.063143, theta=12.917367 -> V=1.0, theta=0.0
% INFO    : Bus 2430	: V=1.039783, theta=-12.117188 -> V=1.0, theta=0.0
% INFO    : Bus 2431	: V=0.992323, theta=-21.573229 -> V=1.0, theta=0.0
% INFO    : Bus 2432	: V=1.021679, theta=-32.538904 -> V=1.0, theta=0.0
% INFO    : Bus 2433	: V=1.015149, theta=6.190111 -> V=1.0, theta=0.0
% INFO    : Bus 2434	: V=1.055535, theta=-27.608504 -> V=1.0, theta=0.0
% INFO    : Bus 2435	: V=1.144156, theta=-23.633231 -> V=1.0, theta=0.0
% INFO    : Bus 2436	: V=0.998471, theta=-3.00089 -> V=1.0, theta=0.0
% INFO    : Bus 2437	: V=1.057795, theta=-42.136814 -> V=1.0, theta=0.0
% INFO    : Bus 2438	: V=1.043195, theta=-21.559867 -> V=1.0, theta=0.0
% INFO    : Bus 2439	: V=1.005857, theta=23.692042 -> V=1.0, theta=0.0
% INFO    : Bus 2440	: V=1.02046, theta=3.58516 -> V=1.0, theta=0.0
% INFO    : Bus 2441	: V=0.994601, theta=-5.150369 -> V=1.0, theta=0.0
% INFO    : Bus 2442	: V=0.998662, theta=-26.864718 -> V=1.0, theta=0.0
% INFO    : Bus 2443	: V=1.009217, theta=8.41599 -> V=1.0, theta=0.0
% INFO    : Bus 2444	: V=1.026884, theta=7.398524 -> V=1.0, theta=0.0
% INFO    : Bus 2445	: V=0.962275, theta=-31.64821 -> V=1.0, theta=0.0
% INFO    : Bus 2446	: V=1.048971, theta=7.52887 -> V=1.0, theta=0.0
% INFO    : Bus 2447	: V=1.031874, theta=-11.988534 -> V=1.0, theta=0.0
% INFO    : Bus 2448	: V=1.040932, theta=25.764861 -> V=1.0, theta=0.0
% INFO    : Bus 2449	: V=1.062433, theta=-6.280372 -> V=1.0, theta=0.0
% INFO    : Bus 2450	: V=1.021508, theta=3.940089 -> V=1.0, theta=0.0
% INFO    : Bus 2451	: V=1.040158, theta=-21.474336 -> V=1.0, theta=0.0
% INFO    : Bus 2452	: V=1.026174, theta=16.830485 -> V=1.0, theta=0.0
% INFO    : Bus 2453	: V=1.040903, theta=-2.446956 -> V=1.0, theta=0.0
% INFO    : Bus 2454	: V=1.02755, theta=-30.467201 -> V=1.0, theta=0.0
% INFO    : Bus 2455	: V=0.999933, theta=-3.616676 -> V=1.0, theta=0.0
% INFO    : Bus 2456	: V=1.032684, theta=-15.137228 -> V=1.0, theta=0.0
% INFO    : Bus 2457	: V=1.037629, theta=-24.947308 -> V=1.0, theta=0.0
% INFO    : Bus 2458	: V=1.00176, theta=-13.726748 -> V=1.0, theta=0.0
% INFO    : Bus 2459	: V=1.04316, theta=-42.879326 -> V=1.0, theta=0.0
% INFO    : Bus 2460	: V=0.979599, theta=-40.295757 -> V=1.0, theta=0.0
% INFO    : Bus 2461	: V=1.042742, theta=-8.232623 -> V=1.0, theta=0.0
% INFO    : Bus 2462	: V=1.014526, theta=-26.776272 -> V=1.0, theta=0.0
% INFO    : Bus 2463	: V=1.086073, theta=45.377841 -> V=1.0, theta=0.0
% INFO    : Bus 2464	: V=0.978522, theta=-33.017724 -> V=1.0, theta=0.0
% INFO    : Bus 2465	: V=1.064101, theta=1.055741 -> V=1.0, theta=0.0
% INFO    : Bus 2466	: V=0.936778, theta=-32.12342 -> V=1.0, theta=0.0
% INFO    : Bus 2467	: V=1.011431, theta=-14.414053 -> V=1.0, theta=0.0
% INFO    : Bus 2468	: V=1.046839, theta=-6.281333 -> V=1.0, theta=0.0
% INFO    : Bus 2469	: V=1.001957, theta=-30.409265 -> V=1.0, theta=0.0
% INFO    : Bus 2470	: V=1.020155, theta=-25.904378 -> V=1.0, theta=0.0
% INFO    : Bus 2471	: V=1.011871, theta=-47.766524 -> V=1.0, theta=0.0
% INFO    : Bus 2472	: V=0.98671, theta=4.854467 -> V=1.0, theta=0.0
% INFO    : Bus 2473	: V=0.943732, theta=-35.399912 -> V=1.0, theta=0.0
% INFO    : Bus 2474	: V=1.060294, theta=-27.122887 -> V=1.0, theta=0.0
% INFO    : Bus 2475	: V=1.055302, theta=-8.059108 -> V=1.0, theta=0.0
% INFO    : Bus 2476	: V=0.970883, theta=-24.101597 -> V=1.0, theta=0.0
% INFO    : Bus 2477	: V=1.008651, theta=-9.743001 -> V=1.0, theta=0.0
% INFO    : Bus 2478	: V=1.027168, theta=15.022854 -> V=1.0, theta=0.0
% INFO    : Bus 2479	: V=1.004264, theta=-2.650053 -> V=1.0, theta=0.0
% INFO    : Bus 2480	: V=1.001341, theta=-36.96814 -> V=1.0, theta=0.0
% INFO    : Bus 2481	: V=1.045831, theta=-18.206422 -> V=1.0, theta=0.0
% INFO    : Bus 2482	: V=1.022565, theta=8.174762 -> V=1.0, theta=0.0
% INFO    : Bus 2483	: V=1.020708, theta=-3.051755 -> V=1.0, theta=0.0
% INFO    : Bus 2484	: V=1.055668, theta=-48.878125 -> V=1.0, theta=0.0
% INFO    : Bus 2485	: V=1.040915, theta=8.404641 -> V=1.0, theta=0.0
% INFO    : Bus 2486	: V=1.042068, theta=11.909351 -> V=1.0, theta=0.0
% INFO    : Bus 2487	: V=1.051406, theta=-19.92777 -> V=1.0, theta=0.0
% INFO    : Bus 2488	: V=0.997894, theta=-25.797116 -> V=1.0, theta=0.0
% INFO    : Bus 2489	: V=1.046032, theta=1.069051 -> V=1.0, theta=0.0
% INFO    : Bus 2490	: V=1.012284, theta=-1.786344 -> V=1.0, theta=0.0
% INFO    : Bus 2491	: V=1.006433, theta=7.066289 -> V=1.0, theta=0.0
% INFO    : Bus 2492	: V=0.972676, theta=-18.887241 -> V=1.0, theta=0.0
% INFO    : Bus 2493	: V=1.031054, theta=-10.742367 -> V=1.0, theta=0.0
% INFO    : Bus 2494	: V=1.017252, theta=0.511391 -> V=1.0, theta=0.0
% INFO    : Bus 2495	: V=1.047044, theta=-24.959324 -> V=1.0, theta=0.0
% INFO    : Bus 2496	: V=1.009835, theta=-61.002304 -> V=1.0, theta=0.0
% INFO    : Bus 2497	: V=0.976143, theta=-56.682465 -> V=1.0, theta=0.0
% INFO    : Bus 2498	: V=1.039709, theta=-16.75247 -> V=1.0, theta=0.0
% INFO    : Bus 2499	: V=1.030521, theta=6.209771 -> V=1.0, theta=0.0
% INFO    : Bus 2500	: V=1.136559, theta=-25.931448 -> V=1.0, theta=0.0
% INFO    : Bus 2501	: V=1.044679, theta=-23.67977 -> V=1.0, theta=0.0
% INFO    : Bus 2502	: V=1.065757, theta=-39.403617 -> V=1.0, theta=0.0
% INFO    : Bus 2503	: V=1.00763, theta=-21.840345 -> V=1.0, theta=0.0
% INFO    : Bus 2504	: V=1.005424, theta=-45.865158 -> V=1.0, theta=0.0
% INFO    : Bus 2505	: V=0.996704, theta=-35.118129 -> V=1.0, theta=0.0
% INFO    : Bus 2506	: V=0.974779, theta=-22.08123 -> V=1.0, theta=0.0
% INFO    : Bus 2507	: V=1.06149, theta=-42.008359 -> V=1.0, theta=0.0
% INFO    : Bus 2508	: V=1.005889, theta=7.847197 -> V=1.0, theta=0.0
% INFO    : Bus 2509	: V=1.025789, theta=-14.476871 -> V=1.0, theta=0.0
% INFO    : Bus 2510	: V=1.025451, theta=-12.308601 -> V=1.0, theta=0.0
% INFO    : Bus 2511	: V=1.045056, theta=16.162224 -> V=1.0, theta=0.0
% INFO    : Bus 2512	: V=1.054857, theta=-34.872387 -> V=1.0, theta=0.0
% INFO    : Bus 2513	: V=1.038107, theta=35.125312 -> V=1.0, theta=0.0
% INFO    : Bus 2514	: V=1.024359, theta=-6.570675 -> V=1.0, theta=0.0
% INFO    : Bus 2515	: V=0.998497, theta=-25.884845 -> V=1.0, theta=0.0
% INFO    : Bus 2516	: V=1.026768, theta=-12.590765 -> V=1.0, theta=0.0
% INFO    : Bus 2517	: V=1.013559, theta=-45.235352 -> V=1.0, theta=0.0
% INFO    : Bus 2518	: V=0.996983, theta=-11.616978 -> V=1.0, theta=0.0
% INFO    : Bus 2519	: V=1.028396, theta=65.846601 -> V=1.0, theta=0.0
% INFO    : Bus 2520	: V=0.99239, theta=-5.13982 -> V=1.0, theta=0.0
% INFO    : Bus 2521	: V=1.020279, theta=-7.528828 -> V=1.0, theta=0.0
% INFO    : Bus 2522	: V=1.069701, theta=-24.040225 -> V=1.0, theta=0.0
% INFO    : Bus 2523	: V=1.039971, theta=25.635635 -> V=1.0, theta=0.0
% INFO    : Bus 2524	: V=1.012873, theta=-4.734816 -> V=1.0, theta=0.0
% INFO    : Bus 2525	: V=0.994561, theta=-28.409429 -> V=1.0, theta=0.0
% INFO    : Bus 2526	: V=1.041902, theta=-20.143178 -> V=1.0, theta=0.0
% INFO    : Bus 2527	: V=1.041963, theta=-4.898556 -> V=1.0, theta=0.0
% INFO    : Bus 2528	: V=1.037117, theta=-22.898476 -> V=1.0, theta=0.0
% INFO    : Bus 2529	: V=1.020241, theta=-29.747583 -> V=1.0, theta=0.0
% INFO    : Bus 2530	: V=1.058488, theta=-26.840441 -> V=1.0, theta=0.0
% INFO    : Bus 2531	: V=0.985798, theta=-23.177847 -> V=1.0, theta=0.0
% INFO    : Bus 2532	: V=1.091238, theta=45.829104 -> V=1.0, theta=0.0
% INFO    : Bus 2533	: V=1.002974, theta=-7.531116 -> V=1.0, theta=0.0
% INFO    : Bus 2534	: V=1.066932, theta=-21.855019 -> V=1.0, theta=0.0
% INFO    : Bus 2535	: V=1.033154, theta=-3.315871 -> V=1.0, theta=0.0
% INFO    : Bus 2536	: V=1.003452, theta=-31.424496 -> V=1.0, theta=0.0
% INFO    : Bus 2537	: V=1.001309, theta=-26.217035 -> V=1.0, theta=0.0
% INFO    : Bus 2538	: V=1.009528, theta=-44.137993 -> V=1.0, theta=0.0
% INFO    : Bus 2539	: V=1.024702, theta=-7.289116 -> V=1.0, theta=0.0
% INFO    : Bus 2540	: V=1.000879, theta=-32.900184 -> V=1.0, theta=0.0
% INFO    : Bus 2541	: V=1.02273, theta=-21.791278 -> V=1.0, theta=0.0
% INFO    : Bus 2542	: V=0.991401, theta=-30.700734 -> V=1.0, theta=0.0
% INFO    : Bus 2543	: V=1.027732, theta=-38.707722 -> V=1.0, theta=0.0
% INFO    : Bus 2544	: V=1.017203, theta=61.75354 -> V=1.0, theta=0.0
% INFO    : Bus 2545	: V=1.030444, theta=18.762567 -> V=1.0, theta=0.0
% INFO    : Bus 2546	: V=1.07694, theta=-25.692549 -> V=1.0, theta=0.0
% INFO    : Bus 2547	: V=1.014326, theta=-2.727604 -> V=1.0, theta=0.0
% INFO    : Bus 2548	: V=1.0032, theta=-36.682256 -> V=1.0, theta=0.0
% INFO    : Bus 2549	: V=1.046283, theta=-3.447313 -> V=1.0, theta=0.0
% INFO    : Bus 2550	: V=1.047876, theta=-6.732622 -> V=1.0, theta=0.0
% INFO    : Bus 2551	: V=1.005574, theta=-61.354086 -> V=1.0, theta=0.0
% INFO    : Bus 2552	: V=1.044585, theta=4.016008 -> V=1.0, theta=0.0
% INFO    : Bus 2553	: V=1.043674, theta=13.172731 -> V=1.0, theta=0.0
% INFO    : Bus 2554	: V=0.933736, theta=-36.784298 -> V=1.0, theta=0.0
% INFO    : Bus 2555	: V=1.066476, theta=11.763351 -> V=1.0, theta=0.0
% INFO    : Bus 2556	: V=1.048219, theta=-19.794039 -> V=1.0, theta=0.0
% INFO    : Bus 2557	: V=1.018903, theta=-16.139966 -> V=1.0, theta=0.0
% INFO    : Bus 2558	: V=1.018448, theta=-16.992434 -> V=1.0, theta=0.0
% INFO    : Bus 2559	: V=1.02844, theta=-24.493083 -> V=1.0, theta=0.0
% INFO    : Bus 2560	: V=1.00289, theta=-25.000015 -> V=1.0, theta=0.0
% INFO    : Bus 2561	: V=1.000799, theta=-31.486927 -> V=1.0, theta=0.0
% INFO    : Bus 2562	: V=0.998383, theta=-52.123371 -> V=1.0, theta=0.0
% INFO    : Bus 2563	: V=1.044592, theta=-4.927884 -> V=1.0, theta=0.0
% INFO    : Bus 2564	: V=1.025766, theta=-53.795529 -> V=1.0, theta=0.0
% INFO    : Bus 2565	: V=1.006421, theta=-14.843498 -> V=1.0, theta=0.0
% INFO    : Bus 2566	: V=1.034203, theta=-45.289648 -> V=1.0, theta=0.0
% INFO    : Bus 2567	: V=0.999382, theta=-27.831283 -> V=1.0, theta=0.0
% INFO    : Bus 2568	: V=1.020248, theta=-29.849094 -> V=1.0, theta=0.0
% INFO    : Bus 2569	: V=1.027206, theta=62.77383 -> V=1.0, theta=0.0
% INFO    : Bus 2570	: V=1.073931, theta=-48.191881 -> V=1.0, theta=0.0
% INFO    : Bus 2571	: V=1.022478, theta=-29.065479 -> V=1.0, theta=0.0
% INFO    : Bus 2572	: V=1.044176, theta=17.000824 -> V=1.0, theta=0.0
% INFO    : Bus 2573	: V=1.025584, theta=-4.056179 -> V=1.0, theta=0.0
% INFO    : Bus 2574	: V=1.003942, theta=-50.629163 -> V=1.0, theta=0.0
% INFO    : Bus 2575	: V=1.030857, theta=-3.002196 -> V=1.0, theta=0.0
% INFO    : Bus 2576	: V=1.053356, theta=-29.283394 -> V=1.0, theta=0.0
% INFO    : Bus 2577	: V=1.036793, theta=-34.094563 -> V=1.0, theta=0.0
% INFO    : Bus 2578	: V=1.004649, theta=-50.494286 -> V=1.0, theta=0.0
% INFO    : Bus 2579	: V=1.047813, theta=-31.69296 -> V=1.0, theta=0.0
% INFO    : Bus 2580	: V=0.917979, theta=-35.780229 -> V=1.0, theta=0.0
% INFO    : Bus 2581	: V=0.958173, theta=-32.107715 -> V=1.0, theta=0.0
% INFO    : Bus 2582	: V=1.054389, theta=-22.5657 -> V=1.0, theta=0.0
% INFO    : Bus 2583	: V=1.012051, theta=-14.539673 -> V=1.0, theta=0.0
% INFO    : Bus 2584	: V=1.013649, theta=9.107989 -> V=1.0, theta=0.0
% INFO    : Bus 2585	: V=1.09874, theta=-26.818256 -> V=1.0, theta=0.0
% INFO    : Bus 2586	: V=1.061697, theta=-21.361889 -> V=1.0, theta=0.0
% INFO    : Bus 2587	: V=1.013679, theta=-32.975234 -> V=1.0, theta=0.0
% INFO    : Bus 2588	: V=1.028186, theta=-13.772507 -> V=1.0, theta=0.0
% INFO    : Bus 2589	: V=1.02499, theta=-12.475736 -> V=1.0, theta=0.0
% INFO    : Bus 2590	: V=1.039701, theta=3.293239 -> V=1.0, theta=0.0
% INFO    : Bus 2591	: V=1.025968, theta=-15.577476 -> V=1.0, theta=0.0
% INFO    : Bus 2592	: V=0.978821, theta=-24.09493 -> V=1.0, theta=0.0
% INFO    : Bus 2593	: V=0.967156, theta=-26.738596 -> V=1.0, theta=0.0
% INFO    : Bus 2594	: V=1.058099, theta=-28.005721 -> V=1.0, theta=0.0
% INFO    : Bus 2595	: V=1.073729, theta=13.746806 -> V=1.0, theta=0.0
% INFO    : Bus 2596	: V=1.040499, theta=-27.864931 -> V=1.0, theta=0.0
% INFO    : Bus 2597	: V=1.030134, theta=-10.945874 -> V=1.0, theta=0.0
% INFO    : Bus 2598	: V=1.037585, theta=-15.393641 -> V=1.0, theta=0.0
% INFO    : Bus 2599	: V=1.029312, theta=14.802272 -> V=1.0, theta=0.0
% INFO    : Bus 2600	: V=1.047035, theta=-13.430179 -> V=1.0, theta=0.0
% INFO    : Bus 2601	: V=1.006105, theta=-38.033085 -> V=1.0, theta=0.0
% INFO    : Bus 2602	: V=1.055981, theta=-26.5034 -> V=1.0, theta=0.0
% INFO    : Bus 2603	: V=0.985189, theta=-34.73886 -> V=1.0, theta=0.0
% INFO    : Bus 2604	: V=1.031949, theta=13.582886 -> V=1.0, theta=0.0
% INFO    : Bus 2605	: V=1.049286, theta=-10.626042 -> V=1.0, theta=0.0
% INFO    : Bus 2606	: V=1.041601, theta=11.411295 -> V=1.0, theta=0.0
% INFO    : Bus 2607	: V=1.05799, theta=-19.927793 -> V=1.0, theta=0.0
% INFO    : Bus 2608	: V=1.006305, theta=19.873213 -> V=1.0, theta=0.0
% INFO    : Bus 2609	: V=0.976604, theta=-28.293193 -> V=1.0, theta=0.0
% INFO    : Bus 2610	: V=1.016134, theta=8.806843 -> V=1.0, theta=0.0
% INFO    : Bus 2611	: V=1.042426, theta=-15.652309 -> V=1.0, theta=0.0
% INFO    : Bus 2612	: V=1.064253, theta=-34.598289 -> V=1.0, theta=0.0
% INFO    : Bus 2613	: V=1.011055, theta=-37.608964 -> V=1.0, theta=0.0
% INFO    : Bus 2614	: V=1.01386, theta=-8.240749 -> V=1.0, theta=0.0
% INFO    : Bus 2615	: V=1.029475, theta=-45.006416 -> V=1.0, theta=0.0
% INFO    : Bus 2616	: V=1.0389, theta=4.953667 -> V=1.0, theta=0.0
% INFO    : Bus 2617	: V=1.048731, theta=-29.212214 -> V=1.0, theta=0.0
% INFO    : Bus 2618	: V=1.011451, theta=-12.59031 -> V=1.0, theta=0.0
% INFO    : Bus 2619	: V=1.016494, theta=5.847438 -> V=1.0, theta=0.0
% INFO    : Bus 2620	: V=1.030287, theta=-31.664696 -> V=1.0, theta=0.0
% INFO    : Bus 2621	: V=1.014006, theta=-22.877447 -> V=1.0, theta=0.0
% INFO    : Bus 2622	: V=1.04369, theta=-50.070672 -> V=1.0, theta=0.0
% INFO    : Bus 2623	: V=1.019356, theta=-7.385053 -> V=1.0, theta=0.0
% INFO    : Bus 2624	: V=1.037675, theta=-25.413258 -> V=1.0, theta=0.0
% INFO    : Bus 2625	: V=1.029129, theta=-33.934715 -> V=1.0, theta=0.0
% INFO    : Bus 2626	: V=1.062882, theta=-18.416903 -> V=1.0, theta=0.0
% INFO    : Bus 2627	: V=1.048065, theta=7.49733 -> V=1.0, theta=0.0
% INFO    : Bus 2628	: V=0.976189, theta=-31.892903 -> V=1.0, theta=0.0
% INFO    : Bus 2629	: V=1.041141, theta=-24.819636 -> V=1.0, theta=0.0
% INFO    : Bus 2630	: V=1.017944, theta=-13.180311 -> V=1.0, theta=0.0
% INFO    : Bus 2631	: V=1.009262, theta=36.74247 -> V=1.0, theta=0.0
% INFO    : Bus 2632	: V=1.022404, theta=-10.187631 -> V=1.0, theta=0.0
% INFO    : Bus 2633	: V=1.015076, theta=-23.917266 -> V=1.0, theta=0.0
% INFO    : Bus 2634	: V=1.028551, theta=-37.887644 -> V=1.0, theta=0.0
% INFO    : Bus 2635	: V=0.849692, theta=-39.840933 -> V=1.0, theta=0.0
% INFO    : Bus 2636	: V=0.999505, theta=-49.363859 -> V=1.0, theta=0.0
% INFO    : Bus 2637	: V=1.021527, theta=-40.234528 -> V=1.0, theta=0.0
% INFO    : Bus 2638	: V=0.970876, theta=-32.262237 -> V=1.0, theta=0.0
% INFO    : Bus 2639	: V=1.041487, theta=-27.48851 -> V=1.0, theta=0.0
% INFO    : Bus 2640	: V=1.01507, theta=-5.047736 -> V=1.0, theta=0.0
% INFO    : Bus 2641	: V=1.036589, theta=-11.578452 -> V=1.0, theta=0.0
% INFO    : Bus 2642	: V=1.052836, theta=-37.523797 -> V=1.0, theta=0.0
% INFO    : Bus 2643	: V=1.004558, theta=-30.619224 -> V=1.0, theta=0.0
% INFO    : Bus 2644	: V=1.068086, theta=-25.190835 -> V=1.0, theta=0.0
% INFO    : Bus 2645	: V=0.994287, theta=-25.732813 -> V=1.0, theta=0.0
% INFO    : Bus 2646	: V=1.060015, theta=-11.39007 -> V=1.0, theta=0.0
% INFO    : Bus 2647	: V=1.001038, theta=-0.332218 -> V=1.0, theta=0.0
% INFO    : Bus 2648	: V=1.058647, theta=10.388439 -> V=1.0, theta=0.0
% INFO    : Bus 2649	: V=1.087006, theta=-36.284446 -> V=1.0, theta=0.0
% INFO    : Bus 2650	: V=1.036234, theta=-36.354105 -> V=1.0, theta=0.0
% INFO    : Bus 2651	: V=0.990147, theta=-27.471409 -> V=1.0, theta=0.0
% INFO    : Bus 2652	: V=1.013967, theta=-32.66926 -> V=1.0, theta=0.0
% INFO    : Bus 2653	: V=1.032593, theta=-23.359386 -> V=1.0, theta=0.0
% INFO    : Bus 2654	: V=1.016656, theta=-18.8984 -> V=1.0, theta=0.0
% INFO    : Bus 2655	: V=0.983151, theta=9.190976 -> V=1.0, theta=0.0
% INFO    : Bus 2656	: V=1.031889, theta=-23.227885 -> V=1.0, theta=0.0
% INFO    : Bus 2657	: V=1.018, theta=51.385645 -> V=1.0, theta=0.0
% INFO    : Bus 2658	: V=1.020867, theta=-49.501838 -> V=1.0, theta=0.0
% INFO    : Bus 2659	: V=1.000418, theta=-4.242926 -> V=1.0, theta=0.0
% INFO    : Bus 2660	: V=1.011944, theta=-31.986779 -> V=1.0, theta=0.0
% INFO    : Bus 2661	: V=0.942596, theta=-32.670874 -> V=1.0, theta=0.0
% INFO    : Bus 2662	: V=1.014043, theta=60.625336 -> V=1.0, theta=0.0
% INFO    : Bus 2663	: V=1.016474, theta=-23.509763 -> V=1.0, theta=0.0
% INFO    : Bus 2664	: V=1.049614, theta=-24.724471 -> V=1.0, theta=0.0
% INFO    : Bus 2665	: V=0.982173, theta=9.934066 -> V=1.0, theta=0.0
% INFO    : Bus 2666	: V=1.009676, theta=-10.943069 -> V=1.0, theta=0.0
% INFO    : Bus 2667	: V=1.027765, theta=-53.665943 -> V=1.0, theta=0.0
% INFO    : Bus 2668	: V=1.017882, theta=-44.645979 -> V=1.0, theta=0.0
% INFO    : Bus 2669	: V=1.00927, theta=-49.478765 -> V=1.0, theta=0.0
% INFO    : Bus 2670	: V=1.007831, theta=-43.395901 -> V=1.0, theta=0.0
% INFO    : Bus 2671	: V=1.027314, theta=-34.113967 -> V=1.0, theta=0.0
% INFO    : Bus 2672	: V=1.02577, theta=-24.719652 -> V=1.0, theta=0.0
% INFO    : Bus 2673	: V=0.986099, theta=-39.714474 -> V=1.0, theta=0.0
% INFO    : Bus 2674	: V=0.964839, theta=-31.450337 -> V=1.0, theta=0.0
% INFO    : Bus 2675	: V=1.02691, theta=-42.54101 -> V=1.0, theta=0.0
% INFO    : Bus 2676	: V=1.033964, theta=-15.170761 -> V=1.0, theta=0.0
% INFO    : Bus 2677	: V=1.031552, theta=-19.193726 -> V=1.0, theta=0.0
% INFO    : Bus 2678	: V=1.065178, theta=-25.764629 -> V=1.0, theta=0.0
% INFO    : Bus 2679	: V=1.047069, theta=-22.055493 -> V=1.0, theta=0.0
% INFO    : Bus 2680	: V=1.036493, theta=-36.212633 -> V=1.0, theta=0.0
% INFO    : Bus 2681	: V=1.07137, theta=38.529441 -> V=1.0, theta=0.0
% INFO    : Bus 2682	: V=1.030385, theta=-32.053978 -> V=1.0, theta=0.0
% INFO    : Bus 2683	: V=0.997836, theta=-3.313818 -> V=1.0, theta=0.0
% INFO    : Bus 2684	: V=1.019875, theta=-37.557528 -> V=1.0, theta=0.0
% INFO    : Bus 2685	: V=1.010899, theta=-46.024063 -> V=1.0, theta=0.0
% INFO    : Bus 2686	: V=1.016926, theta=-43.107811 -> V=1.0, theta=0.0
% INFO    : Bus 2687	: V=0.999412, theta=-31.321582 -> V=1.0, theta=0.0
% INFO    : Bus 2688	: V=0.91444, theta=-35.99744 -> V=1.0, theta=0.0
% INFO    : Bus 2689	: V=1.029591, theta=-3.635667 -> V=1.0, theta=0.0
% INFO    : Bus 2690	: V=1.033725, theta=-25.74667 -> V=1.0, theta=0.0
% INFO    : Bus 2691	: V=1.00458, theta=-27.583723 -> V=1.0, theta=0.0
% INFO    : Bus 2692	: V=0.984603, theta=-54.826143 -> V=1.0, theta=0.0
% INFO    : Bus 2693	: V=1.035092, theta=-21.709891 -> V=1.0, theta=0.0
% INFO    : Bus 2694	: V=1.01873, theta=-45.679842 -> V=1.0, theta=0.0
% INFO    : Bus 2695	: V=1.035198, theta=-21.311735 -> V=1.0, theta=0.0
% INFO    : Bus 2696	: V=1.047114, theta=-29.542662 -> V=1.0, theta=0.0
% INFO    : Bus 2697	: V=0.997048, theta=-32.273639 -> V=1.0, theta=0.0
% INFO    : Bus 2698	: V=1.025059, theta=25.157021 -> V=1.0, theta=0.0
% INFO    : Bus 2699	: V=1.022844, theta=-33.862575 -> V=1.0, theta=0.0
% INFO    : Bus 2700	: V=1.032391, theta=-39.588219 -> V=1.0, theta=0.0
% INFO    : Bus 2701	: V=0.998514, theta=-36.87879 -> V=1.0, theta=0.0
% INFO    : Bus 2702	: V=1.038835, theta=-25.946279 -> V=1.0, theta=0.0
% INFO    : Bus 2703	: V=1.03322, theta=8.744635 -> V=1.0, theta=0.0
% INFO    : Bus 2704	: V=1.012671, theta=-38.95539 -> V=1.0, theta=0.0
% INFO    : Bus 2705	: V=1.015261, theta=8.941171 -> V=1.0, theta=0.0
% INFO    : Bus 2706	: V=0.998322, theta=-18.958592 -> V=1.0, theta=0.0
% INFO    : Bus 2707	: V=1.077199, theta=-18.620358 -> V=1.0, theta=0.0
% INFO    : Bus 2708	: V=1.020394, theta=-1.163142 -> V=1.0, theta=0.0
% INFO    : Bus 2709	: V=1.017832, theta=-46.73738 -> V=1.0, theta=0.0
% INFO    : Bus 2710	: V=1.035068, theta=-32.913136 -> V=1.0, theta=0.0
% INFO    : Bus 2711	: V=1.014654, theta=-4.23761 -> V=1.0, theta=0.0
% INFO    : Bus 2712	: V=1.0119, theta=5.624279 -> V=1.0, theta=0.0
% INFO    : Bus 2713	: V=0.985098, theta=-19.398169 -> V=1.0, theta=0.0
% INFO    : Bus 2714	: V=1.021979, theta=-28.207355 -> V=1.0, theta=0.0
% INFO    : Bus 2715	: V=1.039521, theta=-17.297222 -> V=1.0, theta=0.0
% INFO    : Bus 2716	: V=1.030728, theta=-23.553656 -> V=1.0, theta=0.0
% INFO    : Bus 2717	: V=1.051375, theta=-24.797832 -> V=1.0, theta=0.0
% INFO    : Bus 2718	: V=1.047495, theta=8.441712 -> V=1.0, theta=0.0
% INFO    : Bus 2719	: V=1.041789, theta=-15.262311 -> V=1.0, theta=0.0
% INFO    : Bus 2720	: V=1.017355, theta=17.213175 -> V=1.0, theta=0.0
% INFO    : Bus 2721	: V=0.970233, theta=-22.79896 -> V=1.0, theta=0.0
% INFO    : Bus 2722	: V=1.024193, theta=7.612357 -> V=1.0, theta=0.0
% INFO    : Bus 2723	: V=1.004169, theta=-14.384208 -> V=1.0, theta=0.0
% INFO    : Bus 2724	: V=1.028195, theta=9.110165 -> V=1.0, theta=0.0
% INFO    : Bus 2725	: V=1.014934, theta=-32.528518 -> V=1.0, theta=0.0
% INFO    : Bus 2726	: V=1.026411, theta=17.398129 -> V=1.0, theta=0.0
% INFO    : Bus 2727	: V=1.034724, theta=-23.021547 -> V=1.0, theta=0.0
% INFO    : Bus 2728	: V=1.040851, theta=25.722036 -> V=1.0, theta=0.0
% INFO    : Bus 2729	: V=1.050822, theta=-30.778243 -> V=1.0, theta=0.0
% INFO    : Bus 2730	: V=1.038131, theta=-44.171569 -> V=1.0, theta=0.0
% INFO    : Bus 2731	: V=0.951201, theta=-34.851087 -> V=1.0, theta=0.0
% INFO    : Bus 2732	: V=1.009988, theta=-10.274142 -> V=1.0, theta=0.0
% INFO    : Bus 2733	: V=0.990654, theta=-18.000787 -> V=1.0, theta=0.0
% INFO    : Bus 2734	: V=0.990417, theta=-48.424201 -> V=1.0, theta=0.0
% INFO    : Bus 2735	: V=1.024055, theta=-7.446564 -> V=1.0, theta=0.0
% INFO    : Bus 2736	: V=1.032664, theta=48.534354 -> V=1.0, theta=0.0
% INFO    : Bus 2737	: V=1.138972, theta=-24.417364 -> V=1.0, theta=0.0
% INFO    : Bus 2738	: V=0.991581, theta=-33.759111 -> V=1.0, theta=0.0
% INFO    : Bus 2739	: V=0.968155, theta=-32.370791 -> V=1.0, theta=0.0
% INFO    : Bus 2740	: V=1.024555, theta=-54.562835 -> V=1.0, theta=0.0
% INFO    : Bus 2741	: V=1.013219, theta=-10.342488 -> V=1.0, theta=0.0
% INFO    : Bus 2742	: V=1.058712, theta=-28.62346 -> V=1.0, theta=0.0
% INFO    : Bus 2743	: V=1.039467, theta=49.466963 -> V=1.0, theta=0.0
% INFO    : Bus 2744	: V=1.015437, theta=-23.030628 -> V=1.0, theta=0.0
% INFO    : Bus 2745	: V=1.024272, theta=-3.625612 -> V=1.0, theta=0.0
% INFO    : Bus 2746	: V=1.01238, theta=-10.587219 -> V=1.0, theta=0.0
% INFO    : Bus 2747	: V=1.021113, theta=-25.831255 -> V=1.0, theta=0.0
% INFO    : Bus 2748	: V=1.020283, theta=-4.093043 -> V=1.0, theta=0.0
% INFO    : Bus 2749	: V=1.032053, theta=-30.886187 -> V=1.0, theta=0.0
% INFO    : Bus 2750	: V=1.028659, theta=-21.464327 -> V=1.0, theta=0.0
% INFO    : Bus 2751	: V=1.038706, theta=-22.195411 -> V=1.0, theta=0.0
% INFO    : Bus 2752	: V=0.982719, theta=-28.541001 -> V=1.0, theta=0.0
% INFO    : Bus 2753	: V=0.938258, theta=-33.381368 -> V=1.0, theta=0.0
% INFO    : Bus 2754	: V=1.055002, theta=-13.426452 -> V=1.0, theta=0.0
% INFO    : Bus 2755	: V=1.026681, theta=-0.863624 -> V=1.0, theta=0.0
% INFO    : Bus 2756	: V=1.026317, theta=-15.932493 -> V=1.0, theta=0.0
% INFO    : Bus 2757	: V=0.977317, theta=-30.407805 -> V=1.0, theta=0.0
% INFO    : Bus 2758	: V=1.050098, theta=13.34262 -> V=1.0, theta=0.0
% INFO    : Bus 2759	: V=1.031458, theta=-3.483077 -> V=1.0, theta=0.0
% INFO    : Bus 2760	: V=1.026109, theta=4.108859 -> V=1.0, theta=0.0
% INFO    : Bus 2761	: V=1.031993, theta=-32.837218 -> V=1.0, theta=0.0
% INFO    : Bus 2762	: V=0.999792, theta=1.59613 -> V=1.0, theta=0.0
% INFO    : Bus 2763	: V=1.004992, theta=-28.810992 -> V=1.0, theta=0.0
% INFO    : Bus 2764	: V=1.045688, theta=-49.588961 -> V=1.0, theta=0.0
% INFO    : Bus 2765	: V=1.018043, theta=5.781934 -> V=1.0, theta=0.0
% INFO    : Bus 2766	: V=1.034573, theta=-37.389409 -> V=1.0, theta=0.0
% INFO    : Bus 2767	: V=0.98926, theta=-29.34769 -> V=1.0, theta=0.0
% INFO    : Bus 2768	: V=1.015763, theta=-7.408629 -> V=1.0, theta=0.0
% INFO    : Bus 2769	: V=1.022321, theta=25.504546 -> V=1.0, theta=0.0
% INFO    : Bus 2770	: V=1.043105, theta=-9.922486 -> V=1.0, theta=0.0
% INFO    : Bus 2771	: V=1.053762, theta=5.759052 -> V=1.0, theta=0.0
% INFO    : Bus 2772	: V=1.052122, theta=-31.311203 -> V=1.0, theta=0.0
% INFO    : Bus 2773	: V=0.982801, theta=-16.125592 -> V=1.0, theta=0.0
% INFO    : Bus 2774	: V=0.99937, theta=-26.805513 -> V=1.0, theta=0.0
% INFO    : Bus 2775	: V=1.024728, theta=-2.202138 -> V=1.0, theta=0.0
% INFO    : Bus 2776	: V=1.035688, theta=-25.116356 -> V=1.0, theta=0.0
% INFO    : Bus 2777	: V=1.055463, theta=-17.204768 -> V=1.0, theta=0.0
% INFO    : Bus 2778	: V=1.001273, theta=-31.157699 -> V=1.0, theta=0.0
% INFO    : Bus 2779	: V=0.93851, theta=-33.36495 -> V=1.0, theta=0.0
% INFO    : Bus 2780	: V=0.975698, theta=-27.577467 -> V=1.0, theta=0.0
% INFO    : Bus 2781	: V=0.994606, theta=-28.128704 -> V=1.0, theta=0.0
% INFO    : Bus 2782	: V=1.06541, theta=-11.831115 -> V=1.0, theta=0.0
% INFO    : Bus 2783	: V=0.96428, theta=-31.550888 -> V=1.0, theta=0.0
% INFO    : Bus 2784	: V=0.998791, theta=9.953837 -> V=1.0, theta=0.0
% INFO    : Bus 2785	: V=0.977375, theta=-50.459208 -> V=1.0, theta=0.0
% INFO    : Bus 2786	: V=1.078984, theta=6.21927 -> V=1.0, theta=0.0
% INFO    : Bus 2787	: V=1.004684, theta=8.971485 -> V=1.0, theta=0.0
% INFO    : Bus 2788	: V=1.011891, theta=20.397835 -> V=1.0, theta=0.0
% INFO    : Bus 2789	: V=0.991606, theta=-34.386656 -> V=1.0, theta=0.0
% INFO    : Bus 2790	: V=1.078102, theta=-18.667474 -> V=1.0, theta=0.0
% INFO    : Bus 2791	: V=1.015494, theta=-6.230119 -> V=1.0, theta=0.0
% INFO    : Bus 2792	: V=0.978902, theta=-28.402875 -> V=1.0, theta=0.0
% INFO    : Bus 2793	: V=1.029761, theta=-12.0953 -> V=1.0, theta=0.0
% INFO    : Bus 2794	: V=1.031591, theta=-18.751587 -> V=1.0, theta=0.0
% INFO    : Bus 2795	: V=1.065409, theta=-32.692499 -> V=1.0, theta=0.0
% INFO    : Bus 2796	: V=1.032648, theta=8.706417 -> V=1.0, theta=0.0
% INFO    : Bus 2797	: V=1.041702, theta=-4.550845 -> V=1.0, theta=0.0
% INFO    : Bus 2798	: V=0.998181, theta=-28.063947 -> V=1.0, theta=0.0
% INFO    : Bus 2799	: V=1.059752, theta=-12.774681 -> V=1.0, theta=0.0
% INFO    : Bus 2800	: V=1.02478, theta=-49.077869 -> V=1.0, theta=0.0
% INFO    : Bus 2801	: V=1.038595, theta=-24.830424 -> V=1.0, theta=0.0
% INFO    : Bus 2802	: V=0.996128, theta=-30.484678 -> V=1.0, theta=0.0
% INFO    : Bus 2803	: V=1.011048, theta=-36.660202 -> V=1.0, theta=0.0
% INFO    : Bus 2804	: V=1.024956, theta=12.196809 -> V=1.0, theta=0.0
% INFO    : Bus 2805	: V=1.03929, theta=-42.532182 -> V=1.0, theta=0.0
% INFO    : Bus 2806	: V=1.047179, theta=0.06827 -> V=1.0, theta=0.0
% INFO    : Bus 2807	: V=1.049225, theta=-15.943237 -> V=1.0, theta=0.0
% INFO    : Bus 2808	: V=1.004781, theta=-7.608827 -> V=1.0, theta=0.0
% INFO    : Bus 2809	: V=0.976442, theta=-43.345773 -> V=1.0, theta=0.0
% INFO    : Bus 2810	: V=1.036015, theta=10.886015 -> V=1.0, theta=0.0
% INFO    : Bus 2811	: V=1.016293, theta=-36.133941 -> V=1.0, theta=0.0
% INFO    : Bus 2812	: V=1.014703, theta=16.417772 -> V=1.0, theta=0.0
% INFO    : Bus 2813	: V=1.030804, theta=-20.424831 -> V=1.0, theta=0.0
% INFO    : Bus 2814	: V=1.083254, theta=-21.619172 -> V=1.0, theta=0.0
% INFO    : Bus 2815	: V=1.03261, theta=-23.33567 -> V=1.0, theta=0.0
% INFO    : Bus 2816	: V=1.049577, theta=-0.552935 -> V=1.0, theta=0.0
% INFO    : Bus 2817	: V=0.987457, theta=-46.749645 -> V=1.0, theta=0.0
% INFO    : Bus 2818	: V=1.020677, theta=-18.188454 -> V=1.0, theta=0.0
% INFO    : Bus 2819	: V=1.031706, theta=-40.994508 -> V=1.0, theta=0.0
% INFO    : Bus 2820	: V=0.990161, theta=-28.867672 -> V=1.0, theta=0.0
% INFO    : Bus 2821	: V=0.996239, theta=-50.859495 -> V=1.0, theta=0.0
% INFO    : Bus 2822	: V=1.020284, theta=-47.696189 -> V=1.0, theta=0.0
% INFO    : Bus 2823	: V=1.031745, theta=-34.063986 -> V=1.0, theta=0.0
% INFO    : Bus 2824	: V=1.027527, theta=17.039752 -> V=1.0, theta=0.0
% INFO    : Bus 2825	: V=1.027309, theta=-31.879944 -> V=1.0, theta=0.0
% INFO    : Bus 2826	: V=1.022551, theta=14.133547 -> V=1.0, theta=0.0
% INFO    : Bus 2827	: V=1.0311, theta=-0.969133 -> V=1.0, theta=0.0
% INFO    : Bus 2828	: V=0.991601, theta=-19.963847 -> V=1.0, theta=0.0
% INFO    : Bus 2829	: V=1.04606, theta=-39.53587 -> V=1.0, theta=0.0
% INFO    : Bus 2830	: V=0.962464, theta=-28.599476 -> V=1.0, theta=0.0
% INFO    : Bus 2831	: V=1.030661, theta=-28.268286 -> V=1.0, theta=0.0
% INFO    : Bus 2832	: V=1.017823, theta=11.708681 -> V=1.0, theta=0.0
% INFO    : Bus 2833	: V=1.00055, theta=-8.454266 -> V=1.0, theta=0.0
% INFO    : Bus 2834	: V=0.991996, theta=-17.769124 -> V=1.0, theta=0.0
% INFO    : Bus 2835	: V=1.043216, theta=-4.574191 -> V=1.0, theta=0.0
% INFO    : Bus 2836	: V=1.014779, theta=62.286835 -> V=1.0, theta=0.0
% INFO    : Bus 2837	: V=0.979638, theta=-37.172863 -> V=1.0, theta=0.0
% INFO    : Bus 2838	: V=0.975149, theta=-30.416337 -> V=1.0, theta=0.0
% INFO    : Bus 2839	: V=1.03617, theta=66.168864 -> V=1.0, theta=0.0
% INFO    : Bus 2840	: V=1.073314, theta=-23.976137 -> V=1.0, theta=0.0
% INFO    : Bus 2841	: V=1.080183, theta=-26.698323 -> V=1.0, theta=0.0
% INFO    : Bus 2842	: V=1.037135, theta=-6.862585 -> V=1.0, theta=0.0
% INFO    : Bus 2843	: V=0.977313, theta=-30.412799 -> V=1.0, theta=0.0
% INFO    : Bus 2844	: V=1.005585, theta=-46.599252 -> V=1.0, theta=0.0
% INFO    : Bus 2845	: V=0.988307, theta=-27.518793 -> V=1.0, theta=0.0
% INFO    : Bus 2846	: V=0.95674, theta=-20.143962 -> V=1.0, theta=0.0
% INFO    : Bus 2847	: V=1.048491, theta=-4.163013 -> V=1.0, theta=0.0
% INFO    : Bus 2848	: V=0.992888, theta=-8.120882 -> V=1.0, theta=0.0
% INFO    : Bus 2849	: V=1.033309, theta=-43.152205 -> V=1.0, theta=0.0
% INFO    : Bus 2850	: V=1.030813, theta=-18.975096 -> V=1.0, theta=0.0
% INFO    : Bus 2851	: V=1.01491, theta=-29.563895 -> V=1.0, theta=0.0
% INFO    : Bus 2852	: V=1.063812, theta=55.043975 -> V=1.0, theta=0.0
% INFO    : Bus 2853	: V=0.998154, theta=-36.333293 -> V=1.0, theta=0.0
% INFO    : Bus 2854	: V=1.045263, theta=-11.049115 -> V=1.0, theta=0.0
% INFO    : Bus 2855	: V=1.091144, theta=-19.374171 -> V=1.0, theta=0.0
% INFO    : Bus 2856	: V=0.971505, theta=-27.269578 -> V=1.0, theta=0.0
% INFO    : Bus 2857	: V=0.989308, theta=-21.617076 -> V=1.0, theta=0.0
% INFO    : Bus 2858	: V=1.012613, theta=-22.000892 -> V=1.0, theta=0.0
% INFO    : Bus 2859	: V=0.953125, theta=-33.534205 -> V=1.0, theta=0.0
% INFO    : Bus 2860	: V=1.003452, theta=-31.424496 -> V=1.0, theta=0.0
% INFO    : Bus 2861	: V=1.007288, theta=-31.886508 -> V=1.0, theta=0.0
% INFO    : Bus 2862	: V=1.027949, theta=-8.633574 -> V=1.0, theta=0.0
% INFO    : Bus 2863	: V=1.029675, theta=-11.102464 -> V=1.0, theta=0.0
% INFO    : Bus 2864	: V=0.988359, theta=-31.358077 -> V=1.0, theta=0.0
% INFO    : Bus 2865	: V=1.037073, theta=-21.986951 -> V=1.0, theta=0.0
% INFO    : Bus 2866	: V=1.031218, theta=-7.49201 -> V=1.0, theta=0.0
% INFO    : Bus 2867	: V=1.047385, theta=-21.683087 -> V=1.0, theta=0.0
% INFO    : Bus 2868	: V=1.030278, theta=-10.667649 -> V=1.0, theta=0.0
% INFO    : Bus 2869	: V=1.133869, theta=-22.192198 -> V=1.0, theta=0.0
% INFO    : Bus 2870	: V=1.018031, theta=4.736975 -> V=1.0, theta=0.0
% INFO    : Bus 2871	: V=1.01203, theta=-49.019171 -> V=1.0, theta=0.0
% INFO    : Bus 2872	: V=1.054344, theta=-11.000358 -> V=1.0, theta=0.0
% INFO    : Bus 2873	: V=1.085818, theta=-36.683985 -> V=1.0, theta=0.0
% INFO    : Bus 2874	: V=1.006921, theta=6.527903 -> V=1.0, theta=0.0
% INFO    : Bus 2875	: V=1.040036, theta=-39.699982 -> V=1.0, theta=0.0
% INFO    : Bus 2876	: V=1.043966, theta=-30.135632 -> V=1.0, theta=0.0
% INFO    : Bus 2877	: V=1.03854, theta=-15.020325 -> V=1.0, theta=0.0
% INFO    : Bus 2878	: V=1.047923, theta=-11.279115 -> V=1.0, theta=0.0
% INFO    : Bus 2879	: V=1.040681, theta=-8.793401 -> V=1.0, theta=0.0
% INFO    : Bus 2880	: V=0.999267, theta=-50.029004 -> V=1.0, theta=0.0
% INFO    : Bus 2881	: V=1.024879, theta=5.732448 -> V=1.0, theta=0.0
% INFO    : Bus 2882	: V=0.990424, theta=-28.476946 -> V=1.0, theta=0.0
% INFO    : Bus 2883	: V=1.027049, theta=-12.837 -> V=1.0, theta=0.0
% INFO    : Bus 2884	: V=1.021727, theta=-38.978171 -> V=1.0, theta=0.0
% INFO    : Bus 2885	: V=1.092743, theta=-27.783251 -> V=1.0, theta=0.0
% INFO    : Bus 2886	: V=1.057004, theta=-14.159417 -> V=1.0, theta=0.0
% INFO    : Bus 2887	: V=1.014384, theta=-42.141546 -> V=1.0, theta=0.0
% INFO    : Bus 2888	: V=1.008512, theta=-21.614525 -> V=1.0, theta=0.0
% INFO    : Bus 2889	: V=1.048889, theta=-1.184833 -> V=1.0, theta=0.0
% INFO    : Bus 2890	: V=1.049854, theta=-8.204924 -> V=1.0, theta=0.0
% INFO    : Bus 2891	: V=1.00994, theta=0.65866 -> V=1.0, theta=0.0
% INFO    : Bus 2892	: V=1.107563, theta=-16.256154 -> V=1.0, theta=0.0
% INFO    : Bus 2893	: V=0.994768, theta=-33.816686 -> V=1.0, theta=0.0
% INFO    : Bus 2894	: V=0.999263, theta=-39.177231 -> V=1.0, theta=0.0
% INFO    : Bus 2895	: V=1.015901, theta=-14.604545 -> V=1.0, theta=0.0
% INFO    : Bus 2896	: V=1.009058, theta=-44.759958 -> V=1.0, theta=0.0
% INFO    : Bus 2897	: V=1.079272, theta=-21.14894 -> V=1.0, theta=0.0
% INFO    : Bus 2898	: V=1.031918, theta=-23.422434 -> V=1.0, theta=0.0
% INFO    : Bus 2899	: V=1.051592, theta=-45.108007 -> V=1.0, theta=0.0
% INFO    : Bus 2900	: V=1.04402, theta=3.726033 -> V=1.0, theta=0.0
% INFO    : Bus 2901	: V=1.026238, theta=-16.034962 -> V=1.0, theta=0.0
% INFO    : Bus 2902	: V=1.069, theta=-23.903912 -> V=1.0, theta=0.0
% INFO    : Bus 2903	: V=0.984771, theta=7.428385 -> V=1.0, theta=0.0
% INFO    : Bus 2904	: V=1.078809, theta=-15.204432 -> V=1.0, theta=0.0
% INFO    : Bus 2905	: V=1.013927, theta=-36.121069 -> V=1.0, theta=0.0
% INFO    : Bus 2906	: V=1.022345, theta=-10.578895 -> V=1.0, theta=0.0
% INFO    : Bus 2907	: V=1.021017, theta=-48.745448 -> V=1.0, theta=0.0
% INFO    : Bus 2908	: V=1.020421, theta=-10.96388 -> V=1.0, theta=0.0
% INFO    : Bus 2909	: V=1.016841, theta=-36.283483 -> V=1.0, theta=0.0
% INFO    : Bus 2910	: V=1.036477, theta=-2.654621 -> V=1.0, theta=0.0
% INFO    : Bus 2911	: V=1.026114, theta=-34.141297 -> V=1.0, theta=0.0
% INFO    : Bus 2912	: V=1.034581, theta=39.039067 -> V=1.0, theta=0.0
% INFO    : Bus 2913	: V=1.062326, theta=-42.065477 -> V=1.0, theta=0.0
% INFO    : Bus 2914	: V=1.001622, theta=-31.241205 -> V=1.0, theta=0.0
% INFO    : Bus 2915	: V=0.999553, theta=-27.968035 -> V=1.0, theta=0.0
% INFO    : Bus 2916	: V=1.047375, theta=-38.507533 -> V=1.0, theta=0.0
% INFO    : Bus 2917	: V=1.021158, theta=-47.142434 -> V=1.0, theta=0.0
% INFO    : Bus 2918	: V=1.015176, theta=-28.547308 -> V=1.0, theta=0.0
% INFO    : Bus 2919	: V=0.987081, theta=-18.615623 -> V=1.0, theta=0.0
% INFO    : Bus 2920	: V=1.036969, theta=-37.703704 -> V=1.0, theta=0.0
% INFO    : Bus 2921	: V=1.006267, theta=-40.895161 -> V=1.0, theta=0.0
% INFO    : Bus 2922	: V=1.079186, theta=-24.897557 -> V=1.0, theta=0.0
% INFO    : Bus 2923	: V=1.040379, theta=-41.959629 -> V=1.0, theta=0.0
% INFO    : Bus 2924	: V=1.035974, theta=-34.013211 -> V=1.0, theta=0.0
% INFO    : Bus 2925	: V=1.02447, theta=-26.749332 -> V=1.0, theta=0.0
% INFO    : Bus 2926	: V=1.044436, theta=-19.423255 -> V=1.0, theta=0.0
% INFO    : Bus 2927	: V=1.047894, theta=17.850304 -> V=1.0, theta=0.0
% INFO    : Bus 2928	: V=1.068841, theta=-26.733551 -> V=1.0, theta=0.0
% INFO    : Bus 2929	: V=1.045999, theta=-29.589377 -> V=1.0, theta=0.0
% INFO    : Bus 2930	: V=1.054065, theta=-13.329734 -> V=1.0, theta=0.0
% INFO    : Bus 2931	: V=1.040596, theta=-32.581614 -> V=1.0, theta=0.0
% INFO    : Bus 2932	: V=1.054877, theta=17.294612 -> V=1.0, theta=0.0
% INFO    : Bus 2933	: V=1.054733, theta=-33.13248 -> V=1.0, theta=0.0
% INFO    : Bus 2934	: V=1.049297, theta=-6.587965 -> V=1.0, theta=0.0
% INFO    : Bus 2935	: V=1.085479, theta=-16.581927 -> V=1.0, theta=0.0
% INFO    : Bus 2936	: V=1.064112, theta=-23.309406 -> V=1.0, theta=0.0
% INFO    : Bus 2937	: V=0.944097, theta=-22.244519 -> V=1.0, theta=0.0
% INFO    : Bus 2938	: V=1.001021, theta=-7.705453 -> V=1.0, theta=0.0
% INFO    : Bus 2939	: V=1.043126, theta=-25.836237 -> V=1.0, theta=0.0
% INFO    : Bus 2940	: V=1.011603, theta=-14.637485 -> V=1.0, theta=0.0
% INFO    : Bus 2941	: V=1.061091, theta=-35.525707 -> V=1.0, theta=0.0
% INFO    : Bus 2942	: V=1.049098, theta=-16.466845 -> V=1.0, theta=0.0
% INFO    : Bus 2943	: V=0.956647, theta=-31.595848 -> V=1.0, theta=0.0
% INFO    : Bus 2944	: V=1.0151, theta=6.183297 -> V=1.0, theta=0.0
% INFO    : Bus 2945	: V=1.013102, theta=-33.068927 -> V=1.0, theta=0.0
% INFO    : Bus 2946	: V=1.012911, theta=-46.294974 -> V=1.0, theta=0.0
% INFO    : Bus 2947	: V=1.057374, theta=-25.784371 -> V=1.0, theta=0.0
% INFO    : Bus 2948	: V=1.03412, theta=-0.509094 -> V=1.0, theta=0.0
% INFO    : Bus 2949	: V=1.043611, theta=-5.024372 -> V=1.0, theta=0.0
% INFO    : Bus 2950	: V=1.07764, theta=-22.720407 -> V=1.0, theta=0.0
% INFO    : Bus 2951	: V=1.008726, theta=-54.443403 -> V=1.0, theta=0.0
% INFO    : Bus 2952	: V=1.008174, theta=-1.804058 -> V=1.0, theta=0.0
% INFO    : Bus 2953	: V=1.008824, theta=-32.768968 -> V=1.0, theta=0.0
% INFO    : Bus 2954	: V=0.984971, theta=-56.456146 -> V=1.0, theta=0.0
% INFO    : Bus 2955	: V=1.029208, theta=-20.116623 -> V=1.0, theta=0.0
% INFO    : Bus 2956	: V=1.032523, theta=-11.250517 -> V=1.0, theta=0.0
% INFO    : Bus 2957	: V=1.02001, theta=-39.361605 -> V=1.0, theta=0.0
% INFO    : Bus 2958	: V=1.011738, theta=-39.294638 -> V=1.0, theta=0.0
% INFO    : Bus 2959	: V=1.003446, theta=-21.373326 -> V=1.0, theta=0.0
% INFO    : Bus 2960	: V=0.991571, theta=-23.778785 -> V=1.0, theta=0.0
% INFO    : Bus 2961	: V=1.03879, theta=-24.714825 -> V=1.0, theta=0.0
% INFO    : Bus 2962	: V=1.061514, theta=-43.047139 -> V=1.0, theta=0.0
% INFO    : Bus 2963	: V=1.034488, theta=-24.679438 -> V=1.0, theta=0.0
% INFO    : Bus 2964	: V=1.002355, theta=-30.878774 -> V=1.0, theta=0.0
% INFO    : Bus 2965	: V=1.032633, theta=17.696999 -> V=1.0, theta=0.0
% INFO    : Bus 2966	: V=0.965485, theta=-25.299972 -> V=1.0, theta=0.0
% INFO    : Bus 2967	: V=1.048781, theta=-17.081495 -> V=1.0, theta=0.0
% INFO    : Bus 2968	: V=1.040217, theta=-9.191608 -> V=1.0, theta=0.0
% INFO    : Bus 2969	: V=1.033558, theta=-34.216418 -> V=1.0, theta=0.0
% INFO    : Bus 2970	: V=1.025839, theta=-24.861508 -> V=1.0, theta=0.0
% INFO    : Bus 2971	: V=0.987575, theta=-6.33598 -> V=1.0, theta=0.0
% INFO    : Bus 2972	: V=1.041103, theta=-15.150263 -> V=1.0, theta=0.0
% INFO    : Bus 2973	: V=1.088757, theta=7.127899 -> V=1.0, theta=0.0
% INFO    : Bus 2974	: V=1.02475, theta=-2.696229 -> V=1.0, theta=0.0
% INFO    : Bus 2975	: V=1.03823, theta=-33.552254 -> V=1.0, theta=0.0
% INFO    : Bus 2976	: V=0.987069, theta=-31.650843 -> V=1.0, theta=0.0
% INFO    : Bus 2977	: V=0.992153, theta=-31.495485 -> V=1.0, theta=0.0
% INFO    : Bus 2978	: V=1.022192, theta=-48.811885 -> V=1.0, theta=0.0
% INFO    : Bus 2979	: V=1.022074, theta=6.277637 -> V=1.0, theta=0.0
% INFO    : Bus 2980	: V=1.057858, theta=-9.33132 -> V=1.0, theta=0.0
% INFO    : Bus 2981	: V=1.070326, theta=-15.59772 -> V=1.0, theta=0.0
% INFO    : Bus 2982	: V=1.020472, theta=-26.26597 -> V=1.0, theta=0.0
% INFO    : Bus 2983	: V=0.996013, theta=-18.679169 -> V=1.0, theta=0.0
% INFO    : Bus 2984	: V=0.979502, theta=-28.268969 -> V=1.0, theta=0.0
% INFO    : Bus 2985	: V=1.046452, theta=-8.853706 -> V=1.0, theta=0.0
% INFO    : Bus 2986	: V=1.049678, theta=-30.353615 -> V=1.0, theta=0.0
% INFO    : Bus 2987	: V=1.060068, theta=-13.245919 -> V=1.0, theta=0.0
% INFO    : Bus 2988	: V=0.985971, theta=-33.277396 -> V=1.0, theta=0.0
% INFO    : Bus 2989	: V=1.066576, theta=-9.028732 -> V=1.0, theta=0.0
% INFO    : Bus 2990	: V=1.036355, theta=8.130253 -> V=1.0, theta=0.0
% INFO    : Bus 2991	: V=0.849692, theta=-39.840933 -> V=1.0, theta=0.0
% INFO    : Bus 2992	: V=1.104121, theta=-28.617369 -> V=1.0, theta=0.0
% INFO    : Bus 2993	: V=0.961041, theta=-29.937601 -> V=1.0, theta=0.0
% INFO    : Bus 2994	: V=1.026577, theta=-34.598751 -> V=1.0, theta=0.0
% INFO    : Bus 2995	: V=1.05007, theta=-3.99566 -> V=1.0, theta=0.0
% INFO    : Bus 2996	: V=0.992457, theta=-17.729497 -> V=1.0, theta=0.0
% INFO    : Bus 2997	: V=1.089588, theta=11.337758 -> V=1.0, theta=0.0
% INFO    : Bus 2998	: V=1.026711, theta=-18.1185 -> V=1.0, theta=0.0
% INFO    : Bus 2999	: V=1.009359, theta=-7.569742 -> V=1.0, theta=0.0
% INFO    : Bus 3000	: V=1.016633, theta=14.476175 -> V=1.0, theta=0.0
% INFO    : Bus 3001	: V=1.038947, theta=0.573036 -> V=1.0, theta=0.0
% INFO    : Bus 3002	: V=1.015981, theta=-4.196438 -> V=1.0, theta=0.0
% INFO    : Bus 3003	: V=1.048371, theta=4.644305 -> V=1.0, theta=0.0
% INFO    : Bus 3004	: V=1.049384, theta=-22.134337 -> V=1.0, theta=0.0
% INFO    : Bus 3005	: V=1.034768, theta=-8.954997 -> V=1.0, theta=0.0
% INFO    : Bus 3006	: V=1.02229, theta=-9.808214 -> V=1.0, theta=0.0
% INFO    : Bus 3007	: V=1.026831, theta=-52.43662 -> V=1.0, theta=0.0
% INFO    : Bus 3008	: V=1.015578, theta=-46.572417 -> V=1.0, theta=0.0
% INFO    : Bus 3009	: V=1.016186, theta=60.721526 -> V=1.0, theta=0.0
% INFO    : Bus 3010	: V=0.997745, theta=-37.019205 -> V=1.0, theta=0.0
% INFO    : Bus 3011	: V=0.932629, theta=-36.806773 -> V=1.0, theta=0.0
% INFO    : Bus 3012	: V=1.045286, theta=-6.147845 -> V=1.0, theta=0.0
% INFO    : Bus 3013	: V=1.042921, theta=-5.434538 -> V=1.0, theta=0.0
% INFO    : Bus 3014	: V=1.065098, theta=-23.02092 -> V=1.0, theta=0.0
% INFO    : Bus 3015	: V=1.029181, theta=-6.402962 -> V=1.0, theta=0.0
% INFO    : Bus 3016	: V=1.029637, theta=-26.416748 -> V=1.0, theta=0.0
% INFO    : Bus 3017	: V=1.073135, theta=-26.089398 -> V=1.0, theta=0.0
% INFO    : Bus 3018	: V=1.049496, theta=-13.234142 -> V=1.0, theta=0.0
% INFO    : Bus 3019	: V=1.032865, theta=-23.112666 -> V=1.0, theta=0.0
% INFO    : Bus 3020	: V=1.026507, theta=-40.896191 -> V=1.0, theta=0.0
% INFO    : Bus 3021	: V=1.037061, theta=-11.750342 -> V=1.0, theta=0.0
% INFO    : Bus 3022	: V=1.035342, theta=-15.176209 -> V=1.0, theta=0.0
% INFO    : Bus 3023	: V=1.009179, theta=8.109483 -> V=1.0, theta=0.0
% INFO    : Bus 3024	: V=1.00813, theta=-35.11709 -> V=1.0, theta=0.0
% INFO    : Bus 3025	: V=1.037826, theta=-20.011046 -> V=1.0, theta=0.0
% INFO    : Bus 3026	: V=0.990606, theta=-31.511948 -> V=1.0, theta=0.0
% INFO    : Bus 3027	: V=1.025585, theta=-53.810418 -> V=1.0, theta=0.0
% INFO    : Bus 3028	: V=1.02789, theta=0.312117 -> V=1.0, theta=0.0
% INFO    : Bus 3029	: V=1.011669, theta=-24.036628 -> V=1.0, theta=0.0
% INFO    : Bus 3030	: V=0.955245, theta=-31.245551 -> V=1.0, theta=0.0
% INFO    : Bus 3031	: V=1.002742, theta=-30.544865 -> V=1.0, theta=0.0
% INFO    : Bus 3032	: V=1.03482, theta=8.756423 -> V=1.0, theta=0.0
% INFO    : Bus 3033	: V=0.995509, theta=-27.246275 -> V=1.0, theta=0.0
% INFO    : Bus 3034	: V=0.99031, theta=-21.392171 -> V=1.0, theta=0.0
% INFO    : Bus 3035	: V=1.0405, theta=-44.417652 -> V=1.0, theta=0.0
% INFO    : Bus 3036	: V=1.042421, theta=-25.50891 -> V=1.0, theta=0.0
% INFO    : Bus 3037	: V=1.046509, theta=-6.795112 -> V=1.0, theta=0.0
% INFO    : Bus 3038	: V=1.041581, theta=11.016318 -> V=1.0, theta=0.0
% INFO    : Bus 3039	: V=1.027247, theta=-13.246536 -> V=1.0, theta=0.0
% INFO    : Bus 3040	: V=0.964351, theta=-31.543421 -> V=1.0, theta=0.0
% INFO    : Bus 3041	: V=1.051796, theta=-17.803926 -> V=1.0, theta=0.0
% INFO    : Bus 3042	: V=1.033591, theta=-24.386253 -> V=1.0, theta=0.0
% INFO    : Bus 3043	: V=0.988359, theta=-26.324046 -> V=1.0, theta=0.0
% INFO    : Bus 3044	: V=1.034203, theta=-21.502172 -> V=1.0, theta=0.0
% INFO    : Bus 3045	: V=1.015762, theta=-21.786592 -> V=1.0, theta=0.0
% INFO    : Bus 3046	: V=1.001737, theta=-33.665913 -> V=1.0, theta=0.0
% INFO    : Bus 3047	: V=1.020996, theta=2.361043 -> V=1.0, theta=0.0
% INFO    : Bus 3048	: V=1.036371, theta=-29.916545 -> V=1.0, theta=0.0
% INFO    : Bus 3049	: V=1.055171, theta=-29.298676 -> V=1.0, theta=0.0
% INFO    : Bus 3050	: V=1.069212, theta=-16.749495 -> V=1.0, theta=0.0
% INFO    : Bus 3051	: V=1.033036, theta=-25.366125 -> V=1.0, theta=0.0
% INFO    : Bus 3052	: V=1.026583, theta=2.770976 -> V=1.0, theta=0.0
% INFO    : Bus 3053	: V=1.026793, theta=-26.97167 -> V=1.0, theta=0.0
% INFO    : Bus 3054	: V=0.995142, theta=-52.008983 -> V=1.0, theta=0.0
% INFO    : Bus 3055	: V=1.032793, theta=12.002819 -> V=1.0, theta=0.0
% INFO    : Bus 3056	: V=1.129011, theta=-23.483011 -> V=1.0, theta=0.0
% INFO    : Bus 3057	: V=1.103456, theta=43.57667 -> V=1.0, theta=0.0
% INFO    : Bus 3058	: V=1.009579, theta=-5.065324 -> V=1.0, theta=0.0
% INFO    : Bus 3059	: V=1.012119, theta=-24.291729 -> V=1.0, theta=0.0
% INFO    : Bus 3060	: V=0.969256, theta=-26.685103 -> V=1.0, theta=0.0
% INFO    : Bus 3061	: V=1.028742, theta=-48.459328 -> V=1.0, theta=0.0
% INFO    : Bus 3062	: V=1.038916, theta=-11.177215 -> V=1.0, theta=0.0
% INFO    : Bus 3063	: V=1.009389, theta=-45.957702 -> V=1.0, theta=0.0
% INFO    : Bus 3064	: V=1.022454, theta=6.290456 -> V=1.0, theta=0.0
% INFO    : Bus 3065	: V=1.022689, theta=-54.937831 -> V=1.0, theta=0.0
% INFO    : Bus 3066	: V=1.023701, theta=-54.698384 -> V=1.0, theta=0.0
% INFO    : Bus 3067	: V=1.023558, theta=-42.498692 -> V=1.0, theta=0.0
% INFO    : Bus 3068	: V=1.014253, theta=-48.193733 -> V=1.0, theta=0.0
% INFO    : Bus 3069	: V=1.031548, theta=-8.816262 -> V=1.0, theta=0.0
% INFO    : Bus 3070	: V=1.008506, theta=-21.61448 -> V=1.0, theta=0.0
% INFO    : Bus 3071	: V=1.043171, theta=-7.35147 -> V=1.0, theta=0.0
% INFO    : Bus 3072	: V=1.032815, theta=-30.857548 -> V=1.0, theta=0.0
% INFO    : Bus 3073	: V=1.036802, theta=-23.378769 -> V=1.0, theta=0.0
% INFO    : Bus 3074	: V=1.013258, theta=-31.770181 -> V=1.0, theta=0.0
% INFO    : Bus 3075	: V=1.018015, theta=-17.076837 -> V=1.0, theta=0.0
% INFO    : Bus 3076	: V=1.008645, theta=-48.288192 -> V=1.0, theta=0.0
% INFO    : Bus 3077	: V=1.002162, theta=-19.016337 -> V=1.0, theta=0.0
% INFO    : Bus 3078	: V=1.024108, theta=-28.323701 -> V=1.0, theta=0.0
% INFO    : Bus 3079	: V=0.957868, theta=-22.853426 -> V=1.0, theta=0.0
% INFO    : Bus 3080	: V=1.059423, theta=-47.950493 -> V=1.0, theta=0.0
% INFO    : Bus 3081	: V=1.079373, theta=-22.093837 -> V=1.0, theta=0.0
% INFO    : Bus 3082	: V=0.995759, theta=-15.36659 -> V=1.0, theta=0.0
% INFO    : Bus 3083	: V=1.065475, theta=-27.933024 -> V=1.0, theta=0.0
% INFO    : Bus 3084	: V=1.042602, theta=0.578717 -> V=1.0, theta=0.0
% INFO    : Bus 3085	: V=1.0643, theta=-27.989896 -> V=1.0, theta=0.0
% INFO    : Bus 3086	: V=1.001534, theta=-31.139027 -> V=1.0, theta=0.0
% INFO    : Bus 3087	: V=1.015735, theta=-38.890869 -> V=1.0, theta=0.0
% INFO    : Bus 3088	: V=1.043452, theta=-13.261837 -> V=1.0, theta=0.0
% INFO    : Bus 3089	: V=1.022413, theta=-34.775191 -> V=1.0, theta=0.0
% INFO    : Bus 3090	: V=1.003861, theta=-8.868521 -> V=1.0, theta=0.0
% INFO    : Bus 3091	: V=1.021666, theta=-5.352923 -> V=1.0, theta=0.0
% INFO    : Bus 3092	: V=1.016073, theta=-40.204318 -> V=1.0, theta=0.0
% INFO    : Bus 3093	: V=1.04636, theta=-31.97867 -> V=1.0, theta=0.0
% INFO    : Bus 3094	: V=1.061022, theta=-18.293025 -> V=1.0, theta=0.0
% INFO    : Bus 3095	: V=1.00647, theta=-54.688448 -> V=1.0, theta=0.0
% INFO    : Bus 3096	: V=1.008864, theta=-5.774957 -> V=1.0, theta=0.0
% INFO    : Bus 3097	: V=1.01882, theta=4.182018 -> V=1.0, theta=0.0
% INFO    : Bus 3098	: V=1.015846, theta=-32.549429 -> V=1.0, theta=0.0
% INFO    : Bus 3099	: V=1.038121, theta=-27.474863 -> V=1.0, theta=0.0
% INFO    : Bus 3100	: V=1.009767, theta=-30.858281 -> V=1.0, theta=0.0
% INFO    : Bus 3101	: V=1.024102, theta=-28.059188 -> V=1.0, theta=0.0
% INFO    : Bus 3102	: V=1.030087, theta=11.006241 -> V=1.0, theta=0.0
% INFO    : Bus 3103	: V=1.058579, theta=-23.210274 -> V=1.0, theta=0.0
% INFO    : Bus 3104	: V=1.034098, theta=-26.275271 -> V=1.0, theta=0.0
% INFO    : Bus 3105	: V=1.014062, theta=-36.909489 -> V=1.0, theta=0.0
% INFO    : Bus 3106	: V=1.048498, theta=-45.743612 -> V=1.0, theta=0.0
% INFO    : Bus 3107	: V=1.039794, theta=-3.280428 -> V=1.0, theta=0.0
% INFO    : Bus 3108	: V=1.015489, theta=-30.06294 -> V=1.0, theta=0.0
% INFO    : Bus 3109	: V=1.016108, theta=-43.007828 -> V=1.0, theta=0.0
% INFO    : Bus 3110	: V=1.052047, theta=15.39943 -> V=1.0, theta=0.0
% INFO    : Bus 3111	: V=1.030818, theta=-42.746869 -> V=1.0, theta=0.0
% INFO    : Bus 3112	: V=1.051067, theta=2.324898 -> V=1.0, theta=0.0
% INFO    : Bus 3113	: V=1.064513, theta=-38.339894 -> V=1.0, theta=0.0
% INFO    : Bus 3114	: V=1.063117, theta=-12.151193 -> V=1.0, theta=0.0
% INFO    : Bus 3115	: V=1.082739, theta=-15.213748 -> V=1.0, theta=0.0
% INFO    : Bus 3116	: V=1.026615, theta=-0.863273 -> V=1.0, theta=0.0
% INFO    : Bus 3117	: V=1.046412, theta=-22.334303 -> V=1.0, theta=0.0
% INFO    : Bus 3118	: V=1.008613, theta=36.846475 -> V=1.0, theta=0.0
% INFO    : Bus 3119	: V=1.023437, theta=8.989266 -> V=1.0, theta=0.0
% INFO    : Bus 3120	: V=1.063948, theta=-22.743998 -> V=1.0, theta=0.0
% INFO    : Bus 3121	: V=1.024619, theta=-7.433164 -> V=1.0, theta=0.0
% INFO    : Bus 3122	: V=0.969759, theta=-32.190343 -> V=1.0, theta=0.0
% INFO    : Bus 3123	: V=1.032457, theta=-21.310663 -> V=1.0, theta=0.0
% INFO    : Bus 3124	: V=1.036819, theta=-23.850146 -> V=1.0, theta=0.0
% INFO    : Bus 3125	: V=1.015575, theta=-40.39929 -> V=1.0, theta=0.0
% INFO    : Bus 3126	: V=1.017916, theta=-18.019007 -> V=1.0, theta=0.0
% INFO    : Bus 3127	: V=1.097365, theta=54.206958 -> V=1.0, theta=0.0
% INFO    : Bus 3128	: V=0.989103, theta=-20.887239 -> V=1.0, theta=0.0
% INFO    : Bus 3129	: V=0.929883, theta=-30.326449 -> V=1.0, theta=0.0
% INFO    : Bus 3130	: V=1.038694, theta=-20.722363 -> V=1.0, theta=0.0
% INFO    : Bus 3131	: V=0.969995, theta=-34.069945 -> V=1.0, theta=0.0
% INFO    : Bus 3132	: V=0.995803, theta=-20.666157 -> V=1.0, theta=0.0
% INFO    : Bus 3133	: V=1.05743, theta=-9.623166 -> V=1.0, theta=0.0
% INFO    : Bus 3134	: V=1.034426, theta=-16.117435 -> V=1.0, theta=0.0
% INFO    : Bus 3135	: V=1.03216, theta=-23.565566 -> V=1.0, theta=0.0
% INFO    : Bus 3136	: V=1.018401, theta=-29.010141 -> V=1.0, theta=0.0
% INFO    : Bus 3137	: V=1.057467, theta=-26.432569 -> V=1.0, theta=0.0
% INFO    : Bus 3138	: V=1.013801, theta=-26.606601 -> V=1.0, theta=0.0
% INFO    : Bus 3139	: V=1.023174, theta=-26.038202 -> V=1.0, theta=0.0
% INFO    : Bus 3140	: V=1.040626, theta=-21.081939 -> V=1.0, theta=0.0
% INFO    : Bus 3141	: V=1.048468, theta=-25.314747 -> V=1.0, theta=0.0
% INFO    : Bus 3142	: V=1.069389, theta=-22.616678 -> V=1.0, theta=0.0
% INFO    : Bus 3143	: V=1.034924, theta=-25.024397 -> V=1.0, theta=0.0
% INFO    : Bus 3144	: V=1.024183, theta=-25.753432 -> V=1.0, theta=0.0
% INFO    : Bus 3145	: V=0.980241, theta=-41.867779 -> V=1.0, theta=0.0
% INFO    : Bus 3146	: V=1.125942, theta=-22.906239 -> V=1.0, theta=0.0
% INFO    : Bus 3147	: V=1.063849, theta=20.694081 -> V=1.0, theta=0.0
% INFO    : Bus 3148	: V=1.040818, theta=3.328266 -> V=1.0, theta=0.0
% INFO    : Bus 3149	: V=1.021578, theta=19.129883 -> V=1.0, theta=0.0
% INFO    : Bus 3150	: V=1.010317, theta=-48.620794 -> V=1.0, theta=0.0
% INFO    : Bus 3151	: V=1.045167, theta=-22.631971 -> V=1.0, theta=0.0
% INFO    : Bus 3152	: V=1.069675, theta=-20.967243 -> V=1.0, theta=0.0
% INFO    : Bus 3153	: V=0.997269, theta=-20.527634 -> V=1.0, theta=0.0
% INFO    : Bus 3154	: V=0.941134, theta=-34.246158 -> V=1.0, theta=0.0
% INFO    : Bus 3155	: V=1.002319, theta=-0.228436 -> V=1.0, theta=0.0
% INFO    : Bus 3156	: V=1.024848, theta=-6.484438 -> V=1.0, theta=0.0
% INFO    : Bus 3157	: V=1.021742, theta=-38.172815 -> V=1.0, theta=0.0
% INFO    : Bus 3158	: V=1.058123, theta=63.8325 -> V=1.0, theta=0.0
% INFO    : Bus 3159	: V=1.032151, theta=-20.96825 -> V=1.0, theta=0.0
% INFO    : Bus 3160	: V=1.046099, theta=12.386083 -> V=1.0, theta=0.0
% INFO    : Bus 3161	: V=0.994233, theta=-25.746094 -> V=1.0, theta=0.0
% INFO    : Bus 3162	: V=1.015917, theta=-23.585985 -> V=1.0, theta=0.0
% INFO    : Bus 3163	: V=1.002654, theta=-47.833185 -> V=1.0, theta=0.0
% INFO    : Bus 3164	: V=1.015087, theta=-4.216597 -> V=1.0, theta=0.0
% INFO    : Bus 3165	: V=1.018334, theta=-32.142815 -> V=1.0, theta=0.0
% INFO    : Bus 3166	: V=1.037728, theta=-17.809451 -> V=1.0, theta=0.0
% INFO    : Bus 3167	: V=1.026051, theta=-34.57357 -> V=1.0, theta=0.0
% INFO    : Bus 3168	: V=1.019, theta=-22.376658 -> V=1.0, theta=0.0
% INFO    : Bus 3169	: V=1.032824, theta=3.573787 -> V=1.0, theta=0.0
% INFO    : Bus 3170	: V=0.986731, theta=-45.275791 -> V=1.0, theta=0.0
% INFO    : Bus 3171	: V=1.012664, theta=-22.795931 -> V=1.0, theta=0.0
% INFO    : Bus 3172	: V=0.970959, theta=-26.759528 -> V=1.0, theta=0.0
% INFO    : Bus 3173	: V=1.039184, theta=-21.542575 -> V=1.0, theta=0.0
% INFO    : Bus 3174	: V=1.025066, theta=-45.160027 -> V=1.0, theta=0.0
% INFO    : Bus 3175	: V=1.036042, theta=-29.785074 -> V=1.0, theta=0.0
% INFO    : Bus 3176	: V=1.00792, theta=5.571006 -> V=1.0, theta=0.0
% INFO    : Bus 3177	: V=1.017462, theta=7.133812 -> V=1.0, theta=0.0
% INFO    : Bus 3178	: V=1.034206, theta=-45.723311 -> V=1.0, theta=0.0
% INFO    : Bus 3179	: V=1.027153, theta=-34.371397 -> V=1.0, theta=0.0
% INFO    : Bus 3180	: V=1.032148, theta=-38.739468 -> V=1.0, theta=0.0
% INFO    : Bus 3181	: V=0.944519, theta=-32.754224 -> V=1.0, theta=0.0
% INFO    : Bus 3182	: V=1.031492, theta=3.864128 -> V=1.0, theta=0.0
% INFO    : Bus 3183	: V=1.061538, theta=-12.259951 -> V=1.0, theta=0.0
% INFO    : Bus 3184	: V=1.037191, theta=-21.646471 -> V=1.0, theta=0.0
% INFO    : Bus 3185	: V=1.031803, theta=-29.22026 -> V=1.0, theta=0.0
% INFO    : Bus 3186	: V=1.017107, theta=-33.798706 -> V=1.0, theta=0.0
% INFO    : Bus 3187	: V=1.045742, theta=-13.029721 -> V=1.0, theta=0.0
% INFO    : Bus 3188	: V=1.022784, theta=-43.114628 -> V=1.0, theta=0.0
% INFO    : Bus 3189	: V=1.027406, theta=47.583401 -> V=1.0, theta=0.0
% INFO    : Bus 3190	: V=1.03242, theta=13.30251 -> V=1.0, theta=0.0
% INFO    : Bus 3191	: V=1.034972, theta=-12.379308 -> V=1.0, theta=0.0
% INFO    : Bus 3192	: V=1.084468, theta=-17.766436 -> V=1.0, theta=0.0
% INFO    : Bus 3193	: V=1.065116, theta=-43.742608 -> V=1.0, theta=0.0
% INFO    : Bus 3194	: V=1.012434, theta=9.719434 -> V=1.0, theta=0.0
% INFO    : Bus 3195	: V=1.006576, theta=-37.208653 -> V=1.0, theta=0.0
% INFO    : Bus 3196	: V=1.03574, theta=-34.436191 -> V=1.0, theta=0.0
% INFO    : Bus 3197	: V=0.978533, theta=-13.888229 -> V=1.0, theta=0.0
% INFO    : Bus 3198	: V=1.008016, theta=-37.94449 -> V=1.0, theta=0.0
% INFO    : Bus 3199	: V=1.038944, theta=1.077782 -> V=1.0, theta=0.0
% INFO    : Bus 3200	: V=1.032243, theta=-23.40526 -> V=1.0, theta=0.0
% INFO    : Bus 3201	: V=0.964845, theta=-31.486373 -> V=1.0, theta=0.0
% INFO    : Bus 3202	: V=1.033191, theta=24.896503 -> V=1.0, theta=0.0
% INFO    : Bus 3203	: V=1.028876, theta=-21.014885 -> V=1.0, theta=0.0
% INFO    : Bus 3204	: V=1.015199, theta=-10.325109 -> V=1.0, theta=0.0
% INFO    : Bus 3205	: V=1.043987, theta=-1.453156 -> V=1.0, theta=0.0
% INFO    : Bus 3206	: V=1.033915, theta=9.697252 -> V=1.0, theta=0.0
% INFO    : Bus 3207	: V=0.938219, theta=-27.443062 -> V=1.0, theta=0.0
% INFO    : Bus 3208	: V=1.082871, theta=-28.948201 -> V=1.0, theta=0.0
% INFO    : Bus 3209	: V=1.004125, theta=-41.22604 -> V=1.0, theta=0.0
% INFO    : Bus 3210	: V=1.025177, theta=6.395982 -> V=1.0, theta=0.0
% INFO    : Bus 3211	: V=1.003983, theta=-44.924447 -> V=1.0, theta=0.0
% INFO    : Bus 3212	: V=1.022821, theta=-20.853163 -> V=1.0, theta=0.0
% INFO    : Bus 3213	: V=1.029705, theta=-26.057232 -> V=1.0, theta=0.0
% INFO    : Bus 3214	: V=0.97262, theta=-27.178609 -> V=1.0, theta=0.0
% INFO    : Bus 3215	: V=1.019913, theta=-4.168894 -> V=1.0, theta=0.0
% INFO    : Bus 3216	: V=1.018799, theta=-4.292908 -> V=1.0, theta=0.0
% INFO    : Bus 3217	: V=1.024067, theta=11.753871 -> V=1.0, theta=0.0
% INFO    : Bus 3218	: V=1.02981, theta=-11.281302 -> V=1.0, theta=0.0
% INFO    : Bus 3219	: V=1.06035, theta=8.785773 -> V=1.0, theta=0.0
% INFO    : Bus 3220	: V=1.036268, theta=14.95352 -> V=1.0, theta=0.0
% INFO    : Bus 3221	: V=1.05011, theta=-12.277426 -> V=1.0, theta=0.0
% INFO    : Bus 3222	: V=1.012228, theta=-40.450912 -> V=1.0, theta=0.0
% INFO    : Bus 3223	: V=1.001615, theta=-29.037021 -> V=1.0, theta=0.0
% INFO    : Bus 3224	: V=1.038864, theta=27.61637 -> V=1.0, theta=0.0
% INFO    : Bus 3225	: V=1.038338, theta=12.206547 -> V=1.0, theta=0.0
% INFO    : Bus 3226	: V=1.01262, theta=-8.309205 -> V=1.0, theta=0.0
% INFO    : Bus 3227	: V=1.051132, theta=-28.487653 -> V=1.0, theta=0.0
% INFO    : Bus 3228	: V=1.026045, theta=-13.340911 -> V=1.0, theta=0.0
% INFO    : Bus 3229	: V=1.034116, theta=-13.165635 -> V=1.0, theta=0.0
% INFO    : Bus 3230	: V=1.024432, theta=5.586276 -> V=1.0, theta=0.0
% INFO    : Bus 3231	: V=1.019628, theta=-14.638597 -> V=1.0, theta=0.0
% INFO    : Bus 3232	: V=1.002743, theta=-30.117477 -> V=1.0, theta=0.0
% INFO    : Bus 3233	: V=1.006814, theta=-46.444024 -> V=1.0, theta=0.0
% INFO    : Bus 3234	: V=1.034756, theta=-24.800598 -> V=1.0, theta=0.0
% INFO    : Bus 3235	: V=1.022894, theta=-19.896997 -> V=1.0, theta=0.0
% INFO    : Bus 3236	: V=1.022886, theta=-31.356422 -> V=1.0, theta=0.0
% INFO    : Bus 3237	: V=1.028917, theta=-26.001768 -> V=1.0, theta=0.0
% INFO    : Bus 3238	: V=1.036264, theta=-36.34369 -> V=1.0, theta=0.0
% INFO    : Bus 3239	: V=1.052583, theta=-11.882218 -> V=1.0, theta=0.0
% INFO    : Bus 3240	: V=1.048993, theta=-1.195378 -> V=1.0, theta=0.0
% INFO    : Bus 3241	: V=1.027307, theta=-18.073023 -> V=1.0, theta=0.0
% INFO    : Bus 3242	: V=1.052842, theta=-9.770395 -> V=1.0, theta=0.0
% INFO    : Bus 3243	: V=0.985966, theta=-18.490962 -> V=1.0, theta=0.0
% INFO    : Bus 3244	: V=0.963858, theta=-26.99749 -> V=1.0, theta=0.0
% INFO    : Bus 3245	: V=1.020645, theta=-24.080506 -> V=1.0, theta=0.0
% INFO    : Bus 3246	: V=1.075945, theta=7.839523 -> V=1.0, theta=0.0
% INFO    : Bus 3247	: V=0.992233, theta=-34.753986 -> V=1.0, theta=0.0
% INFO    : Bus 3248	: V=1.050664, theta=-11.63598 -> V=1.0, theta=0.0
% INFO    : Bus 3249	: V=1.025749, theta=-0.319615 -> V=1.0, theta=0.0
% INFO    : Bus 3250	: V=1.006298, theta=-19.586545 -> V=1.0, theta=0.0
% INFO    : Bus 3251	: V=1.085025, theta=23.509451 -> V=1.0, theta=0.0
% INFO    : Bus 3252	: V=0.984433, theta=-23.606104 -> V=1.0, theta=0.0
% INFO    : Bus 3253	: V=1.024777, theta=-6.321564 -> V=1.0, theta=0.0
% INFO    : Bus 3254	: V=1.024755, theta=-16.181084 -> V=1.0, theta=0.0
% INFO    : Bus 3255	: V=1.034827, theta=-22.379621 -> V=1.0, theta=0.0
% INFO    : Bus 3256	: V=1.036534, theta=-51.990546 -> V=1.0, theta=0.0
% INFO    : Bus 3257	: V=1.047393, theta=12.895607 -> V=1.0, theta=0.0
% INFO    : Bus 3258	: V=0.995506, theta=-31.841795 -> V=1.0, theta=0.0
% INFO    : Bus 3259	: V=1.142893, theta=-23.3897 -> V=1.0, theta=0.0
% INFO    : Bus 3260	: V=1.039685, theta=3.822592 -> V=1.0, theta=0.0
% INFO    : Bus 3261	: V=1.001078, theta=8.535194 -> V=1.0, theta=0.0
% INFO    : Bus 3262	: V=1.126522, theta=-25.245392 -> V=1.0, theta=0.0
% INFO    : Bus 3263	: V=1.036588, theta=-27.733931 -> V=1.0, theta=0.0
% INFO    : Bus 3264	: V=1.039352, theta=17.354571 -> V=1.0, theta=0.0
% INFO    : Bus 3265	: V=1.030307, theta=-51.794533 -> V=1.0, theta=0.0
% INFO    : Bus 3266	: V=0.984933, theta=-54.747739 -> V=1.0, theta=0.0
% INFO    : Bus 3267	: V=1.03073, theta=20.597426 -> V=1.0, theta=0.0
% INFO    : Bus 3268	: V=1.038384, theta=-40.013191 -> V=1.0, theta=0.0
% INFO    : Bus 3269	: V=1.024852, theta=-6.895393 -> V=1.0, theta=0.0
% INFO    : Bus 3270	: V=1.012867, theta=3.04441 -> V=1.0, theta=0.0
% INFO    : Bus 3271	: V=1.038289, theta=3.97828 -> V=1.0, theta=0.0
% INFO    : Bus 3272	: V=0.970883, theta=-24.101597 -> V=1.0, theta=0.0
% INFO    : Bus 3273	: V=0.982449, theta=-28.284052 -> V=1.0, theta=0.0
% INFO    : Bus 3274	: V=1.020263, theta=-34.990644 -> V=1.0, theta=0.0
% INFO    : Bus 3275	: V=1.042383, theta=-43.384878 -> V=1.0, theta=0.0
% INFO    : Bus 3276	: V=1.047364, theta=-7.951911 -> V=1.0, theta=0.0
% INFO    : Bus 3277	: V=1.045909, theta=-16.489223 -> V=1.0, theta=0.0
% INFO    : Bus 3278	: V=1.024557, theta=-28.170285 -> V=1.0, theta=0.0
% INFO    : Bus 3279	: V=1.00372, theta=-3.125253 -> V=1.0, theta=0.0
% INFO    : Bus 3280	: V=1.023776, theta=-3.631665 -> V=1.0, theta=0.0
% INFO    : Bus 3281	: V=1.003133, theta=-15.881363 -> V=1.0, theta=0.0
% INFO    : Bus 3282	: V=1.015198, theta=-57.678557 -> V=1.0, theta=0.0
% INFO    : Bus 3283	: V=1.027874, theta=0.721469 -> V=1.0, theta=0.0
% INFO    : Bus 3284	: V=1.031123, theta=-30.983299 -> V=1.0, theta=0.0
% INFO    : Bus 3285	: V=1.04544, theta=-27.002752 -> V=1.0, theta=0.0
% INFO    : Bus 3286	: V=1.0048, theta=-16.394162 -> V=1.0, theta=0.0
% INFO    : Bus 3287	: V=1.030245, theta=11.41359 -> V=1.0, theta=0.0
% INFO    : Bus 3288	: V=1.053315, theta=-24.416702 -> V=1.0, theta=0.0
% INFO    : Bus 3289	: V=0.995682, theta=-31.065574 -> V=1.0, theta=0.0
% INFO    : Bus 3290	: V=1.076876, theta=7.965584 -> V=1.0, theta=0.0
% INFO    : Bus 3291	: V=1.020441, theta=-44.798684 -> V=1.0, theta=0.0
% INFO    : Bus 3292	: V=0.995766, theta=3.120373 -> V=1.0, theta=0.0
% INFO    : Bus 3293	: V=1.033298, theta=-11.661741 -> V=1.0, theta=0.0
% INFO    : Bus 3294	: V=1.035991, theta=-4.951672 -> V=1.0, theta=0.0
% INFO    : Bus 3295	: V=1.082067, theta=-35.999712 -> V=1.0, theta=0.0
% INFO    : Bus 3296	: V=1.044514, theta=-28.223768 -> V=1.0, theta=0.0
% INFO    : Bus 3297	: V=0.996432, theta=-30.704621 -> V=1.0, theta=0.0
% INFO    : Bus 3298	: V=1.06827, theta=-26.211418 -> V=1.0, theta=0.0
% INFO    : Bus 3299	: V=1.017027, theta=7.501874 -> V=1.0, theta=0.0
% INFO    : Bus 3300	: V=1.002796, theta=-30.022842 -> V=1.0, theta=0.0
% INFO    : Bus 3301	: V=1.023716, theta=-3.389174 -> V=1.0, theta=0.0
% INFO    : Bus 3302	: V=1.024008, theta=7.979243 -> V=1.0, theta=0.0
% INFO    : Bus 3303	: V=1.026201, theta=-10.658019 -> V=1.0, theta=0.0
% INFO    : Bus 3304	: V=1.024949, theta=13.939543 -> V=1.0, theta=0.0
% INFO    : Bus 3305	: V=1.00183, theta=-27.474238 -> V=1.0, theta=0.0
% INFO    : Bus 3306	: V=1.065504, theta=8.070469 -> V=1.0, theta=0.0
% INFO    : Bus 3307	: V=0.991379, theta=-30.823779 -> V=1.0, theta=0.0
% INFO    : Bus 3308	: V=1.049926, theta=-19.383964 -> V=1.0, theta=0.0
% INFO    : Bus 3309	: V=1.008616, theta=-28.806845 -> V=1.0, theta=0.0
% INFO    : Bus 3310	: V=1.032355, theta=-10.130263 -> V=1.0, theta=0.0
% INFO    : Bus 3311	: V=1.023597, theta=-37.693898 -> V=1.0, theta=0.0
% INFO    : Bus 3312	: V=1.030866, theta=-22.122041 -> V=1.0, theta=0.0
% INFO    : Bus 3313	: V=1.04533, theta=-15.776359 -> V=1.0, theta=0.0
% INFO    : Bus 3314	: V=1.03099, theta=3.60651 -> V=1.0, theta=0.0
% INFO    : Bus 3315	: V=1.089019, theta=-27.770812 -> V=1.0, theta=0.0
% INFO    : Bus 3316	: V=1.000662, theta=-36.968905 -> V=1.0, theta=0.0
% INFO    : Bus 3317	: V=1.017587, theta=1.50211 -> V=1.0, theta=0.0
% INFO    : Bus 3318	: V=1.009022, theta=-33.106438 -> V=1.0, theta=0.0
% INFO    : Bus 3319	: V=1.01871, theta=-16.053033 -> V=1.0, theta=0.0
% INFO    : Bus 3320	: V=1.054266, theta=-27.699221 -> V=1.0, theta=0.0
% INFO    : Bus 3321	: V=1.023353, theta=11.967133 -> V=1.0, theta=0.0
% INFO    : Bus 3322	: V=1.029763, theta=65.225449 -> V=1.0, theta=0.0
% INFO    : Bus 3323	: V=1.021399, theta=14.587549 -> V=1.0, theta=0.0
% INFO    : Bus 3324	: V=1.012342, theta=-16.331122 -> V=1.0, theta=0.0
% INFO    : Bus 3325	: V=1.030173, theta=-20.370249 -> V=1.0, theta=0.0
% INFO    : Bus 3326	: V=1.057931, theta=6.3407 -> V=1.0, theta=0.0
% INFO    : Bus 3327	: V=1.040431, theta=-12.287145 -> V=1.0, theta=0.0
% INFO    : Bus 3328	: V=1.002664, theta=-24.296768 -> V=1.0, theta=0.0
% INFO    : Bus 3329	: V=0.977574, theta=-22.100659 -> V=1.0, theta=0.0
% INFO    : Bus 3330	: V=1.049026, theta=64.390308 -> V=1.0, theta=0.0
% INFO    : Bus 3331	: V=1.015678, theta=-10.273718 -> V=1.0, theta=0.0
% INFO    : Bus 3332	: V=1.026477, theta=38.071701 -> V=1.0, theta=0.0
% INFO    : Bus 3333	: V=1.040908, theta=-39.939697 -> V=1.0, theta=0.0
% INFO    : Bus 3334	: V=1.027102, theta=-38.773472 -> V=1.0, theta=0.0
% INFO    : Bus 3335	: V=1.08064, theta=31.725381 -> V=1.0, theta=0.0
% INFO    : Bus 3336	: V=1.010354, theta=-5.899949 -> V=1.0, theta=0.0
% INFO    : Bus 3337	: V=0.996896, theta=-35.038392 -> V=1.0, theta=0.0
% INFO    : Bus 3338	: V=0.986716, theta=-27.147128 -> V=1.0, theta=0.0
% INFO    : Bus 3339	: V=0.988637, theta=-30.966256 -> V=1.0, theta=0.0
% INFO    : Bus 3340	: V=1.027329, theta=-10.387112 -> V=1.0, theta=0.0
% INFO    : Bus 3341	: V=0.992929, theta=-43.712078 -> V=1.0, theta=0.0
% INFO    : Bus 3342	: V=1.025535, theta=-40.505398 -> V=1.0, theta=0.0
% INFO    : Bus 3343	: V=1.029529, theta=-45.122723 -> V=1.0, theta=0.0
% INFO    : Bus 3344	: V=1.041765, theta=-16.618277 -> V=1.0, theta=0.0
% INFO    : Bus 3345	: V=0.998722, theta=-23.729182 -> V=1.0, theta=0.0
% INFO    : Bus 3346	: V=1.014446, theta=-12.166453 -> V=1.0, theta=0.0
% INFO    : Bus 3347	: V=1.026132, theta=-22.241868 -> V=1.0, theta=0.0
% INFO    : Bus 3348	: V=1.028993, theta=-31.533375 -> V=1.0, theta=0.0
% INFO    : Bus 3349	: V=1.047992, theta=65.933266 -> V=1.0, theta=0.0
% INFO    : Bus 3350	: V=0.985794, theta=-28.367567 -> V=1.0, theta=0.0
% INFO    : Bus 3351	: V=1.039446, theta=-27.195467 -> V=1.0, theta=0.0
% INFO    : Bus 3352	: V=1.024972, theta=11.353365 -> V=1.0, theta=0.0
% INFO    : Bus 3353	: V=1.045086, theta=-3.111681 -> V=1.0, theta=0.0
% INFO    : Bus 3354	: V=1.023094, theta=-32.476655 -> V=1.0, theta=0.0
% INFO    : Bus 3355	: V=1.031224, theta=-4.244743 -> V=1.0, theta=0.0
% INFO    : Bus 3356	: V=1.075263, theta=-18.49023 -> V=1.0, theta=0.0
% INFO    : Bus 3357	: V=0.976332, theta=13.454371 -> V=1.0, theta=0.0
% INFO    : Bus 3358	: V=1.024826, theta=-25.076779 -> V=1.0, theta=0.0
% INFO    : Bus 3359	: V=1.002922, theta=-27.79104 -> V=1.0, theta=0.0
% INFO    : Bus 3360	: V=1.045789, theta=-27.19641 -> V=1.0, theta=0.0
% INFO    : Bus 3361	: V=1.023311, theta=4.22218 -> V=1.0, theta=0.0
% INFO    : Bus 3362	: V=1.060735, theta=-19.68938 -> V=1.0, theta=0.0
% INFO    : Bus 3363	: V=1.022161, theta=1.431179 -> V=1.0, theta=0.0
% INFO    : Bus 3364	: V=1.059596, theta=-12.778615 -> V=1.0, theta=0.0
% INFO    : Bus 3365	: V=1.063179, theta=-22.825995 -> V=1.0, theta=0.0
% INFO    : Bus 3366	: V=0.986109, theta=-26.796119 -> V=1.0, theta=0.0
% INFO    : Bus 3367	: V=1.018093, theta=-52.831262 -> V=1.0, theta=0.0
% INFO    : Bus 3368	: V=1.043656, theta=-8.471313 -> V=1.0, theta=0.0
% INFO    : Bus 3369	: V=0.994634, theta=-25.281268 -> V=1.0, theta=0.0
% INFO    : Bus 3370	: V=1.047845, theta=18.20106 -> V=1.0, theta=0.0
% INFO    : Bus 3371	: V=1.029674, theta=-35.973456 -> V=1.0, theta=0.0
% INFO    : Bus 3372	: V=1.021707, theta=-27.973729 -> V=1.0, theta=0.0
% INFO    : Bus 3373	: V=1.010616, theta=-20.118719 -> V=1.0, theta=0.0
% INFO    : Bus 3374	: V=1.019272, theta=9.870343 -> V=1.0, theta=0.0
% INFO    : Bus 3375	: V=1.035048, theta=2.179444 -> V=1.0, theta=0.0
% INFO    : Bus 3376	: V=1.020937, theta=-22.652943 -> V=1.0, theta=0.0
% INFO    : Bus 3377	: V=1.016074, theta=-10.56574 -> V=1.0, theta=0.0
% INFO    : Bus 3378	: V=1.016937, theta=-45.491741 -> V=1.0, theta=0.0
% INFO    : Bus 3379	: V=1.039815, theta=2.431643 -> V=1.0, theta=0.0
% INFO    : Bus 3380	: V=1.055018, theta=-27.471518 -> V=1.0, theta=0.0
% INFO    : Bus 3381	: V=0.979142, theta=-23.204984 -> V=1.0, theta=0.0
% INFO    : Bus 3382	: V=1.021675, theta=-47.230805 -> V=1.0, theta=0.0
% INFO    : Bus 3383	: V=0.991029, theta=-36.657183 -> V=1.0, theta=0.0
% INFO    : Bus 3384	: V=1.009327, theta=-46.581744 -> V=1.0, theta=0.0
% INFO    : Bus 3385	: V=0.920065, theta=-35.658325 -> V=1.0, theta=0.0
% INFO    : Bus 3386	: V=1.019186, theta=-21.648748 -> V=1.0, theta=0.0
% INFO    : Bus 3387	: V=1.006574, theta=-28.829212 -> V=1.0, theta=0.0
% INFO    : Bus 3388	: V=1.03099, theta=3.60651 -> V=1.0, theta=0.0
% INFO    : Bus 3389	: V=1.037252, theta=-4.035324 -> V=1.0, theta=0.0
% INFO    : Bus 3390	: V=1.035344, theta=-11.772404 -> V=1.0, theta=0.0
% INFO    : Bus 3391	: V=1.054876, theta=-21.249752 -> V=1.0, theta=0.0
% INFO    : Bus 3392	: V=0.997163, theta=-32.412159 -> V=1.0, theta=0.0
% INFO    : Bus 3393	: V=1.019427, theta=-14.361209 -> V=1.0, theta=0.0
% INFO    : Bus 3394	: V=1.015848, theta=-29.529341 -> V=1.0, theta=0.0
% INFO    : Bus 3395	: V=0.99554, theta=-31.892503 -> V=1.0, theta=0.0
% INFO    : Bus 3396	: V=1.095689, theta=53.980552 -> V=1.0, theta=0.0
% INFO    : Bus 3397	: V=1.017014, theta=-0.831895 -> V=1.0, theta=0.0
% INFO    : Bus 3398	: V=1.036168, theta=-33.730561 -> V=1.0, theta=0.0
% INFO    : Bus 3399	: V=1.000784, theta=-30.931974 -> V=1.0, theta=0.0
% INFO    : Bus 3400	: V=1.043188, theta=-25.417287 -> V=1.0, theta=0.0
% INFO    : Bus 3401	: V=1.042909, theta=-13.901958 -> V=1.0, theta=0.0
% INFO    : Bus 3402	: V=1.015139, theta=-21.841008 -> V=1.0, theta=0.0
% INFO    : Bus 3403	: V=1.013126, theta=-22.985262 -> V=1.0, theta=0.0
% INFO    : Bus 3404	: V=1.037431, theta=-0.674629 -> V=1.0, theta=0.0
% INFO    : Bus 3405	: V=1.037782, theta=-32.221968 -> V=1.0, theta=0.0
% INFO    : Bus 3406	: V=1.000105, theta=-30.932302 -> V=1.0, theta=0.0
% INFO    : Bus 3407	: V=1.025102, theta=-23.44681 -> V=1.0, theta=0.0
% INFO    : Bus 3408	: V=0.981792, theta=-34.919816 -> V=1.0, theta=0.0
% INFO    : Bus 3409	: V=1.020151, theta=-38.993027 -> V=1.0, theta=0.0
% INFO    : Bus 3410	: V=1.013843, theta=-29.711149 -> V=1.0, theta=0.0
% INFO    : Bus 3411	: V=1.024699, theta=-7.29082 -> V=1.0, theta=0.0
% INFO    : Bus 3412	: V=1.051067, theta=2.324898 -> V=1.0, theta=0.0
% INFO    : Bus 3413	: V=0.985559, theta=-48.852329 -> V=1.0, theta=0.0
% INFO    : Bus 3414	: V=1.028494, theta=-40.4823 -> V=1.0, theta=0.0
% INFO    : Bus 3415	: V=1.017252, theta=-26.562376 -> V=1.0, theta=0.0
% INFO    : Bus 3416	: V=0.99364, theta=-37.271039 -> V=1.0, theta=0.0
% INFO    : Bus 3417	: V=0.98196, theta=-33.257434 -> V=1.0, theta=0.0
% INFO    : Bus 3418	: V=1.055201, theta=-27.39433 -> V=1.0, theta=0.0
% INFO    : Bus 3419	: V=1.05343, theta=-28.763135 -> V=1.0, theta=0.0
% INFO    : Bus 3420	: V=1.035139, theta=-24.267368 -> V=1.0, theta=0.0
% INFO    : Bus 3421	: V=1.063078, theta=-18.313704 -> V=1.0, theta=0.0
% INFO    : Bus 3422	: V=1.068276, theta=-11.121919 -> V=1.0, theta=0.0
% INFO    : Bus 3423	: V=1.026069, theta=-18.887132 -> V=1.0, theta=0.0
% INFO    : Bus 3424	: V=1.007957, theta=-6.106231 -> V=1.0, theta=0.0
% INFO    : Bus 3425	: V=1.023755, theta=-54.374613 -> V=1.0, theta=0.0
% INFO    : Bus 3426	: V=1.01782, theta=2.146836 -> V=1.0, theta=0.0
% INFO    : Bus 3427	: V=1.02442, theta=-54.181061 -> V=1.0, theta=0.0
% INFO    : Bus 3428	: V=1.03688, theta=-45.000213 -> V=1.0, theta=0.0
% INFO    : Bus 3429	: V=0.980011, theta=-57.065563 -> V=1.0, theta=0.0
% INFO    : Bus 3430	: V=1.025197, theta=-16.439994 -> V=1.0, theta=0.0
% INFO    : Bus 3431	: V=1.037857, theta=65.155592 -> V=1.0, theta=0.0
% INFO    : Bus 3432	: V=1.042952, theta=-17.524884 -> V=1.0, theta=0.0
% INFO    : Bus 3433	: V=1.030669, theta=-22.850681 -> V=1.0, theta=0.0
% INFO    : Bus 3434	: V=0.995667, theta=-26.3926 -> V=1.0, theta=0.0
% INFO    : Bus 3435	: V=1.039221, theta=-25.891769 -> V=1.0, theta=0.0
% INFO    : Bus 3436	: V=1.052704, theta=-13.695663 -> V=1.0, theta=0.0
% INFO    : Bus 3437	: V=1.042946, theta=-20.458651 -> V=1.0, theta=0.0
% INFO    : Bus 3438	: V=1.048328, theta=2.09489 -> V=1.0, theta=0.0
% INFO    : Bus 3439	: V=1.020047, theta=-5.087122 -> V=1.0, theta=0.0
% INFO    : Bus 3440	: V=1.075387, theta=-16.776668 -> V=1.0, theta=0.0
% INFO    : Bus 3441	: V=1.059719, theta=-16.905097 -> V=1.0, theta=0.0
% INFO    : Bus 3442	: V=1.028465, theta=-53.809916 -> V=1.0, theta=0.0
% INFO    : Bus 3443	: V=1.017983, theta=6.449833 -> V=1.0, theta=0.0
% INFO    : Bus 3444	: V=0.979988, theta=-28.556612 -> V=1.0, theta=0.0
% INFO    : Bus 3445	: V=0.992908, theta=-6.161579 -> V=1.0, theta=0.0
% INFO    : Bus 3446	: V=1.054592, theta=-7.033609 -> V=1.0, theta=0.0
% INFO    : Bus 3447	: V=1.017418, theta=-41.092897 -> V=1.0, theta=0.0
% INFO    : Bus 3448	: V=1.067993, theta=-27.916992 -> V=1.0, theta=0.0
% INFO    : Bus 3449	: V=1.03469, theta=-24.748184 -> V=1.0, theta=0.0
% INFO    : Bus 3450	: V=1.043402, theta=-21.780648 -> V=1.0, theta=0.0
% INFO    : Bus 3451	: V=0.959432, theta=-22.765455 -> V=1.0, theta=0.0
% INFO    : Bus 3452	: V=0.95362, theta=-29.988893 -> V=1.0, theta=0.0
% INFO    : Bus 3453	: V=0.985273, theta=-26.713246 -> V=1.0, theta=0.0
% INFO    : Bus 3454	: V=1.03762, theta=-5.743891 -> V=1.0, theta=0.0
% INFO    : Bus 3455	: V=1.034721, theta=-28.713871 -> V=1.0, theta=0.0
% INFO    : Bus 3456	: V=1.023885, theta=-3.618127 -> V=1.0, theta=0.0
% INFO    : Bus 3457	: V=1.027908, theta=-40.515859 -> V=1.0, theta=0.0
% INFO    : Bus 3458	: V=1.033989, theta=12.131257 -> V=1.0, theta=0.0
% INFO    : Bus 3459	: V=1.022605, theta=-5.992828 -> V=1.0, theta=0.0
% INFO    : Bus 3460	: V=1.04269, theta=-24.913869 -> V=1.0, theta=0.0
% INFO    : Bus 3461	: V=1.013524, theta=-32.326805 -> V=1.0, theta=0.0
% INFO    : Bus 3462	: V=1.023996, theta=11.110517 -> V=1.0, theta=0.0
% INFO    : Bus 3463	: V=0.997198, theta=-30.597829 -> V=1.0, theta=0.0
% INFO    : Bus 3464	: V=1.055563, theta=-19.124141 -> V=1.0, theta=0.0
% INFO    : Bus 3465	: V=1.001856, theta=-50.899311 -> V=1.0, theta=0.0
% INFO    : Bus 3466	: V=1.020739, theta=-34.936213 -> V=1.0, theta=0.0
% INFO    : Bus 3467	: V=1.033755, theta=-34.258331 -> V=1.0, theta=0.0
% INFO    : Bus 3468	: V=1.026246, theta=-48.014875 -> V=1.0, theta=0.0
% INFO    : Bus 3469	: V=1.040633, theta=-32.329218 -> V=1.0, theta=0.0
% INFO    : Bus 3470	: V=1.017239, theta=-27.181267 -> V=1.0, theta=0.0
% INFO    : Bus 3471	: V=1.037452, theta=-33.497141 -> V=1.0, theta=0.0
% INFO    : Bus 3472	: V=1.058466, theta=-24.602689 -> V=1.0, theta=0.0
% INFO    : Bus 3473	: V=1.004888, theta=-32.9331 -> V=1.0, theta=0.0
% INFO    : Bus 3474	: V=1.032567, theta=-27.514987 -> V=1.0, theta=0.0
% INFO    : Bus 3475	: V=1.016081, theta=16.936639 -> V=1.0, theta=0.0
% INFO    : Bus 3476	: V=1.029567, theta=33.682355 -> V=1.0, theta=0.0
% INFO    : Bus 3477	: V=1.043352, theta=-18.411585 -> V=1.0, theta=0.0
% INFO    : Bus 3478	: V=1.004025, theta=-44.918549 -> V=1.0, theta=0.0
% INFO    : Bus 3479	: V=0.995033, theta=10.148104 -> V=1.0, theta=0.0
% INFO    : Bus 3480	: V=1.039565, theta=-15.023882 -> V=1.0, theta=0.0
% INFO    : Bus 3481	: V=1.020131, theta=-21.073223 -> V=1.0, theta=0.0
% INFO    : Bus 3482	: V=0.96568, theta=-37.714763 -> V=1.0, theta=0.0
% INFO    : Bus 3483	: V=1.057283, theta=2.073747 -> V=1.0, theta=0.0
% INFO    : Bus 3484	: V=1.03238, theta=13.28195 -> V=1.0, theta=0.0
% INFO    : Bus 3485	: V=0.987214, theta=-16.561475 -> V=1.0, theta=0.0
% INFO    : Bus 3486	: V=1.034572, theta=-21.143387 -> V=1.0, theta=0.0
% INFO    : Bus 3487	: V=1.008468, theta=-40.53524 -> V=1.0, theta=0.0
% INFO    : Bus 3488	: V=1.033154, theta=-12.683749 -> V=1.0, theta=0.0
% INFO    : Bus 3489	: V=1.021883, theta=-53.739345 -> V=1.0, theta=0.0
% INFO    : Bus 3490	: V=1.016214, theta=-37.064491 -> V=1.0, theta=0.0
% INFO    : Bus 3491	: V=1.012, theta=-39.093054 -> V=1.0, theta=0.0
% INFO    : Bus 3492	: V=1.049517, theta=-8.753604 -> V=1.0, theta=0.0
% INFO    : Bus 3493	: V=1.030522, theta=-10.855222 -> V=1.0, theta=0.0
% INFO    : Bus 3494	: V=1.040916, theta=-20.181938 -> V=1.0, theta=0.0
% INFO    : Bus 3495	: V=1.011873, theta=-57.860179 -> V=1.0, theta=0.0
% INFO    : Bus 3496	: V=1.031337, theta=-21.679626 -> V=1.0, theta=0.0
% INFO    : Bus 3497	: V=1.032235, theta=3.545389 -> V=1.0, theta=0.0
% INFO    : Bus 3498	: V=1.038411, theta=-10.391747 -> V=1.0, theta=0.0
% INFO    : Bus 3499	: V=1.031705, theta=-3.679012 -> V=1.0, theta=0.0
% INFO    : Bus 3500	: V=1.027326, theta=-52.891329 -> V=1.0, theta=0.0
% INFO    : Bus 3501	: V=0.997562, theta=-8.529192 -> V=1.0, theta=0.0
% INFO    : Bus 3502	: V=1.018814, theta=-10.609035 -> V=1.0, theta=0.0
% INFO    : Bus 3503	: V=1.029182, theta=-11.728946 -> V=1.0, theta=0.0
% INFO    : Bus 3504	: V=1.001149, theta=-27.034513 -> V=1.0, theta=0.0
% INFO    : Bus 3505	: V=1.004322, theta=-11.424973 -> V=1.0, theta=0.0
% INFO    : Bus 3506	: V=1.004098, theta=-11.409418 -> V=1.0, theta=0.0
% INFO    : Bus 3507	: V=1.009668, theta=-36.42353 -> V=1.0, theta=0.0
% INFO    : Bus 3508	: V=1.05417, theta=-24.96694 -> V=1.0, theta=0.0
% INFO    : Bus 3509	: V=1.023115, theta=11.11478 -> V=1.0, theta=0.0
% INFO    : Bus 3510	: V=1.077225, theta=-22.203902 -> V=1.0, theta=0.0
% INFO    : Bus 3511	: V=1.086282, theta=-1.99271 -> V=1.0, theta=0.0
% INFO    : Bus 3512	: V=1.00546, theta=-53.369968 -> V=1.0, theta=0.0
% INFO    : Bus 3513	: V=1.027289, theta=-3.805998 -> V=1.0, theta=0.0
% INFO    : Bus 3514	: V=1.070779, theta=44.26994 -> V=1.0, theta=0.0
% INFO    : Bus 3515	: V=1.053923, theta=-0.652883 -> V=1.0, theta=0.0
% INFO    : Bus 3516	: V=1.067373, theta=-22.730945 -> V=1.0, theta=0.0
% INFO    : Bus 3517	: V=1.074675, theta=5.430037 -> V=1.0, theta=0.0
% INFO    : Bus 3518	: V=1.006674, theta=-10.001199 -> V=1.0, theta=0.0
% INFO    : Bus 3519	: V=1.031544, theta=-23.261886 -> V=1.0, theta=0.0
% INFO    : Bus 3520	: V=1.033136, theta=-6.430079 -> V=1.0, theta=0.0
% INFO    : Bus 3521	: V=1.030845, theta=11.444625 -> V=1.0, theta=0.0
% INFO    : Bus 3522	: V=1.024607, theta=7.384057 -> V=1.0, theta=0.0
% INFO    : Bus 3523	: V=0.96895, theta=-32.994795 -> V=1.0, theta=0.0
% INFO    : Bus 3524	: V=1.035659, theta=-27.412126 -> V=1.0, theta=0.0
% INFO    : Bus 3525	: V=1.025525, theta=64.851641 -> V=1.0, theta=0.0
% INFO    : Bus 3526	: V=1.053035, theta=-4.537809 -> V=1.0, theta=0.0
% INFO    : Bus 3527	: V=0.989431, theta=-26.529496 -> V=1.0, theta=0.0
% INFO    : Bus 3528	: V=1.044635, theta=-29.457279 -> V=1.0, theta=0.0
% INFO    : Bus 3529	: V=1.047492, theta=-20.222834 -> V=1.0, theta=0.0
% INFO    : Bus 3530	: V=1.016575, theta=0.400195 -> V=1.0, theta=0.0
% INFO    : Bus 3531	: V=1.019989, theta=-27.855737 -> V=1.0, theta=0.0
% INFO    : Bus 3532	: V=0.916596, theta=-35.844928 -> V=1.0, theta=0.0
% INFO    : Bus 3533	: V=1.045069, theta=-12.896252 -> V=1.0, theta=0.0
% INFO    : Bus 3534	: V=1.051225, theta=-25.209197 -> V=1.0, theta=0.0
% INFO    : Bus 3535	: V=1.030744, theta=-24.81643 -> V=1.0, theta=0.0
% INFO    : Bus 3536	: V=1.043359, theta=-24.890743 -> V=1.0, theta=0.0
% INFO    : Bus 3537	: V=1.033796, theta=-10.932693 -> V=1.0, theta=0.0
% INFO    : Bus 3538	: V=1.025276, theta=17.761025 -> V=1.0, theta=0.0
% INFO    : Bus 3539	: V=1.024188, theta=-11.815297 -> V=1.0, theta=0.0
% INFO    : Bus 3540	: V=1.013842, theta=-36.127515 -> V=1.0, theta=0.0
% INFO    : Bus 3541	: V=1.034174, theta=-24.344455 -> V=1.0, theta=0.0
% INFO    : Bus 3542	: V=0.996699, theta=9.316876 -> V=1.0, theta=0.0
% INFO    : Bus 3543	: V=0.987091, theta=-17.860899 -> V=1.0, theta=0.0
% INFO    : Bus 3544	: V=1.04866, theta=-43.909021 -> V=1.0, theta=0.0
% INFO    : Bus 3545	: V=1.046427, theta=-8.068997 -> V=1.0, theta=0.0
% INFO    : Bus 3546	: V=1.039138, theta=-17.687503 -> V=1.0, theta=0.0
% INFO    : Bus 3547	: V=1.05946, theta=-0.972444 -> V=1.0, theta=0.0
% INFO    : Bus 3548	: V=0.947688, theta=-35.958443 -> V=1.0, theta=0.0
% INFO    : Bus 3549	: V=1.013673, theta=-42.828833 -> V=1.0, theta=0.0
% INFO    : Bus 3550	: V=1.042925, theta=-21.756874 -> V=1.0, theta=0.0
% INFO    : Bus 3551	: V=1.039557, theta=3.294351 -> V=1.0, theta=0.0
% INFO    : Bus 3552	: V=1.02243, theta=21.250325 -> V=1.0, theta=0.0
% INFO    : Bus 3553	: V=0.98226, theta=-23.625281 -> V=1.0, theta=0.0
% INFO    : Bus 3554	: V=1.010725, theta=-19.083646 -> V=1.0, theta=0.0
% INFO    : Bus 3555	: V=1.016482, theta=-26.249817 -> V=1.0, theta=0.0
% INFO    : Bus 3556	: V=1.03815, theta=-49.637833 -> V=1.0, theta=0.0
% INFO    : Bus 3557	: V=1.031344, theta=-31.203578 -> V=1.0, theta=0.0
% INFO    : Bus 3558	: V=1.061361, theta=2.327475 -> V=1.0, theta=0.0
% INFO    : Bus 3559	: V=1.006934, theta=-30.186936 -> V=1.0, theta=0.0
% INFO    : Bus 3560	: V=1.002793, theta=-35.403578 -> V=1.0, theta=0.0
% INFO    : Bus 3561	: V=1.008119, theta=-31.216752 -> V=1.0, theta=0.0
% INFO    : Bus 3562	: V=0.930545, theta=-32.781271 -> V=1.0, theta=0.0
% INFO    : Bus 3563	: V=1.028862, theta=-36.110427 -> V=1.0, theta=0.0
% INFO    : Bus 3564	: V=1.034865, theta=-2.725945 -> V=1.0, theta=0.0
% INFO    : Bus 3565	: V=1.079183, theta=-26.904591 -> V=1.0, theta=0.0
% INFO    : Bus 3566	: V=0.95235, theta=-30.885389 -> V=1.0, theta=0.0
% INFO    : Bus 3567	: V=0.95682, theta=-37.631909 -> V=1.0, theta=0.0
% INFO    : Bus 3568	: V=1.043573, theta=2.632597 -> V=1.0, theta=0.0
% INFO    : Bus 3569	: V=1.042101, theta=-21.88812 -> V=1.0, theta=0.0
% INFO    : Bus 3570	: V=1.062522, theta=-22.923792 -> V=1.0, theta=0.0
% INFO    : Bus 3571	: V=0.997978, theta=-49.825907 -> V=1.0, theta=0.0
% INFO    : Bus 3572	: V=0.998955, theta=-16.495251 -> V=1.0, theta=0.0
% INFO    : Bus 3573	: V=0.991174, theta=-30.802996 -> V=1.0, theta=0.0
% INFO    : Bus 3574	: V=1.031327, theta=-31.908208 -> V=1.0, theta=0.0
% INFO    : Bus 3575	: V=1.031556, theta=-27.321527 -> V=1.0, theta=0.0
% INFO    : Bus 3576	: V=1.074439, theta=-16.993961 -> V=1.0, theta=0.0
% INFO    : Bus 3577	: V=1.027066, theta=-5.390772 -> V=1.0, theta=0.0
% INFO    : Bus 3578	: V=1.037916, theta=37.328866 -> V=1.0, theta=0.0
% INFO    : Bus 3579	: V=1.071688, theta=-39.757905 -> V=1.0, theta=0.0
% INFO    : Bus 3580	: V=1.071709, theta=-33.67965 -> V=1.0, theta=0.0
% INFO    : Bus 3581	: V=0.957996, theta=-31.878474 -> V=1.0, theta=0.0
% INFO    : Bus 3582	: V=1.040375, theta=-49.699237 -> V=1.0, theta=0.0
% INFO    : Bus 3583	: V=1.041006, theta=32.019238 -> V=1.0, theta=0.0
% INFO    : Bus 3584	: V=1.016191, theta=-45.589535 -> V=1.0, theta=0.0
% INFO    : Bus 3585	: V=1.001933, theta=-45.137255 -> V=1.0, theta=0.0
% INFO    : Bus 3586	: V=1.03216, theta=-26.069193 -> V=1.0, theta=0.0
% INFO    : Bus 3587	: V=1.066334, theta=-40.491176 -> V=1.0, theta=0.0
% INFO    : Bus 3588	: V=0.973088, theta=-32.109368 -> V=1.0, theta=0.0
% INFO    : Bus 3589	: V=1.036354, theta=-6.941677 -> V=1.0, theta=0.0
% INFO    : Bus 3590	: V=1.014988, theta=-6.451716 -> V=1.0, theta=0.0
% INFO    : Bus 3591	: V=1.022027, theta=-12.309284 -> V=1.0, theta=0.0
% INFO    : Bus 3592	: V=1.008158, theta=-49.718813 -> V=1.0, theta=0.0
% INFO    : Bus 3593	: V=1.013847, theta=-32.766687 -> V=1.0, theta=0.0
% INFO    : Bus 3594	: V=1.031842, theta=-20.054986 -> V=1.0, theta=0.0
% INFO    : Bus 3595	: V=1.00521, theta=-17.829322 -> V=1.0, theta=0.0
% INFO    : Bus 3596	: V=0.995624, theta=-51.624297 -> V=1.0, theta=0.0
% INFO    : Bus 3597	: V=1.053304, theta=-24.416894 -> V=1.0, theta=0.0
% INFO    : Bus 3598	: V=1.020221, theta=-39.571645 -> V=1.0, theta=0.0
% INFO    : Bus 3599	: V=1.035573, theta=-4.319991 -> V=1.0, theta=0.0
% INFO    : Bus 3600	: V=1.024841, theta=-21.89593 -> V=1.0, theta=0.0
% INFO    : Bus 3601	: V=1.037299, theta=-21.668191 -> V=1.0, theta=0.0
% INFO    : Bus 3602	: V=1.028652, theta=-19.205363 -> V=1.0, theta=0.0
% INFO    : Bus 3603	: V=1.059036, theta=-28.598785 -> V=1.0, theta=0.0
% INFO    : Bus 3604	: V=1.031503, theta=-22.253073 -> V=1.0, theta=0.0
% INFO    : Bus 3605	: V=1.037656, theta=-37.493839 -> V=1.0, theta=0.0
% INFO    : Bus 3606	: V=1.060971, theta=42.771684 -> V=1.0, theta=0.0
% INFO    : Bus 3607	: V=1.057813, theta=11.781879 -> V=1.0, theta=0.0
% INFO    : Bus 3608	: V=1.005954, theta=-41.940464 -> V=1.0, theta=0.0
% INFO    : Bus 3609	: V=1.065404, theta=-11.8324 -> V=1.0, theta=0.0
% INFO    : Bus 3610	: V=1.032147, theta=-23.09589 -> V=1.0, theta=0.0
% INFO    : Bus 3611	: V=1.0427, theta=-18.977598 -> V=1.0, theta=0.0
% INFO    : Bus 3612	: V=1.03493, theta=3.177325 -> V=1.0, theta=0.0
% INFO    : Bus 3613	: V=1.027552, theta=-28.290396 -> V=1.0, theta=0.0
% INFO    : Bus 3614	: V=1.051765, theta=-19.459008 -> V=1.0, theta=0.0
% INFO    : Bus 3615	: V=1.020308, theta=-38.803377 -> V=1.0, theta=0.0
% INFO    : Bus 3616	: V=1.027726, theta=-1.864399 -> V=1.0, theta=0.0
% INFO    : Bus 3617	: V=0.981291, theta=29.186876 -> V=1.0, theta=0.0
% INFO    : Bus 3618	: V=1.059129, theta=-20.439167 -> V=1.0, theta=0.0
% INFO    : Bus 3619	: V=0.961409, theta=-31.649013 -> V=1.0, theta=0.0
% INFO    : Bus 3620	: V=1.03722, theta=1.667564 -> V=1.0, theta=0.0
% INFO    : Bus 3621	: V=1.018584, theta=-52.604451 -> V=1.0, theta=0.0
% INFO    : Bus 3622	: V=1.098571, theta=-31.865767 -> V=1.0, theta=0.0
% INFO    : Bus 3623	: V=1.030825, theta=-34.021264 -> V=1.0, theta=0.0
% INFO    : Bus 3624	: V=0.997079, theta=-32.31357 -> V=1.0, theta=0.0
% INFO    : Bus 3625	: V=1.035196, theta=3.481897 -> V=1.0, theta=0.0
% INFO    : Bus 3626	: V=1.036804, theta=-25.936777 -> V=1.0, theta=0.0
% INFO    : Bus 3627	: V=1.031483, theta=-29.235879 -> V=1.0, theta=0.0
% INFO    : Bus 3628	: V=1.011525, theta=-19.030838 -> V=1.0, theta=0.0
% INFO    : Bus 3629	: V=1.019084, theta=-44.573053 -> V=1.0, theta=0.0
% INFO    : Bus 3630	: V=0.952693, theta=-30.456432 -> V=1.0, theta=0.0
% INFO    : Bus 3631	: V=1.059298, theta=54.603492 -> V=1.0, theta=0.0
% INFO    : Bus 3632	: V=1.074155, theta=-26.401369 -> V=1.0, theta=0.0
% INFO    : Bus 3633	: V=1.028353, theta=-55.614104 -> V=1.0, theta=0.0
% INFO    : Bus 3634	: V=1.058312, theta=-28.162333 -> V=1.0, theta=0.0
% INFO    : Bus 3635	: V=1.027369, theta=17.315007 -> V=1.0, theta=0.0
% INFO    : Bus 3636	: V=1.021807, theta=16.231169 -> V=1.0, theta=0.0
% INFO    : Bus 3637	: V=1.044046, theta=-26.789423 -> V=1.0, theta=0.0
% INFO    : Bus 3638	: V=1.027553, theta=-9.145708 -> V=1.0, theta=0.0
% INFO    : Bus 3639	: V=0.9699, theta=-29.797995 -> V=1.0, theta=0.0
% INFO    : Bus 3640	: V=1.038862, theta=-26.224708 -> V=1.0, theta=0.0
% INFO    : Bus 3641	: V=1.07845, theta=-24.869934 -> V=1.0, theta=0.0
% INFO    : Bus 3642	: V=1.011194, theta=-17.661283 -> V=1.0, theta=0.0
% INFO    : Bus 3643	: V=1.035538, theta=-19.389636 -> V=1.0, theta=0.0
% INFO    : Bus 3644	: V=1.01566, theta=-43.78835 -> V=1.0, theta=0.0
% INFO    : Bus 3645	: V=1.035645, theta=-34.036565 -> V=1.0, theta=0.0
% INFO    : Bus 3646	: V=1.030587, theta=-26.137737 -> V=1.0, theta=0.0
% INFO    : Bus 3647	: V=1.044476, theta=33.28174 -> V=1.0, theta=0.0
% INFO    : Bus 3648	: V=1.05487, theta=4.822118 -> V=1.0, theta=0.0
% INFO    : Bus 3649	: V=1.061718, theta=-38.073141 -> V=1.0, theta=0.0
% INFO    : Bus 3650	: V=1.023313, theta=-43.662861 -> V=1.0, theta=0.0
% INFO    : Bus 3651	: V=1.075494, theta=-25.869106 -> V=1.0, theta=0.0
% INFO    : Bus 3652	: V=1.008222, theta=-7.892933 -> V=1.0, theta=0.0
% INFO    : Bus 3653	: V=1.06713, theta=-27.981342 -> V=1.0, theta=0.0
% INFO    : Bus 3654	: V=1.068425, theta=-26.791691 -> V=1.0, theta=0.0
% INFO    : Bus 3655	: V=1.018477, theta=2.812602 -> V=1.0, theta=0.0
% INFO    : Bus 3656	: V=1.062208, theta=-12.302586 -> V=1.0, theta=0.0
% INFO    : Bus 3657	: V=1.069887, theta=-26.477929 -> V=1.0, theta=0.0
% INFO    : Bus 3658	: V=1.055179, theta=-27.394045 -> V=1.0, theta=0.0
% INFO    : Bus 3659	: V=1.057396, theta=0.724854 -> V=1.0, theta=0.0
% INFO    : Bus 3660	: V=1.032448, theta=4.126448 -> V=1.0, theta=0.0
% INFO    : Bus 3661	: V=1.055245, theta=4.477021 -> V=1.0, theta=0.0
% INFO    : Bus 3662	: V=1.020061, theta=-43.910876 -> V=1.0, theta=0.0
% INFO    : Bus 3663	: V=1.027886, theta=0.182084 -> V=1.0, theta=0.0
% INFO    : Bus 3664	: V=1.020031, theta=8.412929 -> V=1.0, theta=0.0
% INFO    : Bus 3665	: V=1.011358, theta=-43.221397 -> V=1.0, theta=0.0
% INFO    : Bus 3666	: V=1.03051, theta=-29.291022 -> V=1.0, theta=0.0
% INFO    : Bus 3667	: V=0.978178, theta=-27.174726 -> V=1.0, theta=0.0
% INFO    : Bus 3668	: V=1.050201, theta=9.308989 -> V=1.0, theta=0.0
% INFO    : Bus 3669	: V=1.04073, theta=-27.873462 -> V=1.0, theta=0.0
% INFO    : Bus 3670	: V=1.031403, theta=-22.326779 -> V=1.0, theta=0.0
% INFO    : Bus 3671	: V=0.925563, theta=-30.71087 -> V=1.0, theta=0.0
% INFO    : Bus 3672	: V=1.027236, theta=-13.187416 -> V=1.0, theta=0.0
% INFO    : Bus 3673	: V=1.011536, theta=-39.38978 -> V=1.0, theta=0.0
% INFO    : Bus 3674	: V=1.038893, theta=-14.934461 -> V=1.0, theta=0.0
% INFO    : Bus 3675	: V=1.017296, theta=62.359062 -> V=1.0, theta=0.0
% INFO    : Bus 3676	: V=1.049019, theta=-8.638156 -> V=1.0, theta=0.0
% INFO    : Bus 3677	: V=1.011531, theta=-36.657808 -> V=1.0, theta=0.0
% INFO    : Bus 3678	: V=1.009653, theta=-27.771537 -> V=1.0, theta=0.0
% INFO    : Bus 3679	: V=0.998124, theta=-12.616636 -> V=1.0, theta=0.0
% INFO    : Bus 3680	: V=1.041782, theta=-15.274034 -> V=1.0, theta=0.0
% INFO    : Bus 3681	: V=0.917096, theta=-35.817405 -> V=1.0, theta=0.0
% INFO    : Bus 3682	: V=0.968066, theta=-28.685503 -> V=1.0, theta=0.0
% INFO    : Bus 3683	: V=1.011346, theta=-25.944614 -> V=1.0, theta=0.0
% INFO    : Bus 3684	: V=1.076869, theta=-24.59787 -> V=1.0, theta=0.0
% INFO    : Bus 3685	: V=0.938194, theta=-27.473163 -> V=1.0, theta=0.0
% INFO    : Bus 3686	: V=0.997509, theta=-29.526848 -> V=1.0, theta=0.0
% INFO    : Bus 3687	: V=1.04322, theta=-50.454955 -> V=1.0, theta=0.0
% INFO    : Bus 3688	: V=1.03526, theta=-29.588837 -> V=1.0, theta=0.0
% INFO    : Bus 3689	: V=1.029361, theta=-45.589399 -> V=1.0, theta=0.0
% INFO    : Bus 3690	: V=1.018828, theta=-29.278078 -> V=1.0, theta=0.0
% INFO    : Bus 3691	: V=1.030004, theta=12.928231 -> V=1.0, theta=0.0
% INFO    : Bus 3692	: V=1.024383, theta=-42.674931 -> V=1.0, theta=0.0
% INFO    : Bus 3693	: V=1.007682, theta=3.259225 -> V=1.0, theta=0.0
% INFO    : Bus 3694	: V=1.013472, theta=-5.932551 -> V=1.0, theta=0.0
% INFO    : Bus 3695	: V=1.0156, theta=-28.615692 -> V=1.0, theta=0.0
% INFO    : Bus 3696	: V=1.041264, theta=-30.043549 -> V=1.0, theta=0.0
% INFO    : Bus 3697	: V=1.0464, theta=-20.856428 -> V=1.0, theta=0.0
% INFO    : Bus 3698	: V=1.039409, theta=-24.639936 -> V=1.0, theta=0.0
% INFO    : Bus 3699	: V=1.068441, theta=-48.37893 -> V=1.0, theta=0.0
% INFO    : Bus 3700	: V=1.001182, theta=-24.476336 -> V=1.0, theta=0.0
% INFO    : Bus 3701	: V=1.04365, theta=-25.354476 -> V=1.0, theta=0.0
% INFO    : Bus 3702	: V=1.040283, theta=-21.72381 -> V=1.0, theta=0.0
% INFO    : Bus 3703	: V=1.019123, theta=-22.652098 -> V=1.0, theta=0.0
% INFO    : Bus 3704	: V=0.991297, theta=-30.713122 -> V=1.0, theta=0.0
% INFO    : Bus 3705	: V=1.015587, theta=-36.522251 -> V=1.0, theta=0.0
% INFO    : Bus 3706	: V=1.00948, theta=-20.294045 -> V=1.0, theta=0.0
% INFO    : Bus 3707	: V=1.042205, theta=-15.70797 -> V=1.0, theta=0.0
% INFO    : Bus 3708	: V=1.035938, theta=3.727934 -> V=1.0, theta=0.0
% INFO    : Bus 3709	: V=1.020456, theta=-5.269925 -> V=1.0, theta=0.0
% INFO    : Bus 3710	: V=1.040313, theta=-26.941454 -> V=1.0, theta=0.0
% INFO    : Bus 3711	: V=0.999169, theta=-39.203039 -> V=1.0, theta=0.0
% INFO    : Bus 3712	: V=1.027334, theta=3.504304 -> V=1.0, theta=0.0
% INFO    : Bus 3713	: V=1.016072, theta=-22.733185 -> V=1.0, theta=0.0
% INFO    : Bus 3714	: V=1.04883, theta=-8.994879 -> V=1.0, theta=0.0
% INFO    : Bus 3715	: V=1.021862, theta=-48.907312 -> V=1.0, theta=0.0
% INFO    : Bus 3716	: V=1.017439, theta=-13.963996 -> V=1.0, theta=0.0
% INFO    : Bus 3717	: V=1.058098, theta=-27.28061 -> V=1.0, theta=0.0
% INFO    : Bus 3718	: V=1.041371, theta=-25.581584 -> V=1.0, theta=0.0
% INFO    : Bus 3719	: V=1.032431, theta=-38.880183 -> V=1.0, theta=0.0
% INFO    : Bus 3720	: V=1.050724, theta=-2.16522 -> V=1.0, theta=0.0
% INFO    : Bus 3721	: V=1.01754, theta=-47.965957 -> V=1.0, theta=0.0
% INFO    : Bus 3722	: V=1.015245, theta=-30.961669 -> V=1.0, theta=0.0
% INFO    : Bus 3723	: V=1.048349, theta=49.380362 -> V=1.0, theta=0.0
% INFO    : Bus 3724	: V=1.020045, theta=-9.45686 -> V=1.0, theta=0.0
% INFO    : Bus 3725	: V=1.033935, theta=-30.806474 -> V=1.0, theta=0.0
% INFO    : Bus 3726	: V=1.040597, theta=-40.004223 -> V=1.0, theta=0.0
% INFO    : Bus 3727	: V=1.032763, theta=7.097249 -> V=1.0, theta=0.0
% INFO    : Bus 3728	: V=1.028811, theta=-53.237993 -> V=1.0, theta=0.0
% INFO    : Bus 3729	: V=1.08063, theta=-12.865076 -> V=1.0, theta=0.0
% INFO    : Bus 3730	: V=0.982534, theta=-21.666771 -> V=1.0, theta=0.0
% INFO    : Bus 3731	: V=1.045331, theta=-16.015346 -> V=1.0, theta=0.0
% INFO    : Bus 3732	: V=1.02505, theta=-13.957262 -> V=1.0, theta=0.0
% INFO    : Bus 3733	: V=1.007979, theta=-23.863667 -> V=1.0, theta=0.0
% INFO    : Bus 3734	: V=1.02085, theta=-47.275913 -> V=1.0, theta=0.0
% INFO    : Bus 3735	: V=0.993103, theta=-32.678683 -> V=1.0, theta=0.0
% INFO    : Bus 3736	: V=1.01133, theta=-58.622336 -> V=1.0, theta=0.0
% INFO    : Bus 3737	: V=1.032515, theta=-3.354012 -> V=1.0, theta=0.0
% INFO    : Bus 3738	: V=0.969277, theta=-33.47506 -> V=1.0, theta=0.0
% INFO    : Bus 3739	: V=1.035011, theta=49.103214 -> V=1.0, theta=0.0
% INFO    : Bus 3740	: V=1.034825, theta=-21.527104 -> V=1.0, theta=0.0
% INFO    : Bus 3741	: V=1.029075, theta=0.423962 -> V=1.0, theta=0.0
% INFO    : Bus 3742	: V=1.029537, theta=-22.781849 -> V=1.0, theta=0.0
% INFO    : Bus 3743	: V=1.026432, theta=64.598966 -> V=1.0, theta=0.0
% INFO    : Bus 3744	: V=1.021254, theta=-47.060128 -> V=1.0, theta=0.0
% INFO    : Bus 3745	: V=0.998625, theta=-31.326971 -> V=1.0, theta=0.0
% INFO    : Bus 3746	: V=1.035948, theta=-26.006613 -> V=1.0, theta=0.0
% INFO    : Bus 3747	: V=1.023444, theta=-53.632832 -> V=1.0, theta=0.0
% INFO    : Bus 3748	: V=1.022204, theta=-29.051332 -> V=1.0, theta=0.0
% INFO    : Bus 3749	: V=1.044531, theta=-17.68671 -> V=1.0, theta=0.0
% INFO    : Bus 3750	: V=1.066155, theta=-26.745554 -> V=1.0, theta=0.0
% INFO    : Bus 3751	: V=0.999949, theta=-18.815407 -> V=1.0, theta=0.0
% INFO    : Bus 3752	: V=0.970786, theta=-24.576145 -> V=1.0, theta=0.0
% INFO    : Bus 3753	: V=1.055722, theta=9.871976 -> V=1.0, theta=0.0
% INFO    : Bus 3754	: V=1.035766, theta=-39.401367 -> V=1.0, theta=0.0
% INFO    : Bus 3755	: V=0.993935, theta=-23.515599 -> V=1.0, theta=0.0
% INFO    : Bus 3756	: V=1.018418, theta=-29.345862 -> V=1.0, theta=0.0
% INFO    : Bus 3757	: V=1.009695, theta=-36.71181 -> V=1.0, theta=0.0
% INFO    : Bus 3758	: V=1.020395, theta=-19.293122 -> V=1.0, theta=0.0
% INFO    : Bus 3759	: V=1.031969, theta=48.203983 -> V=1.0, theta=0.0
% INFO    : Bus 3760	: V=1.053243, theta=-21.24519 -> V=1.0, theta=0.0
% INFO    : Bus 3761	: V=1.036413, theta=-17.713414 -> V=1.0, theta=0.0
% INFO    : Bus 3762	: V=1.020714, theta=-6.273053 -> V=1.0, theta=0.0
% INFO    : Bus 3763	: V=1.039391, theta=-27.930465 -> V=1.0, theta=0.0
% INFO    : Bus 3764	: V=0.999708, theta=-27.06631 -> V=1.0, theta=0.0
% INFO    : Bus 3765	: V=1.037361, theta=-23.418438 -> V=1.0, theta=0.0
% INFO    : Bus 3766	: V=1.0335, theta=-5.773065 -> V=1.0, theta=0.0
% INFO    : Bus 3767	: V=1.044123, theta=-48.905275 -> V=1.0, theta=0.0
% INFO    : Bus 3768	: V=1.038574, theta=-22.203887 -> V=1.0, theta=0.0
% INFO    : Bus 3769	: V=1.021894, theta=-45.791424 -> V=1.0, theta=0.0
% INFO    : Bus 3770	: V=0.987648, theta=-31.926626 -> V=1.0, theta=0.0
% INFO    : Bus 3771	: V=1.020138, theta=-1.224966 -> V=1.0, theta=0.0
% INFO    : Bus 3772	: V=1.047921, theta=6.46881 -> V=1.0, theta=0.0
% INFO    : Bus 3773	: V=1.058639, theta=-33.269095 -> V=1.0, theta=0.0
% INFO    : Bus 3774	: V=0.935503, theta=-34.665326 -> V=1.0, theta=0.0
% INFO    : Bus 3775	: V=1.00144, theta=-23.546474 -> V=1.0, theta=0.0
% INFO    : Bus 3776	: V=1.022576, theta=11.004156 -> V=1.0, theta=0.0
% INFO    : Bus 3777	: V=0.998564, theta=7.675291 -> V=1.0, theta=0.0
% INFO    : Bus 3778	: V=1.057766, theta=-25.840464 -> V=1.0, theta=0.0
% INFO    : Bus 3779	: V=1.091216, theta=-27.852933 -> V=1.0, theta=0.0
% INFO    : Bus 3780	: V=1.028604, theta=38.481234 -> V=1.0, theta=0.0
% INFO    : Bus 3781	: V=1.035901, theta=-26.094417 -> V=1.0, theta=0.0
% INFO    : Bus 3782	: V=1.02915, theta=-5.086551 -> V=1.0, theta=0.0
% INFO    : Bus 3783	: V=1.03166, theta=-14.770149 -> V=1.0, theta=0.0
% INFO    : Bus 3784	: V=1.058319, theta=11.041843 -> V=1.0, theta=0.0
% INFO    : Bus 3785	: V=1.011918, theta=-5.392793 -> V=1.0, theta=0.0
% INFO    : Bus 3786	: V=1.040861, theta=-19.805642 -> V=1.0, theta=0.0
% INFO    : Bus 3787	: V=1.031362, theta=13.632437 -> V=1.0, theta=0.0
% INFO    : Bus 3788	: V=1.050359, theta=-26.33833 -> V=1.0, theta=0.0
% INFO    : Bus 3789	: V=1.025184, theta=17.266234 -> V=1.0, theta=0.0
% INFO    : Bus 3790	: V=1.041201, theta=-28.036796 -> V=1.0, theta=0.0
% INFO    : Bus 3791	: V=0.995335, theta=-40.34716 -> V=1.0, theta=0.0
% INFO    : Bus 3792	: V=1.052349, theta=-44.345634 -> V=1.0, theta=0.0
% INFO    : Bus 3793	: V=1.030761, theta=-20.931618 -> V=1.0, theta=0.0
% INFO    : Bus 3794	: V=1.028017, theta=-28.383082 -> V=1.0, theta=0.0
% INFO    : Bus 3795	: V=0.982538, theta=-27.706633 -> V=1.0, theta=0.0
% INFO    : Bus 3796	: V=1.051732, theta=-25.18782 -> V=1.0, theta=0.0
% INFO    : Bus 3797	: V=1.060935, theta=18.234389 -> V=1.0, theta=0.0
% INFO    : Bus 3798	: V=1.063213, theta=-41.590854 -> V=1.0, theta=0.0
% INFO    : Bus 3799	: V=1.031586, theta=15.134334 -> V=1.0, theta=0.0
% INFO    : Bus 3800	: V=1.036528, theta=17.026278 -> V=1.0, theta=0.0
% INFO    : Bus 3801	: V=1.014626, theta=-38.774067 -> V=1.0, theta=0.0
% INFO    : Bus 3802	: V=1.064117, theta=-26.171152 -> V=1.0, theta=0.0
% INFO    : Bus 3803	: V=1.020288, theta=-8.413808 -> V=1.0, theta=0.0
% INFO    : Bus 3804	: V=0.986796, theta=-28.076796 -> V=1.0, theta=0.0
% INFO    : Bus 3805	: V=0.931189, theta=-32.565723 -> V=1.0, theta=0.0
% INFO    : Bus 3806	: V=1.036116, theta=-28.47287 -> V=1.0, theta=0.0
% INFO    : Bus 3807	: V=1.007444, theta=-16.522529 -> V=1.0, theta=0.0
% INFO    : Bus 3808	: V=1.073884, theta=10.845509 -> V=1.0, theta=0.0
% INFO    : Bus 3809	: V=1.081564, theta=-34.264616 -> V=1.0, theta=0.0
% INFO    : Bus 3810	: V=1.038535, theta=-8.84055 -> V=1.0, theta=0.0
% INFO    : Bus 3811	: V=1.030166, theta=-36.340808 -> V=1.0, theta=0.0
% INFO    : Bus 3812	: V=0.964929, theta=-31.486598 -> V=1.0, theta=0.0
% INFO    : Bus 3813	: V=1.021403, theta=-54.029162 -> V=1.0, theta=0.0
% INFO    : Bus 3814	: V=1.037722, theta=-22.267714 -> V=1.0, theta=0.0
% INFO    : Bus 3815	: V=0.990982, theta=-26.200522 -> V=1.0, theta=0.0
% INFO    : Bus 3816	: V=1.004119, theta=-50.618066 -> V=1.0, theta=0.0
% INFO    : Bus 3817	: V=1.082789, theta=-15.473434 -> V=1.0, theta=0.0
% INFO    : Bus 3818	: V=1.038479, theta=-26.123299 -> V=1.0, theta=0.0
% INFO    : Bus 3819	: V=1.014365, theta=-5.042182 -> V=1.0, theta=0.0
% INFO    : Bus 3820	: V=1.029328, theta=-34.111494 -> V=1.0, theta=0.0
% INFO    : Bus 3821	: V=1.022257, theta=-39.179203 -> V=1.0, theta=0.0
% INFO    : Bus 3822	: V=1.02071, theta=6.692511 -> V=1.0, theta=0.0
% INFO    : Bus 3823	: V=1.036489, theta=-44.778533 -> V=1.0, theta=0.0
% INFO    : Bus 3824	: V=0.983081, theta=-31.410789 -> V=1.0, theta=0.0
% INFO    : Bus 3825	: V=1.024468, theta=-8.742214 -> V=1.0, theta=0.0
% INFO    : Bus 3826	: V=1.017955, theta=-36.045837 -> V=1.0, theta=0.0
% INFO    : Bus 3827	: V=1.041472, theta=0.343332 -> V=1.0, theta=0.0
% INFO    : Bus 3828	: V=0.983046, theta=-21.891128 -> V=1.0, theta=0.0
% INFO    : Bus 3829	: V=0.944418, theta=-32.587786 -> V=1.0, theta=0.0
% INFO    : Bus 3830	: V=0.990018, theta=-14.047581 -> V=1.0, theta=0.0
% INFO    : Bus 3831	: V=1.028921, theta=-29.481204 -> V=1.0, theta=0.0
% INFO    : Bus 3832	: V=0.993255, theta=-26.502145 -> V=1.0, theta=0.0
% INFO    : Bus 3833	: V=0.988667, theta=-26.331209 -> V=1.0, theta=0.0
% INFO    : Bus 3834	: V=1.032203, theta=-22.593387 -> V=1.0, theta=0.0
% INFO    : Bus 3835	: V=1.009608, theta=-11.135296 -> V=1.0, theta=0.0
% INFO    : Bus 3836	: V=1.001472, theta=-44.645173 -> V=1.0, theta=0.0
% INFO    : Bus 3837	: V=0.997079, theta=-32.31357 -> V=1.0, theta=0.0
% INFO    : Bus 3838	: V=1.028571, theta=-38.295607 -> V=1.0, theta=0.0
% INFO    : Bus 3839	: V=1.008217, theta=-32.065747 -> V=1.0, theta=0.0
% INFO    : Bus 3840	: V=1.027073, theta=-44.570683 -> V=1.0, theta=0.0
% INFO    : Bus 3841	: V=1.03976, theta=-15.031301 -> V=1.0, theta=0.0
% INFO    : Bus 3842	: V=1.005181, theta=-21.152822 -> V=1.0, theta=0.0
% INFO    : Bus 3843	: V=1.012416, theta=-44.582275 -> V=1.0, theta=0.0
% INFO    : Bus 3844	: V=1.046985, theta=-4.119378 -> V=1.0, theta=0.0
% INFO    : Bus 3845	: V=1.017228, theta=2.936461 -> V=1.0, theta=0.0
% INFO    : Bus 3846	: V=1.021343, theta=10.878691 -> V=1.0, theta=0.0
% INFO    : Bus 3847	: V=0.986826, theta=-30.310885 -> V=1.0, theta=0.0
% INFO    : Bus 3848	: V=1.033356, theta=3.492423 -> V=1.0, theta=0.0
% INFO    : Bus 3849	: V=1.005911, theta=-33.771512 -> V=1.0, theta=0.0
% INFO    : Bus 3850	: V=1.039563, theta=-15.021363 -> V=1.0, theta=0.0
% INFO    : Bus 3851	: V=1.022667, theta=62.987741 -> V=1.0, theta=0.0
% INFO    : Bus 3852	: V=1.063393, theta=33.536857 -> V=1.0, theta=0.0
% INFO    : Bus 3853	: V=1.080197, theta=-12.455971 -> V=1.0, theta=0.0
% INFO    : Bus 3854	: V=0.977713, theta=11.366736 -> V=1.0, theta=0.0
% INFO    : Bus 3855	: V=1.069795, theta=-26.566752 -> V=1.0, theta=0.0
% INFO    : Bus 3856	: V=1.02737, theta=-34.077286 -> V=1.0, theta=0.0
% INFO    : Bus 3857	: V=1.074004, theta=-23.723781 -> V=1.0, theta=0.0
% INFO    : Bus 3858	: V=1.03237, theta=-25.842451 -> V=1.0, theta=0.0
% INFO    : Bus 3859	: V=1.041425, theta=-2.993357 -> V=1.0, theta=0.0
% INFO    : Bus 3860	: V=1.036486, theta=59.825516 -> V=1.0, theta=0.0
% INFO    : Bus 3861	: V=1.035472, theta=-24.231604 -> V=1.0, theta=0.0
% INFO    : Bus 3862	: V=1.025684, theta=2.642027 -> V=1.0, theta=0.0
% INFO    : Bus 3863	: V=1.010567, theta=-29.732557 -> V=1.0, theta=0.0
% INFO    : Bus 3864	: V=1.028747, theta=-21.380405 -> V=1.0, theta=0.0
% INFO    : Bus 3865	: V=1.025528, theta=-15.028298 -> V=1.0, theta=0.0
% INFO    : Bus 3866	: V=1.049401, theta=-28.018776 -> V=1.0, theta=0.0
% INFO    : Bus 3867	: V=1.027292, theta=-29.311327 -> V=1.0, theta=0.0
% INFO    : Bus 3868	: V=1.020133, theta=0.828151 -> V=1.0, theta=0.0
% INFO    : Bus 3869	: V=1.028967, theta=0.907249 -> V=1.0, theta=0.0
% INFO    : Bus 3870	: V=1.023622, theta=-1.201992 -> V=1.0, theta=0.0
% INFO    : Bus 3871	: V=0.995472, theta=-50.925622 -> V=1.0, theta=0.0
% INFO    : Bus 3872	: V=1.028094, theta=-6.486951 -> V=1.0, theta=0.0
% INFO    : Bus 3873	: V=0.98774, theta=-18.128573 -> V=1.0, theta=0.0
% INFO    : Bus 3874	: V=1.048573, theta=-15.840108 -> V=1.0, theta=0.0
% INFO    : Bus 3875	: V=1.052577, theta=-24.982026 -> V=1.0, theta=0.0
% INFO    : Bus 3876	: V=1.04066, theta=-9.801695 -> V=1.0, theta=0.0
% INFO    : Bus 3877	: V=1.017804, theta=-15.067134 -> V=1.0, theta=0.0
% INFO    : Bus 3878	: V=1.03299, theta=21.738093 -> V=1.0, theta=0.0
% INFO    : Bus 3879	: V=1.042235, theta=-25.413451 -> V=1.0, theta=0.0
% INFO    : Bus 3880	: V=1.065391, theta=-11.831636 -> V=1.0, theta=0.0
% INFO    : Bus 3881	: V=0.988893, theta=-27.264103 -> V=1.0, theta=0.0
% INFO    : Bus 3882	: V=1.016182, theta=-24.995584 -> V=1.0, theta=0.0
% INFO    : Bus 3883	: V=1.016025, theta=-22.642882 -> V=1.0, theta=0.0
% INFO    : Bus 3884	: V=1.041428, theta=-27.961037 -> V=1.0, theta=0.0
% INFO    : Bus 3885	: V=1.047858, theta=-16.613454 -> V=1.0, theta=0.0
% INFO    : Bus 3886	: V=1.014676, theta=8.853104 -> V=1.0, theta=0.0
% INFO    : Bus 3887	: V=1.048305, theta=-20.831942 -> V=1.0, theta=0.0
% INFO    : Bus 3888	: V=1.064956, theta=-24.323541 -> V=1.0, theta=0.0
% INFO    : Bus 3889	: V=1.017503, theta=-27.418905 -> V=1.0, theta=0.0
% INFO    : Bus 3890	: V=1.031901, theta=-22.759508 -> V=1.0, theta=0.0
% INFO    : Bus 3891	: V=1.043299, theta=15.804627 -> V=1.0, theta=0.0
% INFO    : Bus 3892	: V=1.037667, theta=-36.041159 -> V=1.0, theta=0.0
% INFO    : Bus 3893	: V=1.05529, theta=-17.093776 -> V=1.0, theta=0.0
% INFO    : Bus 3894	: V=1.022407, theta=-15.481544 -> V=1.0, theta=0.0
% INFO    : Bus 3895	: V=1.03666, theta=-28.392836 -> V=1.0, theta=0.0
% INFO    : Bus 3896	: V=1.004806, theta=-39.948467 -> V=1.0, theta=0.0
% INFO    : Bus 3897	: V=1.063019, theta=-25.581302 -> V=1.0, theta=0.0
% INFO    : Bus 3898	: V=1.002855, theta=-1.928796 -> V=1.0, theta=0.0
% INFO    : Bus 3899	: V=0.955225, theta=-29.860405 -> V=1.0, theta=0.0
% INFO    : Bus 3900	: V=1.061016, theta=-22.918735 -> V=1.0, theta=0.0
% INFO    : Bus 3901	: V=0.965876, theta=-32.241266 -> V=1.0, theta=0.0
% INFO    : Bus 3902	: V=0.995358, theta=-27.065993 -> V=1.0, theta=0.0
% INFO    : Bus 3903	: V=1.046996, theta=-24.842582 -> V=1.0, theta=0.0
% INFO    : Bus 3904	: V=0.973906, theta=-28.572412 -> V=1.0, theta=0.0
% INFO    : Bus 3905	: V=0.983021, theta=9.191641 -> V=1.0, theta=0.0
% INFO    : Bus 3906	: V=1.033983, theta=-13.62493 -> V=1.0, theta=0.0
% INFO    : Bus 3907	: V=1.025805, theta=9.632959 -> V=1.0, theta=0.0
% INFO    : Bus 3908	: V=0.982046, theta=-29.027646 -> V=1.0, theta=0.0
% INFO    : Bus 3909	: V=1.030915, theta=-10.701167 -> V=1.0, theta=0.0
% INFO    : Bus 3910	: V=1.069291, theta=19.435434 -> V=1.0, theta=0.0
% INFO    : Bus 3911	: V=1.081005, theta=-21.199935 -> V=1.0, theta=0.0
% INFO    : Bus 3912	: V=1.035094, theta=-21.386174 -> V=1.0, theta=0.0
% INFO    : Bus 3913	: V=1.00287, theta=-8.369051 -> V=1.0, theta=0.0
% INFO    : Bus 3914	: V=0.971068, theta=-32.261085 -> V=1.0, theta=0.0
% INFO    : Bus 3915	: V=1.079222, theta=-12.471756 -> V=1.0, theta=0.0
% INFO    : Bus 3916	: V=1.039177, theta=-14.333423 -> V=1.0, theta=0.0
% INFO    : Bus 3917	: V=0.992675, theta=-31.608578 -> V=1.0, theta=0.0
% INFO    : Bus 3918	: V=1.020637, theta=-2.16455 -> V=1.0, theta=0.0
% INFO    : Bus 3919	: V=1.025031, theta=-6.086566 -> V=1.0, theta=0.0
% INFO    : Bus 3920	: V=1.064621, theta=1.351316 -> V=1.0, theta=0.0
% INFO    : Bus 3921	: V=1.001231, theta=-20.204666 -> V=1.0, theta=0.0
% INFO    : Bus 3922	: V=1.07194, theta=12.761553 -> V=1.0, theta=0.0
% INFO    : Bus 3923	: V=1.03489, theta=-19.865903 -> V=1.0, theta=0.0
% INFO    : Bus 3924	: V=1.048868, theta=-28.613564 -> V=1.0, theta=0.0
% INFO    : Bus 3925	: V=1.024217, theta=-13.307404 -> V=1.0, theta=0.0
% INFO    : Bus 3926	: V=1.003405, theta=-43.226976 -> V=1.0, theta=0.0
% INFO    : Bus 3927	: V=0.917414, theta=-35.806411 -> V=1.0, theta=0.0
% INFO    : Bus 3928	: V=1.044126, theta=-4.978831 -> V=1.0, theta=0.0
% INFO    : Bus 3929	: V=1.028838, theta=-20.533141 -> V=1.0, theta=0.0
% INFO    : Bus 3930	: V=1.042095, theta=27.099563 -> V=1.0, theta=0.0
% INFO    : Bus 3931	: V=1.029087, theta=62.729982 -> V=1.0, theta=0.0
% INFO    : Bus 3932	: V=1.026753, theta=-34.842553 -> V=1.0, theta=0.0
% INFO    : Bus 3933	: V=1.002413, theta=-30.25303 -> V=1.0, theta=0.0
% INFO    : Bus 3934	: V=0.998415, theta=5.424314 -> V=1.0, theta=0.0
% INFO    : Bus 3935	: V=1.041388, theta=-5.736526 -> V=1.0, theta=0.0
% INFO    : Bus 3936	: V=1.03405, theta=-33.85919 -> V=1.0, theta=0.0
% INFO    : Bus 3937	: V=1.021808, theta=-43.507932 -> V=1.0, theta=0.0
% INFO    : Bus 3938	: V=1.049226, theta=-0.339481 -> V=1.0, theta=0.0
% INFO    : Bus 3939	: V=1.020565, theta=-18.201653 -> V=1.0, theta=0.0
% INFO    : Bus 3940	: V=1.018221, theta=-10.942619 -> V=1.0, theta=0.0
% INFO    : Bus 3941	: V=0.958492, theta=-30.478094 -> V=1.0, theta=0.0
% INFO    : Bus 3942	: V=1.027536, theta=-36.381609 -> V=1.0, theta=0.0
% INFO    : Bus 3943	: V=1.019158, theta=6.298048 -> V=1.0, theta=0.0
% INFO    : Bus 3944	: V=1.02866, theta=-13.120921 -> V=1.0, theta=0.0
% INFO    : Bus 3945	: V=1.037147, theta=-17.758493 -> V=1.0, theta=0.0
% INFO    : Bus 3946	: V=1.015015, theta=-30.091097 -> V=1.0, theta=0.0
% INFO    : Bus 3947	: V=0.98294, theta=9.18829 -> V=1.0, theta=0.0
% INFO    : Bus 3948	: V=1.03639, theta=-37.486103 -> V=1.0, theta=0.0
% INFO    : Bus 3949	: V=1.052164, theta=-12.244761 -> V=1.0, theta=0.0
% INFO    : Bus 3950	: V=1.035258, theta=34.769482 -> V=1.0, theta=0.0
% INFO    : Bus 3951	: V=1.03485, theta=-13.335873 -> V=1.0, theta=0.0
% INFO    : Bus 3952	: V=0.952264, theta=-30.671125 -> V=1.0, theta=0.0
% INFO    : Bus 3953	: V=1.031948, theta=6.614385 -> V=1.0, theta=0.0
% INFO    : Bus 3954	: V=0.975077, theta=-56.829144 -> V=1.0, theta=0.0
% INFO    : Bus 3955	: V=0.962335, theta=-15.73451 -> V=1.0, theta=0.0
% INFO    : Bus 3956	: V=1.044996, theta=-24.413265 -> V=1.0, theta=0.0
% INFO    : Bus 3957	: V=1.001778, theta=-45.153027 -> V=1.0, theta=0.0
% INFO    : Bus 3958	: V=1.034533, theta=-34.836278 -> V=1.0, theta=0.0
% INFO    : Bus 3959	: V=1.052799, theta=9.681964 -> V=1.0, theta=0.0
% INFO    : Bus 3960	: V=1.034466, theta=9.04075 -> V=1.0, theta=0.0
% INFO    : Bus 3961	: V=1.006923, theta=-48.154846 -> V=1.0, theta=0.0
% INFO    : Bus 3962	: V=1.036556, theta=-24.058669 -> V=1.0, theta=0.0
% INFO    : Bus 3963	: V=1.020596, theta=-46.298437 -> V=1.0, theta=0.0
% INFO    : Bus 3964	: V=0.995855, theta=-26.915906 -> V=1.0, theta=0.0
% INFO    : Bus 3965	: V=0.977329, theta=-31.493768 -> V=1.0, theta=0.0
% INFO    : Bus 3966	: V=1.042714, theta=-43.322909 -> V=1.0, theta=0.0
% INFO    : Bus 3967	: V=1.059299, theta=-21.998958 -> V=1.0, theta=0.0
% INFO    : Bus 3968	: V=1.048237, theta=18.202352 -> V=1.0, theta=0.0
% INFO    : Bus 3969	: V=1.016279, theta=-10.549563 -> V=1.0, theta=0.0
% INFO    : Bus 3970	: V=0.959234, theta=-30.149348 -> V=1.0, theta=0.0
% INFO    : Bus 3971	: V=1.053061, theta=-9.118186 -> V=1.0, theta=0.0
% INFO    : Bus 3972	: V=1.02952, theta=-15.684934 -> V=1.0, theta=0.0
% INFO    : Bus 3973	: V=1.038157, theta=-28.281886 -> V=1.0, theta=0.0
% INFO    : Bus 3974	: V=1.022625, theta=3.874386 -> V=1.0, theta=0.0
% INFO    : Bus 3975	: V=0.98597, theta=-24.863841 -> V=1.0, theta=0.0
% INFO    : Bus 3976	: V=1.024952, theta=3.133455 -> V=1.0, theta=0.0
% INFO    : Bus 3977	: V=1.033288, theta=-2.962765 -> V=1.0, theta=0.0
% INFO    : Bus 3978	: V=1.093267, theta=-33.294124 -> V=1.0, theta=0.0
% INFO    : Bus 3979	: V=1.027309, theta=-1.718871 -> V=1.0, theta=0.0
% INFO    : Bus 3980	: V=1.014725, theta=-2.51955 -> V=1.0, theta=0.0
% INFO    : Bus 3981	: V=1.064123, theta=-19.939188 -> V=1.0, theta=0.0
% INFO    : Bus 3982	: V=1.018498, theta=1.671347 -> V=1.0, theta=0.0
% INFO    : Bus 3983	: V=1.014828, theta=16.462462 -> V=1.0, theta=0.0
% INFO    : Bus 3984	: V=1.023174, theta=-26.038202 -> V=1.0, theta=0.0
% INFO    : Bus 3985	: V=1.043935, theta=-0.168775 -> V=1.0, theta=0.0
% INFO    : Bus 3986	: V=0.995145, theta=-27.217275 -> V=1.0, theta=0.0
% INFO    : Bus 3987	: V=1.019043, theta=-33.538829 -> V=1.0, theta=0.0
% INFO    : Bus 3988	: V=1.032522, theta=-26.401538 -> V=1.0, theta=0.0
% INFO    : Bus 3989	: V=0.998086, theta=-22.778757 -> V=1.0, theta=0.0
% INFO    : Bus 3990	: V=1.051551, theta=-49.108929 -> V=1.0, theta=0.0
% INFO    : Bus 3991	: V=1.035055, theta=3.238867 -> V=1.0, theta=0.0
% INFO    : Bus 3992	: V=0.98201, theta=-27.314622 -> V=1.0, theta=0.0
% INFO    : Bus 3993	: V=1.055754, theta=-27.405779 -> V=1.0, theta=0.0
% INFO    : Bus 3994	: V=1.032031, theta=-3.028214 -> V=1.0, theta=0.0
% INFO    : Bus 3995	: V=0.956693, theta=-31.59276 -> V=1.0, theta=0.0
% INFO    : Bus 3996	: V=1.034652, theta=-6.592997 -> V=1.0, theta=0.0
% INFO    : Bus 3997	: V=1.037337, theta=-12.258676 -> V=1.0, theta=0.0
% INFO    : Bus 3998	: V=0.997561, theta=-29.542302 -> V=1.0, theta=0.0
% INFO    : Bus 3999	: V=1.047269, theta=-6.708317 -> V=1.0, theta=0.0
% INFO    : Bus 4000	: V=0.987988, theta=-15.802118 -> V=1.0, theta=0.0
% INFO    : Bus 4001	: V=1.025871, theta=12.586597 -> V=1.0, theta=0.0
% INFO    : Bus 4002	: V=1.058927, theta=17.854873 -> V=1.0, theta=0.0
% INFO    : Bus 4003	: V=1.043581, theta=-12.669131 -> V=1.0, theta=0.0
% INFO    : Bus 4004	: V=1.020362, theta=-29.475309 -> V=1.0, theta=0.0
% INFO    : Bus 4005	: V=1.060797, theta=-32.050564 -> V=1.0, theta=0.0
% INFO    : Bus 4006	: V=1.021595, theta=10.57369 -> V=1.0, theta=0.0
% INFO    : Bus 4007	: V=1.017324, theta=-22.243506 -> V=1.0, theta=0.0
% INFO    : Bus 4008	: V=1.069936, theta=-25.232127 -> V=1.0, theta=0.0
% INFO    : Bus 4009	: V=1.043192, theta=-8.175707 -> V=1.0, theta=0.0
% INFO    : Bus 4010	: V=1.016756, theta=-40.50939 -> V=1.0, theta=0.0
% INFO    : Bus 4011	: V=1.025129, theta=-54.334861 -> V=1.0, theta=0.0
% INFO    : Bus 4012	: V=1.04188, theta=62.600682 -> V=1.0, theta=0.0
% INFO    : Bus 4013	: V=0.984886, theta=-56.240492 -> V=1.0, theta=0.0
% INFO    : Bus 4014	: V=1.02664, theta=-13.635302 -> V=1.0, theta=0.0
% INFO    : Bus 4015	: V=0.993458, theta=-30.724811 -> V=1.0, theta=0.0
% INFO    : Bus 4016	: V=1.022786, theta=-43.184654 -> V=1.0, theta=0.0
% INFO    : Bus 4017	: V=1.073977, theta=-49.479938 -> V=1.0, theta=0.0
% INFO    : Bus 4018	: V=0.971505, theta=-27.269578 -> V=1.0, theta=0.0
% INFO    : Bus 4019	: V=1.03341, theta=-39.158514 -> V=1.0, theta=0.0
% INFO    : Bus 4020	: V=1.042316, theta=-50.37737 -> V=1.0, theta=0.0
% INFO    : Bus 4021	: V=1.025368, theta=6.397762 -> V=1.0, theta=0.0
% INFO    : Bus 4022	: V=1.095409, theta=-31.632735 -> V=1.0, theta=0.0
% INFO    : Bus 4023	: V=1.029115, theta=1.738319 -> V=1.0, theta=0.0
% INFO    : Bus 4024	: V=1.029565, theta=2.288816 -> V=1.0, theta=0.0
% INFO    : Bus 4025	: V=1.032176, theta=-3.017042 -> V=1.0, theta=0.0
% INFO    : Bus 4026	: V=1.05562, theta=-41.532068 -> V=1.0, theta=0.0
% INFO    : Bus 4027	: V=1.046487, theta=-26.102165 -> V=1.0, theta=0.0
% INFO    : Bus 4028	: V=1.022221, theta=-28.502738 -> V=1.0, theta=0.0
% INFO    : Bus 4029	: V=0.960003, theta=-29.159918 -> V=1.0, theta=0.0
% INFO    : Bus 4030	: V=1.08382, theta=-28.028856 -> V=1.0, theta=0.0
% INFO    : Bus 4031	: V=1.054311, theta=-11.010018 -> V=1.0, theta=0.0
% INFO    : Bus 4032	: V=0.997508, theta=-11.76106 -> V=1.0, theta=0.0
% INFO    : Bus 4033	: V=1.025548, theta=56.993309 -> V=1.0, theta=0.0
% INFO    : Bus 4034	: V=1.001466, theta=-26.170849 -> V=1.0, theta=0.0
% INFO    : Bus 4035	: V=1.030419, theta=-21.593477 -> V=1.0, theta=0.0
% INFO    : Bus 4036	: V=1.041024, theta=-27.643985 -> V=1.0, theta=0.0
% INFO    : Bus 4037	: V=1.032069, theta=-19.610125 -> V=1.0, theta=0.0
% INFO    : Bus 4038	: V=1.018873, theta=-36.406651 -> V=1.0, theta=0.0
% INFO    : Bus 4039	: V=1.033941, theta=-22.873209 -> V=1.0, theta=0.0
% INFO    : Bus 4040	: V=1.032406, theta=-18.580042 -> V=1.0, theta=0.0
% INFO    : Bus 4041	: V=1.034415, theta=29.478216 -> V=1.0, theta=0.0
% INFO    : Bus 4042	: V=1.031208, theta=-10.044032 -> V=1.0, theta=0.0
% INFO    : Bus 4043	: V=1.016992, theta=-10.480195 -> V=1.0, theta=0.0
% INFO    : Bus 4044	: V=1.04924, theta=-14.04151 -> V=1.0, theta=0.0
% INFO    : Bus 4045	: V=0.967919, theta=-28.718168 -> V=1.0, theta=0.0
% INFO    : Bus 4046	: V=1.071125, theta=-1.423326 -> V=1.0, theta=0.0
% INFO    : Bus 4047	: V=1.042383, theta=-17.618442 -> V=1.0, theta=0.0
% INFO    : Bus 4048	: V=1.038673, theta=-3.249222 -> V=1.0, theta=0.0
% INFO    : Bus 4049	: V=1.01536, theta=-10.191137 -> V=1.0, theta=0.0
% INFO    : Bus 4050	: V=1.05168, theta=3.848506 -> V=1.0, theta=0.0
% INFO    : Bus 4051	: V=1.043582, theta=13.183243 -> V=1.0, theta=0.0
% INFO    : Bus 4052	: V=1.059535, theta=49.902081 -> V=1.0, theta=0.0
% INFO    : Bus 4053	: V=0.98128, theta=-27.962853 -> V=1.0, theta=0.0
% INFO    : Bus 4054	: V=1.03161, theta=-18.751733 -> V=1.0, theta=0.0
% INFO    : Bus 4055	: V=1.043979, theta=-18.088298 -> V=1.0, theta=0.0
% INFO    : Bus 4056	: V=1.038451, theta=-9.852296 -> V=1.0, theta=0.0
% INFO    : Bus 4057	: V=1.039902, theta=8.020393 -> V=1.0, theta=0.0
% INFO    : Bus 4058	: V=1.005208, theta=-48.287338 -> V=1.0, theta=0.0
% INFO    : Bus 4059	: V=1.079468, theta=31.589738 -> V=1.0, theta=0.0
% INFO    : Bus 4060	: V=1.055551, theta=-15.2235 -> V=1.0, theta=0.0
% INFO    : Bus 4061	: V=1.008585, theta=-25.37963 -> V=1.0, theta=0.0
% INFO    : Bus 4062	: V=1.008647, theta=-48.903829 -> V=1.0, theta=0.0
% INFO    : Bus 4063	: V=1.060287, theta=-13.44471 -> V=1.0, theta=0.0
% INFO    : Bus 4064	: V=1.033499, theta=-3.54913 -> V=1.0, theta=0.0
% INFO    : Bus 4065	: V=1.019819, theta=-29.008702 -> V=1.0, theta=0.0
% INFO    : Bus 4066	: V=1.025394, theta=-25.953072 -> V=1.0, theta=0.0
% INFO    : Bus 4067	: V=1.025119, theta=-22.133999 -> V=1.0, theta=0.0
% INFO    : Bus 4068	: V=0.973947, theta=-32.243936 -> V=1.0, theta=0.0
% INFO    : Bus 4069	: V=1.003753, theta=-31.343984 -> V=1.0, theta=0.0
% INFO    : Bus 4070	: V=0.982693, theta=-27.895484 -> V=1.0, theta=0.0
% INFO    : Bus 4071	: V=1.026598, theta=2.362831 -> V=1.0, theta=0.0
% INFO    : Bus 4072	: V=0.984045, theta=-16.08228 -> V=1.0, theta=0.0
% INFO    : Bus 4073	: V=1.068179, theta=-26.714677 -> V=1.0, theta=0.0
% INFO    : Bus 4074	: V=1.025354, theta=-24.831739 -> V=1.0, theta=0.0
% INFO    : Bus 4075	: V=1.033829, theta=-10.847174 -> V=1.0, theta=0.0
% INFO    : Bus 4076	: V=1.042958, theta=4.479736 -> V=1.0, theta=0.0
% INFO    : Bus 4077	: V=1.043151, theta=16.235866 -> V=1.0, theta=0.0
% INFO    : Bus 4078	: V=1.024053, theta=-8.802712 -> V=1.0, theta=0.0
% INFO    : Bus 4079	: V=1.021796, theta=-28.526157 -> V=1.0, theta=0.0
% INFO    : Bus 4080	: V=1.060911, theta=-27.026792 -> V=1.0, theta=0.0
% INFO    : Bus 4081	: V=1.027834, theta=-53.268647 -> V=1.0, theta=0.0
% INFO    : Bus 4082	: V=1.031489, theta=12.027323 -> V=1.0, theta=0.0
% INFO    : Bus 4083	: V=1.005675, theta=-32.160727 -> V=1.0, theta=0.0
% INFO    : Bus 4084	: V=1.053107, theta=-9.058405 -> V=1.0, theta=0.0
% INFO    : Bus 4085	: V=1.028863, theta=38.500197 -> V=1.0, theta=0.0
% INFO    : Bus 4086	: V=1.018756, theta=-22.452168 -> V=1.0, theta=0.0
% INFO    : Bus 4087	: V=1.047271, theta=17.789624 -> V=1.0, theta=0.0
% INFO    : Bus 4088	: V=1.048087, theta=-20.442706 -> V=1.0, theta=0.0
% INFO    : Bus 4089	: V=0.996796, theta=-18.606163 -> V=1.0, theta=0.0
% INFO    : Bus 4090	: V=1.010258, theta=-24.552568 -> V=1.0, theta=0.0
% INFO    : Bus 4091	: V=1.119258, theta=-23.704462 -> V=1.0, theta=0.0
% INFO    : Bus 4092	: V=0.986344, theta=14.7005 -> V=1.0, theta=0.0
% INFO    : Bus 4093	: V=1.006283, theta=-27.062298 -> V=1.0, theta=0.0
% INFO    : Bus 4094	: V=1.026088, theta=-41.974953 -> V=1.0, theta=0.0
% INFO    : Bus 4095	: V=1.011773, theta=-58.826771 -> V=1.0, theta=0.0
% INFO    : Bus 4096	: V=1.009252, theta=-48.779933 -> V=1.0, theta=0.0
% INFO    : Bus 4097	: V=1.021071, theta=-6.030317 -> V=1.0, theta=0.0
% INFO    : Bus 4098	: V=0.962168, theta=-44.407983 -> V=1.0, theta=0.0
% INFO    : Bus 4099	: V=1.02402, theta=-17.261834 -> V=1.0, theta=0.0
% INFO    : Bus 4100	: V=1.068198, theta=-11.140706 -> V=1.0, theta=0.0
% INFO    : Bus 4101	: V=1.033704, theta=18.896597 -> V=1.0, theta=0.0
% INFO    : Bus 4102	: V=0.988737, theta=-18.009915 -> V=1.0, theta=0.0
% INFO    : Bus 4103	: V=1.032405, theta=-22.044842 -> V=1.0, theta=0.0
% INFO    : Bus 4104	: V=1.021613, theta=10.483701 -> V=1.0, theta=0.0
% INFO    : Bus 4105	: V=1.043143, theta=-3.069097 -> V=1.0, theta=0.0
% INFO    : Bus 4106	: V=1.022601, theta=-5.652252 -> V=1.0, theta=0.0
% INFO    : Bus 4107	: V=1.009935, theta=51.392856 -> V=1.0, theta=0.0
% INFO    : Bus 4108	: V=0.97339, theta=-23.920548 -> V=1.0, theta=0.0
% INFO    : Bus 4109	: V=1.031638, theta=6.730991 -> V=1.0, theta=0.0
% INFO    : Bus 4110	: V=1.045421, theta=0.527375 -> V=1.0, theta=0.0
% INFO    : Bus 4111	: V=1.048823, theta=-13.156135 -> V=1.0, theta=0.0
% INFO    : Bus 4112	: V=1.017139, theta=-45.032425 -> V=1.0, theta=0.0
% INFO    : Bus 4113	: V=1.017304, theta=-16.688031 -> V=1.0, theta=0.0
% INFO    : Bus 4114	: V=1.044271, theta=-24.809474 -> V=1.0, theta=0.0
% INFO    : Bus 4115	: V=1.042411, theta=-22.654062 -> V=1.0, theta=0.0
% INFO    : Bus 4116	: V=0.98368, theta=-51.197164 -> V=1.0, theta=0.0
% INFO    : Bus 4117	: V=1.010188, theta=30.86743 -> V=1.0, theta=0.0
% INFO    : Bus 4118	: V=1.025736, theta=-14.964695 -> V=1.0, theta=0.0
% INFO    : Bus 4119	: V=1.062772, theta=43.365819 -> V=1.0, theta=0.0
% INFO    : Bus 4120	: V=1.044239, theta=-25.077662 -> V=1.0, theta=0.0
% INFO    : Bus 4121	: V=1.021382, theta=14.426094 -> V=1.0, theta=0.0
% INFO    : Bus 4122	: V=1.016568, theta=36.384533 -> V=1.0, theta=0.0
% INFO    : Bus 4123	: V=0.989609, theta=-30.814829 -> V=1.0, theta=0.0
% INFO    : Bus 4124	: V=1.014009, theta=-45.930495 -> V=1.0, theta=0.0
% INFO    : Bus 4125	: V=1.002666, theta=-8.596461 -> V=1.0, theta=0.0
% INFO    : Bus 4126	: V=1.024485, theta=-13.787118 -> V=1.0, theta=0.0
% INFO    : Bus 4127	: V=1.029406, theta=-20.472049 -> V=1.0, theta=0.0
% INFO    : Bus 4128	: V=1.027647, theta=-15.463095 -> V=1.0, theta=0.0
% INFO    : Bus 4129	: V=1.011842, theta=61.759219 -> V=1.0, theta=0.0
% INFO    : Bus 4130	: V=1.015307, theta=10.365855 -> V=1.0, theta=0.0
% INFO    : Bus 4131	: V=1.034065, theta=-26.037778 -> V=1.0, theta=0.0
% INFO    : Bus 4132	: V=1.016338, theta=11.716163 -> V=1.0, theta=0.0
% INFO    : Bus 4133	: V=1.006942, theta=-49.469981 -> V=1.0, theta=0.0
% INFO    : Bus 4134	: V=1.069875, theta=-33.898771 -> V=1.0, theta=0.0
% INFO    : Bus 4135	: V=1.010695, theta=5.975283 -> V=1.0, theta=0.0
% INFO    : Bus 4136	: V=1.021921, theta=-31.27007 -> V=1.0, theta=0.0
% INFO    : Bus 4137	: V=1.005911, theta=-33.771512 -> V=1.0, theta=0.0
% INFO    : Bus 4138	: V=1.01547, theta=-32.204194 -> V=1.0, theta=0.0
% INFO    : Bus 4139	: V=1.025481, theta=5.379476 -> V=1.0, theta=0.0
% INFO    : Bus 4140	: V=1.013716, theta=-21.422838 -> V=1.0, theta=0.0
% INFO    : Bus 4141	: V=1.030132, theta=-21.352318 -> V=1.0, theta=0.0
% INFO    : Bus 4142	: V=1.062784, theta=-21.951534 -> V=1.0, theta=0.0
% INFO    : Bus 4143	: V=1.048779, theta=-1.219149 -> V=1.0, theta=0.0
% INFO    : Bus 4144	: V=1.037466, theta=-19.789647 -> V=1.0, theta=0.0
% INFO    : Bus 4145	: V=1.010696, theta=61.676903 -> V=1.0, theta=0.0
% INFO    : Bus 4146	: V=0.982819, theta=9.414059 -> V=1.0, theta=0.0
% INFO    : Bus 4147	: V=1.029151, theta=-31.51084 -> V=1.0, theta=0.0
% INFO    : Bus 4148	: V=1.004853, theta=-50.224318 -> V=1.0, theta=0.0
% INFO    : Bus 4149	: V=1.016767, theta=-15.388627 -> V=1.0, theta=0.0
% INFO    : Bus 4150	: V=0.993895, theta=-22.508601 -> V=1.0, theta=0.0
% INFO    : Bus 4151	: V=1.023997, theta=-3.039664 -> V=1.0, theta=0.0
% INFO    : Bus 4152	: V=1.004086, theta=-50.610328 -> V=1.0, theta=0.0
% INFO    : Bus 4153	: V=1.030434, theta=48.268758 -> V=1.0, theta=0.0
% INFO    : Bus 4154	: V=1.003321, theta=8.805053 -> V=1.0, theta=0.0
% INFO    : Bus 4155	: V=1.032095, theta=-28.416454 -> V=1.0, theta=0.0
% INFO    : Bus 4156	: V=1.071034, theta=59.203115 -> V=1.0, theta=0.0
% INFO    : Bus 4157	: V=1.068844, theta=-26.733655 -> V=1.0, theta=0.0
% INFO    : Bus 4158	: V=1.018564, theta=-16.083787 -> V=1.0, theta=0.0
% INFO    : Bus 4159	: V=1.03101, theta=-19.53333 -> V=1.0, theta=0.0
% INFO    : Bus 4160	: V=0.990312, theta=-30.214954 -> V=1.0, theta=0.0
% INFO    : Bus 4161	: V=1.060545, theta=-18.151108 -> V=1.0, theta=0.0
% INFO    : Bus 4162	: V=1.127149, theta=-21.902131 -> V=1.0, theta=0.0
% INFO    : Bus 4163	: V=1.047216, theta=-1.442069 -> V=1.0, theta=0.0
% INFO    : Bus 4164	: V=1.017898, theta=-16.185279 -> V=1.0, theta=0.0
% INFO    : Bus 4165	: V=1.025082, theta=-43.939303 -> V=1.0, theta=0.0
% INFO    : Bus 4166	: V=1.01376, theta=-26.588907 -> V=1.0, theta=0.0
% INFO    : Bus 4167	: V=1.043491, theta=-20.51172 -> V=1.0, theta=0.0
% INFO    : Bus 4168	: V=1.004424, theta=-50.572566 -> V=1.0, theta=0.0
% INFO    : Bus 4169	: V=0.983291, theta=-31.912299 -> V=1.0, theta=0.0
% INFO    : Bus 4170	: V=0.99126, theta=-32.514071 -> V=1.0, theta=0.0
% INFO    : Bus 4171	: V=1.014773, theta=-26.307063 -> V=1.0, theta=0.0
% INFO    : Bus 4172	: V=1.02637, theta=-36.492048 -> V=1.0, theta=0.0
% INFO    : Bus 4173	: V=1.007409, theta=-10.237514 -> V=1.0, theta=0.0
% INFO    : Bus 4174	: V=1.011231, theta=-30.639196 -> V=1.0, theta=0.0
% INFO    : Bus 4175	: V=1.078047, theta=44.862058 -> V=1.0, theta=0.0
% INFO    : Bus 4176	: V=1.025419, theta=-13.727286 -> V=1.0, theta=0.0
% INFO    : Bus 4177	: V=1.019708, theta=-45.343115 -> V=1.0, theta=0.0
% INFO    : Bus 4178	: V=1.031771, theta=-38.209109 -> V=1.0, theta=0.0
% INFO    : Bus 4179	: V=1.010218, theta=-27.997197 -> V=1.0, theta=0.0
% INFO    : Bus 4180	: V=1.035036, theta=-17.3396 -> V=1.0, theta=0.0
% INFO    : Bus 4181	: V=1.037185, theta=-46.022811 -> V=1.0, theta=0.0
% INFO    : Bus 4182	: V=1.011247, theta=-44.11642 -> V=1.0, theta=0.0
% INFO    : Bus 4183	: V=1.031152, theta=-10.701804 -> V=1.0, theta=0.0
% INFO    : Bus 4184	: V=1.069781, theta=-19.474091 -> V=1.0, theta=0.0
% INFO    : Bus 4185	: V=1.038294, theta=-26.144543 -> V=1.0, theta=0.0
% INFO    : Bus 4186	: V=1.032163, theta=-23.48406 -> V=1.0, theta=0.0
% INFO    : Bus 4187	: V=1.058969, theta=-18.603344 -> V=1.0, theta=0.0
% INFO    : Bus 4188	: V=1.010423, theta=-0.341615 -> V=1.0, theta=0.0
% INFO    : Bus 4189	: V=1.028895, theta=-26.578685 -> V=1.0, theta=0.0
% INFO    : Bus 4190	: V=1.045226, theta=-11.788173 -> V=1.0, theta=0.0
% INFO    : Bus 4191	: V=0.982488, theta=-30.116866 -> V=1.0, theta=0.0
% INFO    : Bus 4192	: V=1.076318, theta=18.042352 -> V=1.0, theta=0.0
% INFO    : Bus 4193	: V=1.014182, theta=-5.477015 -> V=1.0, theta=0.0
% INFO    : Bus 4194	: V=0.951351, theta=-29.98231 -> V=1.0, theta=0.0
% INFO    : Bus 4195	: V=1.076653, theta=4.62948 -> V=1.0, theta=0.0
% INFO    : Bus 4196	: V=1.02511, theta=-7.715077 -> V=1.0, theta=0.0
% INFO    : Bus 4197	: V=1.061789, theta=0.582825 -> V=1.0, theta=0.0
% INFO    : Bus 4198	: V=1.01015, theta=1.802303 -> V=1.0, theta=0.0
% INFO    : Bus 4199	: V=1.035373, theta=7.6217 -> V=1.0, theta=0.0
% INFO    : Bus 4200	: V=1.016165, theta=66.484445 -> V=1.0, theta=0.0
% INFO    : Bus 4201	: V=1.034586, theta=-20.71494 -> V=1.0, theta=0.0
% INFO    : Bus 4202	: V=1.042806, theta=-39.579659 -> V=1.0, theta=0.0
% INFO    : Bus 4203	: V=0.962313, theta=-37.255005 -> V=1.0, theta=0.0
% INFO    : Bus 4204	: V=1.014828, theta=-40.210588 -> V=1.0, theta=0.0
% INFO    : Bus 4205	: V=1.042725, theta=-13.028579 -> V=1.0, theta=0.0
% INFO    : Bus 4206	: V=1.034464, theta=-1.395933 -> V=1.0, theta=0.0
% INFO    : Bus 4207	: V=1.009702, theta=-27.338201 -> V=1.0, theta=0.0
% INFO    : Bus 4208	: V=1.14157, theta=-23.643367 -> V=1.0, theta=0.0
% INFO    : Bus 4209	: V=1.048002, theta=18.18959 -> V=1.0, theta=0.0
% INFO    : Bus 4210	: V=1.031932, theta=-26.167183 -> V=1.0, theta=0.0
% INFO    : Bus 4211	: V=1.042563, theta=-24.017297 -> V=1.0, theta=0.0
% INFO    : Bus 4212	: V=1.028935, theta=-21.684767 -> V=1.0, theta=0.0
% INFO    : Bus 4213	: V=0.998759, theta=-26.288816 -> V=1.0, theta=0.0
% INFO    : Bus 4214	: V=1.074255, theta=61.102292 -> V=1.0, theta=0.0
% INFO    : Bus 4215	: V=1.041291, theta=-23.383686 -> V=1.0, theta=0.0
% INFO    : Bus 4216	: V=1.028315, theta=7.907933 -> V=1.0, theta=0.0
% INFO    : Bus 4217	: V=1.031653, theta=66.374308 -> V=1.0, theta=0.0
% INFO    : Bus 4218	: V=1.063506, theta=27.291012 -> V=1.0, theta=0.0
% INFO    : Bus 4219	: V=0.994825, theta=-31.851557 -> V=1.0, theta=0.0
% INFO    : Bus 4220	: V=1.013969, theta=-31.986962 -> V=1.0, theta=0.0
% INFO    : Bus 4221	: V=1.036578, theta=-20.82525 -> V=1.0, theta=0.0
% INFO    : Bus 4222	: V=1.067224, theta=-26.550309 -> V=1.0, theta=0.0
% INFO    : Bus 4223	: V=1.012498, theta=-19.744499 -> V=1.0, theta=0.0
% INFO    : Bus 4224	: V=1.021092, theta=-38.627211 -> V=1.0, theta=0.0
% INFO    : Bus 4225	: V=1.013124, theta=10.540111 -> V=1.0, theta=0.0
% INFO    : Bus 4226	: V=1.045038, theta=-16.143617 -> V=1.0, theta=0.0
% INFO    : Bus 4227	: V=1.00828, theta=-24.572415 -> V=1.0, theta=0.0
% INFO    : Bus 4228	: V=1.060932, theta=64.062878 -> V=1.0, theta=0.0
% INFO    : Bus 4229	: V=0.870967, theta=-38.524972 -> V=1.0, theta=0.0
% INFO    : Bus 4230	: V=0.980235, theta=-45.225947 -> V=1.0, theta=0.0
% INFO    : Bus 4231	: V=1.042866, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 4232	: V=1.021825, theta=-28.614751 -> V=1.0, theta=0.0
% INFO    : Bus 4233	: V=0.962703, theta=-27.325558 -> V=1.0, theta=0.0
% INFO    : Bus 4234	: V=1.043784, theta=-17.44016 -> V=1.0, theta=0.0
% INFO    : Bus 4235	: V=1.042991, theta=-19.568975 -> V=1.0, theta=0.0
% INFO    : Bus 4236	: V=1.042174, theta=-29.589505 -> V=1.0, theta=0.0
% INFO    : Bus 4237	: V=1.014748, theta=10.103007 -> V=1.0, theta=0.0
% INFO    : Bus 4238	: V=1.007519, theta=-48.060372 -> V=1.0, theta=0.0
% INFO    : Bus 4239	: V=1.043664, theta=-13.554722 -> V=1.0, theta=0.0
% INFO    : Bus 4240	: V=1.015037, theta=-32.004489 -> V=1.0, theta=0.0
% INFO    : Bus 4241	: V=1.021345, theta=-43.991555 -> V=1.0, theta=0.0
% INFO    : Bus 4242	: V=1.019378, theta=-27.068452 -> V=1.0, theta=0.0
% INFO    : Bus 4243	: V=1.016657, theta=-29.054582 -> V=1.0, theta=0.0
% INFO    : Bus 4244	: V=1.039687, theta=11.244957 -> V=1.0, theta=0.0
% INFO    : Bus 4245	: V=1.037662, theta=-10.152328 -> V=1.0, theta=0.0
% INFO    : Bus 4246	: V=1.025701, theta=-40.895394 -> V=1.0, theta=0.0
% INFO    : Bus 4247	: V=0.85042, theta=-39.715801 -> V=1.0, theta=0.0
% INFO    : Bus 4248	: V=1.00246, theta=25.861349 -> V=1.0, theta=0.0
% INFO    : Bus 4249	: V=1.022176, theta=-55.071765 -> V=1.0, theta=0.0
% INFO    : Bus 4250	: V=1.04599, theta=-25.355234 -> V=1.0, theta=0.0
% INFO    : Bus 4251	: V=1.02428, theta=-17.852918 -> V=1.0, theta=0.0
% INFO    : Bus 4252	: V=1.023266, theta=-14.144948 -> V=1.0, theta=0.0
% INFO    : Bus 4253	: V=1.023905, theta=-54.602507 -> V=1.0, theta=0.0
% INFO    : Bus 4254	: V=1.023046, theta=-30.120615 -> V=1.0, theta=0.0
% INFO    : Bus 4255	: V=1.026601, theta=-2.601651 -> V=1.0, theta=0.0
% INFO    : Bus 4256	: V=0.997399, theta=18.8049 -> V=1.0, theta=0.0
% INFO    : Bus 4257	: V=1.042258, theta=7.921226 -> V=1.0, theta=0.0
% INFO    : Bus 4258	: V=1.010196, theta=-30.742157 -> V=1.0, theta=0.0
% INFO    : Bus 4259	: V=1.01039, theta=-41.935972 -> V=1.0, theta=0.0
% INFO    : Bus 4260	: V=1.029271, theta=-22.100951 -> V=1.0, theta=0.0
% INFO    : Bus 4261	: V=1.019612, theta=2.948367 -> V=1.0, theta=0.0
% INFO    : Bus 4262	: V=1.010534, theta=-27.286436 -> V=1.0, theta=0.0
% INFO    : Bus 4263	: V=1.007259, theta=-23.98794 -> V=1.0, theta=0.0
% INFO    : Bus 4264	: V=1.028908, theta=21.106834 -> V=1.0, theta=0.0
% INFO    : Bus 4265	: V=1.015048, theta=-30.094475 -> V=1.0, theta=0.0
% INFO    : Bus 4266	: V=1.002825, theta=-7.68797 -> V=1.0, theta=0.0
% INFO    : Bus 4267	: V=1.037756, theta=-8.97903 -> V=1.0, theta=0.0
% INFO    : Bus 4268	: V=0.981228, theta=28.310474 -> V=1.0, theta=0.0
% INFO    : Bus 4269	: V=0.978526, theta=-32.290997 -> V=1.0, theta=0.0
% INFO    : Bus 4270	: V=1.057033, theta=-32.004083 -> V=1.0, theta=0.0
% INFO    : Bus 4271	: V=0.946828, theta=-17.562886 -> V=1.0, theta=0.0
% INFO    : Bus 4272	: V=1.023497, theta=2.13201 -> V=1.0, theta=0.0
% INFO    : Bus 4273	: V=0.998443, theta=-19.858555 -> V=1.0, theta=0.0
% INFO    : Bus 4274	: V=1.025662, theta=-54.027522 -> V=1.0, theta=0.0
% INFO    : Bus 4275	: V=1.020804, theta=-30.404515 -> V=1.0, theta=0.0
% INFO    : Bus 4276	: V=1.028246, theta=-15.72612 -> V=1.0, theta=0.0
% INFO    : Bus 4277	: V=0.997034, theta=-39.364023 -> V=1.0, theta=0.0
% INFO    : Bus 4278	: V=1.038839, theta=7.739529 -> V=1.0, theta=0.0
% INFO    : Bus 4279	: V=1.01498, theta=-34.516631 -> V=1.0, theta=0.0
% INFO    : Bus 4280	: V=1.038835, theta=-7.918348 -> V=1.0, theta=0.0
% INFO    : Bus 4281	: V=1.046492, theta=-11.999402 -> V=1.0, theta=0.0
% INFO    : Bus 4282	: V=1.004437, theta=-19.772135 -> V=1.0, theta=0.0
% INFO    : Bus 4283	: V=1.009168, theta=-32.909866 -> V=1.0, theta=0.0
% INFO    : Bus 4284	: V=1.043054, theta=-17.362805 -> V=1.0, theta=0.0
% INFO    : Bus 4285	: V=1.084133, theta=45.095107 -> V=1.0, theta=0.0
% INFO    : Bus 4286	: V=1.022352, theta=67.175363 -> V=1.0, theta=0.0
% INFO    : Bus 4287	: V=1.042671, theta=-24.914763 -> V=1.0, theta=0.0
% INFO    : Bus 4288	: V=1.041887, theta=-5.990756 -> V=1.0, theta=0.0
% INFO    : Bus 4289	: V=0.998324, theta=-28.72802 -> V=1.0, theta=0.0
% INFO    : Bus 4290	: V=1.067072, theta=-41.01452 -> V=1.0, theta=0.0
% INFO    : Bus 4291	: V=1.019753, theta=-35.792407 -> V=1.0, theta=0.0
% INFO    : Bus 4292	: V=1.03438, theta=-20.587427 -> V=1.0, theta=0.0
% INFO    : Bus 4293	: V=1.009395, theta=-55.082432 -> V=1.0, theta=0.0
% INFO    : Bus 4294	: V=1.028795, theta=18.803182 -> V=1.0, theta=0.0
% INFO    : Bus 4295	: V=1.038508, theta=6.226684 -> V=1.0, theta=0.0
% INFO    : Bus 4296	: V=1.040271, theta=40.274729 -> V=1.0, theta=0.0
% INFO    : Bus 4297	: V=1.023326, theta=-28.504442 -> V=1.0, theta=0.0
% INFO    : Bus 4298	: V=1.024646, theta=3.684489 -> V=1.0, theta=0.0
% INFO    : Bus 4299	: V=1.023342, theta=-26.016359 -> V=1.0, theta=0.0
% INFO    : Bus 4300	: V=0.997189, theta=-16.532436 -> V=1.0, theta=0.0
% INFO    : Bus 4301	: V=1.035104, theta=-21.386539 -> V=1.0, theta=0.0
% INFO    : Bus 4302	: V=1.023399, theta=22.755352 -> V=1.0, theta=0.0
% INFO    : Bus 4303	: V=1.042733, theta=-20.562838 -> V=1.0, theta=0.0
% INFO    : Bus 4304	: V=1.063231, theta=-25.689127 -> V=1.0, theta=0.0
% INFO    : Bus 4305	: V=1.008749, theta=-0.91416 -> V=1.0, theta=0.0
% INFO    : Bus 4306	: V=1.031495, theta=-31.068518 -> V=1.0, theta=0.0
% INFO    : Bus 4307	: V=1.018022, theta=-36.16273 -> V=1.0, theta=0.0
% INFO    : Bus 4308	: V=1.018993, theta=-7.38201 -> V=1.0, theta=0.0
% INFO    : Bus 4309	: V=1.066341, theta=-25.283343 -> V=1.0, theta=0.0
% INFO    : Bus 4310	: V=1.000348, theta=-31.938279 -> V=1.0, theta=0.0
% INFO    : Bus 4311	: V=0.981183, theta=-20.807579 -> V=1.0, theta=0.0
% INFO    : Bus 4312	: V=1.013049, theta=-23.93019 -> V=1.0, theta=0.0
% INFO    : Bus 4313	: V=1.040449, theta=-21.438772 -> V=1.0, theta=0.0
% INFO    : Bus 4314	: V=1.039315, theta=-14.542727 -> V=1.0, theta=0.0
% INFO    : Bus 4315	: V=1.047833, theta=-38.77663 -> V=1.0, theta=0.0
% INFO    : Bus 4316	: V=0.963858, theta=-26.99749 -> V=1.0, theta=0.0
% INFO    : Bus 4317	: V=1.007687, theta=-41.231523 -> V=1.0, theta=0.0
% INFO    : Bus 4318	: V=1.056768, theta=10.598214 -> V=1.0, theta=0.0
% INFO    : Bus 4319	: V=1.009299, theta=-5.109314 -> V=1.0, theta=0.0
% INFO    : Bus 4320	: V=1.002978, theta=25.800176 -> V=1.0, theta=0.0
% INFO    : Bus 4321	: V=1.029006, theta=-32.125299 -> V=1.0, theta=0.0
% INFO    : Bus 4322	: V=1.055269, theta=-25.21651 -> V=1.0, theta=0.0
% INFO    : Bus 4323	: V=1.038456, theta=-23.365393 -> V=1.0, theta=0.0
% INFO    : Bus 4324	: V=1.054994, theta=-30.340052 -> V=1.0, theta=0.0
% INFO    : Bus 4325	: V=1.079412, theta=-23.930117 -> V=1.0, theta=0.0
% INFO    : Bus 4326	: V=1.007639, theta=-39.21017 -> V=1.0, theta=0.0
% INFO    : Bus 4327	: V=1.02376, theta=-27.906617 -> V=1.0, theta=0.0
% INFO    : Bus 4328	: V=0.965235, theta=-31.45534 -> V=1.0, theta=0.0
% INFO    : Bus 4329	: V=1.019083, theta=-30.189885 -> V=1.0, theta=0.0
% INFO    : Bus 4330	: V=1.049093, theta=-26.995714 -> V=1.0, theta=0.0
% INFO    : Bus 4331	: V=1.029918, theta=-11.076786 -> V=1.0, theta=0.0
% INFO    : Bus 4332	: V=1.037314, theta=34.960373 -> V=1.0, theta=0.0
% INFO    : Bus 4333	: V=0.997274, theta=-30.814658 -> V=1.0, theta=0.0
% INFO    : Bus 4334	: V=1.057462, theta=53.972685 -> V=1.0, theta=0.0
% INFO    : Bus 4335	: V=1.075192, theta=-22.438681 -> V=1.0, theta=0.0
% INFO    : Bus 4336	: V=1.023007, theta=-54.854276 -> V=1.0, theta=0.0
% INFO    : Bus 4337	: V=1.026934, theta=6.309425 -> V=1.0, theta=0.0
% INFO    : Bus 4338	: V=1.021243, theta=-48.103156 -> V=1.0, theta=0.0
% INFO    : Bus 4339	: V=0.991594, theta=-16.075924 -> V=1.0, theta=0.0
% INFO    : Bus 4340	: V=1.041286, theta=25.793343 -> V=1.0, theta=0.0
% INFO    : Bus 4341	: V=0.982706, theta=-21.606447 -> V=1.0, theta=0.0
% INFO    : Bus 4342	: V=1.038927, theta=-20.557735 -> V=1.0, theta=0.0
% INFO    : Bus 4343	: V=1.011953, theta=-29.854681 -> V=1.0, theta=0.0
% INFO    : Bus 4344	: V=0.996295, theta=-51.660806 -> V=1.0, theta=0.0
% INFO    : Bus 4345	: V=1.029059, theta=19.441789 -> V=1.0, theta=0.0
% INFO    : Bus 4346	: V=1.121952, theta=-22.192108 -> V=1.0, theta=0.0
% INFO    : Bus 4347	: V=1.026364, theta=-10.160124 -> V=1.0, theta=0.0
% INFO    : Bus 4348	: V=1.021688, theta=-42.801815 -> V=1.0, theta=0.0
% INFO    : Bus 4349	: V=1.097775, theta=45.321662 -> V=1.0, theta=0.0
% INFO    : Bus 4350	: V=1.028107, theta=50.105767 -> V=1.0, theta=0.0
% INFO    : Bus 4351	: V=0.961099, theta=-30.713211 -> V=1.0, theta=0.0
% INFO    : Bus 4352	: V=1.031777, theta=-30.784781 -> V=1.0, theta=0.0
% INFO    : Bus 4353	: V=1.047865, theta=-26.985262 -> V=1.0, theta=0.0
% INFO    : Bus 4354	: V=1.023532, theta=-31.480583 -> V=1.0, theta=0.0
% INFO    : Bus 4355	: V=1.067756, theta=-26.834354 -> V=1.0, theta=0.0
% INFO    : Bus 4356	: V=1.027567, theta=-34.403559 -> V=1.0, theta=0.0
% INFO    : Bus 4357	: V=1.038258, theta=-16.356336 -> V=1.0, theta=0.0
% INFO    : Bus 4358	: V=1.036903, theta=1.417042 -> V=1.0, theta=0.0
% INFO    : Bus 4359	: V=1.016808, theta=-12.113719 -> V=1.0, theta=0.0
% INFO    : Bus 4360	: V=1.012505, theta=-52.773741 -> V=1.0, theta=0.0
% INFO    : Bus 4361	: V=1.013688, theta=-28.100746 -> V=1.0, theta=0.0
% INFO    : Bus 4362	: V=1.017231, theta=3.89138 -> V=1.0, theta=0.0
% INFO    : Bus 4363	: V=1.023014, theta=-39.840295 -> V=1.0, theta=0.0
% INFO    : Bus 4364	: V=0.993438, theta=-24.391143 -> V=1.0, theta=0.0
% INFO    : Bus 4365	: V=0.972435, theta=-27.159885 -> V=1.0, theta=0.0
% INFO    : Bus 4366	: V=1.035263, theta=-8.915283 -> V=1.0, theta=0.0
% INFO    : Bus 4367	: V=1.026057, theta=-34.198538 -> V=1.0, theta=0.0
% INFO    : Bus 4368	: V=1.054091, theta=-25.431523 -> V=1.0, theta=0.0
% INFO    : Bus 4369	: V=1.02512, theta=-14.187003 -> V=1.0, theta=0.0
% INFO    : Bus 4370	: V=1.057153, theta=1.871666 -> V=1.0, theta=0.0
% INFO    : Bus 4371	: V=1.009912, theta=-55.34295 -> V=1.0, theta=0.0
% INFO    : Bus 4372	: V=1.073, theta=-16.309536 -> V=1.0, theta=0.0
% INFO    : Bus 4373	: V=1.031784, theta=-41.15786 -> V=1.0, theta=0.0
% INFO    : Bus 4374	: V=0.98249, theta=-28.084166 -> V=1.0, theta=0.0
% INFO    : Bus 4375	: V=1.045136, theta=-25.411977 -> V=1.0, theta=0.0
% INFO    : Bus 4376	: V=1.018032, theta=63.599951 -> V=1.0, theta=0.0
% INFO    : Bus 4377	: V=1.020653, theta=14.554382 -> V=1.0, theta=0.0
% INFO    : Bus 4378	: V=0.986067, theta=-15.96343 -> V=1.0, theta=0.0
% INFO    : Bus 4379	: V=1.052863, theta=1.908947 -> V=1.0, theta=0.0
% INFO    : Bus 4380	: V=1.023792, theta=0.717698 -> V=1.0, theta=0.0
% INFO    : Bus 4381	: V=1.031633, theta=-44.292473 -> V=1.0, theta=0.0
% INFO    : Bus 4382	: V=1.014988, theta=-35.836229 -> V=1.0, theta=0.0
% INFO    : Bus 4383	: V=1.018334, theta=-29.585053 -> V=1.0, theta=0.0
% INFO    : Bus 4384	: V=1.074143, theta=-30.832333 -> V=1.0, theta=0.0
% INFO    : Bus 4385	: V=0.998388, theta=-37.313561 -> V=1.0, theta=0.0
% INFO    : Bus 4386	: V=1.02273, theta=-0.206279 -> V=1.0, theta=0.0
% INFO    : Bus 4387	: V=1.007751, theta=-36.336224 -> V=1.0, theta=0.0
% INFO    : Bus 4388	: V=1.045933, theta=-27.186622 -> V=1.0, theta=0.0
% INFO    : Bus 4389	: V=1.039327, theta=12.546785 -> V=1.0, theta=0.0
% INFO    : Bus 4390	: V=1.051477, theta=-39.489487 -> V=1.0, theta=0.0
% INFO    : Bus 4391	: V=1.001379, theta=-19.656286 -> V=1.0, theta=0.0
% INFO    : Bus 4392	: V=1.044445, theta=-27.915096 -> V=1.0, theta=0.0
% INFO    : Bus 4393	: V=1.061357, theta=-44.814563 -> V=1.0, theta=0.0
% INFO    : Bus 4394	: V=1.07967, theta=-23.908777 -> V=1.0, theta=0.0
% INFO    : Bus 4395	: V=1.036974, theta=-20.964863 -> V=1.0, theta=0.0
% INFO    : Bus 4396	: V=1.08226, theta=-20.191342 -> V=1.0, theta=0.0
% INFO    : Bus 4397	: V=1.014447, theta=-47.685772 -> V=1.0, theta=0.0
% INFO    : Bus 4398	: V=1.046214, theta=-25.453683 -> V=1.0, theta=0.0
% INFO    : Bus 4399	: V=1.054017, theta=-26.25452 -> V=1.0, theta=0.0
% INFO    : Bus 4400	: V=1.077395, theta=8.102273 -> V=1.0, theta=0.0
% INFO    : Bus 4401	: V=1.041415, theta=-21.104843 -> V=1.0, theta=0.0
% INFO    : Bus 4402	: V=1.082792, theta=-15.473491 -> V=1.0, theta=0.0
% INFO    : Bus 4403	: V=1.05117, theta=-28.87403 -> V=1.0, theta=0.0
% INFO    : Bus 4404	: V=0.95719, theta=-29.999812 -> V=1.0, theta=0.0
% INFO    : Bus 4405	: V=0.984433, theta=-23.606104 -> V=1.0, theta=0.0
% INFO    : Bus 4406	: V=1.020663, theta=-28.695737 -> V=1.0, theta=0.0
% INFO    : Bus 4407	: V=1.061264, theta=-41.277281 -> V=1.0, theta=0.0
% INFO    : Bus 4408	: V=1.010367, theta=-41.467274 -> V=1.0, theta=0.0
% INFO    : Bus 4409	: V=1.036468, theta=17.146109 -> V=1.0, theta=0.0
% INFO    : Bus 4410	: V=1.041145, theta=-37.170777 -> V=1.0, theta=0.0
% INFO    : Bus 4411	: V=1.019039, theta=-9.031289 -> V=1.0, theta=0.0
% INFO    : Bus 4412	: V=1.007967, theta=-3.533645 -> V=1.0, theta=0.0
% INFO    : Bus 4413	: V=1.025355, theta=11.098662 -> V=1.0, theta=0.0
% INFO    : Bus 4414	: V=1.027205, theta=-34.077804 -> V=1.0, theta=0.0
% INFO    : Bus 4415	: V=1.029972, theta=7.953503 -> V=1.0, theta=0.0
% INFO    : Bus 4416	: V=1.024783, theta=-13.991666 -> V=1.0, theta=0.0
% INFO    : Bus 4417	: V=1.016455, theta=-37.569258 -> V=1.0, theta=0.0
% INFO    : Bus 4418	: V=1.074227, theta=-24.636521 -> V=1.0, theta=0.0
% INFO    : Bus 4419	: V=1.055121, theta=4.46001 -> V=1.0, theta=0.0
% INFO    : Bus 4420	: V=1.009808, theta=-10.334322 -> V=1.0, theta=0.0
% INFO    : Bus 4421	: V=0.977645, theta=-28.44939 -> V=1.0, theta=0.0
% INFO    : Bus 4422	: V=0.980745, theta=-31.583482 -> V=1.0, theta=0.0
% INFO    : Bus 4423	: V=1.031521, theta=-11.573048 -> V=1.0, theta=0.0
% INFO    : Bus 4424	: V=1.028537, theta=-16.531217 -> V=1.0, theta=0.0
% INFO    : Bus 4425	: V=0.986025, theta=9.380075 -> V=1.0, theta=0.0
% INFO    : Bus 4426	: V=1.06424, theta=-47.083696 -> V=1.0, theta=0.0
% INFO    : Bus 4427	: V=1.029896, theta=-11.3652 -> V=1.0, theta=0.0
% INFO    : Bus 4428	: V=1.016576, theta=-44.153521 -> V=1.0, theta=0.0
% INFO    : Bus 4429	: V=1.007433, theta=-4.171966 -> V=1.0, theta=0.0
% INFO    : Bus 4430	: V=1.048812, theta=-20.863288 -> V=1.0, theta=0.0
% INFO    : Bus 4431	: V=1.017867, theta=8.169606 -> V=1.0, theta=0.0
% INFO    : Bus 4432	: V=1.068843, theta=-26.73362 -> V=1.0, theta=0.0
% INFO    : Bus 4433	: V=1.051614, theta=-15.841626 -> V=1.0, theta=0.0
% INFO    : Bus 4434	: V=1.032779, theta=24.876477 -> V=1.0, theta=0.0
% INFO    : Bus 4435	: V=1.010783, theta=-8.696684 -> V=1.0, theta=0.0
% INFO    : Bus 4436	: V=1.052317, theta=-15.83616 -> V=1.0, theta=0.0
% INFO    : Bus 4437	: V=1.026437, theta=-26.750642 -> V=1.0, theta=0.0
% INFO    : Bus 4438	: V=1.063656, theta=-26.075553 -> V=1.0, theta=0.0
% INFO    : Bus 4439	: V=1.024658, theta=-34.268009 -> V=1.0, theta=0.0
% INFO    : Bus 4440	: V=1.012622, theta=62.214553 -> V=1.0, theta=0.0
% INFO    : Bus 4441	: V=1.02633, theta=-10.922726 -> V=1.0, theta=0.0
% INFO    : Bus 4442	: V=1.031243, theta=-50.622294 -> V=1.0, theta=0.0
% INFO    : Bus 4443	: V=1.007119, theta=-28.314443 -> V=1.0, theta=0.0
% INFO    : Bus 4444	: V=0.998693, theta=-24.624089 -> V=1.0, theta=0.0
% INFO    : Bus 4445	: V=1.031204, theta=-37.688891 -> V=1.0, theta=0.0
% INFO    : Bus 4446	: V=1.035897, theta=-39.478385 -> V=1.0, theta=0.0
% INFO    : Bus 4447	: V=1.115565, theta=-23.575874 -> V=1.0, theta=0.0
% INFO    : Bus 4448	: V=0.976159, theta=-53.121709 -> V=1.0, theta=0.0
% INFO    : Bus 4449	: V=1.025407, theta=4.559943 -> V=1.0, theta=0.0
% INFO    : Bus 4450	: V=1.023587, theta=-54.685261 -> V=1.0, theta=0.0
% INFO    : Bus 4451	: V=0.960231, theta=-27.579716 -> V=1.0, theta=0.0
% INFO    : Bus 4452	: V=1.031824, theta=7.264218 -> V=1.0, theta=0.0
% INFO    : Bus 4453	: V=1.041997, theta=-11.076954 -> V=1.0, theta=0.0
% INFO    : Bus 4454	: V=1.006626, theta=-17.657551 -> V=1.0, theta=0.0
% INFO    : Bus 4455	: V=1.01091, theta=-9.685572 -> V=1.0, theta=0.0
% INFO    : Bus 4456	: V=1.001715, theta=-29.833816 -> V=1.0, theta=0.0
% INFO    : Bus 4457	: V=1.015266, theta=0.37257 -> V=1.0, theta=0.0
% INFO    : Bus 4458	: V=1.060133, theta=-20.243328 -> V=1.0, theta=0.0
% INFO    : Bus 4459	: V=1.02497, theta=-4.673317 -> V=1.0, theta=0.0
% INFO    : Bus 4460	: V=1.105887, theta=-24.716121 -> V=1.0, theta=0.0
% INFO    : Bus 4461	: V=1.022586, theta=-31.689003 -> V=1.0, theta=0.0
% INFO    : Bus 4462	: V=1.035045, theta=-28.394827 -> V=1.0, theta=0.0
% INFO    : Bus 4463	: V=1.016703, theta=-37.138163 -> V=1.0, theta=0.0
% INFO    : Bus 4464	: V=1.054883, theta=-29.186919 -> V=1.0, theta=0.0
% INFO    : Bus 4465	: V=0.990701, theta=-31.137598 -> V=1.0, theta=0.0
% INFO    : Bus 4466	: V=0.998815, theta=9.954113 -> V=1.0, theta=0.0
% INFO    : Bus 4467	: V=0.994136, theta=-46.767778 -> V=1.0, theta=0.0
% INFO    : Bus 4468	: V=1.041888, theta=-6.97892 -> V=1.0, theta=0.0
% INFO    : Bus 4469	: V=1.016104, theta=6.117545 -> V=1.0, theta=0.0
% INFO    : Bus 4470	: V=1.017342, theta=-38.072059 -> V=1.0, theta=0.0
% INFO    : Bus 4471	: V=1.014999, theta=6.95466 -> V=1.0, theta=0.0
% INFO    : Bus 4472	: V=1.022976, theta=2.582263 -> V=1.0, theta=0.0
% INFO    : Bus 4473	: V=1.089071, theta=-27.765632 -> V=1.0, theta=0.0
% INFO    : Bus 4474	: V=1.020183, theta=18.753546 -> V=1.0, theta=0.0
% INFO    : Bus 4475	: V=0.934086, theta=-33.42388 -> V=1.0, theta=0.0
% INFO    : Bus 4476	: V=0.97125, theta=-37.361789 -> V=1.0, theta=0.0
% INFO    : Bus 4477	: V=1.03099, theta=3.60651 -> V=1.0, theta=0.0
% INFO    : Bus 4478	: V=1.062733, theta=47.922029 -> V=1.0, theta=0.0
% INFO    : Bus 4479	: V=0.96163, theta=-31.626246 -> V=1.0, theta=0.0
% INFO    : Bus 4480	: V=1.065482, theta=7.961387 -> V=1.0, theta=0.0
% INFO    : Bus 4481	: V=1.016911, theta=-33.841262 -> V=1.0, theta=0.0
% INFO    : Bus 4482	: V=1.043069, theta=-6.662274 -> V=1.0, theta=0.0
% INFO    : Bus 4483	: V=1.044395, theta=-29.479203 -> V=1.0, theta=0.0
% INFO    : Bus 4484	: V=1.042834, theta=-13.696329 -> V=1.0, theta=0.0
% INFO    : Bus 4485	: V=1.041056, theta=15.445155 -> V=1.0, theta=0.0
% INFO    : Bus 4486	: V=1.026359, theta=-26.73494 -> V=1.0, theta=0.0
% INFO    : Bus 4487	: V=1.021496, theta=-41.49216 -> V=1.0, theta=0.0
% INFO    : Bus 4488	: V=1.04134, theta=-21.120784 -> V=1.0, theta=0.0
% INFO    : Bus 4489	: V=1.021322, theta=-47.40207 -> V=1.0, theta=0.0
% INFO    : Bus 4490	: V=0.993329, theta=-37.832964 -> V=1.0, theta=0.0
% INFO    : Bus 4491	: V=1.02361, theta=-30.715686 -> V=1.0, theta=0.0
% INFO    : Bus 4492	: V=1.045494, theta=38.496563 -> V=1.0, theta=0.0
% INFO    : Bus 4493	: V=1.018268, theta=-40.970053 -> V=1.0, theta=0.0
% INFO    : Bus 4494	: V=1.016149, theta=-1.082662 -> V=1.0, theta=0.0
% INFO    : Bus 4495	: V=1.028274, theta=-11.333961 -> V=1.0, theta=0.0
% INFO    : Bus 4496	: V=1.00363, theta=11.171429 -> V=1.0, theta=0.0
% INFO    : Bus 4497	: V=0.966015, theta=-16.2589 -> V=1.0, theta=0.0
% INFO    : Bus 4498	: V=1.085986, theta=45.525024 -> V=1.0, theta=0.0
% INFO    : Bus 4499	: V=1.060005, theta=43.379649 -> V=1.0, theta=0.0
% INFO    : Bus 4500	: V=1.014972, theta=14.443444 -> V=1.0, theta=0.0
% INFO    : Bus 4501	: V=1.028081, theta=34.889783 -> V=1.0, theta=0.0
% INFO    : Bus 4502	: V=1.022423, theta=-45.514512 -> V=1.0, theta=0.0
% INFO    : Bus 4503	: V=1.000822, theta=-37.50556 -> V=1.0, theta=0.0
% INFO    : Bus 4504	: V=1.07122, theta=-42.503881 -> V=1.0, theta=0.0
% INFO    : Bus 4505	: V=1.038528, theta=-16.322612 -> V=1.0, theta=0.0
% INFO    : Bus 4506	: V=1.032581, theta=-6.338408 -> V=1.0, theta=0.0
% INFO    : Bus 4507	: V=1.026647, theta=-42.167898 -> V=1.0, theta=0.0
% INFO    : Bus 4508	: V=1.01112, theta=61.583042 -> V=1.0, theta=0.0
% INFO    : Bus 4509	: V=1.030757, theta=2.155188 -> V=1.0, theta=0.0
% INFO    : Bus 4510	: V=1.019973, theta=-39.369587 -> V=1.0, theta=0.0
% INFO    : Bus 4511	: V=1.037521, theta=-26.269073 -> V=1.0, theta=0.0
% INFO    : Bus 4512	: V=1.019063, theta=-46.353713 -> V=1.0, theta=0.0
% INFO    : Bus 4513	: V=1.030937, theta=-9.873276 -> V=1.0, theta=0.0
% INFO    : Bus 4514	: V=1.022975, theta=4.738024 -> V=1.0, theta=0.0
% INFO    : Bus 4515	: V=1.024584, theta=-25.074941 -> V=1.0, theta=0.0
% INFO    : Bus 4516	: V=1.018246, theta=-47.782987 -> V=1.0, theta=0.0
% INFO    : Bus 4517	: V=1.016047, theta=1.046488 -> V=1.0, theta=0.0
% INFO    : Bus 4518	: V=1.074936, theta=-17.283865 -> V=1.0, theta=0.0
% INFO    : Bus 4519	: V=1.024115, theta=7.200395 -> V=1.0, theta=0.0
% INFO    : Bus 4520	: V=1.01536, theta=-10.191142 -> V=1.0, theta=0.0
% INFO    : Bus 4521	: V=1.022583, theta=-42.115886 -> V=1.0, theta=0.0
% INFO    : Bus 4522	: V=0.97151, theta=10.604814 -> V=1.0, theta=0.0
% INFO    : Bus 4523	: V=1.020917, theta=2.948453 -> V=1.0, theta=0.0
% INFO    : Bus 4524	: V=1.005634, theta=-4.312594 -> V=1.0, theta=0.0
% INFO    : Bus 4525	: V=1.053159, theta=-9.223606 -> V=1.0, theta=0.0
% INFO    : Bus 4526	: V=1.059432, theta=-48.715162 -> V=1.0, theta=0.0
% INFO    : Bus 4527	: V=0.988635, theta=-31.00334 -> V=1.0, theta=0.0
% INFO    : Bus 4528	: V=0.95621, theta=-32.123967 -> V=1.0, theta=0.0
% INFO    : Bus 4529	: V=1.056482, theta=-15.446113 -> V=1.0, theta=0.0
% INFO    : Bus 4530	: V=1.017749, theta=-3.100429 -> V=1.0, theta=0.0
% INFO    : Bus 4531	: V=0.98249, theta=-28.084166 -> V=1.0, theta=0.0
% INFO    : Bus 4532	: V=0.992948, theta=-16.6809 -> V=1.0, theta=0.0
% INFO    : Bus 4533	: V=1.087859, theta=12.675438 -> V=1.0, theta=0.0
% INFO    : Bus 4534	: V=1.00848, theta=-20.386669 -> V=1.0, theta=0.0
% INFO    : Bus 4535	: V=1.02934, theta=9.534577 -> V=1.0, theta=0.0
% INFO    : Bus 4536	: V=1.042638, theta=-23.368692 -> V=1.0, theta=0.0
% INFO    : Bus 4537	: V=0.995045, theta=-31.877583 -> V=1.0, theta=0.0
% INFO    : Bus 4538	: V=1.018205, theta=-26.124455 -> V=1.0, theta=0.0
% INFO    : Bus 4539	: V=1.031929, theta=-38.517056 -> V=1.0, theta=0.0
% INFO    : Bus 4540	: V=1.025359, theta=-24.523057 -> V=1.0, theta=0.0
% INFO    : Bus 4541	: V=1.022812, theta=-9.949699 -> V=1.0, theta=0.0
% INFO    : Bus 4542	: V=1.045397, theta=-43.550688 -> V=1.0, theta=0.0
% INFO    : Bus 4543	: V=1.052729, theta=-45.804884 -> V=1.0, theta=0.0
% INFO    : Bus 4544	: V=1.044954, theta=-14.795371 -> V=1.0, theta=0.0
% INFO    : Bus 4545	: V=0.962682, theta=-27.37169 -> V=1.0, theta=0.0
% INFO    : Bus 4546	: V=1.003212, theta=-27.884307 -> V=1.0, theta=0.0
% INFO    : Bus 4547	: V=0.978811, theta=-32.268679 -> V=1.0, theta=0.0
% INFO    : Bus 4548	: V=1.015228, theta=-31.090387 -> V=1.0, theta=0.0
% INFO    : Bus 4549	: V=1.029194, theta=-11.729101 -> V=1.0, theta=0.0
% INFO    : Bus 4550	: V=1.017355, theta=-10.569179 -> V=1.0, theta=0.0
% INFO    : Bus 4551	: V=1.020947, theta=-29.722641 -> V=1.0, theta=0.0
% INFO    : Bus 4552	: V=1.021862, theta=3.978169 -> V=1.0, theta=0.0
% INFO    : Bus 4553	: V=1.027689, theta=-14.030999 -> V=1.0, theta=0.0
% INFO    : Bus 4554	: V=1.037349, theta=-10.05047 -> V=1.0, theta=0.0
% INFO    : Bus 4555	: V=0.98347, theta=-31.80027 -> V=1.0, theta=0.0
% INFO    : Bus 4556	: V=0.973834, theta=-49.622386 -> V=1.0, theta=0.0
% INFO    : Bus 4557	: V=0.969948, theta=13.501715 -> V=1.0, theta=0.0
% INFO    : Bus 4558	: V=1.050132, theta=-26.127932 -> V=1.0, theta=0.0
% INFO    : Bus 4559	: V=1.045792, theta=-25.014876 -> V=1.0, theta=0.0
% INFO    : Bus 4560	: V=0.923247, theta=-33.083728 -> V=1.0, theta=0.0
% INFO    : Bus 4561	: V=1.023444, theta=-44.433238 -> V=1.0, theta=0.0
% INFO    : Bus 4562	: V=1.018826, theta=-16.997061 -> V=1.0, theta=0.0
% INFO    : Bus 4563	: V=1.010732, theta=-24.420942 -> V=1.0, theta=0.0
% INFO    : Bus 4564	: V=1.026639, theta=-13.312726 -> V=1.0, theta=0.0
% INFO    : Bus 4565	: V=1.023351, theta=11.178136 -> V=1.0, theta=0.0
% INFO    : Bus 4566	: V=1.07048, theta=-27.96894 -> V=1.0, theta=0.0
% INFO    : Bus 4567	: V=0.999125, theta=-3.513287 -> V=1.0, theta=0.0
% INFO    : Bus 4568	: V=1.0034, theta=-33.847076 -> V=1.0, theta=0.0
% INFO    : Bus 4569	: V=1.025197, theta=-24.327029 -> V=1.0, theta=0.0
% INFO    : Bus 4570	: V=1.051768, theta=-21.390504 -> V=1.0, theta=0.0
% INFO    : Bus 4571	: V=1.051203, theta=32.904719 -> V=1.0, theta=0.0
% INFO    : Bus 4572	: V=1.008625, theta=-36.67786 -> V=1.0, theta=0.0
% INFO    : Bus 4573	: V=1.021097, theta=-7.845838 -> V=1.0, theta=0.0
% INFO    : Bus 4574	: V=1.009484, theta=-49.307569 -> V=1.0, theta=0.0
% INFO    : Bus 4575	: V=1.008687, theta=-36.601691 -> V=1.0, theta=0.0
% INFO    : Bus 4576	: V=1.022715, theta=-45.023038 -> V=1.0, theta=0.0
% INFO    : Bus 4577	: V=0.984859, theta=-56.244171 -> V=1.0, theta=0.0
% INFO    : Bus 4578	: V=1.05528, theta=10.516173 -> V=1.0, theta=0.0
% INFO    : Bus 4579	: V=1.043825, theta=-29.528517 -> V=1.0, theta=0.0
% INFO    : Bus 4580	: V=1.040913, theta=-12.304623 -> V=1.0, theta=0.0
% INFO    : Bus 4581	: V=1.053606, theta=10.541803 -> V=1.0, theta=0.0
% INFO    : Bus 4582	: V=1.034802, theta=2.707797 -> V=1.0, theta=0.0
% INFO    : Bus 4583	: V=1.045026, theta=-32.815045 -> V=1.0, theta=0.0
% INFO    : Bus 4584	: V=1.060256, theta=-16.482948 -> V=1.0, theta=0.0
% INFO    : Bus 4585	: V=1.001306, theta=-27.676187 -> V=1.0, theta=0.0
% INFO    : Bus 4586	: V=1.037111, theta=-11.328305 -> V=1.0, theta=0.0
% INFO    : Bus 4587	: V=1.017057, theta=-11.607643 -> V=1.0, theta=0.0
% INFO    : Bus 4588	: V=1.044309, theta=-50.448008 -> V=1.0, theta=0.0
% INFO    : Bus 4589	: V=1.035839, theta=-30.232915 -> V=1.0, theta=0.0
% INFO    : Bus 4590	: V=1.048353, theta=-27.370587 -> V=1.0, theta=0.0
% INFO    : Bus 4591	: V=1.022447, theta=-35.199569 -> V=1.0, theta=0.0
% INFO    : Bus 4592	: V=0.975653, theta=-49.288883 -> V=1.0, theta=0.0
% INFO    : Bus 4593	: V=1.02754, theta=7.892834 -> V=1.0, theta=0.0
% INFO    : Bus 4594	: V=0.993301, theta=-5.867396 -> V=1.0, theta=0.0
% INFO    : Bus 4595	: V=1.038273, theta=10.102597 -> V=1.0, theta=0.0
% INFO    : Bus 4596	: V=1.026034, theta=-35.157759 -> V=1.0, theta=0.0
% INFO    : Bus 4597	: V=1.008674, theta=36.796684 -> V=1.0, theta=0.0
% INFO    : Bus 4598	: V=1.025605, theta=-7.967697 -> V=1.0, theta=0.0
% INFO    : Bus 4599	: V=1.067097, theta=-20.860508 -> V=1.0, theta=0.0
% INFO    : Bus 4600	: V=1.02798, theta=-50.447526 -> V=1.0, theta=0.0
% INFO    : Bus 4601	: V=1.016828, theta=62.846259 -> V=1.0, theta=0.0
% INFO    : Bus 4602	: V=1.120537, theta=-23.246353 -> V=1.0, theta=0.0
% INFO    : Bus 4603	: V=1.014218, theta=-52.607022 -> V=1.0, theta=0.0
% INFO    : Bus 4604	: V=1.046663, theta=-27.065702 -> V=1.0, theta=0.0
% INFO    : Bus 4605	: V=1.065277, theta=-25.758953 -> V=1.0, theta=0.0
% INFO    : Bus 4606	: V=1.033837, theta=-39.750273 -> V=1.0, theta=0.0
% INFO    : Bus 4607	: V=1.0072, theta=-20.965267 -> V=1.0, theta=0.0
% INFO    : Bus 4608	: V=1.034566, theta=14.064182 -> V=1.0, theta=0.0
% INFO    : Bus 4609	: V=1.019251, theta=-7.112921 -> V=1.0, theta=0.0
% INFO    : Bus 4610	: V=1.040483, theta=-41.949678 -> V=1.0, theta=0.0
% INFO    : Bus 4611	: V=1.025155, theta=-4.184983 -> V=1.0, theta=0.0
% INFO    : Bus 4612	: V=1.037926, theta=-33.206689 -> V=1.0, theta=0.0
% INFO    : Bus 4613	: V=1.021632, theta=7.441997 -> V=1.0, theta=0.0
% INFO    : Bus 4614	: V=1.024787, theta=7.57852 -> V=1.0, theta=0.0
% INFO    : Bus 4615	: V=1.059263, theta=-25.746141 -> V=1.0, theta=0.0
% INFO    : Bus 4616	: V=1.014257, theta=16.410389 -> V=1.0, theta=0.0
% INFO    : Bus 4617	: V=1.009059, theta=-26.346838 -> V=1.0, theta=0.0
% INFO    : Bus 4618	: V=0.997564, theta=-39.017154 -> V=1.0, theta=0.0
% INFO    : Bus 4619	: V=0.997745, theta=-37.019205 -> V=1.0, theta=0.0
% INFO    : Bus 4620	: V=1.089892, theta=37.788886 -> V=1.0, theta=0.0
% INFO    : Bus 4621	: V=1.016409, theta=-30.703143 -> V=1.0, theta=0.0
% INFO    : Bus 4622	: V=0.991439, theta=27.885255 -> V=1.0, theta=0.0
% INFO    : Bus 4623	: V=0.990686, theta=-17.130144 -> V=1.0, theta=0.0
% INFO    : Bus 4624	: V=1.045235, theta=-15.735017 -> V=1.0, theta=0.0
% INFO    : Bus 4625	: V=1.022752, theta=-30.753846 -> V=1.0, theta=0.0
% INFO    : Bus 4626	: V=1.025049, theta=-1.48635 -> V=1.0, theta=0.0
% INFO    : Bus 4627	: V=1.002736, theta=-12.227064 -> V=1.0, theta=0.0
% INFO    : Bus 4628	: V=1.014584, theta=-10.135515 -> V=1.0, theta=0.0
% INFO    : Bus 4629	: V=1.035957, theta=-10.334885 -> V=1.0, theta=0.0
% INFO    : Bus 4630	: V=1.040554, theta=-21.071197 -> V=1.0, theta=0.0
% INFO    : Bus 4631	: V=1.034671, theta=-20.329864 -> V=1.0, theta=0.0
% INFO    : Bus 4632	: V=1.013277, theta=-48.949226 -> V=1.0, theta=0.0
% INFO    : Bus 4633	: V=1.009572, theta=-8.700854 -> V=1.0, theta=0.0
% INFO    : Bus 4634	: V=1.016909, theta=-11.763164 -> V=1.0, theta=0.0
% INFO    : Bus 4635	: V=1.050774, theta=-25.185846 -> V=1.0, theta=0.0
% INFO    : Bus 4636	: V=1.028166, theta=-34.087026 -> V=1.0, theta=0.0
% INFO    : Bus 4637	: V=1.019606, theta=-13.307458 -> V=1.0, theta=0.0
% INFO    : Bus 4638	: V=1.050874, theta=-6.909462 -> V=1.0, theta=0.0
% INFO    : Bus 4639	: V=1.012845, theta=-27.830536 -> V=1.0, theta=0.0
% INFO    : Bus 4640	: V=1.029956, theta=4.087062 -> V=1.0, theta=0.0
% INFO    : Bus 4641	: V=0.993058, theta=-27.153987 -> V=1.0, theta=0.0
% INFO    : Bus 4642	: V=1.044207, theta=-24.904203 -> V=1.0, theta=0.0
% INFO    : Bus 4643	: V=1.04714, theta=-25.703503 -> V=1.0, theta=0.0
% INFO    : Bus 4644	: V=1.030242, theta=-44.573358 -> V=1.0, theta=0.0
% INFO    : Bus 4645	: V=1.028738, theta=1.67222 -> V=1.0, theta=0.0
% INFO    : Bus 4646	: V=1.043008, theta=-6.663752 -> V=1.0, theta=0.0
% INFO    : Bus 4647	: V=1.050276, theta=33.029812 -> V=1.0, theta=0.0
% INFO    : Bus 4648	: V=1.032876, theta=-33.918645 -> V=1.0, theta=0.0
% INFO    : Bus 4649	: V=1.031923, theta=-28.555693 -> V=1.0, theta=0.0
% INFO    : Bus 4650	: V=0.988431, theta=-54.38092 -> V=1.0, theta=0.0
% INFO    : Bus 4651	: V=1.024869, theta=-54.400941 -> V=1.0, theta=0.0
% INFO    : Bus 4652	: V=1.060738, theta=-45.351003 -> V=1.0, theta=0.0
% INFO    : Bus 4653	: V=0.988894, theta=-17.901615 -> V=1.0, theta=0.0
% INFO    : Bus 4654	: V=1.017349, theta=-21.71044 -> V=1.0, theta=0.0
% INFO    : Bus 4655	: V=1.057375, theta=-25.146177 -> V=1.0, theta=0.0
% INFO    : Bus 4656	: V=1.041932, theta=-20.065226 -> V=1.0, theta=0.0
% INFO    : Bus 4657	: V=1.020179, theta=-38.717477 -> V=1.0, theta=0.0
% INFO    : Bus 4658	: V=1.006975, theta=-47.89191 -> V=1.0, theta=0.0
% INFO    : Bus 4659	: V=1.061656, theta=-21.366509 -> V=1.0, theta=0.0
% INFO    : Bus 4660	: V=0.960681, theta=-29.361569 -> V=1.0, theta=0.0
% INFO    : Bus 4661	: V=1.056504, theta=-26.712402 -> V=1.0, theta=0.0
% INFO    : Bus 4662	: V=1.066687, theta=43.668995 -> V=1.0, theta=0.0
% INFO    : Bus 4663	: V=1.021171, theta=-50.126756 -> V=1.0, theta=0.0
% INFO    : Bus 4664	: V=0.995969, theta=-19.109257 -> V=1.0, theta=0.0
% INFO    : Bus 4665	: V=1.028821, theta=-11.97837 -> V=1.0, theta=0.0
% INFO    : Bus 4666	: V=1.011313, theta=-20.889278 -> V=1.0, theta=0.0
% INFO    : Bus 4667	: V=1.01948, theta=-28.508662 -> V=1.0, theta=0.0
% INFO    : Bus 4668	: V=1.014022, theta=-30.214599 -> V=1.0, theta=0.0
% INFO    : Bus 4669	: V=1.014375, theta=-23.471051 -> V=1.0, theta=0.0
% INFO    : Bus 4670	: V=1.092961, theta=49.659948 -> V=1.0, theta=0.0
% INFO    : Bus 4671	: V=1.008783, theta=-31.767138 -> V=1.0, theta=0.0
% INFO    : Bus 4672	: V=1.009819, theta=-32.361289 -> V=1.0, theta=0.0
% INFO    : Bus 4673	: V=0.93836, theta=-33.379623 -> V=1.0, theta=0.0
% INFO    : Bus 4674	: V=1.027034, theta=-12.764531 -> V=1.0, theta=0.0
% INFO    : Bus 4675	: V=1.033192, theta=24.896508 -> V=1.0, theta=0.0
% INFO    : Bus 4676	: V=1.088792, theta=-11.699775 -> V=1.0, theta=0.0
% INFO    : Bus 4677	: V=1.054278, theta=-29.798853 -> V=1.0, theta=0.0
% INFO    : Bus 4678	: V=1.051163, theta=-17.647251 -> V=1.0, theta=0.0
% INFO    : Bus 4679	: V=1.03925, theta=-20.91864 -> V=1.0, theta=0.0
% INFO    : Bus 4680	: V=1.043133, theta=-27.420476 -> V=1.0, theta=0.0
% INFO    : Bus 4681	: V=1.038752, theta=-18.976871 -> V=1.0, theta=0.0
% INFO    : Bus 4682	: V=0.92094, theta=-33.044671 -> V=1.0, theta=0.0
% INFO    : Bus 4683	: V=1.049891, theta=-3.935934 -> V=1.0, theta=0.0
% INFO    : Bus 4684	: V=1.04512, theta=-20.498566 -> V=1.0, theta=0.0
% INFO    : Bus 4685	: V=1.038585, theta=-26.129161 -> V=1.0, theta=0.0
% INFO    : Bus 4686	: V=1.034458, theta=8.213903 -> V=1.0, theta=0.0
% INFO    : Bus 4687	: V=1.016575, theta=0.400195 -> V=1.0, theta=0.0
% INFO    : Bus 4688	: V=1.018329, theta=-1.583907 -> V=1.0, theta=0.0
% INFO    : Bus 4689	: V=1.031744, theta=-31.539915 -> V=1.0, theta=0.0
% INFO    : Bus 4690	: V=1.026559, theta=-43.415903 -> V=1.0, theta=0.0
% INFO    : Bus 4691	: V=1.084841, theta=-36.918755 -> V=1.0, theta=0.0
% INFO    : Bus 4692	: V=1.016442, theta=-0.965415 -> V=1.0, theta=0.0
% INFO    : Bus 4693	: V=1.051673, theta=-22.960021 -> V=1.0, theta=0.0
% INFO    : Bus 4694	: V=1.045223, theta=-25.898854 -> V=1.0, theta=0.0
% INFO    : Bus 4695	: V=1.053968, theta=-0.654287 -> V=1.0, theta=0.0
% INFO    : Bus 4696	: V=0.984964, theta=-28.429627 -> V=1.0, theta=0.0
% INFO    : Bus 4697	: V=1.089426, theta=-14.435564 -> V=1.0, theta=0.0
% INFO    : Bus 4698	: V=1.018117, theta=-34.713039 -> V=1.0, theta=0.0
% INFO    : Bus 4699	: V=0.956699, theta=-33.348477 -> V=1.0, theta=0.0
% INFO    : Bus 4700	: V=1.009378, theta=-26.081154 -> V=1.0, theta=0.0
% INFO    : Bus 4701	: V=1.042354, theta=-10.260507 -> V=1.0, theta=0.0
% INFO    : Bus 4702	: V=1.03984, theta=-14.490377 -> V=1.0, theta=0.0
% INFO    : Bus 4703	: V=1.016597, theta=-24.867765 -> V=1.0, theta=0.0
% INFO    : Bus 4704	: V=1.075406, theta=-35.989052 -> V=1.0, theta=0.0
% INFO    : Bus 4705	: V=1.062823, theta=-21.501559 -> V=1.0, theta=0.0
% INFO    : Bus 4706	: V=1.056106, theta=-46.58034 -> V=1.0, theta=0.0
% INFO    : Bus 4707	: V=1.015378, theta=-32.311818 -> V=1.0, theta=0.0
% INFO    : Bus 4708	: V=0.996652, theta=-17.478391 -> V=1.0, theta=0.0
% INFO    : Bus 4709	: V=1.017401, theta=4.166487 -> V=1.0, theta=0.0
% INFO    : Bus 4710	: V=1.025123, theta=-9.245807 -> V=1.0, theta=0.0
% INFO    : Bus 4711	: V=1.037466, theta=-11.707006 -> V=1.0, theta=0.0
% INFO    : Bus 4712	: V=1.030273, theta=-34.784151 -> V=1.0, theta=0.0
% INFO    : Bus 4713	: V=1.050161, theta=-25.455576 -> V=1.0, theta=0.0
% INFO    : Bus 4714	: V=1.014134, theta=3.843624 -> V=1.0, theta=0.0
% INFO    : Bus 4715	: V=1.041648, theta=-48.667335 -> V=1.0, theta=0.0
% INFO    : Bus 4716	: V=1.038999, theta=-19.455771 -> V=1.0, theta=0.0
% INFO    : Bus 4717	: V=1.039748, theta=-42.848896 -> V=1.0, theta=0.0
% INFO    : Bus 4718	: V=1.029209, theta=-11.803938 -> V=1.0, theta=0.0
% INFO    : Bus 4719	: V=1.010182, theta=-36.984842 -> V=1.0, theta=0.0
% INFO    : Bus 4720	: V=1.019139, theta=62.912023 -> V=1.0, theta=0.0
% INFO    : Bus 4721	: V=0.988034, theta=-55.007165 -> V=1.0, theta=0.0
% INFO    : Bus 4722	: V=1.036827, theta=12.102438 -> V=1.0, theta=0.0
% INFO    : Bus 4723	: V=1.017996, theta=3.131543 -> V=1.0, theta=0.0
% INFO    : Bus 4724	: V=1.014721, theta=-32.352939 -> V=1.0, theta=0.0
% INFO    : Bus 4725	: V=1.012202, theta=-10.659528 -> V=1.0, theta=0.0
% INFO    : Bus 4726	: V=0.96405, theta=-31.91617 -> V=1.0, theta=0.0
% INFO    : Bus 4727	: V=0.976405, theta=-32.063514 -> V=1.0, theta=0.0
% INFO    : Bus 4728	: V=1.037292, theta=-21.668108 -> V=1.0, theta=0.0
% INFO    : Bus 4729	: V=1.026533, theta=-9.241781 -> V=1.0, theta=0.0
% INFO    : Bus 4730	: V=0.956024, theta=-29.933031 -> V=1.0, theta=0.0
% INFO    : Bus 4731	: V=1.038302, theta=-23.13186 -> V=1.0, theta=0.0
% INFO    : Bus 4732	: V=1.055652, theta=17.016439 -> V=1.0, theta=0.0
% INFO    : Bus 4733	: V=1.047928, theta=18.07872 -> V=1.0, theta=0.0
% INFO    : Bus 4734	: V=1.019192, theta=-10.274453 -> V=1.0, theta=0.0
% INFO    : Bus 4735	: V=0.985176, theta=-44.869375 -> V=1.0, theta=0.0
% INFO    : Bus 4736	: V=1.077459, theta=-15.116153 -> V=1.0, theta=0.0
% INFO    : Bus 4737	: V=1.009608, theta=0.739976 -> V=1.0, theta=0.0
% INFO    : Bus 4738	: V=1.06023, theta=-11.244543 -> V=1.0, theta=0.0
% INFO    : Bus 4739	: V=1.021645, theta=-12.210831 -> V=1.0, theta=0.0
% INFO    : Bus 4740	: V=1.033532, theta=16.621621 -> V=1.0, theta=0.0
% INFO    : Bus 4741	: V=0.984405, theta=-16.0631 -> V=1.0, theta=0.0
% INFO    : Bus 4742	: V=1.019517, theta=-0.458767 -> V=1.0, theta=0.0
% INFO    : Bus 4743	: V=1.063165, theta=-33.996846 -> V=1.0, theta=0.0
% INFO    : Bus 4744	: V=0.974785, theta=-41.675373 -> V=1.0, theta=0.0
% INFO    : Bus 4745	: V=1.038799, theta=-22.569603 -> V=1.0, theta=0.0
% INFO    : Bus 4746	: V=1.02826, theta=-27.196577 -> V=1.0, theta=0.0
% INFO    : Bus 4747	: V=1.030442, theta=-12.622107 -> V=1.0, theta=0.0
% INFO    : Bus 4748	: V=1.029885, theta=-12.614931 -> V=1.0, theta=0.0
% INFO    : Bus 4749	: V=1.030135, theta=1.76446 -> V=1.0, theta=0.0
% INFO    : Bus 4750	: V=1.007905, theta=-45.954364 -> V=1.0, theta=0.0
% INFO    : Bus 4751	: V=1.013847, theta=-32.766687 -> V=1.0, theta=0.0
% INFO    : Bus 4752	: V=1.003304, theta=-48.431638 -> V=1.0, theta=0.0
% INFO    : Bus 4753	: V=1.0366, theta=59.160645 -> V=1.0, theta=0.0
% INFO    : Bus 4754	: V=0.987901, theta=-23.107942 -> V=1.0, theta=0.0
% INFO    : Bus 4755	: V=1.0132, theta=-5.020784 -> V=1.0, theta=0.0
% INFO    : Bus 4756	: V=0.919635, theta=-36.305721 -> V=1.0, theta=0.0
% INFO    : Bus 4757	: V=1.026011, theta=3.040149 -> V=1.0, theta=0.0
% INFO    : Bus 4758	: V=1.064718, theta=13.012268 -> V=1.0, theta=0.0
% INFO    : Bus 4759	: V=0.987109, theta=-20.147328 -> V=1.0, theta=0.0
% INFO    : Bus 4760	: V=1.071663, theta=-23.040954 -> V=1.0, theta=0.0
% INFO    : Bus 4761	: V=1.021014, theta=-25.555438 -> V=1.0, theta=0.0
% INFO    : Bus 4762	: V=1.024473, theta=-26.6387 -> V=1.0, theta=0.0
% INFO    : Bus 4763	: V=0.962855, theta=-32.204002 -> V=1.0, theta=0.0
% INFO    : Bus 4764	: V=0.990229, theta=-29.174476 -> V=1.0, theta=0.0
% INFO    : Bus 4765	: V=1.039707, theta=-12.376759 -> V=1.0, theta=0.0
% INFO    : Bus 4766	: V=1.039299, theta=44.191195 -> V=1.0, theta=0.0
% INFO    : Bus 4767	: V=1.016935, theta=-39.034904 -> V=1.0, theta=0.0
% INFO    : Bus 4768	: V=1.007739, theta=-11.291231 -> V=1.0, theta=0.0
% INFO    : Bus 4769	: V=1.019849, theta=-23.59881 -> V=1.0, theta=0.0
% INFO    : Bus 4770	: V=1.011545, theta=-36.410984 -> V=1.0, theta=0.0
% INFO    : Bus 4771	: V=0.991474, theta=-36.774818 -> V=1.0, theta=0.0
% INFO    : Bus 4772	: V=1.023126, theta=-48.430245 -> V=1.0, theta=0.0
% INFO    : Bus 4773	: V=1.017383, theta=-42.835159 -> V=1.0, theta=0.0
% INFO    : Bus 4774	: V=1.036095, theta=1.264238 -> V=1.0, theta=0.0
% INFO    : Bus 4775	: V=1.048902, theta=-22.223071 -> V=1.0, theta=0.0
% INFO    : Bus 4776	: V=1.063105, theta=26.806955 -> V=1.0, theta=0.0
% INFO    : Bus 4777	: V=1.032992, theta=-24.051017 -> V=1.0, theta=0.0
% INFO    : Bus 4778	: V=0.975132, theta=-31.984222 -> V=1.0, theta=0.0
% INFO    : Bus 4779	: V=1.062119, theta=32.50466 -> V=1.0, theta=0.0
% INFO    : Bus 4780	: V=0.974542, theta=-29.644756 -> V=1.0, theta=0.0
% INFO    : Bus 4781	: V=0.961409, theta=-31.649013 -> V=1.0, theta=0.0
% INFO    : Bus 4782	: V=1.000106, theta=-30.520244 -> V=1.0, theta=0.0
% INFO    : Bus 4783	: V=1.06564, theta=8.268721 -> V=1.0, theta=0.0
% INFO    : Bus 4784	: V=0.981687, theta=-33.345316 -> V=1.0, theta=0.0
% INFO    : Bus 4785	: V=1.0433, theta=-3.069758 -> V=1.0, theta=0.0
% INFO    : Bus 4786	: V=1.024011, theta=19.961509 -> V=1.0, theta=0.0
% INFO    : Bus 4787	: V=0.987262, theta=-14.984001 -> V=1.0, theta=0.0
% INFO    : Bus 4788	: V=1.009861, theta=-8.800983 -> V=1.0, theta=0.0
% INFO    : Bus 4789	: V=1.050877, theta=1.718645 -> V=1.0, theta=0.0
% INFO    : Bus 4790	: V=0.993761, theta=-32.641501 -> V=1.0, theta=0.0
% INFO    : Bus 4791	: V=1.028363, theta=-33.549703 -> V=1.0, theta=0.0
% INFO    : Bus 4792	: V=1.032521, theta=-30.871912 -> V=1.0, theta=0.0
% INFO    : Bus 4793	: V=1.009198, theta=-4.731499 -> V=1.0, theta=0.0
% INFO    : Bus 4794	: V=1.067214, theta=-16.568703 -> V=1.0, theta=0.0
% INFO    : Bus 4795	: V=1.066419, theta=-44.250688 -> V=1.0, theta=0.0
% INFO    : Bus 4796	: V=1.097162, theta=-24.424031 -> V=1.0, theta=0.0
% INFO    : Bus 4797	: V=1.079402, theta=31.594293 -> V=1.0, theta=0.0
% INFO    : Bus 4798	: V=1.016409, theta=-30.703143 -> V=1.0, theta=0.0
% INFO    : Bus 4799	: V=1.022774, theta=5.3994 -> V=1.0, theta=0.0
% INFO    : Bus 4800	: V=1.03935, theta=-29.675036 -> V=1.0, theta=0.0
% INFO    : Bus 4801	: V=1.095999, theta=-25.627197 -> V=1.0, theta=0.0
% INFO    : Bus 4802	: V=0.999385, theta=-28.927844 -> V=1.0, theta=0.0
% INFO    : Bus 4803	: V=1.007102, theta=-30.594835 -> V=1.0, theta=0.0
% INFO    : Bus 4804	: V=1.030914, theta=-21.955421 -> V=1.0, theta=0.0
% INFO    : Bus 4805	: V=1.046224, theta=5.406275 -> V=1.0, theta=0.0
% INFO    : Bus 4806	: V=1.021554, theta=-47.07847 -> V=1.0, theta=0.0
% INFO    : Bus 4807	: V=1.051133, theta=-42.289639 -> V=1.0, theta=0.0
% INFO    : Bus 4808	: V=1.020706, theta=-27.864908 -> V=1.0, theta=0.0
% INFO    : Bus 4809	: V=1.006384, theta=-45.998249 -> V=1.0, theta=0.0
% INFO    : Bus 4810	: V=1.060127, theta=-29.656805 -> V=1.0, theta=0.0
% INFO    : Bus 4811	: V=1.04153, theta=-6.009141 -> V=1.0, theta=0.0
% INFO    : Bus 4812	: V=1.024747, theta=-4.028591 -> V=1.0, theta=0.0
% INFO    : Bus 4813	: V=0.992803, theta=-50.740529 -> V=1.0, theta=0.0
% INFO    : Bus 4814	: V=0.982604, theta=-30.201957 -> V=1.0, theta=0.0
% INFO    : Bus 4815	: V=1.031204, theta=-26.292889 -> V=1.0, theta=0.0
% INFO    : Bus 4816	: V=1.060527, theta=-24.1453 -> V=1.0, theta=0.0
% INFO    : Bus 4817	: V=1.060926, theta=-24.219659 -> V=1.0, theta=0.0
% INFO    : Bus 4818	: V=1.025646, theta=3.281034 -> V=1.0, theta=0.0
% INFO    : Bus 4819	: V=1.028949, theta=0.926703 -> V=1.0, theta=0.0
% INFO    : Bus 4820	: V=1.08399, theta=-47.775641 -> V=1.0, theta=0.0
% INFO    : Bus 4821	: V=0.996011, theta=-31.048839 -> V=1.0, theta=0.0
% INFO    : Bus 4822	: V=0.977947, theta=-31.778345 -> V=1.0, theta=0.0
% INFO    : Bus 4823	: V=1.055712, theta=-15.19649 -> V=1.0, theta=0.0
% INFO    : Bus 4824	: V=1.089599, theta=-14.508804 -> V=1.0, theta=0.0
% INFO    : Bus 4825	: V=1.009259, theta=8.12329 -> V=1.0, theta=0.0
% INFO    : Bus 4826	: V=1.074227, theta=-24.636519 -> V=1.0, theta=0.0
% INFO    : Bus 4827	: V=1.033461, theta=58.438338 -> V=1.0, theta=0.0
% INFO    : Bus 4828	: V=1.027792, theta=-29.418146 -> V=1.0, theta=0.0
% INFO    : Bus 4829	: V=1.015623, theta=-5.852548 -> V=1.0, theta=0.0
% INFO    : Bus 4830	: V=1.029413, theta=-11.080903 -> V=1.0, theta=0.0
% INFO    : Bus 4831	: V=1.031088, theta=-15.625679 -> V=1.0, theta=0.0
% INFO    : Bus 4832	: V=1.023151, theta=-43.126712 -> V=1.0, theta=0.0
% INFO    : Bus 4833	: V=0.92644, theta=-32.984156 -> V=1.0, theta=0.0
% INFO    : Bus 4834	: V=1.038553, theta=10.065557 -> V=1.0, theta=0.0
% INFO    : Bus 4835	: V=1.084853, theta=-36.920174 -> V=1.0, theta=0.0
% INFO    : Bus 4836	: V=1.050935, theta=-30.001995 -> V=1.0, theta=0.0
% INFO    : Bus 4837	: V=1.018654, theta=-14.598693 -> V=1.0, theta=0.0
% INFO    : Bus 4838	: V=0.97368, theta=-29.714155 -> V=1.0, theta=0.0
% INFO    : Bus 4839	: V=1.063954, theta=-34.589904 -> V=1.0, theta=0.0
% INFO    : Bus 4840	: V=1.017478, theta=-16.182331 -> V=1.0, theta=0.0
% INFO    : Bus 4841	: V=1.003311, theta=-31.350195 -> V=1.0, theta=0.0
% INFO    : Bus 4842	: V=1.036905, theta=-32.653186 -> V=1.0, theta=0.0
% INFO    : Bus 4843	: V=1.048394, theta=-42.642098 -> V=1.0, theta=0.0
% INFO    : Bus 4844	: V=1.00703, theta=33.093639 -> V=1.0, theta=0.0
% INFO    : Bus 4845	: V=1.024167, theta=61.965245 -> V=1.0, theta=0.0
% INFO    : Bus 4846	: V=1.030121, theta=12.96686 -> V=1.0, theta=0.0
% INFO    : Bus 4847	: V=1.081656, theta=12.984521 -> V=1.0, theta=0.0
% INFO    : Bus 4848	: V=1.070363, theta=-26.152532 -> V=1.0, theta=0.0
% INFO    : Bus 4849	: V=1.029581, theta=-7.660653 -> V=1.0, theta=0.0
% INFO    : Bus 4850	: V=1.057137, theta=-13.928912 -> V=1.0, theta=0.0
% INFO    : Bus 4851	: V=0.984372, theta=-27.718943 -> V=1.0, theta=0.0
% INFO    : Bus 4852	: V=1.037552, theta=-20.631579 -> V=1.0, theta=0.0
% INFO    : Bus 4853	: V=1.011478, theta=-31.784552 -> V=1.0, theta=0.0
% INFO    : Bus 4854	: V=0.98255, theta=6.741383 -> V=1.0, theta=0.0
% INFO    : Bus 4855	: V=1.011289, theta=-60.1788 -> V=1.0, theta=0.0
% INFO    : Bus 4856	: V=1.021361, theta=-45.516743 -> V=1.0, theta=0.0
% INFO    : Bus 4857	: V=1.049037, theta=-27.233229 -> V=1.0, theta=0.0
% INFO    : Bus 4858	: V=1.064085, theta=29.968955 -> V=1.0, theta=0.0
% INFO    : Bus 4859	: V=1.06403, theta=55.017036 -> V=1.0, theta=0.0
% INFO    : Bus 4860	: V=1.014639, theta=-3.738268 -> V=1.0, theta=0.0
% INFO    : Bus 4861	: V=1.032468, theta=-26.038409 -> V=1.0, theta=0.0
% INFO    : Bus 4862	: V=1.001217, theta=-24.471022 -> V=1.0, theta=0.0
% INFO    : Bus 4863	: V=1.022069, theta=10.989113 -> V=1.0, theta=0.0
% INFO    : Bus 4864	: V=1.044886, theta=-13.237652 -> V=1.0, theta=0.0
% INFO    : Bus 4865	: V=1.019121, theta=-48.988888 -> V=1.0, theta=0.0
% INFO    : Bus 4866	: V=1.027719, theta=20.158525 -> V=1.0, theta=0.0
% INFO    : Bus 4867	: V=1.027117, theta=-3.83085 -> V=1.0, theta=0.0
% INFO    : Bus 4868	: V=0.994275, theta=-48.159668 -> V=1.0, theta=0.0
% INFO    : Bus 4869	: V=1.026579, theta=-13.337718 -> V=1.0, theta=0.0
% INFO    : Bus 4870	: V=0.997277, theta=4.262502 -> V=1.0, theta=0.0
% INFO    : Bus 4871	: V=1.054823, theta=-21.307193 -> V=1.0, theta=0.0
% INFO    : Bus 4872	: V=1.020922, theta=7.053602 -> V=1.0, theta=0.0
% INFO    : Bus 4873	: V=0.996169, theta=-48.406794 -> V=1.0, theta=0.0
% INFO    : Bus 4874	: V=1.075415, theta=-39.326121 -> V=1.0, theta=0.0
% INFO    : Bus 4875	: V=0.996138, theta=9.405021 -> V=1.0, theta=0.0
% INFO    : Bus 4876	: V=1.022928, theta=-23.903668 -> V=1.0, theta=0.0
% INFO    : Bus 4877	: V=1.048444, theta=-24.999745 -> V=1.0, theta=0.0
% INFO    : Bus 4878	: V=1.028678, theta=-34.027355 -> V=1.0, theta=0.0
% INFO    : Bus 4879	: V=1.026685, theta=-0.863653 -> V=1.0, theta=0.0
% INFO    : Bus 4880	: V=1.041763, theta=-15.664109 -> V=1.0, theta=0.0
% INFO    : Bus 4881	: V=0.954039, theta=-31.055989 -> V=1.0, theta=0.0
% INFO    : Bus 4882	: V=1.028068, theta=17.747314 -> V=1.0, theta=0.0
% INFO    : Bus 4883	: V=1.00371, theta=-32.000976 -> V=1.0, theta=0.0
% INFO    : Bus 4884	: V=1.019233, theta=-0.73514 -> V=1.0, theta=0.0
% INFO    : Bus 4885	: V=1.06846, theta=-26.747409 -> V=1.0, theta=0.0
% INFO    : Bus 4886	: V=1.071272, theta=60.019932 -> V=1.0, theta=0.0
% INFO    : Bus 4887	: V=0.982898, theta=-28.745965 -> V=1.0, theta=0.0
% INFO    : Bus 4888	: V=1.000821, theta=-18.823128 -> V=1.0, theta=0.0
% INFO    : Bus 4889	: V=1.028982, theta=-12.570692 -> V=1.0, theta=0.0
% INFO    : Bus 4890	: V=1.019498, theta=-48.757938 -> V=1.0, theta=0.0
% INFO    : Bus 4891	: V=1.01492, theta=-13.803384 -> V=1.0, theta=0.0
% INFO    : Bus 4892	: V=1.033418, theta=-2.864989 -> V=1.0, theta=0.0
% INFO    : Bus 4893	: V=1.039906, theta=4.586896 -> V=1.0, theta=0.0
% INFO    : Bus 4894	: V=1.102158, theta=-15.536498 -> V=1.0, theta=0.0
% INFO    : Bus 4895	: V=1.040119, theta=-21.348536 -> V=1.0, theta=0.0
% INFO    : Bus 4896	: V=1.009835, theta=-58.953855 -> V=1.0, theta=0.0
% INFO    : Bus 4897	: V=1.014069, theta=-46.541884 -> V=1.0, theta=0.0
% INFO    : Bus 4898	: V=1.031771, theta=-11.979093 -> V=1.0, theta=0.0
% INFO    : Bus 4899	: V=1.024222, theta=-27.975557 -> V=1.0, theta=0.0
% INFO    : Bus 4900	: V=1.023832, theta=14.693276 -> V=1.0, theta=0.0
% INFO    : Bus 4901	: V=1.004799, theta=-26.239776 -> V=1.0, theta=0.0
% INFO    : Bus 4902	: V=0.994314, theta=-31.942978 -> V=1.0, theta=0.0
% INFO    : Bus 4903	: V=1.089802, theta=-13.333108 -> V=1.0, theta=0.0
% INFO    : Bus 4904	: V=1.006792, theta=-37.073353 -> V=1.0, theta=0.0
% INFO    : Bus 4905	: V=1.024715, theta=-34.268369 -> V=1.0, theta=0.0
% INFO    : Bus 4906	: V=1.023576, theta=-46.41154 -> V=1.0, theta=0.0
% INFO    : Bus 4907	: V=1.037484, theta=-13.630352 -> V=1.0, theta=0.0
% INFO    : Bus 4908	: V=1.034526, theta=-21.581828 -> V=1.0, theta=0.0
% INFO    : Bus 4909	: V=1.03446, theta=-21.776933 -> V=1.0, theta=0.0
% INFO    : Bus 4910	: V=1.021443, theta=-47.156402 -> V=1.0, theta=0.0
% INFO    : Bus 4911	: V=1.047684, theta=-27.412491 -> V=1.0, theta=0.0
% INFO    : Bus 4912	: V=1.036375, theta=-21.486687 -> V=1.0, theta=0.0
% INFO    : Bus 4913	: V=1.018213, theta=-26.024805 -> V=1.0, theta=0.0
% INFO    : Bus 4914	: V=1.032689, theta=-23.332011 -> V=1.0, theta=0.0
% INFO    : Bus 4915	: V=0.998633, theta=-32.348994 -> V=1.0, theta=0.0
% INFO    : Bus 4916	: V=1.021276, theta=-14.380448 -> V=1.0, theta=0.0
% INFO    : Bus 4917	: V=1.001322, theta=-13.363196 -> V=1.0, theta=0.0
% INFO    : Bus 4918	: V=1.053068, theta=-11.355832 -> V=1.0, theta=0.0
% INFO    : Bus 4919	: V=1.048486, theta=-29.24882 -> V=1.0, theta=0.0
% INFO    : Bus 4920	: V=1.003171, theta=-1.030666 -> V=1.0, theta=0.0
% INFO    : Bus 4921	: V=1.022562, theta=6.896935 -> V=1.0, theta=0.0
% INFO    : Bus 4922	: V=1.047775, theta=-16.290741 -> V=1.0, theta=0.0
% INFO    : Bus 4923	: V=1.032381, theta=-17.722009 -> V=1.0, theta=0.0
% INFO    : Bus 4924	: V=1.061023, theta=-19.247849 -> V=1.0, theta=0.0
% INFO    : Bus 4925	: V=1.032032, theta=-22.830457 -> V=1.0, theta=0.0
% INFO    : Bus 4926	: V=1.051879, theta=-42.309199 -> V=1.0, theta=0.0
% INFO    : Bus 4927	: V=0.99652, theta=-22.778897 -> V=1.0, theta=0.0
% INFO    : Bus 4928	: V=1.021927, theta=-46.925549 -> V=1.0, theta=0.0
% INFO    : Bus 4929	: V=1.018028, theta=4.736989 -> V=1.0, theta=0.0
% INFO    : Bus 4930	: V=0.997633, theta=-26.018623 -> V=1.0, theta=0.0
% INFO    : Bus 4931	: V=1.035713, theta=-43.642893 -> V=1.0, theta=0.0
% INFO    : Bus 4932	: V=0.982693, theta=-27.895484 -> V=1.0, theta=0.0
% INFO    : Bus 4933	: V=0.977104, theta=-29.903365 -> V=1.0, theta=0.0
% INFO    : Bus 4934	: V=1.013716, theta=-38.904971 -> V=1.0, theta=0.0
% INFO    : Bus 4935	: V=1.041012, theta=-31.424919 -> V=1.0, theta=0.0
% INFO    : Bus 4936	: V=1.031863, theta=-31.443839 -> V=1.0, theta=0.0
% INFO    : Bus 4937	: V=1.064197, theta=-31.921414 -> V=1.0, theta=0.0
% INFO    : Bus 4938	: V=1.031692, theta=-7.869883 -> V=1.0, theta=0.0
% INFO    : Bus 4939	: V=1.041972, theta=-4.812959 -> V=1.0, theta=0.0
% INFO    : Bus 4940	: V=0.917613, theta=-35.788282 -> V=1.0, theta=0.0
% INFO    : Bus 4941	: V=1.002344, theta=8.412161 -> V=1.0, theta=0.0
% INFO    : Bus 4942	: V=1.026049, theta=-13.088391 -> V=1.0, theta=0.0
% INFO    : Bus 4943	: V=1.04576, theta=-16.022015 -> V=1.0, theta=0.0
% INFO    : Bus 4944	: V=1.0154, theta=-22.809584 -> V=1.0, theta=0.0
% INFO    : Bus 4945	: V=1.055797, theta=-41.194507 -> V=1.0, theta=0.0
% INFO    : Bus 4946	: V=1.013935, theta=-13.593736 -> V=1.0, theta=0.0
% INFO    : Bus 4947	: V=1.015918, theta=-39.946101 -> V=1.0, theta=0.0
% INFO    : Bus 4948	: V=1.030299, theta=-40.316404 -> V=1.0, theta=0.0
% INFO    : Bus 4949	: V=1.046901, theta=2.83582 -> V=1.0, theta=0.0
% INFO    : Bus 4950	: V=1.030927, theta=-40.498397 -> V=1.0, theta=0.0
% INFO    : Bus 4951	: V=1.041769, theta=-1.912149 -> V=1.0, theta=0.0
% INFO    : Bus 4952	: V=1.047958, theta=-17.520372 -> V=1.0, theta=0.0
% INFO    : Bus 4953	: V=1.014288, theta=-51.969966 -> V=1.0, theta=0.0
% INFO    : Bus 4954	: V=1.016721, theta=-43.596314 -> V=1.0, theta=0.0
% INFO    : Bus 4955	: V=1.037342, theta=-7.422474 -> V=1.0, theta=0.0
% INFO    : Bus 4956	: V=1.042247, theta=-3.198061 -> V=1.0, theta=0.0
% INFO    : Bus 4957	: V=1.045811, theta=-39.083866 -> V=1.0, theta=0.0
% INFO    : Bus 4958	: V=1.027072, theta=-45.983946 -> V=1.0, theta=0.0
% INFO    : Bus 4959	: V=1.051773, theta=-18.155087 -> V=1.0, theta=0.0
% INFO    : Bus 4960	: V=0.958246, theta=-30.72556 -> V=1.0, theta=0.0
% INFO    : Bus 4961	: V=0.953377, theta=-18.616786 -> V=1.0, theta=0.0
% INFO    : Bus 4962	: V=0.983081, theta=-31.410789 -> V=1.0, theta=0.0
% INFO    : Bus 4963	: V=0.989807, theta=-30.82242 -> V=1.0, theta=0.0
% INFO    : Bus 4964	: V=1.026578, theta=11.490083 -> V=1.0, theta=0.0
% INFO    : Bus 4965	: V=1.020634, theta=-29.934806 -> V=1.0, theta=0.0
% INFO    : Bus 4966	: V=1.008477, theta=-41.810075 -> V=1.0, theta=0.0
% INFO    : Bus 4967	: V=1.020942, theta=-42.545101 -> V=1.0, theta=0.0
% INFO    : Bus 4968	: V=1.049681, theta=11.588745 -> V=1.0, theta=0.0
% INFO    : Bus 4969	: V=1.065019, theta=-9.014123 -> V=1.0, theta=0.0
% INFO    : Bus 4970	: V=1.058166, theta=-17.965332 -> V=1.0, theta=0.0
% INFO    : Bus 4971	: V=1.014937, theta=-14.841613 -> V=1.0, theta=0.0
% INFO    : Bus 4972	: V=1.019416, theta=-7.659192 -> V=1.0, theta=0.0
% INFO    : Bus 4973	: V=1.029241, theta=-22.185994 -> V=1.0, theta=0.0
% INFO    : Bus 4974	: V=1.020099, theta=-13.73201 -> V=1.0, theta=0.0
% INFO    : Bus 4975	: V=0.893435, theta=-35.853165 -> V=1.0, theta=0.0
% INFO    : Bus 4976	: V=0.984261, theta=-28.464149 -> V=1.0, theta=0.0
% INFO    : Bus 4977	: V=1.059145, theta=-29.297782 -> V=1.0, theta=0.0
% INFO    : Bus 4978	: V=0.963067, theta=-31.477381 -> V=1.0, theta=0.0
% INFO    : Bus 4979	: V=1.039397, theta=-19.104141 -> V=1.0, theta=0.0
% INFO    : Bus 4980	: V=1.013058, theta=-8.277201 -> V=1.0, theta=0.0
% INFO    : Bus 4981	: V=1.00481, theta=-32.06595 -> V=1.0, theta=0.0
% INFO    : Bus 4982	: V=1.004947, theta=-41.059674 -> V=1.0, theta=0.0
% INFO    : Bus 4983	: V=1.007916, theta=-25.306148 -> V=1.0, theta=0.0
% INFO    : Bus 4984	: V=1.000242, theta=-28.038181 -> V=1.0, theta=0.0
% INFO    : Bus 4985	: V=1.110771, theta=-22.731958 -> V=1.0, theta=0.0
% INFO    : Bus 4986	: V=1.0658, theta=-25.302839 -> V=1.0, theta=0.0
% INFO    : Bus 4987	: V=1.017878, theta=-26.029213 -> V=1.0, theta=0.0
% INFO    : Bus 4988	: V=1.018071, theta=-20.102983 -> V=1.0, theta=0.0
% INFO    : Bus 4989	: V=0.997604, theta=-24.708005 -> V=1.0, theta=0.0
% INFO    : Bus 4990	: V=1.040475, theta=-26.159191 -> V=1.0, theta=0.0
% INFO    : Bus 4991	: V=1.023645, theta=-46.005472 -> V=1.0, theta=0.0
% INFO    : Bus 4992	: V=0.95548, theta=-17.778421 -> V=1.0, theta=0.0
% INFO    : Bus 4993	: V=1.08106, theta=31.726559 -> V=1.0, theta=0.0
% INFO    : Bus 4994	: V=1.047685, theta=-28.158838 -> V=1.0, theta=0.0
% INFO    : Bus 4995	: V=0.987735, theta=-50.740816 -> V=1.0, theta=0.0
% INFO    : Bus 4996	: V=1.040488, theta=-32.985607 -> V=1.0, theta=0.0
% INFO    : Bus 4997	: V=1.066858, theta=-26.629056 -> V=1.0, theta=0.0
% INFO    : Bus 4998	: V=1.000934, theta=-24.434419 -> V=1.0, theta=0.0
% INFO    : Bus 4999	: V=1.004825, theta=-11.522006 -> V=1.0, theta=0.0
% INFO    : Bus 5000	: V=1.066857, theta=-26.629052 -> V=1.0, theta=0.0
% INFO    : Bus 5001	: V=1.064885, theta=14.706305 -> V=1.0, theta=0.0
% INFO    : Bus 5002	: V=1.072288, theta=-7.351176 -> V=1.0, theta=0.0
% INFO    : Bus 5003	: V=1.03844, theta=-9.926369 -> V=1.0, theta=0.0
% INFO    : Bus 5004	: V=1.054301, theta=-15.923141 -> V=1.0, theta=0.0
% INFO    : Bus 5005	: V=1.062291, theta=54.461313 -> V=1.0, theta=0.0
% INFO    : Bus 5006	: V=0.991224, theta=-37.430456 -> V=1.0, theta=0.0
% INFO    : Bus 5007	: V=1.020758, theta=-15.351482 -> V=1.0, theta=0.0
% INFO    : Bus 5008	: V=1.017261, theta=11.508675 -> V=1.0, theta=0.0
% INFO    : Bus 5009	: V=1.079182, theta=-14.241458 -> V=1.0, theta=0.0
% INFO    : Bus 5010	: V=1.031193, theta=4.637375 -> V=1.0, theta=0.0
% INFO    : Bus 5011	: V=1.052752, theta=12.478077 -> V=1.0, theta=0.0
% INFO    : Bus 5012	: V=0.959202, theta=-29.296099 -> V=1.0, theta=0.0
% INFO    : Bus 5013	: V=0.960889, theta=-31.648573 -> V=1.0, theta=0.0
% INFO    : Bus 5014	: V=1.025949, theta=-13.350064 -> V=1.0, theta=0.0
% INFO    : Bus 5015	: V=1.051844, theta=-19.601795 -> V=1.0, theta=0.0
% INFO    : Bus 5016	: V=1.019196, theta=-5.050368 -> V=1.0, theta=0.0
% INFO    : Bus 5017	: V=1.045354, theta=-20.92555 -> V=1.0, theta=0.0
% INFO    : Bus 5018	: V=0.98564, theta=-26.685436 -> V=1.0, theta=0.0
% INFO    : Bus 5019	: V=1.05406, theta=-13.335274 -> V=1.0, theta=0.0
% INFO    : Bus 5020	: V=1.067392, theta=-27.874565 -> V=1.0, theta=0.0
% INFO    : Bus 5021	: V=1.009321, theta=51.728828 -> V=1.0, theta=0.0
% INFO    : Bus 5022	: V=0.990784, theta=-30.586521 -> V=1.0, theta=0.0
% INFO    : Bus 5023	: V=1.028198, theta=18.916671 -> V=1.0, theta=0.0
% INFO    : Bus 5024	: V=1.054697, theta=-20.712211 -> V=1.0, theta=0.0
% INFO    : Bus 5025	: V=1.002981, theta=-48.33968 -> V=1.0, theta=0.0
% INFO    : Bus 5026	: V=1.056144, theta=-6.90172 -> V=1.0, theta=0.0
% INFO    : Bus 5027	: V=1.046647, theta=-18.582863 -> V=1.0, theta=0.0
% INFO    : Bus 5028	: V=1.000587, theta=-8.829005 -> V=1.0, theta=0.0
% INFO    : Bus 5029	: V=1.020712, theta=-15.292549 -> V=1.0, theta=0.0
% INFO    : Bus 5030	: V=0.962887, theta=-32.243935 -> V=1.0, theta=0.0
% INFO    : Bus 5031	: V=1.020947, theta=7.905729 -> V=1.0, theta=0.0
% INFO    : Bus 5032	: V=1.012239, theta=-35.608603 -> V=1.0, theta=0.0
% INFO    : Bus 5033	: V=1.028024, theta=-11.574594 -> V=1.0, theta=0.0
% INFO    : Bus 5034	: V=1.02172, theta=-52.053756 -> V=1.0, theta=0.0
% INFO    : Bus 5035	: V=1.031718, theta=-42.193252 -> V=1.0, theta=0.0
% INFO    : Bus 5036	: V=1.060776, theta=-22.800944 -> V=1.0, theta=0.0
% INFO    : Bus 5037	: V=0.95097, theta=-30.827123 -> V=1.0, theta=0.0
% INFO    : Bus 5038	: V=1.019784, theta=-11.434184 -> V=1.0, theta=0.0
% INFO    : Bus 5039	: V=0.950642, theta=-30.558087 -> V=1.0, theta=0.0
% INFO    : Bus 5040	: V=1.028521, theta=-7.657229 -> V=1.0, theta=0.0
% INFO    : Bus 5041	: V=1.060344, theta=-30.926836 -> V=1.0, theta=0.0
% INFO    : Bus 5042	: V=1.037823, theta=-50.188852 -> V=1.0, theta=0.0
% INFO    : Bus 5043	: V=1.07576, theta=-19.742609 -> V=1.0, theta=0.0
% INFO    : Bus 5044	: V=1.056908, theta=-40.620016 -> V=1.0, theta=0.0
% INFO    : Bus 5045	: V=0.985984, theta=-20.249217 -> V=1.0, theta=0.0
% INFO    : Bus 5046	: V=1.012038, theta=65.139289 -> V=1.0, theta=0.0
% INFO    : Bus 5047	: V=0.990151, theta=-29.55751 -> V=1.0, theta=0.0
% INFO    : Bus 5048	: V=1.064535, theta=53.239353 -> V=1.0, theta=0.0
% INFO    : Bus 5049	: V=1.014828, theta=-20.777774 -> V=1.0, theta=0.0
% INFO    : Bus 5050	: V=1.047816, theta=-21.271323 -> V=1.0, theta=0.0
% INFO    : Bus 5051	: V=1.042576, theta=-16.820552 -> V=1.0, theta=0.0
% INFO    : Bus 5052	: V=0.972477, theta=-23.585502 -> V=1.0, theta=0.0
% INFO    : Bus 5053	: V=1.04204, theta=-29.563033 -> V=1.0, theta=0.0
% INFO    : Bus 5054	: V=1.074611, theta=37.120818 -> V=1.0, theta=0.0
% INFO    : Bus 5055	: V=1.024425, theta=-21.542982 -> V=1.0, theta=0.0
% INFO    : Bus 5056	: V=1.012688, theta=-8.331742 -> V=1.0, theta=0.0
% INFO    : Bus 5057	: V=1.01624, theta=-29.209206 -> V=1.0, theta=0.0
% INFO    : Bus 5058	: V=1.018173, theta=-32.163346 -> V=1.0, theta=0.0
% INFO    : Bus 5059	: V=1.031064, theta=-30.99284 -> V=1.0, theta=0.0
% INFO    : Bus 5060	: V=1.06427, theta=-41.076251 -> V=1.0, theta=0.0
% INFO    : Bus 5061	: V=1.051369, theta=9.332018 -> V=1.0, theta=0.0
% INFO    : Bus 5062	: V=1.059351, theta=-25.889195 -> V=1.0, theta=0.0
% INFO    : Bus 5063	: V=0.967209, theta=-32.44223 -> V=1.0, theta=0.0
% INFO    : Bus 5064	: V=1.005521, theta=-36.907508 -> V=1.0, theta=0.0
% INFO    : Bus 5065	: V=1.06654, theta=28.353276 -> V=1.0, theta=0.0
% INFO    : Bus 5066	: V=0.915156, theta=-35.96451 -> V=1.0, theta=0.0
% INFO    : Bus 5067	: V=1.016664, theta=-8.184508 -> V=1.0, theta=0.0
% INFO    : Bus 5068	: V=0.99844, theta=-26.718859 -> V=1.0, theta=0.0
% INFO    : Bus 5069	: V=1.039073, theta=-32.600601 -> V=1.0, theta=0.0
% INFO    : Bus 5070	: V=1.005401, theta=-36.46178 -> V=1.0, theta=0.0
% INFO    : Bus 5071	: V=1.007605, theta=-13.940011 -> V=1.0, theta=0.0
% INFO    : Bus 5072	: V=1.085787, theta=-36.678116 -> V=1.0, theta=0.0
% INFO    : Bus 5073	: V=1.005567, theta=-6.023147 -> V=1.0, theta=0.0
% INFO    : Bus 5074	: V=0.930518, theta=-32.610216 -> V=1.0, theta=0.0
% INFO    : Bus 5075	: V=1.027964, theta=-8.633841 -> V=1.0, theta=0.0
% INFO    : Bus 5076	: V=0.970692, theta=-29.74789 -> V=1.0, theta=0.0
% INFO    : Bus 5077	: V=1.047713, theta=-27.005552 -> V=1.0, theta=0.0
% INFO    : Bus 5078	: V=1.026431, theta=-32.887984 -> V=1.0, theta=0.0
% INFO    : Bus 5079	: V=1.007664, theta=8.988419 -> V=1.0, theta=0.0
% INFO    : Bus 5080	: V=1.022004, theta=-32.45595 -> V=1.0, theta=0.0
% INFO    : Bus 5081	: V=0.948504, theta=-22.572543 -> V=1.0, theta=0.0
% INFO    : Bus 5082	: V=1.032319, theta=-26.126865 -> V=1.0, theta=0.0
% INFO    : Bus 5083	: V=1.033581, theta=-12.500536 -> V=1.0, theta=0.0
% INFO    : Bus 5084	: V=1.019024, theta=-16.104265 -> V=1.0, theta=0.0
% INFO    : Bus 5085	: V=1.022169, theta=-39.246409 -> V=1.0, theta=0.0
% INFO    : Bus 5086	: V=1.046587, theta=-17.262933 -> V=1.0, theta=0.0
% INFO    : Bus 5087	: V=1.053842, theta=-14.978871 -> V=1.0, theta=0.0
% INFO    : Bus 5088	: V=1.035486, theta=-22.562506 -> V=1.0, theta=0.0
% INFO    : Bus 5089	: V=0.996716, theta=-35.041034 -> V=1.0, theta=0.0
% INFO    : Bus 5090	: V=1.026047, theta=2.440706 -> V=1.0, theta=0.0
% INFO    : Bus 5091	: V=1.051243, theta=-39.461817 -> V=1.0, theta=0.0
% INFO    : Bus 5092	: V=1.061075, theta=-9.584041 -> V=1.0, theta=0.0
% INFO    : Bus 5093	: V=1.004057, theta=-15.185299 -> V=1.0, theta=0.0
% INFO    : Bus 5094	: V=1.026644, theta=-34.880598 -> V=1.0, theta=0.0
% INFO    : Bus 5095	: V=0.982011, theta=-28.162982 -> V=1.0, theta=0.0
% INFO    : Bus 5096	: V=1.043485, theta=-39.194179 -> V=1.0, theta=0.0
% INFO    : Bus 5097	: V=1.052774, theta=-9.767291 -> V=1.0, theta=0.0
% INFO    : Bus 5098	: V=1.006462, theta=8.730842 -> V=1.0, theta=0.0
% INFO    : Bus 5099	: V=1.057548, theta=1.412506 -> V=1.0, theta=0.0
% INFO    : Bus 5100	: V=1.040413, theta=-8.41358 -> V=1.0, theta=0.0
% INFO    : Bus 5101	: V=1.000338, theta=65.472066 -> V=1.0, theta=0.0
% INFO    : Bus 5102	: V=1.043535, theta=33.165934 -> V=1.0, theta=0.0
% INFO    : Bus 5103	: V=1.000647, theta=-15.004443 -> V=1.0, theta=0.0
% INFO    : Bus 5104	: V=1.038383, theta=-20.744706 -> V=1.0, theta=0.0
% INFO    : Bus 5105	: V=1.013039, theta=-7.922909 -> V=1.0, theta=0.0
% INFO    : Bus 5106	: V=1.069889, theta=-31.663003 -> V=1.0, theta=0.0
% INFO    : Bus 5107	: V=1.046562, theta=-18.547393 -> V=1.0, theta=0.0
% INFO    : Bus 5108	: V=1.037984, theta=14.73529 -> V=1.0, theta=0.0
% INFO    : Bus 5109	: V=1.045103, theta=-27.401915 -> V=1.0, theta=0.0
% INFO    : Bus 5110	: V=1.033935, theta=-10.289662 -> V=1.0, theta=0.0
% INFO    : Bus 5111	: V=1.012688, theta=-52.793246 -> V=1.0, theta=0.0
% INFO    : Bus 5112	: V=1.020362, theta=-29.475309 -> V=1.0, theta=0.0
% INFO    : Bus 5113	: V=1.039086, theta=-23.556866 -> V=1.0, theta=0.0
% INFO    : Bus 5114	: V=1.023245, theta=-15.041571 -> V=1.0, theta=0.0
% INFO    : Bus 5115	: V=1.022088, theta=64.205077 -> V=1.0, theta=0.0
% INFO    : Bus 5116	: V=1.035964, theta=7.244022 -> V=1.0, theta=0.0
% INFO    : Bus 5117	: V=1.019223, theta=-47.112917 -> V=1.0, theta=0.0
% INFO    : Bus 5118	: V=1.009127, theta=-7.7018 -> V=1.0, theta=0.0
% INFO    : Bus 5119	: V=1.0364, theta=-24.671527 -> V=1.0, theta=0.0
% INFO    : Bus 5120	: V=1.06465, theta=-24.207883 -> V=1.0, theta=0.0
% INFO    : Bus 5121	: V=1.014598, theta=-44.269584 -> V=1.0, theta=0.0
% INFO    : Bus 5122	: V=0.998421, theta=-26.410038 -> V=1.0, theta=0.0
% INFO    : Bus 5123	: V=1.002649, theta=-31.677218 -> V=1.0, theta=0.0
% INFO    : Bus 5124	: V=1.028994, theta=-31.533375 -> V=1.0, theta=0.0
% INFO    : Bus 5125	: V=1.04785, theta=-37.9788 -> V=1.0, theta=0.0
% INFO    : Bus 5126	: V=0.992635, theta=-27.392721 -> V=1.0, theta=0.0
% INFO    : Bus 5127	: V=1.036246, theta=-30.577267 -> V=1.0, theta=0.0
% INFO    : Bus 5128	: V=1.016749, theta=-10.162057 -> V=1.0, theta=0.0
% INFO    : Bus 5129	: V=1.025499, theta=-25.984106 -> V=1.0, theta=0.0
% INFO    : Bus 5130	: V=1.026774, theta=-33.39654 -> V=1.0, theta=0.0
% INFO    : Bus 5131	: V=1.068914, theta=-26.734404 -> V=1.0, theta=0.0
% INFO    : Bus 5132	: V=0.96521, theta=-29.830591 -> V=1.0, theta=0.0
% INFO    : Bus 5133	: V=1.055766, theta=-27.405972 -> V=1.0, theta=0.0
% INFO    : Bus 5134	: V=1.022715, theta=-8.773783 -> V=1.0, theta=0.0
% INFO    : Bus 5135	: V=0.977188, theta=-26.554615 -> V=1.0, theta=0.0
% INFO    : Bus 5136	: V=1.000985, theta=-36.77408 -> V=1.0, theta=0.0
% INFO    : Bus 5137	: V=1.022383, theta=-16.545048 -> V=1.0, theta=0.0
% INFO    : Bus 5138	: V=1.048344, theta=-25.74707 -> V=1.0, theta=0.0
% INFO    : Bus 5139	: V=1.034744, theta=3.444052 -> V=1.0, theta=0.0
% INFO    : Bus 5140	: V=1.016117, theta=-31.378283 -> V=1.0, theta=0.0
% INFO    : Bus 5141	: V=0.989027, theta=-29.757084 -> V=1.0, theta=0.0
% INFO    : Bus 5142	: V=1.033675, theta=55.712656 -> V=1.0, theta=0.0
% INFO    : Bus 5143	: V=1.015791, theta=-31.456773 -> V=1.0, theta=0.0
% INFO    : Bus 5144	: V=1.032838, theta=-3.148546 -> V=1.0, theta=0.0
% INFO    : Bus 5145	: V=1.049287, theta=-20.894198 -> V=1.0, theta=0.0
% INFO    : Bus 5146	: V=1.006633, theta=-34.449474 -> V=1.0, theta=0.0
% INFO    : Bus 5147	: V=1.023848, theta=3.383433 -> V=1.0, theta=0.0
% INFO    : Bus 5148	: V=1.023799, theta=-8.049269 -> V=1.0, theta=0.0
% INFO    : Bus 5149	: V=0.989063, theta=12.894504 -> V=1.0, theta=0.0
% INFO    : Bus 5150	: V=0.994149, theta=-30.584157 -> V=1.0, theta=0.0
% INFO    : Bus 5151	: V=1.040193, theta=-33.295872 -> V=1.0, theta=0.0
% INFO    : Bus 5152	: V=1.033193, theta=24.896513 -> V=1.0, theta=0.0
% INFO    : Bus 5153	: V=0.950584, theta=-35.141712 -> V=1.0, theta=0.0
% INFO    : Bus 5154	: V=1.021968, theta=67.005317 -> V=1.0, theta=0.0
% INFO    : Bus 5155	: V=1.025638, theta=-11.295879 -> V=1.0, theta=0.0
% INFO    : Bus 5156	: V=1.012996, theta=-27.195344 -> V=1.0, theta=0.0
% INFO    : Bus 5157	: V=1.01048, theta=-24.157713 -> V=1.0, theta=0.0
% INFO    : Bus 5158	: V=1.043194, theta=10.693138 -> V=1.0, theta=0.0
% INFO    : Bus 5159	: V=1.03892, theta=-8.307439 -> V=1.0, theta=0.0
% INFO    : Bus 5160	: V=1.041089, theta=-12.912267 -> V=1.0, theta=0.0
% INFO    : Bus 5161	: V=1.019958, theta=-36.560167 -> V=1.0, theta=0.0
% INFO    : Bus 5162	: V=1.009888, theta=-48.531709 -> V=1.0, theta=0.0
% INFO    : Bus 5163	: V=1.034355, theta=-39.091202 -> V=1.0, theta=0.0
% INFO    : Bus 5164	: V=1.083362, theta=36.17773 -> V=1.0, theta=0.0
% INFO    : Bus 5165	: V=1.024106, theta=7.542973 -> V=1.0, theta=0.0
% INFO    : Bus 5166	: V=0.935772, theta=-34.646986 -> V=1.0, theta=0.0
% INFO    : Bus 5167	: V=1.027953, theta=50.072739 -> V=1.0, theta=0.0
% INFO    : Bus 5168	: V=0.999285, theta=-35.774577 -> V=1.0, theta=0.0
% INFO    : Bus 5169	: V=1.070559, theta=12.625799 -> V=1.0, theta=0.0
% INFO    : Bus 5170	: V=1.026589, theta=-53.761687 -> V=1.0, theta=0.0
% INFO    : Bus 5171	: V=1.011094, theta=-47.540213 -> V=1.0, theta=0.0
% INFO    : Bus 5172	: V=1.0704, theta=-22.127149 -> V=1.0, theta=0.0
% INFO    : Bus 5173	: V=1.033809, theta=-34.0408 -> V=1.0, theta=0.0
% INFO    : Bus 5174	: V=1.041954, theta=-21.336015 -> V=1.0, theta=0.0
% INFO    : Bus 5175	: V=1.031881, theta=-15.733969 -> V=1.0, theta=0.0
% INFO    : Bus 5176	: V=1.021206, theta=-28.411576 -> V=1.0, theta=0.0
% INFO    : Bus 5177	: V=1.042099, theta=-18.696816 -> V=1.0, theta=0.0
% INFO    : Bus 5178	: V=1.04332, theta=35.587159 -> V=1.0, theta=0.0
% INFO    : Bus 5179	: V=1.032567, theta=-31.167837 -> V=1.0, theta=0.0
% INFO    : Bus 5180	: V=1.010906, theta=5.415517 -> V=1.0, theta=0.0
% INFO    : Bus 5181	: V=1.006184, theta=-36.954734 -> V=1.0, theta=0.0
% INFO    : Bus 5182	: V=1.041325, theta=-8.044042 -> V=1.0, theta=0.0
% INFO    : Bus 5183	: V=1.025241, theta=-25.129178 -> V=1.0, theta=0.0
% INFO    : Bus 5184	: V=1.020455, theta=-5.269919 -> V=1.0, theta=0.0
% INFO    : Bus 5185	: V=1.046406, theta=-15.155092 -> V=1.0, theta=0.0
% INFO    : Bus 5186	: V=0.992915, theta=-27.541743 -> V=1.0, theta=0.0
% INFO    : Bus 5187	: V=1.007766, theta=-5.873752 -> V=1.0, theta=0.0
% INFO    : Bus 5188	: V=1.018558, theta=0.328446 -> V=1.0, theta=0.0
% INFO    : Bus 5189	: V=1.020802, theta=-47.248139 -> V=1.0, theta=0.0
% INFO    : Bus 5190	: V=1.040185, theta=-30.045821 -> V=1.0, theta=0.0
% INFO    : Bus 5191	: V=1.029465, theta=-50.177641 -> V=1.0, theta=0.0
% INFO    : Bus 5192	: V=1.039762, theta=-15.033657 -> V=1.0, theta=0.0
% INFO    : Bus 5193	: V=1.022466, theta=-14.154389 -> V=1.0, theta=0.0
% INFO    : Bus 5194	: V=1.074026, theta=36.916958 -> V=1.0, theta=0.0
% INFO    : Bus 5195	: V=0.984634, theta=-35.249395 -> V=1.0, theta=0.0
% INFO    : Bus 5196	: V=1.045019, theta=-30.553817 -> V=1.0, theta=0.0
% INFO    : Bus 5197	: V=1.055397, theta=-22.593679 -> V=1.0, theta=0.0
% INFO    : Bus 5198	: V=1.040031, theta=-20.975515 -> V=1.0, theta=0.0
% INFO    : Bus 5199	: V=1.003128, theta=-23.967089 -> V=1.0, theta=0.0
% INFO    : Bus 5200	: V=1.024102, theta=-23.05819 -> V=1.0, theta=0.0
% INFO    : Bus 5201	: V=1.061466, theta=-26.766863 -> V=1.0, theta=0.0
% INFO    : Bus 5202	: V=1.02566, theta=-53.811747 -> V=1.0, theta=0.0
% INFO    : Bus 5203	: V=1.02662, theta=5.169172 -> V=1.0, theta=0.0
% INFO    : Bus 5204	: V=1.011682, theta=-5.893879 -> V=1.0, theta=0.0
% INFO    : Bus 5205	: V=1.018645, theta=-46.209653 -> V=1.0, theta=0.0
% INFO    : Bus 5206	: V=1.019532, theta=-19.41052 -> V=1.0, theta=0.0
% INFO    : Bus 5207	: V=1.002522, theta=-39.681438 -> V=1.0, theta=0.0
% INFO    : Bus 5208	: V=0.98578, theta=-31.882609 -> V=1.0, theta=0.0
% INFO    : Bus 5209	: V=1.033176, theta=1.355573 -> V=1.0, theta=0.0
% INFO    : Bus 5210	: V=0.999109, theta=-0.359974 -> V=1.0, theta=0.0
% INFO    : Bus 5211	: V=1.039999, theta=-21.26053 -> V=1.0, theta=0.0
% INFO    : Bus 5212	: V=1.038537, theta=-11.276713 -> V=1.0, theta=0.0
% INFO    : Bus 5213	: V=1.042076, theta=-26.712515 -> V=1.0, theta=0.0
% INFO    : Bus 5214	: V=1.035293, theta=-3.021305 -> V=1.0, theta=0.0
% INFO    : Bus 5215	: V=1.025196, theta=-6.168163 -> V=1.0, theta=0.0
% INFO    : Bus 5216	: V=1.032101, theta=-26.069945 -> V=1.0, theta=0.0
% INFO    : Bus 5217	: V=1.010242, theta=-48.583008 -> V=1.0, theta=0.0
% INFO    : Bus 5218	: V=1.009924, theta=-30.100704 -> V=1.0, theta=0.0
% INFO    : Bus 5219	: V=1.024872, theta=-25.973264 -> V=1.0, theta=0.0
% INFO    : Bus 5220	: V=1.011786, theta=4.483442 -> V=1.0, theta=0.0
% INFO    : Bus 5221	: V=0.967916, theta=-28.697244 -> V=1.0, theta=0.0
% INFO    : Bus 5222	: V=1.022327, theta=-7.463931 -> V=1.0, theta=0.0
% INFO    : Bus 5223	: V=1.045671, theta=-20.30397 -> V=1.0, theta=0.0
% INFO    : Bus 5224	: V=0.948815, theta=-33.811513 -> V=1.0, theta=0.0
% INFO    : Bus 5225	: V=1.050345, theta=-16.499112 -> V=1.0, theta=0.0
% INFO    : Bus 5226	: V=0.992484, theta=-19.76807 -> V=1.0, theta=0.0
% INFO    : Bus 5227	: V=0.971517, theta=-24.768318 -> V=1.0, theta=0.0
% INFO    : Bus 5228	: V=1.034342, theta=-5.624977 -> V=1.0, theta=0.0
% INFO    : Bus 5229	: V=1.020723, theta=-36.503257 -> V=1.0, theta=0.0
% INFO    : Bus 5230	: V=1.038229, theta=-23.891029 -> V=1.0, theta=0.0
% INFO    : Bus 5231	: V=1.026163, theta=-25.303176 -> V=1.0, theta=0.0
% INFO    : Bus 5232	: V=1.004065, theta=8.888477 -> V=1.0, theta=0.0
% INFO    : Bus 5233	: V=1.036537, theta=-11.313155 -> V=1.0, theta=0.0
% INFO    : Bus 5234	: V=1.049607, theta=30.137973 -> V=1.0, theta=0.0
% INFO    : Bus 5235	: V=1.020203, theta=-37.140827 -> V=1.0, theta=0.0
% INFO    : Bus 5236	: V=1.047863, theta=-15.699293 -> V=1.0, theta=0.0
% INFO    : Bus 5237	: V=1.0542, theta=-14.77106 -> V=1.0, theta=0.0
% INFO    : Bus 5238	: V=1.005045, theta=-30.746404 -> V=1.0, theta=0.0
% INFO    : Bus 5239	: V=0.990479, theta=-47.567504 -> V=1.0, theta=0.0
% INFO    : Bus 5240	: V=1.046727, theta=2.053615 -> V=1.0, theta=0.0
% INFO    : Bus 5241	: V=1.022883, theta=-3.838129 -> V=1.0, theta=0.0
% INFO    : Bus 5242	: V=1.055573, theta=-23.781828 -> V=1.0, theta=0.0
% INFO    : Bus 5243	: V=1.009551, theta=6.826901 -> V=1.0, theta=0.0
% INFO    : Bus 5244	: V=1.0215, theta=-6.514417 -> V=1.0, theta=0.0
% INFO    : Bus 5245	: V=0.970823, theta=-24.11316 -> V=1.0, theta=0.0
% INFO    : Bus 5246	: V=1.031531, theta=12.035142 -> V=1.0, theta=0.0
% INFO    : Bus 5247	: V=1.017084, theta=-0.826915 -> V=1.0, theta=0.0
% INFO    : Bus 5248	: V=1.045953, theta=-29.59783 -> V=1.0, theta=0.0
% INFO    : Bus 5249	: V=0.976058, theta=-29.616818 -> V=1.0, theta=0.0
% INFO    : Bus 5250	: V=0.991606, theta=-34.386656 -> V=1.0, theta=0.0
% INFO    : Bus 5251	: V=1.038759, theta=-22.367388 -> V=1.0, theta=0.0
% INFO    : Bus 5252	: V=0.997303, theta=-20.520889 -> V=1.0, theta=0.0
% INFO    : Bus 5253	: V=1.019086, theta=-43.205705 -> V=1.0, theta=0.0
% INFO    : Bus 5254	: V=1.006283, theta=-27.062298 -> V=1.0, theta=0.0
% INFO    : Bus 5255	: V=1.033206, theta=8.744605 -> V=1.0, theta=0.0
% INFO    : Bus 5256	: V=0.998096, theta=-17.006205 -> V=1.0, theta=0.0
% INFO    : Bus 5257	: V=1.046449, theta=-6.348504 -> V=1.0, theta=0.0
% INFO    : Bus 5258	: V=1.06951, theta=26.086158 -> V=1.0, theta=0.0
% INFO    : Bus 5259	: V=1.022475, theta=-15.124227 -> V=1.0, theta=0.0
% INFO    : Bus 5260	: V=1.027358, theta=15.769371 -> V=1.0, theta=0.0
% INFO    : Bus 5261	: V=1.0425, theta=7.235152 -> V=1.0, theta=0.0
% INFO    : Bus 5262	: V=1.059967, theta=-12.124644 -> V=1.0, theta=0.0
% INFO    : Bus 5263	: V=1.051592, theta=-45.10801 -> V=1.0, theta=0.0
% INFO    : Bus 5264	: V=1.034663, theta=13.971282 -> V=1.0, theta=0.0
% INFO    : Bus 5265	: V=0.968795, theta=-30.437259 -> V=1.0, theta=0.0
% INFO    : Bus 5266	: V=1.026639, theta=-34.881289 -> V=1.0, theta=0.0
% INFO    : Bus 5267	: V=1.016558, theta=-30.283741 -> V=1.0, theta=0.0
% INFO    : Bus 5268	: V=1.012986, theta=-32.963293 -> V=1.0, theta=0.0
% INFO    : Bus 5269	: V=0.997627, theta=-30.728085 -> V=1.0, theta=0.0
% INFO    : Bus 5270	: V=1.035997, theta=-21.458109 -> V=1.0, theta=0.0
% INFO    : Bus 5271	: V=1.019244, theta=8.389274 -> V=1.0, theta=0.0
% INFO    : Bus 5272	: V=1.031303, theta=33.539401 -> V=1.0, theta=0.0
% INFO    : Bus 5273	: V=1.026805, theta=64.035538 -> V=1.0, theta=0.0
% INFO    : Bus 5274	: V=0.991018, theta=-47.662261 -> V=1.0, theta=0.0
% INFO    : Bus 5275	: V=1.064437, theta=-19.94623 -> V=1.0, theta=0.0
% INFO    : Bus 5276	: V=1.015292, theta=-44.635585 -> V=1.0, theta=0.0
% INFO    : Bus 5277	: V=1.040114, theta=8.289062 -> V=1.0, theta=0.0
% INFO    : Bus 5278	: V=1.03962, theta=-24.585875 -> V=1.0, theta=0.0
% INFO    : Bus 5279	: V=1.014488, theta=16.403747 -> V=1.0, theta=0.0
% INFO    : Bus 5280	: V=1.018895, theta=-41.9271 -> V=1.0, theta=0.0
% INFO    : Bus 5281	: V=1.01376, theta=-26.588907 -> V=1.0, theta=0.0
% INFO    : Bus 5282	: V=1.022227, theta=-25.047372 -> V=1.0, theta=0.0
% INFO    : Bus 5283	: V=0.995772, theta=-24.245834 -> V=1.0, theta=0.0
% INFO    : Bus 5284	: V=1.019426, theta=-20.552231 -> V=1.0, theta=0.0
% INFO    : Bus 5285	: V=1.057359, theta=-28.685756 -> V=1.0, theta=0.0
% INFO    : Bus 5286	: V=1.032855, theta=-22.511244 -> V=1.0, theta=0.0
% INFO    : Bus 5287	: V=1.036152, theta=1.812718 -> V=1.0, theta=0.0
% INFO    : Bus 5288	: V=0.995768, theta=-15.366713 -> V=1.0, theta=0.0
% INFO    : Bus 5289	: V=1.067874, theta=-38.358205 -> V=1.0, theta=0.0
% INFO    : Bus 5290	: V=1.009333, theta=-36.158828 -> V=1.0, theta=0.0
% INFO    : Bus 5291	: V=1.026323, theta=-15.478612 -> V=1.0, theta=0.0
% INFO    : Bus 5292	: V=1.011478, theta=-48.444663 -> V=1.0, theta=0.0
% INFO    : Bus 5293	: V=1.008689, theta=-5.494677 -> V=1.0, theta=0.0
% INFO    : Bus 5294	: V=1.015317, theta=1.679636 -> V=1.0, theta=0.0
% INFO    : Bus 5295	: V=1.028907, theta=20.742927 -> V=1.0, theta=0.0
% INFO    : Bus 5296	: V=1.011237, theta=18.573824 -> V=1.0, theta=0.0
% INFO    : Bus 5297	: V=1.038998, theta=-24.689993 -> V=1.0, theta=0.0
% INFO    : Bus 5298	: V=1.075555, theta=-26.412788 -> V=1.0, theta=0.0
% INFO    : Bus 5299	: V=1.045101, theta=33.747987 -> V=1.0, theta=0.0
% INFO    : Bus 5300	: V=1.039522, theta=-11.286385 -> V=1.0, theta=0.0
% INFO    : Bus 5301	: V=1.034956, theta=49.088982 -> V=1.0, theta=0.0
% INFO    : Bus 5302	: V=1.029755, theta=-35.443964 -> V=1.0, theta=0.0
% INFO    : Bus 5303	: V=0.994526, theta=-50.407214 -> V=1.0, theta=0.0
% INFO    : Bus 5304	: V=1.040268, theta=-30.537588 -> V=1.0, theta=0.0
% INFO    : Bus 5305	: V=1.029341, theta=-5.808129 -> V=1.0, theta=0.0
% INFO    : Bus 5306	: V=0.999778, theta=-27.933194 -> V=1.0, theta=0.0
% INFO    : Bus 5307	: V=0.998324, theta=-28.72802 -> V=1.0, theta=0.0
% INFO    : Bus 5308	: V=0.980119, theta=-18.492863 -> V=1.0, theta=0.0
% INFO    : Bus 5309	: V=1.042975, theta=-17.817254 -> V=1.0, theta=0.0
% INFO    : Bus 5310	: V=1.040939, theta=-2.439408 -> V=1.0, theta=0.0
% INFO    : Bus 5311	: V=1.043286, theta=15.805059 -> V=1.0, theta=0.0
% INFO    : Bus 5312	: V=1.029474, theta=-31.041682 -> V=1.0, theta=0.0
% INFO    : Bus 5313	: V=1.002792, theta=-21.384316 -> V=1.0, theta=0.0
% INFO    : Bus 5314	: V=1.081616, theta=-27.637386 -> V=1.0, theta=0.0
% INFO    : Bus 5315	: V=1.020828, theta=16.809684 -> V=1.0, theta=0.0
% INFO    : Bus 5316	: V=1.071573, theta=38.707798 -> V=1.0, theta=0.0
% INFO    : Bus 5317	: V=1.019252, theta=-44.845345 -> V=1.0, theta=0.0
% INFO    : Bus 5318	: V=0.968294, theta=-32.433569 -> V=1.0, theta=0.0
% INFO    : Bus 5319	: V=1.037618, theta=-26.094347 -> V=1.0, theta=0.0
% INFO    : Bus 5320	: V=1.030478, theta=3.320751 -> V=1.0, theta=0.0
% INFO    : Bus 5321	: V=1.020916, theta=-7.445394 -> V=1.0, theta=0.0
% INFO    : Bus 5322	: V=0.948009, theta=-19.391946 -> V=1.0, theta=0.0
% INFO    : Bus 5323	: V=1.031211, theta=47.015813 -> V=1.0, theta=0.0
% INFO    : Bus 5324	: V=1.026268, theta=-4.598739 -> V=1.0, theta=0.0
% INFO    : Bus 5325	: V=1.031465, theta=-21.73042 -> V=1.0, theta=0.0
% INFO    : Bus 5326	: V=1.068222, theta=-27.526345 -> V=1.0, theta=0.0
% INFO    : Bus 5327	: V=1.086214, theta=-24.82175 -> V=1.0, theta=0.0
% INFO    : Bus 5328	: V=1.02561, theta=-41.417935 -> V=1.0, theta=0.0
% INFO    : Bus 5329	: V=1.015053, theta=-43.535832 -> V=1.0, theta=0.0
% INFO    : Bus 5330	: V=1.015595, theta=-28.749261 -> V=1.0, theta=0.0
% INFO    : Bus 5331	: V=0.997637, theta=-36.411037 -> V=1.0, theta=0.0
% INFO    : Bus 5332	: V=1.015602, theta=-51.421675 -> V=1.0, theta=0.0
% INFO    : Bus 5333	: V=0.998616, theta=-47.446935 -> V=1.0, theta=0.0
% INFO    : Bus 5334	: V=1.028446, theta=-13.059233 -> V=1.0, theta=0.0
% INFO    : Bus 5335	: V=0.982132, theta=-28.928227 -> V=1.0, theta=0.0
% INFO    : Bus 5336	: V=1.014454, theta=-15.830309 -> V=1.0, theta=0.0
% INFO    : Bus 5337	: V=1.017114, theta=-28.690154 -> V=1.0, theta=0.0
% INFO    : Bus 5338	: V=1.025419, theta=11.439032 -> V=1.0, theta=0.0
% INFO    : Bus 5339	: V=0.996653, theta=-32.801882 -> V=1.0, theta=0.0
% INFO    : Bus 5340	: V=1.044898, theta=-11.45967 -> V=1.0, theta=0.0
% INFO    : Bus 5341	: V=1.005913, theta=-22.013831 -> V=1.0, theta=0.0
% INFO    : Bus 5342	: V=1.028756, theta=-1.361457 -> V=1.0, theta=0.0
% INFO    : Bus 5343	: V=1.070746, theta=-6.106433 -> V=1.0, theta=0.0
% INFO    : Bus 5344	: V=0.987054, theta=-31.911414 -> V=1.0, theta=0.0
% INFO    : Bus 5345	: V=0.999728, theta=-26.068443 -> V=1.0, theta=0.0
% INFO    : Bus 5346	: V=1.038003, theta=27.563022 -> V=1.0, theta=0.0
% INFO    : Bus 5347	: V=0.974897, theta=-31.802144 -> V=1.0, theta=0.0
% INFO    : Bus 5348	: V=1.013341, theta=-43.142787 -> V=1.0, theta=0.0
% INFO    : Bus 5349	: V=1.039682, theta=10.492143 -> V=1.0, theta=0.0
% INFO    : Bus 5350	: V=0.967222, theta=-24.900034 -> V=1.0, theta=0.0
% INFO    : Bus 5351	: V=1.042756, theta=-13.916064 -> V=1.0, theta=0.0
% INFO    : Bus 5352	: V=1.022029, theta=8.423604 -> V=1.0, theta=0.0
% INFO    : Bus 5353	: V=1.054254, theta=-27.918373 -> V=1.0, theta=0.0
% INFO    : Bus 5354	: V=1.041191, theta=-8.880271 -> V=1.0, theta=0.0
% INFO    : Bus 5355	: V=1.030605, theta=-38.511768 -> V=1.0, theta=0.0
% INFO    : Bus 5356	: V=1.039815, theta=1.985184 -> V=1.0, theta=0.0
% INFO    : Bus 5357	: V=1.010431, theta=-30.336741 -> V=1.0, theta=0.0
% INFO    : Bus 5358	: V=0.942834, theta=-32.683782 -> V=1.0, theta=0.0
% INFO    : Bus 5359	: V=0.903388, theta=-35.988527 -> V=1.0, theta=0.0
% INFO    : Bus 5360	: V=1.012933, theta=-15.056043 -> V=1.0, theta=0.0
% INFO    : Bus 5361	: V=0.968713, theta=-43.493259 -> V=1.0, theta=0.0
% INFO    : Bus 5362	: V=1.03922, theta=-24.598476 -> V=1.0, theta=0.0
% INFO    : Bus 5363	: V=1.006246, theta=-31.812632 -> V=1.0, theta=0.0
% INFO    : Bus 5364	: V=1.026444, theta=-2.016826 -> V=1.0, theta=0.0
% INFO    : Bus 5365	: V=1.065324, theta=-11.846174 -> V=1.0, theta=0.0
% INFO    : Bus 5366	: V=1.020717, theta=-47.279801 -> V=1.0, theta=0.0
% INFO    : Bus 5367	: V=1.014817, theta=-5.921008 -> V=1.0, theta=0.0
% INFO    : Bus 5368	: V=1.058977, theta=-0.563499 -> V=1.0, theta=0.0
% INFO    : Bus 5369	: V=1.037177, theta=5.654189 -> V=1.0, theta=0.0
% INFO    : Bus 5370	: V=0.995273, theta=-14.1203 -> V=1.0, theta=0.0
% INFO    : Bus 5371	: V=1.060178, theta=-30.916528 -> V=1.0, theta=0.0
% INFO    : Bus 5372	: V=1.059752, theta=-41.178352 -> V=1.0, theta=0.0
% INFO    : Bus 5373	: V=0.956585, theta=-31.461459 -> V=1.0, theta=0.0
% INFO    : Bus 5374	: V=1.013322, theta=61.623338 -> V=1.0, theta=0.0
% INFO    : Bus 5375	: V=1.008396, theta=2.085281 -> V=1.0, theta=0.0
% INFO    : Bus 5376	: V=1.025658, theta=-37.244067 -> V=1.0, theta=0.0
% INFO    : Bus 5377	: V=1.033071, theta=65.032272 -> V=1.0, theta=0.0
% INFO    : Bus 5378	: V=0.998714, theta=-44.729132 -> V=1.0, theta=0.0
% INFO    : Bus 5379	: V=1.10493, theta=-7.012792 -> V=1.0, theta=0.0
% INFO    : Bus 5380	: V=1.018969, theta=3.256671 -> V=1.0, theta=0.0
% INFO    : Bus 5381	: V=1.013102, theta=-33.068927 -> V=1.0, theta=0.0
% INFO    : Bus 5382	: V=0.986578, theta=-31.221938 -> V=1.0, theta=0.0
% INFO    : Bus 5383	: V=1.044201, theta=-24.790628 -> V=1.0, theta=0.0
% INFO    : Bus 5384	: V=1.004283, theta=-32.089465 -> V=1.0, theta=0.0
% INFO    : Bus 5385	: V=1.040121, theta=-21.319331 -> V=1.0, theta=0.0
% INFO    : Bus 5386	: V=1.019636, theta=-7.825709 -> V=1.0, theta=0.0
% INFO    : Bus 5387	: V=1.059001, theta=10.223443 -> V=1.0, theta=0.0
% INFO    : Bus 5388	: V=1.006693, theta=-15.086388 -> V=1.0, theta=0.0
% INFO    : Bus 5389	: V=0.995955, theta=-16.116371 -> V=1.0, theta=0.0
% INFO    : Bus 5390	: V=1.03767, theta=-3.28139 -> V=1.0, theta=0.0
% INFO    : Bus 5391	: V=1.020385, theta=-48.75014 -> V=1.0, theta=0.0
% INFO    : Bus 5392	: V=0.963665, theta=-27.354454 -> V=1.0, theta=0.0
% INFO    : Bus 5393	: V=1.053922, theta=-15.971462 -> V=1.0, theta=0.0
% INFO    : Bus 5394	: V=1.027555, theta=2.293855 -> V=1.0, theta=0.0
% INFO    : Bus 5395	: V=1.05041, theta=-27.819641 -> V=1.0, theta=0.0
% INFO    : Bus 5396	: V=0.994262, theta=-24.110122 -> V=1.0, theta=0.0
% INFO    : Bus 5397	: V=1.016845, theta=-29.585014 -> V=1.0, theta=0.0
% INFO    : Bus 5398	: V=1.041434, theta=-41.871134 -> V=1.0, theta=0.0
% INFO    : Bus 5399	: V=1.025297, theta=18.608931 -> V=1.0, theta=0.0
% INFO    : Bus 5400	: V=1.022935, theta=-14.201511 -> V=1.0, theta=0.0
% INFO    : Bus 5401	: V=1.056816, theta=52.771969 -> V=1.0, theta=0.0
% INFO    : Bus 5402	: V=0.99228, theta=-31.5665 -> V=1.0, theta=0.0
% INFO    : Bus 5403	: V=1.032334, theta=13.97906 -> V=1.0, theta=0.0
% INFO    : Bus 5404	: V=1.037044, theta=-31.762642 -> V=1.0, theta=0.0
% INFO    : Bus 5405	: V=1.023046, theta=-30.120615 -> V=1.0, theta=0.0
% INFO    : Bus 5406	: V=1.105578, theta=-24.714218 -> V=1.0, theta=0.0
% INFO    : Bus 5407	: V=0.985403, theta=-26.680829 -> V=1.0, theta=0.0
% INFO    : Bus 5408	: V=1.025733, theta=-26.104482 -> V=1.0, theta=0.0
% INFO    : Bus 5409	: V=1.021468, theta=-39.327661 -> V=1.0, theta=0.0
% INFO    : Bus 5410	: V=1.042284, theta=-21.670669 -> V=1.0, theta=0.0
% INFO    : Bus 5411	: V=1.02277, theta=-5.585233 -> V=1.0, theta=0.0
% INFO    : Bus 5412	: V=1.07527, theta=8.89403 -> V=1.0, theta=0.0
% INFO    : Bus 5413	: V=1.032887, theta=-18.313717 -> V=1.0, theta=0.0
% INFO    : Bus 5414	: V=1.036655, theta=-33.030803 -> V=1.0, theta=0.0
% INFO    : Bus 5415	: V=1.008861, theta=-7.879657 -> V=1.0, theta=0.0
% INFO    : Bus 5416	: V=1.003937, theta=11.803413 -> V=1.0, theta=0.0
% INFO    : Bus 5417	: V=1.061368, theta=-12.472756 -> V=1.0, theta=0.0
% INFO    : Bus 5418	: V=1.03456, theta=-21.58226 -> V=1.0, theta=0.0
% INFO    : Bus 5419	: V=1.024125, theta=-15.192507 -> V=1.0, theta=0.0
% INFO    : Bus 5420	: V=1.017861, theta=-23.368601 -> V=1.0, theta=0.0
% INFO    : Bus 5421	: V=0.995766, theta=-15.366638 -> V=1.0, theta=0.0
% INFO    : Bus 5422	: V=1.026675, theta=-6.579714 -> V=1.0, theta=0.0
% INFO    : Bus 5423	: V=1.005727, theta=5.973185 -> V=1.0, theta=0.0
% INFO    : Bus 5424	: V=1.082032, theta=-24.688907 -> V=1.0, theta=0.0
% INFO    : Bus 5425	: V=1.074405, theta=-36.140712 -> V=1.0, theta=0.0
% INFO    : Bus 5426	: V=1.023076, theta=2.523931 -> V=1.0, theta=0.0
% INFO    : Bus 5427	: V=1.01296, theta=-22.278965 -> V=1.0, theta=0.0
% INFO    : Bus 5428	: V=1.028043, theta=26.098856 -> V=1.0, theta=0.0
% INFO    : Bus 5429	: V=1.043614, theta=10.777174 -> V=1.0, theta=0.0
% INFO    : Bus 5430	: V=1.026594, theta=4.059264 -> V=1.0, theta=0.0
% INFO    : Bus 5431	: V=1.015774, theta=-14.1263 -> V=1.0, theta=0.0
% INFO    : Bus 5432	: V=1.021874, theta=7.21054 -> V=1.0, theta=0.0
% INFO    : Bus 5433	: V=0.991152, theta=5.727907 -> V=1.0, theta=0.0
% INFO    : Bus 5434	: V=1.007927, theta=-10.759175 -> V=1.0, theta=0.0
% INFO    : Bus 5435	: V=1.009014, theta=-47.601522 -> V=1.0, theta=0.0
% INFO    : Bus 5436	: V=1.000228, theta=-24.534422 -> V=1.0, theta=0.0
% INFO    : Bus 5437	: V=1.035669, theta=-15.838076 -> V=1.0, theta=0.0
% INFO    : Bus 5438	: V=1.050658, theta=-19.170239 -> V=1.0, theta=0.0
% INFO    : Bus 5439	: V=1.038274, theta=38.762763 -> V=1.0, theta=0.0
% INFO    : Bus 5440	: V=1.049377, theta=-10.587189 -> V=1.0, theta=0.0
% INFO    : Bus 5441	: V=1.033391, theta=-3.238779 -> V=1.0, theta=0.0
% INFO    : Bus 5442	: V=1.014377, theta=16.388914 -> V=1.0, theta=0.0
% INFO    : Bus 5443	: V=1.019611, theta=-28.986553 -> V=1.0, theta=0.0
% INFO    : Bus 5444	: V=1.059208, theta=10.233319 -> V=1.0, theta=0.0
% INFO    : Bus 5445	: V=1.02477, theta=-25.099863 -> V=1.0, theta=0.0
% INFO    : Bus 5446	: V=0.960277, theta=-31.774093 -> V=1.0, theta=0.0
% INFO    : Bus 5447	: V=0.955232, theta=-30.324084 -> V=1.0, theta=0.0
% INFO    : Bus 5448	: V=1.021965, theta=-27.426392 -> V=1.0, theta=0.0
% INFO    : Bus 5449	: V=1.028401, theta=10.789888 -> V=1.0, theta=0.0
% INFO    : Bus 5450	: V=1.058314, theta=0.575404 -> V=1.0, theta=0.0
% INFO    : Bus 5451	: V=1.068356, theta=-48.383117 -> V=1.0, theta=0.0
% INFO    : Bus 5452	: V=0.992868, theta=-48.243558 -> V=1.0, theta=0.0
% INFO    : Bus 5453	: V=1.022873, theta=62.697236 -> V=1.0, theta=0.0
% INFO    : Bus 5454	: V=1.0207, theta=-25.552974 -> V=1.0, theta=0.0
% INFO    : Bus 5455	: V=1.041319, theta=-8.044004 -> V=1.0, theta=0.0
% INFO    : Bus 5456	: V=0.95194, theta=-22.56403 -> V=1.0, theta=0.0
% INFO    : Bus 5457	: V=1.044659, theta=-9.940212 -> V=1.0, theta=0.0
% INFO    : Bus 5458	: V=1.034223, theta=-21.767033 -> V=1.0, theta=0.0
% INFO    : Bus 5459	: V=0.986171, theta=-50.721367 -> V=1.0, theta=0.0
% INFO    : Bus 5460	: V=0.981174, theta=-18.227809 -> V=1.0, theta=0.0
% INFO    : Bus 5461	: V=1.055685, theta=-18.707132 -> V=1.0, theta=0.0
% INFO    : Bus 5462	: V=1.042235, theta=7.92914 -> V=1.0, theta=0.0
% INFO    : Bus 5463	: V=1.020822, theta=-42.641009 -> V=1.0, theta=0.0
% INFO    : Bus 5464	: V=1.046547, theta=-39.052752 -> V=1.0, theta=0.0
% INFO    : Bus 5465	: V=0.997959, theta=-47.341255 -> V=1.0, theta=0.0
% INFO    : Bus 5466	: V=1.037366, theta=-19.083886 -> V=1.0, theta=0.0
% INFO    : Bus 5467	: V=1.002425, theta=-31.412163 -> V=1.0, theta=0.0
% INFO    : Bus 5468	: V=1.027297, theta=-9.338361 -> V=1.0, theta=0.0
% INFO    : Bus 5469	: V=1.068254, theta=-38.443073 -> V=1.0, theta=0.0
% INFO    : Bus 5470	: V=1.041272, theta=-33.026205 -> V=1.0, theta=0.0
% INFO    : Bus 5471	: V=1.026437, theta=-47.947151 -> V=1.0, theta=0.0
% INFO    : Bus 5472	: V=1.026232, theta=-19.774007 -> V=1.0, theta=0.0
% INFO    : Bus 5473	: V=1.050309, theta=30.291614 -> V=1.0, theta=0.0
% INFO    : Bus 5474	: V=0.973291, theta=-27.712296 -> V=1.0, theta=0.0
% INFO    : Bus 5475	: V=1.052475, theta=-24.929716 -> V=1.0, theta=0.0
% INFO    : Bus 5476	: V=1.031757, theta=-46.789773 -> V=1.0, theta=0.0
% INFO    : Bus 5477	: V=1.069678, theta=-26.5629 -> V=1.0, theta=0.0
% INFO    : Bus 5478	: V=0.996923, theta=13.538273 -> V=1.0, theta=0.0
% INFO    : Bus 5479	: V=1.05048, theta=29.622719 -> V=1.0, theta=0.0
% INFO    : Bus 5480	: V=1.043829, theta=-19.748499 -> V=1.0, theta=0.0
% INFO    : Bus 5481	: V=1.05825, theta=-9.184906 -> V=1.0, theta=0.0
% INFO    : Bus 5482	: V=1.042942, theta=-7.385046 -> V=1.0, theta=0.0
% INFO    : Bus 5483	: V=1.005753, theta=-37.426895 -> V=1.0, theta=0.0
% INFO    : Bus 5484	: V=1.084447, theta=-36.839736 -> V=1.0, theta=0.0
% INFO    : Bus 5485	: V=1.032409, theta=-3.136568 -> V=1.0, theta=0.0
% INFO    : Bus 5486	: V=1.055199, theta=4.459301 -> V=1.0, theta=0.0
% INFO    : Bus 5487	: V=1.050272, theta=-17.936662 -> V=1.0, theta=0.0
% INFO    : Bus 5488	: V=1.037007, theta=-30.257494 -> V=1.0, theta=0.0
% INFO    : Bus 5489	: V=0.996826, theta=-17.380713 -> V=1.0, theta=0.0
% INFO    : Bus 5490	: V=1.062487, theta=-15.472573 -> V=1.0, theta=0.0
% INFO    : Bus 5491	: V=1.038788, theta=3.64887 -> V=1.0, theta=0.0
% INFO    : Bus 5492	: V=1.011986, theta=5.623815 -> V=1.0, theta=0.0
% INFO    : Bus 5493	: V=1.008785, theta=-47.094951 -> V=1.0, theta=0.0
% INFO    : Bus 5494	: V=0.99706, theta=-37.536546 -> V=1.0, theta=0.0
% INFO    : Bus 5495	: V=1.067943, theta=52.899561 -> V=1.0, theta=0.0
% INFO    : Bus 5496	: V=0.965112, theta=-31.467815 -> V=1.0, theta=0.0
% INFO    : Bus 5497	: V=1.043684, theta=-20.144478 -> V=1.0, theta=0.0
% INFO    : Bus 5498	: V=1.011277, theta=-36.310892 -> V=1.0, theta=0.0
% INFO    : Bus 5499	: V=1.043636, theta=-26.106859 -> V=1.0, theta=0.0
% INFO    : Bus 5500	: V=1.021558, theta=-54.126055 -> V=1.0, theta=0.0
% INFO    : Bus 5501	: V=1.004736, theta=-38.330114 -> V=1.0, theta=0.0
% INFO    : Bus 5502	: V=1.035356, theta=-20.817081 -> V=1.0, theta=0.0
% INFO    : Bus 5503	: V=1.059208, theta=-12.863591 -> V=1.0, theta=0.0
% INFO    : Bus 5504	: V=1.033273, theta=-38.800825 -> V=1.0, theta=0.0
% INFO    : Bus 5505	: V=1.049006, theta=-8.701195 -> V=1.0, theta=0.0
% INFO    : Bus 5506	: V=0.890999, theta=-36.148908 -> V=1.0, theta=0.0
% INFO    : Bus 5507	: V=1.02587, theta=-39.761737 -> V=1.0, theta=0.0
% INFO    : Bus 5508	: V=1.012924, theta=-30.696006 -> V=1.0, theta=0.0
% INFO    : Bus 5509	: V=0.994902, theta=-6.469273 -> V=1.0, theta=0.0
% INFO    : Bus 5510	: V=1.017387, theta=-46.391346 -> V=1.0, theta=0.0
% INFO    : Bus 5511	: V=1.010438, theta=-60.067724 -> V=1.0, theta=0.0
% INFO    : Bus 5512	: V=1.017916, theta=-41.936012 -> V=1.0, theta=0.0
% INFO    : Bus 5513	: V=1.030251, theta=-5.016549 -> V=1.0, theta=0.0
% INFO    : Bus 5514	: V=1.022118, theta=51.364458 -> V=1.0, theta=0.0
% INFO    : Bus 5515	: V=1.072081, theta=-17.672798 -> V=1.0, theta=0.0
% INFO    : Bus 5516	: V=1.032259, theta=-34.232499 -> V=1.0, theta=0.0
% INFO    : Bus 5517	: V=0.974654, theta=-43.199572 -> V=1.0, theta=0.0
% INFO    : Bus 5518	: V=1.037784, theta=-37.319885 -> V=1.0, theta=0.0
% INFO    : Bus 5519	: V=1.044448, theta=-24.851567 -> V=1.0, theta=0.0
% INFO    : Bus 5520	: V=1.007081, theta=-2.487018 -> V=1.0, theta=0.0
% INFO    : Bus 5521	: V=1.018613, theta=-27.370398 -> V=1.0, theta=0.0
% INFO    : Bus 5522	: V=1.061913, theta=0.592035 -> V=1.0, theta=0.0
% INFO    : Bus 5523	: V=1.02722, theta=1.492171 -> V=1.0, theta=0.0
% INFO    : Bus 5524	: V=1.025708, theta=-23.614535 -> V=1.0, theta=0.0
% INFO    : Bus 5525	: V=1.03757, theta=-14.19565 -> V=1.0, theta=0.0
% INFO    : Bus 5526	: V=1.041416, theta=17.400508 -> V=1.0, theta=0.0
% INFO    : Bus 5527	: V=1.041969, theta=-16.353168 -> V=1.0, theta=0.0
% INFO    : Bus 5528	: V=1.024151, theta=19.97811 -> V=1.0, theta=0.0
% INFO    : Bus 5529	: V=1.033411, theta=-3.238958 -> V=1.0, theta=0.0
% INFO    : Bus 5530	: V=1.011393, theta=3.278996 -> V=1.0, theta=0.0
% INFO    : Bus 5531	: V=1.027817, theta=50.048565 -> V=1.0, theta=0.0
% INFO    : Bus 5532	: V=1.020753, theta=-42.72507 -> V=1.0, theta=0.0
% INFO    : Bus 5533	: V=1.046404, theta=-13.450032 -> V=1.0, theta=0.0
% INFO    : Bus 5534	: V=1.029683, theta=-33.201948 -> V=1.0, theta=0.0
% INFO    : Bus 5535	: V=1.009172, theta=-32.442398 -> V=1.0, theta=0.0
% INFO    : Bus 5536	: V=1.010983, theta=-7.372311 -> V=1.0, theta=0.0
% INFO    : Bus 5537	: V=1.068354, theta=-24.94168 -> V=1.0, theta=0.0
% INFO    : Bus 5538	: V=1.035147, theta=1.510321 -> V=1.0, theta=0.0
% INFO    : Bus 5539	: V=0.960918, theta=-22.964315 -> V=1.0, theta=0.0
% INFO    : Bus 5540	: V=0.991434, theta=-20.676063 -> V=1.0, theta=0.0
% INFO    : Bus 5541	: V=1.059687, theta=-32.169418 -> V=1.0, theta=0.0
% INFO    : Bus 5542	: V=1.035299, theta=-26.295162 -> V=1.0, theta=0.0
% INFO    : Bus 5543	: V=1.017345, theta=-13.937245 -> V=1.0, theta=0.0
% INFO    : Bus 5544	: V=0.90329, theta=-35.996951 -> V=1.0, theta=0.0
% INFO    : Bus 5545	: V=1.004202, theta=-44.550982 -> V=1.0, theta=0.0
% INFO    : Bus 5546	: V=1.063123, theta=-24.286461 -> V=1.0, theta=0.0
% INFO    : Bus 5547	: V=1.001522, theta=-30.896248 -> V=1.0, theta=0.0
% INFO    : Bus 5548	: V=0.975272, theta=-32.247157 -> V=1.0, theta=0.0
% INFO    : Bus 5549	: V=1.018012, theta=-0.960924 -> V=1.0, theta=0.0
% INFO    : Bus 5550	: V=1.040307, theta=-26.337142 -> V=1.0, theta=0.0
% INFO    : Bus 5551	: V=1.012651, theta=-38.597824 -> V=1.0, theta=0.0
% INFO    : Bus 5552	: V=1.023176, theta=-25.397739 -> V=1.0, theta=0.0
% INFO    : Bus 5553	: V=0.970518, theta=-32.199871 -> V=1.0, theta=0.0
% INFO    : Bus 5554	: V=0.954288, theta=-32.366016 -> V=1.0, theta=0.0
% INFO    : Bus 5555	: V=1.034991, theta=8.405677 -> V=1.0, theta=0.0
% INFO    : Bus 5556	: V=1.067161, theta=12.086246 -> V=1.0, theta=0.0
% INFO    : Bus 5557	: V=0.999397, theta=-31.323747 -> V=1.0, theta=0.0
% INFO    : Bus 5558	: V=1.016579, theta=16.58643 -> V=1.0, theta=0.0
% INFO    : Bus 5559	: V=0.99875, theta=-43.311421 -> V=1.0, theta=0.0
% INFO    : Bus 5560	: V=1.01234, theta=-28.707192 -> V=1.0, theta=0.0
% INFO    : Bus 5561	: V=1.032807, theta=-26.569915 -> V=1.0, theta=0.0
% INFO    : Bus 5562	: V=1.064025, theta=-46.256666 -> V=1.0, theta=0.0
% INFO    : Bus 5563	: V=1.086139, theta=-17.202714 -> V=1.0, theta=0.0
% INFO    : Bus 5564	: V=1.038385, theta=-12.644533 -> V=1.0, theta=0.0
% INFO    : Bus 5565	: V=1.039021, theta=-9.508375 -> V=1.0, theta=0.0
% INFO    : Bus 5566	: V=1.010037, theta=1.120766 -> V=1.0, theta=0.0
% INFO    : Bus 5567	: V=1.015187, theta=-19.059134 -> V=1.0, theta=0.0
% INFO    : Bus 5568	: V=1.003095, theta=-36.693826 -> V=1.0, theta=0.0
% INFO    : Bus 5569	: V=0.983695, theta=-16.09428 -> V=1.0, theta=0.0
% INFO    : Bus 5570	: V=0.991081, theta=-28.405577 -> V=1.0, theta=0.0
% INFO    : Bus 5571	: V=1.032023, theta=-22.830475 -> V=1.0, theta=0.0
% INFO    : Bus 5572	: V=1.033768, theta=-10.89418 -> V=1.0, theta=0.0
% INFO    : Bus 5573	: V=1.068948, theta=-23.910257 -> V=1.0, theta=0.0
% INFO    : Bus 5574	: V=1.033871, theta=-12.192277 -> V=1.0, theta=0.0
% INFO    : Bus 5575	: V=1.040449, theta=-41.112082 -> V=1.0, theta=0.0
% INFO    : Bus 5576	: V=1.034825, theta=-23.248284 -> V=1.0, theta=0.0
% INFO    : Bus 5577	: V=1.041024, theta=-27.643983 -> V=1.0, theta=0.0
% INFO    : Bus 5578	: V=0.934329, theta=-33.800641 -> V=1.0, theta=0.0
% INFO    : Bus 5579	: V=1.010415, theta=-36.389942 -> V=1.0, theta=0.0
% INFO    : Bus 5580	: V=1.019717, theta=-5.305656 -> V=1.0, theta=0.0
% INFO    : Bus 5581	: V=1.042638, theta=3.534523 -> V=1.0, theta=0.0
% INFO    : Bus 5582	: V=1.00513, theta=-18.733291 -> V=1.0, theta=0.0
% INFO    : Bus 5583	: V=1.069405, theta=-18.465793 -> V=1.0, theta=0.0
% INFO    : Bus 5584	: V=1.026351, theta=16.339817 -> V=1.0, theta=0.0
% INFO    : Bus 5585	: V=1.026637, theta=-38.41479 -> V=1.0, theta=0.0
% INFO    : Bus 5586	: V=1.051067, theta=2.324898 -> V=1.0, theta=0.0
% INFO    : Bus 5587	: V=1.030648, theta=-10.826911 -> V=1.0, theta=0.0
% INFO    : Bus 5588	: V=0.962214, theta=-32.51376 -> V=1.0, theta=0.0
% INFO    : Bus 5589	: V=1.031495, theta=-31.068515 -> V=1.0, theta=0.0
% INFO    : Bus 5590	: V=1.010152, theta=2.8802 -> V=1.0, theta=0.0
% INFO    : Bus 5591	: V=1.024918, theta=-2.12304 -> V=1.0, theta=0.0
% INFO    : Bus 5592	: V=1.008732, theta=-51.786702 -> V=1.0, theta=0.0
% INFO    : Bus 5593	: V=1.051054, theta=-25.445268 -> V=1.0, theta=0.0
% INFO    : Bus 5594	: V=1.048652, theta=-33.520974 -> V=1.0, theta=0.0
% INFO    : Bus 5595	: V=1.032832, theta=2.906602 -> V=1.0, theta=0.0
% INFO    : Bus 5596	: V=1.024078, theta=-17.267999 -> V=1.0, theta=0.0
% INFO    : Bus 5597	: V=1.023283, theta=12.805407 -> V=1.0, theta=0.0
% INFO    : Bus 5598	: V=1.030805, theta=-9.685276 -> V=1.0, theta=0.0
% INFO    : Bus 5599	: V=1.011688, theta=-8.700111 -> V=1.0, theta=0.0
% INFO    : Bus 5600	: V=0.970986, theta=68.621915 -> V=1.0, theta=0.0
% INFO    : Bus 5601	: V=1.023746, theta=-21.503966 -> V=1.0, theta=0.0
% INFO    : Bus 5602	: V=1.032916, theta=9.689117 -> V=1.0, theta=0.0
% INFO    : Bus 5603	: V=1.027661, theta=0.058712 -> V=1.0, theta=0.0
% INFO    : Bus 5604	: V=1.013716, theta=-7.690535 -> V=1.0, theta=0.0
% INFO    : Bus 5605	: V=1.011071, theta=-33.040519 -> V=1.0, theta=0.0
% INFO    : Bus 5606	: V=1.036946, theta=-30.614337 -> V=1.0, theta=0.0
% INFO    : Bus 5607	: V=1.049101, theta=-25.872086 -> V=1.0, theta=0.0
% INFO    : Bus 5608	: V=1.022612, theta=-51.075631 -> V=1.0, theta=0.0
% INFO    : Bus 5609	: V=1.013915, theta=60.756802 -> V=1.0, theta=0.0
% INFO    : Bus 5610	: V=1.041396, theta=-24.529577 -> V=1.0, theta=0.0
% INFO    : Bus 5611	: V=1.079526, theta=43.868294 -> V=1.0, theta=0.0
% INFO    : Bus 5612	: V=1.033844, theta=2.402845 -> V=1.0, theta=0.0
% INFO    : Bus 5613	: V=0.999749, theta=-4.494898 -> V=1.0, theta=0.0
% INFO    : Bus 5614	: V=0.999853, theta=-28.287278 -> V=1.0, theta=0.0
% INFO    : Bus 5615	: V=1.026737, theta=-8.119017 -> V=1.0, theta=0.0
% INFO    : Bus 5616	: V=1.072539, theta=-35.51358 -> V=1.0, theta=0.0
% INFO    : Bus 5617	: V=0.975099, theta=-49.885167 -> V=1.0, theta=0.0
% INFO    : Bus 5618	: V=1.014579, theta=-4.867251 -> V=1.0, theta=0.0
% INFO    : Bus 5619	: V=1.037855, theta=-26.053406 -> V=1.0, theta=0.0
% INFO    : Bus 5620	: V=1.055555, theta=10.797767 -> V=1.0, theta=0.0
% INFO    : Bus 5621	: V=0.966759, theta=-29.955048 -> V=1.0, theta=0.0
% INFO    : Bus 5622	: V=1.025208, theta=-16.586535 -> V=1.0, theta=0.0
% INFO    : Bus 5623	: V=1.034284, theta=-33.747114 -> V=1.0, theta=0.0
% INFO    : Bus 5624	: V=1.042101, theta=-28.475363 -> V=1.0, theta=0.0
% INFO    : Bus 5625	: V=1.089754, theta=-30.701634 -> V=1.0, theta=0.0
% INFO    : Bus 5626	: V=0.978647, theta=-28.322089 -> V=1.0, theta=0.0
% INFO    : Bus 5627	: V=1.021141, theta=-32.671306 -> V=1.0, theta=0.0
% INFO    : Bus 5628	: V=0.967096, theta=-28.823328 -> V=1.0, theta=0.0
% INFO    : Bus 5629	: V=1.004946, theta=-34.428357 -> V=1.0, theta=0.0
% INFO    : Bus 5630	: V=1.037673, theta=-4.438859 -> V=1.0, theta=0.0
% INFO    : Bus 5631	: V=0.986345, theta=-43.712619 -> V=1.0, theta=0.0
% INFO    : Bus 5632	: V=0.966943, theta=-29.462839 -> V=1.0, theta=0.0
% INFO    : Bus 5633	: V=0.965817, theta=-55.158907 -> V=1.0, theta=0.0
% INFO    : Bus 5634	: V=0.945107, theta=-32.784726 -> V=1.0, theta=0.0
% INFO    : Bus 5635	: V=0.984669, theta=-35.597077 -> V=1.0, theta=0.0
% INFO    : Bus 5636	: V=1.043966, theta=-30.135632 -> V=1.0, theta=0.0
% INFO    : Bus 5637	: V=1.029059, theta=-28.575685 -> V=1.0, theta=0.0
% INFO    : Bus 5638	: V=0.961838, theta=-31.677351 -> V=1.0, theta=0.0
% INFO    : Bus 5639	: V=1.011634, theta=-15.392348 -> V=1.0, theta=0.0
% INFO    : Bus 5640	: V=1.030182, theta=7.58524 -> V=1.0, theta=0.0
% INFO    : Bus 5641	: V=1.04872, theta=-26.545657 -> V=1.0, theta=0.0
% INFO    : Bus 5642	: V=0.977041, theta=-35.24252 -> V=1.0, theta=0.0
% INFO    : Bus 5643	: V=0.984517, theta=-56.623592 -> V=1.0, theta=0.0
% INFO    : Bus 5644	: V=0.996385, theta=8.148142 -> V=1.0, theta=0.0
% INFO    : Bus 5645	: V=1.000282, theta=-50.759087 -> V=1.0, theta=0.0
% INFO    : Bus 5646	: V=0.960604, theta=-23.244396 -> V=1.0, theta=0.0
% INFO    : Bus 5647	: V=0.976466, theta=-29.43603 -> V=1.0, theta=0.0
% INFO    : Bus 5648	: V=0.990755, theta=-13.733686 -> V=1.0, theta=0.0
% INFO    : Bus 5649	: V=1.005758, theta=2.727909 -> V=1.0, theta=0.0
% INFO    : Bus 5650	: V=1.044978, theta=14.427814 -> V=1.0, theta=0.0
% INFO    : Bus 5651	: V=0.977947, theta=-31.778345 -> V=1.0, theta=0.0
% INFO    : Bus 5652	: V=1.043285, theta=-25.092566 -> V=1.0, theta=0.0
% INFO    : Bus 5653	: V=1.043716, theta=-7.876751 -> V=1.0, theta=0.0
% INFO    : Bus 5654	: V=1.023998, theta=-39.099754 -> V=1.0, theta=0.0
% INFO    : Bus 5655	: V=1.018501, theta=2.360099 -> V=1.0, theta=0.0
% INFO    : Bus 5656	: V=1.039989, theta=-1.865111 -> V=1.0, theta=0.0
% INFO    : Bus 5657	: V=1.062052, theta=-27.004954 -> V=1.0, theta=0.0
% INFO    : Bus 5658	: V=1.005722, theta=-24.221396 -> V=1.0, theta=0.0
% INFO    : Bus 5659	: V=0.970077, theta=-26.662415 -> V=1.0, theta=0.0
% INFO    : Bus 5660	: V=1.015958, theta=-36.15525 -> V=1.0, theta=0.0
% INFO    : Bus 5661	: V=1.008119, theta=-31.216752 -> V=1.0, theta=0.0
% INFO    : Bus 5662	: V=1.007382, theta=-42.592885 -> V=1.0, theta=0.0
% INFO    : Bus 5663	: V=1.033921, theta=-29.923351 -> V=1.0, theta=0.0
% INFO    : Bus 5664	: V=1.063661, theta=0.849588 -> V=1.0, theta=0.0
% INFO    : Bus 5665	: V=1.051109, theta=40.203424 -> V=1.0, theta=0.0
% INFO    : Bus 5666	: V=1.040436, theta=-11.065628 -> V=1.0, theta=0.0
% INFO    : Bus 5667	: V=1.029457, theta=15.695778 -> V=1.0, theta=0.0
% INFO    : Bus 5668	: V=1.028943, theta=-42.875803 -> V=1.0, theta=0.0
% INFO    : Bus 5669	: V=1.000678, theta=-34.61665 -> V=1.0, theta=0.0
% INFO    : Bus 5670	: V=1.013301, theta=-47.786839 -> V=1.0, theta=0.0
% INFO    : Bus 5671	: V=0.984988, theta=-28.800852 -> V=1.0, theta=0.0
% INFO    : Bus 5672	: V=0.979268, theta=-41.802551 -> V=1.0, theta=0.0
% INFO    : Bus 5673	: V=1.045466, theta=-2.635573 -> V=1.0, theta=0.0
% INFO    : Bus 5674	: V=1.024555, theta=6.468167 -> V=1.0, theta=0.0
% INFO    : Bus 5675	: V=1.017851, theta=-41.096757 -> V=1.0, theta=0.0
% INFO    : Bus 5676	: V=1.025006, theta=-25.07857 -> V=1.0, theta=0.0
% INFO    : Bus 5677	: V=1.033561, theta=-20.889102 -> V=1.0, theta=0.0
% INFO    : Bus 5678	: V=1.01515, theta=-31.918978 -> V=1.0, theta=0.0
% INFO    : Bus 5679	: V=1.057325, theta=63.249417 -> V=1.0, theta=0.0
% INFO    : Bus 5680	: V=1.015818, theta=-14.622302 -> V=1.0, theta=0.0
% INFO    : Bus 5681	: V=1.026281, theta=-53.916536 -> V=1.0, theta=0.0
% INFO    : Bus 5682	: V=1.026991, theta=1.798275 -> V=1.0, theta=0.0
% INFO    : Bus 5683	: V=1.031443, theta=4.244555 -> V=1.0, theta=0.0
% INFO    : Bus 5684	: V=1.116329, theta=-23.61188 -> V=1.0, theta=0.0
% INFO    : Bus 5685	: V=1.031682, theta=-43.528573 -> V=1.0, theta=0.0
% INFO    : Bus 5686	: V=1.031801, theta=-10.245193 -> V=1.0, theta=0.0
% INFO    : Bus 5687	: V=1.012743, theta=-30.260645 -> V=1.0, theta=0.0
% INFO    : Bus 5688	: V=1.032263, theta=-8.133455 -> V=1.0, theta=0.0
% INFO    : Bus 5689	: V=1.011966, theta=5.765357 -> V=1.0, theta=0.0
% INFO    : Bus 5690	: V=1.066932, theta=-21.855019 -> V=1.0, theta=0.0
% INFO    : Bus 5691	: V=1.057263, theta=-45.566306 -> V=1.0, theta=0.0
% INFO    : Bus 5692	: V=1.048689, theta=-28.313509 -> V=1.0, theta=0.0
% INFO    : Bus 5693	: V=1.044671, theta=-16.526474 -> V=1.0, theta=0.0
% INFO    : Bus 5694	: V=1.004692, theta=-34.806865 -> V=1.0, theta=0.0
% INFO    : Bus 5695	: V=1.045234, theta=-27.538048 -> V=1.0, theta=0.0
% INFO    : Bus 5696	: V=1.012996, theta=-27.195344 -> V=1.0, theta=0.0
% INFO    : Bus 5697	: V=1.007841, theta=-47.751091 -> V=1.0, theta=0.0
% INFO    : Bus 5698	: V=1.015975, theta=-35.374905 -> V=1.0, theta=0.0
% INFO    : Bus 5699	: V=1.042214, theta=-6.729499 -> V=1.0, theta=0.0
% INFO    : Bus 5700	: V=1.007101, theta=-41.693794 -> V=1.0, theta=0.0
% INFO    : Bus 5701	: V=1.015035, theta=14.156324 -> V=1.0, theta=0.0
% INFO    : Bus 5702	: V=1.051762, theta=-27.086268 -> V=1.0, theta=0.0
% INFO    : Bus 5703	: V=1.041076, theta=-25.457532 -> V=1.0, theta=0.0
% INFO    : Bus 5704	: V=1.003745, theta=-50.704049 -> V=1.0, theta=0.0
% INFO    : Bus 5705	: V=1.084017, theta=-47.770008 -> V=1.0, theta=0.0
% INFO    : Bus 5706	: V=1.049203, theta=-27.104818 -> V=1.0, theta=0.0
% INFO    : Bus 5707	: V=0.993703, theta=-33.881672 -> V=1.0, theta=0.0
% INFO    : Bus 5708	: V=1.020915, theta=-7.243486 -> V=1.0, theta=0.0
% INFO    : Bus 5709	: V=1.024594, theta=-8.738245 -> V=1.0, theta=0.0
% INFO    : Bus 5710	: V=0.990126, theta=-30.071523 -> V=1.0, theta=0.0
% INFO    : Bus 5711	: V=1.050262, theta=10.155329 -> V=1.0, theta=0.0
% INFO    : Bus 5712	: V=1.042355, theta=-4.844771 -> V=1.0, theta=0.0
% INFO    : Bus 5713	: V=1.002389, theta=-27.016013 -> V=1.0, theta=0.0
% INFO    : Bus 5714	: V=1.020678, theta=-35.27281 -> V=1.0, theta=0.0
% INFO    : Bus 5715	: V=1.015021, theta=61.817919 -> V=1.0, theta=0.0
% INFO    : Bus 5716	: V=1.019593, theta=21.87074 -> V=1.0, theta=0.0
% INFO    : Bus 5717	: V=1.070074, theta=61.642171 -> V=1.0, theta=0.0
% INFO    : Bus 5718	: V=0.99498, theta=-38.82174 -> V=1.0, theta=0.0
% INFO    : Bus 5719	: V=1.035793, theta=46.935855 -> V=1.0, theta=0.0
% INFO    : Bus 5720	: V=1.031595, theta=-25.4469 -> V=1.0, theta=0.0
% INFO    : Bus 5721	: V=1.054563, theta=-35.198466 -> V=1.0, theta=0.0
% INFO    : Bus 5722	: V=1.009245, theta=2.026844 -> V=1.0, theta=0.0
% INFO    : Bus 5723	: V=1.047237, theta=-9.77142 -> V=1.0, theta=0.0
% INFO    : Bus 5724	: V=0.996765, theta=-27.051875 -> V=1.0, theta=0.0
% INFO    : Bus 5725	: V=0.977827, theta=-31.426381 -> V=1.0, theta=0.0
% INFO    : Bus 5726	: V=1.01699, theta=-42.84553 -> V=1.0, theta=0.0
% INFO    : Bus 5727	: V=0.977247, theta=-32.621818 -> V=1.0, theta=0.0
% INFO    : Bus 5728	: V=0.99603, theta=-29.460103 -> V=1.0, theta=0.0
% INFO    : Bus 5729	: V=0.963102, theta=-31.646588 -> V=1.0, theta=0.0
% INFO    : Bus 5730	: V=1.056495, theta=-26.549947 -> V=1.0, theta=0.0
% INFO    : Bus 5731	: V=1.05341, theta=-24.417595 -> V=1.0, theta=0.0
% INFO    : Bus 5732	: V=1.030213, theta=1.277029 -> V=1.0, theta=0.0
% INFO    : Bus 5733	: V=1.071684, theta=-20.328453 -> V=1.0, theta=0.0
% INFO    : Bus 5734	: V=1.008175, theta=-25.211628 -> V=1.0, theta=0.0
% INFO    : Bus 5735	: V=1.052722, theta=-27.276527 -> V=1.0, theta=0.0
% INFO    : Bus 5736	: V=1.001805, theta=-16.336173 -> V=1.0, theta=0.0
% INFO    : Bus 5737	: V=1.008529, theta=-26.402638 -> V=1.0, theta=0.0
% INFO    : Bus 5738	: V=1.011797, theta=-10.601661 -> V=1.0, theta=0.0
% INFO    : Bus 5739	: V=1.012967, theta=-23.798598 -> V=1.0, theta=0.0
% INFO    : Bus 5740	: V=1.014887, theta=4.50971 -> V=1.0, theta=0.0
% INFO    : Bus 5741	: V=1.001487, theta=-26.183348 -> V=1.0, theta=0.0
% INFO    : Bus 5742	: V=1.023074, theta=25.583399 -> V=1.0, theta=0.0
% INFO    : Bus 5743	: V=1.047811, theta=-24.447648 -> V=1.0, theta=0.0
% INFO    : Bus 5744	: V=1.026817, theta=15.773204 -> V=1.0, theta=0.0
% INFO    : Bus 5745	: V=1.015744, theta=-36.169581 -> V=1.0, theta=0.0
% INFO    : Bus 5746	: V=1.005852, theta=-33.864557 -> V=1.0, theta=0.0
% INFO    : Bus 5747	: V=1.023072, theta=-46.933301 -> V=1.0, theta=0.0
% INFO    : Bus 5748	: V=1.013586, theta=-4.84178 -> V=1.0, theta=0.0
% INFO    : Bus 5749	: V=1.073053, theta=12.833517 -> V=1.0, theta=0.0
% INFO    : Bus 5750	: V=1.026001, theta=-40.550051 -> V=1.0, theta=0.0
% INFO    : Bus 5751	: V=1.006834, theta=6.56926 -> V=1.0, theta=0.0
% INFO    : Bus 5752	: V=1.043572, theta=-30.853587 -> V=1.0, theta=0.0
% INFO    : Bus 5753	: V=1.029575, theta=-3.635523 -> V=1.0, theta=0.0
% INFO    : Bus 5754	: V=1.051896, theta=11.217526 -> V=1.0, theta=0.0
% INFO    : Bus 5755	: V=1.03532, theta=-30.60779 -> V=1.0, theta=0.0
% INFO    : Bus 5756	: V=1.031823, theta=5.570708 -> V=1.0, theta=0.0
% INFO    : Bus 5757	: V=1.0135, theta=-21.167181 -> V=1.0, theta=0.0
% INFO    : Bus 5758	: V=1.000204, theta=-34.877053 -> V=1.0, theta=0.0
% INFO    : Bus 5759	: V=1.075601, theta=-14.315009 -> V=1.0, theta=0.0
% INFO    : Bus 5760	: V=1.046466, theta=6.968336 -> V=1.0, theta=0.0
% INFO    : Bus 5761	: V=1.066618, theta=-26.339413 -> V=1.0, theta=0.0
% INFO    : Bus 5762	: V=1.045992, theta=0.091901 -> V=1.0, theta=0.0
% INFO    : Bus 5763	: V=1.037443, theta=-3.388841 -> V=1.0, theta=0.0
% INFO    : Bus 5764	: V=1.025723, theta=-25.902611 -> V=1.0, theta=0.0
% INFO    : Bus 5765	: V=1.024999, theta=-4.203502 -> V=1.0, theta=0.0
% INFO    : Bus 5766	: V=0.988622, theta=-27.421562 -> V=1.0, theta=0.0
% INFO    : Bus 5767	: V=1.022193, theta=-48.812496 -> V=1.0, theta=0.0
% INFO    : Bus 5768	: V=1.014636, theta=-3.801727 -> V=1.0, theta=0.0
% INFO    : Bus 5769	: V=1.014996, theta=-32.518182 -> V=1.0, theta=0.0
% INFO    : Bus 5770	: V=1.055745, theta=-27.34578 -> V=1.0, theta=0.0
% INFO    : Bus 5771	: V=0.993072, theta=-47.263595 -> V=1.0, theta=0.0
% INFO    : Bus 5772	: V=1.04225, theta=4.855848 -> V=1.0, theta=0.0
% INFO    : Bus 5773	: V=1.034676, theta=-3.028522 -> V=1.0, theta=0.0
% INFO    : Bus 5774	: V=1.058859, theta=33.790167 -> V=1.0, theta=0.0
% INFO    : Bus 5775	: V=1.002468, theta=-30.954996 -> V=1.0, theta=0.0
% INFO    : Bus 5776	: V=1.059236, theta=-7.623477 -> V=1.0, theta=0.0
% INFO    : Bus 5777	: V=1.011617, theta=-32.734235 -> V=1.0, theta=0.0
% INFO    : Bus 5778	: V=0.996449, theta=-32.437195 -> V=1.0, theta=0.0
% INFO    : Bus 5779	: V=1.027385, theta=-5.585061 -> V=1.0, theta=0.0
% INFO    : Bus 5780	: V=1.025535, theta=-53.709471 -> V=1.0, theta=0.0
% INFO    : Bus 5781	: V=1.046351, theta=-11.820299 -> V=1.0, theta=0.0
% INFO    : Bus 5782	: V=1.063656, theta=-34.581513 -> V=1.0, theta=0.0
% INFO    : Bus 5783	: V=1.064429, theta=10.944095 -> V=1.0, theta=0.0
% INFO    : Bus 5784	: V=1.022502, theta=51.362314 -> V=1.0, theta=0.0
% INFO    : Bus 5785	: V=1.035848, theta=-24.966777 -> V=1.0, theta=0.0
% INFO    : Bus 5786	: V=1.006382, theta=-44.432452 -> V=1.0, theta=0.0
% INFO    : Bus 5787	: V=1.028374, theta=-44.07079 -> V=1.0, theta=0.0
% INFO    : Bus 5788	: V=1.026933, theta=-1.65936 -> V=1.0, theta=0.0
% INFO    : Bus 5789	: V=0.998953, theta=-16.361319 -> V=1.0, theta=0.0
% INFO    : Bus 5790	: V=1.024154, theta=-36.540708 -> V=1.0, theta=0.0
% INFO    : Bus 5791	: V=0.987974, theta=-28.298663 -> V=1.0, theta=0.0
% INFO    : Bus 5792	: V=1.024592, theta=0.113189 -> V=1.0, theta=0.0
% INFO    : Bus 5793	: V=1.006923, theta=-48.159604 -> V=1.0, theta=0.0
% INFO    : Bus 5794	: V=1.002506, theta=63.840851 -> V=1.0, theta=0.0
% INFO    : Bus 5795	: V=1.020039, theta=-24.528292 -> V=1.0, theta=0.0
% INFO    : Bus 5796	: V=0.933765, theta=-34.74988 -> V=1.0, theta=0.0
% INFO    : Bus 5797	: V=0.977842, theta=-56.716813 -> V=1.0, theta=0.0
% INFO    : Bus 5798	: V=1.094064, theta=-27.46693 -> V=1.0, theta=0.0
% INFO    : Bus 5799	: V=1.040881, theta=-32.583535 -> V=1.0, theta=0.0
% INFO    : Bus 5800	: V=1.036238, theta=5.081152 -> V=1.0, theta=0.0
% INFO    : Bus 5801	: V=1.129334, theta=-23.470807 -> V=1.0, theta=0.0
% INFO    : Bus 5802	: V=1.015581, theta=-32.80905 -> V=1.0, theta=0.0
% INFO    : Bus 5803	: V=1.039193, theta=-14.333535 -> V=1.0, theta=0.0
% INFO    : Bus 5804	: V=0.979141, theta=-21.961167 -> V=1.0, theta=0.0
% INFO    : Bus 5805	: V=0.987424, theta=-55.254875 -> V=1.0, theta=0.0
% INFO    : Bus 5806	: V=0.977739, theta=11.36644 -> V=1.0, theta=0.0
% INFO    : Bus 5807	: V=1.022417, theta=-24.11271 -> V=1.0, theta=0.0
% INFO    : Bus 5808	: V=1.036506, theta=-22.038886 -> V=1.0, theta=0.0
% INFO    : Bus 5809	: V=1.010105, theta=-15.848444 -> V=1.0, theta=0.0
% INFO    : Bus 5810	: V=1.046545, theta=10.545931 -> V=1.0, theta=0.0
% INFO    : Bus 5811	: V=1.018688, theta=-27.872394 -> V=1.0, theta=0.0
% INFO    : Bus 5812	: V=1.031099, theta=10.404698 -> V=1.0, theta=0.0
% INFO    : Bus 5813	: V=0.969821, theta=-29.796188 -> V=1.0, theta=0.0
% INFO    : Bus 5814	: V=1.040708, theta=-12.172003 -> V=1.0, theta=0.0
% INFO    : Bus 5815	: V=1.039004, theta=-51.595201 -> V=1.0, theta=0.0
% INFO    : Bus 5816	: V=0.993123, theta=-27.286226 -> V=1.0, theta=0.0
% INFO    : Bus 5817	: V=1.029045, theta=-6.970313 -> V=1.0, theta=0.0
% INFO    : Bus 5818	: V=0.995012, theta=-31.350024 -> V=1.0, theta=0.0
% INFO    : Bus 5819	: V=1.037139, theta=-17.774505 -> V=1.0, theta=0.0
% INFO    : Bus 5820	: V=1.023371, theta=56.767166 -> V=1.0, theta=0.0
% INFO    : Bus 5821	: V=1.016327, theta=-44.486059 -> V=1.0, theta=0.0
% INFO    : Bus 5822	: V=1.063749, theta=17.871794 -> V=1.0, theta=0.0
% INFO    : Bus 5823	: V=1.060066, theta=-39.802079 -> V=1.0, theta=0.0
% INFO    : Bus 5824	: V=1.050736, theta=-35.4935 -> V=1.0, theta=0.0
% INFO    : Bus 5825	: V=0.992342, theta=-37.451762 -> V=1.0, theta=0.0
% INFO    : Bus 5826	: V=1.03378, theta=-7.835541 -> V=1.0, theta=0.0
% INFO    : Bus 5827	: V=0.993711, theta=-33.877317 -> V=1.0, theta=0.0
% INFO    : Bus 5828	: V=1.027766, theta=-37.164045 -> V=1.0, theta=0.0
% INFO    : Bus 5829	: V=1.01633, theta=-0.962608 -> V=1.0, theta=0.0
% INFO    : Bus 5830	: V=0.970359, theta=-32.12441 -> V=1.0, theta=0.0
% INFO    : Bus 5831	: V=1.026046, theta=-47.638826 -> V=1.0, theta=0.0
% INFO    : Bus 5832	: V=0.896899, theta=-35.666492 -> V=1.0, theta=0.0
% INFO    : Bus 5833	: V=1.02486, theta=-22.148298 -> V=1.0, theta=0.0
% INFO    : Bus 5834	: V=1.033758, theta=-33.943646 -> V=1.0, theta=0.0
% INFO    : Bus 5835	: V=1.014592, theta=16.388587 -> V=1.0, theta=0.0
% INFO    : Bus 5836	: V=1.034539, theta=-12.333542 -> V=1.0, theta=0.0
% INFO    : Bus 5837	: V=1.015008, theta=-10.384142 -> V=1.0, theta=0.0
% INFO    : Bus 5838	: V=1.030725, theta=-0.492637 -> V=1.0, theta=0.0
% INFO    : Bus 5839	: V=1.013483, theta=-48.180115 -> V=1.0, theta=0.0
% INFO    : Bus 5840	: V=1.019201, theta=-24.016883 -> V=1.0, theta=0.0
% INFO    : Bus 5841	: V=1.046487, theta=-26.102165 -> V=1.0, theta=0.0
% INFO    : Bus 5842	: V=1.006214, theta=-28.428663 -> V=1.0, theta=0.0
% INFO    : Bus 5843	: V=1.033237, theta=14.707305 -> V=1.0, theta=0.0
% INFO    : Bus 5844	: V=1.050341, theta=-17.725294 -> V=1.0, theta=0.0
% INFO    : Bus 5845	: V=1.029227, theta=0.783771 -> V=1.0, theta=0.0
% INFO    : Bus 5846	: V=1.02116, theta=-5.089899 -> V=1.0, theta=0.0
% INFO    : Bus 5847	: V=1.045067, theta=-23.65353 -> V=1.0, theta=0.0
% INFO    : Bus 5848	: V=1.011427, theta=-5.10517 -> V=1.0, theta=0.0
% INFO    : Bus 5849	: V=0.985881, theta=-28.357949 -> V=1.0, theta=0.0
% INFO    : Bus 5850	: V=1.038252, theta=-21.21357 -> V=1.0, theta=0.0
% INFO    : Bus 5851	: V=1.025529, theta=-4.052572 -> V=1.0, theta=0.0
% INFO    : Bus 5852	: V=1.011842, theta=61.759219 -> V=1.0, theta=0.0
% INFO    : Bus 5853	: V=1.041243, theta=-7.53257 -> V=1.0, theta=0.0
% INFO    : Bus 5854	: V=1.023833, theta=-33.510557 -> V=1.0, theta=0.0
% INFO    : Bus 5855	: V=1.065097, theta=-8.984355 -> V=1.0, theta=0.0
% INFO    : Bus 5856	: V=1.036185, theta=-11.799895 -> V=1.0, theta=0.0
% INFO    : Bus 5857	: V=1.052836, theta=-21.385103 -> V=1.0, theta=0.0
% INFO    : Bus 5858	: V=1.01626, theta=-32.346245 -> V=1.0, theta=0.0
% INFO    : Bus 5859	: V=1.000233, theta=-32.592963 -> V=1.0, theta=0.0
% INFO    : Bus 5860	: V=1.034403, theta=-30.610144 -> V=1.0, theta=0.0
% INFO    : Bus 5861	: V=0.999379, theta=-32.166617 -> V=1.0, theta=0.0
% INFO    : Bus 5862	: V=1.059582, theta=49.895507 -> V=1.0, theta=0.0
% INFO    : Bus 5863	: V=1.048267, theta=4.652501 -> V=1.0, theta=0.0
% INFO    : Bus 5864	: V=1.024889, theta=-4.770654 -> V=1.0, theta=0.0
% INFO    : Bus 5865	: V=0.978977, theta=-31.241717 -> V=1.0, theta=0.0
% INFO    : Bus 5866	: V=1.024209, theta=-42.872954 -> V=1.0, theta=0.0
% INFO    : Bus 5867	: V=0.961286, theta=-31.66657 -> V=1.0, theta=0.0
% INFO    : Bus 5868	: V=1.048327, theta=-28.435905 -> V=1.0, theta=0.0
% INFO    : Bus 5869	: V=1.021723, theta=-11.257071 -> V=1.0, theta=0.0
% INFO    : Bus 5870	: V=1.002783, theta=-36.703624 -> V=1.0, theta=0.0
% INFO    : Bus 5871	: V=1.030589, theta=-39.461644 -> V=1.0, theta=0.0
% INFO    : Bus 5872	: V=1.020568, theta=10.85579 -> V=1.0, theta=0.0
% INFO    : Bus 5873	: V=1.012973, theta=-45.813911 -> V=1.0, theta=0.0
% INFO    : Bus 5874	: V=1.045045, theta=64.333927 -> V=1.0, theta=0.0
% INFO    : Bus 5875	: V=1.002143, theta=-29.086089 -> V=1.0, theta=0.0
% INFO    : Bus 5876	: V=1.063836, theta=-28.78544 -> V=1.0, theta=0.0
% INFO    : Bus 5877	: V=1.043576, theta=-50.502884 -> V=1.0, theta=0.0
% INFO    : Bus 5878	: V=1.043588, theta=-20.621973 -> V=1.0, theta=0.0
% INFO    : Bus 5879	: V=1.004879, theta=-31.845761 -> V=1.0, theta=0.0
% INFO    : Bus 5880	: V=1.03245, theta=24.731469 -> V=1.0, theta=0.0
% INFO    : Bus 5881	: V=1.056126, theta=-10.760666 -> V=1.0, theta=0.0
% INFO    : Bus 5882	: V=1.077465, theta=8.100026 -> V=1.0, theta=0.0
% INFO    : Bus 5883	: V=1.175144, theta=-19.224951 -> V=1.0, theta=0.0
% INFO    : Bus 5884	: V=1.036964, theta=-40.132357 -> V=1.0, theta=0.0
% INFO    : Bus 5885	: V=1.031733, theta=-20.996223 -> V=1.0, theta=0.0
% INFO    : Bus 5886	: V=1.005533, theta=-24.819539 -> V=1.0, theta=0.0
% INFO    : Bus 5887	: V=1.001678, theta=21.061751 -> V=1.0, theta=0.0
% INFO    : Bus 5888	: V=1.05046, theta=16.816424 -> V=1.0, theta=0.0
% INFO    : Bus 5889	: V=1.037146, theta=9.801924 -> V=1.0, theta=0.0
% INFO    : Bus 5890	: V=1.027395, theta=-46.396757 -> V=1.0, theta=0.0
% INFO    : Bus 5891	: V=1.031513, theta=-12.447025 -> V=1.0, theta=0.0
% INFO    : Bus 5892	: V=1.022362, theta=-48.79846 -> V=1.0, theta=0.0
% INFO    : Bus 5893	: V=1.023505, theta=15.322267 -> V=1.0, theta=0.0
% INFO    : Bus 5894	: V=1.035315, theta=-5.512525 -> V=1.0, theta=0.0
% INFO    : Bus 5895	: V=0.995326, theta=-35.195598 -> V=1.0, theta=0.0
% INFO    : Bus 5896	: V=0.986344, theta=14.700502 -> V=1.0, theta=0.0
% INFO    : Bus 5897	: V=1.047643, theta=17.999988 -> V=1.0, theta=0.0
% INFO    : Bus 5898	: V=1.054015, theta=-14.917486 -> V=1.0, theta=0.0
% INFO    : Bus 5899	: V=1.013511, theta=-20.047796 -> V=1.0, theta=0.0
% INFO    : Bus 5900	: V=1.085303, theta=-27.976492 -> V=1.0, theta=0.0
% INFO    : Bus 5901	: V=1.028065, theta=-26.84935 -> V=1.0, theta=0.0
% INFO    : Bus 5902	: V=0.998746, theta=-30.611628 -> V=1.0, theta=0.0
% INFO    : Bus 5903	: V=1.034736, theta=-28.713871 -> V=1.0, theta=0.0
% INFO    : Bus 5904	: V=1.024114, theta=-7.021107 -> V=1.0, theta=0.0
% INFO    : Bus 5905	: V=1.031661, theta=-13.65715 -> V=1.0, theta=0.0
% INFO    : Bus 5906	: V=0.969449, theta=-29.110513 -> V=1.0, theta=0.0
% INFO    : Bus 5907	: V=1.042618, theta=-8.712204 -> V=1.0, theta=0.0
% INFO    : Bus 5908	: V=0.99477, theta=-31.893947 -> V=1.0, theta=0.0
% INFO    : Bus 5909	: V=0.99022, theta=-20.158549 -> V=1.0, theta=0.0
% INFO    : Bus 5910	: V=1.023544, theta=-38.299118 -> V=1.0, theta=0.0
% INFO    : Bus 5911	: V=1.03698, theta=-25.21858 -> V=1.0, theta=0.0
% INFO    : Bus 5912	: V=1.030072, theta=-20.401195 -> V=1.0, theta=0.0
% INFO    : Bus 5913	: V=1.018238, theta=-29.270452 -> V=1.0, theta=0.0
% INFO    : Bus 5914	: V=1.036238, theta=1.780853 -> V=1.0, theta=0.0
% INFO    : Bus 5915	: V=1.00769, theta=-30.933315 -> V=1.0, theta=0.0
% INFO    : Bus 5916	: V=1.03926, theta=17.310915 -> V=1.0, theta=0.0
% INFO    : Bus 5917	: V=1.03057, theta=-26.483209 -> V=1.0, theta=0.0
% INFO    : Bus 5918	: V=1.054009, theta=-26.268399 -> V=1.0, theta=0.0
% INFO    : Bus 5919	: V=1.041114, theta=-50.368417 -> V=1.0, theta=0.0
% INFO    : Bus 5920	: V=1.057048, theta=-20.065958 -> V=1.0, theta=0.0
% INFO    : Bus 5921	: V=1.009, theta=6.925417 -> V=1.0, theta=0.0
% INFO    : Bus 5922	: V=1.030869, theta=-38.497457 -> V=1.0, theta=0.0
% INFO    : Bus 5923	: V=1.023696, theta=-54.459398 -> V=1.0, theta=0.0
% INFO    : Bus 5924	: V=1.004888, theta=-32.9331 -> V=1.0, theta=0.0
% INFO    : Bus 5925	: V=0.97801, theta=-29.767009 -> V=1.0, theta=0.0
% INFO    : Bus 5926	: V=1.068631, theta=-48.196248 -> V=1.0, theta=0.0
% INFO    : Bus 5927	: V=0.991444, theta=-36.806588 -> V=1.0, theta=0.0
% INFO    : Bus 5928	: V=1.017195, theta=-28.972732 -> V=1.0, theta=0.0
% INFO    : Bus 5929	: V=1.045842, theta=63.192896 -> V=1.0, theta=0.0
% INFO    : Bus 5930	: V=1.042525, theta=-31.111521 -> V=1.0, theta=0.0
% INFO    : Bus 5931	: V=1.00929, theta=-30.089314 -> V=1.0, theta=0.0
% INFO    : Bus 5932	: V=1.03346, theta=-7.875888 -> V=1.0, theta=0.0
% INFO    : Bus 5933	: V=1.005708, theta=-48.889663 -> V=1.0, theta=0.0
% INFO    : Bus 5934	: V=1.003321, theta=-5.390135 -> V=1.0, theta=0.0
% INFO    : Bus 5935	: V=1.06545, theta=-22.573477 -> V=1.0, theta=0.0
% INFO    : Bus 5936	: V=1.01939, theta=-22.655348 -> V=1.0, theta=0.0
% INFO    : Bus 5937	: V=1.044953, theta=-33.486934 -> V=1.0, theta=0.0
% INFO    : Bus 5938	: V=1.056395, theta=-34.749164 -> V=1.0, theta=0.0
% INFO    : Bus 5939	: V=1.069977, theta=-26.579592 -> V=1.0, theta=0.0
% INFO    : Bus 5940	: V=1.026879, theta=-14.638592 -> V=1.0, theta=0.0
% INFO    : Bus 5941	: V=1.051545, theta=49.790477 -> V=1.0, theta=0.0
% INFO    : Bus 5942	: V=1.038025, theta=-33.20709 -> V=1.0, theta=0.0
% INFO    : Bus 5943	: V=1.006106, theta=11.425005 -> V=1.0, theta=0.0
% INFO    : Bus 5944	: V=1.052506, theta=-26.232886 -> V=1.0, theta=0.0
% INFO    : Bus 5945	: V=1.044227, theta=-48.841113 -> V=1.0, theta=0.0
% INFO    : Bus 5946	: V=1.021262, theta=-42.836601 -> V=1.0, theta=0.0
% INFO    : Bus 5947	: V=1.053714, theta=-22.746881 -> V=1.0, theta=0.0
% INFO    : Bus 5948	: V=1.021508, theta=-48.968975 -> V=1.0, theta=0.0
% INFO    : Bus 5949	: V=1.018073, theta=2.35558 -> V=1.0, theta=0.0
% INFO    : Bus 5950	: V=0.998984, theta=-30.306116 -> V=1.0, theta=0.0
% INFO    : Bus 5951	: V=1.020223, theta=-30.568507 -> V=1.0, theta=0.0
% INFO    : Bus 5952	: V=1.031206, theta=3.839057 -> V=1.0, theta=0.0
% INFO    : Bus 5953	: V=0.991065, theta=-34.243743 -> V=1.0, theta=0.0
% INFO    : Bus 5954	: V=1.048336, theta=-18.628039 -> V=1.0, theta=0.0
% INFO    : Bus 5955	: V=1.015926, theta=-15.025291 -> V=1.0, theta=0.0
% INFO    : Bus 5956	: V=1.036355, theta=-29.780714 -> V=1.0, theta=0.0
% INFO    : Bus 5957	: V=1.021081, theta=-16.562596 -> V=1.0, theta=0.0
% INFO    : Bus 5958	: V=0.993945, theta=-22.313337 -> V=1.0, theta=0.0
% INFO    : Bus 5959	: V=1.01214, theta=-36.645736 -> V=1.0, theta=0.0
% INFO    : Bus 5960	: V=1.016922, theta=-33.838231 -> V=1.0, theta=0.0
% INFO    : Bus 5961	: V=1.013483, theta=-46.991416 -> V=1.0, theta=0.0
% INFO    : Bus 5962	: V=1.043271, theta=-24.414808 -> V=1.0, theta=0.0
% INFO    : Bus 5963	: V=1.071359, theta=44.333413 -> V=1.0, theta=0.0
% INFO    : Bus 5964	: V=1.005428, theta=-24.106443 -> V=1.0, theta=0.0
% INFO    : Bus 5965	: V=0.997579, theta=8.680327 -> V=1.0, theta=0.0
% INFO    : Bus 5966	: V=1.021894, theta=-28.446813 -> V=1.0, theta=0.0
% INFO    : Bus 5967	: V=1.030975, theta=-25.934721 -> V=1.0, theta=0.0
% INFO    : Bus 5968	: V=1.047043, theta=-24.829942 -> V=1.0, theta=0.0
% INFO    : Bus 5969	: V=1.036469, theta=13.002506 -> V=1.0, theta=0.0
% INFO    : Bus 5970	: V=1.017378, theta=-41.457427 -> V=1.0, theta=0.0
% INFO    : Bus 5971	: V=1.076888, theta=4.711259 -> V=1.0, theta=0.0
% INFO    : Bus 5972	: V=1.017198, theta=-16.166595 -> V=1.0, theta=0.0
% INFO    : Bus 5973	: V=1.055332, theta=-13.19785 -> V=1.0, theta=0.0
% INFO    : Bus 5974	: V=1.023351, theta=11.178136 -> V=1.0, theta=0.0
% INFO    : Bus 5975	: V=1.0347, theta=-33.956308 -> V=1.0, theta=0.0
% INFO    : Bus 5976	: V=1.045419, theta=-27.707756 -> V=1.0, theta=0.0
% INFO    : Bus 5977	: V=1.030489, theta=67.261675 -> V=1.0, theta=0.0
% INFO    : Bus 5978	: V=1.000781, theta=-28.914997 -> V=1.0, theta=0.0
% INFO    : Bus 5979	: V=1.040605, theta=25.720506 -> V=1.0, theta=0.0
% INFO    : Bus 5980	: V=1.05163, theta=-24.648119 -> V=1.0, theta=0.0
% INFO    : Bus 5981	: V=0.99111, theta=-27.640402 -> V=1.0, theta=0.0
% INFO    : Bus 5982	: V=1.025239, theta=-34.309954 -> V=1.0, theta=0.0
% INFO    : Bus 5983	: V=1.061878, theta=-15.173411 -> V=1.0, theta=0.0
% INFO    : Bus 5984	: V=1.018485, theta=-34.915936 -> V=1.0, theta=0.0
% INFO    : Bus 5985	: V=1.120491, theta=-23.13795 -> V=1.0, theta=0.0
% INFO    : Bus 5986	: V=1.103376, theta=32.82865 -> V=1.0, theta=0.0
% INFO    : Bus 5987	: V=1.03492, theta=-14.153007 -> V=1.0, theta=0.0
% INFO    : Bus 5988	: V=1.069038, theta=6.568109 -> V=1.0, theta=0.0
% INFO    : Bus 5989	: V=1.050893, theta=-27.991284 -> V=1.0, theta=0.0
% INFO    : Bus 5990	: V=1.02099, theta=-10.272683 -> V=1.0, theta=0.0
% INFO    : Bus 5991	: V=1.012716, theta=-50.368894 -> V=1.0, theta=0.0
% INFO    : Bus 5992	: V=1.019913, theta=-25.506468 -> V=1.0, theta=0.0
% INFO    : Bus 5993	: V=1.038533, theta=-11.276657 -> V=1.0, theta=0.0
% INFO    : Bus 5994	: V=1.036793, theta=-15.198385 -> V=1.0, theta=0.0
% INFO    : Bus 5995	: V=1.005109, theta=-30.74235 -> V=1.0, theta=0.0
% INFO    : Bus 5996	: V=1.045944, theta=0.092131 -> V=1.0, theta=0.0
% INFO    : Bus 5997	: V=1.039308, theta=-15.177815 -> V=1.0, theta=0.0
% INFO    : Bus 5998	: V=1.02348, theta=6.16016 -> V=1.0, theta=0.0
% INFO    : Bus 5999	: V=1.028607, theta=-33.173086 -> V=1.0, theta=0.0
% INFO    : Bus 6000	: V=1.085353, theta=16.420992 -> V=1.0, theta=0.0
% INFO    : Bus 6001	: V=1.036406, theta=12.673591 -> V=1.0, theta=0.0
% INFO    : Bus 6002	: V=1.028604, theta=-25.606622 -> V=1.0, theta=0.0
% INFO    : Bus 6003	: V=1.011541, theta=-36.739082 -> V=1.0, theta=0.0
% INFO    : Bus 6004	: V=1.059483, theta=-47.950752 -> V=1.0, theta=0.0
% INFO    : Bus 6005	: V=1.102227, theta=-20.658022 -> V=1.0, theta=0.0
% INFO    : Bus 6006	: V=1.061051, theta=-25.469497 -> V=1.0, theta=0.0
% INFO    : Bus 6007	: V=1.064324, theta=-9.14907 -> V=1.0, theta=0.0
% INFO    : Bus 6008	: V=1.009932, theta=11.192575 -> V=1.0, theta=0.0
% INFO    : Bus 6009	: V=1.008404, theta=-51.715229 -> V=1.0, theta=0.0
% INFO    : Bus 6010	: V=1.074075, theta=-23.724285 -> V=1.0, theta=0.0
% INFO    : Bus 6011	: V=1.003207, theta=-18.17065 -> V=1.0, theta=0.0
% INFO    : Bus 6012	: V=0.948971, theta=-29.211036 -> V=1.0, theta=0.0
% INFO    : Bus 6013	: V=0.998514, theta=-36.87879 -> V=1.0, theta=0.0
% INFO    : Bus 6014	: V=1.050964, theta=-1.994212 -> V=1.0, theta=0.0
% INFO    : Bus 6015	: V=1.028227, theta=-1.865839 -> V=1.0, theta=0.0
% INFO    : Bus 6016	: V=0.973172, theta=-53.387565 -> V=1.0, theta=0.0
% INFO    : Bus 6017	: V=1.025236, theta=11.354177 -> V=1.0, theta=0.0
% INFO    : Bus 6018	: V=1.00266, theta=-30.532747 -> V=1.0, theta=0.0
% INFO    : Bus 6019	: V=1.040028, theta=-15.624439 -> V=1.0, theta=0.0
% INFO    : Bus 6020	: V=1.025616, theta=-22.276632 -> V=1.0, theta=0.0
% INFO    : Bus 6021	: V=1.000863, theta=-2.156852 -> V=1.0, theta=0.0
% INFO    : Bus 6022	: V=0.99945, theta=-38.380058 -> V=1.0, theta=0.0
% INFO    : Bus 6023	: V=1.045064, theta=-27.645735 -> V=1.0, theta=0.0
% INFO    : Bus 6024	: V=0.991089, theta=-30.78687 -> V=1.0, theta=0.0
% INFO    : Bus 6025	: V=1.027402, theta=14.331794 -> V=1.0, theta=0.0
% INFO    : Bus 6026	: V=1.044025, theta=-29.510191 -> V=1.0, theta=0.0
% INFO    : Bus 6027	: V=1.028697, theta=18.809566 -> V=1.0, theta=0.0
% INFO    : Bus 6028	: V=1.028186, theta=7.910399 -> V=1.0, theta=0.0
% INFO    : Bus 6029	: V=0.99547, theta=-39.22732 -> V=1.0, theta=0.0
% INFO    : Bus 6030	: V=1.017533, theta=10.839594 -> V=1.0, theta=0.0
% INFO    : Bus 6031	: V=1.044676, theta=-15.800131 -> V=1.0, theta=0.0
% INFO    : Bus 6032	: V=0.980506, theta=-30.314291 -> V=1.0, theta=0.0
% INFO    : Bus 6033	: V=1.013332, theta=-25.393443 -> V=1.0, theta=0.0
% INFO    : Bus 6034	: V=1.03183, theta=-26.239987 -> V=1.0, theta=0.0
% INFO    : Bus 6035	: V=1.01559, theta=-28.206303 -> V=1.0, theta=0.0
% INFO    : Bus 6036	: V=1.036335, theta=-1.030445 -> V=1.0, theta=0.0
% INFO    : Bus 6037	: V=0.996493, theta=-26.971273 -> V=1.0, theta=0.0
% INFO    : Bus 6038	: V=1.040399, theta=-45.85497 -> V=1.0, theta=0.0
% INFO    : Bus 6039	: V=1.037599, theta=-51.305829 -> V=1.0, theta=0.0
% INFO    : Bus 6040	: V=1.02391, theta=-45.47508 -> V=1.0, theta=0.0
% INFO    : Bus 6041	: V=1.068673, theta=-48.196524 -> V=1.0, theta=0.0
% INFO    : Bus 6042	: V=0.935862, theta=-34.589217 -> V=1.0, theta=0.0
% INFO    : Bus 6043	: V=0.966175, theta=-33.849002 -> V=1.0, theta=0.0
% INFO    : Bus 6044	: V=1.033573, theta=-5.804134 -> V=1.0, theta=0.0
% INFO    : Bus 6045	: V=1.017016, theta=-0.831864 -> V=1.0, theta=0.0
% INFO    : Bus 6046	: V=1.094629, theta=-11.855334 -> V=1.0, theta=0.0
% INFO    : Bus 6047	: V=1.020029, theta=8.412898 -> V=1.0, theta=0.0
% INFO    : Bus 6048	: V=0.976107, theta=-30.206932 -> V=1.0, theta=0.0
% INFO    : Bus 6049	: V=1.004227, theta=-8.419176 -> V=1.0, theta=0.0
% INFO    : Bus 6050	: V=1.014473, theta=9.704336 -> V=1.0, theta=0.0
% INFO    : Bus 6051	: V=0.955577, theta=-19.048184 -> V=1.0, theta=0.0
% INFO    : Bus 6052	: V=1.017309, theta=18.203559 -> V=1.0, theta=0.0
% INFO    : Bus 6053	: V=1.050641, theta=-26.961918 -> V=1.0, theta=0.0
% INFO    : Bus 6054	: V=1.040191, theta=-33.020646 -> V=1.0, theta=0.0
% INFO    : Bus 6055	: V=1.032882, theta=-6.143066 -> V=1.0, theta=0.0
% INFO    : Bus 6056	: V=1.058644, theta=-28.636542 -> V=1.0, theta=0.0
% INFO    : Bus 6057	: V=1.022376, theta=-1.911451 -> V=1.0, theta=0.0
% INFO    : Bus 6058	: V=1.037048, theta=8.948628 -> V=1.0, theta=0.0
% INFO    : Bus 6059	: V=1.030759, theta=-39.279516 -> V=1.0, theta=0.0
% INFO    : Bus 6060	: V=1.068745, theta=-38.373468 -> V=1.0, theta=0.0
% INFO    : Bus 6061	: V=1.003609, theta=-32.005398 -> V=1.0, theta=0.0
% INFO    : Bus 6062	: V=1.001227, theta=-26.614531 -> V=1.0, theta=0.0
% INFO    : Bus 6063	: V=1.001285, theta=-27.675348 -> V=1.0, theta=0.0
% INFO    : Bus 6064	: V=1.1702, theta=-20.509705 -> V=1.0, theta=0.0
% INFO    : Bus 6065	: V=1.027429, theta=-20.311759 -> V=1.0, theta=0.0
% INFO    : Bus 6066	: V=1.020695, theta=-12.866151 -> V=1.0, theta=0.0
% INFO    : Bus 6067	: V=1.020339, theta=-36.103606 -> V=1.0, theta=0.0
% INFO    : Bus 6068	: V=1.032737, theta=12.679876 -> V=1.0, theta=0.0
% INFO    : Bus 6069	: V=0.982629, theta=-6.460921 -> V=1.0, theta=0.0
% INFO    : Bus 6070	: V=1.02244, theta=-23.638649 -> V=1.0, theta=0.0
% INFO    : Bus 6071	: V=1.038766, theta=-16.393907 -> V=1.0, theta=0.0
% INFO    : Bus 6072	: V=1.139986, theta=-21.685102 -> V=1.0, theta=0.0
% INFO    : Bus 6073	: V=1.008579, theta=-7.84577 -> V=1.0, theta=0.0
% INFO    : Bus 6074	: V=1.017385, theta=-35.961352 -> V=1.0, theta=0.0
% INFO    : Bus 6075	: V=1.048897, theta=-14.232788 -> V=1.0, theta=0.0
% INFO    : Bus 6076	: V=1.080309, theta=-17.705586 -> V=1.0, theta=0.0
% INFO    : Bus 6077	: V=1.075401, theta=-17.159039 -> V=1.0, theta=0.0
% INFO    : Bus 6078	: V=0.982173, theta=-27.299078 -> V=1.0, theta=0.0
% INFO    : Bus 6079	: V=1.01909, theta=-22.656195 -> V=1.0, theta=0.0
% INFO    : Bus 6080	: V=1.053137, theta=-42.75542 -> V=1.0, theta=0.0
% INFO    : Bus 6081	: V=0.987882, theta=-26.43586 -> V=1.0, theta=0.0
% INFO    : Bus 6082	: V=0.985788, theta=-28.136945 -> V=1.0, theta=0.0
% INFO    : Bus 6083	: V=1.046828, theta=11.879288 -> V=1.0, theta=0.0
% INFO    : Bus 6084	: V=1.01587, theta=66.119603 -> V=1.0, theta=0.0
% INFO    : Bus 6085	: V=1.004991, theta=14.361891 -> V=1.0, theta=0.0
% INFO    : Bus 6086	: V=1.017402, theta=2.4054 -> V=1.0, theta=0.0
% INFO    : Bus 6087	: V=1.013589, theta=-2.829796 -> V=1.0, theta=0.0
% INFO    : Bus 6088	: V=1.069764, theta=4.834103 -> V=1.0, theta=0.0
% INFO    : Bus 6089	: V=1.026807, theta=-34.16069 -> V=1.0, theta=0.0
% INFO    : Bus 6090	: V=1.030088, theta=-39.174845 -> V=1.0, theta=0.0
% INFO    : Bus 6091	: V=1.013386, theta=-11.921046 -> V=1.0, theta=0.0
% INFO    : Bus 6092	: V=1.035378, theta=-39.920989 -> V=1.0, theta=0.0
% INFO    : Bus 6093	: V=1.005956, theta=-41.042922 -> V=1.0, theta=0.0
% INFO    : Bus 6094	: V=1.023585, theta=-29.739277 -> V=1.0, theta=0.0
% INFO    : Bus 6095	: V=1.050059, theta=49.096409 -> V=1.0, theta=0.0
% INFO    : Bus 6096	: V=1.036804, theta=-25.936777 -> V=1.0, theta=0.0
% INFO    : Bus 6097	: V=1.02081, theta=16.80975 -> V=1.0, theta=0.0
% INFO    : Bus 6098	: V=1.112778, theta=-24.13176 -> V=1.0, theta=0.0
% INFO    : Bus 6099	: V=1.045983, theta=-1.585831 -> V=1.0, theta=0.0
% INFO    : Bus 6100	: V=1.041341, theta=0.964908 -> V=1.0, theta=0.0
% INFO    : Bus 6101	: V=1.02371, theta=-10.937212 -> V=1.0, theta=0.0
% INFO    : Bus 6102	: V=1.022422, theta=-29.626211 -> V=1.0, theta=0.0
% INFO    : Bus 6103	: V=1.013429, theta=-21.718838 -> V=1.0, theta=0.0
% INFO    : Bus 6104	: V=1.046851, theta=-12.433827 -> V=1.0, theta=0.0
% INFO    : Bus 6105	: V=1.010683, theta=-27.426254 -> V=1.0, theta=0.0
% INFO    : Bus 6106	: V=0.95515, theta=-30.275609 -> V=1.0, theta=0.0
% INFO    : Bus 6107	: V=1.011511, theta=-36.514878 -> V=1.0, theta=0.0
% INFO    : Bus 6108	: V=1.038751, theta=34.137872 -> V=1.0, theta=0.0
% INFO    : Bus 6109	: V=1.007365, theta=-10.436065 -> V=1.0, theta=0.0
% INFO    : Bus 6110	: V=1.052198, theta=-36.243599 -> V=1.0, theta=0.0
% INFO    : Bus 6111	: V=1.024669, theta=-15.702901 -> V=1.0, theta=0.0
% INFO    : Bus 6112	: V=1.022264, theta=-9.359412 -> V=1.0, theta=0.0
% INFO    : Bus 6113	: V=0.964579, theta=-31.523448 -> V=1.0, theta=0.0
% INFO    : Bus 6114	: V=1.042632, theta=-10.600548 -> V=1.0, theta=0.0
% INFO    : Bus 6115	: V=1.0225, theta=-12.390675 -> V=1.0, theta=0.0
% INFO    : Bus 6116	: V=1.050251, theta=-17.936656 -> V=1.0, theta=0.0
% INFO    : Bus 6117	: V=0.975165, theta=-30.425695 -> V=1.0, theta=0.0
% INFO    : Bus 6118	: V=1.022324, theta=25.507998 -> V=1.0, theta=0.0
% INFO    : Bus 6119	: V=1.036247, theta=-16.100323 -> V=1.0, theta=0.0
% INFO    : Bus 6120	: V=1.024222, theta=20.450903 -> V=1.0, theta=0.0
% INFO    : Bus 6121	: V=1.079735, theta=-22.080279 -> V=1.0, theta=0.0
% INFO    : Bus 6122	: V=1.062638, theta=-21.930056 -> V=1.0, theta=0.0
% INFO    : Bus 6123	: V=1.014472, theta=-14.458656 -> V=1.0, theta=0.0
% INFO    : Bus 6124	: V=1.025031, theta=13.594718 -> V=1.0, theta=0.0
% INFO    : Bus 6125	: V=0.982201, theta=-27.085684 -> V=1.0, theta=0.0
% INFO    : Bus 6126	: V=1.011893, theta=-25.430103 -> V=1.0, theta=0.0
% INFO    : Bus 6127	: V=1.046216, theta=-47.494042 -> V=1.0, theta=0.0
% INFO    : Bus 6128	: V=0.989931, theta=-36.870947 -> V=1.0, theta=0.0
% INFO    : Bus 6129	: V=1.033744, theta=-11.132083 -> V=1.0, theta=0.0
% INFO    : Bus 6130	: V=1.026444, theta=38.067642 -> V=1.0, theta=0.0
% INFO    : Bus 6131	: V=1.133869, theta=18.740277 -> V=1.0, theta=0.0
% INFO    : Bus 6132	: V=1.007513, theta=-48.230416 -> V=1.0, theta=0.0
% INFO    : Bus 6133	: V=1.0405, theta=-25.928997 -> V=1.0, theta=0.0
% INFO    : Bus 6134	: V=1.032343, theta=-53.498271 -> V=1.0, theta=0.0
% INFO    : Bus 6135	: V=0.964329, theta=-56.362142 -> V=1.0, theta=0.0
% INFO    : Bus 6136	: V=1.016978, theta=5.6322 -> V=1.0, theta=0.0
% INFO    : Bus 6137	: V=1.036527, theta=43.984721 -> V=1.0, theta=0.0
% INFO    : Bus 6138	: V=1.010882, theta=-44.602993 -> V=1.0, theta=0.0
% INFO    : Bus 6139	: V=1.058135, theta=0.578948 -> V=1.0, theta=0.0
% INFO    : Bus 6140	: V=1.027477, theta=-38.211715 -> V=1.0, theta=0.0
% INFO    : Bus 6141	: V=1.004979, theta=-28.578928 -> V=1.0, theta=0.0
% INFO    : Bus 6142	: V=1.009131, theta=1.535376 -> V=1.0, theta=0.0
% INFO    : Bus 6143	: V=1.010717, theta=-8.822062 -> V=1.0, theta=0.0
% INFO    : Bus 6144	: V=0.987224, theta=-29.149765 -> V=1.0, theta=0.0
% INFO    : Bus 6145	: V=1.019556, theta=-33.283906 -> V=1.0, theta=0.0
% INFO    : Bus 6146	: V=1.025358, theta=-12.3051 -> V=1.0, theta=0.0
% INFO    : Bus 6147	: V=1.018949, theta=-29.407907 -> V=1.0, theta=0.0
% INFO    : Bus 6148	: V=0.966862, theta=-34.40203 -> V=1.0, theta=0.0
% INFO    : Bus 6149	: V=1.014375, theta=16.388893 -> V=1.0, theta=0.0
% INFO    : Bus 6150	: V=1.015654, theta=-23.507465 -> V=1.0, theta=0.0
% INFO    : Bus 6151	: V=1.027467, theta=-24.374708 -> V=1.0, theta=0.0
% INFO    : Bus 6152	: V=1.014727, theta=53.934674 -> V=1.0, theta=0.0
% INFO    : Bus 6153	: V=1.019885, theta=-14.247746 -> V=1.0, theta=0.0
% INFO    : Bus 6154	: V=1.054274, theta=-29.79948 -> V=1.0, theta=0.0
% INFO    : Bus 6155	: V=0.970396, theta=27.73135 -> V=1.0, theta=0.0
% INFO    : Bus 6156	: V=1.008626, theta=-37.016487 -> V=1.0, theta=0.0
% INFO    : Bus 6157	: V=1.014522, theta=-22.608933 -> V=1.0, theta=0.0
% INFO    : Bus 6158	: V=1.088023, theta=-14.698335 -> V=1.0, theta=0.0
% INFO    : Bus 6159	: V=1.023772, theta=-24.941987 -> V=1.0, theta=0.0
% INFO    : Bus 6160	: V=1.034987, theta=8.210955 -> V=1.0, theta=0.0
% INFO    : Bus 6161	: V=1.023556, theta=-46.171565 -> V=1.0, theta=0.0
% INFO    : Bus 6162	: V=0.991401, theta=-30.700734 -> V=1.0, theta=0.0
% INFO    : Bus 6163	: V=1.031507, theta=-22.306281 -> V=1.0, theta=0.0
% INFO    : Bus 6164	: V=1.063268, theta=12.865238 -> V=1.0, theta=0.0
% INFO    : Bus 6165	: V=0.988879, theta=-31.192112 -> V=1.0, theta=0.0
% INFO    : Bus 6166	: V=1.02932, theta=-6.96665 -> V=1.0, theta=0.0
% INFO    : Bus 6167	: V=1.015226, theta=10.355031 -> V=1.0, theta=0.0
% INFO    : Bus 6168	: V=1.047693, theta=-13.227008 -> V=1.0, theta=0.0
% INFO    : Bus 6169	: V=1.033616, theta=8.6214 -> V=1.0, theta=0.0
% INFO    : Bus 6170	: V=0.997407, theta=-9.164303 -> V=1.0, theta=0.0
% INFO    : Bus 6171	: V=1.017535, theta=20.66908 -> V=1.0, theta=0.0
% INFO    : Bus 6172	: V=0.986605, theta=-23.409457 -> V=1.0, theta=0.0
% INFO    : Bus 6173	: V=1.006283, theta=37.079999 -> V=1.0, theta=0.0
% INFO    : Bus 6174	: V=1.005058, theta=-48.558234 -> V=1.0, theta=0.0
% INFO    : Bus 6175	: V=1.023886, theta=-8.712734 -> V=1.0, theta=0.0
% INFO    : Bus 6176	: V=1.021694, theta=-36.758293 -> V=1.0, theta=0.0
% INFO    : Bus 6177	: V=0.996746, theta=-26.991818 -> V=1.0, theta=0.0
% INFO    : Bus 6178	: V=1.037814, theta=-24.930251 -> V=1.0, theta=0.0
% INFO    : Bus 6179	: V=1.036613, theta=-39.795448 -> V=1.0, theta=0.0
% INFO    : Bus 6180	: V=1.040132, theta=12.738566 -> V=1.0, theta=0.0
% INFO    : Bus 6181	: V=1.000322, theta=-0.775253 -> V=1.0, theta=0.0
% INFO    : Bus 6182	: V=1.054529, theta=-29.782644 -> V=1.0, theta=0.0
% INFO    : Bus 6183	: V=1.027664, theta=-53.950037 -> V=1.0, theta=0.0
% INFO    : Bus 6184	: V=1.005908, theta=-39.513914 -> V=1.0, theta=0.0
% INFO    : Bus 6185	: V=1.016349, theta=-28.570554 -> V=1.0, theta=0.0
% INFO    : Bus 6186	: V=1.027064, theta=-54.149347 -> V=1.0, theta=0.0
% INFO    : Bus 6187	: V=1.051127, theta=-41.658601 -> V=1.0, theta=0.0
% INFO    : Bus 6188	: V=0.980312, theta=-51.312007 -> V=1.0, theta=0.0
% INFO    : Bus 6189	: V=1.0306, theta=-41.007869 -> V=1.0, theta=0.0
% INFO    : Bus 6190	: V=1.044175, theta=-12.838162 -> V=1.0, theta=0.0
% INFO    : Bus 6191	: V=1.010183, theta=-36.984825 -> V=1.0, theta=0.0
% INFO    : Bus 6192	: V=1.023461, theta=-43.410715 -> V=1.0, theta=0.0
% INFO    : Bus 6193	: V=1.008205, theta=-11.819576 -> V=1.0, theta=0.0
% INFO    : Bus 6194	: V=1.023574, theta=-16.503984 -> V=1.0, theta=0.0
% INFO    : Bus 6195	: V=1.015711, theta=-26.359994 -> V=1.0, theta=0.0
% INFO    : Bus 6196	: V=1.048297, theta=-17.424548 -> V=1.0, theta=0.0
% INFO    : Bus 6197	: V=1.021877, theta=-14.540572 -> V=1.0, theta=0.0
% INFO    : Bus 6198	: V=1.022414, theta=-25.277559 -> V=1.0, theta=0.0
% INFO    : Bus 6199	: V=1.069317, theta=-12.830557 -> V=1.0, theta=0.0
% INFO    : Bus 6200	: V=0.970957, theta=-24.095442 -> V=1.0, theta=0.0
% INFO    : Bus 6201	: V=1.049209, theta=-30.350265 -> V=1.0, theta=0.0
% INFO    : Bus 6202	: V=1.043376, theta=3.446178 -> V=1.0, theta=0.0
% INFO    : Bus 6203	: V=1.067351, theta=-27.64379 -> V=1.0, theta=0.0
% INFO    : Bus 6204	: V=1.02934, theta=-21.276092 -> V=1.0, theta=0.0
% INFO    : Bus 6205	: V=1.013865, theta=-22.844663 -> V=1.0, theta=0.0
% INFO    : Bus 6206	: V=1.035075, theta=-0.012484 -> V=1.0, theta=0.0
% INFO    : Bus 6207	: V=1.03672, theta=-13.020576 -> V=1.0, theta=0.0
% INFO    : Bus 6208	: V=1.006088, theta=-27.425904 -> V=1.0, theta=0.0
% INFO    : Bus 6209	: V=1.021564, theta=-48.828688 -> V=1.0, theta=0.0
% INFO    : Bus 6210	: V=1.004535, theta=-22.995135 -> V=1.0, theta=0.0
% INFO    : Bus 6211	: V=1.012162, theta=-10.026558 -> V=1.0, theta=0.0
% INFO    : Bus 6212	: V=1.022578, theta=-5.680793 -> V=1.0, theta=0.0
% INFO    : Bus 6213	: V=0.999721, theta=-27.058885 -> V=1.0, theta=0.0
% INFO    : Bus 6214	: V=1.010006, theta=-35.666762 -> V=1.0, theta=0.0
% INFO    : Bus 6215	: V=1.014717, theta=-32.253715 -> V=1.0, theta=0.0
% INFO    : Bus 6216	: V=1.005661, theta=-36.701716 -> V=1.0, theta=0.0
% INFO    : Bus 6217	: V=1.033582, theta=-44.088027 -> V=1.0, theta=0.0
% INFO    : Bus 6218	: V=1.026244, theta=4.343265 -> V=1.0, theta=0.0
% INFO    : Bus 6219	: V=1.028453, theta=-13.059302 -> V=1.0, theta=0.0
% INFO    : Bus 6220	: V=1.051531, theta=-23.264883 -> V=1.0, theta=0.0
% INFO    : Bus 6221	: V=1.035504, theta=58.917069 -> V=1.0, theta=0.0
% INFO    : Bus 6222	: V=1.068025, theta=52.94959 -> V=1.0, theta=0.0
% INFO    : Bus 6223	: V=0.93559, theta=-33.413173 -> V=1.0, theta=0.0
% INFO    : Bus 6224	: V=0.997449, theta=-13.147218 -> V=1.0, theta=0.0
% INFO    : Bus 6225	: V=1.057364, theta=-20.767128 -> V=1.0, theta=0.0
% INFO    : Bus 6226	: V=1.001311, theta=-31.160904 -> V=1.0, theta=0.0
% INFO    : Bus 6227	: V=1.024457, theta=18.973752 -> V=1.0, theta=0.0
% INFO    : Bus 6228	: V=1.002508, theta=0.870952 -> V=1.0, theta=0.0
% INFO    : Bus 6229	: V=1.002315, theta=-43.161864 -> V=1.0, theta=0.0
% INFO    : Bus 6230	: V=0.970755, theta=-32.184776 -> V=1.0, theta=0.0
% INFO    : Bus 6231	: V=1.03265, theta=-8.086069 -> V=1.0, theta=0.0
% INFO    : Bus 6232	: V=1.038527, theta=-26.132776 -> V=1.0, theta=0.0
% INFO    : Bus 6233	: V=1.017658, theta=6.086699 -> V=1.0, theta=0.0
% INFO    : Bus 6234	: V=1.004663, theta=-18.337725 -> V=1.0, theta=0.0
% INFO    : Bus 6235	: V=1.089698, theta=-27.989026 -> V=1.0, theta=0.0
% INFO    : Bus 6236	: V=1.020252, theta=-14.638927 -> V=1.0, theta=0.0
% INFO    : Bus 6237	: V=1.01301, theta=-24.427366 -> V=1.0, theta=0.0
% INFO    : Bus 6238	: V=1.048493, theta=0.180714 -> V=1.0, theta=0.0
% INFO    : Bus 6239	: V=1.026501, theta=-45.304593 -> V=1.0, theta=0.0
% INFO    : Bus 6240	: V=1.071299, theta=-34.524554 -> V=1.0, theta=0.0
% INFO    : Bus 6241	: V=1.013864, theta=-32.762942 -> V=1.0, theta=0.0
% INFO    : Bus 6242	: V=1.018892, theta=-22.911651 -> V=1.0, theta=0.0
% INFO    : Bus 6243	: V=1.033075, theta=-44.53921 -> V=1.0, theta=0.0
% INFO    : Bus 6244	: V=0.975696, theta=-50.033323 -> V=1.0, theta=0.0
% INFO    : Bus 6245	: V=1.081036, theta=-13.340032 -> V=1.0, theta=0.0
% INFO    : Bus 6246	: V=1.019835, theta=-37.533438 -> V=1.0, theta=0.0
% INFO    : Bus 6247	: V=0.999875, theta=-27.889716 -> V=1.0, theta=0.0
% INFO    : Bus 6248	: V=1.115298, theta=-23.607239 -> V=1.0, theta=0.0
% INFO    : Bus 6249	: V=1.040939, theta=-41.872191 -> V=1.0, theta=0.0
% INFO    : Bus 6250	: V=0.974648, theta=-24.580743 -> V=1.0, theta=0.0
% INFO    : Bus 6251	: V=1.06817, theta=-3.174976 -> V=1.0, theta=0.0
% INFO    : Bus 6252	: V=1.019466, theta=-30.39953 -> V=1.0, theta=0.0
% INFO    : Bus 6253	: V=1.038769, theta=-26.091528 -> V=1.0, theta=0.0
% INFO    : Bus 6254	: V=0.985623, theta=-55.089132 -> V=1.0, theta=0.0
% INFO    : Bus 6255	: V=1.08589, theta=-36.686255 -> V=1.0, theta=0.0
% INFO    : Bus 6256	: V=1.08226, theta=-21.155278 -> V=1.0, theta=0.0
% INFO    : Bus 6257	: V=1.128073, theta=-23.762504 -> V=1.0, theta=0.0
% INFO    : Bus 6258	: V=1.017726, theta=-22.318199 -> V=1.0, theta=0.0
% INFO    : Bus 6259	: V=1.022938, theta=-25.672006 -> V=1.0, theta=0.0
% INFO    : Bus 6260	: V=0.989904, theta=-28.489073 -> V=1.0, theta=0.0
% INFO    : Bus 6261	: V=1.022722, theta=-54.933363 -> V=1.0, theta=0.0
% INFO    : Bus 6262	: V=1.018884, theta=-28.554307 -> V=1.0, theta=0.0
% INFO    : Bus 6263	: V=1.033114, theta=12.718572 -> V=1.0, theta=0.0
% INFO    : Bus 6264	: V=0.99319, theta=-28.514207 -> V=1.0, theta=0.0
% INFO    : Bus 6265	: V=1.001672, theta=-26.56415 -> V=1.0, theta=0.0
% INFO    : Bus 6266	: V=1.009675, theta=-22.744437 -> V=1.0, theta=0.0
% INFO    : Bus 6267	: V=1.038786, theta=-24.721929 -> V=1.0, theta=0.0
% INFO    : Bus 6268	: V=1.028758, theta=-10.98801 -> V=1.0, theta=0.0
% INFO    : Bus 6269	: V=1.017159, theta=-21.800592 -> V=1.0, theta=0.0
% INFO    : Bus 6270	: V=1.02754, theta=-20.916236 -> V=1.0, theta=0.0
% INFO    : Bus 6271	: V=1.049467, theta=-20.418725 -> V=1.0, theta=0.0
% INFO    : Bus 6272	: V=1.045219, theta=38.225194 -> V=1.0, theta=0.0
% INFO    : Bus 6273	: V=1.007417, theta=-41.689181 -> V=1.0, theta=0.0
% INFO    : Bus 6274	: V=1.014048, theta=-14.184814 -> V=1.0, theta=0.0
% INFO    : Bus 6275	: V=1.014286, theta=-5.040216 -> V=1.0, theta=0.0
% INFO    : Bus 6276	: V=1.002585, theta=-34.537706 -> V=1.0, theta=0.0
% INFO    : Bus 6277	: V=1.009854, theta=-23.52965 -> V=1.0, theta=0.0
% INFO    : Bus 6278	: V=1.010298, theta=-29.886387 -> V=1.0, theta=0.0
% INFO    : Bus 6279	: V=1.008432, theta=-26.417695 -> V=1.0, theta=0.0
% INFO    : Bus 6280	: V=1.017343, theta=-33.741034 -> V=1.0, theta=0.0
% INFO    : Bus 6281	: V=1.02011, theta=0.909328 -> V=1.0, theta=0.0
% INFO    : Bus 6282	: V=1.041347, theta=25.837851 -> V=1.0, theta=0.0
% INFO    : Bus 6283	: V=1.041071, theta=15.4593 -> V=1.0, theta=0.0
% INFO    : Bus 6284	: V=1.057119, theta=52.656319 -> V=1.0, theta=0.0
% INFO    : Bus 6285	: V=0.992621, theta=-27.394743 -> V=1.0, theta=0.0
% INFO    : Bus 6286	: V=1.034293, theta=38.874729 -> V=1.0, theta=0.0
% INFO    : Bus 6287	: V=1.038228, theta=-0.750536 -> V=1.0, theta=0.0
% INFO    : Bus 6288	: V=1.021175, theta=-3.901 -> V=1.0, theta=0.0
% INFO    : Bus 6289	: V=1.023817, theta=-1.557372 -> V=1.0, theta=0.0
% INFO    : Bus 6290	: V=1.054471, theta=-13.30135 -> V=1.0, theta=0.0
% INFO    : Bus 6291	: V=1.036939, theta=-24.369757 -> V=1.0, theta=0.0
% INFO    : Bus 6292	: V=1.035234, theta=-48.988617 -> V=1.0, theta=0.0
% INFO    : Bus 6293	: V=0.998042, theta=-4.763116 -> V=1.0, theta=0.0
% INFO    : Bus 6294	: V=1.001876, theta=1.535738 -> V=1.0, theta=0.0
% INFO    : Bus 6295	: V=1.047998, theta=8.46211 -> V=1.0, theta=0.0
% INFO    : Bus 6296	: V=1.028373, theta=-24.381207 -> V=1.0, theta=0.0
% INFO    : Bus 6297	: V=1.026195, theta=-25.005607 -> V=1.0, theta=0.0
% INFO    : Bus 6298	: V=1.046599, theta=-48.609726 -> V=1.0, theta=0.0
% INFO    : Bus 6299	: V=1.044484, theta=-45.095059 -> V=1.0, theta=0.0
% INFO    : Bus 6300	: V=1.005743, theta=-20.134354 -> V=1.0, theta=0.0
% INFO    : Bus 6301	: V=1.055283, theta=-29.297904 -> V=1.0, theta=0.0
% INFO    : Bus 6302	: V=1.019087, theta=-29.180313 -> V=1.0, theta=0.0
% INFO    : Bus 6303	: V=0.996209, theta=-51.087726 -> V=1.0, theta=0.0
% INFO    : Bus 6304	: V=1.031791, theta=-24.727457 -> V=1.0, theta=0.0
% INFO    : Bus 6305	: V=0.918517, theta=-36.137209 -> V=1.0, theta=0.0
% INFO    : Bus 6306	: V=1.0745, theta=-24.576742 -> V=1.0, theta=0.0
% INFO    : Bus 6307	: V=1.015778, theta=-17.48363 -> V=1.0, theta=0.0
% INFO    : Bus 6308	: V=1.040265, theta=-25.881678 -> V=1.0, theta=0.0
% INFO    : Bus 6309	: V=1.014099, theta=-32.864305 -> V=1.0, theta=0.0
% INFO    : Bus 6310	: V=1.012343, theta=-33.151582 -> V=1.0, theta=0.0
% INFO    : Bus 6311	: V=0.968737, theta=-43.487953 -> V=1.0, theta=0.0
% INFO    : Bus 6312	: V=1.035023, theta=-13.116164 -> V=1.0, theta=0.0
% INFO    : Bus 6313	: V=1.028849, theta=-24.275998 -> V=1.0, theta=0.0
% INFO    : Bus 6314	: V=1.047653, theta=-25.220007 -> V=1.0, theta=0.0
% INFO    : Bus 6315	: V=0.985882, theta=-43.369761 -> V=1.0, theta=0.0
% INFO    : Bus 6316	: V=1.021233, theta=-41.921847 -> V=1.0, theta=0.0
% INFO    : Bus 6317	: V=1.062566, theta=-22.918964 -> V=1.0, theta=0.0
% INFO    : Bus 6318	: V=0.994817, theta=-32.037385 -> V=1.0, theta=0.0
% INFO    : Bus 6319	: V=1.065832, theta=-17.36782 -> V=1.0, theta=0.0
% INFO    : Bus 6320	: V=1.03099, theta=3.60651 -> V=1.0, theta=0.0
% INFO    : Bus 6321	: V=0.999268, theta=10.486422 -> V=1.0, theta=0.0
% INFO    : Bus 6322	: V=0.952053, theta=-33.603403 -> V=1.0, theta=0.0
% INFO    : Bus 6323	: V=1.014377, theta=2.339782 -> V=1.0, theta=0.0
% INFO    : Bus 6324	: V=1.004665, theta=-24.090363 -> V=1.0, theta=0.0
% INFO    : Bus 6325	: V=1.010867, theta=-2.924483 -> V=1.0, theta=0.0
% INFO    : Bus 6326	: V=1.039285, theta=9.023334 -> V=1.0, theta=0.0
% INFO    : Bus 6327	: V=0.994681, theta=-50.394002 -> V=1.0, theta=0.0
% INFO    : Bus 6328	: V=1.010196, theta=-30.742157 -> V=1.0, theta=0.0
% INFO    : Bus 6329	: V=0.991058, theta=-44.553431 -> V=1.0, theta=0.0
% INFO    : Bus 6330	: V=1.018101, theta=-32.158935 -> V=1.0, theta=0.0
% INFO    : Bus 6331	: V=1.050971, theta=-0.912749 -> V=1.0, theta=0.0
% INFO    : Bus 6332	: V=1.065904, theta=-11.688816 -> V=1.0, theta=0.0
% INFO    : Bus 6333	: V=1.008527, theta=-41.358456 -> V=1.0, theta=0.0
% INFO    : Bus 6334	: V=1.005334, theta=-50.248843 -> V=1.0, theta=0.0
% INFO    : Bus 6335	: V=1.021846, theta=-25.530587 -> V=1.0, theta=0.0
% INFO    : Bus 6336	: V=1.014144, theta=8.984849 -> V=1.0, theta=0.0
% INFO    : Bus 6337	: V=1.087363, theta=-9.876082 -> V=1.0, theta=0.0
% INFO    : Bus 6338	: V=1.022507, theta=-26.966389 -> V=1.0, theta=0.0
% INFO    : Bus 6339	: V=0.967776, theta=-30.269237 -> V=1.0, theta=0.0
% INFO    : Bus 6340	: V=1.052729, theta=-45.804866 -> V=1.0, theta=0.0
% INFO    : Bus 6341	: V=0.997693, theta=-26.954942 -> V=1.0, theta=0.0
% INFO    : Bus 6342	: V=1.036453, theta=17.18525 -> V=1.0, theta=0.0
% INFO    : Bus 6343	: V=1.029324, theta=5.16207 -> V=1.0, theta=0.0
% INFO    : Bus 6344	: V=1.019574, theta=-44.356473 -> V=1.0, theta=0.0
% INFO    : Bus 6345	: V=1.00913, theta=8.083384 -> V=1.0, theta=0.0
% INFO    : Bus 6346	: V=1.031575, theta=-37.915148 -> V=1.0, theta=0.0
% INFO    : Bus 6347	: V=1.027292, theta=-29.311327 -> V=1.0, theta=0.0
% INFO    : Bus 6348	: V=1.025206, theta=-30.620221 -> V=1.0, theta=0.0
% INFO    : Bus 6349	: V=1.019543, theta=-48.799658 -> V=1.0, theta=0.0
% INFO    : Bus 6350	: V=1.015073, theta=-27.645206 -> V=1.0, theta=0.0
% INFO    : Bus 6351	: V=1.0521, theta=-16.751466 -> V=1.0, theta=0.0
% INFO    : Bus 6352	: V=0.975717, theta=-33.254967 -> V=1.0, theta=0.0
% INFO    : Bus 6353	: V=0.998324, theta=-24.595489 -> V=1.0, theta=0.0
% INFO    : Bus 6354	: V=1.038149, theta=6.223478 -> V=1.0, theta=0.0
% INFO    : Bus 6355	: V=1.066746, theta=-28.057054 -> V=1.0, theta=0.0
% INFO    : Bus 6356	: V=1.018984, theta=6.965976 -> V=1.0, theta=0.0
% INFO    : Bus 6357	: V=0.986348, theta=-24.831394 -> V=1.0, theta=0.0
% INFO    : Bus 6358	: V=0.986287, theta=-33.260386 -> V=1.0, theta=0.0
% INFO    : Bus 6359	: V=1.023774, theta=-54.379092 -> V=1.0, theta=0.0
% INFO    : Bus 6360	: V=1.080589, theta=-21.471577 -> V=1.0, theta=0.0
% INFO    : Bus 6361	: V=0.974587, theta=-32.126019 -> V=1.0, theta=0.0
% INFO    : Bus 6362	: V=1.059022, theta=-38.046681 -> V=1.0, theta=0.0
% INFO    : Bus 6363	: V=0.983651, theta=-16.099618 -> V=1.0, theta=0.0
% INFO    : Bus 6364	: V=1.025309, theta=-29.308119 -> V=1.0, theta=0.0
% INFO    : Bus 6365	: V=1.056272, theta=-29.780742 -> V=1.0, theta=0.0
% INFO    : Bus 6366	: V=1.077817, theta=8.163184 -> V=1.0, theta=0.0
% INFO    : Bus 6367	: V=0.988789, theta=-15.148376 -> V=1.0, theta=0.0
% INFO    : Bus 6368	: V=1.042432, theta=-8.519581 -> V=1.0, theta=0.0
% INFO    : Bus 6369	: V=1.031063, theta=18.744746 -> V=1.0, theta=0.0
% INFO    : Bus 6370	: V=1.014839, theta=-20.352422 -> V=1.0, theta=0.0
% INFO    : Bus 6371	: V=1.045225, theta=-0.934949 -> V=1.0, theta=0.0
% INFO    : Bus 6372	: V=0.999992, theta=-36.806485 -> V=1.0, theta=0.0
% INFO    : Bus 6373	: V=1.04869, theta=-2.774001 -> V=1.0, theta=0.0
% INFO    : Bus 6374	: V=1.077431, theta=59.335183 -> V=1.0, theta=0.0
% INFO    : Bus 6375	: V=1.022959, theta=-25.302017 -> V=1.0, theta=0.0
% INFO    : Bus 6376	: V=1.044986, theta=-0.4155 -> V=1.0, theta=0.0
% INFO    : Bus 6377	: V=0.962313, theta=-37.255005 -> V=1.0, theta=0.0
% INFO    : Bus 6378	: V=1.00561, theta=-36.784313 -> V=1.0, theta=0.0
% INFO    : Bus 6379	: V=1.035545, theta=-1.331734 -> V=1.0, theta=0.0
% INFO    : Bus 6380	: V=1.060164, theta=-26.992958 -> V=1.0, theta=0.0
% INFO    : Bus 6381	: V=0.9827, theta=-56.788513 -> V=1.0, theta=0.0
% INFO    : Bus 6382	: V=1.038313, theta=-9.903026 -> V=1.0, theta=0.0
% INFO    : Bus 6383	: V=1.013232, theta=22.32879 -> V=1.0, theta=0.0
% INFO    : Bus 6384	: V=1.041723, theta=-1.727757 -> V=1.0, theta=0.0
% INFO    : Bus 6385	: V=0.996222, theta=-27.549163 -> V=1.0, theta=0.0
% INFO    : Bus 6386	: V=1.033209, theta=-11.212932 -> V=1.0, theta=0.0
% INFO    : Bus 6387	: V=1.042671, theta=-35.832808 -> V=1.0, theta=0.0
% INFO    : Bus 6388	: V=1.00708, theta=-26.130031 -> V=1.0, theta=0.0
% INFO    : Bus 6389	: V=0.961942, theta=-31.67051 -> V=1.0, theta=0.0
% INFO    : Bus 6390	: V=1.059508, theta=-47.950975 -> V=1.0, theta=0.0
% INFO    : Bus 6391	: V=1.017321, theta=62.550015 -> V=1.0, theta=0.0
% INFO    : Bus 6392	: V=1.024028, theta=-25.903809 -> V=1.0, theta=0.0
% INFO    : Bus 6393	: V=1.018797, theta=6.838622 -> V=1.0, theta=0.0
% INFO    : Bus 6394	: V=1.019286, theta=-46.504574 -> V=1.0, theta=0.0
% INFO    : Bus 6395	: V=1.027426, theta=8.00829 -> V=1.0, theta=0.0
% INFO    : Bus 6396	: V=0.893322, theta=-35.880472 -> V=1.0, theta=0.0
% INFO    : Bus 6397	: V=1.019958, theta=-42.190769 -> V=1.0, theta=0.0
% INFO    : Bus 6398	: V=1.016121, theta=-13.243746 -> V=1.0, theta=0.0
% INFO    : Bus 6399	: V=1.022592, theta=-1.581502 -> V=1.0, theta=0.0
% INFO    : Bus 6400	: V=1.03561, theta=1.947556 -> V=1.0, theta=0.0
% INFO    : Bus 6401	: V=1.036279, theta=7.07135 -> V=1.0, theta=0.0
% INFO    : Bus 6402	: V=1.033159, theta=-33.633581 -> V=1.0, theta=0.0
% INFO    : Bus 6403	: V=1.020309, theta=-4.088178 -> V=1.0, theta=0.0
% INFO    : Bus 6404	: V=0.96858, theta=-37.394208 -> V=1.0, theta=0.0
% INFO    : Bus 6405	: V=1.014784, theta=-16.214284 -> V=1.0, theta=0.0
% INFO    : Bus 6406	: V=0.984677, theta=-22.684523 -> V=1.0, theta=0.0
% INFO    : Bus 6407	: V=1.043751, theta=-3.07285 -> V=1.0, theta=0.0
% INFO    : Bus 6408	: V=1.053672, theta=-15.757992 -> V=1.0, theta=0.0
% INFO    : Bus 6409	: V=0.968577, theta=-29.817241 -> V=1.0, theta=0.0
% INFO    : Bus 6410	: V=1.044406, theta=2.065252 -> V=1.0, theta=0.0
% INFO    : Bus 6411	: V=1.020974, theta=-23.843324 -> V=1.0, theta=0.0
% INFO    : Bus 6412	: V=0.909668, theta=-36.192665 -> V=1.0, theta=0.0
% INFO    : Bus 6413	: V=1.044796, theta=1.632047 -> V=1.0, theta=0.0
% INFO    : Bus 6414	: V=1.013181, theta=-9.318163 -> V=1.0, theta=0.0
% INFO    : Bus 6415	: V=0.983673, theta=-38.669395 -> V=1.0, theta=0.0
% INFO    : Bus 6416	: V=1.04044, theta=-9.7577 -> V=1.0, theta=0.0
% INFO    : Bus 6417	: V=0.991065, theta=-34.243743 -> V=1.0, theta=0.0
% INFO    : Bus 6418	: V=1.028356, theta=7.81585 -> V=1.0, theta=0.0
% INFO    : Bus 6419	: V=1.095905, theta=16.059867 -> V=1.0, theta=0.0
% INFO    : Bus 6420	: V=0.920126, theta=-35.646845 -> V=1.0, theta=0.0
% INFO    : Bus 6421	: V=1.056443, theta=-3.058176 -> V=1.0, theta=0.0
% INFO    : Bus 6422	: V=0.964839, theta=-29.645443 -> V=1.0, theta=0.0
% INFO    : Bus 6423	: V=1.014849, theta=-4.843274 -> V=1.0, theta=0.0
% INFO    : Bus 6424	: V=1.048288, theta=18.202614 -> V=1.0, theta=0.0
% INFO    : Bus 6425	: V=1.014064, theta=-32.843762 -> V=1.0, theta=0.0
% INFO    : Bus 6426	: V=1.053076, theta=1.410155 -> V=1.0, theta=0.0
% INFO    : Bus 6427	: V=1.000068, theta=-13.384209 -> V=1.0, theta=0.0
% INFO    : Bus 6428	: V=1.013807, theta=-32.593868 -> V=1.0, theta=0.0
% INFO    : Bus 6429	: V=1.035857, theta=-18.645859 -> V=1.0, theta=0.0
% INFO    : Bus 6430	: V=1.048821, theta=-29.228272 -> V=1.0, theta=0.0
% INFO    : Bus 6431	: V=1.032381, theta=-33.705099 -> V=1.0, theta=0.0
% INFO    : Bus 6432	: V=1.049448, theta=65.665542 -> V=1.0, theta=0.0
% INFO    : Bus 6433	: V=0.987316, theta=-35.155752 -> V=1.0, theta=0.0
% INFO    : Bus 6434	: V=1.116905, theta=-11.690075 -> V=1.0, theta=0.0
% INFO    : Bus 6435	: V=1.007686, theta=-36.096522 -> V=1.0, theta=0.0
% INFO    : Bus 6436	: V=1.01064, theta=-48.505837 -> V=1.0, theta=0.0
% INFO    : Bus 6437	: V=1.036921, theta=-30.618148 -> V=1.0, theta=0.0
% INFO    : Bus 6438	: V=0.981335, theta=6.382274 -> V=1.0, theta=0.0
% INFO    : Bus 6439	: V=1.023634, theta=5.250321 -> V=1.0, theta=0.0
% INFO    : Bus 6440	: V=1.023785, theta=37.6441 -> V=1.0, theta=0.0
% INFO    : Bus 6441	: V=0.980843, theta=-27.928734 -> V=1.0, theta=0.0
% INFO    : Bus 6442	: V=1.028268, theta=11.682241 -> V=1.0, theta=0.0
% INFO    : Bus 6443	: V=1.022415, theta=-49.843209 -> V=1.0, theta=0.0
% INFO    : Bus 6444	: V=1.043159, theta=-28.591602 -> V=1.0, theta=0.0
% INFO    : Bus 6445	: V=1.056723, theta=-22.024824 -> V=1.0, theta=0.0
% INFO    : Bus 6446	: V=1.051187, theta=-11.794001 -> V=1.0, theta=0.0
% INFO    : Bus 6447	: V=1.033662, theta=-33.869271 -> V=1.0, theta=0.0
% INFO    : Bus 6448	: V=1.004995, theta=-32.51982 -> V=1.0, theta=0.0
% INFO    : Bus 6449	: V=1.075881, theta=-24.985626 -> V=1.0, theta=0.0
% INFO    : Bus 6450	: V=1.008104, theta=-10.991611 -> V=1.0, theta=0.0
% INFO    : Bus 6451	: V=1.024441, theta=-13.686948 -> V=1.0, theta=0.0
% INFO    : Bus 6452	: V=1.010648, theta=-6.914115 -> V=1.0, theta=0.0
% INFO    : Bus 6453	: V=1.047048, theta=-18.507778 -> V=1.0, theta=0.0
% INFO    : Bus 6454	: V=1.024026, theta=-54.339495 -> V=1.0, theta=0.0
% INFO    : Bus 6455	: V=1.034211, theta=-22.39971 -> V=1.0, theta=0.0
% INFO    : Bus 6456	: V=1.020407, theta=-47.323325 -> V=1.0, theta=0.0
% INFO    : Bus 6457	: V=1.058488, theta=21.135353 -> V=1.0, theta=0.0
% INFO    : Bus 6458	: V=1.078056, theta=56.614172 -> V=1.0, theta=0.0
% INFO    : Bus 6459	: V=1.005175, theta=-38.615882 -> V=1.0, theta=0.0
% INFO    : Bus 6460	: V=1.043918, theta=-31.79712 -> V=1.0, theta=0.0
% INFO    : Bus 6461	: V=1.062223, theta=-27.058127 -> V=1.0, theta=0.0
% INFO    : Bus 6462	: V=1.013876, theta=0.058271 -> V=1.0, theta=0.0
% INFO    : Bus 6463	: V=1.016941, theta=-24.028219 -> V=1.0, theta=0.0
% INFO    : Bus 6464	: V=1.034962, theta=-25.817629 -> V=1.0, theta=0.0
% INFO    : Bus 6465	: V=1.002795, theta=-30.602319 -> V=1.0, theta=0.0
% INFO    : Bus 6466	: V=1.085178, theta=45.265218 -> V=1.0, theta=0.0
% INFO    : Bus 6467	: V=1.013131, theta=-2.607288 -> V=1.0, theta=0.0
% INFO    : Bus 6468	: V=1.052987, theta=8.023458 -> V=1.0, theta=0.0
% INFO    : Bus 6469	: V=1.031686, theta=48.420935 -> V=1.0, theta=0.0
% INFO    : Bus 6470	: V=1.013845, theta=13.946269 -> V=1.0, theta=0.0
% INFO    : Bus 6471	: V=1.008088, theta=-30.00138 -> V=1.0, theta=0.0
% INFO    : Bus 6472	: V=1.038332, theta=-24.365225 -> V=1.0, theta=0.0
% INFO    : Bus 6473	: V=1.02296, theta=4.124025 -> V=1.0, theta=0.0
% INFO    : Bus 6474	: V=1.055298, theta=-8.059073 -> V=1.0, theta=0.0
% INFO    : Bus 6475	: V=1.02402, theta=-8.915069 -> V=1.0, theta=0.0
% INFO    : Bus 6476	: V=1.026494, theta=0.885319 -> V=1.0, theta=0.0
% INFO    : Bus 6477	: V=1.028909, theta=20.742007 -> V=1.0, theta=0.0
% INFO    : Bus 6478	: V=1.009054, theta=-14.629451 -> V=1.0, theta=0.0
% INFO    : Bus 6479	: V=0.985639, theta=-32.451664 -> V=1.0, theta=0.0
% INFO    : Bus 6480	: V=1.018493, theta=2.360002 -> V=1.0, theta=0.0
% INFO    : Bus 6481	: V=1.058624, theta=-17.551184 -> V=1.0, theta=0.0
% INFO    : Bus 6482	: V=1.032857, theta=-43.819875 -> V=1.0, theta=0.0
% INFO    : Bus 6483	: V=1.064876, theta=-20.928891 -> V=1.0, theta=0.0
% INFO    : Bus 6484	: V=1.024853, theta=-45.979688 -> V=1.0, theta=0.0
% INFO    : Bus 6485	: V=1.024272, theta=-9.6072 -> V=1.0, theta=0.0
% INFO    : Bus 6486	: V=1.046967, theta=-4.241061 -> V=1.0, theta=0.0
% INFO    : Bus 6487	: V=0.989539, theta=-24.431575 -> V=1.0, theta=0.0
% INFO    : Bus 6488	: V=1.037157, theta=-1.340065 -> V=1.0, theta=0.0
% INFO    : Bus 6489	: V=1.079806, theta=31.595391 -> V=1.0, theta=0.0
% INFO    : Bus 6490	: V=1.021192, theta=-53.017221 -> V=1.0, theta=0.0
% INFO    : Bus 6491	: V=1.097271, theta=-27.582868 -> V=1.0, theta=0.0
% INFO    : Bus 6492	: V=1.004319, theta=65.867968 -> V=1.0, theta=0.0
% INFO    : Bus 6493	: V=0.966345, theta=-32.483962 -> V=1.0, theta=0.0
% INFO    : Bus 6494	: V=1.054522, theta=-41.983931 -> V=1.0, theta=0.0
% INFO    : Bus 6495	: V=1.039608, theta=-22.065882 -> V=1.0, theta=0.0
% INFO    : Bus 6496	: V=1.057457, theta=-41.559059 -> V=1.0, theta=0.0
% INFO    : Bus 6497	: V=1.064333, theta=34.261506 -> V=1.0, theta=0.0
% INFO    : Bus 6498	: V=1.019, theta=7.11935 -> V=1.0, theta=0.0
% INFO    : Bus 6499	: V=1.04354, theta=-45.399854 -> V=1.0, theta=0.0
% INFO    : Bus 6500	: V=1.068208, theta=-23.335816 -> V=1.0, theta=0.0
% INFO    : Bus 6501	: V=1.000879, theta=-31.297345 -> V=1.0, theta=0.0
% INFO    : Bus 6502	: V=1.002332, theta=-31.18928 -> V=1.0, theta=0.0
% INFO    : Bus 6503	: V=1.067733, theta=-16.878507 -> V=1.0, theta=0.0
% INFO    : Bus 6504	: V=1.001777, theta=-45.153023 -> V=1.0, theta=0.0
% INFO    : Bus 6505	: V=1.055869, theta=-26.396286 -> V=1.0, theta=0.0
% INFO    : Bus 6506	: V=1.013914, theta=61.440605 -> V=1.0, theta=0.0
% INFO    : Bus 6507	: V=1.02202, theta=2.511103 -> V=1.0, theta=0.0
% INFO    : Bus 6508	: V=1.028383, theta=2.026329 -> V=1.0, theta=0.0
% INFO    : Bus 6509	: V=1.014496, theta=-22.612039 -> V=1.0, theta=0.0
% INFO    : Bus 6510	: V=1.050766, theta=-26.818777 -> V=1.0, theta=0.0
% INFO    : Bus 6511	: V=1.014563, theta=-31.538546 -> V=1.0, theta=0.0
% INFO    : Bus 6512	: V=0.989658, theta=-54.467029 -> V=1.0, theta=0.0
% INFO    : Bus 6513	: V=0.981051, theta=-18.068546 -> V=1.0, theta=0.0
% INFO    : Bus 6514	: V=1.043803, theta=6.060087 -> V=1.0, theta=0.0
% INFO    : Bus 6515	: V=0.959609, theta=-34.477699 -> V=1.0, theta=0.0
% INFO    : Bus 6516	: V=1.050158, theta=-3.806608 -> V=1.0, theta=0.0
% INFO    : Bus 6517	: V=0.997296, theta=-27.836517 -> V=1.0, theta=0.0
% INFO    : Bus 6518	: V=0.999167, theta=8.848426 -> V=1.0, theta=0.0
% INFO    : Bus 6519	: V=1.023884, theta=11.17255 -> V=1.0, theta=0.0
% INFO    : Bus 6520	: V=1.037031, theta=-26.556733 -> V=1.0, theta=0.0
% INFO    : Bus 6521	: V=1.044234, theta=-4.960268 -> V=1.0, theta=0.0
% INFO    : Bus 6522	: V=0.994852, theta=-24.893891 -> V=1.0, theta=0.0
% INFO    : Bus 6523	: V=1.028745, theta=-8.319493 -> V=1.0, theta=0.0
% INFO    : Bus 6524	: V=1.035962, theta=13.048122 -> V=1.0, theta=0.0
% INFO    : Bus 6525	: V=1.007591, theta=-11.130613 -> V=1.0, theta=0.0
% INFO    : Bus 6526	: V=1.020731, theta=12.405464 -> V=1.0, theta=0.0
% INFO    : Bus 6527	: V=1.060073, theta=-27.001207 -> V=1.0, theta=0.0
% INFO    : Bus 6528	: V=1.008749, theta=-36.396484 -> V=1.0, theta=0.0
% INFO    : Bus 6529	: V=1.015578, theta=-39.22214 -> V=1.0, theta=0.0
% INFO    : Bus 6530	: V=1.025164, theta=-40.667466 -> V=1.0, theta=0.0
% INFO    : Bus 6531	: V=1.038415, theta=-33.058858 -> V=1.0, theta=0.0
% INFO    : Bus 6532	: V=1.067601, theta=-31.837785 -> V=1.0, theta=0.0
% INFO    : Bus 6533	: V=1.08443, theta=-36.845222 -> V=1.0, theta=0.0
% INFO    : Bus 6534	: V=1.031932, theta=-26.167183 -> V=1.0, theta=0.0
% INFO    : Bus 6535	: V=1.022792, theta=-0.959174 -> V=1.0, theta=0.0
% INFO    : Bus 6536	: V=1.015099, theta=-22.497253 -> V=1.0, theta=0.0
% INFO    : Bus 6537	: V=1.033133, theta=-24.344337 -> V=1.0, theta=0.0
% INFO    : Bus 6538	: V=1.0642, theta=56.438431 -> V=1.0, theta=0.0
% INFO    : Bus 6539	: V=1.01829, theta=0.554314 -> V=1.0, theta=0.0
% INFO    : Bus 6540	: V=0.991423, theta=-36.809297 -> V=1.0, theta=0.0
% INFO    : Bus 6541	: V=1.019739, theta=-9.491578 -> V=1.0, theta=0.0
% INFO    : Bus 6542	: V=1.033854, theta=-3.037915 -> V=1.0, theta=0.0
% INFO    : Bus 6543	: V=1.021518, theta=-48.984823 -> V=1.0, theta=0.0
% INFO    : Bus 6544	: V=1.012644, theta=-43.004801 -> V=1.0, theta=0.0
% INFO    : Bus 6545	: V=1.015478, theta=-22.400542 -> V=1.0, theta=0.0
% INFO    : Bus 6546	: V=1.006447, theta=-18.016355 -> V=1.0, theta=0.0
% INFO    : Bus 6547	: V=1.022867, theta=-35.857699 -> V=1.0, theta=0.0
% INFO    : Bus 6548	: V=0.957126, theta=-31.218742 -> V=1.0, theta=0.0
% INFO    : Bus 6549	: V=0.890685, theta=-37.323381 -> V=1.0, theta=0.0
% INFO    : Bus 6550	: V=1.013572, theta=-18.93499 -> V=1.0, theta=0.0
% INFO    : Bus 6551	: V=1.024471, theta=-0.636312 -> V=1.0, theta=0.0
% INFO    : Bus 6552	: V=1.045563, theta=-21.436085 -> V=1.0, theta=0.0
% INFO    : Bus 6553	: V=1.009106, theta=-5.875714 -> V=1.0, theta=0.0
% INFO    : Bus 6554	: V=1.019608, theta=2.984743 -> V=1.0, theta=0.0
% INFO    : Bus 6555	: V=1.005583, theta=-43.970734 -> V=1.0, theta=0.0
% INFO    : Bus 6556	: V=1.04276, theta=-13.023711 -> V=1.0, theta=0.0
% INFO    : Bus 6557	: V=1.050799, theta=-25.79533 -> V=1.0, theta=0.0
% INFO    : Bus 6558	: V=1.022941, theta=4.361002 -> V=1.0, theta=0.0
% INFO    : Bus 6559	: V=1.022806, theta=-1.780878 -> V=1.0, theta=0.0
% INFO    : Bus 6560	: V=1.038437, theta=-33.560165 -> V=1.0, theta=0.0
% INFO    : Bus 6561	: V=1.000631, theta=-49.571421 -> V=1.0, theta=0.0
% INFO    : Bus 6562	: V=0.920987, theta=-34.594655 -> V=1.0, theta=0.0
% INFO    : Bus 6563	: V=1.038187, theta=-24.977946 -> V=1.0, theta=0.0
% INFO    : Bus 6564	: V=1.045854, theta=-43.736595 -> V=1.0, theta=0.0
% INFO    : Bus 6565	: V=1.026594, theta=-7.466272 -> V=1.0, theta=0.0
% INFO    : Bus 6566	: V=1.005069, theta=-35.144988 -> V=1.0, theta=0.0
% INFO    : Bus 6567	: V=1.018261, theta=-29.166572 -> V=1.0, theta=0.0
% INFO    : Bus 6568	: V=1.092467, theta=-21.688002 -> V=1.0, theta=0.0
% INFO    : Bus 6569	: V=1.087962, theta=6.895826 -> V=1.0, theta=0.0
% INFO    : Bus 6570	: V=1.042473, theta=-21.070856 -> V=1.0, theta=0.0
% INFO    : Bus 6571	: V=0.990822, theta=-26.223119 -> V=1.0, theta=0.0
% INFO    : Bus 6572	: V=0.970523, theta=-32.930385 -> V=1.0, theta=0.0
% INFO    : Bus 6573	: V=1.065303, theta=-25.402871 -> V=1.0, theta=0.0
% INFO    : Bus 6574	: V=1.087544, theta=-21.290004 -> V=1.0, theta=0.0
% INFO    : Bus 6575	: V=1.069716, theta=0.756228 -> V=1.0, theta=0.0
% INFO    : Bus 6576	: V=1.053162, theta=-30.773664 -> V=1.0, theta=0.0
% INFO    : Bus 6577	: V=1.010475, theta=-33.979657 -> V=1.0, theta=0.0
% INFO    : Bus 6578	: V=1.032875, theta=3.567164 -> V=1.0, theta=0.0
% INFO    : Bus 6579	: V=0.994046, theta=-29.200405 -> V=1.0, theta=0.0
% INFO    : Bus 6580	: V=1.002402, theta=-26.476301 -> V=1.0, theta=0.0
% INFO    : Bus 6581	: V=1.037904, theta=-2.639566 -> V=1.0, theta=0.0
% INFO    : Bus 6582	: V=1.029713, theta=11.808225 -> V=1.0, theta=0.0
% INFO    : Bus 6583	: V=0.982898, theta=-28.745965 -> V=1.0, theta=0.0
% INFO    : Bus 6584	: V=1.05456, theta=46.610634 -> V=1.0, theta=0.0
% INFO    : Bus 6585	: V=1.02546, theta=-24.631882 -> V=1.0, theta=0.0
% INFO    : Bus 6586	: V=1.026459, theta=-10.177086 -> V=1.0, theta=0.0
% INFO    : Bus 6587	: V=1.017615, theta=2.135914 -> V=1.0, theta=0.0
% INFO    : Bus 6588	: V=1.009398, theta=-21.29386 -> V=1.0, theta=0.0
% INFO    : Bus 6589	: V=1.025082, theta=16.182362 -> V=1.0, theta=0.0
% INFO    : Bus 6590	: V=1.029523, theta=-19.121462 -> V=1.0, theta=0.0
% INFO    : Bus 6591	: V=1.040735, theta=-0.830934 -> V=1.0, theta=0.0
% INFO    : Bus 6592	: V=0.953545, theta=-30.563089 -> V=1.0, theta=0.0
% INFO    : Bus 6593	: V=0.941728, theta=-34.204462 -> V=1.0, theta=0.0
% INFO    : Bus 6594	: V=1.022988, theta=-28.726987 -> V=1.0, theta=0.0
% INFO    : Bus 6595	: V=1.028867, theta=-34.156928 -> V=1.0, theta=0.0
% INFO    : Bus 6596	: V=0.998835, theta=-54.824288 -> V=1.0, theta=0.0
% INFO    : Bus 6597	: V=1.022878, theta=-48.793956 -> V=1.0, theta=0.0
% INFO    : Bus 6598	: V=1.013084, theta=-35.644676 -> V=1.0, theta=0.0
% INFO    : Bus 6599	: V=1.039568, theta=-8.004553 -> V=1.0, theta=0.0
% INFO    : Bus 6600	: V=1.066459, theta=11.763623 -> V=1.0, theta=0.0
% INFO    : Bus 6601	: V=1.054508, theta=14.632944 -> V=1.0, theta=0.0
% INFO    : Bus 6602	: V=1.036954, theta=-32.168548 -> V=1.0, theta=0.0
% INFO    : Bus 6603	: V=1.006317, theta=-19.270653 -> V=1.0, theta=0.0
% INFO    : Bus 6604	: V=1.015004, theta=-40.11876 -> V=1.0, theta=0.0
% INFO    : Bus 6605	: V=1.02251, theta=-16.453805 -> V=1.0, theta=0.0
% INFO    : Bus 6606	: V=0.953098, theta=-31.912298 -> V=1.0, theta=0.0
% INFO    : Bus 6607	: V=1.051391, theta=-42.235348 -> V=1.0, theta=0.0
% INFO    : Bus 6608	: V=1.019233, theta=62.350649 -> V=1.0, theta=0.0
% INFO    : Bus 6609	: V=1.035975, theta=-25.972361 -> V=1.0, theta=0.0
% INFO    : Bus 6610	: V=1.050877, theta=-26.231261 -> V=1.0, theta=0.0
% INFO    : Bus 6611	: V=1.069181, theta=59.197642 -> V=1.0, theta=0.0
% INFO    : Bus 6612	: V=1.027317, theta=-32.558678 -> V=1.0, theta=0.0
% INFO    : Bus 6613	: V=1.033639, theta=-2.952605 -> V=1.0, theta=0.0
% INFO    : Bus 6614	: V=0.99179, theta=-20.213506 -> V=1.0, theta=0.0
% INFO    : Bus 6615	: V=1.048798, theta=40.834804 -> V=1.0, theta=0.0
% INFO    : Bus 6616	: V=1.047083, theta=-15.929799 -> V=1.0, theta=0.0
% INFO    : Bus 6617	: V=1.005011, theta=-10.66523 -> V=1.0, theta=0.0
% INFO    : Bus 6618	: V=1.019156, theta=3.439669 -> V=1.0, theta=0.0
% INFO    : Bus 6619	: V=1.041665, theta=-15.788489 -> V=1.0, theta=0.0
% INFO    : Bus 6620	: V=1.021698, theta=-29.695588 -> V=1.0, theta=0.0
% INFO    : Bus 6621	: V=1.077535, theta=43.809315 -> V=1.0, theta=0.0
% INFO    : Bus 6622	: V=1.015825, theta=-36.496694 -> V=1.0, theta=0.0
% INFO    : Bus 6623	: V=1.021842, theta=4.726064 -> V=1.0, theta=0.0
% INFO    : Bus 6624	: V=1.054184, theta=4.222548 -> V=1.0, theta=0.0
% INFO    : Bus 6625	: V=1.018954, theta=-57.362709 -> V=1.0, theta=0.0
% INFO    : Bus 6626	: V=1.042091, theta=-27.345725 -> V=1.0, theta=0.0
% INFO    : Bus 6627	: V=1.064448, theta=-23.669638 -> V=1.0, theta=0.0
% INFO    : Bus 6628	: V=0.974051, theta=-32.701563 -> V=1.0, theta=0.0
% INFO    : Bus 6629	: V=1.050125, theta=-11.711561 -> V=1.0, theta=0.0
% INFO    : Bus 6630	: V=1.034462, theta=-24.515125 -> V=1.0, theta=0.0
% INFO    : Bus 6631	: V=1.004579, theta=-36.783441 -> V=1.0, theta=0.0
% INFO    : Bus 6632	: V=1.057948, theta=-41.084592 -> V=1.0, theta=0.0
% INFO    : Bus 6633	: V=1.02863, theta=-24.975347 -> V=1.0, theta=0.0
% INFO    : Bus 6634	: V=1.022293, theta=16.82388 -> V=1.0, theta=0.0
% INFO    : Bus 6635	: V=1.020771, theta=-29.719031 -> V=1.0, theta=0.0
% INFO    : Bus 6636	: V=1.033858, theta=0.35533 -> V=1.0, theta=0.0
% INFO    : Bus 6637	: V=1.089775, theta=-28.95671 -> V=1.0, theta=0.0
% INFO    : Bus 6638	: V=1.018314, theta=-15.09801 -> V=1.0, theta=0.0
% INFO    : Bus 6639	: V=1.04045, theta=-2.949092 -> V=1.0, theta=0.0
% INFO    : Bus 6640	: V=1.016745, theta=-12.7671 -> V=1.0, theta=0.0
% INFO    : Bus 6641	: V=1.007887, theta=-44.355418 -> V=1.0, theta=0.0
% INFO    : Bus 6642	: V=0.991117, theta=-20.719538 -> V=1.0, theta=0.0
% INFO    : Bus 6643	: V=0.890999, theta=-36.148908 -> V=1.0, theta=0.0
% INFO    : Bus 6644	: V=1.016514, theta=-30.698964 -> V=1.0, theta=0.0
% INFO    : Bus 6645	: V=0.951351, theta=-29.98231 -> V=1.0, theta=0.0
% INFO    : Bus 6646	: V=1.026078, theta=-15.84813 -> V=1.0, theta=0.0
% INFO    : Bus 6647	: V=0.991973, theta=-27.913735 -> V=1.0, theta=0.0
% INFO    : Bus 6648	: V=1.065399, theta=-11.833033 -> V=1.0, theta=0.0
% INFO    : Bus 6649	: V=1.00861, theta=-36.870958 -> V=1.0, theta=0.0
% INFO    : Bus 6650	: V=1.035108, theta=-33.809859 -> V=1.0, theta=0.0
% INFO    : Bus 6651	: V=1.065345, theta=-19.869365 -> V=1.0, theta=0.0
% INFO    : Bus 6652	: V=1.04051, theta=-3.235703 -> V=1.0, theta=0.0
% INFO    : Bus 6653	: V=1.005353, theta=65.666316 -> V=1.0, theta=0.0
% INFO    : Bus 6654	: V=1.021829, theta=-46.874798 -> V=1.0, theta=0.0
% INFO    : Bus 6655	: V=1.015791, theta=-17.492134 -> V=1.0, theta=0.0
% INFO    : Bus 6656	: V=1.021248, theta=-37.522583 -> V=1.0, theta=0.0
% INFO    : Bus 6657	: V=1.013122, theta=25.786647 -> V=1.0, theta=0.0
% INFO    : Bus 6658	: V=0.983528, theta=-39.236437 -> V=1.0, theta=0.0
% INFO    : Bus 6659	: V=1.023823, theta=-45.476259 -> V=1.0, theta=0.0
% INFO    : Bus 6660	: V=1.006581, theta=-49.631709 -> V=1.0, theta=0.0
% INFO    : Bus 6661	: V=0.997723, theta=9.398578 -> V=1.0, theta=0.0
% INFO    : Bus 6662	: V=1.03099, theta=3.60651 -> V=1.0, theta=0.0
% INFO    : Bus 6663	: V=1.009405, theta=-48.745192 -> V=1.0, theta=0.0
% INFO    : Bus 6664	: V=1.06588, theta=-46.619327 -> V=1.0, theta=0.0
% INFO    : Bus 6665	: V=1.056221, theta=-22.880474 -> V=1.0, theta=0.0
% INFO    : Bus 6666	: V=1.031749, theta=-25.329109 -> V=1.0, theta=0.0
% INFO    : Bus 6667	: V=1.018785, theta=-3.636685 -> V=1.0, theta=0.0
% INFO    : Bus 6668	: V=1.064039, theta=55.017174 -> V=1.0, theta=0.0
% INFO    : Bus 6669	: V=1.006991, theta=-53.318964 -> V=1.0, theta=0.0
% INFO    : Bus 6670	: V=1.026778, theta=-24.94221 -> V=1.0, theta=0.0
% INFO    : Bus 6671	: V=1.026272, theta=-13.566694 -> V=1.0, theta=0.0
% INFO    : Bus 6672	: V=0.96488, theta=-25.340903 -> V=1.0, theta=0.0
% INFO    : Bus 6673	: V=1.004066, theta=-30.031041 -> V=1.0, theta=0.0
% INFO    : Bus 6674	: V=1.021631, theta=-12.457879 -> V=1.0, theta=0.0
% INFO    : Bus 6675	: V=1.031326, theta=-23.642893 -> V=1.0, theta=0.0
% INFO    : Bus 6676	: V=1.017147, theta=-28.974177 -> V=1.0, theta=0.0
% INFO    : Bus 6677	: V=1.010881, theta=-5.581868 -> V=1.0, theta=0.0
% INFO    : Bus 6678	: V=1.01717, theta=-24.655234 -> V=1.0, theta=0.0
% INFO    : Bus 6679	: V=1.028614, theta=-53.994532 -> V=1.0, theta=0.0
% INFO    : Bus 6680	: V=1.025575, theta=-46.91691 -> V=1.0, theta=0.0
% INFO    : Bus 6681	: V=1.067534, theta=-41.04651 -> V=1.0, theta=0.0
% INFO    : Bus 6682	: V=1.060301, theta=-32.015299 -> V=1.0, theta=0.0
% INFO    : Bus 6683	: V=1.029435, theta=-21.636054 -> V=1.0, theta=0.0
% INFO    : Bus 6684	: V=1.040265, theta=-25.88167 -> V=1.0, theta=0.0
% INFO    : Bus 6685	: V=0.999762, theta=-24.218159 -> V=1.0, theta=0.0
% INFO    : Bus 6686	: V=0.999342, theta=-24.208457 -> V=1.0, theta=0.0
% INFO    : Bus 6687	: V=1.048081, theta=18.196526 -> V=1.0, theta=0.0
% INFO    : Bus 6688	: V=1.103679, theta=-28.69286 -> V=1.0, theta=0.0
% INFO    : Bus 6689	: V=0.962351, theta=-29.210137 -> V=1.0, theta=0.0
% INFO    : Bus 6690	: V=0.999008, theta=-36.938285 -> V=1.0, theta=0.0
% INFO    : Bus 6691	: V=1.080764, theta=-34.348226 -> V=1.0, theta=0.0
% INFO    : Bus 6692	: V=1.021278, theta=-15.766876 -> V=1.0, theta=0.0
% INFO    : Bus 6693	: V=1.063223, theta=-18.651224 -> V=1.0, theta=0.0
% INFO    : Bus 6694	: V=1.017693, theta=-42.675585 -> V=1.0, theta=0.0
% INFO    : Bus 6695	: V=1.044718, theta=-25.525618 -> V=1.0, theta=0.0
% INFO    : Bus 6696	: V=0.989039, theta=-28.255999 -> V=1.0, theta=0.0
% INFO    : Bus 6697	: V=1.041614, theta=-37.409045 -> V=1.0, theta=0.0
% INFO    : Bus 6698	: V=1.044786, theta=-25.523647 -> V=1.0, theta=0.0
% INFO    : Bus 6699	: V=1.013524, theta=-32.326805 -> V=1.0, theta=0.0
% INFO    : Bus 6700	: V=1.021422, theta=-0.756478 -> V=1.0, theta=0.0
% INFO    : Bus 6701	: V=1.027805, theta=-8.66411 -> V=1.0, theta=0.0
% INFO    : Bus 6702	: V=1.002413, theta=-30.25303 -> V=1.0, theta=0.0
% INFO    : Bus 6703	: V=1.089943, theta=-12.791757 -> V=1.0, theta=0.0
% INFO    : Bus 6704	: V=0.991196, theta=-3.76298 -> V=1.0, theta=0.0
% INFO    : Bus 6705	: V=1.044635, theta=-29.457279 -> V=1.0, theta=0.0
% INFO    : Bus 6706	: V=0.983638, theta=-16.068502 -> V=1.0, theta=0.0
% INFO    : Bus 6707	: V=1.021005, theta=10.860309 -> V=1.0, theta=0.0
% INFO    : Bus 6708	: V=1.044499, theta=0.506424 -> V=1.0, theta=0.0
% INFO    : Bus 6709	: V=0.996873, theta=-33.045095 -> V=1.0, theta=0.0
% INFO    : Bus 6710	: V=1.07958, theta=-23.72775 -> V=1.0, theta=0.0
% INFO    : Bus 6711	: V=0.962861, theta=-25.447365 -> V=1.0, theta=0.0
% INFO    : Bus 6712	: V=0.943879, theta=-31.452218 -> V=1.0, theta=0.0
% INFO    : Bus 6713	: V=0.999008, theta=-36.938285 -> V=1.0, theta=0.0
% INFO    : Bus 6714	: V=1.045223, theta=-0.934918 -> V=1.0, theta=0.0
% INFO    : Bus 6715	: V=1.025113, theta=47.677055 -> V=1.0, theta=0.0
% INFO    : Bus 6716	: V=1.039972, theta=-5.088363 -> V=1.0, theta=0.0
% INFO    : Bus 6717	: V=1.017316, theta=-46.573289 -> V=1.0, theta=0.0
% INFO    : Bus 6718	: V=1.029383, theta=-20.114842 -> V=1.0, theta=0.0
% INFO    : Bus 6719	: V=1.025617, theta=-14.193295 -> V=1.0, theta=0.0
% INFO    : Bus 6720	: V=1.024902, theta=-29.194864 -> V=1.0, theta=0.0
% INFO    : Bus 6721	: V=1.031379, theta=-27.285526 -> V=1.0, theta=0.0
% INFO    : Bus 6722	: V=1.017782, theta=-35.780142 -> V=1.0, theta=0.0
% INFO    : Bus 6723	: V=1.03262, theta=-9.513194 -> V=1.0, theta=0.0
% INFO    : Bus 6724	: V=1.047253, theta=15.082934 -> V=1.0, theta=0.0
% INFO    : Bus 6725	: V=1.018821, theta=-44.649613 -> V=1.0, theta=0.0
% INFO    : Bus 6726	: V=0.955424, theta=-30.687827 -> V=1.0, theta=0.0
% INFO    : Bus 6727	: V=0.962201, theta=-32.513552 -> V=1.0, theta=0.0
% INFO    : Bus 6728	: V=1.03221, theta=-7.850441 -> V=1.0, theta=0.0
% INFO    : Bus 6729	: V=1.080808, theta=-19.366298 -> V=1.0, theta=0.0
% INFO    : Bus 6730	: V=1.035104, theta=-21.386459 -> V=1.0, theta=0.0
% INFO    : Bus 6731	: V=1.01328, theta=-22.245563 -> V=1.0, theta=0.0
% INFO    : Bus 6732	: V=1.080593, theta=-17.338718 -> V=1.0, theta=0.0
% INFO    : Bus 6733	: V=1.004375, theta=-24.946676 -> V=1.0, theta=0.0
% INFO    : Bus 6734	: V=1.061659, theta=-3.667603 -> V=1.0, theta=0.0
% INFO    : Bus 6735	: V=1.043988, theta=-1.453163 -> V=1.0, theta=0.0
% INFO    : Bus 6736	: V=1.032666, theta=-34.198945 -> V=1.0, theta=0.0
% INFO    : Bus 6737	: V=1.0191, theta=-10.589491 -> V=1.0, theta=0.0
% INFO    : Bus 6738	: V=1.02709, theta=-25.011209 -> V=1.0, theta=0.0
% INFO    : Bus 6739	: V=1.07283, theta=-16.070338 -> V=1.0, theta=0.0
% INFO    : Bus 6740	: V=1.03767, theta=-1.073745 -> V=1.0, theta=0.0
% INFO    : Bus 6741	: V=1.166873, theta=-20.237294 -> V=1.0, theta=0.0
% INFO    : Bus 6742	: V=1.033206, theta=-21.845565 -> V=1.0, theta=0.0
% INFO    : Bus 6743	: V=1.069321, theta=-21.296261 -> V=1.0, theta=0.0
% INFO    : Bus 6744	: V=1.030454, theta=-10.296212 -> V=1.0, theta=0.0
% INFO    : Bus 6745	: V=1.013756, theta=-40.052079 -> V=1.0, theta=0.0
% INFO    : Bus 6746	: V=1.041833, theta=3.40788 -> V=1.0, theta=0.0
% INFO    : Bus 6747	: V=1.023667, theta=2.127798 -> V=1.0, theta=0.0
% INFO    : Bus 6748	: V=1.027034, theta=-32.698811 -> V=1.0, theta=0.0
% INFO    : Bus 6749	: V=1.022364, theta=-49.130749 -> V=1.0, theta=0.0
% INFO    : Bus 6750	: V=1.018107, theta=-36.407447 -> V=1.0, theta=0.0
% INFO    : Bus 6751	: V=0.990989, theta=-0.237283 -> V=1.0, theta=0.0
% INFO    : Bus 6752	: V=1.074044, theta=-21.761211 -> V=1.0, theta=0.0
% INFO    : Bus 6753	: V=1.045824, theta=39.68115 -> V=1.0, theta=0.0
% INFO    : Bus 6754	: V=1.045135, theta=-15.724698 -> V=1.0, theta=0.0
% INFO    : Bus 6755	: V=0.973002, theta=-32.848031 -> V=1.0, theta=0.0
% INFO    : Bus 6756	: V=1.025997, theta=-46.853452 -> V=1.0, theta=0.0
% INFO    : Bus 6757	: V=1.033435, theta=-1.313929 -> V=1.0, theta=0.0
% INFO    : Bus 6758	: V=1.027453, theta=-28.328891 -> V=1.0, theta=0.0
% INFO    : Bus 6759	: V=1.043522, theta=-16.247543 -> V=1.0, theta=0.0
% INFO    : Bus 6760	: V=1.047631, theta=-42.762581 -> V=1.0, theta=0.0
% INFO    : Bus 6761	: V=1.044313, theta=-23.034488 -> V=1.0, theta=0.0
% INFO    : Bus 6762	: V=1.027936, theta=-32.99687 -> V=1.0, theta=0.0
% INFO    : Bus 6763	: V=1.039282, theta=-24.599259 -> V=1.0, theta=0.0
% INFO    : Bus 6764	: V=0.99015, theta=-28.828647 -> V=1.0, theta=0.0
% INFO    : Bus 6765	: V=1.036921, theta=-30.617101 -> V=1.0, theta=0.0
% INFO    : Bus 6766	: V=1.025019, theta=11.340754 -> V=1.0, theta=0.0
% INFO    : Bus 6767	: V=0.912651, theta=-36.033898 -> V=1.0, theta=0.0
% INFO    : Bus 6768	: V=1.024616, theta=-45.660094 -> V=1.0, theta=0.0
% INFO    : Bus 6769	: V=1.038685, theta=-44.785861 -> V=1.0, theta=0.0
% INFO    : Bus 6770	: V=1.002077, theta=-26.419817 -> V=1.0, theta=0.0
% INFO    : Bus 6771	: V=1.048542, theta=-43.937081 -> V=1.0, theta=0.0
% INFO    : Bus 6772	: V=1.040983, theta=-24.457946 -> V=1.0, theta=0.0
% INFO    : Bus 6773	: V=1.03956, theta=-24.600336 -> V=1.0, theta=0.0
% INFO    : Bus 6774	: V=0.972605, theta=-32.139314 -> V=1.0, theta=0.0
% INFO    : Bus 6775	: V=1.030191, theta=-16.698866 -> V=1.0, theta=0.0
% INFO    : Bus 6776	: V=0.99181, theta=-28.172115 -> V=1.0, theta=0.0
% INFO    : Bus 6777	: V=1.051803, theta=-7.55464 -> V=1.0, theta=0.0
% INFO    : Bus 6778	: V=1.038013, theta=-36.82811 -> V=1.0, theta=0.0
% INFO    : Bus 6779	: V=1.011617, theta=-32.734235 -> V=1.0, theta=0.0
% INFO    : Bus 6780	: V=1.074673, theta=-20.589176 -> V=1.0, theta=0.0
% INFO    : Bus 6781	: V=1.038616, theta=-1.166785 -> V=1.0, theta=0.0
% INFO    : Bus 6782	: V=1.033058, theta=3.304265 -> V=1.0, theta=0.0
% INFO    : Bus 6783	: V=1.023694, theta=-54.395974 -> V=1.0, theta=0.0
% INFO    : Bus 6784	: V=1.056442, theta=-24.212325 -> V=1.0, theta=0.0
% INFO    : Bus 6785	: V=1.04291, theta=-1.012512 -> V=1.0, theta=0.0
% INFO    : Bus 6786	: V=1.026314, theta=-19.780908 -> V=1.0, theta=0.0
% INFO    : Bus 6787	: V=1.048295, theta=-18.194704 -> V=1.0, theta=0.0
% INFO    : Bus 6788	: V=0.983719, theta=-28.350412 -> V=1.0, theta=0.0
% INFO    : Bus 6789	: V=0.963175, theta=-31.640692 -> V=1.0, theta=0.0
% INFO    : Bus 6790	: V=1.073696, theta=-25.028264 -> V=1.0, theta=0.0
% INFO    : Bus 6791	: V=1.042529, theta=-25.5606 -> V=1.0, theta=0.0
% INFO    : Bus 6792	: V=0.966238, theta=-29.985221 -> V=1.0, theta=0.0
% INFO    : Bus 6793	: V=1.049876, theta=-32.799947 -> V=1.0, theta=0.0
% INFO    : Bus 6794	: V=1.098897, theta=23.835219 -> V=1.0, theta=0.0
% INFO    : Bus 6795	: V=0.995348, theta=-49.674217 -> V=1.0, theta=0.0
% INFO    : Bus 6796	: V=1.057472, theta=10.260704 -> V=1.0, theta=0.0
% INFO    : Bus 6797	: V=1.022448, theta=-50.891154 -> V=1.0, theta=0.0
% INFO    : Bus 6798	: V=1.018682, theta=6.386371 -> V=1.0, theta=0.0
% INFO    : Bus 6799	: V=1.000628, theta=-24.084029 -> V=1.0, theta=0.0
% INFO    : Bus 6800	: V=1.051979, theta=-15.235826 -> V=1.0, theta=0.0
% INFO    : Bus 6801	: V=0.989107, theta=-17.984271 -> V=1.0, theta=0.0
% INFO    : Bus 6802	: V=1.03121, theta=-6.438625 -> V=1.0, theta=0.0
% INFO    : Bus 6803	: V=1.007231, theta=-16.058199 -> V=1.0, theta=0.0
% INFO    : Bus 6804	: V=1.005281, theta=-34.431326 -> V=1.0, theta=0.0
% INFO    : Bus 6805	: V=0.987496, theta=-29.138849 -> V=1.0, theta=0.0
% INFO    : Bus 6806	: V=1.04316, theta=-21.559494 -> V=1.0, theta=0.0
% INFO    : Bus 6807	: V=1.025274, theta=-15.869079 -> V=1.0, theta=0.0
% INFO    : Bus 6808	: V=0.973167, theta=5.367763 -> V=1.0, theta=0.0
% INFO    : Bus 6809	: V=1.010642, theta=-36.564273 -> V=1.0, theta=0.0
% INFO    : Bus 6810	: V=1.013906, theta=-36.128707 -> V=1.0, theta=0.0
% INFO    : Bus 6811	: V=1.093866, theta=45.741934 -> V=1.0, theta=0.0
% INFO    : Bus 6812	: V=1.019103, theta=4.226701 -> V=1.0, theta=0.0
% INFO    : Bus 6813	: V=1.030676, theta=-28.526923 -> V=1.0, theta=0.0
% INFO    : Bus 6814	: V=1.040134, theta=-33.295098 -> V=1.0, theta=0.0
% INFO    : Bus 6815	: V=0.979516, theta=-21.235793 -> V=1.0, theta=0.0
% INFO    : Bus 6816	: V=1.062526, theta=-24.747281 -> V=1.0, theta=0.0
% INFO    : Bus 6817	: V=1.034935, theta=-24.867879 -> V=1.0, theta=0.0
% INFO    : Bus 6818	: V=1.067428, theta=-28.590472 -> V=1.0, theta=0.0
% INFO    : Bus 6819	: V=0.972407, theta=-32.151223 -> V=1.0, theta=0.0
% INFO    : Bus 6820	: V=1.047984, theta=-6.715994 -> V=1.0, theta=0.0
% INFO    : Bus 6821	: V=1.028628, theta=-6.505156 -> V=1.0, theta=0.0
% INFO    : Bus 6822	: V=1.039383, theta=-19.102075 -> V=1.0, theta=0.0
% INFO    : Bus 6823	: V=1.042858, theta=3.417992 -> V=1.0, theta=0.0
% INFO    : Bus 6824	: V=1.011287, theta=-4.992497 -> V=1.0, theta=0.0
% INFO    : Bus 6825	: V=0.959831, theta=-22.876857 -> V=1.0, theta=0.0
% INFO    : Bus 6826	: V=1.063269, theta=-8.045999 -> V=1.0, theta=0.0
% INFO    : Bus 6827	: V=0.983853, theta=-34.426794 -> V=1.0, theta=0.0
% INFO    : Bus 6828	: V=1.033305, theta=-13.74934 -> V=1.0, theta=0.0
% INFO    : Bus 6829	: V=1.006688, theta=31.027518 -> V=1.0, theta=0.0
% INFO    : Bus 6830	: V=0.990731, theta=7.463538 -> V=1.0, theta=0.0
% INFO    : Bus 6831	: V=1.031732, theta=-9.829512 -> V=1.0, theta=0.0
% INFO    : Bus 6832	: V=1.079815, theta=31.595432 -> V=1.0, theta=0.0
% INFO    : Bus 6833	: V=0.973456, theta=-7.173915 -> V=1.0, theta=0.0
% INFO    : Bus 6834	: V=0.999719, theta=-27.892541 -> V=1.0, theta=0.0
% INFO    : Bus 6835	: V=1.025803, theta=17.762871 -> V=1.0, theta=0.0
% INFO    : Bus 6836	: V=1.022259, theta=-48.813369 -> V=1.0, theta=0.0
% INFO    : Bus 6837	: V=1.047535, theta=-7.972968 -> V=1.0, theta=0.0
% INFO    : Bus 6838	: V=1.050849, theta=4.821282 -> V=1.0, theta=0.0
% INFO    : Bus 6839	: V=1.01181, theta=61.954496 -> V=1.0, theta=0.0
% INFO    : Bus 6840	: V=1.021842, theta=-7.278252 -> V=1.0, theta=0.0
% INFO    : Bus 6841	: V=1.025239, theta=-53.891327 -> V=1.0, theta=0.0
% INFO    : Bus 6842	: V=1.036174, theta=-8.502674 -> V=1.0, theta=0.0
% INFO    : Bus 6843	: V=1.013427, theta=-28.349592 -> V=1.0, theta=0.0
% INFO    : Bus 6844	: V=1.011515, theta=-29.690265 -> V=1.0, theta=0.0
% INFO    : Bus 6845	: V=1.045173, theta=-11.439959 -> V=1.0, theta=0.0
% INFO    : Bus 6846	: V=1.053446, theta=-4.807622 -> V=1.0, theta=0.0
% INFO    : Bus 6847	: V=1.018848, theta=2.887133 -> V=1.0, theta=0.0
% INFO    : Bus 6848	: V=1.027262, theta=1.580761 -> V=1.0, theta=0.0
% INFO    : Bus 6849	: V=0.987046, theta=-26.764003 -> V=1.0, theta=0.0
% INFO    : Bus 6850	: V=1.010801, theta=-8.455575 -> V=1.0, theta=0.0
% INFO    : Bus 6851	: V=0.99745, theta=-26.064833 -> V=1.0, theta=0.0
% INFO    : Bus 6852	: V=1.034908, theta=-20.130283 -> V=1.0, theta=0.0
% INFO    : Bus 6853	: V=1.01029, theta=-30.963324 -> V=1.0, theta=0.0
% INFO    : Bus 6854	: V=1.05059, theta=-11.653422 -> V=1.0, theta=0.0
% INFO    : Bus 6855	: V=0.92059, theta=-34.147317 -> V=1.0, theta=0.0
% INFO    : Bus 6856	: V=1.036628, theta=-39.641147 -> V=1.0, theta=0.0
% INFO    : Bus 6857	: V=1.018722, theta=-8.798226 -> V=1.0, theta=0.0
% INFO    : Bus 6858	: V=0.960834, theta=-27.235744 -> V=1.0, theta=0.0
% INFO    : Bus 6859	: V=1.063045, theta=-33.986886 -> V=1.0, theta=0.0
% INFO    : Bus 6860	: V=1.022858, theta=-24.2758 -> V=1.0, theta=0.0
% INFO    : Bus 6861	: V=1.037118, theta=5.638422 -> V=1.0, theta=0.0
% INFO    : Bus 6862	: V=1.043582, theta=-30.847862 -> V=1.0, theta=0.0
% INFO    : Bus 6863	: V=1.022704, theta=-29.450197 -> V=1.0, theta=0.0
% INFO    : Bus 6864	: V=1.020438, theta=24.563168 -> V=1.0, theta=0.0
% INFO    : Bus 6865	: V=1.025349, theta=-24.32202 -> V=1.0, theta=0.0
% INFO    : Bus 6866	: V=1.013186, theta=-35.824164 -> V=1.0, theta=0.0
% INFO    : Bus 6867	: V=1.034972, theta=-28.119193 -> V=1.0, theta=0.0
% INFO    : Bus 6868	: V=1.042934, theta=8.937058 -> V=1.0, theta=0.0
% INFO    : Bus 6869	: V=1.022281, theta=-53.5165 -> V=1.0, theta=0.0
% INFO    : Bus 6870	: V=1.028473, theta=65.164851 -> V=1.0, theta=0.0
% INFO    : Bus 6871	: V=1.028131, theta=-22.162596 -> V=1.0, theta=0.0
% INFO    : Bus 6872	: V=0.999884, theta=-29.224674 -> V=1.0, theta=0.0
% INFO    : Bus 6873	: V=0.980745, theta=-31.583482 -> V=1.0, theta=0.0
% INFO    : Bus 6874	: V=1.03371, theta=-11.209656 -> V=1.0, theta=0.0
% INFO    : Bus 6875	: V=0.991313, theta=-30.820225 -> V=1.0, theta=0.0
% INFO    : Bus 6876	: V=1.020214, theta=-38.870017 -> V=1.0, theta=0.0
% INFO    : Bus 6877	: V=1.062542, theta=-42.235295 -> V=1.0, theta=0.0
% INFO    : Bus 6878	: V=0.97868, theta=-32.463806 -> V=1.0, theta=0.0
% INFO    : Bus 6879	: V=1.036595, theta=-45.824534 -> V=1.0, theta=0.0
% INFO    : Bus 6880	: V=1.043251, theta=-4.724019 -> V=1.0, theta=0.0
% INFO    : Bus 6881	: V=0.922343, theta=-32.798823 -> V=1.0, theta=0.0
% INFO    : Bus 6882	: V=1.009653, theta=-54.489183 -> V=1.0, theta=0.0
% INFO    : Bus 6883	: V=1.056872, theta=-40.622181 -> V=1.0, theta=0.0
% INFO    : Bus 6884	: V=1.079826, theta=31.59123 -> V=1.0, theta=0.0
% INFO    : Bus 6885	: V=0.96795, theta=-32.435222 -> V=1.0, theta=0.0
% INFO    : Bus 6886	: V=0.998542, theta=9.756196 -> V=1.0, theta=0.0
% INFO    : Bus 6887	: V=1.044495, theta=-3.165926 -> V=1.0, theta=0.0
% INFO    : Bus 6888	: V=1.046712, theta=-13.457465 -> V=1.0, theta=0.0
% INFO    : Bus 6889	: V=1.029246, theta=2.262303 -> V=1.0, theta=0.0
% INFO    : Bus 6890	: V=1.006955, theta=-4.145691 -> V=1.0, theta=0.0
% INFO    : Bus 6891	: V=1.037473, theta=-14.658529 -> V=1.0, theta=0.0
% INFO    : Bus 6892	: V=1.058992, theta=-28.152698 -> V=1.0, theta=0.0
% INFO    : Bus 6893	: V=1.002405, theta=23.539101 -> V=1.0, theta=0.0
% INFO    : Bus 6894	: V=1.067746, theta=54.777918 -> V=1.0, theta=0.0
% INFO    : Bus 6895	: V=1.028013, theta=-42.93267 -> V=1.0, theta=0.0
% INFO    : Bus 6896	: V=1.035677, theta=-33.647621 -> V=1.0, theta=0.0
% INFO    : Bus 6897	: V=1.050254, theta=-16.909677 -> V=1.0, theta=0.0
% INFO    : Bus 6898	: V=1.00096, theta=-31.245697 -> V=1.0, theta=0.0
% INFO    : Bus 6899	: V=1.030208, theta=-32.873404 -> V=1.0, theta=0.0
% INFO    : Bus 6900	: V=1.08427, theta=48.195272 -> V=1.0, theta=0.0
% INFO    : Bus 6901	: V=1.00996, theta=-32.23459 -> V=1.0, theta=0.0
% INFO    : Bus 6902	: V=1.046903, theta=-2.652524 -> V=1.0, theta=0.0
% INFO    : Bus 6903	: V=1.016371, theta=-13.962953 -> V=1.0, theta=0.0
% INFO    : Bus 6904	: V=1.024553, theta=-56.340587 -> V=1.0, theta=0.0
% INFO    : Bus 6905	: V=0.994534, theta=-34.603144 -> V=1.0, theta=0.0
% INFO    : Bus 6906	: V=1.056962, theta=12.098847 -> V=1.0, theta=0.0
% INFO    : Bus 6907	: V=1.059798, theta=-37.191473 -> V=1.0, theta=0.0
% INFO    : Bus 6908	: V=1.032036, theta=-40.507685 -> V=1.0, theta=0.0
% INFO    : Bus 6909	: V=1.032135, theta=-23.480384 -> V=1.0, theta=0.0
% INFO    : Bus 6910	: V=1.028742, theta=-37.860449 -> V=1.0, theta=0.0
% INFO    : Bus 6911	: V=0.988014, theta=-39.679641 -> V=1.0, theta=0.0
% INFO    : Bus 6912	: V=1.001369, theta=-29.850843 -> V=1.0, theta=0.0
% INFO    : Bus 6913	: V=1.004998, theta=-36.450118 -> V=1.0, theta=0.0
% INFO    : Bus 6914	: V=1.083288, theta=55.169444 -> V=1.0, theta=0.0
% INFO    : Bus 6915	: V=1.023422, theta=13.262415 -> V=1.0, theta=0.0
% INFO    : Bus 6916	: V=1.075717, theta=-26.413433 -> V=1.0, theta=0.0
% INFO    : Bus 6917	: V=1.060595, theta=-42.915887 -> V=1.0, theta=0.0
% INFO    : Bus 6918	: V=0.984829, theta=-27.636035 -> V=1.0, theta=0.0
% INFO    : Bus 6919	: V=0.998163, theta=-26.941463 -> V=1.0, theta=0.0
% INFO    : Bus 6920	: V=1.008862, theta=-6.332689 -> V=1.0, theta=0.0
% INFO    : Bus 6921	: V=1.028797, theta=-1.750787 -> V=1.0, theta=0.0
% INFO    : Bus 6922	: V=1.035254, theta=-8.69566 -> V=1.0, theta=0.0
% INFO    : Bus 6923	: V=1.034428, theta=14.578941 -> V=1.0, theta=0.0
% INFO    : Bus 6924	: V=1.02139, theta=-36.374905 -> V=1.0, theta=0.0
% INFO    : Bus 6925	: V=1.071735, theta=-30.969262 -> V=1.0, theta=0.0
% INFO    : Bus 6926	: V=1.035565, theta=-12.545415 -> V=1.0, theta=0.0
% INFO    : Bus 6927	: V=1.01541, theta=0.234942 -> V=1.0, theta=0.0
% INFO    : Bus 6928	: V=1.023523, theta=-29.563055 -> V=1.0, theta=0.0
% INFO    : Bus 6929	: V=1.052834, theta=-17.763654 -> V=1.0, theta=0.0
% INFO    : Bus 6930	: V=1.047953, theta=-13.982011 -> V=1.0, theta=0.0
% INFO    : Bus 6931	: V=1.015354, theta=-9.011275 -> V=1.0, theta=0.0
% INFO    : Bus 6932	: V=1.028056, theta=-53.852837 -> V=1.0, theta=0.0
% INFO    : Bus 6933	: V=1.031105, theta=-26.078897 -> V=1.0, theta=0.0
% INFO    : Bus 6934	: V=1.059171, theta=62.942185 -> V=1.0, theta=0.0
% INFO    : Bus 6935	: V=0.970025, theta=-24.238119 -> V=1.0, theta=0.0
% INFO    : Bus 6936	: V=1.022407, theta=-39.112868 -> V=1.0, theta=0.0
% INFO    : Bus 6937	: V=1.025063, theta=-7.633494 -> V=1.0, theta=0.0
% INFO    : Bus 6938	: V=1.027581, theta=-33.829709 -> V=1.0, theta=0.0
% INFO    : Bus 6939	: V=1.0377, theta=-36.880041 -> V=1.0, theta=0.0
% INFO    : Bus 6940	: V=1.049805, theta=-28.106742 -> V=1.0, theta=0.0
% INFO    : Bus 6941	: V=1.002574, theta=-9.256496 -> V=1.0, theta=0.0
% INFO    : Bus 6942	: V=1.035522, theta=-22.267144 -> V=1.0, theta=0.0
% INFO    : Bus 6943	: V=1.039166, theta=-28.646488 -> V=1.0, theta=0.0
% INFO    : Bus 6944	: V=1.025716, theta=-29.458867 -> V=1.0, theta=0.0
% INFO    : Bus 6945	: V=1.01086, theta=-9.175729 -> V=1.0, theta=0.0
% INFO    : Bus 6946	: V=1.033877, theta=47.079271 -> V=1.0, theta=0.0
% INFO    : Bus 6947	: V=1.049432, theta=-3.998316 -> V=1.0, theta=0.0
% INFO    : Bus 6948	: V=1.010398, theta=11.762126 -> V=1.0, theta=0.0
% INFO    : Bus 6949	: V=1.024047, theta=-54.300611 -> V=1.0, theta=0.0
% INFO    : Bus 6950	: V=1.020998, theta=-5.538575 -> V=1.0, theta=0.0
% INFO    : Bus 6951	: V=1.056422, theta=9.349947 -> V=1.0, theta=0.0
% INFO    : Bus 6952	: V=1.07171, theta=-25.432953 -> V=1.0, theta=0.0
% INFO    : Bus 6953	: V=1.015316, theta=-50.439781 -> V=1.0, theta=0.0
% INFO    : Bus 6954	: V=1.030112, theta=-20.371845 -> V=1.0, theta=0.0
% INFO    : Bus 6955	: V=1.001649, theta=-25.341796 -> V=1.0, theta=0.0
% INFO    : Bus 6956	: V=1.069137, theta=26.053819 -> V=1.0, theta=0.0
% INFO    : Bus 6957	: V=1.081823, theta=-35.990705 -> V=1.0, theta=0.0
% INFO    : Bus 6958	: V=1.013663, theta=-36.143405 -> V=1.0, theta=0.0
% INFO    : Bus 6959	: V=1.045083, theta=-14.961356 -> V=1.0, theta=0.0
% INFO    : Bus 6960	: V=0.986652, theta=-56.659914 -> V=1.0, theta=0.0
% INFO    : Bus 6961	: V=1.045446, theta=-0.160283 -> V=1.0, theta=0.0
% INFO    : Bus 6962	: V=1.070029, theta=-24.62348 -> V=1.0, theta=0.0
% INFO    : Bus 6963	: V=1.023802, theta=-14.065178 -> V=1.0, theta=0.0
% INFO    : Bus 6964	: V=1.033776, theta=-45.4233 -> V=1.0, theta=0.0
% INFO    : Bus 6965	: V=1.034078, theta=8.639908 -> V=1.0, theta=0.0
% INFO    : Bus 6966	: V=1.023334, theta=5.03485 -> V=1.0, theta=0.0
% INFO    : Bus 6967	: V=1.065194, theta=-23.706414 -> V=1.0, theta=0.0
% INFO    : Bus 6968	: V=1.001887, theta=-31.055317 -> V=1.0, theta=0.0
% INFO    : Bus 6969	: V=1.069563, theta=-23.792716 -> V=1.0, theta=0.0
% INFO    : Bus 6970	: V=1.020925, theta=-46.712181 -> V=1.0, theta=0.0
% INFO    : Bus 6971	: V=1.058891, theta=-15.907161 -> V=1.0, theta=0.0
% INFO    : Bus 6972	: V=1.036075, theta=-5.904054 -> V=1.0, theta=0.0
% INFO    : Bus 6973	: V=1.016606, theta=7.865112 -> V=1.0, theta=0.0
% INFO    : Bus 6974	: V=0.991487, theta=-20.978285 -> V=1.0, theta=0.0
% INFO    : Bus 6975	: V=0.99645, theta=-26.963968 -> V=1.0, theta=0.0
% INFO    : Bus 6976	: V=0.916596, theta=-35.844928 -> V=1.0, theta=0.0
% INFO    : Bus 6977	: V=1.032865, theta=-0.690816 -> V=1.0, theta=0.0
% INFO    : Bus 6978	: V=1.065903, theta=45.68187 -> V=1.0, theta=0.0
% INFO    : Bus 6979	: V=1.019782, theta=-8.698855 -> V=1.0, theta=0.0
% INFO    : Bus 6980	: V=1.034733, theta=13.970076 -> V=1.0, theta=0.0
% INFO    : Bus 6981	: V=1.006038, theta=5.432391 -> V=1.0, theta=0.0
% INFO    : Bus 6982	: V=1.039641, theta=-21.299201 -> V=1.0, theta=0.0
% INFO    : Bus 6983	: V=1.018641, theta=13.955711 -> V=1.0, theta=0.0
% INFO    : Bus 6984	: V=0.85042, theta=-39.715801 -> V=1.0, theta=0.0
% INFO    : Bus 6985	: V=1.023726, theta=-54.438443 -> V=1.0, theta=0.0
% INFO    : Bus 6986	: V=1.021862, theta=51.360184 -> V=1.0, theta=0.0
% INFO    : Bus 6987	: V=1.036672, theta=2.72691 -> V=1.0, theta=0.0
% INFO    : Bus 6988	: V=0.984204, theta=-31.843275 -> V=1.0, theta=0.0
% INFO    : Bus 6989	: V=1.041863, theta=-24.366301 -> V=1.0, theta=0.0
% INFO    : Bus 6990	: V=1.045081, theta=-24.415761 -> V=1.0, theta=0.0
% INFO    : Bus 6991	: V=1.023401, theta=-27.835001 -> V=1.0, theta=0.0
% INFO    : Bus 6992	: V=1.008232, theta=-38.128195 -> V=1.0, theta=0.0
% INFO    : Bus 6993	: V=1.069361, theta=34.929165 -> V=1.0, theta=0.0
% INFO    : Bus 6994	: V=1.018182, theta=-41.506416 -> V=1.0, theta=0.0
% INFO    : Bus 6995	: V=1.036507, theta=2.851584 -> V=1.0, theta=0.0
% INFO    : Bus 6996	: V=1.041131, theta=-17.086191 -> V=1.0, theta=0.0
% INFO    : Bus 6997	: V=0.990611, theta=-8.595684 -> V=1.0, theta=0.0
% INFO    : Bus 6998	: V=1.022559, theta=8.17473 -> V=1.0, theta=0.0
% INFO    : Bus 6999	: V=1.083106, theta=-14.553923 -> V=1.0, theta=0.0
% INFO    : Bus 7000	: V=1.06783, theta=-19.57607 -> V=1.0, theta=0.0
% INFO    : Bus 7001	: V=1.001649, theta=-25.341796 -> V=1.0, theta=0.0
% INFO    : Bus 7002	: V=1.027944, theta=-42.390022 -> V=1.0, theta=0.0
% INFO    : Bus 7003	: V=1.018511, theta=-16.167688 -> V=1.0, theta=0.0
% INFO    : Bus 7004	: V=1.047845, theta=18.20106 -> V=1.0, theta=0.0
% INFO    : Bus 7005	: V=1.020264, theta=-28.161001 -> V=1.0, theta=0.0
% INFO    : Bus 7006	: V=1.044873, theta=52.29999 -> V=1.0, theta=0.0
% INFO    : Bus 7007	: V=1.003454, theta=-26.41149 -> V=1.0, theta=0.0
% INFO    : Bus 7008	: V=1.04776, theta=-29.710984 -> V=1.0, theta=0.0
% INFO    : Bus 7009	: V=1.036539, theta=7.192909 -> V=1.0, theta=0.0
% INFO    : Bus 7010	: V=1.028432, theta=-27.289128 -> V=1.0, theta=0.0
% INFO    : Bus 7011	: V=1.02726, theta=7.833295 -> V=1.0, theta=0.0
% INFO    : Bus 7012	: V=1.045141, theta=-25.390576 -> V=1.0, theta=0.0
% INFO    : Bus 7013	: V=1.03657, theta=8.839728 -> V=1.0, theta=0.0
% INFO    : Bus 7014	: V=1.032053, theta=-2.878521 -> V=1.0, theta=0.0
% INFO    : Bus 7015	: V=1.045951, theta=-25.528326 -> V=1.0, theta=0.0
% INFO    : Bus 7016	: V=1.007348, theta=-37.328107 -> V=1.0, theta=0.0
% INFO    : Bus 7017	: V=1.066885, theta=-17.152077 -> V=1.0, theta=0.0
% INFO    : Bus 7018	: V=1.023351, theta=11.178136 -> V=1.0, theta=0.0
% INFO    : Bus 7019	: V=1.038185, theta=-26.156975 -> V=1.0, theta=0.0
% INFO    : Bus 7020	: V=0.992233, theta=-34.753986 -> V=1.0, theta=0.0
% INFO    : Bus 7021	: V=1.003991, theta=-17.389789 -> V=1.0, theta=0.0
% INFO    : Bus 7022	: V=1.033177, theta=-23.873027 -> V=1.0, theta=0.0
% INFO    : Bus 7023	: V=0.961286, theta=-31.66657 -> V=1.0, theta=0.0
% INFO    : Bus 7024	: V=1.01541, theta=-32.309824 -> V=1.0, theta=0.0
% INFO    : Bus 7025	: V=1.027158, theta=8.837805 -> V=1.0, theta=0.0
% INFO    : Bus 7026	: V=1.01494, theta=7.860167 -> V=1.0, theta=0.0
% INFO    : Bus 7027	: V=1.043049, theta=-17.690411 -> V=1.0, theta=0.0
% INFO    : Bus 7028	: V=1.031022, theta=15.293375 -> V=1.0, theta=0.0
% INFO    : Bus 7029	: V=1.058412, theta=-37.465559 -> V=1.0, theta=0.0
% INFO    : Bus 7030	: V=1.055302, theta=-8.059104 -> V=1.0, theta=0.0
% INFO    : Bus 7031	: V=1.026374, theta=-33.913457 -> V=1.0, theta=0.0
% INFO    : Bus 7032	: V=1.004806, theta=-21.757638 -> V=1.0, theta=0.0
% INFO    : Bus 7033	: V=1.098728, theta=-21.123741 -> V=1.0, theta=0.0
% INFO    : Bus 7034	: V=0.988671, theta=-30.990507 -> V=1.0, theta=0.0
% INFO    : Bus 7035	: V=1.012093, theta=23.698604 -> V=1.0, theta=0.0
% INFO    : Bus 7036	: V=1.038394, theta=-12.636984 -> V=1.0, theta=0.0
% INFO    : Bus 7037	: V=0.986557, theta=-56.179606 -> V=1.0, theta=0.0
% INFO    : Bus 7038	: V=1.02997, theta=-34.33488 -> V=1.0, theta=0.0
% INFO    : Bus 7039	: V=1.025647, theta=-11.475663 -> V=1.0, theta=0.0
% INFO    : Bus 7040	: V=1.006841, theta=-28.372228 -> V=1.0, theta=0.0
% INFO    : Bus 7041	: V=1.010693, theta=-42.421354 -> V=1.0, theta=0.0
% INFO    : Bus 7042	: V=1.050508, theta=-30.568646 -> V=1.0, theta=0.0
% INFO    : Bus 7043	: V=1.020104, theta=-14.479523 -> V=1.0, theta=0.0
% INFO    : Bus 7044	: V=1.039381, theta=-33.747307 -> V=1.0, theta=0.0
% INFO    : Bus 7045	: V=1.013374, theta=-19.56497 -> V=1.0, theta=0.0
% INFO    : Bus 7046	: V=1.09164, theta=-27.608366 -> V=1.0, theta=0.0
% INFO    : Bus 7047	: V=1.031776, theta=-22.247708 -> V=1.0, theta=0.0
% INFO    : Bus 7048	: V=1.010337, theta=-24.15527 -> V=1.0, theta=0.0
% INFO    : Bus 7049	: V=1.052472, theta=-14.395209 -> V=1.0, theta=0.0
% INFO    : Bus 7050	: V=1.034621, theta=-21.547605 -> V=1.0, theta=0.0
% INFO    : Bus 7051	: V=0.992555, theta=-0.609221 -> V=1.0, theta=0.0
% INFO    : Bus 7052	: V=1.051113, theta=-12.473183 -> V=1.0, theta=0.0
% INFO    : Bus 7053	: V=1.062405, theta=-41.501124 -> V=1.0, theta=0.0
% INFO    : Bus 7054	: V=1.021776, theta=-28.875823 -> V=1.0, theta=0.0
% INFO    : Bus 7055	: V=1.033958, theta=-13.939042 -> V=1.0, theta=0.0
% INFO    : Bus 7056	: V=1.000187, theta=-4.542481 -> V=1.0, theta=0.0
% INFO    : Bus 7057	: V=0.964811, theta=-31.483445 -> V=1.0, theta=0.0
% INFO    : Bus 7058	: V=1.040913, theta=-36.969182 -> V=1.0, theta=0.0
% INFO    : Bus 7059	: V=1.023192, theta=8.964208 -> V=1.0, theta=0.0
% INFO    : Bus 7060	: V=1.023557, theta=-7.713513 -> V=1.0, theta=0.0
% INFO    : Bus 7061	: V=1.017417, theta=-15.622114 -> V=1.0, theta=0.0
% INFO    : Bus 7062	: V=1.037352, theta=-25.302957 -> V=1.0, theta=0.0
% INFO    : Bus 7063	: V=1.059581, theta=-15.448599 -> V=1.0, theta=0.0
% INFO    : Bus 7064	: V=1.010017, theta=-47.239712 -> V=1.0, theta=0.0
% INFO    : Bus 7065	: V=1.019881, theta=-20.228686 -> V=1.0, theta=0.0
% INFO    : Bus 7066	: V=1.026491, theta=-40.896042 -> V=1.0, theta=0.0
% INFO    : Bus 7067	: V=0.954479, theta=-30.312019 -> V=1.0, theta=0.0
% INFO    : Bus 7068	: V=1.051283, theta=-21.393887 -> V=1.0, theta=0.0
% INFO    : Bus 7069	: V=1.034779, theta=-8.197856 -> V=1.0, theta=0.0
% INFO    : Bus 7070	: V=1.042461, theta=-13.76476 -> V=1.0, theta=0.0
% INFO    : Bus 7071	: V=1.013438, theta=-36.673949 -> V=1.0, theta=0.0
% INFO    : Bus 7072	: V=1.015382, theta=-35.580216 -> V=1.0, theta=0.0
% INFO    : Bus 7073	: V=1.046708, theta=8.458606 -> V=1.0, theta=0.0
% INFO    : Bus 7074	: V=1.00388, theta=-31.357499 -> V=1.0, theta=0.0
% INFO    : Bus 7075	: V=1.019093, theta=-43.133872 -> V=1.0, theta=0.0
% INFO    : Bus 7076	: V=1.027182, theta=-12.740408 -> V=1.0, theta=0.0
% INFO    : Bus 7077	: V=1.020593, theta=-28.291209 -> V=1.0, theta=0.0
% INFO    : Bus 7078	: V=1.009728, theta=-30.47591 -> V=1.0, theta=0.0
% INFO    : Bus 7079	: V=1.036534, theta=-51.990596 -> V=1.0, theta=0.0
% INFO    : Bus 7080	: V=1.014551, theta=-22.607149 -> V=1.0, theta=0.0
% INFO    : Bus 7081	: V=1.064899, theta=-37.690039 -> V=1.0, theta=0.0
% INFO    : Bus 7082	: V=1.021393, theta=-7.314334 -> V=1.0, theta=0.0
% INFO    : Bus 7083	: V=1.004805, theta=-4.709685 -> V=1.0, theta=0.0
% INFO    : Bus 7084	: V=1.006489, theta=-25.146599 -> V=1.0, theta=0.0
% INFO    : Bus 7085	: V=1.044403, theta=10.521716 -> V=1.0, theta=0.0
% INFO    : Bus 7086	: V=1.011412, theta=-38.830245 -> V=1.0, theta=0.0
% INFO    : Bus 7087	: V=1.04466, theta=-23.032906 -> V=1.0, theta=0.0
% INFO    : Bus 7088	: V=0.973574, theta=-32.247772 -> V=1.0, theta=0.0
% INFO    : Bus 7089	: V=1.081026, theta=11.515562 -> V=1.0, theta=0.0
% INFO    : Bus 7090	: V=1.031643, theta=10.359545 -> V=1.0, theta=0.0
% INFO    : Bus 7091	: V=1.017136, theta=-28.972189 -> V=1.0, theta=0.0
% INFO    : Bus 7092	: V=1.043734, theta=-25.430923 -> V=1.0, theta=0.0
% INFO    : Bus 7093	: V=1.03985, theta=35.192342 -> V=1.0, theta=0.0
% INFO    : Bus 7094	: V=1.015676, theta=0.741492 -> V=1.0, theta=0.0
% INFO    : Bus 7095	: V=1.01832, theta=-30.055686 -> V=1.0, theta=0.0
% INFO    : Bus 7096	: V=1.066995, theta=-40.951798 -> V=1.0, theta=0.0
% INFO    : Bus 7097	: V=1.014749, theta=6.93111 -> V=1.0, theta=0.0
% INFO    : Bus 7098	: V=1.036326, theta=-2.652895 -> V=1.0, theta=0.0
% INFO    : Bus 7099	: V=1.015959, theta=36.786282 -> V=1.0, theta=0.0
% INFO    : Bus 7100	: V=0.973184, theta=-34.115427 -> V=1.0, theta=0.0
% INFO    : Bus 7101	: V=1.028926, theta=-28.291929 -> V=1.0, theta=0.0
% INFO    : Bus 7102	: V=1.02884, theta=1.689902 -> V=1.0, theta=0.0
% INFO    : Bus 7103	: V=1.016158, theta=-28.311302 -> V=1.0, theta=0.0
% INFO    : Bus 7104	: V=1.002634, theta=-29.070294 -> V=1.0, theta=0.0
% INFO    : Bus 7105	: V=1.094875, theta=-31.536519 -> V=1.0, theta=0.0
% INFO    : Bus 7106	: V=1.070254, theta=-26.565172 -> V=1.0, theta=0.0
% INFO    : Bus 7107	: V=1.040026, theta=-5.420572 -> V=1.0, theta=0.0
% INFO    : Bus 7108	: V=1.016025, theta=-41.954894 -> V=1.0, theta=0.0
% INFO    : Bus 7109	: V=0.990039, theta=-17.90541 -> V=1.0, theta=0.0
% INFO    : Bus 7110	: V=1.021163, theta=-42.21352 -> V=1.0, theta=0.0
% INFO    : Bus 7111	: V=1.056462, theta=-38.889606 -> V=1.0, theta=0.0
% INFO    : Bus 7112	: V=1.055047, theta=-26.127795 -> V=1.0, theta=0.0
% INFO    : Bus 7113	: V=1.033847, theta=-7.032003 -> V=1.0, theta=0.0
% INFO    : Bus 7114	: V=1.083134, theta=4.617435 -> V=1.0, theta=0.0
% INFO    : Bus 7115	: V=1.026738, theta=-15.536813 -> V=1.0, theta=0.0
% INFO    : Bus 7116	: V=1.016276, theta=1.615489 -> V=1.0, theta=0.0
% INFO    : Bus 7117	: V=1.03102, theta=26.404933 -> V=1.0, theta=0.0
% INFO    : Bus 7118	: V=1.108858, theta=-21.938093 -> V=1.0, theta=0.0
% INFO    : Bus 7119	: V=1.009263, theta=-16.529806 -> V=1.0, theta=0.0
% INFO    : Bus 7120	: V=1.065996, theta=-12.920134 -> V=1.0, theta=0.0
% INFO    : Bus 7121	: V=1.016626, theta=-28.916482 -> V=1.0, theta=0.0
% INFO    : Bus 7122	: V=1.14349, theta=-21.530056 -> V=1.0, theta=0.0
% INFO    : Bus 7123	: V=1.010031, theta=-36.741184 -> V=1.0, theta=0.0
% INFO    : Bus 7124	: V=1.068939, theta=-27.474719 -> V=1.0, theta=0.0
% INFO    : Bus 7125	: V=1.005032, theta=11.493321 -> V=1.0, theta=0.0
% INFO    : Bus 7126	: V=1.008391, theta=-24.561842 -> V=1.0, theta=0.0
% INFO    : Bus 7127	: V=1.012402, theta=-17.910043 -> V=1.0, theta=0.0
% INFO    : Bus 7128	: V=1.007918, theta=17.912282 -> V=1.0, theta=0.0
% INFO    : Bus 7129	: V=1.033259, theta=-3.259642 -> V=1.0, theta=0.0
% INFO    : Bus 7130	: V=1.022819, theta=-24.428657 -> V=1.0, theta=0.0
% INFO    : Bus 7131	: V=1.056852, theta=-23.705839 -> V=1.0, theta=0.0
% INFO    : Bus 7132	: V=1.025359, theta=-15.656092 -> V=1.0, theta=0.0
% INFO    : Bus 7133	: V=1.043055, theta=-14.04535 -> V=1.0, theta=0.0
% INFO    : Bus 7134	: V=1.039671, theta=11.116123 -> V=1.0, theta=0.0
% INFO    : Bus 7135	: V=1.026445, theta=-11.206428 -> V=1.0, theta=0.0
% INFO    : Bus 7136	: V=1.027007, theta=7.151388 -> V=1.0, theta=0.0
% INFO    : Bus 7137	: V=1.024472, theta=-45.229123 -> V=1.0, theta=0.0
% INFO    : Bus 7138	: V=1.015276, theta=-4.651351 -> V=1.0, theta=0.0
% INFO    : Bus 7139	: V=1.026773, theta=-54.251658 -> V=1.0, theta=0.0
% INFO    : Bus 7140	: V=1.01882, theta=1.935449 -> V=1.0, theta=0.0
% INFO    : Bus 7141	: V=1.044296, theta=-28.134322 -> V=1.0, theta=0.0
% INFO    : Bus 7142	: V=0.986331, theta=-28.704613 -> V=1.0, theta=0.0
% INFO    : Bus 7143	: V=0.967584, theta=-32.441251 -> V=1.0, theta=0.0
% INFO    : Bus 7144	: V=1.024916, theta=-13.312237 -> V=1.0, theta=0.0
% INFO    : Bus 7145	: V=1.011612, theta=-58.744613 -> V=1.0, theta=0.0
% INFO    : Bus 7146	: V=1.079481, theta=31.593816 -> V=1.0, theta=0.0
% INFO    : Bus 7147	: V=1.033187, theta=3.270759 -> V=1.0, theta=0.0
% INFO    : Bus 7148	: V=1.046487, theta=-23.666485 -> V=1.0, theta=0.0
% INFO    : Bus 7149	: V=1.053577, theta=-17.345053 -> V=1.0, theta=0.0
% INFO    : Bus 7150	: V=1.05817, theta=-24.085398 -> V=1.0, theta=0.0
% INFO    : Bus 7151	: V=0.970303, theta=-28.709834 -> V=1.0, theta=0.0
% INFO    : Bus 7152	: V=1.042145, theta=-28.526496 -> V=1.0, theta=0.0
% INFO    : Bus 7153	: V=1.034539, theta=-24.674893 -> V=1.0, theta=0.0
% INFO    : Bus 7154	: V=1.035929, theta=-3.51424 -> V=1.0, theta=0.0
% INFO    : Bus 7155	: V=1.00228, theta=-31.656527 -> V=1.0, theta=0.0
% INFO    : Bus 7156	: V=1.047271, theta=8.411476 -> V=1.0, theta=0.0
% INFO    : Bus 7157	: V=1.027513, theta=5.388751 -> V=1.0, theta=0.0
% INFO    : Bus 7158	: V=0.999862, theta=6.947454 -> V=1.0, theta=0.0
% INFO    : Bus 7159	: V=1.055132, theta=4.464452 -> V=1.0, theta=0.0
% INFO    : Bus 7160	: V=1.023736, theta=3.817974 -> V=1.0, theta=0.0
% INFO    : Bus 7161	: V=0.997387, theta=9.734185 -> V=1.0, theta=0.0
% INFO    : Bus 7162	: V=1.042623, theta=-13.767265 -> V=1.0, theta=0.0
% INFO    : Bus 7163	: V=1.045634, theta=-25.197 -> V=1.0, theta=0.0
% INFO    : Bus 7164	: V=1.024409, theta=-22.545445 -> V=1.0, theta=0.0
% INFO    : Bus 7165	: V=1.066671, theta=-34.484319 -> V=1.0, theta=0.0
% INFO    : Bus 7166	: V=1.002006, theta=-26.80616 -> V=1.0, theta=0.0
% INFO    : Bus 7167	: V=1.002622, theta=-35.62321 -> V=1.0, theta=0.0
% INFO    : Bus 7168	: V=1.008085, theta=-23.034104 -> V=1.0, theta=0.0
% INFO    : Bus 7169	: V=1.087809, theta=42.474107 -> V=1.0, theta=0.0
% INFO    : Bus 7170	: V=1.053025, theta=-6.907386 -> V=1.0, theta=0.0
% INFO    : Bus 7171	: V=1.04536, theta=-20.925425 -> V=1.0, theta=0.0
% INFO    : Bus 7172	: V=0.991117, theta=-30.792246 -> V=1.0, theta=0.0
% INFO    : Bus 7173	: V=1.027247, theta=4.050137 -> V=1.0, theta=0.0
% INFO    : Bus 7174	: V=1.043805, theta=1.379832 -> V=1.0, theta=0.0
% INFO    : Bus 7175	: V=1.014832, theta=23.048441 -> V=1.0, theta=0.0
% INFO    : Bus 7176	: V=1.015634, theta=-35.212323 -> V=1.0, theta=0.0
% INFO    : Bus 7177	: V=1.017537, theta=-38.058658 -> V=1.0, theta=0.0
% INFO    : Bus 7178	: V=1.01172, theta=-14.547245 -> V=1.0, theta=0.0
% INFO    : Bus 7179	: V=1.020654, theta=-4.830216 -> V=1.0, theta=0.0
% INFO    : Bus 7180	: V=0.976049, theta=-7.262397 -> V=1.0, theta=0.0
% INFO    : Bus 7181	: V=1.056719, theta=-25.761257 -> V=1.0, theta=0.0
% INFO    : Bus 7182	: V=1.016598, theta=-43.031895 -> V=1.0, theta=0.0
% INFO    : Bus 7183	: V=1.104721, theta=-7.066134 -> V=1.0, theta=0.0
% INFO    : Bus 7184	: V=1.029441, theta=-0.041577 -> V=1.0, theta=0.0
% INFO    : Bus 7185	: V=1.015765, theta=-28.366088 -> V=1.0, theta=0.0
% INFO    : Bus 7186	: V=1.011199, theta=-24.534116 -> V=1.0, theta=0.0
% INFO    : Bus 7187	: V=1.007999, theta=-40.530577 -> V=1.0, theta=0.0
% INFO    : Bus 7188	: V=1.016588, theta=-6.620753 -> V=1.0, theta=0.0
% INFO    : Bus 7189	: V=1.028643, theta=-16.495545 -> V=1.0, theta=0.0
% INFO    : Bus 7190	: V=0.982642, theta=-31.428797 -> V=1.0, theta=0.0
% INFO    : Bus 7191	: V=1.021115, theta=-48.781587 -> V=1.0, theta=0.0
% INFO    : Bus 7192	: V=0.979313, theta=-27.16062 -> V=1.0, theta=0.0
% INFO    : Bus 7193	: V=1.015962, theta=-47.157967 -> V=1.0, theta=0.0
% INFO    : Bus 7194	: V=1.006994, theta=51.272937 -> V=1.0, theta=0.0
% INFO    : Bus 7195	: V=1.018676, theta=0.762842 -> V=1.0, theta=0.0
% INFO    : Bus 7196	: V=1.022369, theta=-55.130527 -> V=1.0, theta=0.0
% INFO    : Bus 7197	: V=1.04408, theta=-43.548131 -> V=1.0, theta=0.0
% INFO    : Bus 7198	: V=1.041752, theta=-3.275387 -> V=1.0, theta=0.0
% INFO    : Bus 7199	: V=0.997694, theta=-26.738112 -> V=1.0, theta=0.0
% INFO    : Bus 7200	: V=1.022531, theta=-29.01631 -> V=1.0, theta=0.0
% INFO    : Bus 7201	: V=0.964669, theta=-24.813208 -> V=1.0, theta=0.0
% INFO    : Bus 7202	: V=1.048931, theta=-4.187607 -> V=1.0, theta=0.0
% INFO    : Bus 7203	: V=1.031691, theta=-26.556416 -> V=1.0, theta=0.0
% INFO    : Bus 7204	: V=1.074559, theta=-25.861826 -> V=1.0, theta=0.0
% INFO    : Bus 7205	: V=1.004397, theta=-30.090261 -> V=1.0, theta=0.0
% INFO    : Bus 7206	: V=1.013173, theta=11.41942 -> V=1.0, theta=0.0
% INFO    : Bus 7207	: V=1.039936, theta=35.201132 -> V=1.0, theta=0.0
% INFO    : Bus 7208	: V=0.974903, theta=-35.35308 -> V=1.0, theta=0.0
% INFO    : Bus 7209	: V=1.049275, theta=-6.593882 -> V=1.0, theta=0.0
% INFO    : Bus 7210	: V=1.068185, theta=-31.443276 -> V=1.0, theta=0.0
% INFO    : Bus 7211	: V=0.988078, theta=-20.950879 -> V=1.0, theta=0.0
% INFO    : Bus 7212	: V=1.021331, theta=-44.432519 -> V=1.0, theta=0.0
% INFO    : Bus 7213	: V=1.022468, theta=-7.333554 -> V=1.0, theta=0.0
% INFO    : Bus 7214	: V=1.0752, theta=8.895766 -> V=1.0, theta=0.0
% INFO    : Bus 7215	: V=1.019269, theta=-14.406567 -> V=1.0, theta=0.0
% INFO    : Bus 7216	: V=0.935606, theta=-33.742689 -> V=1.0, theta=0.0
% INFO    : Bus 7217	: V=1.02958, theta=21.227948 -> V=1.0, theta=0.0
% INFO    : Bus 7218	: V=1.024869, theta=-9.306127 -> V=1.0, theta=0.0
% INFO    : Bus 7219	: V=1.02589, theta=-22.734407 -> V=1.0, theta=0.0
% INFO    : Bus 7220	: V=1.009426, theta=-4.732275 -> V=1.0, theta=0.0
% INFO    : Bus 7221	: V=0.923556, theta=-33.061189 -> V=1.0, theta=0.0
% INFO    : Bus 7222	: V=1.062175, theta=-24.161142 -> V=1.0, theta=0.0
% INFO    : Bus 7223	: V=1.018777, theta=2.39191 -> V=1.0, theta=0.0
% INFO    : Bus 7224	: V=1.003808, theta=-27.599126 -> V=1.0, theta=0.0
% INFO    : Bus 7225	: V=1.045374, theta=-22.979064 -> V=1.0, theta=0.0
% INFO    : Bus 7226	: V=1.016944, theta=-15.886541 -> V=1.0, theta=0.0
% INFO    : Bus 7227	: V=1.008346, theta=1.023457 -> V=1.0, theta=0.0
% INFO    : Bus 7228	: V=1.172784, theta=-19.671404 -> V=1.0, theta=0.0
% INFO    : Bus 7229	: V=0.96078, theta=-31.700326 -> V=1.0, theta=0.0
% INFO    : Bus 7230	: V=1.021156, theta=10.861291 -> V=1.0, theta=0.0
% INFO    : Bus 7231	: V=1.035344, theta=-11.772407 -> V=1.0, theta=0.0
% INFO    : Bus 7232	: V=0.994308, theta=-31.830644 -> V=1.0, theta=0.0
% INFO    : Bus 7233	: V=1.021669, theta=-32.12307 -> V=1.0, theta=0.0
% INFO    : Bus 7234	: V=1.018027, theta=-42.307076 -> V=1.0, theta=0.0
% INFO    : Bus 7235	: V=1.051434, theta=38.85912 -> V=1.0, theta=0.0
% INFO    : Bus 7236	: V=0.962801, theta=-44.351836 -> V=1.0, theta=0.0
% INFO    : Bus 7237	: V=0.974217, theta=-31.060355 -> V=1.0, theta=0.0
% INFO    : Bus 7238	: V=1.019781, theta=-12.721337 -> V=1.0, theta=0.0
% INFO    : Bus 7239	: V=1.004347, theta=-30.856234 -> V=1.0, theta=0.0
% INFO    : Bus 7240	: V=1.033934, theta=47.079127 -> V=1.0, theta=0.0
% INFO    : Bus 7241	: V=1.010777, theta=-39.215522 -> V=1.0, theta=0.0
% INFO    : Bus 7242	: V=1.021069, theta=-28.41258 -> V=1.0, theta=0.0
% INFO    : Bus 7243	: V=0.981044, theta=-32.367839 -> V=1.0, theta=0.0
% INFO    : Bus 7244	: V=1.008394, theta=-3.368331 -> V=1.0, theta=0.0
% INFO    : Bus 7245	: V=0.982593, theta=9.30718 -> V=1.0, theta=0.0
% INFO    : Bus 7246	: V=1.024264, theta=-25.998758 -> V=1.0, theta=0.0
% INFO    : Bus 7247	: V=1.053601, theta=-28.968049 -> V=1.0, theta=0.0
% INFO    : Bus 7248	: V=1.024517, theta=-30.84311 -> V=1.0, theta=0.0
% INFO    : Bus 7249	: V=1.028006, theta=-42.600996 -> V=1.0, theta=0.0
% INFO    : Bus 7250	: V=1.041313, theta=-25.406873 -> V=1.0, theta=0.0
% INFO    : Bus 7251	: V=0.995125, theta=-30.856007 -> V=1.0, theta=0.0
% INFO    : Bus 7252	: V=0.961795, theta=-44.756426 -> V=1.0, theta=0.0
% INFO    : Bus 7253	: V=1.035374, theta=-3.050273 -> V=1.0, theta=0.0
% INFO    : Bus 7254	: V=1.043589, theta=-20.621975 -> V=1.0, theta=0.0
% INFO    : Bus 7255	: V=1.009289, theta=-40.079993 -> V=1.0, theta=0.0
% INFO    : Bus 7256	: V=1.007111, theta=-34.649721 -> V=1.0, theta=0.0
% INFO    : Bus 7257	: V=1.023182, theta=-46.899294 -> V=1.0, theta=0.0
% INFO    : Bus 7258	: V=1.006474, theta=-36.041466 -> V=1.0, theta=0.0
% INFO    : Bus 7259	: V=1.055097, theta=-8.128627 -> V=1.0, theta=0.0
% INFO    : Bus 7260	: V=1.020734, theta=18.488306 -> V=1.0, theta=0.0
% INFO    : Bus 7261	: V=1.050327, theta=30.877519 -> V=1.0, theta=0.0
% INFO    : Bus 7262	: V=1.071381, theta=-33.363949 -> V=1.0, theta=0.0
% INFO    : Bus 7263	: V=1.017688, theta=-22.517768 -> V=1.0, theta=0.0
% INFO    : Bus 7264	: V=1.037453, theta=-11.256183 -> V=1.0, theta=0.0
% INFO    : Bus 7265	: V=1.018104, theta=-20.137 -> V=1.0, theta=0.0
% INFO    : Bus 7266	: V=1.02803, theta=-5.817903 -> V=1.0, theta=0.0
% INFO    : Bus 7267	: V=1.006635, theta=-7.962981 -> V=1.0, theta=0.0
% INFO    : Bus 7268	: V=1.029606, theta=-15.712052 -> V=1.0, theta=0.0
% INFO    : Bus 7269	: V=1.018141, theta=-32.156086 -> V=1.0, theta=0.0
% INFO    : Bus 7270	: V=1.063771, theta=26.076966 -> V=1.0, theta=0.0
% INFO    : Bus 7271	: V=1.050328, theta=-24.814128 -> V=1.0, theta=0.0
% INFO    : Bus 7272	: V=1.044203, theta=-26.082613 -> V=1.0, theta=0.0
% INFO    : Bus 7273	: V=1.038052, theta=-24.670916 -> V=1.0, theta=0.0
% INFO    : Bus 7274	: V=1.03186, theta=-4.222416 -> V=1.0, theta=0.0
% INFO    : Bus 7275	: V=1.044197, theta=3.98215 -> V=1.0, theta=0.0
% INFO    : Bus 7276	: V=1.042871, theta=-21.734523 -> V=1.0, theta=0.0
% INFO    : Bus 7277	: V=1.02596, theta=-22.59388 -> V=1.0, theta=0.0
% INFO    : Bus 7278	: V=1.063694, theta=-15.573936 -> V=1.0, theta=0.0
% INFO    : Bus 7279	: V=1.02664, theta=-13.635302 -> V=1.0, theta=0.0
% INFO    : Bus 7280	: V=1.035372, theta=-21.48109 -> V=1.0, theta=0.0
% INFO    : Bus 7281	: V=1.020691, theta=-24.050831 -> V=1.0, theta=0.0
% INFO    : Bus 7282	: V=1.029197, theta=-4.82313 -> V=1.0, theta=0.0
% INFO    : Bus 7283	: V=1.03338, theta=-46.106964 -> V=1.0, theta=0.0
% INFO    : Bus 7284	: V=1.085432, theta=-1.082662 -> V=1.0, theta=0.0
% INFO    : Bus 7285	: V=1.108938, theta=-29.514945 -> V=1.0, theta=0.0
% INFO    : Bus 7286	: V=1.056629, theta=-24.199026 -> V=1.0, theta=0.0
% INFO    : Bus 7287	: V=1.060667, theta=-41.565457 -> V=1.0, theta=0.0
% INFO    : Bus 7288	: V=1.012472, theta=-25.361801 -> V=1.0, theta=0.0
% INFO    : Bus 7289	: V=1.049679, theta=-6.239897 -> V=1.0, theta=0.0
% INFO    : Bus 7290	: V=1.016232, theta=-32.6798 -> V=1.0, theta=0.0
% INFO    : Bus 7291	: V=1.0255, theta=-11.196419 -> V=1.0, theta=0.0
% INFO    : Bus 7292	: V=1.028167, theta=-34.087434 -> V=1.0, theta=0.0
% INFO    : Bus 7293	: V=1.029739, theta=-9.45721 -> V=1.0, theta=0.0
% INFO    : Bus 7294	: V=0.991451, theta=-27.535638 -> V=1.0, theta=0.0
% INFO    : Bus 7295	: V=1.040482, theta=2.636868 -> V=1.0, theta=0.0
% INFO    : Bus 7296	: V=1.0138, theta=-17.179093 -> V=1.0, theta=0.0
% INFO    : Bus 7297	: V=1.040466, theta=2.636616 -> V=1.0, theta=0.0
% INFO    : Bus 7298	: V=1.03893, theta=9.638331 -> V=1.0, theta=0.0
% INFO    : Bus 7299	: V=1.015409, theta=52.961176 -> V=1.0, theta=0.0
% INFO    : Bus 7300	: V=0.994058, theta=-30.578514 -> V=1.0, theta=0.0
% INFO    : Bus 7301	: V=0.984897, theta=-31.81215 -> V=1.0, theta=0.0
% INFO    : Bus 7302	: V=1.023792, theta=-1.567692 -> V=1.0, theta=0.0
% INFO    : Bus 7303	: V=1.026431, theta=-43.382912 -> V=1.0, theta=0.0
% INFO    : Bus 7304	: V=1.01082, theta=-27.278081 -> V=1.0, theta=0.0
% INFO    : Bus 7305	: V=1.044909, theta=3.479513 -> V=1.0, theta=0.0
% INFO    : Bus 7306	: V=1.00785, theta=-32.36366 -> V=1.0, theta=0.0
% INFO    : Bus 7307	: V=0.981231, theta=-35.406383 -> V=1.0, theta=0.0
% INFO    : Bus 7308	: V=0.95998, theta=-22.856198 -> V=1.0, theta=0.0
% INFO    : Bus 7309	: V=1.05059, theta=-11.653422 -> V=1.0, theta=0.0
% INFO    : Bus 7310	: V=1.022253, theta=-46.41738 -> V=1.0, theta=0.0
% INFO    : Bus 7311	: V=1.021381, theta=-48.724733 -> V=1.0, theta=0.0
% INFO    : Bus 7312	: V=1.002377, theta=-48.515496 -> V=1.0, theta=0.0
% INFO    : Bus 7313	: V=1.143494, theta=-24.568389 -> V=1.0, theta=0.0
% INFO    : Bus 7314	: V=1.130799, theta=-25.608096 -> V=1.0, theta=0.0
% INFO    : Bus 7315	: V=1.054837, theta=-32.593249 -> V=1.0, theta=0.0
% INFO    : Bus 7316	: V=1.043172, theta=-7.351483 -> V=1.0, theta=0.0
% INFO    : Bus 7317	: V=1.036146, theta=-3.693886 -> V=1.0, theta=0.0
% INFO    : Bus 7318	: V=1.023928, theta=19.805822 -> V=1.0, theta=0.0
% INFO    : Bus 7319	: V=1.014013, theta=-26.553685 -> V=1.0, theta=0.0
% INFO    : Bus 7320	: V=1.014993, theta=-36.020364 -> V=1.0, theta=0.0
% INFO    : Bus 7321	: V=1.016304, theta=20.570874 -> V=1.0, theta=0.0
% INFO    : Bus 7322	: V=0.985729, theta=-31.284095 -> V=1.0, theta=0.0
% INFO    : Bus 7323	: V=1.002613, theta=-29.942299 -> V=1.0, theta=0.0
% INFO    : Bus 7324	: V=1.025703, theta=-5.011162 -> V=1.0, theta=0.0
% INFO    : Bus 7325	: V=1.042768, theta=-13.023775 -> V=1.0, theta=0.0
% INFO    : Bus 7326	: V=0.998326, theta=-25.231875 -> V=1.0, theta=0.0
% INFO    : Bus 7327	: V=1.046207, theta=-18.098445 -> V=1.0, theta=0.0
% INFO    : Bus 7328	: V=0.98954, theta=-14.833223 -> V=1.0, theta=0.0
% INFO    : Bus 7329	: V=1.037608, theta=-34.291657 -> V=1.0, theta=0.0
% INFO    : Bus 7330	: V=1.166291, theta=-21.054036 -> V=1.0, theta=0.0
% INFO    : Bus 7331	: V=1.064241, theta=-37.878234 -> V=1.0, theta=0.0
% INFO    : Bus 7332	: V=1.018065, theta=-3.120514 -> V=1.0, theta=0.0
% INFO    : Bus 7333	: V=1.036075, theta=-29.78924 -> V=1.0, theta=0.0
% INFO    : Bus 7334	: V=1.027071, theta=-39.633663 -> V=1.0, theta=0.0
% INFO    : Bus 7335	: V=1.02041, theta=-5.272859 -> V=1.0, theta=0.0
% INFO    : Bus 7336	: V=0.992771, theta=-17.685822 -> V=1.0, theta=0.0
% INFO    : Bus 7337	: V=1.015107, theta=-6.438735 -> V=1.0, theta=0.0
% INFO    : Bus 7338	: V=1.042914, theta=-14.841123 -> V=1.0, theta=0.0
% INFO    : Bus 7339	: V=0.997809, theta=-30.283644 -> V=1.0, theta=0.0
% INFO    : Bus 7340	: V=1.019852, theta=-29.550767 -> V=1.0, theta=0.0
% INFO    : Bus 7341	: V=1.036058, theta=-2.795886 -> V=1.0, theta=0.0
% INFO    : Bus 7342	: V=1.014786, theta=-16.173977 -> V=1.0, theta=0.0
% INFO    : Bus 7343	: V=1.026913, theta=-43.465223 -> V=1.0, theta=0.0
% INFO    : Bus 7344	: V=1.002717, theta=-30.609813 -> V=1.0, theta=0.0
% INFO    : Bus 7345	: V=0.978292, theta=-32.010355 -> V=1.0, theta=0.0
% INFO    : Bus 7346	: V=1.044003, theta=14.367709 -> V=1.0, theta=0.0
% INFO    : Bus 7347	: V=1.008541, theta=-48.920169 -> V=1.0, theta=0.0
% INFO    : Bus 7348	: V=1.084423, theta=-16.467495 -> V=1.0, theta=0.0
% INFO    : Bus 7349	: V=1.014685, theta=-51.502231 -> V=1.0, theta=0.0
% INFO    : Bus 7350	: V=1.027675, theta=6.194663 -> V=1.0, theta=0.0
% INFO    : Bus 7351	: V=1.033161, theta=-3.263056 -> V=1.0, theta=0.0
% INFO    : Bus 7352	: V=1.011167, theta=0.526638 -> V=1.0, theta=0.0
% INFO    : Bus 7353	: V=0.985079, theta=-22.561059 -> V=1.0, theta=0.0
% INFO    : Bus 7354	: V=1.003437, theta=-29.755843 -> V=1.0, theta=0.0
% INFO    : Bus 7355	: V=1.040333, theta=8.324539 -> V=1.0, theta=0.0
% INFO    : Bus 7356	: V=0.980107, theta=-29.959298 -> V=1.0, theta=0.0
% INFO    : Bus 7357	: V=1.026055, theta=-25.145654 -> V=1.0, theta=0.0
% INFO    : Bus 7358	: V=0.996928, theta=-48.829455 -> V=1.0, theta=0.0
% INFO    : Bus 7359	: V=1.046487, theta=-26.102165 -> V=1.0, theta=0.0
% INFO    : Bus 7360	: V=0.976728, theta=13.47457 -> V=1.0, theta=0.0
% INFO    : Bus 7361	: V=1.051981, theta=-15.532005 -> V=1.0, theta=0.0
% INFO    : Bus 7362	: V=1.032049, theta=-3.472036 -> V=1.0, theta=0.0
% INFO    : Bus 7363	: V=1.005537, theta=-25.548958 -> V=1.0, theta=0.0
% INFO    : Bus 7364	: V=1.115295, theta=-23.60728 -> V=1.0, theta=0.0
% INFO    : Bus 7365	: V=0.985997, theta=-27.51912 -> V=1.0, theta=0.0
% INFO    : Bus 7366	: V=1.012248, theta=-40.784255 -> V=1.0, theta=0.0
% INFO    : Bus 7367	: V=1.027876, theta=-18.951852 -> V=1.0, theta=0.0
% INFO    : Bus 7368	: V=0.968835, theta=-31.329943 -> V=1.0, theta=0.0
% INFO    : Bus 7369	: V=1.014772, theta=17.844108 -> V=1.0, theta=0.0
% INFO    : Bus 7370	: V=1.034338, theta=7.51478 -> V=1.0, theta=0.0
% INFO    : Bus 7371	: V=1.010706, theta=4.159172 -> V=1.0, theta=0.0
% INFO    : Bus 7372	: V=1.004081, theta=-19.703313 -> V=1.0, theta=0.0
% INFO    : Bus 7373	: V=1.066452, theta=-23.971054 -> V=1.0, theta=0.0
% INFO    : Bus 7374	: V=1.020851, theta=-1.172884 -> V=1.0, theta=0.0
% INFO    : Bus 7375	: V=1.047027, theta=-25.519254 -> V=1.0, theta=0.0
% INFO    : Bus 7376	: V=1.041198, theta=3.572761 -> V=1.0, theta=0.0
% INFO    : Bus 7377	: V=1.012383, theta=-16.331531 -> V=1.0, theta=0.0
% INFO    : Bus 7378	: V=0.994011, theta=-9.356245 -> V=1.0, theta=0.0
% INFO    : Bus 7379	: V=1.017015, theta=2.059734 -> V=1.0, theta=0.0
% INFO    : Bus 7380	: V=0.988082, theta=-14.843414 -> V=1.0, theta=0.0
% INFO    : Bus 7381	: V=0.998683, theta=-32.343314 -> V=1.0, theta=0.0
% INFO    : Bus 7382	: V=0.945608, theta=-29.541812 -> V=1.0, theta=0.0
% INFO    : Bus 7383	: V=1.011076, theta=-36.03631 -> V=1.0, theta=0.0
% INFO    : Bus 7384	: V=0.990709, theta=-21.745983 -> V=1.0, theta=0.0
% INFO    : Bus 7385	: V=1.016823, theta=-40.623861 -> V=1.0, theta=0.0
% INFO    : Bus 7386	: V=1.023477, theta=6.232212 -> V=1.0, theta=0.0
% INFO    : Bus 7387	: V=0.981743, theta=-31.650542 -> V=1.0, theta=0.0
% INFO    : Bus 7388	: V=1.079481, theta=31.593816 -> V=1.0, theta=0.0
% INFO    : Bus 7389	: V=1.014668, theta=-32.548395 -> V=1.0, theta=0.0
% INFO    : Bus 7390	: V=1.047851, theta=-35.726585 -> V=1.0, theta=0.0
% INFO    : Bus 7391	: V=1.033694, theta=-21.446299 -> V=1.0, theta=0.0
% INFO    : Bus 7392	: V=1.008915, theta=-55.287574 -> V=1.0, theta=0.0
% INFO    : Bus 7393	: V=1.057049, theta=-24.684949 -> V=1.0, theta=0.0
% INFO    : Bus 7394	: V=1.043868, theta=8.975598 -> V=1.0, theta=0.0
% INFO    : Bus 7395	: V=1.019928, theta=-44.315775 -> V=1.0, theta=0.0
% INFO    : Bus 7396	: V=1.016684, theta=-19.679601 -> V=1.0, theta=0.0
% INFO    : Bus 7397	: V=0.981241, theta=-27.966079 -> V=1.0, theta=0.0
% INFO    : Bus 7398	: V=1.013724, theta=-50.85172 -> V=1.0, theta=0.0
% INFO    : Bus 7399	: V=1.021627, theta=16.485616 -> V=1.0, theta=0.0
% INFO    : Bus 7400	: V=1.014538, theta=-27.099328 -> V=1.0, theta=0.0
% INFO    : Bus 7401	: V=1.018508, theta=9.298494 -> V=1.0, theta=0.0
% INFO    : Bus 7402	: V=1.015015, theta=-30.091097 -> V=1.0, theta=0.0
% INFO    : Bus 7403	: V=1.003818, theta=-50.897179 -> V=1.0, theta=0.0
% INFO    : Bus 7404	: V=1.058779, theta=10.889206 -> V=1.0, theta=0.0
% INFO    : Bus 7405	: V=1.034205, theta=-23.672695 -> V=1.0, theta=0.0
% INFO    : Bus 7406	: V=1.023941, theta=-47.986677 -> V=1.0, theta=0.0
% INFO    : Bus 7407	: V=1.020293, theta=-4.164944 -> V=1.0, theta=0.0
% INFO    : Bus 7408	: V=1.010858, theta=-9.720144 -> V=1.0, theta=0.0
% INFO    : Bus 7409	: V=0.866113, theta=-38.811746 -> V=1.0, theta=0.0
% INFO    : Bus 7410	: V=1.00468, theta=-18.331887 -> V=1.0, theta=0.0
% INFO    : Bus 7411	: V=0.999197, theta=-39.199433 -> V=1.0, theta=0.0
% INFO    : Bus 7412	: V=1.047787, theta=63.702085 -> V=1.0, theta=0.0
% INFO    : Bus 7413	: V=1.027443, theta=-54.133826 -> V=1.0, theta=0.0
% INFO    : Bus 7414	: V=1.017764, theta=-28.743126 -> V=1.0, theta=0.0
% INFO    : Bus 7415	: V=0.992829, theta=-25.884348 -> V=1.0, theta=0.0
% INFO    : Bus 7416	: V=1.034259, theta=66.585489 -> V=1.0, theta=0.0
% INFO    : Bus 7417	: V=1.034614, theta=-46.039871 -> V=1.0, theta=0.0
% INFO    : Bus 7418	: V=1.082134, theta=-20.046836 -> V=1.0, theta=0.0
% INFO    : Bus 7419	: V=0.964639, theta=-24.814322 -> V=1.0, theta=0.0
% INFO    : Bus 7420	: V=1.026099, theta=-33.962005 -> V=1.0, theta=0.0
% INFO    : Bus 7421	: V=1.030592, theta=-34.106483 -> V=1.0, theta=0.0
% INFO    : Bus 7422	: V=1.030703, theta=-10.888099 -> V=1.0, theta=0.0
% INFO    : Bus 7423	: V=1.017598, theta=-40.734394 -> V=1.0, theta=0.0
% INFO    : Bus 7424	: V=1.013443, theta=-12.494664 -> V=1.0, theta=0.0
% INFO    : Bus 7425	: V=1.038275, theta=-0.668044 -> V=1.0, theta=0.0
% INFO    : Bus 7426	: V=1.012408, theta=-19.2322 -> V=1.0, theta=0.0
% INFO    : Bus 7427	: V=1.072596, theta=-22.451974 -> V=1.0, theta=0.0
% INFO    : Bus 7428	: V=1.043312, theta=-50.518322 -> V=1.0, theta=0.0
% INFO    : Bus 7429	: V=1.011339, theta=-5.731264 -> V=1.0, theta=0.0
% INFO    : Bus 7430	: V=0.992466, theta=9.075547 -> V=1.0, theta=0.0
% INFO    : Bus 7431	: V=1.016271, theta=-33.87332 -> V=1.0, theta=0.0
% INFO    : Bus 7432	: V=1.040989, theta=-21.158174 -> V=1.0, theta=0.0
% INFO    : Bus 7433	: V=0.981792, theta=-34.919816 -> V=1.0, theta=0.0
% INFO    : Bus 7434	: V=1.048635, theta=1.215771 -> V=1.0, theta=0.0
% INFO    : Bus 7435	: V=0.983989, theta=-31.364669 -> V=1.0, theta=0.0
% INFO    : Bus 7436	: V=1.019386, theta=-50.516499 -> V=1.0, theta=0.0
% INFO    : Bus 7437	: V=1.039177, theta=-25.992105 -> V=1.0, theta=0.0
% INFO    : Bus 7438	: V=1.030599, theta=-13.038703 -> V=1.0, theta=0.0
% INFO    : Bus 7439	: V=0.959246, theta=-30.912503 -> V=1.0, theta=0.0
% INFO    : Bus 7440	: V=1.023632, theta=31.656073 -> V=1.0, theta=0.0
% INFO    : Bus 7441	: V=1.021033, theta=-20.073125 -> V=1.0, theta=0.0
% INFO    : Bus 7442	: V=1.015133, theta=16.414535 -> V=1.0, theta=0.0
% INFO    : Bus 7443	: V=1.044874, theta=14.986516 -> V=1.0, theta=0.0
% INFO    : Bus 7444	: V=1.038851, theta=11.46126 -> V=1.0, theta=0.0
% INFO    : Bus 7445	: V=1.026914, theta=49.225874 -> V=1.0, theta=0.0
% INFO    : Bus 7446	: V=1.008326, theta=-46.24313 -> V=1.0, theta=0.0
% INFO    : Bus 7447	: V=1.018055, theta=-8.026783 -> V=1.0, theta=0.0
% INFO    : Bus 7448	: V=1.059456, theta=-15.726807 -> V=1.0, theta=0.0
% INFO    : Bus 7449	: V=1.017627, theta=61.478443 -> V=1.0, theta=0.0
% INFO    : Bus 7450	: V=1.021344, theta=10.842619 -> V=1.0, theta=0.0
% INFO    : Bus 7451	: V=0.996166, theta=9.117017 -> V=1.0, theta=0.0
% INFO    : Bus 7452	: V=1.04041, theta=-39.709614 -> V=1.0, theta=0.0
% INFO    : Bus 7453	: V=0.999445, theta=-32.159093 -> V=1.0, theta=0.0
% INFO    : Bus 7454	: V=1.046271, theta=-8.202077 -> V=1.0, theta=0.0
% INFO    : Bus 7455	: V=1.086657, theta=-14.067392 -> V=1.0, theta=0.0
% INFO    : Bus 7456	: V=1.076625, theta=-17.396277 -> V=1.0, theta=0.0
% INFO    : Bus 7457	: V=1.042806, theta=-3.068932 -> V=1.0, theta=0.0
% INFO    : Bus 7458	: V=1.057103, theta=-22.285226 -> V=1.0, theta=0.0
% INFO    : Bus 7459	: V=1.037978, theta=-21.221717 -> V=1.0, theta=0.0
% INFO    : Bus 7460	: V=1.037667, theta=-46.665179 -> V=1.0, theta=0.0
% INFO    : Bus 7461	: V=1.015254, theta=-23.621982 -> V=1.0, theta=0.0
% INFO    : Bus 7462	: V=1.042191, theta=-23.736143 -> V=1.0, theta=0.0
% INFO    : Bus 7463	: V=1.025555, theta=-54.035347 -> V=1.0, theta=0.0
% INFO    : Bus 7464	: V=1.038219, theta=-12.663099 -> V=1.0, theta=0.0
% INFO    : Bus 7465	: V=1.012708, theta=61.67261 -> V=1.0, theta=0.0
% INFO    : Bus 7466	: V=1.060565, theta=-34.28863 -> V=1.0, theta=0.0
% INFO    : Bus 7467	: V=1.032778, theta=-23.639814 -> V=1.0, theta=0.0
% INFO    : Bus 7468	: V=0.973649, theta=-32.737856 -> V=1.0, theta=0.0
% INFO    : Bus 7469	: V=0.96597, theta=-22.232088 -> V=1.0, theta=0.0
% INFO    : Bus 7470	: V=1.07691, theta=-35.421507 -> V=1.0, theta=0.0
% INFO    : Bus 7471	: V=1.012658, theta=-6.664898 -> V=1.0, theta=0.0
% INFO    : Bus 7472	: V=1.04852, theta=-16.614246 -> V=1.0, theta=0.0
% INFO    : Bus 7473	: V=1.041663, theta=-15.791744 -> V=1.0, theta=0.0
% INFO    : Bus 7474	: V=1.035524, theta=-14.622562 -> V=1.0, theta=0.0
% INFO    : Bus 7475	: V=1.023441, theta=-54.63894 -> V=1.0, theta=0.0
% INFO    : Bus 7476	: V=1.037093, theta=5.951041 -> V=1.0, theta=0.0
% INFO    : Bus 7477	: V=1.036246, theta=-26.543946 -> V=1.0, theta=0.0
% INFO    : Bus 7478	: V=0.941728, theta=-34.204462 -> V=1.0, theta=0.0
% INFO    : Bus 7479	: V=0.999232, theta=-51.517521 -> V=1.0, theta=0.0
% INFO    : Bus 7480	: V=1.017363, theta=17.213196 -> V=1.0, theta=0.0
% INFO    : Bus 7481	: V=1.025922, theta=4.612908 -> V=1.0, theta=0.0
% INFO    : Bus 7482	: V=0.964965, theta=-31.459019 -> V=1.0, theta=0.0
% INFO    : Bus 7483	: V=1.049175, theta=49.216593 -> V=1.0, theta=0.0
% INFO    : Bus 7484	: V=1.02013, theta=-25.824468 -> V=1.0, theta=0.0
% INFO    : Bus 7485	: V=1.038191, theta=-26.165239 -> V=1.0, theta=0.0
% INFO    : Bus 7486	: V=0.9702, theta=-27.71633 -> V=1.0, theta=0.0
% INFO    : Bus 7487	: V=1.018688, theta=-29.208471 -> V=1.0, theta=0.0
% INFO    : Bus 7488	: V=0.986342, theta=14.700495 -> V=1.0, theta=0.0
% INFO    : Bus 7489	: V=1.007426, theta=-49.42421 -> V=1.0, theta=0.0
% INFO    : Bus 7490	: V=1.097048, theta=45.389496 -> V=1.0, theta=0.0
% INFO    : Bus 7491	: V=1.007019, theta=-21.833553 -> V=1.0, theta=0.0
% INFO    : Bus 7492	: V=1.05365, theta=18.017409 -> V=1.0, theta=0.0
% INFO    : Bus 7493	: V=1.035207, theta=3.445303 -> V=1.0, theta=0.0
% INFO    : Bus 7494	: V=1.01018, theta=-36.985158 -> V=1.0, theta=0.0
% INFO    : Bus 7495	: V=1.031216, theta=-15.255053 -> V=1.0, theta=0.0
% INFO    : Bus 7496	: V=1.026541, theta=-23.154781 -> V=1.0, theta=0.0
% INFO    : Bus 7497	: V=1.040579, theta=-39.790195 -> V=1.0, theta=0.0
% INFO    : Bus 7498	: V=1.000261, theta=-3.434589 -> V=1.0, theta=0.0
% INFO    : Bus 7499	: V=0.999526, theta=-16.796989 -> V=1.0, theta=0.0
% INFO    : Bus 7500	: V=1.039826, theta=-14.486951 -> V=1.0, theta=0.0
% INFO    : Bus 7501	: V=0.994734, theta=-34.15431 -> V=1.0, theta=0.0
% INFO    : Bus 7502	: V=1.035437, theta=19.496096 -> V=1.0, theta=0.0
% INFO    : Bus 7503	: V=0.997238, theta=-43.422688 -> V=1.0, theta=0.0
% INFO    : Bus 7504	: V=1.015325, theta=-43.221319 -> V=1.0, theta=0.0
% INFO    : Bus 7505	: V=1.033062, theta=-0.176606 -> V=1.0, theta=0.0
% INFO    : Bus 7506	: V=1.068978, theta=-22.479995 -> V=1.0, theta=0.0
% INFO    : Bus 7507	: V=1.044799, theta=-24.411805 -> V=1.0, theta=0.0
% INFO    : Bus 7508	: V=1.058554, theta=-40.238969 -> V=1.0, theta=0.0
% INFO    : Bus 7509	: V=1.053987, theta=-48.004141 -> V=1.0, theta=0.0
% INFO    : Bus 7510	: V=1.022821, theta=-47.132805 -> V=1.0, theta=0.0
% INFO    : Bus 7511	: V=1.04215, theta=0.142791 -> V=1.0, theta=0.0
% INFO    : Bus 7512	: V=1.013069, theta=3.182736 -> V=1.0, theta=0.0
% INFO    : Bus 7513	: V=0.989662, theta=-15.298658 -> V=1.0, theta=0.0
% INFO    : Bus 7514	: V=1.019422, theta=24.07354 -> V=1.0, theta=0.0
% INFO    : Bus 7515	: V=1.058579, theta=-16.388932 -> V=1.0, theta=0.0
% INFO    : Bus 7516	: V=0.969057, theta=-22.128022 -> V=1.0, theta=0.0
% INFO    : Bus 7517	: V=1.057243, theta=-24.998707 -> V=1.0, theta=0.0
% INFO    : Bus 7518	: V=0.971666, theta=-22.117368 -> V=1.0, theta=0.0
% INFO    : Bus 7519	: V=1.033872, theta=-10.882569 -> V=1.0, theta=0.0
% INFO    : Bus 7520	: V=1.027003, theta=-9.358633 -> V=1.0, theta=0.0
% INFO    : Bus 7521	: V=1.008595, theta=-29.116434 -> V=1.0, theta=0.0
% INFO    : Bus 7522	: V=0.995659, theta=-11.246091 -> V=1.0, theta=0.0
% INFO    : Bus 7523	: V=1.050802, theta=-0.784953 -> V=1.0, theta=0.0
% INFO    : Bus 7524	: V=1.011914, theta=-8.720586 -> V=1.0, theta=0.0
% INFO    : Bus 7525	: V=1.022174, theta=17.018992 -> V=1.0, theta=0.0
% INFO    : Bus 7526	: V=1.021601, theta=6.203426 -> V=1.0, theta=0.0
% INFO    : Bus 7527	: V=1.024309, theta=4.17589 -> V=1.0, theta=0.0
% INFO    : Bus 7528	: V=1.015519, theta=-27.648326 -> V=1.0, theta=0.0
% INFO    : Bus 7529	: V=1.02609, theta=-25.261522 -> V=1.0, theta=0.0
% INFO    : Bus 7530	: V=1.043248, theta=-20.130634 -> V=1.0, theta=0.0
% INFO    : Bus 7531	: V=1.025896, theta=-35.482797 -> V=1.0, theta=0.0
% INFO    : Bus 7532	: V=1.069576, theta=-25.272383 -> V=1.0, theta=0.0
% INFO    : Bus 7533	: V=1.087886, theta=-21.828117 -> V=1.0, theta=0.0
% INFO    : Bus 7534	: V=0.993725, theta=-30.761815 -> V=1.0, theta=0.0
% INFO    : Bus 7535	: V=0.955662, theta=-33.07479 -> V=1.0, theta=0.0
% INFO    : Bus 7536	: V=1.00694, theta=-28.363401 -> V=1.0, theta=0.0
% INFO    : Bus 7537	: V=0.98576, theta=-15.917614 -> V=1.0, theta=0.0
% INFO    : Bus 7538	: V=1.005756, theta=-50.384652 -> V=1.0, theta=0.0
% INFO    : Bus 7539	: V=1.044276, theta=-12.725707 -> V=1.0, theta=0.0
% INFO    : Bus 7540	: V=1.003815, theta=-50.653713 -> V=1.0, theta=0.0
% INFO    : Bus 7541	: V=1.051631, theta=-16.709801 -> V=1.0, theta=0.0
% INFO    : Bus 7542	: V=1.060157, theta=-26.994694 -> V=1.0, theta=0.0
% INFO    : Bus 7543	: V=0.975873, theta=-35.299892 -> V=1.0, theta=0.0
% INFO    : Bus 7544	: V=1.021696, theta=65.99455 -> V=1.0, theta=0.0
% INFO    : Bus 7545	: V=1.035259, theta=34.769524 -> V=1.0, theta=0.0
% INFO    : Bus 7546	: V=0.917414, theta=-35.806411 -> V=1.0, theta=0.0
% INFO    : Bus 7547	: V=1.096732, theta=-23.861514 -> V=1.0, theta=0.0
% INFO    : Bus 7548	: V=1.025915, theta=-35.014202 -> V=1.0, theta=0.0
% INFO    : Bus 7549	: V=1.00146, theta=-19.644156 -> V=1.0, theta=0.0
% INFO    : Bus 7550	: V=1.001368, theta=-39.424985 -> V=1.0, theta=0.0
% INFO    : Bus 7551	: V=1.028534, theta=-4.964919 -> V=1.0, theta=0.0
% INFO    : Bus 7552	: V=1.021733, theta=-32.467743 -> V=1.0, theta=0.0
% INFO    : Bus 7553	: V=1.047249, theta=9.172669 -> V=1.0, theta=0.0
% INFO    : Bus 7554	: V=1.028509, theta=-25.716891 -> V=1.0, theta=0.0
% INFO    : Bus 7555	: V=0.992214, theta=-25.988665 -> V=1.0, theta=0.0
% INFO    : Bus 7556	: V=1.044301, theta=-33.52744 -> V=1.0, theta=0.0
% INFO    : Bus 7557	: V=1.051797, theta=-24.738071 -> V=1.0, theta=0.0
% INFO    : Bus 7558	: V=1.005058, theta=-22.194728 -> V=1.0, theta=0.0
% INFO    : Bus 7559	: V=1.017685, theta=61.838744 -> V=1.0, theta=0.0
% INFO    : Bus 7560	: V=1.054373, theta=-19.314276 -> V=1.0, theta=0.0
% INFO    : Bus 7561	: V=0.992829, theta=-4.851657 -> V=1.0, theta=0.0
% INFO    : Bus 7562	: V=1.047541, theta=-14.372444 -> V=1.0, theta=0.0
% INFO    : Bus 7563	: V=1.0345, theta=-13.492374 -> V=1.0, theta=0.0
% INFO    : Bus 7564	: V=0.99088, theta=-50.568992 -> V=1.0, theta=0.0
% INFO    : Bus 7565	: V=1.066837, theta=11.80124 -> V=1.0, theta=0.0
% INFO    : Bus 7566	: V=1.014086, theta=-33.092664 -> V=1.0, theta=0.0
% INFO    : Bus 7567	: V=1.029761, theta=7.240879 -> V=1.0, theta=0.0
% INFO    : Bus 7568	: V=1.043388, theta=-31.041557 -> V=1.0, theta=0.0
% INFO    : Bus 7569	: V=0.964544, theta=-56.318516 -> V=1.0, theta=0.0
% INFO    : Bus 7570	: V=1.038503, theta=7.330109 -> V=1.0, theta=0.0
% INFO    : Bus 7571	: V=1.040207, theta=-14.312963 -> V=1.0, theta=0.0
% INFO    : Bus 7572	: V=1.068923, theta=-15.021027 -> V=1.0, theta=0.0
% INFO    : Bus 7573	: V=1.026738, theta=-54.221012 -> V=1.0, theta=0.0
% INFO    : Bus 7574	: V=1.030705, theta=-38.228839 -> V=1.0, theta=0.0
% INFO    : Bus 7575	: V=1.050929, theta=9.688249 -> V=1.0, theta=0.0
% INFO    : Bus 7576	: V=1.034553, theta=-12.333688 -> V=1.0, theta=0.0
% INFO    : Bus 7577	: V=1.042437, theta=-10.786006 -> V=1.0, theta=0.0
% INFO    : Bus 7578	: V=1.002902, theta=-27.805666 -> V=1.0, theta=0.0
% INFO    : Bus 7579	: V=1.037135, theta=-27.098952 -> V=1.0, theta=0.0
% INFO    : Bus 7580	: V=1.0474, theta=-12.31099 -> V=1.0, theta=0.0
% INFO    : Bus 7581	: V=1.023178, theta=-0.742234 -> V=1.0, theta=0.0
% INFO    : Bus 7582	: V=1.030716, theta=-24.81618 -> V=1.0, theta=0.0
% INFO    : Bus 7583	: V=1.046345, theta=-1.027496 -> V=1.0, theta=0.0
% INFO    : Bus 7584	: V=1.03213, theta=-1.348827 -> V=1.0, theta=0.0
% INFO    : Bus 7585	: V=0.988991, theta=-27.243981 -> V=1.0, theta=0.0
% INFO    : Bus 7586	: V=1.017521, theta=-4.530708 -> V=1.0, theta=0.0
% INFO    : Bus 7587	: V=0.948139, theta=-32.704324 -> V=1.0, theta=0.0
% INFO    : Bus 7588	: V=0.99287, theta=-24.994466 -> V=1.0, theta=0.0
% INFO    : Bus 7589	: V=1.006818, theta=-39.42041 -> V=1.0, theta=0.0
% INFO    : Bus 7590	: V=1.002951, theta=-30.560312 -> V=1.0, theta=0.0
% INFO    : Bus 7591	: V=1.024724, theta=-34.262786 -> V=1.0, theta=0.0
% INFO    : Bus 7592	: V=1.050828, theta=1.68523 -> V=1.0, theta=0.0
% INFO    : Bus 7593	: V=1.023992, theta=-43.76072 -> V=1.0, theta=0.0
% INFO    : Bus 7594	: V=1.025746, theta=-8.684743 -> V=1.0, theta=0.0
% INFO    : Bus 7595	: V=0.987318, theta=-31.944297 -> V=1.0, theta=0.0
% INFO    : Bus 7596	: V=1.021583, theta=-1.074276 -> V=1.0, theta=0.0
% INFO    : Bus 7597	: V=1.050861, theta=-26.64185 -> V=1.0, theta=0.0
% INFO    : Bus 7598	: V=0.947931, theta=-32.207203 -> V=1.0, theta=0.0
% INFO    : Bus 7599	: V=1.031223, theta=-6.438893 -> V=1.0, theta=0.0
% INFO    : Bus 7600	: V=1.033028, theta=-46.17218 -> V=1.0, theta=0.0
% INFO    : Bus 7601	: V=1.034496, theta=58.686891 -> V=1.0, theta=0.0
% INFO    : Bus 7602	: V=1.030678, theta=-21.980192 -> V=1.0, theta=0.0
% INFO    : Bus 7603	: V=1.003179, theta=-41.85431 -> V=1.0, theta=0.0
% INFO    : Bus 7604	: V=0.98606, theta=-31.565215 -> V=1.0, theta=0.0
% INFO    : Bus 7605	: V=0.988635, theta=-31.00334 -> V=1.0, theta=0.0
% INFO    : Bus 7606	: V=1.003992, theta=-30.714976 -> V=1.0, theta=0.0
% INFO    : Bus 7607	: V=1.054831, theta=-17.179333 -> V=1.0, theta=0.0
% INFO    : Bus 7608	: V=0.967568, theta=-20.735638 -> V=1.0, theta=0.0
% INFO    : Bus 7609	: V=1.021437, theta=-3.015749 -> V=1.0, theta=0.0
% INFO    : Bus 7610	: V=0.981231, theta=-35.406383 -> V=1.0, theta=0.0
% INFO    : Bus 7611	: V=1.021653, theta=-47.204811 -> V=1.0, theta=0.0
% INFO    : Bus 7612	: V=1.041242, theta=-23.21805 -> V=1.0, theta=0.0
% INFO    : Bus 7613	: V=0.920496, theta=-33.041733 -> V=1.0, theta=0.0
% INFO    : Bus 7614	: V=1.019019, theta=5.953759 -> V=1.0, theta=0.0
% INFO    : Bus 7615	: V=0.981178, theta=-53.873099 -> V=1.0, theta=0.0
% INFO    : Bus 7616	: V=1.131608, theta=-22.062538 -> V=1.0, theta=0.0
% INFO    : Bus 7617	: V=1.049522, theta=-16.107883 -> V=1.0, theta=0.0
% INFO    : Bus 7618	: V=1.017916, theta=-29.278342 -> V=1.0, theta=0.0
% INFO    : Bus 7619	: V=1.037789, theta=-36.854382 -> V=1.0, theta=0.0
% INFO    : Bus 7620	: V=1.008205, theta=9.580034 -> V=1.0, theta=0.0
% INFO    : Bus 7621	: V=1.008866, theta=-33.752136 -> V=1.0, theta=0.0
% INFO    : Bus 7622	: V=1.033759, theta=-3.23424 -> V=1.0, theta=0.0
% INFO    : Bus 7623	: V=1.009701, theta=1.582877 -> V=1.0, theta=0.0
% INFO    : Bus 7624	: V=1.010731, theta=-21.256786 -> V=1.0, theta=0.0
% INFO    : Bus 7625	: V=1.072566, theta=4.746322 -> V=1.0, theta=0.0
% INFO    : Bus 7626	: V=1.02695, theta=-12.756876 -> V=1.0, theta=0.0
% INFO    : Bus 7627	: V=1.054377, theta=-24.30542 -> V=1.0, theta=0.0
% INFO    : Bus 7628	: V=1.064136, theta=3.784087 -> V=1.0, theta=0.0
% INFO    : Bus 7629	: V=1.015993, theta=-55.973239 -> V=1.0, theta=0.0
% INFO    : Bus 7630	: V=1.017306, theta=-44.944646 -> V=1.0, theta=0.0
% INFO    : Bus 7631	: V=1.032549, theta=38.780071 -> V=1.0, theta=0.0
% INFO    : Bus 7632	: V=1.022447, theta=-56.809735 -> V=1.0, theta=0.0
% INFO    : Bus 7633	: V=1.02035, theta=-35.218871 -> V=1.0, theta=0.0
% INFO    : Bus 7634	: V=1.014731, theta=-9.370106 -> V=1.0, theta=0.0
% INFO    : Bus 7635	: V=1.047307, theta=-7.949655 -> V=1.0, theta=0.0
% INFO    : Bus 7636	: V=1.032102, theta=-26.066906 -> V=1.0, theta=0.0
% INFO    : Bus 7637	: V=1.006165, theta=18.142288 -> V=1.0, theta=0.0
% INFO    : Bus 7638	: V=1.064775, theta=-21.698244 -> V=1.0, theta=0.0
% INFO    : Bus 7639	: V=1.016695, theta=-36.384211 -> V=1.0, theta=0.0
% INFO    : Bus 7640	: V=1.029162, theta=-6.10323 -> V=1.0, theta=0.0
% INFO    : Bus 7641	: V=1.049265, theta=-6.450367 -> V=1.0, theta=0.0
% INFO    : Bus 7642	: V=1.038438, theta=5.517843 -> V=1.0, theta=0.0
% INFO    : Bus 7643	: V=1.043026, theta=35.447616 -> V=1.0, theta=0.0
% INFO    : Bus 7644	: V=1.034619, theta=-46.307286 -> V=1.0, theta=0.0
% INFO    : Bus 7645	: V=1.028371, theta=-6.365534 -> V=1.0, theta=0.0
% INFO    : Bus 7646	: V=1.062816, theta=-11.73385 -> V=1.0, theta=0.0
% INFO    : Bus 7647	: V=1.058956, theta=-20.48042 -> V=1.0, theta=0.0
% INFO    : Bus 7648	: V=1.054998, theta=-25.914188 -> V=1.0, theta=0.0
% INFO    : Bus 7649	: V=0.993367, theta=-17.616084 -> V=1.0, theta=0.0
% INFO    : Bus 7650	: V=1.094733, theta=45.525792 -> V=1.0, theta=0.0
% INFO    : Bus 7651	: V=1.092516, theta=-27.545772 -> V=1.0, theta=0.0
% INFO    : Bus 7652	: V=0.980657, theta=6.38938 -> V=1.0, theta=0.0
% INFO    : Bus 7653	: V=1.032828, theta=-23.116419 -> V=1.0, theta=0.0
% INFO    : Bus 7654	: V=1.011955, theta=-7.817271 -> V=1.0, theta=0.0
% INFO    : Bus 7655	: V=1.013643, theta=8.708415 -> V=1.0, theta=0.0
% INFO    : Bus 7656	: V=1.013707, theta=-35.671719 -> V=1.0, theta=0.0
% INFO    : Bus 7657	: V=1.129049, theta=-21.956352 -> V=1.0, theta=0.0
% INFO    : Bus 7658	: V=1.004842, theta=-6.875549 -> V=1.0, theta=0.0
% INFO    : Bus 7659	: V=1.029603, theta=-40.886975 -> V=1.0, theta=0.0
% INFO    : Bus 7660	: V=1.055949, theta=-14.740226 -> V=1.0, theta=0.0
% INFO    : Bus 7661	: V=1.037591, theta=-34.298341 -> V=1.0, theta=0.0
% INFO    : Bus 7662	: V=1.023442, theta=8.989291 -> V=1.0, theta=0.0
% INFO    : Bus 7663	: V=1.038529, theta=-12.302936 -> V=1.0, theta=0.0
% INFO    : Bus 7664	: V=1.036686, theta=-19.852744 -> V=1.0, theta=0.0
% INFO    : Bus 7665	: V=1.029597, theta=-41.155975 -> V=1.0, theta=0.0
% INFO    : Bus 7666	: V=1.020655, theta=10.565208 -> V=1.0, theta=0.0
% INFO    : Bus 7667	: V=1.041165, theta=-3.322997 -> V=1.0, theta=0.0
% INFO    : Bus 7668	: V=1.035561, theta=-25.045778 -> V=1.0, theta=0.0
% INFO    : Bus 7669	: V=1.021363, theta=-49.000092 -> V=1.0, theta=0.0
% INFO    : Bus 7670	: V=1.005135, theta=67.228591 -> V=1.0, theta=0.0
% INFO    : Bus 7671	: V=1.080257, theta=-12.457265 -> V=1.0, theta=0.0
% INFO    : Bus 7672	: V=1.03982, theta=-12.082133 -> V=1.0, theta=0.0
% INFO    : Bus 7673	: V=1.043711, theta=-43.284962 -> V=1.0, theta=0.0
% INFO    : Bus 7674	: V=1.109684, theta=-28.896585 -> V=1.0, theta=0.0
% INFO    : Bus 7675	: V=1.012014, theta=0.036914 -> V=1.0, theta=0.0
% INFO    : Bus 7676	: V=1.074322, theta=37.491062 -> V=1.0, theta=0.0
% INFO    : Bus 7677	: V=1.009405, theta=-7.73948 -> V=1.0, theta=0.0
% INFO    : Bus 7678	: V=1.013019, theta=-11.992692 -> V=1.0, theta=0.0
% INFO    : Bus 7679	: V=1.024301, theta=-26.976625 -> V=1.0, theta=0.0
% INFO    : Bus 7680	: V=1.08519, theta=45.258983 -> V=1.0, theta=0.0
% INFO    : Bus 7681	: V=1.052405, theta=-21.118883 -> V=1.0, theta=0.0
% INFO    : Bus 7682	: V=1.020266, theta=-22.730451 -> V=1.0, theta=0.0
% INFO    : Bus 7683	: V=1.038382, theta=10.377986 -> V=1.0, theta=0.0
% INFO    : Bus 7684	: V=1.036834, theta=59.794276 -> V=1.0, theta=0.0
% INFO    : Bus 7685	: V=1.019277, theta=-44.594553 -> V=1.0, theta=0.0
% INFO    : Bus 7686	: V=1.051977, theta=-26.907359 -> V=1.0, theta=0.0
% INFO    : Bus 7687	: V=1.043409, theta=-30.144782 -> V=1.0, theta=0.0
% INFO    : Bus 7688	: V=1.041195, theta=-50.237731 -> V=1.0, theta=0.0
% INFO    : Bus 7689	: V=1.023364, theta=-7.753859 -> V=1.0, theta=0.0
% INFO    : Bus 7690	: V=1.021398, theta=3.775893 -> V=1.0, theta=0.0
% INFO    : Bus 7691	: V=1.02503, theta=-3.969225 -> V=1.0, theta=0.0
% INFO    : Bus 7692	: V=1.024576, theta=-26.04578 -> V=1.0, theta=0.0
% INFO    : Bus 7693	: V=1.025574, theta=-31.851042 -> V=1.0, theta=0.0
% INFO    : Bus 7694	: V=1.02559, theta=-15.023648 -> V=1.0, theta=0.0
% INFO    : Bus 7695	: V=1.023436, theta=-31.481035 -> V=1.0, theta=0.0
% INFO    : Bus 7696	: V=0.976851, theta=-31.464367 -> V=1.0, theta=0.0
% INFO    : Bus 7697	: V=1.050111, theta=-3.787728 -> V=1.0, theta=0.0
% INFO    : Bus 7698	: V=1.041522, theta=-25.438548 -> V=1.0, theta=0.0
% INFO    : Bus 7699	: V=1.041518, theta=10.8605 -> V=1.0, theta=0.0
% INFO    : Bus 7700	: V=1.016311, theta=-10.583646 -> V=1.0, theta=0.0
% INFO    : Bus 7701	: V=1.016426, theta=5.847338 -> V=1.0, theta=0.0
% INFO    : Bus 7702	: V=1.022518, theta=-16.488713 -> V=1.0, theta=0.0
% INFO    : Bus 7703	: V=1.007167, theta=-26.363898 -> V=1.0, theta=0.0
% INFO    : Bus 7704	: V=1.016558, theta=-30.283741 -> V=1.0, theta=0.0
% INFO    : Bus 7705	: V=1.001405, theta=-31.184725 -> V=1.0, theta=0.0
% INFO    : Bus 7706	: V=1.045653, theta=-7.902502 -> V=1.0, theta=0.0
% INFO    : Bus 7707	: V=1.042135, theta=18.811854 -> V=1.0, theta=0.0
% INFO    : Bus 7708	: V=1.003658, theta=67.616703 -> V=1.0, theta=0.0
% INFO    : Bus 7709	: V=1.012268, theta=-41.855728 -> V=1.0, theta=0.0
% INFO    : Bus 7710	: V=0.990419, theta=-32.797505 -> V=1.0, theta=0.0
% INFO    : Bus 7711	: V=1.05815, theta=-2.79987 -> V=1.0, theta=0.0
% INFO    : Bus 7712	: V=0.949809, theta=-29.215766 -> V=1.0, theta=0.0
% INFO    : Bus 7713	: V=0.999973, theta=-37.688524 -> V=1.0, theta=0.0
% INFO    : Bus 7714	: V=1.028066, theta=9.772573 -> V=1.0, theta=0.0
% INFO    : Bus 7715	: V=1.053765, theta=9.778906 -> V=1.0, theta=0.0
% INFO    : Bus 7716	: V=1.022625, theta=1.228696 -> V=1.0, theta=0.0
% INFO    : Bus 7717	: V=1.030901, theta=-9.649569 -> V=1.0, theta=0.0
% INFO    : Bus 7718	: V=1.008757, theta=-36.951753 -> V=1.0, theta=0.0
% INFO    : Bus 7719	: V=1.052232, theta=-20.129634 -> V=1.0, theta=0.0
% INFO    : Bus 7720	: V=0.870967, theta=-38.524972 -> V=1.0, theta=0.0
% INFO    : Bus 7721	: V=1.010822, theta=-34.672501 -> V=1.0, theta=0.0
% INFO    : Bus 7722	: V=0.992167, theta=-31.176403 -> V=1.0, theta=0.0
% INFO    : Bus 7723	: V=1.036019, theta=-32.272172 -> V=1.0, theta=0.0
% INFO    : Bus 7724	: V=1.002154, theta=-26.93002 -> V=1.0, theta=0.0
% INFO    : Bus 7725	: V=1.05186, theta=9.366514 -> V=1.0, theta=0.0
% INFO    : Bus 7726	: V=1.016206, theta=-10.548865 -> V=1.0, theta=0.0
% INFO    : Bus 7727	: V=1.020582, theta=-33.512439 -> V=1.0, theta=0.0
% INFO    : Bus 7728	: V=1.008042, theta=0.473824 -> V=1.0, theta=0.0
% INFO    : Bus 7729	: V=1.028639, theta=7.765834 -> V=1.0, theta=0.0
% INFO    : Bus 7730	: V=1.034831, theta=-28.044352 -> V=1.0, theta=0.0
% INFO    : Bus 7731	: V=1.021323, theta=-9.598819 -> V=1.0, theta=0.0
% INFO    : Bus 7732	: V=1.019657, theta=-26.015061 -> V=1.0, theta=0.0
% INFO    : Bus 7733	: V=1.000347, theta=-27.833154 -> V=1.0, theta=0.0
% INFO    : Bus 7734	: V=0.920987, theta=-34.594655 -> V=1.0, theta=0.0
% INFO    : Bus 7735	: V=1.020146, theta=-22.689264 -> V=1.0, theta=0.0
% INFO    : Bus 7736	: V=1.032289, theta=-1.351916 -> V=1.0, theta=0.0
% INFO    : Bus 7737	: V=1.061861, theta=-21.991295 -> V=1.0, theta=0.0
% INFO    : Bus 7738	: V=1.030914, theta=-22.34307 -> V=1.0, theta=0.0
% INFO    : Bus 7739	: V=1.005262, theta=-29.681727 -> V=1.0, theta=0.0
% INFO    : Bus 7740	: V=0.998038, theta=-32.178415 -> V=1.0, theta=0.0
% INFO    : Bus 7741	: V=1.049273, theta=43.29035 -> V=1.0, theta=0.0
% INFO    : Bus 7742	: V=1.016237, theta=61.636194 -> V=1.0, theta=0.0
% INFO    : Bus 7743	: V=1.011249, theta=-20.92784 -> V=1.0, theta=0.0
% INFO    : Bus 7744	: V=1.012901, theta=-26.277782 -> V=1.0, theta=0.0
% INFO    : Bus 7745	: V=0.989318, theta=-29.054312 -> V=1.0, theta=0.0
% INFO    : Bus 7746	: V=1.01801, theta=-5.451643 -> V=1.0, theta=0.0
% INFO    : Bus 7747	: V=1.007146, theta=-19.568569 -> V=1.0, theta=0.0
% INFO    : Bus 7748	: V=1.022866, theta=-6.081369 -> V=1.0, theta=0.0
% INFO    : Bus 7749	: V=1.023861, theta=-4.402046 -> V=1.0, theta=0.0
% INFO    : Bus 7750	: V=1.063487, theta=-20.192378 -> V=1.0, theta=0.0
% INFO    : Bus 7751	: V=1.024415, theta=-1.614683 -> V=1.0, theta=0.0
% INFO    : Bus 7752	: V=1.027001, theta=-18.689663 -> V=1.0, theta=0.0
% INFO    : Bus 7753	: V=1.012418, theta=-48.244731 -> V=1.0, theta=0.0
% INFO    : Bus 7754	: V=1.028685, theta=-6.819632 -> V=1.0, theta=0.0
% INFO    : Bus 7755	: V=1.058479, theta=-42.500332 -> V=1.0, theta=0.0
% INFO    : Bus 7756	: V=1.025067, theta=-29.462127 -> V=1.0, theta=0.0
% INFO    : Bus 7757	: V=1.062925, theta=-17.102366 -> V=1.0, theta=0.0
% INFO    : Bus 7758	: V=1.059721, theta=-12.30921 -> V=1.0, theta=0.0
% INFO    : Bus 7759	: V=1.17759, theta=-19.026092 -> V=1.0, theta=0.0
% INFO    : Bus 7760	: V=0.989841, theta=-21.852274 -> V=1.0, theta=0.0
% INFO    : Bus 7761	: V=1.012378, theta=-41.832827 -> V=1.0, theta=0.0
% INFO    : Bus 7762	: V=1.006235, theta=-3.979104 -> V=1.0, theta=0.0
% INFO    : Bus 7763	: V=1.053441, theta=-29.282647 -> V=1.0, theta=0.0
% INFO    : Bus 7764	: V=1.049594, theta=-20.329998 -> V=1.0, theta=0.0
% INFO    : Bus 7765	: V=0.996648, theta=-30.560945 -> V=1.0, theta=0.0
% INFO    : Bus 7766	: V=1.027943, theta=-12.996697 -> V=1.0, theta=0.0
% INFO    : Bus 7767	: V=1.026684, theta=-11.317489 -> V=1.0, theta=0.0
% INFO    : Bus 7768	: V=1.024697, theta=-33.481891 -> V=1.0, theta=0.0
% INFO    : Bus 7769	: V=1.027986, theta=-4.269849 -> V=1.0, theta=0.0
% INFO    : Bus 7770	: V=1.02163, theta=-44.828126 -> V=1.0, theta=0.0
% INFO    : Bus 7771	: V=1.071376, theta=44.31689 -> V=1.0, theta=0.0
% INFO    : Bus 7772	: V=1.053847, theta=-26.048725 -> V=1.0, theta=0.0
% INFO    : Bus 7773	: V=1.039391, theta=-27.930465 -> V=1.0, theta=0.0
% INFO    : Bus 7774	: V=1.001867, theta=-31.058425 -> V=1.0, theta=0.0
% INFO    : Bus 7775	: V=1.047794, theta=-29.282448 -> V=1.0, theta=0.0
% INFO    : Bus 7776	: V=1.077614, theta=5.972286 -> V=1.0, theta=0.0
% INFO    : Bus 7777	: V=1.074558, theta=-20.609018 -> V=1.0, theta=0.0
% INFO    : Bus 7778	: V=1.051431, theta=-16.82666 -> V=1.0, theta=0.0
% INFO    : Bus 7779	: V=1.0806, theta=10.157985 -> V=1.0, theta=0.0
% INFO    : Bus 7780	: V=1.048635, theta=1.215771 -> V=1.0, theta=0.0
% INFO    : Bus 7781	: V=1.046792, theta=9.207136 -> V=1.0, theta=0.0
% INFO    : Bus 7782	: V=1.029133, theta=-28.802489 -> V=1.0, theta=0.0
% INFO    : Bus 7783	: V=1.001462, theta=-31.048447 -> V=1.0, theta=0.0
% INFO    : Bus 7784	: V=1.027093, theta=-39.679574 -> V=1.0, theta=0.0
% INFO    : Bus 7785	: V=1.048533, theta=-23.635241 -> V=1.0, theta=0.0
% INFO    : Bus 7786	: V=1.022574, theta=-5.684416 -> V=1.0, theta=0.0
% INFO    : Bus 7787	: V=1.006266, theta=-49.628428 -> V=1.0, theta=0.0
% INFO    : Bus 7788	: V=1.008294, theta=1.280908 -> V=1.0, theta=0.0
% INFO    : Bus 7789	: V=1.021551, theta=4.549434 -> V=1.0, theta=0.0
% INFO    : Bus 7790	: V=1.043792, theta=-20.814489 -> V=1.0, theta=0.0
% INFO    : Bus 7791	: V=1.024916, theta=-13.291854 -> V=1.0, theta=0.0
% INFO    : Bus 7792	: V=1.006966, theta=-37.982122 -> V=1.0, theta=0.0
% INFO    : Bus 7793	: V=1.044057, theta=-20.54901 -> V=1.0, theta=0.0
% INFO    : Bus 7794	: V=0.991709, theta=-9.553785 -> V=1.0, theta=0.0
% INFO    : Bus 7795	: V=1.02187, theta=-46.825102 -> V=1.0, theta=0.0
% INFO    : Bus 7796	: V=1.059894, theta=-25.15852 -> V=1.0, theta=0.0
% INFO    : Bus 7797	: V=1.046734, theta=-24.420983 -> V=1.0, theta=0.0
% INFO    : Bus 7798	: V=1.015906, theta=-15.017134 -> V=1.0, theta=0.0
% INFO    : Bus 7799	: V=1.069146, theta=26.047995 -> V=1.0, theta=0.0
% INFO    : Bus 7800	: V=1.005948, theta=-30.077471 -> V=1.0, theta=0.0
% INFO    : Bus 7801	: V=1.013956, theta=-30.373281 -> V=1.0, theta=0.0
% INFO    : Bus 7802	: V=1.022063, theta=-25.266142 -> V=1.0, theta=0.0
% INFO    : Bus 7803	: V=1.031127, theta=13.410495 -> V=1.0, theta=0.0
% INFO    : Bus 7804	: V=1.006207, theta=-36.150902 -> V=1.0, theta=0.0
% INFO    : Bus 7805	: V=1.025046, theta=-54.258656 -> V=1.0, theta=0.0
% INFO    : Bus 7806	: V=0.992491, theta=-17.727224 -> V=1.0, theta=0.0
% INFO    : Bus 7807	: V=1.101652, theta=-20.569701 -> V=1.0, theta=0.0
% INFO    : Bus 7808	: V=1.050047, theta=-0.347653 -> V=1.0, theta=0.0
% INFO    : Bus 7809	: V=1.026576, theta=-11.552809 -> V=1.0, theta=0.0
% INFO    : Bus 7810	: V=1.046439, theta=-50.114824 -> V=1.0, theta=0.0
% INFO    : Bus 7811	: V=1.026871, theta=49.246356 -> V=1.0, theta=0.0
% INFO    : Bus 7812	: V=1.002777, theta=-18.289885 -> V=1.0, theta=0.0
% INFO    : Bus 7813	: V=0.967541, theta=-22.704345 -> V=1.0, theta=0.0
% INFO    : Bus 7814	: V=1.009504, theta=-7.482186 -> V=1.0, theta=0.0
% INFO    : Bus 7815	: V=1.02006, theta=-23.451919 -> V=1.0, theta=0.0
% INFO    : Bus 7816	: V=1.036197, theta=29.195301 -> V=1.0, theta=0.0
% INFO    : Bus 7817	: V=1.061023, theta=-23.840125 -> V=1.0, theta=0.0
% INFO    : Bus 7818	: V=1.036237, theta=-22.435799 -> V=1.0, theta=0.0
% INFO    : Bus 7819	: V=1.018324, theta=-40.60173 -> V=1.0, theta=0.0
% INFO    : Bus 7820	: V=1.012896, theta=-54.950671 -> V=1.0, theta=0.0
% INFO    : Bus 7821	: V=1.026152, theta=-51.381177 -> V=1.0, theta=0.0
% INFO    : Bus 7822	: V=0.823843, theta=-41.5372 -> V=1.0, theta=0.0
% INFO    : Bus 7823	: V=1.048501, theta=-21.383375 -> V=1.0, theta=0.0
% INFO    : Bus 7824	: V=1.046444, theta=-6.348461 -> V=1.0, theta=0.0
% INFO    : Bus 7825	: V=0.970598, theta=-32.19603 -> V=1.0, theta=0.0
% INFO    : Bus 7826	: V=1.046412, theta=-22.334303 -> V=1.0, theta=0.0
% INFO    : Bus 7827	: V=1.044339, theta=-42.983742 -> V=1.0, theta=0.0
% INFO    : Bus 7828	: V=1.057001, theta=-28.937439 -> V=1.0, theta=0.0
% INFO    : Bus 7829	: V=1.050303, theta=-4.935711 -> V=1.0, theta=0.0
% INFO    : Bus 7830	: V=1.092455, theta=-25.444573 -> V=1.0, theta=0.0
% INFO    : Bus 7831	: V=1.009604, theta=-11.59063 -> V=1.0, theta=0.0
% INFO    : Bus 7832	: V=1.014229, theta=-33.100575 -> V=1.0, theta=0.0
% INFO    : Bus 7833	: V=1.015416, theta=-47.445689 -> V=1.0, theta=0.0
% INFO    : Bus 7834	: V=1.002304, theta=-53.402463 -> V=1.0, theta=0.0
% INFO    : Bus 7835	: V=1.037848, theta=-31.476302 -> V=1.0, theta=0.0
% INFO    : Bus 7836	: V=0.997593, theta=-20.466901 -> V=1.0, theta=0.0
% INFO    : Bus 7837	: V=1.011735, theta=-30.33652 -> V=1.0, theta=0.0
% INFO    : Bus 7838	: V=0.983228, theta=-28.775608 -> V=1.0, theta=0.0
% INFO    : Bus 7839	: V=0.979413, theta=-31.941082 -> V=1.0, theta=0.0
% INFO    : Bus 7840	: V=1.03573, theta=-3.017599 -> V=1.0, theta=0.0
% INFO    : Bus 7841	: V=1.020631, theta=-33.510096 -> V=1.0, theta=0.0
% INFO    : Bus 7842	: V=1.014075, theta=-12.280157 -> V=1.0, theta=0.0
% INFO    : Bus 7843	: V=1.056109, theta=-19.444876 -> V=1.0, theta=0.0
% INFO    : Bus 7844	: V=1.0317, theta=10.360208 -> V=1.0, theta=0.0
% INFO    : Bus 7845	: V=1.027035, theta=-54.015313 -> V=1.0, theta=0.0
% INFO    : Bus 7846	: V=1.025574, theta=-31.851042 -> V=1.0, theta=0.0
% INFO    : Bus 7847	: V=1.038055, theta=-9.097914 -> V=1.0, theta=0.0
% INFO    : Bus 7848	: V=1.032951, theta=-30.886537 -> V=1.0, theta=0.0
% INFO    : Bus 7849	: V=1.023318, theta=30.245947 -> V=1.0, theta=0.0
% INFO    : Bus 7850	: V=1.013769, theta=-3.348148 -> V=1.0, theta=0.0
% INFO    : Bus 7851	: V=1.047047, theta=-20.77235 -> V=1.0, theta=0.0
% INFO    : Bus 7852	: V=1.017155, theta=-0.726874 -> V=1.0, theta=0.0
% INFO    : Bus 7853	: V=0.99252, theta=-27.279983 -> V=1.0, theta=0.0
% INFO    : Bus 7854	: V=1.018633, theta=29.625154 -> V=1.0, theta=0.0
% INFO    : Bus 7855	: V=1.011896, theta=-36.505361 -> V=1.0, theta=0.0
% INFO    : Bus 7856	: V=1.047691, theta=18.060892 -> V=1.0, theta=0.0
% INFO    : Bus 7857	: V=1.04716, theta=0.068415 -> V=1.0, theta=0.0
% INFO    : Bus 7858	: V=0.988647, theta=-30.973141 -> V=1.0, theta=0.0
% INFO    : Bus 7859	: V=1.003656, theta=8.317584 -> V=1.0, theta=0.0
% INFO    : Bus 7860	: V=1.054905, theta=-40.689948 -> V=1.0, theta=0.0
% INFO    : Bus 7861	: V=1.019154, theta=-42.999214 -> V=1.0, theta=0.0
% INFO    : Bus 7862	: V=1.035912, theta=-21.455395 -> V=1.0, theta=0.0
% INFO    : Bus 7863	: V=0.955712, theta=-33.401903 -> V=1.0, theta=0.0
% INFO    : Bus 7864	: V=0.997601, theta=-30.875063 -> V=1.0, theta=0.0
% INFO    : Bus 7865	: V=1.068569, theta=-26.767043 -> V=1.0, theta=0.0
% INFO    : Bus 7866	: V=0.968758, theta=-22.304933 -> V=1.0, theta=0.0
% INFO    : Bus 7867	: V=1.021717, theta=-22.153453 -> V=1.0, theta=0.0
% INFO    : Bus 7868	: V=1.015082, theta=-32.471155 -> V=1.0, theta=0.0
% INFO    : Bus 7869	: V=1.021806, theta=-46.913796 -> V=1.0, theta=0.0
% INFO    : Bus 7870	: V=1.051969, theta=-20.062222 -> V=1.0, theta=0.0
% INFO    : Bus 7871	: V=0.972605, theta=-32.139314 -> V=1.0, theta=0.0
% INFO    : Bus 7872	: V=1.04054, theta=-19.358814 -> V=1.0, theta=0.0
% INFO    : Bus 7873	: V=1.01927, theta=-15.386634 -> V=1.0, theta=0.0
% INFO    : Bus 7874	: V=1.0194, theta=16.370413 -> V=1.0, theta=0.0
% INFO    : Bus 7875	: V=0.985313, theta=-46.083564 -> V=1.0, theta=0.0
% INFO    : Bus 7876	: V=0.985245, theta=66.968754 -> V=1.0, theta=0.0
% INFO    : Bus 7877	: V=1.009463, theta=-46.023329 -> V=1.0, theta=0.0
% INFO    : Bus 7878	: V=1.057954, theta=-2.784924 -> V=1.0, theta=0.0
% INFO    : Bus 7879	: V=0.964375, theta=-56.251818 -> V=1.0, theta=0.0
% INFO    : Bus 7880	: V=1.024905, theta=20.048493 -> V=1.0, theta=0.0
% INFO    : Bus 7881	: V=1.059008, theta=-15.410365 -> V=1.0, theta=0.0
% INFO    : Bus 7882	: V=1.049105, theta=-18.501848 -> V=1.0, theta=0.0
% INFO    : Bus 7883	: V=1.047568, theta=-29.087445 -> V=1.0, theta=0.0
% INFO    : Bus 7884	: V=1.046188, theta=3.58426 -> V=1.0, theta=0.0
% INFO    : Bus 7885	: V=1.034688, theta=-21.418219 -> V=1.0, theta=0.0
% INFO    : Bus 7886	: V=1.015163, theta=-19.425489 -> V=1.0, theta=0.0
% INFO    : Bus 7887	: V=1.003818, theta=63.534546 -> V=1.0, theta=0.0
% INFO    : Bus 7888	: V=1.017363, theta=-21.654827 -> V=1.0, theta=0.0
% INFO    : Bus 7889	: V=1.059932, theta=-18.401721 -> V=1.0, theta=0.0
% INFO    : Bus 7890	: V=1.05789, theta=-2.175715 -> V=1.0, theta=0.0
% INFO    : Bus 7891	: V=1.034632, theta=-38.013968 -> V=1.0, theta=0.0
% INFO    : Bus 7892	: V=1.04376, theta=-11.60199 -> V=1.0, theta=0.0
% INFO    : Bus 7893	: V=1.018258, theta=-48.246771 -> V=1.0, theta=0.0
% INFO    : Bus 7894	: V=1.044899, theta=9.503577 -> V=1.0, theta=0.0
% INFO    : Bus 7895	: V=1.054848, theta=-19.868363 -> V=1.0, theta=0.0
% INFO    : Bus 7896	: V=1.054626, theta=-12.568941 -> V=1.0, theta=0.0
% INFO    : Bus 7897	: V=0.993804, theta=-28.622596 -> V=1.0, theta=0.0
% INFO    : Bus 7898	: V=1.063653, theta=22.361822 -> V=1.0, theta=0.0
% INFO    : Bus 7899	: V=0.994613, theta=-26.228978 -> V=1.0, theta=0.0
% INFO    : Bus 7900	: V=1.023414, theta=-27.227398 -> V=1.0, theta=0.0
% INFO    : Bus 7901	: V=0.988403, theta=-42.964966 -> V=1.0, theta=0.0
% INFO    : Bus 7902	: V=1.022641, theta=-15.117164 -> V=1.0, theta=0.0
% INFO    : Bus 7903	: V=1.071405, theta=-42.005492 -> V=1.0, theta=0.0
% INFO    : Bus 7904	: V=1.006917, theta=-29.683321 -> V=1.0, theta=0.0
% INFO    : Bus 7905	: V=1.044096, theta=-18.14373 -> V=1.0, theta=0.0
% INFO    : Bus 7906	: V=1.027039, theta=-2.259422 -> V=1.0, theta=0.0
% INFO    : Bus 7907	: V=1.053712, theta=-29.238447 -> V=1.0, theta=0.0
% INFO    : Bus 7908	: V=1.022759, theta=14.628752 -> V=1.0, theta=0.0
% INFO    : Bus 7909	: V=1.018041, theta=-22.978925 -> V=1.0, theta=0.0
% INFO    : Bus 7910	: V=1.015669, theta=0.040541 -> V=1.0, theta=0.0
% INFO    : Bus 7911	: V=1.084458, theta=-36.846643 -> V=1.0, theta=0.0
% INFO    : Bus 7912	: V=0.93851, theta=-33.36495 -> V=1.0, theta=0.0
% INFO    : Bus 7913	: V=1.0583, theta=-9.156897 -> V=1.0, theta=0.0
% INFO    : Bus 7914	: V=1.057921, theta=-7.786969 -> V=1.0, theta=0.0
% INFO    : Bus 7915	: V=1.014536, theta=16.390148 -> V=1.0, theta=0.0
% INFO    : Bus 7916	: V=1.034073, theta=-38.613553 -> V=1.0, theta=0.0
% INFO    : Bus 7917	: V=1.0458, theta=-16.592799 -> V=1.0, theta=0.0
% INFO    : Bus 7918	: V=1.024876, theta=-47.970232 -> V=1.0, theta=0.0
% INFO    : Bus 7919	: V=1.084213, theta=45.203319 -> V=1.0, theta=0.0
% INFO    : Bus 7920	: V=1.01435, theta=-8.809807 -> V=1.0, theta=0.0
% INFO    : Bus 7921	: V=1.04929, theta=-22.14211 -> V=1.0, theta=0.0
% INFO    : Bus 7922	: V=1.035891, theta=-12.993029 -> V=1.0, theta=0.0
% INFO    : Bus 7923	: V=1.03458, theta=-22.482591 -> V=1.0, theta=0.0
% INFO    : Bus 7924	: V=1.021353, theta=4.333441 -> V=1.0, theta=0.0
% INFO    : Bus 7925	: V=1.064269, theta=-43.311179 -> V=1.0, theta=0.0
% INFO    : Bus 7926	: V=1.033819, theta=-11.987518 -> V=1.0, theta=0.0
% INFO    : Bus 7927	: V=1.030813, theta=-34.023248 -> V=1.0, theta=0.0
% INFO    : Bus 7928	: V=1.019492, theta=6.24274 -> V=1.0, theta=0.0
% INFO    : Bus 7929	: V=1.044801, theta=-44.589679 -> V=1.0, theta=0.0
% INFO    : Bus 7930	: V=0.986061, theta=-28.33566 -> V=1.0, theta=0.0
% INFO    : Bus 7931	: V=1.061809, theta=-24.814153 -> V=1.0, theta=0.0
% INFO    : Bus 7932	: V=1.039209, theta=-21.588693 -> V=1.0, theta=0.0
% INFO    : Bus 7933	: V=1.00233, theta=-20.357998 -> V=1.0, theta=0.0
% INFO    : Bus 7934	: V=1.090866, theta=46.646981 -> V=1.0, theta=0.0
% INFO    : Bus 7935	: V=1.054273, theta=-48.011301 -> V=1.0, theta=0.0
% INFO    : Bus 7936	: V=1.022726, theta=-14.260765 -> V=1.0, theta=0.0
% INFO    : Bus 7937	: V=1.039373, theta=-7.600731 -> V=1.0, theta=0.0
% INFO    : Bus 7938	: V=1.007696, theta=-32.735194 -> V=1.0, theta=0.0
% INFO    : Bus 7939	: V=0.994734, theta=-34.15431 -> V=1.0, theta=0.0
% INFO    : Bus 7940	: V=1.036846, theta=-12.93378 -> V=1.0, theta=0.0
% INFO    : Bus 7941	: V=1.035735, theta=48.901735 -> V=1.0, theta=0.0
% INFO    : Bus 7942	: V=1.024216, theta=18.003081 -> V=1.0, theta=0.0
% INFO    : Bus 7943	: V=1.047452, theta=-16.169101 -> V=1.0, theta=0.0
% INFO    : Bus 7944	: V=1.015065, theta=-2.592812 -> V=1.0, theta=0.0
% INFO    : Bus 7945	: V=1.02658, theta=-6.07046 -> V=1.0, theta=0.0
% INFO    : Bus 7946	: V=1.064431, theta=-25.178077 -> V=1.0, theta=0.0
% INFO    : Bus 7947	: V=1.028993, theta=-31.533375 -> V=1.0, theta=0.0
% INFO    : Bus 7948	: V=1.000152, theta=-27.243358 -> V=1.0, theta=0.0
% INFO    : Bus 7949	: V=1.033042, theta=3.499382 -> V=1.0, theta=0.0
% INFO    : Bus 7950	: V=1.056077, theta=3.782498 -> V=1.0, theta=0.0
% INFO    : Bus 7951	: V=1.008002, theta=0.704779 -> V=1.0, theta=0.0
% INFO    : Bus 7952	: V=1.008851, theta=-32.506705 -> V=1.0, theta=0.0
% INFO    : Bus 7953	: V=1.067896, theta=-2.73102 -> V=1.0, theta=0.0
% INFO    : Bus 7954	: V=1.01999, theta=3.773328 -> V=1.0, theta=0.0
% INFO    : Bus 7955	: V=1.061959, theta=-23.678465 -> V=1.0, theta=0.0
% INFO    : Bus 7956	: V=1.002622, theta=-10.707448 -> V=1.0, theta=0.0
% INFO    : Bus 7957	: V=1.021124, theta=-10.634569 -> V=1.0, theta=0.0
% INFO    : Bus 7958	: V=1.017087, theta=-0.826561 -> V=1.0, theta=0.0
% INFO    : Bus 7959	: V=1.129512, theta=-23.45798 -> V=1.0, theta=0.0
% INFO    : Bus 7960	: V=1.017582, theta=6.120823 -> V=1.0, theta=0.0
% INFO    : Bus 7961	: V=1.032683, theta=-8.672856 -> V=1.0, theta=0.0
% INFO    : Bus 7962	: V=1.011183, theta=-23.470952 -> V=1.0, theta=0.0
% INFO    : Bus 7963	: V=1.009172, theta=-32.442398 -> V=1.0, theta=0.0
% INFO    : Bus 7964	: V=1.005985, theta=-21.980811 -> V=1.0, theta=0.0
% INFO    : Bus 7965	: V=1.068758, theta=-38.37097 -> V=1.0, theta=0.0
% INFO    : Bus 7966	: V=1.041514, theta=-6.836651 -> V=1.0, theta=0.0
% INFO    : Bus 7967	: V=1.037536, theta=-11.708789 -> V=1.0, theta=0.0
% INFO    : Bus 7968	: V=1.028136, theta=-34.08474 -> V=1.0, theta=0.0
% INFO    : Bus 7969	: V=1.047495, theta=-42.759729 -> V=1.0, theta=0.0
% INFO    : Bus 7970	: V=1.014231, theta=-28.76162 -> V=1.0, theta=0.0
% INFO    : Bus 7971	: V=1.030624, theta=6.450427 -> V=1.0, theta=0.0
% INFO    : Bus 7972	: V=1.038447, theta=-19.316628 -> V=1.0, theta=0.0
% INFO    : Bus 7973	: V=1.024463, theta=-54.505855 -> V=1.0, theta=0.0
% INFO    : Bus 7974	: V=1.030171, theta=-20.370156 -> V=1.0, theta=0.0
% INFO    : Bus 7975	: V=0.967878, theta=-25.140355 -> V=1.0, theta=0.0
% INFO    : Bus 7976	: V=0.915748, theta=-35.933019 -> V=1.0, theta=0.0
% INFO    : Bus 7977	: V=1.016023, theta=4.069925 -> V=1.0, theta=0.0
% INFO    : Bus 7978	: V=1.027815, theta=-26.568135 -> V=1.0, theta=0.0
% INFO    : Bus 7979	: V=1.064388, theta=-21.628838 -> V=1.0, theta=0.0
% INFO    : Bus 7980	: V=1.041778, theta=-43.928298 -> V=1.0, theta=0.0
% INFO    : Bus 7981	: V=1.031763, theta=-28.453814 -> V=1.0, theta=0.0
% INFO    : Bus 7982	: V=1.032099, theta=-23.4836 -> V=1.0, theta=0.0
% INFO    : Bus 7983	: V=1.014534, theta=-4.149497 -> V=1.0, theta=0.0
% INFO    : Bus 7984	: V=1.02858, theta=-4.971328 -> V=1.0, theta=0.0
% INFO    : Bus 7985	: V=1.006287, theta=7.522666 -> V=1.0, theta=0.0
% INFO    : Bus 7986	: V=1.044085, theta=0.20693 -> V=1.0, theta=0.0
% INFO    : Bus 7987	: V=0.994584, theta=-28.409429 -> V=1.0, theta=0.0
% INFO    : Bus 7988	: V=1.028689, theta=-2.162063 -> V=1.0, theta=0.0
% INFO    : Bus 7989	: V=1.049894, theta=-3.935951 -> V=1.0, theta=0.0
% INFO    : Bus 7990	: V=0.960834, theta=-27.235744 -> V=1.0, theta=0.0
% INFO    : Bus 7991	: V=1.03465, theta=-24.182375 -> V=1.0, theta=0.0
% INFO    : Bus 7992	: V=1.044474, theta=-26.640277 -> V=1.0, theta=0.0
% INFO    : Bus 7993	: V=1.010579, theta=-24.407164 -> V=1.0, theta=0.0
% INFO    : Bus 7994	: V=1.010173, theta=-16.613735 -> V=1.0, theta=0.0
% INFO    : Bus 7995	: V=1.024627, theta=12.839869 -> V=1.0, theta=0.0
% INFO    : Bus 7996	: V=1.026529, theta=-1.949583 -> V=1.0, theta=0.0
% INFO    : Bus 7997	: V=1.030629, theta=9.964589 -> V=1.0, theta=0.0
% INFO    : Bus 7998	: V=1.046131, theta=4.063717 -> V=1.0, theta=0.0
% INFO    : Bus 7999	: V=1.023023, theta=-48.741108 -> V=1.0, theta=0.0
% INFO    : Bus 8000	: V=1.025636, theta=-22.76283 -> V=1.0, theta=0.0
% INFO    : Bus 8001	: V=1.011753, theta=63.312472 -> V=1.0, theta=0.0
% INFO    : Bus 8002	: V=1.003367, theta=-31.347071 -> V=1.0, theta=0.0
% INFO    : Bus 8003	: V=1.039083, theta=-32.196713 -> V=1.0, theta=0.0
% INFO    : Bus 8004	: V=0.975044, theta=-31.992071 -> V=1.0, theta=0.0
% INFO    : Bus 8005	: V=1.02503, theta=-13.906514 -> V=1.0, theta=0.0
% INFO    : Bus 8006	: V=1.02459, theta=31.438507 -> V=1.0, theta=0.0
% INFO    : Bus 8007	: V=0.984871, theta=-56.241859 -> V=1.0, theta=0.0
% INFO    : Bus 8008	: V=1.017556, theta=-7.401892 -> V=1.0, theta=0.0
% INFO    : Bus 8009	: V=1.033583, theta=-44.088164 -> V=1.0, theta=0.0
% INFO    : Bus 8010	: V=0.995026, theta=-28.509398 -> V=1.0, theta=0.0
% INFO    : Bus 8011	: V=0.909072, theta=-36.225682 -> V=1.0, theta=0.0
% INFO    : Bus 8012	: V=1.055496, theta=-40.813552 -> V=1.0, theta=0.0
% INFO    : Bus 8013	: V=0.974865, theta=-30.795403 -> V=1.0, theta=0.0
% INFO    : Bus 8014	: V=1.007037, theta=-37.083594 -> V=1.0, theta=0.0
% INFO    : Bus 8015	: V=1.005973, theta=-28.439152 -> V=1.0, theta=0.0
% INFO    : Bus 8016	: V=1.024642, theta=3.976217 -> V=1.0, theta=0.0
% INFO    : Bus 8017	: V=1.02388, theta=11.172528 -> V=1.0, theta=0.0
% INFO    : Bus 8018	: V=0.990633, theta=-21.238054 -> V=1.0, theta=0.0
% INFO    : Bus 8019	: V=0.971819, theta=27.711925 -> V=1.0, theta=0.0
% INFO    : Bus 8020	: V=1.016375, theta=-22.556812 -> V=1.0, theta=0.0
% INFO    : Bus 8021	: V=0.994734, theta=-31.231931 -> V=1.0, theta=0.0
% INFO    : Bus 8022	: V=1.026477, theta=-11.783692 -> V=1.0, theta=0.0
% INFO    : Bus 8023	: V=1.078199, theta=-35.260564 -> V=1.0, theta=0.0
% INFO    : Bus 8024	: V=1.007491, theta=-30.159237 -> V=1.0, theta=0.0
% INFO    : Bus 8025	: V=0.994462, theta=-26.541378 -> V=1.0, theta=0.0
% INFO    : Bus 8026	: V=1.018061, theta=61.87766 -> V=1.0, theta=0.0
% INFO    : Bus 8027	: V=1.019202, theta=-0.749794 -> V=1.0, theta=0.0
% INFO    : Bus 8028	: V=1.032406, theta=-32.982123 -> V=1.0, theta=0.0
% INFO    : Bus 8029	: V=1.029909, theta=-8.604911 -> V=1.0, theta=0.0
% INFO    : Bus 8030	: V=1.029369, theta=-4.649346 -> V=1.0, theta=0.0
% INFO    : Bus 8031	: V=1.00175, theta=-39.804622 -> V=1.0, theta=0.0
% INFO    : Bus 8032	: V=1.046606, theta=64.452646 -> V=1.0, theta=0.0
% INFO    : Bus 8033	: V=1.030915, theta=9.617072 -> V=1.0, theta=0.0
% INFO    : Bus 8034	: V=1.042279, theta=-50.429478 -> V=1.0, theta=0.0
% INFO    : Bus 8035	: V=1.020888, theta=-16.538295 -> V=1.0, theta=0.0
% INFO    : Bus 8036	: V=1.029729, theta=-48.20706 -> V=1.0, theta=0.0
% INFO    : Bus 8037	: V=1.034424, theta=9.023944 -> V=1.0, theta=0.0
% INFO    : Bus 8038	: V=0.926382, theta=-30.635991 -> V=1.0, theta=0.0
% INFO    : Bus 8039	: V=1.03193, theta=0.87619 -> V=1.0, theta=0.0
% INFO    : Bus 8040	: V=0.988535, theta=-27.421635 -> V=1.0, theta=0.0
% INFO    : Bus 8041	: V=1.067309, theta=-17.919785 -> V=1.0, theta=0.0
% INFO    : Bus 8042	: V=1.075334, theta=-26.411362 -> V=1.0, theta=0.0
% INFO    : Bus 8043	: V=1.058234, theta=-11.690288 -> V=1.0, theta=0.0
% INFO    : Bus 8044	: V=1.041629, theta=27.869278 -> V=1.0, theta=0.0
% INFO    : Bus 8045	: V=1.023558, theta=-39.91457 -> V=1.0, theta=0.0
% INFO    : Bus 8046	: V=1.023854, theta=-26.107145 -> V=1.0, theta=0.0
% INFO    : Bus 8047	: V=1.032226, theta=-6.011158 -> V=1.0, theta=0.0
% INFO    : Bus 8048	: V=0.968795, theta=-30.437259 -> V=1.0, theta=0.0
% INFO    : Bus 8049	: V=1.052765, theta=-15.657994 -> V=1.0, theta=0.0
% INFO    : Bus 8050	: V=0.986637, theta=-25.363262 -> V=1.0, theta=0.0
% INFO    : Bus 8051	: V=1.015284, theta=-27.640966 -> V=1.0, theta=0.0
% INFO    : Bus 8052	: V=1.026897, theta=-21.584056 -> V=1.0, theta=0.0
% INFO    : Bus 8053	: V=1.021077, theta=-7.356538 -> V=1.0, theta=0.0
% INFO    : Bus 8054	: V=0.945107, theta=-32.784726 -> V=1.0, theta=0.0
% INFO    : Bus 8055	: V=1.020361, theta=-35.363588 -> V=1.0, theta=0.0
% INFO    : Bus 8056	: V=1.01142, theta=-41.090225 -> V=1.0, theta=0.0
% INFO    : Bus 8057	: V=1.041648, theta=-8.879856 -> V=1.0, theta=0.0
% INFO    : Bus 8058	: V=1.022907, theta=11.155814 -> V=1.0, theta=0.0
% INFO    : Bus 8059	: V=0.990069, theta=-21.418625 -> V=1.0, theta=0.0
% INFO    : Bus 8060	: V=1.04261, theta=-13.767109 -> V=1.0, theta=0.0
% INFO    : Bus 8061	: V=0.969655, theta=-24.039484 -> V=1.0, theta=0.0
% INFO    : Bus 8062	: V=1.01077, theta=-24.081637 -> V=1.0, theta=0.0
% INFO    : Bus 8063	: V=1.019128, theta=-5.785482 -> V=1.0, theta=0.0
% INFO    : Bus 8064	: V=0.95682, theta=-37.631909 -> V=1.0, theta=0.0
% INFO    : Bus 8065	: V=1.059118, theta=-21.729369 -> V=1.0, theta=0.0
% INFO    : Bus 8066	: V=1.011708, theta=-47.36097 -> V=1.0, theta=0.0
% INFO    : Bus 8067	: V=1.008887, theta=-14.633934 -> V=1.0, theta=0.0
% INFO    : Bus 8068	: V=1.02756, theta=-54.000739 -> V=1.0, theta=0.0
% INFO    : Bus 8069	: V=1.025232, theta=-48.020182 -> V=1.0, theta=0.0
% INFO    : Bus 8070	: V=1.001789, theta=-29.37689 -> V=1.0, theta=0.0
% INFO    : Bus 8071	: V=0.992962, theta=-21.379846 -> V=1.0, theta=0.0
% INFO    : Bus 8072	: V=1.032637, theta=-3.253164 -> V=1.0, theta=0.0
% INFO    : Bus 8073	: V=1.033677, theta=-5.641487 -> V=1.0, theta=0.0
% INFO    : Bus 8074	: V=1.015722, theta=-28.98154 -> V=1.0, theta=0.0
% INFO    : Bus 8075	: V=1.00404, theta=-10.66813 -> V=1.0, theta=0.0
% INFO    : Bus 8076	: V=0.992767, theta=-27.64354 -> V=1.0, theta=0.0
% INFO    : Bus 8077	: V=1.056006, theta=-27.347221 -> V=1.0, theta=0.0
% INFO    : Bus 8078	: V=1.036003, theta=-22.090523 -> V=1.0, theta=0.0
% INFO    : Bus 8079	: V=1.008651, theta=-48.900733 -> V=1.0, theta=0.0
% INFO    : Bus 8080	: V=1.028921, theta=-29.481204 -> V=1.0, theta=0.0
% INFO    : Bus 8081	: V=1.033921, theta=-29.923351 -> V=1.0, theta=0.0
% INFO    : Bus 8082	: V=1.081938, theta=-35.99417 -> V=1.0, theta=0.0
% INFO    : Bus 8083	: V=1.024659, theta=5.632991 -> V=1.0, theta=0.0
% INFO    : Bus 8084	: V=1.016384, theta=-41.084893 -> V=1.0, theta=0.0
% INFO    : Bus 8085	: V=1.020835, theta=9.051289 -> V=1.0, theta=0.0
% INFO    : Bus 8086	: V=1.035004, theta=13.443262 -> V=1.0, theta=0.0
% INFO    : Bus 8087	: V=1.027752, theta=-38.784819 -> V=1.0, theta=0.0
% INFO    : Bus 8088	: V=1.036504, theta=-51.990407 -> V=1.0, theta=0.0
% INFO    : Bus 8089	: V=1.005402, theta=-19.565573 -> V=1.0, theta=0.0
% INFO    : Bus 8090	: V=1.004931, theta=-31.840868 -> V=1.0, theta=0.0
% INFO    : Bus 8091	: V=1.010271, theta=-22.903972 -> V=1.0, theta=0.0
% INFO    : Bus 8092	: V=0.980217, theta=-23.636295 -> V=1.0, theta=0.0
% INFO    : Bus 8093	: V=1.031294, theta=-7.30569 -> V=1.0, theta=0.0
% INFO    : Bus 8094	: V=1.015722, theta=-28.98154 -> V=1.0, theta=0.0
% INFO    : Bus 8095	: V=1.016801, theta=62.369068 -> V=1.0, theta=0.0
% INFO    : Bus 8096	: V=1.065973, theta=-25.177832 -> V=1.0, theta=0.0
% INFO    : Bus 8097	: V=0.925909, theta=-30.7488 -> V=1.0, theta=0.0
% INFO    : Bus 8098	: V=0.988227, theta=-50.353409 -> V=1.0, theta=0.0
% INFO    : Bus 8099	: V=1.021862, theta=4.491551 -> V=1.0, theta=0.0
% INFO    : Bus 8100	: V=1.01468, theta=2.038728 -> V=1.0, theta=0.0
% INFO    : Bus 8101	: V=1.059601, theta=-20.726175 -> V=1.0, theta=0.0
% INFO    : Bus 8102	: V=1.020085, theta=-30.999154 -> V=1.0, theta=0.0
% INFO    : Bus 8103	: V=0.983672, theta=-2.039135 -> V=1.0, theta=0.0
% INFO    : Bus 8104	: V=1.065323, theta=-25.565009 -> V=1.0, theta=0.0
% INFO    : Bus 8105	: V=1.013571, theta=-24.29809 -> V=1.0, theta=0.0
% INFO    : Bus 8106	: V=1.007384, theta=-8.03601 -> V=1.0, theta=0.0
% INFO    : Bus 8107	: V=1.030711, theta=-23.716241 -> V=1.0, theta=0.0
% INFO    : Bus 8108	: V=1.03596, theta=-24.818001 -> V=1.0, theta=0.0
% INFO    : Bus 8109	: V=1.059636, theta=-21.41092 -> V=1.0, theta=0.0
% INFO    : Bus 8110	: V=1.02145, theta=4.543192 -> V=1.0, theta=0.0
% INFO    : Bus 8111	: V=1.014784, theta=-32.577103 -> V=1.0, theta=0.0
% INFO    : Bus 8112	: V=1.027125, theta=-3.966359 -> V=1.0, theta=0.0
% INFO    : Bus 8113	: V=1.000699, theta=-7.014879 -> V=1.0, theta=0.0
% INFO    : Bus 8114	: V=1.008795, theta=10.997705 -> V=1.0, theta=0.0
% INFO    : Bus 8115	: V=0.988958, theta=-18.000178 -> V=1.0, theta=0.0
% INFO    : Bus 8116	: V=1.035167, theta=-21.323561 -> V=1.0, theta=0.0
% INFO    : Bus 8117	: V=1.032328, theta=-40.259667 -> V=1.0, theta=0.0
% INFO    : Bus 8118	: V=1.019467, theta=-29.57919 -> V=1.0, theta=0.0
% INFO    : Bus 8119	: V=1.073486, theta=-22.807799 -> V=1.0, theta=0.0
% INFO    : Bus 8120	: V=1.021706, theta=-46.288927 -> V=1.0, theta=0.0
% INFO    : Bus 8121	: V=1.041828, theta=2.490809 -> V=1.0, theta=0.0
% INFO    : Bus 8122	: V=1.010402, theta=-25.765276 -> V=1.0, theta=0.0
% INFO    : Bus 8123	: V=1.009241, theta=13.00467 -> V=1.0, theta=0.0
% INFO    : Bus 8124	: V=1.009707, theta=-61.020742 -> V=1.0, theta=0.0
% INFO    : Bus 8125	: V=1.033398, theta=-2.906942 -> V=1.0, theta=0.0
% INFO    : Bus 8126	: V=1.050536, theta=-13.828695 -> V=1.0, theta=0.0
% INFO    : Bus 8127	: V=0.963758, theta=-29.170502 -> V=1.0, theta=0.0
% INFO    : Bus 8128	: V=1.087364, theta=-9.876011 -> V=1.0, theta=0.0
% INFO    : Bus 8129	: V=1.015661, theta=61.512735 -> V=1.0, theta=0.0
% INFO    : Bus 8130	: V=0.893435, theta=-35.853165 -> V=1.0, theta=0.0
% INFO    : Bus 8131	: V=0.993837, theta=-33.859399 -> V=1.0, theta=0.0
% INFO    : Bus 8132	: V=1.032999, theta=-3.210999 -> V=1.0, theta=0.0
% INFO    : Bus 8133	: V=1.029563, theta=3.621096 -> V=1.0, theta=0.0
% INFO    : Bus 8134	: V=1.008958, theta=13.021747 -> V=1.0, theta=0.0
% INFO    : Bus 8135	: V=1.020133, theta=-6.60554 -> V=1.0, theta=0.0
% INFO    : Bus 8136	: V=1.028389, theta=-9.568889 -> V=1.0, theta=0.0
% INFO    : Bus 8137	: V=1.066186, theta=-22.897807 -> V=1.0, theta=0.0
% INFO    : Bus 8138	: V=1.046996, theta=-43.360058 -> V=1.0, theta=0.0
% INFO    : Bus 8139	: V=1.0271, theta=-31.739536 -> V=1.0, theta=0.0
% INFO    : Bus 8140	: V=1.025442, theta=-36.544956 -> V=1.0, theta=0.0
% INFO    : Bus 8141	: V=1.045799, theta=2.668899 -> V=1.0, theta=0.0
% INFO    : Bus 8142	: V=1.015771, theta=-26.476212 -> V=1.0, theta=0.0
% INFO    : Bus 8143	: V=1.066559, theta=-31.551132 -> V=1.0, theta=0.0
% INFO    : Bus 8144	: V=1.032076, theta=-6.969711 -> V=1.0, theta=0.0
% INFO    : Bus 8145	: V=1.037076, theta=-38.14014 -> V=1.0, theta=0.0
% INFO    : Bus 8146	: V=1.012743, theta=-30.260645 -> V=1.0, theta=0.0
% INFO    : Bus 8147	: V=1.011517, theta=-48.229112 -> V=1.0, theta=0.0
% INFO    : Bus 8148	: V=1.008977, theta=-19.643517 -> V=1.0, theta=0.0
% INFO    : Bus 8149	: V=1.001472, theta=-46.548205 -> V=1.0, theta=0.0
% INFO    : Bus 8150	: V=1.019025, theta=-5.948255 -> V=1.0, theta=0.0
% INFO    : Bus 8151	: V=1.040089, theta=-25.913804 -> V=1.0, theta=0.0
% INFO    : Bus 8152	: V=0.979646, theta=-37.165348 -> V=1.0, theta=0.0
% INFO    : Bus 8153	: V=1.010673, theta=-24.161118 -> V=1.0, theta=0.0
% INFO    : Bus 8154	: V=1.049994, theta=-24.715315 -> V=1.0, theta=0.0
% INFO    : Bus 8155	: V=1.019325, theta=8.943633 -> V=1.0, theta=0.0
% INFO    : Bus 8156	: V=1.075225, theta=8.81697 -> V=1.0, theta=0.0
% INFO    : Bus 8157	: V=1.045038, theta=-39.487415 -> V=1.0, theta=0.0
% INFO    : Bus 8158	: V=1.051259, theta=-0.62403 -> V=1.0, theta=0.0
% INFO    : Bus 8159	: V=1.060727, theta=-40.97699 -> V=1.0, theta=0.0
% INFO    : Bus 8160	: V=1.005675, theta=-32.160727 -> V=1.0, theta=0.0
% INFO    : Bus 8161	: V=1.033444, theta=-44.087427 -> V=1.0, theta=0.0
% INFO    : Bus 8162	: V=0.990709, theta=-29.416452 -> V=1.0, theta=0.0
% INFO    : Bus 8163	: V=1.021917, theta=-54.195819 -> V=1.0, theta=0.0
% INFO    : Bus 8164	: V=1.017961, theta=6.452451 -> V=1.0, theta=0.0
% INFO    : Bus 8165	: V=1.061672, theta=-3.668047 -> V=1.0, theta=0.0
% INFO    : Bus 8166	: V=1.061057, theta=-26.449392 -> V=1.0, theta=0.0
% INFO    : Bus 8167	: V=1.014897, theta=4.500754 -> V=1.0, theta=0.0
% INFO    : Bus 8168	: V=1.056007, theta=-20.363996 -> V=1.0, theta=0.0
% INFO    : Bus 8169	: V=0.994001, theta=-30.574954 -> V=1.0, theta=0.0
% INFO    : Bus 8170	: V=1.05125, theta=-31.357019 -> V=1.0, theta=0.0
% INFO    : Bus 8171	: V=1.128618, theta=-22.125742 -> V=1.0, theta=0.0
% INFO    : Bus 8172	: V=1.045343, theta=-28.928507 -> V=1.0, theta=0.0
% INFO    : Bus 8173	: V=1.012811, theta=-29.203679 -> V=1.0, theta=0.0
% INFO    : Bus 8174	: V=1.06297, theta=-26.062623 -> V=1.0, theta=0.0
% INFO    : Bus 8175	: V=1.027698, theta=-8.665439 -> V=1.0, theta=0.0
% INFO    : Bus 8176	: V=1.004168, theta=-39.342733 -> V=1.0, theta=0.0
% INFO    : Bus 8177	: V=1.019944, theta=-8.428419 -> V=1.0, theta=0.0
% INFO    : Bus 8178	: V=0.999708, theta=-27.06631 -> V=1.0, theta=0.0
% INFO    : Bus 8179	: V=0.996578, theta=-5.601511 -> V=1.0, theta=0.0
% INFO    : Bus 8180	: V=1.073823, theta=-30.874994 -> V=1.0, theta=0.0
% INFO    : Bus 8181	: V=0.997673, theta=-5.226676 -> V=1.0, theta=0.0
% INFO    : Bus 8182	: V=1.02935, theta=-20.100872 -> V=1.0, theta=0.0
% INFO    : Bus 8183	: V=1.0595, theta=-47.950868 -> V=1.0, theta=0.0
% INFO    : Bus 8184	: V=1.0152, theta=-32.505094 -> V=1.0, theta=0.0
% INFO    : Bus 8185	: V=1.028753, theta=-37.858554 -> V=1.0, theta=0.0
% INFO    : Bus 8186	: V=1.026419, theta=-54.27643 -> V=1.0, theta=0.0
% INFO    : Bus 8187	: V=1.0215, theta=2.359673 -> V=1.0, theta=0.0
% INFO    : Bus 8188	: V=1.04758, theta=42.736603 -> V=1.0, theta=0.0
% INFO    : Bus 8189	: V=1.045168, theta=-18.168399 -> V=1.0, theta=0.0
% INFO    : Bus 8190	: V=1.042647, theta=-10.60065 -> V=1.0, theta=0.0
% INFO    : Bus 8191	: V=1.04325, theta=-15.664936 -> V=1.0, theta=0.0
% INFO    : Bus 8192	: V=0.979985, theta=-31.250322 -> V=1.0, theta=0.0
% INFO    : Bus 8193	: V=1.050524, theta=41.986713 -> V=1.0, theta=0.0
% INFO    : Bus 8194	: V=1.021167, theta=10.861415 -> V=1.0, theta=0.0
% INFO    : Bus 8195	: V=1.022307, theta=-17.099911 -> V=1.0, theta=0.0
% INFO    : Bus 8196	: V=1.012285, theta=1.194766 -> V=1.0, theta=0.0
% INFO    : Bus 8197	: V=1.003237, theta=-38.334059 -> V=1.0, theta=0.0
% INFO    : Bus 8198	: V=1.026529, theta=24.114895 -> V=1.0, theta=0.0
% INFO    : Bus 8199	: V=1.013013, theta=-15.052128 -> V=1.0, theta=0.0
% INFO    : Bus 8200	: V=1.013227, theta=-6.532335 -> V=1.0, theta=0.0
% INFO    : Bus 8201	: V=1.011753, theta=63.312472 -> V=1.0, theta=0.0
% INFO    : Bus 8202	: V=1.029197, theta=5.912943 -> V=1.0, theta=0.0
% INFO    : Bus 8203	: V=1.008878, theta=-5.25837 -> V=1.0, theta=0.0
% INFO    : Bus 8204	: V=1.037372, theta=-0.720895 -> V=1.0, theta=0.0
% INFO    : Bus 8205	: V=0.998408, theta=-38.372067 -> V=1.0, theta=0.0
% INFO    : Bus 8206	: V=1.018881, theta=65.830577 -> V=1.0, theta=0.0
% INFO    : Bus 8207	: V=1.029137, theta=-42.518288 -> V=1.0, theta=0.0
% INFO    : Bus 8208	: V=0.950649, theta=-30.58154 -> V=1.0, theta=0.0
% INFO    : Bus 8209	: V=1.029657, theta=-20.451282 -> V=1.0, theta=0.0
% INFO    : Bus 8210	: V=1.044939, theta=-38.028359 -> V=1.0, theta=0.0
% INFO    : Bus 8211	: V=1.023364, theta=19.415183 -> V=1.0, theta=0.0
% INFO    : Bus 8212	: V=1.009223, theta=-27.52837 -> V=1.0, theta=0.0
% INFO    : Bus 8213	: V=1.033429, theta=-46.419035 -> V=1.0, theta=0.0
% INFO    : Bus 8214	: V=1.037117, theta=-11.762803 -> V=1.0, theta=0.0
% INFO    : Bus 8215	: V=1.031215, theta=-34.760827 -> V=1.0, theta=0.0
% INFO    : Bus 8216	: V=1.001625, theta=-8.149634 -> V=1.0, theta=0.0
% INFO    : Bus 8217	: V=0.962201, theta=-32.513552 -> V=1.0, theta=0.0
% INFO    : Bus 8218	: V=1.013588, theta=-21.939058 -> V=1.0, theta=0.0
% INFO    : Bus 8219	: V=1.071897, theta=-18.921301 -> V=1.0, theta=0.0
% INFO    : Bus 8220	: V=1.066808, theta=-21.238107 -> V=1.0, theta=0.0
% INFO    : Bus 8221	: V=1.04837, theta=-20.841946 -> V=1.0, theta=0.0
% INFO    : Bus 8222	: V=1.013304, theta=-10.689171 -> V=1.0, theta=0.0
% INFO    : Bus 8223	: V=1.056121, theta=17.316391 -> V=1.0, theta=0.0
% INFO    : Bus 8224	: V=1.048689, theta=-42.216026 -> V=1.0, theta=0.0
% INFO    : Bus 8225	: V=1.062685, theta=-12.260471 -> V=1.0, theta=0.0
% INFO    : Bus 8226	: V=1.018717, theta=4.840908 -> V=1.0, theta=0.0
% INFO    : Bus 8227	: V=1.022197, theta=12.147234 -> V=1.0, theta=0.0
% INFO    : Bus 8228	: V=1.049799, theta=-35.627345 -> V=1.0, theta=0.0
% INFO    : Bus 8229	: V=1.059236, theta=-7.623477 -> V=1.0, theta=0.0
% INFO    : Bus 8230	: V=1.035365, theta=11.07861 -> V=1.0, theta=0.0
% INFO    : Bus 8231	: V=0.975419, theta=-31.968769 -> V=1.0, theta=0.0
% INFO    : Bus 8232	: V=1.030544, theta=-20.518157 -> V=1.0, theta=0.0
% INFO    : Bus 8233	: V=1.008979, theta=-27.229246 -> V=1.0, theta=0.0
% INFO    : Bus 8234	: V=1.022901, theta=-32.41943 -> V=1.0, theta=0.0
% INFO    : Bus 8235	: V=1.049964, theta=-16.811641 -> V=1.0, theta=0.0
% INFO    : Bus 8236	: V=1.022936, theta=-54.333594 -> V=1.0, theta=0.0
% INFO    : Bus 8237	: V=1.02248, theta=-41.049727 -> V=1.0, theta=0.0
% INFO    : Bus 8238	: V=1.050287, theta=-24.708967 -> V=1.0, theta=0.0
% INFO    : Bus 8239	: V=1.013181, theta=-40.509773 -> V=1.0, theta=0.0
% INFO    : Bus 8240	: V=1.056841, theta=-39.378648 -> V=1.0, theta=0.0
% INFO    : Bus 8241	: V=1.05487, theta=-17.180585 -> V=1.0, theta=0.0
% INFO    : Bus 8242	: V=1.010793, theta=-46.562916 -> V=1.0, theta=0.0
% INFO    : Bus 8243	: V=0.996999, theta=-32.232554 -> V=1.0, theta=0.0
% INFO    : Bus 8244	: V=1.020146, theta=0.682307 -> V=1.0, theta=0.0
% INFO    : Bus 8245	: V=1.052629, theta=-18.762539 -> V=1.0, theta=0.0
% INFO    : Bus 8246	: V=1.017932, theta=-29.281953 -> V=1.0, theta=0.0
% INFO    : Bus 8247	: V=1.055867, theta=-41.040462 -> V=1.0, theta=0.0
% INFO    : Bus 8248	: V=1.004094, theta=-4.515905 -> V=1.0, theta=0.0
% INFO    : Bus 8249	: V=1.014077, theta=11.203194 -> V=1.0, theta=0.0
% INFO    : Bus 8250	: V=1.026211, theta=-26.484125 -> V=1.0, theta=0.0
% INFO    : Bus 8251	: V=0.977611, theta=-28.394971 -> V=1.0, theta=0.0
% INFO    : Bus 8252	: V=1.02226, theta=-43.190789 -> V=1.0, theta=0.0
% INFO    : Bus 8253	: V=1.055141, theta=-29.298438 -> V=1.0, theta=0.0
% INFO    : Bus 8254	: V=1.010885, theta=-5.581506 -> V=1.0, theta=0.0
% INFO    : Bus 8255	: V=1.019596, theta=-13.990643 -> V=1.0, theta=0.0
% INFO    : Bus 8256	: V=1.058137, theta=18.767735 -> V=1.0, theta=0.0
% INFO    : Bus 8257	: V=0.967209, theta=-32.44223 -> V=1.0, theta=0.0
% INFO    : Bus 8258	: V=1.146803, theta=-24.522183 -> V=1.0, theta=0.0
% INFO    : Bus 8259	: V=1.047063, theta=2.954121 -> V=1.0, theta=0.0
% INFO    : Bus 8260	: V=1.042642, theta=-50.293244 -> V=1.0, theta=0.0
% INFO    : Bus 8261	: V=1.02553, theta=-28.425864 -> V=1.0, theta=0.0
% INFO    : Bus 8262	: V=1.010184, theta=-8.519846 -> V=1.0, theta=0.0
% INFO    : Bus 8263	: V=1.037171, theta=-41.654202 -> V=1.0, theta=0.0
% INFO    : Bus 8264	: V=1.02338, theta=19.408295 -> V=1.0, theta=0.0
% INFO    : Bus 8265	: V=1.059858, theta=-24.193736 -> V=1.0, theta=0.0
% INFO    : Bus 8266	: V=1.01568, theta=-49.022963 -> V=1.0, theta=0.0
% INFO    : Bus 8267	: V=1.042576, theta=-10.311578 -> V=1.0, theta=0.0
% INFO    : Bus 8268	: V=1.129332, theta=-26.334883 -> V=1.0, theta=0.0
% INFO    : Bus 8269	: V=1.039628, theta=-19.617502 -> V=1.0, theta=0.0
% INFO    : Bus 8270	: V=1.031891, theta=17.801282 -> V=1.0, theta=0.0
% INFO    : Bus 8271	: V=0.960551, theta=-34.800379 -> V=1.0, theta=0.0
% INFO    : Bus 8272	: V=1.073949, theta=-25.312276 -> V=1.0, theta=0.0
% INFO    : Bus 8273	: V=1.024472, theta=-35.07305 -> V=1.0, theta=0.0
% INFO    : Bus 8274	: V=1.031672, theta=-24.817077 -> V=1.0, theta=0.0
% INFO    : Bus 8275	: V=1.00419, theta=-50.596527 -> V=1.0, theta=0.0
% INFO    : Bus 8276	: V=1.019363, theta=-24.62562 -> V=1.0, theta=0.0
% INFO    : Bus 8277	: V=1.001417, theta=21.455311 -> V=1.0, theta=0.0
% INFO    : Bus 8278	: V=1.005256, theta=-32.487725 -> V=1.0, theta=0.0
% INFO    : Bus 8279	: V=1.064328, theta=-9.14908 -> V=1.0, theta=0.0
% INFO    : Bus 8280	: V=0.989209, theta=-42.430607 -> V=1.0, theta=0.0
% INFO    : Bus 8281	: V=1.016085, theta=-32.352858 -> V=1.0, theta=0.0
% INFO    : Bus 8282	: V=1.085413, theta=-13.321452 -> V=1.0, theta=0.0
% INFO    : Bus 8283	: V=0.96539, theta=-34.440456 -> V=1.0, theta=0.0
% INFO    : Bus 8284	: V=1.079746, theta=31.595713 -> V=1.0, theta=0.0
% INFO    : Bus 8285	: V=1.010139, theta=-54.759962 -> V=1.0, theta=0.0
% INFO    : Bus 8286	: V=0.998055, theta=-16.505296 -> V=1.0, theta=0.0
% INFO    : Bus 8287	: V=1.031132, theta=-23.670977 -> V=1.0, theta=0.0
% INFO    : Bus 8288	: V=1.058196, theta=10.347966 -> V=1.0, theta=0.0
% INFO    : Bus 8289	: V=1.044611, theta=2.524063 -> V=1.0, theta=0.0
% INFO    : Bus 8290	: V=1.000755, theta=-29.325722 -> V=1.0, theta=0.0
% INFO    : Bus 8291	: V=1.04203, theta=-7.751434 -> V=1.0, theta=0.0
% INFO    : Bus 8292	: V=1.013491, theta=-16.872272 -> V=1.0, theta=0.0
% INFO    : Bus 8293	: V=1.043878, theta=-25.136485 -> V=1.0, theta=0.0
% INFO    : Bus 8294	: V=1.040272, theta=-12.207544 -> V=1.0, theta=0.0
% INFO    : Bus 8295	: V=1.061757, theta=-22.866511 -> V=1.0, theta=0.0
% INFO    : Bus 8296	: V=1.003, theta=-36.6973 -> V=1.0, theta=0.0
% INFO    : Bus 8297	: V=1.024007, theta=-1.464406 -> V=1.0, theta=0.0
% INFO    : Bus 8298	: V=1.079416, theta=31.580844 -> V=1.0, theta=0.0
% INFO    : Bus 8299	: V=1.052737, theta=-29.321529 -> V=1.0, theta=0.0
% INFO    : Bus 8300	: V=1.083791, theta=25.660356 -> V=1.0, theta=0.0
% INFO    : Bus 8301	: V=1.022753, theta=-52.026401 -> V=1.0, theta=0.0
% INFO    : Bus 8302	: V=1.009267, theta=-29.522495 -> V=1.0, theta=0.0
% INFO    : Bus 8303	: V=1.008328, theta=-24.655408 -> V=1.0, theta=0.0
% INFO    : Bus 8304	: V=1.036714, theta=-13.009231 -> V=1.0, theta=0.0
% INFO    : Bus 8305	: V=1.023509, theta=2.100177 -> V=1.0, theta=0.0
% INFO    : Bus 8306	: V=1.022295, theta=-28.392614 -> V=1.0, theta=0.0
% INFO    : Bus 8307	: V=1.049312, theta=-4.132517 -> V=1.0, theta=0.0
% INFO    : Bus 8308	: V=1.009947, theta=-26.481593 -> V=1.0, theta=0.0
% INFO    : Bus 8309	: V=1.003905, theta=-12.026506 -> V=1.0, theta=0.0
% INFO    : Bus 8310	: V=1.050396, theta=-8.818559 -> V=1.0, theta=0.0
% INFO    : Bus 8311	: V=1.041866, theta=-15.286135 -> V=1.0, theta=0.0
% INFO    : Bus 8312	: V=1.075986, theta=-12.446539 -> V=1.0, theta=0.0
% INFO    : Bus 8313	: V=1.026214, theta=-19.752056 -> V=1.0, theta=0.0
% INFO    : Bus 8314	: V=0.978742, theta=-21.555476 -> V=1.0, theta=0.0
% INFO    : Bus 8315	: V=0.991615, theta=-28.318119 -> V=1.0, theta=0.0
% INFO    : Bus 8316	: V=1.080774, theta=-26.771111 -> V=1.0, theta=0.0
% INFO    : Bus 8317	: V=1.000913, theta=-2.045998 -> V=1.0, theta=0.0
% INFO    : Bus 8318	: V=1.04781, theta=18.206206 -> V=1.0, theta=0.0
% INFO    : Bus 8319	: V=1.033139, theta=-28.365301 -> V=1.0, theta=0.0
% INFO    : Bus 8320	: V=0.995898, theta=-51.607781 -> V=1.0, theta=0.0
% INFO    : Bus 8321	: V=1.013389, theta=-41.474694 -> V=1.0, theta=0.0
% INFO    : Bus 8322	: V=1.070507, theta=-15.352172 -> V=1.0, theta=0.0
% INFO    : Bus 8323	: V=1.031263, theta=12.95326 -> V=1.0, theta=0.0
% INFO    : Bus 8324	: V=1.025361, theta=-24.322068 -> V=1.0, theta=0.0
% INFO    : Bus 8325	: V=1.015882, theta=-38.437584 -> V=1.0, theta=0.0
% INFO    : Bus 8326	: V=1.040253, theta=8.308249 -> V=1.0, theta=0.0
% INFO    : Bus 8327	: V=1.002607, theta=-34.537706 -> V=1.0, theta=0.0
% INFO    : Bus 8328	: V=1.038918, theta=-24.742845 -> V=1.0, theta=0.0
% INFO    : Bus 8329	: V=1.010013, theta=5.350987 -> V=1.0, theta=0.0
% INFO    : Bus 8330	: V=1.030157, theta=1.289604 -> V=1.0, theta=0.0
% INFO    : Bus 8331	: V=1.053965, theta=-13.3494 -> V=1.0, theta=0.0
% INFO    : Bus 8332	: V=1.064955, theta=53.263257 -> V=1.0, theta=0.0
% INFO    : Bus 8333	: V=1.064258, theta=56.475531 -> V=1.0, theta=0.0
% INFO    : Bus 8334	: V=1.037243, theta=-14.775985 -> V=1.0, theta=0.0
% INFO    : Bus 8335	: V=1.007944, theta=-11.993469 -> V=1.0, theta=0.0
% INFO    : Bus 8336	: V=1.019599, theta=-0.404353 -> V=1.0, theta=0.0
% INFO    : Bus 8337	: V=1.046451, theta=-43.209981 -> V=1.0, theta=0.0
% INFO    : Bus 8338	: V=1.021297, theta=-44.458579 -> V=1.0, theta=0.0
% INFO    : Bus 8339	: V=1.029002, theta=-30.391257 -> V=1.0, theta=0.0
% INFO    : Bus 8340	: V=1.020459, theta=-32.098619 -> V=1.0, theta=0.0
% INFO    : Bus 8341	: V=1.019672, theta=-12.702071 -> V=1.0, theta=0.0
% INFO    : Bus 8342	: V=1.045055, theta=16.16968 -> V=1.0, theta=0.0
% INFO    : Bus 8343	: V=0.967673, theta=-31.207462 -> V=1.0, theta=0.0
% INFO    : Bus 8344	: V=1.140155, theta=-22.513812 -> V=1.0, theta=0.0
% INFO    : Bus 8345	: V=1.102477, theta=-22.522128 -> V=1.0, theta=0.0
% INFO    : Bus 8346	: V=1.02704, theta=7.750185 -> V=1.0, theta=0.0
% INFO    : Bus 8347	: V=0.984674, theta=-18.922895 -> V=1.0, theta=0.0
% INFO    : Bus 8348	: V=0.994914, theta=-24.815343 -> V=1.0, theta=0.0
% INFO    : Bus 8349	: V=1.030715, theta=38.433991 -> V=1.0, theta=0.0
% INFO    : Bus 8350	: V=1.024609, theta=-11.590033 -> V=1.0, theta=0.0
% INFO    : Bus 8351	: V=1.013482, theta=-18.953127 -> V=1.0, theta=0.0
% INFO    : Bus 8352	: V=1.019463, theta=-39.669039 -> V=1.0, theta=0.0
% INFO    : Bus 8353	: V=1.023371, theta=-56.50364 -> V=1.0, theta=0.0
% INFO    : Bus 8354	: V=1.046637, theta=-27.138917 -> V=1.0, theta=0.0
% INFO    : Bus 8355	: V=1.019471, theta=2.927282 -> V=1.0, theta=0.0
% INFO    : Bus 8356	: V=1.021663, theta=0.83732 -> V=1.0, theta=0.0
% INFO    : Bus 8357	: V=1.039159, theta=-30.106392 -> V=1.0, theta=0.0
% INFO    : Bus 8358	: V=1.088958, theta=-23.293723 -> V=1.0, theta=0.0
% INFO    : Bus 8359	: V=1.037988, theta=0.809889 -> V=1.0, theta=0.0
% INFO    : Bus 8360	: V=1.05831, theta=-18.522173 -> V=1.0, theta=0.0
% INFO    : Bus 8361	: V=1.06792, theta=-26.821509 -> V=1.0, theta=0.0
% INFO    : Bus 8362	: V=1.047632, theta=-10.195555 -> V=1.0, theta=0.0
% INFO    : Bus 8363	: V=0.983771, theta=-28.778868 -> V=1.0, theta=0.0
% INFO    : Bus 8364	: V=0.969193, theta=-33.842232 -> V=1.0, theta=0.0
% INFO    : Bus 8365	: V=1.023365, theta=-7.444922 -> V=1.0, theta=0.0
% INFO    : Bus 8366	: V=1.033976, theta=-10.458179 -> V=1.0, theta=0.0
% INFO    : Bus 8367	: V=1.033693, theta=-6.759533 -> V=1.0, theta=0.0
% INFO    : Bus 8368	: V=1.013549, theta=-32.972603 -> V=1.0, theta=0.0
% INFO    : Bus 8369	: V=1.025353, theta=-9.248105 -> V=1.0, theta=0.0
% INFO    : Bus 8370	: V=1.051458, theta=32.794035 -> V=1.0, theta=0.0
% INFO    : Bus 8371	: V=1.107597, theta=-29.894132 -> V=1.0, theta=0.0
% INFO    : Bus 8372	: V=1.003475, theta=-27.753131 -> V=1.0, theta=0.0
% INFO    : Bus 8373	: V=1.068117, theta=-48.408259 -> V=1.0, theta=0.0
% INFO    : Bus 8374	: V=1.057625, theta=-42.495639 -> V=1.0, theta=0.0
% INFO    : Bus 8375	: V=1.024751, theta=-36.913054 -> V=1.0, theta=0.0
% INFO    : Bus 8376	: V=1.084755, theta=-14.407486 -> V=1.0, theta=0.0
% INFO    : Bus 8377	: V=1.011199, theta=-25.896242 -> V=1.0, theta=0.0
% INFO    : Bus 8378	: V=1.020496, theta=-38.748447 -> V=1.0, theta=0.0
% INFO    : Bus 8379	: V=0.950343, theta=-33.723168 -> V=1.0, theta=0.0
% INFO    : Bus 8380	: V=1.011417, theta=18.74035 -> V=1.0, theta=0.0
% INFO    : Bus 8381	: V=1.06566, theta=-45.192169 -> V=1.0, theta=0.0
% INFO    : Bus 8382	: V=1.013369, theta=-29.690839 -> V=1.0, theta=0.0
% INFO    : Bus 8383	: V=1.008495, theta=-16.34939 -> V=1.0, theta=0.0
% INFO    : Bus 8384	: V=1.051363, theta=-6.810401 -> V=1.0, theta=0.0
% INFO    : Bus 8385	: V=1.071133, theta=-22.308506 -> V=1.0, theta=0.0
% INFO    : Bus 8386	: V=1.022901, theta=-32.41943 -> V=1.0, theta=0.0
% INFO    : Bus 8387	: V=1.030064, theta=7.578606 -> V=1.0, theta=0.0
% INFO    : Bus 8388	: V=1.004349, theta=31.472688 -> V=1.0, theta=0.0
% INFO    : Bus 8389	: V=1.017477, theta=16.817296 -> V=1.0, theta=0.0
% INFO    : Bus 8390	: V=1.011409, theta=-21.678886 -> V=1.0, theta=0.0
% INFO    : Bus 8391	: V=1.025477, theta=3.865363 -> V=1.0, theta=0.0
% INFO    : Bus 8392	: V=1.046081, theta=6.943122 -> V=1.0, theta=0.0
% INFO    : Bus 8393	: V=1.013216, theta=16.740162 -> V=1.0, theta=0.0
% INFO    : Bus 8394	: V=0.995125, theta=-30.856007 -> V=1.0, theta=0.0
% INFO    : Bus 8395	: V=1.027319, theta=-22.979397 -> V=1.0, theta=0.0
% INFO    : Bus 8396	: V=1.058922, theta=-41.288699 -> V=1.0, theta=0.0
% INFO    : Bus 8397	: V=1.044077, theta=-25.82874 -> V=1.0, theta=0.0
% INFO    : Bus 8398	: V=1.034241, theta=-33.913063 -> V=1.0, theta=0.0
% INFO    : Bus 8399	: V=1.033814, theta=-39.750205 -> V=1.0, theta=0.0
% INFO    : Bus 8400	: V=1.03649, theta=-29.85563 -> V=1.0, theta=0.0
% INFO    : Bus 8401	: V=1.074893, theta=4.701019 -> V=1.0, theta=0.0
% INFO    : Bus 8402	: V=0.9876, theta=-24.925906 -> V=1.0, theta=0.0
% INFO    : Bus 8403	: V=1.002808, theta=-30.606777 -> V=1.0, theta=0.0
% INFO    : Bus 8404	: V=1.059469, theta=55.335907 -> V=1.0, theta=0.0
% INFO    : Bus 8405	: V=1.031329, theta=-12.655848 -> V=1.0, theta=0.0
% INFO    : Bus 8406	: V=1.046532, theta=-25.471306 -> V=1.0, theta=0.0
% INFO    : Bus 8407	: V=0.976226, theta=-36.046729 -> V=1.0, theta=0.0
% INFO    : Bus 8408	: V=1.051004, theta=-22.578573 -> V=1.0, theta=0.0
% INFO    : Bus 8409	: V=1.045438, theta=-33.498156 -> V=1.0, theta=0.0
% INFO    : Bus 8410	: V=1.038778, theta=-23.326859 -> V=1.0, theta=0.0
% INFO    : Bus 8411	: V=1.038405, theta=-26.143069 -> V=1.0, theta=0.0
% INFO    : Bus 8412	: V=1.022914, theta=-35.028767 -> V=1.0, theta=0.0
% INFO    : Bus 8413	: V=1.031312, theta=-38.24745 -> V=1.0, theta=0.0
% INFO    : Bus 8414	: V=1.116729, theta=23.686346 -> V=1.0, theta=0.0
% INFO    : Bus 8415	: V=1.082292, theta=53.782849 -> V=1.0, theta=0.0
% INFO    : Bus 8416	: V=1.086385, theta=-21.442648 -> V=1.0, theta=0.0
% INFO    : Bus 8417	: V=1.005143, theta=-48.285615 -> V=1.0, theta=0.0
% INFO    : Bus 8418	: V=1.020354, theta=-29.212066 -> V=1.0, theta=0.0
% INFO    : Bus 8419	: V=1.010846, theta=-60.746633 -> V=1.0, theta=0.0
% INFO    : Bus 8420	: V=1.044478, theta=-9.554053 -> V=1.0, theta=0.0
% INFO    : Bus 8421	: V=1.013008, theta=25.327957 -> V=1.0, theta=0.0
% INFO    : Bus 8422	: V=1.024934, theta=4.963525 -> V=1.0, theta=0.0
% INFO    : Bus 8423	: V=1.018322, theta=-28.704092 -> V=1.0, theta=0.0
% INFO    : Bus 8424	: V=0.969739, theta=-22.513967 -> V=1.0, theta=0.0
% INFO    : Bus 8425	: V=1.044233, theta=-26.058998 -> V=1.0, theta=0.0
% INFO    : Bus 8426	: V=1.020758, theta=-43.187108 -> V=1.0, theta=0.0
% INFO    : Bus 8427	: V=1.012295, theta=21.310711 -> V=1.0, theta=0.0
% INFO    : Bus 8428	: V=1.035015, theta=-13.126798 -> V=1.0, theta=0.0
% INFO    : Bus 8429	: V=1.031411, theta=18.850336 -> V=1.0, theta=0.0
% INFO    : Bus 8430	: V=1.002869, theta=-30.564646 -> V=1.0, theta=0.0
% INFO    : Bus 8431	: V=1.011512, theta=34.728159 -> V=1.0, theta=0.0
% INFO    : Bus 8432	: V=1.0265, theta=11.435168 -> V=1.0, theta=0.0
% INFO    : Bus 8433	: V=1.055181, theta=-34.290765 -> V=1.0, theta=0.0
% INFO    : Bus 8434	: V=1.020874, theta=-7.36671 -> V=1.0, theta=0.0
% INFO    : Bus 8435	: V=0.997008, theta=-32.24721 -> V=1.0, theta=0.0
% INFO    : Bus 8436	: V=1.005642, theta=-31.843939 -> V=1.0, theta=0.0
% INFO    : Bus 8437	: V=0.972298, theta=-33.087967 -> V=1.0, theta=0.0
% INFO    : Bus 8438	: V=1.01228, theta=-47.827544 -> V=1.0, theta=0.0
% INFO    : Bus 8439	: V=0.994526, theta=-23.773173 -> V=1.0, theta=0.0
% INFO    : Bus 8440	: V=1.017254, theta=-9.964329 -> V=1.0, theta=0.0
% INFO    : Bus 8441	: V=1.042054, theta=2.498815 -> V=1.0, theta=0.0
% INFO    : Bus 8442	: V=1.040171, theta=2.622307 -> V=1.0, theta=0.0
% INFO    : Bus 8443	: V=0.996955, theta=-50.261227 -> V=1.0, theta=0.0
% INFO    : Bus 8444	: V=0.96267, theta=-29.940055 -> V=1.0, theta=0.0
% INFO    : Bus 8445	: V=0.993246, theta=-23.815094 -> V=1.0, theta=0.0
% INFO    : Bus 8446	: V=1.019171, theta=-30.654209 -> V=1.0, theta=0.0
% INFO    : Bus 8447	: V=1.032791, theta=-34.255223 -> V=1.0, theta=0.0
% INFO    : Bus 8448	: V=1.012896, theta=-20.944744 -> V=1.0, theta=0.0
% INFO    : Bus 8449	: V=1.044106, theta=7.845761 -> V=1.0, theta=0.0
% INFO    : Bus 8450	: V=1.031128, theta=-38.926529 -> V=1.0, theta=0.0
% INFO    : Bus 8451	: V=0.998015, theta=18.852253 -> V=1.0, theta=0.0
% INFO    : Bus 8452	: V=1.005589, theta=-30.393461 -> V=1.0, theta=0.0
% INFO    : Bus 8453	: V=1.064895, theta=-22.992552 -> V=1.0, theta=0.0
% INFO    : Bus 8454	: V=1.013448, theta=-16.868276 -> V=1.0, theta=0.0
% INFO    : Bus 8455	: V=0.990052, theta=-17.909625 -> V=1.0, theta=0.0
% INFO    : Bus 8456	: V=1.011946, theta=61.701308 -> V=1.0, theta=0.0
% INFO    : Bus 8457	: V=1.021959, theta=-28.230262 -> V=1.0, theta=0.0
% INFO    : Bus 8458	: V=1.042019, theta=-9.780413 -> V=1.0, theta=0.0
% INFO    : Bus 8459	: V=0.96597, theta=-43.873196 -> V=1.0, theta=0.0
% INFO    : Bus 8460	: V=1.009914, theta=3.722562 -> V=1.0, theta=0.0
% INFO    : Bus 8461	: V=0.980526, theta=-30.31025 -> V=1.0, theta=0.0
% INFO    : Bus 8462	: V=1.013093, theta=-23.797372 -> V=1.0, theta=0.0
% INFO    : Bus 8463	: V=1.036561, theta=5.69769 -> V=1.0, theta=0.0
% INFO    : Bus 8464	: V=1.080213, theta=-22.387307 -> V=1.0, theta=0.0
% INFO    : Bus 8465	: V=1.048179, theta=65.975127 -> V=1.0, theta=0.0
% INFO    : Bus 8466	: V=1.043279, theta=-4.736557 -> V=1.0, theta=0.0
% INFO    : Bus 8467	: V=0.982596, theta=-23.281146 -> V=1.0, theta=0.0
% INFO    : Bus 8468	: V=1.002528, theta=-15.14463 -> V=1.0, theta=0.0
% INFO    : Bus 8469	: V=1.088634, theta=-21.665499 -> V=1.0, theta=0.0
% INFO    : Bus 8470	: V=1.015878, theta=-27.78116 -> V=1.0, theta=0.0
% INFO    : Bus 8471	: V=1.053611, theta=-26.038452 -> V=1.0, theta=0.0
% INFO    : Bus 8472	: V=1.017467, theta=-23.010388 -> V=1.0, theta=0.0
% INFO    : Bus 8473	: V=1.038343, theta=-8.939723 -> V=1.0, theta=0.0
% INFO    : Bus 8474	: V=1.093709, theta=-21.648428 -> V=1.0, theta=0.0
% INFO    : Bus 8475	: V=1.068803, theta=-48.115522 -> V=1.0, theta=0.0
% INFO    : Bus 8476	: V=0.974696, theta=-21.991786 -> V=1.0, theta=0.0
% INFO    : Bus 8477	: V=1.060032, theta=-10.617375 -> V=1.0, theta=0.0
% INFO    : Bus 8478	: V=1.043687, theta=-8.725012 -> V=1.0, theta=0.0
% INFO    : Bus 8479	: V=0.995898, theta=9.360812 -> V=1.0, theta=0.0
% INFO    : Bus 8480	: V=1.027373, theta=14.332171 -> V=1.0, theta=0.0
% INFO    : Bus 8481	: V=1.035652, theta=-28.583007 -> V=1.0, theta=0.0
% INFO    : Bus 8482	: V=0.994876, theta=-20.820169 -> V=1.0, theta=0.0
% INFO    : Bus 8483	: V=1.048138, theta=18.207562 -> V=1.0, theta=0.0
% INFO    : Bus 8484	: V=1.015152, theta=-35.999149 -> V=1.0, theta=0.0
% INFO    : Bus 8485	: V=1.037606, theta=-7.581446 -> V=1.0, theta=0.0
% INFO    : Bus 8486	: V=1.043845, theta=-19.840695 -> V=1.0, theta=0.0
% INFO    : Bus 8487	: V=0.994986, theta=-4.06639 -> V=1.0, theta=0.0
% INFO    : Bus 8488	: V=1.022527, theta=-24.16707 -> V=1.0, theta=0.0
% INFO    : Bus 8489	: V=1.044468, theta=-33.475701 -> V=1.0, theta=0.0
% INFO    : Bus 8490	: V=1.020965, theta=-1.151268 -> V=1.0, theta=0.0
% INFO    : Bus 8491	: V=1.018354, theta=-1.418547 -> V=1.0, theta=0.0
% INFO    : Bus 8492	: V=1.019872, theta=-4.282529 -> V=1.0, theta=0.0
% INFO    : Bus 8493	: V=0.969171, theta=-37.027093 -> V=1.0, theta=0.0
% INFO    : Bus 8494	: V=1.086265, theta=-10.060933 -> V=1.0, theta=0.0
% INFO    : Bus 8495	: V=1.04515, theta=-22.254829 -> V=1.0, theta=0.0
% INFO    : Bus 8496	: V=1.067205, theta=-29.196427 -> V=1.0, theta=0.0
% INFO    : Bus 8497	: V=1.04174, theta=-14.836957 -> V=1.0, theta=0.0
% INFO    : Bus 8498	: V=1.044703, theta=46.218731 -> V=1.0, theta=0.0
% INFO    : Bus 8499	: V=1.001762, theta=-20.542659 -> V=1.0, theta=0.0
% INFO    : Bus 8500	: V=1.027198, theta=-35.522122 -> V=1.0, theta=0.0
% INFO    : Bus 8501	: V=0.943472, theta=-31.974863 -> V=1.0, theta=0.0
% INFO    : Bus 8502	: V=0.967291, theta=-32.43496 -> V=1.0, theta=0.0
% INFO    : Bus 8503	: V=1.012117, theta=-6.296154 -> V=1.0, theta=0.0
% INFO    : Bus 8504	: V=1.070173, theta=-38.840203 -> V=1.0, theta=0.0
% INFO    : Bus 8505	: V=1.052274, theta=-19.616218 -> V=1.0, theta=0.0
% INFO    : Bus 8506	: V=0.982012, theta=-27.319954 -> V=1.0, theta=0.0
% INFO    : Bus 8507	: V=1.068688, theta=-26.744893 -> V=1.0, theta=0.0
% INFO    : Bus 8508	: V=1.030505, theta=16.850212 -> V=1.0, theta=0.0
% INFO    : Bus 8509	: V=1.034288, theta=-30.033529 -> V=1.0, theta=0.0
% INFO    : Bus 8510	: V=1.063564, theta=14.839237 -> V=1.0, theta=0.0
% INFO    : Bus 8511	: V=1.038633, theta=-24.833489 -> V=1.0, theta=0.0
% INFO    : Bus 8512	: V=1.007232, theta=-47.769593 -> V=1.0, theta=0.0
% INFO    : Bus 8513	: V=1.027518, theta=-27.107897 -> V=1.0, theta=0.0
% INFO    : Bus 8514	: V=1.067535, theta=-19.55661 -> V=1.0, theta=0.0
% INFO    : Bus 8515	: V=1.059651, theta=-12.797067 -> V=1.0, theta=0.0
% INFO    : Bus 8516	: V=1.018486, theta=7.90663 -> V=1.0, theta=0.0
% INFO    : Bus 8517	: V=1.037198, theta=8.190569 -> V=1.0, theta=0.0
% INFO    : Bus 8518	: V=1.031547, theta=-7.26949 -> V=1.0, theta=0.0
% INFO    : Bus 8519	: V=1.058712, theta=-28.62346 -> V=1.0, theta=0.0
% INFO    : Bus 8520	: V=1.027418, theta=-10.670989 -> V=1.0, theta=0.0
% INFO    : Bus 8521	: V=1.022682, theta=-33.542758 -> V=1.0, theta=0.0
% INFO    : Bus 8522	: V=1.027564, theta=-15.472563 -> V=1.0, theta=0.0
% INFO    : Bus 8523	: V=1.029809, theta=-4.439668 -> V=1.0, theta=0.0
% INFO    : Bus 8524	: V=1.093985, theta=-47.983991 -> V=1.0, theta=0.0
% INFO    : Bus 8525	: V=1.032332, theta=26.341746 -> V=1.0, theta=0.0
% INFO    : Bus 8526	: V=1.049684, theta=-21.785872 -> V=1.0, theta=0.0
% INFO    : Bus 8527	: V=0.985975, theta=-22.366185 -> V=1.0, theta=0.0
% INFO    : Bus 8528	: V=1.022215, theta=51.357588 -> V=1.0, theta=0.0
% INFO    : Bus 8529	: V=1.00959, theta=-47.214593 -> V=1.0, theta=0.0
% INFO    : Bus 8530	: V=1.010375, theta=-46.855704 -> V=1.0, theta=0.0
% INFO    : Bus 8531	: V=1.019991, theta=-20.209592 -> V=1.0, theta=0.0
% INFO    : Bus 8532	: V=1.032486, theta=-13.566695 -> V=1.0, theta=0.0
% INFO    : Bus 8533	: V=0.990619, theta=-21.190201 -> V=1.0, theta=0.0
% INFO    : Bus 8534	: V=1.013794, theta=-44.443797 -> V=1.0, theta=0.0
% INFO    : Bus 8535	: V=1.031595, theta=-22.272387 -> V=1.0, theta=0.0
% INFO    : Bus 8536	: V=0.974217, theta=-31.060355 -> V=1.0, theta=0.0
% INFO    : Bus 8537	: V=1.035589, theta=7.167784 -> V=1.0, theta=0.0
% INFO    : Bus 8538	: V=1.013807, theta=-32.593868 -> V=1.0, theta=0.0
% INFO    : Bus 8539	: V=1.056399, theta=-34.762887 -> V=1.0, theta=0.0
% INFO    : Bus 8540	: V=1.006246, theta=-31.812632 -> V=1.0, theta=0.0
% INFO    : Bus 8541	: V=1.040496, theta=9.279655 -> V=1.0, theta=0.0
% INFO    : Bus 8542	: V=1.041837, theta=-21.334133 -> V=1.0, theta=0.0
% INFO    : Bus 8543	: V=1.073534, theta=-1.689652 -> V=1.0, theta=0.0
% INFO    : Bus 8544	: V=0.982538, theta=6.790327 -> V=1.0, theta=0.0
% INFO    : Bus 8545	: V=1.028466, theta=-40.123318 -> V=1.0, theta=0.0
% INFO    : Bus 8546	: V=1.035972, theta=-11.828136 -> V=1.0, theta=0.0
% INFO    : Bus 8547	: V=1.008267, theta=-52.388483 -> V=1.0, theta=0.0
% INFO    : Bus 8548	: V=1.014538, theta=-27.099328 -> V=1.0, theta=0.0
% INFO    : Bus 8549	: V=1.015773, theta=-24.245852 -> V=1.0, theta=0.0
% INFO    : Bus 8550	: V=0.976417, theta=-30.337941 -> V=1.0, theta=0.0
% INFO    : Bus 8551	: V=0.994046, theta=-21.126665 -> V=1.0, theta=0.0
% INFO    : Bus 8552	: V=1.016198, theta=8.888573 -> V=1.0, theta=0.0
% INFO    : Bus 8553	: V=1.077556, theta=60.968069 -> V=1.0, theta=0.0
% INFO    : Bus 8554	: V=1.092619, theta=-27.557647 -> V=1.0, theta=0.0
% INFO    : Bus 8555	: V=1.032085, theta=-41.190379 -> V=1.0, theta=0.0
% INFO    : Bus 8556	: V=1.040779, theta=-43.284256 -> V=1.0, theta=0.0
% INFO    : Bus 8557	: V=1.012552, theta=-39.089667 -> V=1.0, theta=0.0
% INFO    : Bus 8558	: V=0.96568, theta=-37.714763 -> V=1.0, theta=0.0
% INFO    : Bus 8559	: V=1.013215, theta=-30.419221 -> V=1.0, theta=0.0
% INFO    : Bus 8560	: V=0.980131, theta=-18.492926 -> V=1.0, theta=0.0
% INFO    : Bus 8561	: V=1.060954, theta=-43.422544 -> V=1.0, theta=0.0
% INFO    : Bus 8562	: V=1.096728, theta=-23.569307 -> V=1.0, theta=0.0
% INFO    : Bus 8563	: V=1.010131, theta=-25.941552 -> V=1.0, theta=0.0
% INFO    : Bus 8564	: V=1.01667, theta=-19.679406 -> V=1.0, theta=0.0
% INFO    : Bus 8565	: V=1.048835, theta=7.304522 -> V=1.0, theta=0.0
% INFO    : Bus 8566	: V=1.016108, theta=-27.483837 -> V=1.0, theta=0.0
% INFO    : Bus 8567	: V=1.030261, theta=-38.98912 -> V=1.0, theta=0.0
% INFO    : Bus 8568	: V=1.023273, theta=-6.370838 -> V=1.0, theta=0.0
% INFO    : Bus 8569	: V=1.038006, theta=-36.82583 -> V=1.0, theta=0.0
% INFO    : Bus 8570	: V=0.991237, theta=-31.624371 -> V=1.0, theta=0.0
% INFO    : Bus 8571	: V=1.024502, theta=-54.221095 -> V=1.0, theta=0.0
% INFO    : Bus 8572	: V=0.997313, theta=-26.959645 -> V=1.0, theta=0.0
% INFO    : Bus 8573	: V=1.017811, theta=-46.734623 -> V=1.0, theta=0.0
% INFO    : Bus 8574	: V=0.993535, theta=-4.162453 -> V=1.0, theta=0.0
% INFO    : Bus 8575	: V=1.023769, theta=-54.455841 -> V=1.0, theta=0.0
% INFO    : Bus 8576	: V=1.017525, theta=-5.150807 -> V=1.0, theta=0.0
% INFO    : Bus 8577	: V=1.050327, theta=-31.670632 -> V=1.0, theta=0.0
% INFO    : Bus 8578	: V=1.036215, theta=-22.212869 -> V=1.0, theta=0.0
% INFO    : Bus 8579	: V=1.016275, theta=-35.57685 -> V=1.0, theta=0.0
% INFO    : Bus 8580	: V=1.076159, theta=-25.123339 -> V=1.0, theta=0.0
% INFO    : Bus 8581	: V=1.019212, theta=4.571542 -> V=1.0, theta=0.0
% INFO    : Bus 8582	: V=1.02128, theta=-52.018951 -> V=1.0, theta=0.0
% INFO    : Bus 8583	: V=1.065295, theta=-12.788581 -> V=1.0, theta=0.0
% INFO    : Bus 8584	: V=1.022184, theta=-8.982181 -> V=1.0, theta=0.0
% INFO    : Bus 8585	: V=1.028916, theta=13.84417 -> V=1.0, theta=0.0
% INFO    : Bus 8586	: V=1.002287, theta=-26.032897 -> V=1.0, theta=0.0
% INFO    : Bus 8587	: V=1.025557, theta=-24.888109 -> V=1.0, theta=0.0
% INFO    : Bus 8588	: V=1.020087, theta=-48.936381 -> V=1.0, theta=0.0
% INFO    : Bus 8589	: V=0.967627, theta=-32.440968 -> V=1.0, theta=0.0
% INFO    : Bus 8590	: V=1.038424, theta=-24.662973 -> V=1.0, theta=0.0
% INFO    : Bus 8591	: V=1.06486, theta=-21.126008 -> V=1.0, theta=0.0
% INFO    : Bus 8592	: V=1.050094, theta=-3.995844 -> V=1.0, theta=0.0
% INFO    : Bus 8593	: V=1.095968, theta=45.426526 -> V=1.0, theta=0.0
% INFO    : Bus 8594	: V=0.954489, theta=-30.331753 -> V=1.0, theta=0.0
% INFO    : Bus 8595	: V=1.006996, theta=3.372222 -> V=1.0, theta=0.0
% INFO    : Bus 8596	: V=0.893342, theta=-35.877764 -> V=1.0, theta=0.0
% INFO    : Bus 8597	: V=1.026523, theta=-16.879696 -> V=1.0, theta=0.0
% INFO    : Bus 8598	: V=1.031185, theta=-22.053606 -> V=1.0, theta=0.0
% INFO    : Bus 8599	: V=1.04312, theta=-21.80475 -> V=1.0, theta=0.0
% INFO    : Bus 8600	: V=1.028118, theta=-35.099662 -> V=1.0, theta=0.0
% INFO    : Bus 8601	: V=1.036534, theta=-51.990564 -> V=1.0, theta=0.0
% INFO    : Bus 8602	: V=0.982449, theta=9.7613 -> V=1.0, theta=0.0
% INFO    : Bus 8603	: V=1.022771, theta=-21.785917 -> V=1.0, theta=0.0
% INFO    : Bus 8604	: V=1.020243, theta=15.224814 -> V=1.0, theta=0.0
% INFO    : Bus 8605	: V=1.005953, theta=-0.504817 -> V=1.0, theta=0.0
% INFO    : Bus 8606	: V=0.991297, theta=-30.713122 -> V=1.0, theta=0.0
% INFO    : Bus 8607	: V=0.9901, theta=-34.700265 -> V=1.0, theta=0.0
% INFO    : Bus 8608	: V=1.033413, theta=-35.620556 -> V=1.0, theta=0.0
% INFO    : Bus 8609	: V=1.024958, theta=-22.744767 -> V=1.0, theta=0.0
% INFO    : Bus 8610	: V=1.056933, theta=6.177576 -> V=1.0, theta=0.0
% INFO    : Bus 8611	: V=1.024775, theta=63.476826 -> V=1.0, theta=0.0
% INFO    : Bus 8612	: V=1.019124, theta=-34.958062 -> V=1.0, theta=0.0
% INFO    : Bus 8613	: V=1.023127, theta=1.903711 -> V=1.0, theta=0.0
% INFO    : Bus 8614	: V=1.035176, theta=44.215941 -> V=1.0, theta=0.0
% INFO    : Bus 8615	: V=1.040415, theta=-23.134266 -> V=1.0, theta=0.0
% INFO    : Bus 8616	: V=0.964784, theta=-31.482874 -> V=1.0, theta=0.0
% INFO    : Bus 8617	: V=0.983977, theta=-31.897049 -> V=1.0, theta=0.0
% INFO    : Bus 8618	: V=1.017905, theta=-27.123566 -> V=1.0, theta=0.0
% INFO    : Bus 8619	: V=1.026622, theta=-16.900837 -> V=1.0, theta=0.0
% INFO    : Bus 8620	: V=1.025816, theta=-10.251952 -> V=1.0, theta=0.0
% INFO    : Bus 8621	: V=1.017477, theta=17.227709 -> V=1.0, theta=0.0
% INFO    : Bus 8622	: V=1.028478, theta=-36.114605 -> V=1.0, theta=0.0
% INFO    : Bus 8623	: V=1.034977, theta=-24.552494 -> V=1.0, theta=0.0
% INFO    : Bus 8624	: V=0.982939, theta=9.190133 -> V=1.0, theta=0.0
% INFO    : Bus 8625	: V=1.051079, theta=-41.671715 -> V=1.0, theta=0.0
% INFO    : Bus 8626	: V=0.987786, theta=-17.922777 -> V=1.0, theta=0.0
% INFO    : Bus 8627	: V=1.044027, theta=-26.736186 -> V=1.0, theta=0.0
% INFO    : Bus 8628	: V=1.036975, theta=-23.955541 -> V=1.0, theta=0.0
% INFO    : Bus 8629	: V=0.967122, theta=-43.610509 -> V=1.0, theta=0.0
% INFO    : Bus 8630	: V=1.059594, theta=-47.562957 -> V=1.0, theta=0.0
% INFO    : Bus 8631	: V=0.918045, theta=-35.76819 -> V=1.0, theta=0.0
% INFO    : Bus 8632	: V=1.050716, theta=-24.767052 -> V=1.0, theta=0.0
% INFO    : Bus 8633	: V=1.039381, theta=-16.713316 -> V=1.0, theta=0.0
% INFO    : Bus 8634	: V=1.017282, theta=-29.113408 -> V=1.0, theta=0.0
% INFO    : Bus 8635	: V=1.013338, theta=-47.542885 -> V=1.0, theta=0.0
% INFO    : Bus 8636	: V=1.030477, theta=-22.079517 -> V=1.0, theta=0.0
% INFO    : Bus 8637	: V=0.963865, theta=-31.392893 -> V=1.0, theta=0.0
% INFO    : Bus 8638	: V=1.027699, theta=9.746278 -> V=1.0, theta=0.0
% INFO    : Bus 8639	: V=1.019721, theta=-5.304798 -> V=1.0, theta=0.0
% INFO    : Bus 8640	: V=1.174902, theta=-19.739552 -> V=1.0, theta=0.0
% INFO    : Bus 8641	: V=1.11078, theta=-29.279417 -> V=1.0, theta=0.0
% INFO    : Bus 8642	: V=1.031062, theta=8.31398 -> V=1.0, theta=0.0
% INFO    : Bus 8643	: V=0.992929, theta=-28.53906 -> V=1.0, theta=0.0
% INFO    : Bus 8644	: V=1.165566, theta=-22.013417 -> V=1.0, theta=0.0
% INFO    : Bus 8645	: V=0.977499, theta=-24.296922 -> V=1.0, theta=0.0
% INFO    : Bus 8646	: V=1.062285, theta=-25.159125 -> V=1.0, theta=0.0
% INFO    : Bus 8647	: V=1.020365, theta=1.923148 -> V=1.0, theta=0.0
% INFO    : Bus 8648	: V=1.009446, theta=-22.883661 -> V=1.0, theta=0.0
% INFO    : Bus 8649	: V=1.084595, theta=-28.010738 -> V=1.0, theta=0.0
% INFO    : Bus 8650	: V=1.029588, theta=-40.945637 -> V=1.0, theta=0.0
% INFO    : Bus 8651	: V=1.031215, theta=-17.06483 -> V=1.0, theta=0.0
% INFO    : Bus 8652	: V=1.034612, theta=4.025941 -> V=1.0, theta=0.0
% INFO    : Bus 8653	: V=1.034538, theta=-16.169774 -> V=1.0, theta=0.0
% INFO    : Bus 8654	: V=1.009473, theta=-10.803889 -> V=1.0, theta=0.0
% INFO    : Bus 8655	: V=1.035878, theta=-30.794051 -> V=1.0, theta=0.0
% INFO    : Bus 8656	: V=1.026513, theta=-9.244782 -> V=1.0, theta=0.0
% INFO    : Bus 8657	: V=1.011958, theta=-7.088597 -> V=1.0, theta=0.0
% INFO    : Bus 8658	: V=1.02585, theta=-54.455522 -> V=1.0, theta=0.0
% INFO    : Bus 8659	: V=1.041316, theta=-20.872613 -> V=1.0, theta=0.0
% INFO    : Bus 8660	: V=0.999992, theta=-36.806485 -> V=1.0, theta=0.0
% INFO    : Bus 8661	: V=1.023652, theta=-48.576903 -> V=1.0, theta=0.0
% INFO    : Bus 8662	: V=1.079881, theta=31.582222 -> V=1.0, theta=0.0
% INFO    : Bus 8663	: V=1.025281, theta=-12.708169 -> V=1.0, theta=0.0
% INFO    : Bus 8664	: V=1.056778, theta=-46.823851 -> V=1.0, theta=0.0
% INFO    : Bus 8665	: V=0.976784, theta=-30.555308 -> V=1.0, theta=0.0
% INFO    : Bus 8666	: V=0.974899, theta=-21.620786 -> V=1.0, theta=0.0
% INFO    : Bus 8667	: V=1.00122, theta=-39.501095 -> V=1.0, theta=0.0
% INFO    : Bus 8668	: V=1.017386, theta=13.248317 -> V=1.0, theta=0.0
% INFO    : Bus 8669	: V=1.042341, theta=-15.672433 -> V=1.0, theta=0.0
% INFO    : Bus 8670	: V=1.042199, theta=-6.729364 -> V=1.0, theta=0.0
% INFO    : Bus 8671	: V=1.013382, theta=-51.253863 -> V=1.0, theta=0.0
% INFO    : Bus 8672	: V=1.022513, theta=-21.387883 -> V=1.0, theta=0.0
% INFO    : Bus 8673	: V=0.989519, theta=-35.131931 -> V=1.0, theta=0.0
% INFO    : Bus 8674	: V=1.046981, theta=-24.95506 -> V=1.0, theta=0.0
% INFO    : Bus 8675	: V=1.037158, theta=-23.941358 -> V=1.0, theta=0.0
% INFO    : Bus 8676	: V=1.019558, theta=-21.879637 -> V=1.0, theta=0.0
% INFO    : Bus 8677	: V=1.016261, theta=-10.284826 -> V=1.0, theta=0.0
% INFO    : Bus 8678	: V=0.989904, theta=-28.489073 -> V=1.0, theta=0.0
% INFO    : Bus 8679	: V=1.009551, theta=6.826901 -> V=1.0, theta=0.0
% INFO    : Bus 8680	: V=1.001193, theta=-8.273624 -> V=1.0, theta=0.0
% INFO    : Bus 8681	: V=0.972909, theta=-53.475502 -> V=1.0, theta=0.0
% INFO    : Bus 8682	: V=1.016275, theta=-9.010491 -> V=1.0, theta=0.0
% INFO    : Bus 8683	: V=1.039554, theta=-24.600261 -> V=1.0, theta=0.0
% INFO    : Bus 8684	: V=0.968578, theta=-37.38368 -> V=1.0, theta=0.0
% INFO    : Bus 8685	: V=1.019225, theta=-4.135965 -> V=1.0, theta=0.0
% INFO    : Bus 8686	: V=1.023602, theta=-32.455421 -> V=1.0, theta=0.0
% INFO    : Bus 8687	: V=1.016095, theta=18.588008 -> V=1.0, theta=0.0
% INFO    : Bus 8688	: V=1.092516, theta=-27.545772 -> V=1.0, theta=0.0
% INFO    : Bus 8689	: V=1.03309, theta=-21.003238 -> V=1.0, theta=0.0
% INFO    : Bus 8690	: V=1.045485, theta=-16.317647 -> V=1.0, theta=0.0
% INFO    : Bus 8691	: V=1.041127, theta=-33.775172 -> V=1.0, theta=0.0
% INFO    : Bus 8692	: V=1.059128, theta=-17.181332 -> V=1.0, theta=0.0
% INFO    : Bus 8693	: V=1.073334, theta=60.748503 -> V=1.0, theta=0.0
% INFO    : Bus 8694	: V=1.014733, theta=-33.035812 -> V=1.0, theta=0.0
% INFO    : Bus 8695	: V=1.026323, theta=-2.650757 -> V=1.0, theta=0.0
% INFO    : Bus 8696	: V=1.026382, theta=-12.469966 -> V=1.0, theta=0.0
% INFO    : Bus 8697	: V=1.015734, theta=-26.417686 -> V=1.0, theta=0.0
% INFO    : Bus 8698	: V=0.982379, theta=9.295612 -> V=1.0, theta=0.0
% INFO    : Bus 8699	: V=1.019275, theta=9.277342 -> V=1.0, theta=0.0
% INFO    : Bus 8700	: V=1.013945, theta=-32.760027 -> V=1.0, theta=0.0
% INFO    : Bus 8701	: V=1.021917, theta=-44.217953 -> V=1.0, theta=0.0
% INFO    : Bus 8702	: V=1.026759, theta=-41.204592 -> V=1.0, theta=0.0
% INFO    : Bus 8703	: V=1.010883, theta=-32.679218 -> V=1.0, theta=0.0
% INFO    : Bus 8704	: V=1.038186, theta=-8.064046 -> V=1.0, theta=0.0
% INFO    : Bus 8705	: V=0.995757, theta=-27.153575 -> V=1.0, theta=0.0
% INFO    : Bus 8706	: V=1.017244, theta=4.061846 -> V=1.0, theta=0.0
% INFO    : Bus 8707	: V=1.028321, theta=-11.903148 -> V=1.0, theta=0.0
% INFO    : Bus 8708	: V=1.025238, theta=-34.309952 -> V=1.0, theta=0.0
% INFO    : Bus 8709	: V=1.033387, theta=-23.424365 -> V=1.0, theta=0.0
% INFO    : Bus 8710	: V=1.02164, theta=-48.196695 -> V=1.0, theta=0.0
% INFO    : Bus 8711	: V=1.035108, theta=-12.381387 -> V=1.0, theta=0.0
% INFO    : Bus 8712	: V=0.975055, theta=-32.24574 -> V=1.0, theta=0.0
% INFO    : Bus 8713	: V=1.02082, theta=16.809698 -> V=1.0, theta=0.0
% INFO    : Bus 8714	: V=1.015463, theta=-7.074502 -> V=1.0, theta=0.0
% INFO    : Bus 8715	: V=1.069467, theta=-22.161838 -> V=1.0, theta=0.0
% INFO    : Bus 8716	: V=1.069514, theta=26.080416 -> V=1.0, theta=0.0
% INFO    : Bus 8717	: V=1.083125, theta=-17.411194 -> V=1.0, theta=0.0
% INFO    : Bus 8718	: V=1.026636, theta=-34.506198 -> V=1.0, theta=0.0
% INFO    : Bus 8719	: V=1.010794, theta=-45.334737 -> V=1.0, theta=0.0
% INFO    : Bus 8720	: V=0.968716, theta=-28.617584 -> V=1.0, theta=0.0
% INFO    : Bus 8721	: V=1.055054, theta=-16.297809 -> V=1.0, theta=0.0
% INFO    : Bus 8722	: V=1.066576, theta=-25.430169 -> V=1.0, theta=0.0
% INFO    : Bus 8723	: V=1.026073, theta=-14.019533 -> V=1.0, theta=0.0
% INFO    : Bus 8724	: V=1.041758, theta=-18.876378 -> V=1.0, theta=0.0
% INFO    : Bus 8725	: V=1.036813, theta=8.212135 -> V=1.0, theta=0.0
% INFO    : Bus 8726	: V=1.003185, theta=-23.363326 -> V=1.0, theta=0.0
% INFO    : Bus 8727	: V=0.966862, theta=-34.40203 -> V=1.0, theta=0.0
% INFO    : Bus 8728	: V=1.069096, theta=3.169893 -> V=1.0, theta=0.0
% INFO    : Bus 8729	: V=1.008386, theta=-38.518465 -> V=1.0, theta=0.0
% INFO    : Bus 8730	: V=1.046974, theta=-27.18651 -> V=1.0, theta=0.0
% INFO    : Bus 8731	: V=1.021526, theta=-40.277052 -> V=1.0, theta=0.0
% INFO    : Bus 8732	: V=1.034889, theta=-21.457823 -> V=1.0, theta=0.0
% INFO    : Bus 8733	: V=1.037546, theta=9.238636 -> V=1.0, theta=0.0
% INFO    : Bus 8734	: V=1.008034, theta=-28.929654 -> V=1.0, theta=0.0
% INFO    : Bus 8735	: V=0.986546, theta=-29.724015 -> V=1.0, theta=0.0
% INFO    : Bus 8736	: V=0.989655, theta=-30.821299 -> V=1.0, theta=0.0
% INFO    : Bus 8737	: V=1.058573, theta=-28.372231 -> V=1.0, theta=0.0
% INFO    : Bus 8738	: V=1.025108, theta=5.448735 -> V=1.0, theta=0.0
% INFO    : Bus 8739	: V=0.959797, theta=-37.411141 -> V=1.0, theta=0.0
% INFO    : Bus 8740	: V=0.985151, theta=-28.761493 -> V=1.0, theta=0.0
% INFO    : Bus 8741	: V=1.033837, theta=-39.750284 -> V=1.0, theta=0.0
% INFO    : Bus 8742	: V=1.031843, theta=-9.377241 -> V=1.0, theta=0.0
% INFO    : Bus 8743	: V=1.025606, theta=-34.269151 -> V=1.0, theta=0.0
% INFO    : Bus 8744	: V=0.972972, theta=-37.275725 -> V=1.0, theta=0.0
% INFO    : Bus 8745	: V=0.989405, theta=-30.788811 -> V=1.0, theta=0.0
% INFO    : Bus 8746	: V=1.048871, theta=-20.066491 -> V=1.0, theta=0.0
% INFO    : Bus 8747	: V=1.047501, theta=-24.793142 -> V=1.0, theta=0.0
% INFO    : Bus 8748	: V=1.063635, theta=-49.908328 -> V=1.0, theta=0.0
% INFO    : Bus 8749	: V=0.980914, theta=-30.105334 -> V=1.0, theta=0.0
% INFO    : Bus 8750	: V=0.994461, theta=-30.251812 -> V=1.0, theta=0.0
% INFO    : Bus 8751	: V=1.043288, theta=-17.358459 -> V=1.0, theta=0.0
% INFO    : Bus 8752	: V=0.990312, theta=-30.214954 -> V=1.0, theta=0.0
% INFO    : Bus 8753	: V=1.029088, theta=-11.334255 -> V=1.0, theta=0.0
% INFO    : Bus 8754	: V=1.007818, theta=-26.185595 -> V=1.0, theta=0.0
% INFO    : Bus 8755	: V=0.928442, theta=-30.498908 -> V=1.0, theta=0.0
% INFO    : Bus 8756	: V=1.009712, theta=-60.476539 -> V=1.0, theta=0.0
% INFO    : Bus 8757	: V=0.989012, theta=-30.812297 -> V=1.0, theta=0.0
% INFO    : Bus 8758	: V=1.047294, theta=10.896261 -> V=1.0, theta=0.0
% INFO    : Bus 8759	: V=1.026786, theta=14.2136 -> V=1.0, theta=0.0
% INFO    : Bus 8760	: V=0.948567, theta=-21.02637 -> V=1.0, theta=0.0
% INFO    : Bus 8761	: V=1.017931, theta=62.866743 -> V=1.0, theta=0.0
% INFO    : Bus 8762	: V=1.046022, theta=46.235938 -> V=1.0, theta=0.0
% INFO    : Bus 8763	: V=1.02928, theta=2.451775 -> V=1.0, theta=0.0
% INFO    : Bus 8764	: V=1.048209, theta=-3.324162 -> V=1.0, theta=0.0
% INFO    : Bus 8765	: V=1.042555, theta=-15.65821 -> V=1.0, theta=0.0
% INFO    : Bus 8766	: V=1.021881, theta=-6.603587 -> V=1.0, theta=0.0
% INFO    : Bus 8767	: V=1.03213, theta=-26.669148 -> V=1.0, theta=0.0
% INFO    : Bus 8768	: V=1.035222, theta=-24.061987 -> V=1.0, theta=0.0
% INFO    : Bus 8769	: V=1.04929, theta=-22.14211 -> V=1.0, theta=0.0
% INFO    : Bus 8770	: V=1.012975, theta=-24.464313 -> V=1.0, theta=0.0
% INFO    : Bus 8771	: V=1.006983, theta=-37.979458 -> V=1.0, theta=0.0
% INFO    : Bus 8772	: V=1.022559, theta=8.17473 -> V=1.0, theta=0.0
% INFO    : Bus 8773	: V=1.008807, theta=10.994888 -> V=1.0, theta=0.0
% INFO    : Bus 8774	: V=1.026003, theta=-33.284232 -> V=1.0, theta=0.0
% INFO    : Bus 8775	: V=1.006926, theta=5.67316 -> V=1.0, theta=0.0
% INFO    : Bus 8776	: V=0.999607, theta=-38.362871 -> V=1.0, theta=0.0
% INFO    : Bus 8777	: V=0.984627, theta=-28.428042 -> V=1.0, theta=0.0
% INFO    : Bus 8778	: V=1.008213, theta=-2.607965 -> V=1.0, theta=0.0
% INFO    : Bus 8779	: V=1.05095, theta=15.405182 -> V=1.0, theta=0.0
% INFO    : Bus 8780	: V=0.994674, theta=-20.33854 -> V=1.0, theta=0.0
% INFO    : Bus 8781	: V=1.013383, theta=-41.325087 -> V=1.0, theta=0.0
% INFO    : Bus 8782	: V=1.025664, theta=-28.456413 -> V=1.0, theta=0.0
% INFO    : Bus 8783	: V=0.97866, theta=-31.872838 -> V=1.0, theta=0.0
% INFO    : Bus 8784	: V=1.021916, theta=10.857723 -> V=1.0, theta=0.0
% INFO    : Bus 8785	: V=1.03393, theta=-3.107838 -> V=1.0, theta=0.0
% INFO    : Bus 8786	: V=0.982627, theta=-24.865359 -> V=1.0, theta=0.0
% INFO    : Bus 8787	: V=1.061905, theta=-17.274053 -> V=1.0, theta=0.0
% INFO    : Bus 8788	: V=1.046837, theta=-6.159102 -> V=1.0, theta=0.0
% INFO    : Bus 8789	: V=0.987443, theta=-46.759012 -> V=1.0, theta=0.0
% INFO    : Bus 8790	: V=1.025925, theta=4.550938 -> V=1.0, theta=0.0
% INFO    : Bus 8791	: V=1.054222, theta=-22.685203 -> V=1.0, theta=0.0
% INFO    : Bus 8792	: V=1.026906, theta=3.499429 -> V=1.0, theta=0.0
% INFO    : Bus 8793	: V=1.012192, theta=-21.626493 -> V=1.0, theta=0.0
% INFO    : Bus 8794	: V=1.018534, theta=-16.087801 -> V=1.0, theta=0.0
% INFO    : Bus 8795	: V=1.052731, theta=-0.198514 -> V=1.0, theta=0.0
% INFO    : Bus 8796	: V=0.982515, theta=-34.879291 -> V=1.0, theta=0.0
% INFO    : Bus 8797	: V=1.072681, theta=-17.583553 -> V=1.0, theta=0.0
% INFO    : Bus 8798	: V=1.013086, theta=-6.857034 -> V=1.0, theta=0.0
% INFO    : Bus 8799	: V=1.044314, theta=-27.26816 -> V=1.0, theta=0.0
% INFO    : Bus 8800	: V=0.998919, theta=-43.895136 -> V=1.0, theta=0.0
% INFO    : Bus 8801	: V=1.056476, theta=-17.127916 -> V=1.0, theta=0.0
% INFO    : Bus 8802	: V=1.047815, theta=65.89492 -> V=1.0, theta=0.0
% INFO    : Bus 8803	: V=1.026988, theta=-28.497266 -> V=1.0, theta=0.0
% INFO    : Bus 8804	: V=1.044229, theta=-9.735086 -> V=1.0, theta=0.0
% INFO    : Bus 8805	: V=1.008439, theta=-35.641062 -> V=1.0, theta=0.0
% INFO    : Bus 8806	: V=1.065258, theta=-44.117934 -> V=1.0, theta=0.0
% INFO    : Bus 8807	: V=1.049311, theta=-4.132509 -> V=1.0, theta=0.0
% INFO    : Bus 8808	: V=1.053244, theta=-26.177439 -> V=1.0, theta=0.0
% INFO    : Bus 8809	: V=1.021169, theta=-32.757915 -> V=1.0, theta=0.0
% INFO    : Bus 8810	: V=1.057257, theta=-2.779316 -> V=1.0, theta=0.0
% INFO    : Bus 8811	: V=1.034197, theta=-41.067687 -> V=1.0, theta=0.0
% INFO    : Bus 8812	: V=0.980979, theta=-25.408064 -> V=1.0, theta=0.0
% INFO    : Bus 8813	: V=0.949387, theta=-33.784726 -> V=1.0, theta=0.0
% INFO    : Bus 8814	: V=1.031268, theta=3.404893 -> V=1.0, theta=0.0
% INFO    : Bus 8815	: V=0.966775, theta=-29.185099 -> V=1.0, theta=0.0
% INFO    : Bus 8816	: V=1.026497, theta=7.754492 -> V=1.0, theta=0.0
% INFO    : Bus 8817	: V=1.031901, theta=-3.671816 -> V=1.0, theta=0.0
% INFO    : Bus 8818	: V=1.049908, theta=0.513122 -> V=1.0, theta=0.0
% INFO    : Bus 8819	: V=1.030028, theta=-53.584288 -> V=1.0, theta=0.0
% INFO    : Bus 8820	: V=1.063983, theta=-22.01868 -> V=1.0, theta=0.0
% INFO    : Bus 8821	: V=1.030073, theta=-28.186147 -> V=1.0, theta=0.0
% INFO    : Bus 8822	: V=1.064182, theta=2.842782 -> V=1.0, theta=0.0
% INFO    : Bus 8823	: V=0.973835, theta=-32.030631 -> V=1.0, theta=0.0
% INFO    : Bus 8824	: V=1.018238, theta=-7.533838 -> V=1.0, theta=0.0
% INFO    : Bus 8825	: V=1.003275, theta=-3.014246 -> V=1.0, theta=0.0
% INFO    : Bus 8826	: V=1.047082, theta=-27.54358 -> V=1.0, theta=0.0
% INFO    : Bus 8827	: V=0.98658, theta=-31.221806 -> V=1.0, theta=0.0
% INFO    : Bus 8828	: V=1.016447, theta=5.856189 -> V=1.0, theta=0.0
% INFO    : Bus 8829	: V=1.033798, theta=-21.566094 -> V=1.0, theta=0.0
% INFO    : Bus 8830	: V=1.066758, theta=-24.688851 -> V=1.0, theta=0.0
% INFO    : Bus 8831	: V=0.924772, theta=-33.215113 -> V=1.0, theta=0.0
% INFO    : Bus 8832	: V=1.020209, theta=-1.214855 -> V=1.0, theta=0.0
% INFO    : Bus 8833	: V=0.999553, theta=-36.912321 -> V=1.0, theta=0.0
% INFO    : Bus 8834	: V=0.998306, theta=-22.906243 -> V=1.0, theta=0.0
% INFO    : Bus 8835	: V=1.032665, theta=-23.255961 -> V=1.0, theta=0.0
% INFO    : Bus 8836	: V=0.989016, theta=-25.195238 -> V=1.0, theta=0.0
% INFO    : Bus 8837	: V=1.034416, theta=-36.423723 -> V=1.0, theta=0.0
% INFO    : Bus 8838	: V=0.968504, theta=-37.395062 -> V=1.0, theta=0.0
% INFO    : Bus 8839	: V=1.005281, theta=-34.431326 -> V=1.0, theta=0.0
% INFO    : Bus 8840	: V=1.01206, theta=-29.373767 -> V=1.0, theta=0.0
% INFO    : Bus 8841	: V=1.005244, theta=-36.825291 -> V=1.0, theta=0.0
% INFO    : Bus 8842	: V=0.947855, theta=-29.361997 -> V=1.0, theta=0.0
% INFO    : Bus 8843	: V=1.0448, theta=-11.469831 -> V=1.0, theta=0.0
% INFO    : Bus 8844	: V=0.954467, theta=-30.324095 -> V=1.0, theta=0.0
% INFO    : Bus 8845	: V=1.091749, theta=-24.992145 -> V=1.0, theta=0.0
% INFO    : Bus 8846	: V=1.06383, theta=7.797356 -> V=1.0, theta=0.0
% INFO    : Bus 8847	: V=0.990993, theta=-0.924277 -> V=1.0, theta=0.0
% INFO    : Bus 8848	: V=0.905716, theta=-35.509144 -> V=1.0, theta=0.0
% INFO    : Bus 8849	: V=1.03897, theta=-40.00065 -> V=1.0, theta=0.0
% INFO    : Bus 8850	: V=1.040505, theta=-32.488756 -> V=1.0, theta=0.0
% INFO    : Bus 8851	: V=1.063062, theta=63.161074 -> V=1.0, theta=0.0
% INFO    : Bus 8852	: V=0.999293, theta=-31.516305 -> V=1.0, theta=0.0
% INFO    : Bus 8853	: V=1.047513, theta=-36.823466 -> V=1.0, theta=0.0
% INFO    : Bus 8854	: V=1.018324, theta=-44.929743 -> V=1.0, theta=0.0
% INFO    : Bus 8855	: V=1.040582, theta=-13.396994 -> V=1.0, theta=0.0
% INFO    : Bus 8856	: V=1.053444, theta=-29.282615 -> V=1.0, theta=0.0
% INFO    : Bus 8857	: V=1.020096, theta=-47.730647 -> V=1.0, theta=0.0
% INFO    : Bus 8858	: V=1.023098, theta=-43.776563 -> V=1.0, theta=0.0
% INFO    : Bus 8859	: V=1.038171, theta=-23.570752 -> V=1.0, theta=0.0
% INFO    : Bus 8860	: V=1.018319, theta=-10.244627 -> V=1.0, theta=0.0
% INFO    : Bus 8861	: V=0.984642, theta=-54.835443 -> V=1.0, theta=0.0
% INFO    : Bus 8862	: V=1.040369, theta=13.653554 -> V=1.0, theta=0.0
% INFO    : Bus 8863	: V=1.03086, theta=-29.325776 -> V=1.0, theta=0.0
% INFO    : Bus 8864	: V=1.027588, theta=-32.526591 -> V=1.0, theta=0.0
% INFO    : Bus 8865	: V=0.991171, theta=-30.939935 -> V=1.0, theta=0.0
% INFO    : Bus 8866	: V=1.0309, theta=-9.648344 -> V=1.0, theta=0.0
% INFO    : Bus 8867	: V=1.021392, theta=-49.003739 -> V=1.0, theta=0.0
% INFO    : Bus 8868	: V=1.010425, theta=1.428844 -> V=1.0, theta=0.0
% INFO    : Bus 8869	: V=1.034597, theta=-39.528177 -> V=1.0, theta=0.0
% INFO    : Bus 8870	: V=1.049355, theta=-48.447617 -> V=1.0, theta=0.0
% INFO    : Bus 8871	: V=1.032491, theta=-52.966137 -> V=1.0, theta=0.0
% INFO    : Bus 8872	: V=1.054777, theta=-16.321937 -> V=1.0, theta=0.0
% INFO    : Bus 8873	: V=1.068235, theta=-27.574168 -> V=1.0, theta=0.0
% INFO    : Bus 8874	: V=1.035192, theta=-20.158196 -> V=1.0, theta=0.0
% INFO    : Bus 8875	: V=1.045119, theta=17.388436 -> V=1.0, theta=0.0
% INFO    : Bus 8876	: V=1.041399, theta=-40.915836 -> V=1.0, theta=0.0
% INFO    : Bus 8877	: V=1.036434, theta=-20.951083 -> V=1.0, theta=0.0
% INFO    : Bus 8878	: V=1.013774, theta=22.290758 -> V=1.0, theta=0.0
% INFO    : Bus 8879	: V=1.032441, theta=-23.098207 -> V=1.0, theta=0.0
% INFO    : Bus 8880	: V=1.041681, theta=-19.352535 -> V=1.0, theta=0.0
% INFO    : Bus 8881	: V=1.024415, theta=-1.614683 -> V=1.0, theta=0.0
% INFO    : Bus 8882	: V=1.058799, theta=10.888754 -> V=1.0, theta=0.0
% INFO    : Bus 8883	: V=1.065815, theta=-32.388754 -> V=1.0, theta=0.0
% INFO    : Bus 8884	: V=0.925993, theta=-30.739938 -> V=1.0, theta=0.0
% INFO    : Bus 8885	: V=1.08736, theta=-14.047593 -> V=1.0, theta=0.0
% INFO    : Bus 8886	: V=0.982229, theta=-4.035795 -> V=1.0, theta=0.0
% INFO    : Bus 8887	: V=1.043215, theta=1.507901 -> V=1.0, theta=0.0
% INFO    : Bus 8888	: V=1.032012, theta=-44.872754 -> V=1.0, theta=0.0
% INFO    : Bus 8889	: V=1.049752, theta=7.358598 -> V=1.0, theta=0.0
% INFO    : Bus 8890	: V=1.034323, theta=-21.843664 -> V=1.0, theta=0.0
% INFO    : Bus 8891	: V=1.06486, theta=-22.276124 -> V=1.0, theta=0.0
% INFO    : Bus 8892	: V=1.027002, theta=-32.300734 -> V=1.0, theta=0.0
% INFO    : Bus 8893	: V=1.042688, theta=-15.562576 -> V=1.0, theta=0.0
% INFO    : Bus 8894	: V=1.093076, theta=-29.068311 -> V=1.0, theta=0.0
% INFO    : Bus 8895	: V=1.028671, theta=-1.859193 -> V=1.0, theta=0.0
% INFO    : Bus 8896	: V=1.032282, theta=6.151305 -> V=1.0, theta=0.0
% INFO    : Bus 8897	: V=1.053267, theta=-25.681833 -> V=1.0, theta=0.0
% INFO    : Bus 8898	: V=1.047828, theta=18.203559 -> V=1.0, theta=0.0
% INFO    : Bus 8899	: V=1.0431, theta=-16.571185 -> V=1.0, theta=0.0
% INFO    : Bus 8900	: V=1.043513, theta=-24.062364 -> V=1.0, theta=0.0
% INFO    : Bus 8901	: V=1.008755, theta=-31.096175 -> V=1.0, theta=0.0
% INFO    : Bus 8902	: V=1.032502, theta=-34.761287 -> V=1.0, theta=0.0
% INFO    : Bus 8903	: V=1.023893, theta=-11.312079 -> V=1.0, theta=0.0
% INFO    : Bus 8904	: V=1.021959, theta=-28.230262 -> V=1.0, theta=0.0
% INFO    : Bus 8905	: V=1.031297, theta=-16.055238 -> V=1.0, theta=0.0
% INFO    : Bus 8906	: V=1.032057, theta=-23.413858 -> V=1.0, theta=0.0
% INFO    : Bus 8907	: V=1.02557, theta=-26.70978 -> V=1.0, theta=0.0
% INFO    : Bus 8908	: V=1.056729, theta=-27.525127 -> V=1.0, theta=0.0
% INFO    : Bus 8909	: V=1.015225, theta=-4.187786 -> V=1.0, theta=0.0
% INFO    : Bus 8910	: V=1.033582, theta=-7.348785 -> V=1.0, theta=0.0
% INFO    : Bus 8911	: V=1.021077, theta=-7.356537 -> V=1.0, theta=0.0
% INFO    : Bus 8912	: V=1.022368, theta=-23.469255 -> V=1.0, theta=0.0
% INFO    : Bus 8913	: V=1.037134, theta=-20.861918 -> V=1.0, theta=0.0
% INFO    : Bus 8914	: V=1.034467, theta=-34.15771 -> V=1.0, theta=0.0
% INFO    : Bus 8915	: V=0.99658, theta=9.112436 -> V=1.0, theta=0.0
% INFO    : Bus 8916	: V=1.031753, theta=-10.685374 -> V=1.0, theta=0.0
% INFO    : Bus 8917	: V=0.996189, theta=5.244024 -> V=1.0, theta=0.0
% INFO    : Bus 8918	: V=1.014492, theta=-23.519461 -> V=1.0, theta=0.0
% INFO    : Bus 8919	: V=1.01895, theta=62.05253 -> V=1.0, theta=0.0
% INFO    : Bus 8920	: V=1.01084, theta=-41.307091 -> V=1.0, theta=0.0
% INFO    : Bus 8921	: V=0.994236, theta=-3.341618 -> V=1.0, theta=0.0
% INFO    : Bus 8922	: V=0.995301, theta=-20.66783 -> V=1.0, theta=0.0
% INFO    : Bus 8923	: V=1.009078, theta=-30.763999 -> V=1.0, theta=0.0
% INFO    : Bus 8924	: V=1.029314, theta=-6.971888 -> V=1.0, theta=0.0
% INFO    : Bus 8925	: V=1.052395, theta=-19.630593 -> V=1.0, theta=0.0
% INFO    : Bus 8926	: V=0.984734, theta=-56.618154 -> V=1.0, theta=0.0
% INFO    : Bus 8927	: V=1.012236, theta=-35.17317 -> V=1.0, theta=0.0
% INFO    : Bus 8928	: V=1.012849, theta=-22.093516 -> V=1.0, theta=0.0
% INFO    : Bus 8929	: V=1.039322, theta=-3.419259 -> V=1.0, theta=0.0
% INFO    : Bus 8930	: V=0.984831, theta=-18.95199 -> V=1.0, theta=0.0
% INFO    : Bus 8931	: V=1.08698, theta=-9.874851 -> V=1.0, theta=0.0
% INFO    : Bus 8932	: V=1.014517, theta=-30.270984 -> V=1.0, theta=0.0
% INFO    : Bus 8933	: V=0.99084, theta=-50.573447 -> V=1.0, theta=0.0
% INFO    : Bus 8934	: V=1.00634, theta=37.082907 -> V=1.0, theta=0.0
% INFO    : Bus 8935	: V=1.050895, theta=-13.828639 -> V=1.0, theta=0.0
% INFO    : Bus 8936	: V=1.025772, theta=-53.799441 -> V=1.0, theta=0.0
% INFO    : Bus 8937	: V=1.01815, theta=-5.782371 -> V=1.0, theta=0.0
% INFO    : Bus 8938	: V=1.033893, theta=55.812115 -> V=1.0, theta=0.0
% INFO    : Bus 8939	: V=1.009385, theta=-55.359157 -> V=1.0, theta=0.0
% INFO    : Bus 8940	: V=1.00563, theta=-28.479486 -> V=1.0, theta=0.0
% INFO    : Bus 8941	: V=1.037713, theta=-33.524636 -> V=1.0, theta=0.0
% INFO    : Bus 8942	: V=1.007225, theta=-31.884836 -> V=1.0, theta=0.0
% INFO    : Bus 8943	: V=0.989314, theta=-26.764082 -> V=1.0, theta=0.0
% INFO    : Bus 8944	: V=1.06934, theta=57.258502 -> V=1.0, theta=0.0
% INFO    : Bus 8945	: V=1.018329, theta=-1.583907 -> V=1.0, theta=0.0
% INFO    : Bus 8946	: V=1.036925, theta=-41.807358 -> V=1.0, theta=0.0
% INFO    : Bus 8947	: V=1.03534, theta=-11.773464 -> V=1.0, theta=0.0
% INFO    : Bus 8948	: V=1.023879, theta=3.74107 -> V=1.0, theta=0.0
% INFO    : Bus 8949	: V=1.002255, theta=-27.609858 -> V=1.0, theta=0.0
% INFO    : Bus 8950	: V=1.050158, theta=-14.888414 -> V=1.0, theta=0.0
% INFO    : Bus 8951	: V=0.980982, theta=-52.115488 -> V=1.0, theta=0.0
% INFO    : Bus 8952	: V=1.013006, theta=23.407664 -> V=1.0, theta=0.0
% INFO    : Bus 8953	: V=1.012701, theta=-40.487754 -> V=1.0, theta=0.0
% INFO    : Bus 8954	: V=1.02953, theta=-26.425363 -> V=1.0, theta=0.0
% INFO    : Bus 8955	: V=1.0077, theta=6.146306 -> V=1.0, theta=0.0
% INFO    : Bus 8956	: V=1.061596, theta=22.612591 -> V=1.0, theta=0.0
% INFO    : Bus 8957	: V=0.98498, theta=-54.764172 -> V=1.0, theta=0.0
% INFO    : Bus 8958	: V=0.967758, theta=-31.427129 -> V=1.0, theta=0.0
% INFO    : Bus 8959	: V=1.014491, theta=-30.159914 -> V=1.0, theta=0.0
% INFO    : Bus 8960	: V=1.023767, theta=19.630412 -> V=1.0, theta=0.0
% INFO    : Bus 8961	: V=1.043576, theta=-13.967427 -> V=1.0, theta=0.0
% INFO    : Bus 8962	: V=1.001767, theta=-50.907419 -> V=1.0, theta=0.0
% INFO    : Bus 8963	: V=1.012573, theta=-40.755147 -> V=1.0, theta=0.0
% INFO    : Bus 8964	: V=1.019433, theta=-13.307838 -> V=1.0, theta=0.0
% INFO    : Bus 8965	: V=1.018416, theta=-35.400316 -> V=1.0, theta=0.0
% INFO    : Bus 8966	: V=1.087897, theta=42.466296 -> V=1.0, theta=0.0
% INFO    : Bus 8967	: V=1.062579, theta=-25.645512 -> V=1.0, theta=0.0
% INFO    : Bus 8968	: V=1.026387, theta=-11.3284 -> V=1.0, theta=0.0
% INFO    : Bus 8969	: V=1.00273, theta=-30.117913 -> V=1.0, theta=0.0
% INFO    : Bus 8970	: V=0.959473, theta=-28.847628 -> V=1.0, theta=0.0
% INFO    : Bus 8971	: V=1.043573, theta=-0.237282 -> V=1.0, theta=0.0
% INFO    : Bus 8972	: V=1.038393, theta=-33.53821 -> V=1.0, theta=0.0
% INFO    : Bus 8973	: V=1.048016, theta=-36.544908 -> V=1.0, theta=0.0
% INFO    : Bus 8974	: V=1.08148, theta=-35.19762 -> V=1.0, theta=0.0
% INFO    : Bus 8975	: V=1.039828, theta=-24.602849 -> V=1.0, theta=0.0
% INFO    : Bus 8976	: V=1.04878, theta=-17.081476 -> V=1.0, theta=0.0
% INFO    : Bus 8977	: V=1.017795, theta=0.548554 -> V=1.0, theta=0.0
% INFO    : Bus 8978	: V=1.038763, theta=-7.38624 -> V=1.0, theta=0.0
% INFO    : Bus 8979	: V=0.973815, theta=-32.032315 -> V=1.0, theta=0.0
% INFO    : Bus 8980	: V=1.037996, theta=-11.349561 -> V=1.0, theta=0.0
% INFO    : Bus 8981	: V=1.023844, theta=-43.307726 -> V=1.0, theta=0.0
% INFO    : Bus 8982	: V=1.009058, theta=13.020866 -> V=1.0, theta=0.0
% INFO    : Bus 8983	: V=1.042963, theta=-22.908146 -> V=1.0, theta=0.0
% INFO    : Bus 8984	: V=0.959932, theta=-31.695048 -> V=1.0, theta=0.0
% INFO    : Bus 8985	: V=0.963865, theta=-31.392893 -> V=1.0, theta=0.0
% INFO    : Bus 8986	: V=1.031926, theta=-21.431005 -> V=1.0, theta=0.0
% INFO    : Bus 8987	: V=1.045054, theta=-41.760561 -> V=1.0, theta=0.0
% INFO    : Bus 8988	: V=1.016047, theta=-21.671966 -> V=1.0, theta=0.0
% INFO    : Bus 8989	: V=1.039012, theta=-25.911894 -> V=1.0, theta=0.0
% INFO    : Bus 8990	: V=1.041302, theta=-26.379277 -> V=1.0, theta=0.0
% INFO    : Bus 8991	: V=1.01601, theta=3.272318 -> V=1.0, theta=0.0
% INFO    : Bus 8992	: V=1.04954, theta=-4.036028 -> V=1.0, theta=0.0
% INFO    : Bus 8993	: V=1.020391, theta=-38.19801 -> V=1.0, theta=0.0
% INFO    : Bus 8994	: V=1.036502, theta=5.871334 -> V=1.0, theta=0.0
% INFO    : Bus 8995	: V=1.020381, theta=-3.284953 -> V=1.0, theta=0.0
% INFO    : Bus 8996	: V=1.017579, theta=-5.851805 -> V=1.0, theta=0.0
% INFO    : Bus 8997	: V=1.01701, theta=-12.887035 -> V=1.0, theta=0.0
% INFO    : Bus 8998	: V=0.968092, theta=-43.530682 -> V=1.0, theta=0.0
% INFO    : Bus 8999	: V=1.040946, theta=-21.854751 -> V=1.0, theta=0.0
% INFO    : Bus 9000	: V=1.042081, theta=-40.570202 -> V=1.0, theta=0.0
% INFO    : Bus 9001	: V=1.023475, theta=-42.079218 -> V=1.0, theta=0.0
% INFO    : Bus 9002	: V=1.01897, theta=-10.584797 -> V=1.0, theta=0.0
% INFO    : Bus 9003	: V=1.031835, theta=38.611947 -> V=1.0, theta=0.0
% INFO    : Bus 9004	: V=1.018564, theta=-23.55241 -> V=1.0, theta=0.0
% INFO    : Bus 9005	: V=1.058241, theta=-23.362413 -> V=1.0, theta=0.0
% INFO    : Bus 9006	: V=1.021706, theta=-46.280543 -> V=1.0, theta=0.0
% INFO    : Bus 9007	: V=1.018066, theta=0.846812 -> V=1.0, theta=0.0
% INFO    : Bus 9008	: V=1.00554, theta=-33.793222 -> V=1.0, theta=0.0
% INFO    : Bus 9009	: V=1.025291, theta=-33.898513 -> V=1.0, theta=0.0
% INFO    : Bus 9010	: V=1.086436, theta=-20.936454 -> V=1.0, theta=0.0
% INFO    : Bus 9011	: V=1.032253, theta=-23.376641 -> V=1.0, theta=0.0
% INFO    : Bus 9012	: V=1.045421, theta=0.994578 -> V=1.0, theta=0.0
% INFO    : Bus 9013	: V=1.023407, theta=-47.210196 -> V=1.0, theta=0.0
% INFO    : Bus 9014	: V=1.046672, theta=-6.75147 -> V=1.0, theta=0.0
% INFO    : Bus 9015	: V=0.991796, theta=-27.462791 -> V=1.0, theta=0.0
% INFO    : Bus 9016	: V=1.081763, theta=-25.026346 -> V=1.0, theta=0.0
% INFO    : Bus 9017	: V=1.021183, theta=-27.412183 -> V=1.0, theta=0.0
% INFO    : Bus 9018	: V=1.016825, theta=-6.807104 -> V=1.0, theta=0.0
% INFO    : Bus 9019	: V=1.037991, theta=-25.005711 -> V=1.0, theta=0.0
% INFO    : Bus 9020	: V=0.967608, theta=-29.896714 -> V=1.0, theta=0.0
% INFO    : Bus 9021	: V=1.030914, theta=-6.85138 -> V=1.0, theta=0.0
% INFO    : Bus 9022	: V=1.018529, theta=3.046714 -> V=1.0, theta=0.0
% INFO    : Bus 9023	: V=0.997367, theta=-20.381122 -> V=1.0, theta=0.0
% INFO    : Bus 9024	: V=1.021826, theta=1.47047 -> V=1.0, theta=0.0
% INFO    : Bus 9025	: V=1.000113, theta=-4.896569 -> V=1.0, theta=0.0
% INFO    : Bus 9026	: V=1.068959, theta=-25.032073 -> V=1.0, theta=0.0
% INFO    : Bus 9027	: V=1.070556, theta=4.312968 -> V=1.0, theta=0.0
% INFO    : Bus 9028	: V=1.030767, theta=-53.167609 -> V=1.0, theta=0.0
% INFO    : Bus 9029	: V=1.014533, theta=16.390126 -> V=1.0, theta=0.0
% INFO    : Bus 9030	: V=1.046647, theta=-14.344531 -> V=1.0, theta=0.0
% INFO    : Bus 9031	: V=1.008395, theta=-7.875015 -> V=1.0, theta=0.0
% INFO    : Bus 9032	: V=1.059483, theta=-47.950771 -> V=1.0, theta=0.0
% INFO    : Bus 9033	: V=1.050435, theta=-26.861964 -> V=1.0, theta=0.0
% INFO    : Bus 9034	: V=1.005697, theta=-25.507825 -> V=1.0, theta=0.0
% INFO    : Bus 9035	: V=1.009337, theta=-18.778819 -> V=1.0, theta=0.0
% INFO    : Bus 9036	: V=1.053739, theta=-26.40549 -> V=1.0, theta=0.0
% INFO    : Bus 9037	: V=1.099889, theta=45.549831 -> V=1.0, theta=0.0
% INFO    : Bus 9038	: V=1.061613, theta=-21.371557 -> V=1.0, theta=0.0
% INFO    : Bus 9039	: V=1.017349, theta=-43.798544 -> V=1.0, theta=0.0
% INFO    : Bus 9040	: V=1.043881, theta=1.377245 -> V=1.0, theta=0.0
% INFO    : Bus 9041	: V=1.005066, theta=-31.830279 -> V=1.0, theta=0.0
% INFO    : Bus 9042	: V=1.034241, theta=-23.702133 -> V=1.0, theta=0.0
% INFO    : Bus 9043	: V=1.018389, theta=-40.654877 -> V=1.0, theta=0.0
% INFO    : Bus 9044	: V=1.027751, theta=-33.642346 -> V=1.0, theta=0.0
% INFO    : Bus 9045	: V=1.037474, theta=-24.957769 -> V=1.0, theta=0.0
% INFO    : Bus 9046	: V=1.070778, theta=44.490271 -> V=1.0, theta=0.0
% INFO    : Bus 9047	: V=1.03154, theta=66.593064 -> V=1.0, theta=0.0
% INFO    : Bus 9048	: V=1.050428, theta=-12.580966 -> V=1.0, theta=0.0
% INFO    : Bus 9049	: V=1.016347, theta=-40.800283 -> V=1.0, theta=0.0
% INFO    : Bus 9050	: V=0.87466, theta=-38.032264 -> V=1.0, theta=0.0
% INFO    : Bus 9051	: V=1.033855, theta=0.35535 -> V=1.0, theta=0.0
% INFO    : Bus 9052	: V=1.017289, theta=-10.01002 -> V=1.0, theta=0.0
% INFO    : Bus 9053	: V=1.030453, theta=48.268546 -> V=1.0, theta=0.0
% INFO    : Bus 9054	: V=1.116695, theta=-23.366531 -> V=1.0, theta=0.0
% INFO    : Bus 9055	: V=0.97622, theta=-50.38012 -> V=1.0, theta=0.0
% INFO    : Bus 9056	: V=1.015088, theta=-26.281333 -> V=1.0, theta=0.0
% INFO    : Bus 9057	: V=1.020685, theta=-48.779675 -> V=1.0, theta=0.0
% INFO    : Bus 9058	: V=1.013989, theta=63.346088 -> V=1.0, theta=0.0
% INFO    : Bus 9059	: V=1.06958, theta=-27.481336 -> V=1.0, theta=0.0
% INFO    : Bus 9060	: V=1.066622, theta=0.64924 -> V=1.0, theta=0.0
% INFO    : Bus 9061	: V=1.002505, theta=-8.594522 -> V=1.0, theta=0.0
% INFO    : Bus 9062	: V=1.085303, theta=-27.976492 -> V=1.0, theta=0.0
% INFO    : Bus 9063	: V=1.025839, theta=11.378876 -> V=1.0, theta=0.0
% INFO    : Bus 9064	: V=0.997517, theta=-4.330374 -> V=1.0, theta=0.0
% INFO    : Bus 9065	: V=1.02925, theta=2.262276 -> V=1.0, theta=0.0
% INFO    : Bus 9066	: V=1.019416, theta=-20.851529 -> V=1.0, theta=0.0
% INFO    : Bus 9067	: V=1.03898, theta=1.326718 -> V=1.0, theta=0.0
% INFO    : Bus 9068	: V=1.016522, theta=-47.563374 -> V=1.0, theta=0.0
% INFO    : Bus 9069	: V=1.029345, theta=3.868055 -> V=1.0, theta=0.0
% INFO    : Bus 9070	: V=1.014526, theta=-27.088277 -> V=1.0, theta=0.0
% INFO    : Bus 9071	: V=1.007888, theta=-5.635688 -> V=1.0, theta=0.0
% INFO    : Bus 9072	: V=1.038832, theta=4.912377 -> V=1.0, theta=0.0
% INFO    : Bus 9073	: V=0.999787, theta=-38.482125 -> V=1.0, theta=0.0
% INFO    : Bus 9074	: V=1.022605, theta=13.774034 -> V=1.0, theta=0.0
% INFO    : Bus 9075	: V=1.020531, theta=-43.139819 -> V=1.0, theta=0.0
% INFO    : Bus 9076	: V=0.936148, theta=-34.567675 -> V=1.0, theta=0.0
% INFO    : Bus 9077	: V=1.00627, theta=19.875811 -> V=1.0, theta=0.0
% INFO    : Bus 9078	: V=0.983071, theta=-28.908274 -> V=1.0, theta=0.0
% INFO    : Bus 9079	: V=1.020771, theta=-29.719031 -> V=1.0, theta=0.0
% INFO    : Bus 9080	: V=1.016757, theta=-13.428436 -> V=1.0, theta=0.0
% INFO    : Bus 9081	: V=1.049272, theta=-22.144817 -> V=1.0, theta=0.0
% INFO    : Bus 9082	: V=1.014442, theta=-14.397143 -> V=1.0, theta=0.0
% INFO    : Bus 9083	: V=1.025316, theta=-1.145306 -> V=1.0, theta=0.0
% INFO    : Bus 9084	: V=1.031473, theta=20.252563 -> V=1.0, theta=0.0
% INFO    : Bus 9085	: V=1.023432, theta=-7.241486 -> V=1.0, theta=0.0
% INFO    : Bus 9086	: V=1.033977, theta=-13.93054 -> V=1.0, theta=0.0
% INFO    : Bus 9087	: V=1.040157, theta=2.241184 -> V=1.0, theta=0.0
% INFO    : Bus 9088	: V=1.027431, theta=34.922619 -> V=1.0, theta=0.0
% INFO    : Bus 9089	: V=1.02776, theta=18.322319 -> V=1.0, theta=0.0
% INFO    : Bus 9090	: V=1.009716, theta=51.520897 -> V=1.0, theta=0.0
% INFO    : Bus 9091	: V=1.038463, theta=-9.834074 -> V=1.0, theta=0.0
% INFO    : Bus 9092	: V=1.027912, theta=-30.435624 -> V=1.0, theta=0.0
% INFO    : Bus 9093	: V=1.012092, theta=-16.019132 -> V=1.0, theta=0.0
% INFO    : Bus 9094	: V=1.035337, theta=5.426812 -> V=1.0, theta=0.0
% INFO    : Bus 9095	: V=0.994238, theta=9.203678 -> V=1.0, theta=0.0
% INFO    : Bus 9096	: V=1.025278, theta=-2.821658 -> V=1.0, theta=0.0
% INFO    : Bus 9097	: V=1.016295, theta=-40.223897 -> V=1.0, theta=0.0
% INFO    : Bus 9098	: V=1.005097, theta=-32.912516 -> V=1.0, theta=0.0
% INFO    : Bus 9099	: V=1.028779, theta=-17.085682 -> V=1.0, theta=0.0
% INFO    : Bus 9100	: V=1.07025, theta=61.624988 -> V=1.0, theta=0.0
% INFO    : Bus 9101	: V=1.026276, theta=-22.084157 -> V=1.0, theta=0.0
% INFO    : Bus 9102	: V=1.016926, theta=-6.147136 -> V=1.0, theta=0.0
% INFO    : Bus 9103	: V=1.027331, theta=-16.457891 -> V=1.0, theta=0.0
% INFO    : Bus 9104	: V=1.021698, theta=-29.695588 -> V=1.0, theta=0.0
% INFO    : Bus 9105	: V=1.088711, theta=-16.324228 -> V=1.0, theta=0.0
% INFO    : Bus 9106	: V=0.982322, theta=-56.142555 -> V=1.0, theta=0.0
% INFO    : Bus 9107	: V=1.044678, theta=-18.435797 -> V=1.0, theta=0.0
% INFO    : Bus 9108	: V=1.046328, theta=-16.424177 -> V=1.0, theta=0.0
% INFO    : Bus 9109	: V=1.033857, theta=0.35533 -> V=1.0, theta=0.0
% INFO    : Bus 9110	: V=1.126918, theta=-21.871563 -> V=1.0, theta=0.0
% INFO    : Bus 9111	: V=1.070321, theta=-17.970841 -> V=1.0, theta=0.0
% INFO    : Bus 9112	: V=1.053965, theta=-13.349394 -> V=1.0, theta=0.0
% INFO    : Bus 9113	: V=1.014547, theta=-36.06836 -> V=1.0, theta=0.0
% INFO    : Bus 9114	: V=1.026014, theta=3.694409 -> V=1.0, theta=0.0
% INFO    : Bus 9115	: V=1.014174, theta=-30.322741 -> V=1.0, theta=0.0
% INFO    : Bus 9116	: V=1.014534, theta=-13.764914 -> V=1.0, theta=0.0
% INFO    : Bus 9117	: V=1.017517, theta=-52.837809 -> V=1.0, theta=0.0
% INFO    : Bus 9118	: V=1.031779, theta=3.402444 -> V=1.0, theta=0.0
% INFO    : Bus 9119	: V=1.039783, theta=-20.831188 -> V=1.0, theta=0.0
% INFO    : Bus 9120	: V=1.021557, theta=2.421393 -> V=1.0, theta=0.0
% INFO    : Bus 9121	: V=1.035973, theta=-44.757751 -> V=1.0, theta=0.0
% INFO    : Bus 9122	: V=1.126477, theta=-26.62396 -> V=1.0, theta=0.0
% INFO    : Bus 9123	: V=1.028128, theta=18.829626 -> V=1.0, theta=0.0
% INFO    : Bus 9124	: V=1.016906, theta=-22.219757 -> V=1.0, theta=0.0
% INFO    : Bus 9125	: V=1.042649, theta=-20.934031 -> V=1.0, theta=0.0
% INFO    : Bus 9126	: V=1.016113, theta=-33.749547 -> V=1.0, theta=0.0
% INFO    : Bus 9127	: V=0.999409, theta=20.870776 -> V=1.0, theta=0.0
% INFO    : Bus 9128	: V=1.031517, theta=-2.952699 -> V=1.0, theta=0.0
% INFO    : Bus 9129	: V=1.010953, theta=-25.770716 -> V=1.0, theta=0.0
% INFO    : Bus 9130	: V=1.031578, theta=-31.505951 -> V=1.0, theta=0.0
% INFO    : Bus 9131	: V=1.046774, theta=-24.421469 -> V=1.0, theta=0.0
% INFO    : Bus 9132	: V=1.04609, theta=-27.739751 -> V=1.0, theta=0.0
% INFO    : Bus 9133	: V=1.033538, theta=-40.135467 -> V=1.0, theta=0.0
% INFO    : Bus 9134	: V=0.999342, theta=-24.208457 -> V=1.0, theta=0.0
% INFO    : Bus 9135	: V=0.992973, theta=-52.429746 -> V=1.0, theta=0.0
% INFO    : Bus 9136	: V=0.988179, theta=-54.441306 -> V=1.0, theta=0.0
% INFO    : Bus 9137	: V=1.048884, theta=-26.886512 -> V=1.0, theta=0.0
% INFO    : Bus 9138	: V=1.013519, theta=-9.389245 -> V=1.0, theta=0.0
% INFO    : Bus 9139	: V=1.019118, theta=-48.988879 -> V=1.0, theta=0.0
% INFO    : Bus 9140	: V=1.042971, theta=-5.426378 -> V=1.0, theta=0.0
% INFO    : Bus 9141	: V=0.975873, theta=-35.299892 -> V=1.0, theta=0.0
% INFO    : Bus 9142	: V=1.009593, theta=-24.521036 -> V=1.0, theta=0.0
% INFO    : Bus 9143	: V=1.051592, theta=9.362104 -> V=1.0, theta=0.0
% INFO    : Bus 9144	: V=1.144394, theta=-11.902874 -> V=1.0, theta=0.0
% INFO    : Bus 9145	: V=1.063676, theta=-21.93976 -> V=1.0, theta=0.0
% INFO    : Bus 9146	: V=1.025255, theta=7.725131 -> V=1.0, theta=0.0
% INFO    : Bus 9147	: V=0.99121, theta=-30.809775 -> V=1.0, theta=0.0
% INFO    : Bus 9148	: V=1.078994, theta=-16.53734 -> V=1.0, theta=0.0
% INFO    : Bus 9149	: V=1.00388, theta=-31.357499 -> V=1.0, theta=0.0
% INFO    : Bus 9150	: V=1.034687, theta=-13.442439 -> V=1.0, theta=0.0
% INFO    : Bus 9151	: V=1.028823, theta=6.500564 -> V=1.0, theta=0.0
% INFO    : Bus 9152	: V=1.044039, theta=14.370587 -> V=1.0, theta=0.0
% INFO    : Bus 9153	: V=1.032631, theta=-38.891322 -> V=1.0, theta=0.0
% INFO    : Bus 9154	: V=1.027702, theta=17.543704 -> V=1.0, theta=0.0
% INFO    : Bus 9155	: V=1.023245, theta=-20.905815 -> V=1.0, theta=0.0
% INFO    : Bus 9156	: V=1.031942, theta=-28.003569 -> V=1.0, theta=0.0
% INFO    : Bus 9157	: V=0.942596, theta=-32.670874 -> V=1.0, theta=0.0
% INFO    : Bus 9158	: V=1.022273, theta=-14.756084 -> V=1.0, theta=0.0
% INFO    : Bus 9159	: V=1.045228, theta=-43.943091 -> V=1.0, theta=0.0
% INFO    : Bus 9160	: V=1.036025, theta=0.526834 -> V=1.0, theta=0.0
% INFO    : Bus 9161	: V=1.033176, theta=-21.938164 -> V=1.0, theta=0.0
% INFO    : Bus 9162	: V=1.008691, theta=-61.125492 -> V=1.0, theta=0.0
% INFO    : Bus 9163	: V=0.980011, theta=-30.352301 -> V=1.0, theta=0.0
% INFO    : Bus 9164	: V=1.000808, theta=-19.55897 -> V=1.0, theta=0.0
% INFO    : Bus 9165	: V=1.012348, theta=-17.920039 -> V=1.0, theta=0.0
% INFO    : Bus 9166	: V=1.013916, theta=-26.3912 -> V=1.0, theta=0.0
% INFO    : Bus 9167	: V=1.046867, theta=-25.749667 -> V=1.0, theta=0.0
% INFO    : Bus 9168	: V=1.076561, theta=-19.394973 -> V=1.0, theta=0.0
% INFO    : Bus 9169	: V=1.043761, theta=-18.939825 -> V=1.0, theta=0.0
% INFO    : Bus 9170	: V=0.995012, theta=-31.350024 -> V=1.0, theta=0.0
% INFO    : Bus 9171	: V=1.048212, theta=-25.50859 -> V=1.0, theta=0.0
% INFO    : Bus 9172	: V=0.971529, theta=-34.186542 -> V=1.0, theta=0.0
% INFO    : Bus 9173	: V=1.029075, theta=-20.517581 -> V=1.0, theta=0.0
% INFO    : Bus 9174	: V=1.015292, theta=-33.281168 -> V=1.0, theta=0.0
% INFO    : Bus 9175	: V=1.025176, theta=-34.235555 -> V=1.0, theta=0.0
% INFO    : Bus 9176	: V=1.054197, theta=-13.351984 -> V=1.0, theta=0.0
% INFO    : Bus 9177	: V=1.009783, theta=-36.09656 -> V=1.0, theta=0.0
% INFO    : Bus 9178	: V=1.036985, theta=-20.124603 -> V=1.0, theta=0.0
% INFO    : Bus 9179	: V=1.031959, theta=-29.388091 -> V=1.0, theta=0.0
% INFO    : Bus 9180	: V=1.053552, theta=-9.013967 -> V=1.0, theta=0.0
% INFO    : Bus 9181	: V=1.032604, theta=-9.514471 -> V=1.0, theta=0.0
% INFO    : Bus 9182	: V=1.025252, theta=-2.823766 -> V=1.0, theta=0.0
% INFO    : Bus 9183	: V=1.060831, theta=-28.67579 -> V=1.0, theta=0.0
% INFO    : Bus 9184	: V=1.032579, theta=-20.429918 -> V=1.0, theta=0.0
% INFO    : Bus 9185	: V=1.047418, theta=-6.692485 -> V=1.0, theta=0.0
% INFO    : Bus 9186	: V=1.001193, theta=-30.889935 -> V=1.0, theta=0.0
% INFO    : Bus 9187	: V=1.017206, theta=-28.96425 -> V=1.0, theta=0.0
% INFO    : Bus 9188	: V=1.026633, theta=-17.377747 -> V=1.0, theta=0.0
% INFO    : Bus 9189	: V=1.04364, theta=-25.354346 -> V=1.0, theta=0.0
% INFO    : Bus 9190	: V=1.038421, theta=10.701718 -> V=1.0, theta=0.0
% INFO    : Bus 9191	: V=1.068081, theta=-25.1908 -> V=1.0, theta=0.0
% INFO    : Bus 9192	: V=1.026755, theta=-11.14904 -> V=1.0, theta=0.0
% INFO    : Bus 9193	: V=1.047872, theta=-26.503737 -> V=1.0, theta=0.0
% INFO    : Bus 9194	: V=1.054181, theta=-20.330877 -> V=1.0, theta=0.0
% INFO    : Bus 9195	: V=1.025329, theta=-24.847964 -> V=1.0, theta=0.0
% INFO    : Bus 9196	: V=1.015066, theta=-42.242142 -> V=1.0, theta=0.0
% INFO    : Bus 9197	: V=1.017237, theta=-47.991389 -> V=1.0, theta=0.0
% INFO    : Bus 9198	: V=0.992287, theta=9.626195 -> V=1.0, theta=0.0
% INFO    : Bus 9199	: V=0.918836, theta=-35.875884 -> V=1.0, theta=0.0
% INFO    : Bus 9200	: V=1.040977, theta=9.324287 -> V=1.0, theta=0.0
% INFO    : Bus 9201	: V=1.021708, theta=-43.462923 -> V=1.0, theta=0.0
% INFO    : Bus 9202	: V=1.023129, theta=-39.027798 -> V=1.0, theta=0.0
% INFO    : Bus 9203	: V=1.013724, theta=-12.348813 -> V=1.0, theta=0.0
% INFO    : Bus 9204	: V=0.987777, theta=-26.396232 -> V=1.0, theta=0.0
% INFO    : Bus 9205	: V=1.024091, theta=13.095331 -> V=1.0, theta=0.0
% INFO    : Bus 9206	: V=1.032652, theta=3.577999 -> V=1.0, theta=0.0
% INFO    : Bus 9207	: V=1.022433, theta=-7.901761 -> V=1.0, theta=0.0
% INFO    : Bus 9208	: V=1.057265, theta=-2.779327 -> V=1.0, theta=0.0
% INFO    : Bus 9209	: V=0.992157, theta=-27.396182 -> V=1.0, theta=0.0
% INFO    : Bus 9210	: V=0.958193, theta=-22.277418 -> V=1.0, theta=0.0
% INFO    : Bus 9211	: V=1.021484, theta=5.206879 -> V=1.0, theta=0.0
% INFO    : Bus 9212	: V=1.034219, theta=-23.665647 -> V=1.0, theta=0.0
% INFO    : Bus 9213	: V=1.021887, theta=-4.683055 -> V=1.0, theta=0.0
% INFO    : Bus 9214	: V=0.945446, theta=-32.670959 -> V=1.0, theta=0.0
% INFO    : Bus 9215	: V=1.008696, theta=30.844349 -> V=1.0, theta=0.0
% INFO    : Bus 9216	: V=1.022236, theta=-48.806553 -> V=1.0, theta=0.0
% INFO    : Bus 9217	: V=1.037712, theta=-9.095499 -> V=1.0, theta=0.0
% INFO    : Bus 9218	: V=1.053757, theta=-23.95137 -> V=1.0, theta=0.0
% INFO    : Bus 9219	: V=0.976857, theta=-32.419649 -> V=1.0, theta=0.0
% INFO    : Bus 9220	: V=1.034016, theta=-7.070462 -> V=1.0, theta=0.0
% INFO    : Bus 9221	: V=1.04807, theta=12.002102 -> V=1.0, theta=0.0
% INFO    : Bus 9222	: V=1.05418, theta=-16.505219 -> V=1.0, theta=0.0
% INFO    : Bus 9223	: V=1.013922, theta=6.927286 -> V=1.0, theta=0.0
% INFO    : Bus 9224	: V=1.015032, theta=-5.799018 -> V=1.0, theta=0.0
% INFO    : Bus 9225	: V=1.015668, theta=-6.175679 -> V=1.0, theta=0.0
% INFO    : Bus 9226	: V=1.046637, theta=-27.138917 -> V=1.0, theta=0.0
% INFO    : Bus 9227	: V=1.048335, theta=-18.202764 -> V=1.0, theta=0.0
% INFO    : Bus 9228	: V=1.004437, theta=65.850708 -> V=1.0, theta=0.0
% INFO    : Bus 9229	: V=1.029484, theta=-34.223347 -> V=1.0, theta=0.0
% INFO    : Bus 9230	: V=1.027519, theta=-7.771709 -> V=1.0, theta=0.0
% INFO    : Bus 9231	: V=1.0264, theta=-19.423195 -> V=1.0, theta=0.0
% INFO    : Bus 9232	: V=1.032761, theta=-33.158924 -> V=1.0, theta=0.0
% INFO    : Bus 9233	: V=1.032731, theta=-3.177461 -> V=1.0, theta=0.0
% INFO    : Bus 9234	: V=1.042353, theta=-0.37878 -> V=1.0, theta=0.0
% INFO    : Bus 9235	: V=1.04114, theta=-22.50441 -> V=1.0, theta=0.0
% INFO    : Bus 9236	: V=1.027495, theta=-39.134578 -> V=1.0, theta=0.0
% INFO    : Bus 9237	: V=1.047699, theta=-23.228502 -> V=1.0, theta=0.0
% INFO    : Bus 9238	: V=1.097633, theta=15.484001 -> V=1.0, theta=0.0
% INFO    : Bus 9239	: V=1.017601, theta=6.12547 -> V=1.0, theta=0.0
% INFO    : Bus 9240	: V=0.960374, theta=-31.768249 -> V=1.0, theta=0.0
% INFO    : Bus 9241	: V=1.044245, theta=-9.735227 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 2	: Pg=-81.4, Qg=6.64 -> Pg=-4.265, Qg=10.87
% INFO    : Gen at bus 2	: Vg=1.031734 -> Vg=1.0
% INFO    : Gen at bus 6	: Pg=701.0, Qg=183.79 -> Pg=800.0, Qg=156.48
% INFO    : Gen at bus 6	: Vg=1.038476 -> Vg=1.0
% INFO    : Gen at bus 8	: Pg=499.7, Qg=-0.95 -> Pg=262.34, Qg=2.74
% INFO    : Gen at bus 8	: Vg=1.023005 -> Vg=1.0
% INFO    : Gen at bus 18	: Pg=467.5, Qg=201.91 -> Pg=333.335, Qg=59.745
% INFO    : Gen at bus 18	: Vg=1.026728 -> Vg=1.0
% INFO    : Gen at bus 25	: Pg=319.6, Qg=164.04 -> Pg=200.0, Qg=56.61
% INFO    : Gen at bus 25	: Vg=1.028526 -> Vg=1.0
% INFO    : Gen at bus 32	: Pg=8.0, Qg=-1.02 -> Pg=8.1, Qg=0.675
% INFO    : Gen at bus 32	: Vg=1.003223 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=5.3, Qg=-0.56 -> Pg=2.69, Qg=0.595
% INFO    : Gen at bus 33	: Vg=1.026534 -> Vg=1.0
% INFO    : Gen at bus 39	: Pg=34.3, Qg=4.77 -> Pg=20.0, Qg=5.31
% INFO    : Gen at bus 39	: Vg=1.003511 -> Vg=1.0
% INFO    : Gen at bus 49	: Pg=309.2, Qg=62.33 -> Pg=240.0, Qg=71.275
% INFO    : Gen at bus 49	: Vg=1.020323 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=-144.5, Qg=-0.31 -> Pg=-46.335, Qg=0.645
% INFO    : Gen at bus 51	: Vg=1.006665 -> Vg=1.0
% INFO    : Gen at bus 80	: Pg=43.2, Qg=2.23 -> Pg=64.4, Qg=48.08
% INFO    : Gen at bus 80	: Vg=1.068393 -> Vg=1.0
% INFO    : Gen at bus 107	: Pg=570.0, Qg=-75.96 -> Pg=400.0, Qg=70.03
% INFO    : Gen at bus 107	: Vg=1.083135 -> Vg=1.0
% INFO    : Gen at bus 123	: Pg=24.9, Qg=8.45 -> Pg=20.0, Qg=6.39
% INFO    : Gen at bus 123	: Vg=1.041503 -> Vg=1.0
% INFO    : Gen at bus 124	: Pg=861.3, Qg=69.97 -> Pg=666.665, Qg=133.865
% INFO    : Gen at bus 124	: Vg=1.077112 -> Vg=1.0
% INFO    : Gen at bus 141	: Pg=-73.2, Qg=5.11 -> Pg=1.2, Qg=6.13
% INFO    : Gen at bus 141	: Vg=1.050716 -> Vg=1.0
% INFO    : Gen at bus 142	: Pg=158.7, Qg=2.2 -> Pg=90.0, Qg=22.875
% INFO    : Gen at bus 142	: Vg=1.042299 -> Vg=1.0
% INFO    : Gen at bus 147	: Pg=-16.0, Qg=9.74 -> Pg=39.335, Qg=20.31
% INFO    : Gen at bus 147	: Vg=1.058041 -> Vg=1.0
% INFO    : Gen at bus 150	: Pg=67.29, Qg=-5.08 -> Pg=80.0, Qg=27.275
% INFO    : Gen at bus 150	: Vg=1.062129 -> Vg=1.0
% INFO    : Gen at bus 151	: Pg=-110.35, Qg=-11.36 -> Pg=-23.565, Qg=-10.105
% INFO    : Gen at bus 151	: Vg=1.013748 -> Vg=1.0
% INFO    : Gen at bus 166	: Pg=292.2, Qg=107.13 -> Pg=150.0, Qg=35.57
% INFO    : Gen at bus 166	: Vg=1.040747 -> Vg=1.0
% INFO    : Gen at bus 179	: Pg=-179.2, Qg=-30.19 -> Pg=-69.465, Qg=0.46
% INFO    : Gen at bus 179	: Vg=1.043661 -> Vg=1.0
% INFO    : Gen at bus 190	: Pg=90.69, Qg=31.0 -> Pg=60.0, Qg=16.805
% INFO    : Gen at bus 190	: Vg=1.025544 -> Vg=1.0
% INFO    : Gen at bus 192	: Pg=135.8, Qg=12.15 -> Pg=100.0, Qg=30.315
% INFO    : Gen at bus 192	: Vg=1.048355 -> Vg=1.0
% INFO    : Gen at bus 194	: Pg=268.6, Qg=42.2 -> Pg=200.0, Qg=38.33
% INFO    : Gen at bus 194	: Vg=1.02931 -> Vg=1.0
% INFO    : Gen at bus 197	: Pg=292.2, Qg=-57.05 -> Pg=150.0, Qg=32.175
% INFO    : Gen at bus 197	: Vg=1.099985 -> Vg=1.0
% INFO    : Gen at bus 201	: Pg=5.2, Qg=-0.6 -> Pg=2.685, Qg=0.6
% INFO    : Gen at bus 201	: Vg=1.01914 -> Vg=1.0
% INFO    : Gen at bus 209	: Pg=25.4, Qg=9.44 -> Pg=20.0, Qg=6.265
% INFO    : Gen at bus 209	: Vg=1.026832 -> Vg=1.0
% INFO    : Gen at bus 214	: Pg=-175.2, Qg=1.82 -> Pg=-66.8, Qg=69.555
% INFO    : Gen at bus 214	: Vg=1.079765 -> Vg=1.0
% INFO    : Gen at bus 219	: Pg=1171.0, Qg=704.29 -> Pg=1333.335, Qg=324.635
% INFO    : Gen at bus 219	: Vg=1.056623 -> Vg=1.0
% INFO    : Gen at bus 220	: Pg=668.7, Qg=-115.27 -> Pg=600.0, Qg=127.985
% INFO    : Gen at bus 220	: Vg=1.047116 -> Vg=1.0
% INFO    : Gen at bus 221	: Pg=296.0, Qg=43.03 -> Pg=266.665, Qg=59.31
% INFO    : Gen at bus 221	: Vg=1.030636 -> Vg=1.0
% INFO    : Gen at bus 222	: Pg=-147.3, Qg=2.36 -> Pg=-48.2, Qg=3.445
% INFO    : Gen at bus 222	: Vg=1.030494 -> Vg=1.0
% INFO    : Gen at bus 239	: Pg=-7.05, Qg=7.21 -> Pg=45.3, Qg=13.64
% INFO    : Gen at bus 239	: Vg=1.018711 -> Vg=1.0
% INFO    : Gen at bus 246	: Pg=307.1, Qg=-22.47 -> Pg=533.335, Qg=132.745
% INFO    : Gen at bus 246	: Vg=1.06685 -> Vg=1.0
% INFO    : Gen at bus 248	: Pg=-172.0, Qg=11.84 -> Pg=-64.665, Qg=12.56
% INFO    : Gen at bus 248	: Vg=1.043991 -> Vg=1.0
% INFO    : Gen at bus 255	: Pg=423.2, Qg=-30.86 -> Pg=333.335, Qg=67.385
% INFO    : Gen at bus 255	: Vg=1.059597 -> Vg=1.0
% INFO    : Gen at bus 262	: Pg=-115.4, Qg=12.33 -> Pg=-26.935, Qg=13.19
% INFO    : Gen at bus 262	: Vg=1.033795 -> Vg=1.0
% INFO    : Gen at bus 263	: Pg=-34.4, Qg=-3.16 -> Pg=27.065, Qg=-0.95
% INFO    : Gen at bus 263	: Vg=1.028681 -> Vg=1.0
% INFO    : Gen at bus 278	: Pg=-64.1, Qg=7.04 -> Pg=7.265, Qg=12.805
% INFO    : Gen at bus 278	: Vg=1.014153 -> Vg=1.0
% INFO    : Gen at bus 282	: Pg=1245.7, Qg=-279.39 -> Pg=1333.335, Qg=312.145
% INFO    : Gen at bus 282	: Vg=1.077605 -> Vg=1.0
% INFO    : Gen at bus 289	: Pg=52.7, Qg=-3.66 -> Pg=30.0, Qg=7.605
% INFO    : Gen at bus 289	: Vg=1.046783 -> Vg=1.0
% INFO    : Gen at bus 294	: Pg=250.0, Qg=10.09 -> Pg=320.0, Qg=11.89
% INFO    : Gen at bus 294	: Vg=1.003375 -> Vg=1.0
% INFO    : Gen at bus 299	: Pg=975.9, Qg=97.97 -> Pg=1066.665, Qg=231.27
% INFO    : Gen at bus 299	: Vg=1.039248 -> Vg=1.0
% INFO    : Gen at bus 309	: Pg=95.1, Qg=36.53 -> Pg=50.0, Qg=11.95
% INFO    : Gen at bus 309	: Vg=0.989085 -> Vg=1.0
% INFO    : Gen at bus 310	: Pg=346.18, Qg=632.57 -> Pg=450.0, Qg=0.0
% INFO    : Gen at bus 310	: Vg=1.155322 -> Vg=1.0
% INFO    : Gen at bus 313	: Pg=9.6, Qg=-1.71 -> Pg=5.04, Qg=-1.17
% INFO    : Gen at bus 313	: Vg=1.025259 -> Vg=1.0
% INFO    : Gen at bus 320	: Pg=1760.0, Qg=-355.74 -> Pg=1208.0, Qg=-261.96
% INFO    : Gen at bus 320	: Vg=1.013336 -> Vg=1.0
% INFO    : Gen at bus 324	: Pg=94.0, Qg=30.47 -> Pg=100.0, Qg=34.015
% INFO    : Gen at bus 324	: Vg=1.063285 -> Vg=1.0
% INFO    : Gen at bus 325	: Pg=-21.4, Qg=0.06 -> Pg=35.735, Qg=0.46
% INFO    : Gen at bus 325	: Vg=1.009625 -> Vg=1.0
% INFO    : Gen at bus 328	: Pg=-77.9, Qg=0.12 -> Pg=-1.935, Qg=66.385
% INFO    : Gen at bus 328	: Vg=1.017618 -> Vg=1.0
% INFO    : Gen at bus 338	: Pg=83.7, Qg=3.24 -> Pg=60.0, Qg=18.19
% INFO    : Gen at bus 338	: Vg=1.046957 -> Vg=1.0
% INFO    : Gen at bus 347	: Pg=50.8, Qg=-13.47 -> Pg=26.71, Qg=-4.67
% INFO    : Gen at bus 347	: Vg=1.020949 -> Vg=1.0
% INFO    : Gen at bus 348	: Pg=160.4, Qg=3.38 -> Pg=120.0, Qg=36.835
% INFO    : Gen at bus 348	: Vg=1.057894 -> Vg=1.0
% INFO    : Gen at bus 352	: Pg=1250.4, Qg=256.45 -> Pg=1333.335, Qg=314.335
% INFO    : Gen at bus 352	: Vg=1.048835 -> Vg=1.0
% INFO    : Gen at bus 361	: Pg=238.3, Qg=27.11 -> Pg=266.665, Qg=63.945
% INFO    : Gen at bus 361	: Vg=1.05949 -> Vg=1.0
% INFO    : Gen at bus 366	: Pg=185.6, Qg=-33.91 -> Pg=130.665, Qg=-29.15
% INFO    : Gen at bus 366	: Vg=1.008853 -> Vg=1.0
% INFO    : Gen at bus 372	: Pg=-54.9, Qg=-13.56 -> Pg=13.4, Qg=99.325
% INFO    : Gen at bus 372	: Vg=1.074991 -> Vg=1.0
% INFO    : Gen at bus 382	: Pg=25.68, Qg=11.15 -> Pg=40.0, Qg=13.48
% INFO    : Gen at bus 382	: Vg=1.060853 -> Vg=1.0
% INFO    : Gen at bus 389	: Pg=69.0, Qg=17.57 -> Pg=60.0, Qg=19.445
% INFO    : Gen at bus 389	: Vg=1.017731 -> Vg=1.0
% INFO    : Gen at bus 394	: Pg=2404.4, Qg=-96.56 -> Pg=1866.665, Qg=367.045
% INFO    : Gen at bus 394	: Vg=1.063147 -> Vg=1.0
% INFO    : Gen at bus 406	: Pg=31.0, Qg=10.74 -> Pg=30.615, Qg=2.435
% INFO    : Gen at bus 406	: Vg=1.012399 -> Vg=1.0
% INFO    : Gen at bus 409	: Pg=-62.0, Qg=-7.35 -> Pg=8.665, Qg=-2.675
% INFO    : Gen at bus 409	: Vg=1.032831 -> Vg=1.0
% INFO    : Gen at bus 411	: Pg=35.9, Qg=4.64 -> Pg=20.0, Qg=5.195
% INFO    : Gen at bus 411	: Vg=1.03248 -> Vg=1.0
% INFO    : Gen at bus 413	: Pg=231.0, Qg=21.57 -> Pg=140.0, Qg=37.14
% INFO    : Gen at bus 413	: Vg=1.048421 -> Vg=1.0
% INFO    : Gen at bus 423	: Pg=-19.2, Qg=0.02 -> Pg=37.2, Qg=1.31
% INFO    : Gen at bus 423	: Vg=1.030299 -> Vg=1.0
% INFO    : Gen at bus 424	: Pg=636.3, Qg=269.64 -> Pg=466.665, Qg=89.45
% INFO    : Gen at bus 424	: Vg=1.051241 -> Vg=1.0
% INFO    : Gen at bus 433	: Pg=436.0, Qg=206.71 -> Pg=333.335, Qg=63.98
% INFO    : Gen at bus 433	: Vg=1.024885 -> Vg=1.0
% INFO    : Gen at bus 434	: Pg=-2.8, Qg=-1.11 -> Pg=48.135, Qg=-0.25
% INFO    : Gen at bus 434	: Vg=1.037999 -> Vg=1.0
% INFO    : Gen at bus 438	: Pg=74.0, Qg=9.04 -> Pg=50.0, Qg=14.46
% INFO    : Gen at bus 438	: Vg=1.038705 -> Vg=1.0
% INFO    : Gen at bus 439	: Pg=308.6, Qg=-59.31 -> Pg=200.0, Qg=52.975
% INFO    : Gen at bus 439	: Vg=1.072491 -> Vg=1.0
% INFO    : Gen at bus 440	: Pg=83.1, Qg=-1.51 -> Pg=60.0, Qg=18.36
% INFO    : Gen at bus 440	: Vg=1.028093 -> Vg=1.0
% INFO    : Gen at bus 442	: Pg=-40.35, Qg=-0.32 -> Pg=23.1, Qg=0.51
% INFO    : Gen at bus 442	: Vg=1.011727 -> Vg=1.0
% INFO    : Gen at bus 447	: Pg=37.7, Qg=2.42 -> Pg=20.0, Qg=4.4
% INFO    : Gen at bus 447	: Vg=1.035215 -> Vg=1.0
% INFO    : Gen at bus 452	: Pg=-56.8, Qg=16.67 -> Pg=12.135, Qg=12.96
% INFO    : Gen at bus 452	: Vg=1.013382 -> Vg=1.0
% INFO    : Gen at bus 453	: Pg=260.1, Qg=69.83 -> Pg=270.0, Qg=91.415
% INFO    : Gen at bus 453	: Vg=1.024712 -> Vg=1.0
% INFO    : Gen at bus 456	: Pg=-28.08, Qg=-11.78 -> Pg=31.28, Qg=2.495
% INFO    : Gen at bus 456	: Vg=0.999847 -> Vg=1.0
% INFO    : Gen at bus 484	: Pg=229.5, Qg=-43.46 -> Pg=150.0, Qg=40.78
% INFO    : Gen at bus 484	: Vg=1.054091 -> Vg=1.0
% INFO    : Gen at bus 489	: Pg=-107.4, Qg=-0.53 -> Pg=-21.6, Qg=0.73
% INFO    : Gen at bus 489	: Vg=1.008032 -> Vg=1.0
% INFO    : Gen at bus 491	: Pg=105.4, Qg=83.32 -> Pg=100.0, Qg=33.23
% INFO    : Gen at bus 491	: Vg=1.033193 -> Vg=1.0
% INFO    : Gen at bus 505	: Pg=110.6, Qg=-14.73 -> Pg=58.015, Qg=-10.495
% INFO    : Gen at bus 505	: Vg=1.022173 -> Vg=1.0
% INFO    : Gen at bus 511	: Pg=101.4, Qg=-14.26 -> Pg=100.0, Qg=33.17
% INFO    : Gen at bus 511	: Vg=1.081589 -> Vg=1.0
% INFO    : Gen at bus 515	: Pg=324.82, Qg=28.39 -> Pg=450.0, Qg=22.63
% INFO    : Gen at bus 515	: Vg=1.045162 -> Vg=1.0
% INFO    : Gen at bus 516	: Pg=539.4, Qg=184.01 -> Pg=400.0, Qg=77.56
% INFO    : Gen at bus 516	: Vg=1.07129 -> Vg=1.0
% INFO    : Gen at bus 518	: Pg=-410.3, Qg=1.69 -> Pg=-223.535, Qg=24.21
% INFO    : Gen at bus 518	: Vg=1.067615 -> Vg=1.0
% INFO    : Gen at bus 524	: Pg=69.0, Qg=-13.09 -> Pg=36.225, Qg=-6.46
% INFO    : Gen at bus 524	: Vg=1.046979 -> Vg=1.0
% INFO    : Gen at bus 541	: Pg=118.2, Qg=-15.0 -> Pg=62.095, Qg=-9.69
% INFO    : Gen at bus 541	: Vg=1.03819 -> Vg=1.0
% INFO    : Gen at bus 564	: Pg=-51.67, Qg=-3.19 -> Pg=15.555, Qg=-0.44
% INFO    : Gen at bus 564	: Vg=1.06702 -> Vg=1.0
% INFO    : Gen at bus 578	: Pg=-110.3, Qg=6.59 -> Pg=-23.535, Qg=7.435
% INFO    : Gen at bus 578	: Vg=1.042146 -> Vg=1.0
% INFO    : Gen at bus 583	: Pg=-270.0, Qg=4.89 -> Pg=-130.0, Qg=5.425
% INFO    : Gen at bus 583	: Vg=1.048595 -> Vg=1.0
% INFO    : Gen at bus 587	: Pg=246.0, Qg=1.47 -> Pg=266.665, Qg=63.085
% INFO    : Gen at bus 587	: Vg=1.040079 -> Vg=1.0
% INFO    : Gen at bus 590	: Pg=100.7, Qg=135.79 -> Pg=183.565, Qg=135.115
% INFO    : Gen at bus 590	: Vg=1.065004 -> Vg=1.0
% INFO    : Gen at bus 615	: Pg=38.2, Qg=2.13 -> Pg=20.0, Qg=4.65
% INFO    : Gen at bus 615	: Vg=1.068592 -> Vg=1.0
% INFO    : Gen at bus 616	: Pg=379.2, Qg=31.85 -> Pg=320.0, Qg=68.37
% INFO    : Gen at bus 616	: Vg=1.04484 -> Vg=1.0
% INFO    : Gen at bus 618	: Pg=670.3, Qg=-26.77 -> Pg=533.335, Qg=106.035
% INFO    : Gen at bus 618	: Vg=1.022784 -> Vg=1.0
% INFO    : Gen at bus 628	: Pg=152.4, Qg=41.23 -> Pg=90.0, Qg=23.55
% INFO    : Gen at bus 628	: Vg=0.982057 -> Vg=1.0
% INFO    : Gen at bus 636	: Pg=101.89, Qg=2.48 -> Pg=60.0, Qg=15.56
% INFO    : Gen at bus 636	: Vg=1.04241 -> Vg=1.0
% INFO    : Gen at bus 637	: Pg=21.3, Qg=-0.33 -> Pg=11.16, Qg=1.38
% INFO    : Gen at bus 637	: Vg=1.031148 -> Vg=1.0
% INFO    : Gen at bus 639	: Pg=-46.2, Qg=106.37 -> Pg=19.2, Qg=48.31
% INFO    : Gen at bus 639	: Vg=1.033532 -> Vg=1.0
% INFO    : Gen at bus 642	: Pg=63.33, Qg=-55.21 -> Pg=138.045, Qg=-1.45
% INFO    : Gen at bus 642	: Vg=1.031368 -> Vg=1.0
% INFO    : Gen at bus 648	: Pg=47.2, Qg=2.22 -> Pg=40.0, Qg=13.04
% INFO    : Gen at bus 648	: Vg=1.02749 -> Vg=1.0
% INFO    : Gen at bus 672	: Pg=67.0, Qg=-0.69 -> Pg=102.905, Qg=4.2
% INFO    : Gen at bus 672	: Vg=1.02121 -> Vg=1.0
% INFO    : Gen at bus 682	: Pg=37.4, Qg=8.11 -> Pg=40.0, Qg=13.855
% INFO    : Gen at bus 682	: Vg=1.060787 -> Vg=1.0
% INFO    : Gen at bus 686	: Pg=-21.65, Qg=-8.24 -> Pg=35.57, Qg=0.245
% INFO    : Gen at bus 686	: Vg=1.013903 -> Vg=1.0
% INFO    : Gen at bus 692	: Pg=274.8, Qg=-4.69 -> Pg=266.665, Qg=59.69
% INFO    : Gen at bus 692	: Vg=1.059006 -> Vg=1.0
% INFO    : Gen at bus 697	: Pg=634.8, Qg=27.98 -> Pg=533.335, Qg=112.325
% INFO    : Gen at bus 697	: Vg=1.031719 -> Vg=1.0
% INFO    : Gen at bus 698	: Pg=274.8, Qg=3.65 -> Pg=200.0, Qg=38.015
% INFO    : Gen at bus 698	: Vg=0.999662 -> Vg=1.0
% INFO    : Gen at bus 709	: Pg=16.0, Qg=-8.56 -> Pg=32.65, Qg=0.7
% INFO    : Gen at bus 709	: Vg=1.068875 -> Vg=1.0
% INFO    : Gen at bus 711	: Pg=27.8, Qg=52.62 -> Pg=59.265, Qg=131.69
% INFO    : Gen at bus 711	: Vg=1.070147 -> Vg=1.0
% INFO    : Gen at bus 713	: Pg=99.3, Qg=8.47 -> Pg=60.0, Qg=16.595
% INFO    : Gen at bus 713	: Vg=1.034791 -> Vg=1.0
% INFO    : Gen at bus 714	: Pg=453.4, Qg=62.78 -> Pg=533.335, Qg=131.14
% INFO    : Gen at bus 714	: Vg=1.065017 -> Vg=1.0
% INFO    : Gen at bus 715	: Pg=323.1, Qg=-67.84 -> Pg=244.0, Qg=-56.765
% INFO    : Gen at bus 715	: Vg=1.021604 -> Vg=1.0
% INFO    : Gen at bus 727	: Pg=384.26, Qg=-63.12 -> Pg=533.335, Qg=134.26
% INFO    : Gen at bus 727	: Vg=1.070143 -> Vg=1.0
% INFO    : Gen at bus 728	: Pg=70.8, Qg=-18.79 -> Pg=37.14, Qg=-4.29
% INFO    : Gen at bus 728	: Vg=1.030375 -> Vg=1.0
% INFO    : Gen at bus 735	: Pg=170.0, Qg=-27.79 -> Pg=89.25, Qg=-16.06
% INFO    : Gen at bus 735	: Vg=1.026593 -> Vg=1.0
% INFO    : Gen at bus 738	: Pg=90.79, Qg=47.3 -> Pg=172.995, Qg=6.355
% INFO    : Gen at bus 738	: Vg=1.033376 -> Vg=1.0
% INFO    : Gen at bus 739	: Pg=465.7, Qg=-58.22 -> Pg=333.335, Qg=59.76
% INFO    : Gen at bus 739	: Vg=1.035442 -> Vg=1.0
% INFO    : Gen at bus 749	: Pg=198.88, Qg=4.93 -> Pg=120.0, Qg=30.925
% INFO    : Gen at bus 749	: Vg=1.053546 -> Vg=1.0
% INFO    : Gen at bus 751	: Pg=65.9, Qg=-20.17 -> Pg=150.0, Qg=44.85
% INFO    : Gen at bus 751	: Vg=1.020488 -> Vg=1.0
% INFO    : Gen at bus 757	: Pg=116.7, Qg=15.15 -> Pg=60.0, Qg=13.945
% INFO    : Gen at bus 757	: Vg=1.013994 -> Vg=1.0
% INFO    : Gen at bus 763	: Pg=37.3, Qg=5.58 -> Pg=30.0, Qg=9.455
% INFO    : Gen at bus 763	: Vg=1.042899 -> Vg=1.0
% INFO    : Gen at bus 764	: Pg=138.3, Qg=8.35 -> Pg=266.665, Qg=51.525
% INFO    : Gen at bus 764	: Vg=1.048246 -> Vg=1.0
% INFO    : Gen at bus 765	: Pg=170.7, Qg=20.09 -> Pg=90.0, Qg=21.46
% INFO    : Gen at bus 765	: Vg=1.017174 -> Vg=1.0
% INFO    : Gen at bus 774	: Pg=134.4, Qg=-8.34 -> Pg=70.56, Qg=10.415
% INFO    : Gen at bus 774	: Vg=1.038992 -> Vg=1.0
% INFO    : Gen at bus 776	: Pg=-111.4, Qg=5.14 -> Pg=-24.265, Qg=5.715
% INFO    : Gen at bus 776	: Vg=1.023986 -> Vg=1.0
% INFO    : Gen at bus 778	: Pg=16.5, Qg=-0.64 -> Pg=16.79, Qg=1.505
% INFO    : Gen at bus 778	: Vg=1.047837 -> Vg=1.0
% INFO    : Gen at bus 779	: Pg=37.8, Qg=12.06 -> Pg=22.5, Qg=4.88
% INFO    : Gen at bus 779	: Vg=1.039304 -> Vg=1.0
% INFO    : Gen at bus 780	: Pg=50.8, Qg=17.14 -> Pg=40.0, Qg=12.555
% INFO    : Gen at bus 780	: Vg=1.001975 -> Vg=1.0
% INFO    : Gen at bus 791	: Pg=569.74, Qg=-78.0 -> Pg=800.0, Qg=200.075
% INFO    : Gen at bus 791	: Vg=1.052091 -> Vg=1.0
% INFO    : Gen at bus 795	: Pg=58.4, Qg=7.1 -> Pg=40.0, Qg=11.855
% INFO    : Gen at bus 795	: Vg=1.041931 -> Vg=1.0
% INFO    : Gen at bus 796	: Pg=31.6, Qg=19.62 -> Pg=40.0, Qg=14.13
% INFO    : Gen at bus 796	: Vg=1.01604 -> Vg=1.0
% INFO    : Gen at bus 803	: Pg=-89.2, Qg=9.91 -> Pg=-9.465, Qg=24.245
% INFO    : Gen at bus 803	: Vg=1.04662 -> Vg=1.0
% INFO    : Gen at bus 807	: Pg=1597.5, Qg=-195.51 -> Pg=1333.335, Qg=251.75
% INFO    : Gen at bus 807	: Vg=1.053518 -> Vg=1.0
% INFO    : Gen at bus 813	: Pg=505.6, Qg=0.16 -> Pg=401.335, Qg=9.075
% INFO    : Gen at bus 813	: Vg=1.037003 -> Vg=1.0
% INFO    : Gen at bus 823	: Pg=1274.2, Qg=287.09 -> Pg=1333.335, Qg=314.185
% INFO    : Gen at bus 823	: Vg=1.039055 -> Vg=1.0
% INFO    : Gen at bus 828	: Pg=55.9, Qg=-11.69 -> Pg=29.35, Qg=-0.78
% INFO    : Gen at bus 828	: Vg=1.044382 -> Vg=1.0
% INFO    : Gen at bus 831	: Pg=85.2, Qg=16.49 -> Pg=60.0, Qg=18.205
% INFO    : Gen at bus 831	: Vg=1.003271 -> Vg=1.0
% INFO    : Gen at bus 832	: Pg=507.0, Qg=137.14 -> Pg=400.0, Qg=80.94
% INFO    : Gen at bus 832	: Vg=1.004583 -> Vg=1.0
% INFO    : Gen at bus 837	: Pg=44.0, Qg=7.99 -> Pg=30.0, Qg=8.765
% INFO    : Gen at bus 837	: Vg=1.022737 -> Vg=1.0
% INFO    : Gen at bus 844	: Pg=97.5, Qg=14.12 -> Pg=60.0, Qg=16.94
% INFO    : Gen at bus 844	: Vg=1.064419 -> Vg=1.0
% INFO    : Gen at bus 848	: Pg=4.03, Qg=-7.12 -> Pg=51.345, Qg=5.755
% INFO    : Gen at bus 848	: Vg=1.011431 -> Vg=1.0
% INFO    : Gen at bus 849	: Pg=8.7, Qg=-1.18 -> Pg=8.785, Qg=0.77
% INFO    : Gen at bus 849	: Vg=1.037264 -> Vg=1.0
% INFO    : Gen at bus 851	: Pg=59.56, Qg=41.16 -> Pg=100.0, Qg=34.415
% INFO    : Gen at bus 851	: Vg=1.018845 -> Vg=1.0
% INFO    : Gen at bus 858	: Pg=855.6, Qg=160.89 -> Pg=666.665, Qg=134.26
% INFO    : Gen at bus 858	: Vg=1.028813 -> Vg=1.0
% INFO    : Gen at bus 861	: Pg=55.8, Qg=10.72 -> Pg=60.0, Qg=20.65
% INFO    : Gen at bus 861	: Vg=1.050818 -> Vg=1.0
% INFO    : Gen at bus 875	: Pg=343.5, Qg=45.89 -> Pg=333.335, Qg=74.985
% INFO    : Gen at bus 875	: Vg=1.038959 -> Vg=1.0
% INFO    : Gen at bus 888	: Pg=181.98, Qg=-7.29 -> Pg=200.0, Qg=46.665
% INFO    : Gen at bus 888	: Vg=1.037604 -> Vg=1.0
% INFO    : Gen at bus 891	: Pg=1702.8, Qg=696.58 -> Pg=1600.0, Qg=361.75
% INFO    : Gen at bus 891	: Vg=1.062964 -> Vg=1.0
% INFO    : Gen at bus 894	: Pg=264.67, Qg=69.9 -> Pg=160.0, Qg=42.095
% INFO    : Gen at bus 894	: Vg=1.054199 -> Vg=1.0
% INFO    : Gen at bus 896	: Pg=-2.7, Qg=-2.25 -> Pg=48.2, Qg=-1.4
% INFO    : Gen at bus 896	: Vg=1.021987 -> Vg=1.0
% INFO    : Gen at bus 913	: Pg=1249.4, Qg=683.52 -> Pg=1133.335, Qg=251.085
% INFO    : Gen at bus 913	: Vg=1.026545 -> Vg=1.0
% INFO    : Gen at bus 916	: Pg=230.2, Qg=-24.09 -> Pg=150.0, Qg=42.345
% INFO    : Gen at bus 916	: Vg=1.022135 -> Vg=1.0
% INFO    : Gen at bus 917	: Pg=32.0, Qg=3.93 -> Pg=20.0, Qg=5.745
% INFO    : Gen at bus 917	: Vg=1.061631 -> Vg=1.0
% INFO    : Gen at bus 926	: Pg=420.0, Qg=11.01 -> Pg=314.665, Qg=56.58
% INFO    : Gen at bus 926	: Vg=1.008066 -> Vg=1.0
% INFO    : Gen at bus 927	: Pg=27.4, Qg=-2.86 -> Pg=30.0, Qg=10.265
% INFO    : Gen at bus 927	: Vg=1.067901 -> Vg=1.0
% INFO    : Gen at bus 930	: Pg=679.6, Qg=-118.0 -> Pg=600.0, Qg=130.955
% INFO    : Gen at bus 930	: Vg=1.058189 -> Vg=1.0
% INFO    : Gen at bus 972	: Pg=1221.2, Qg=407.52 -> Pg=1333.335, Qg=321.605
% INFO    : Gen at bus 972	: Vg=1.078612 -> Vg=1.0
% INFO    : Gen at bus 974	: Pg=83.89, Qg=18.08 -> Pg=60.0, Qg=17.075
% INFO    : Gen at bus 974	: Vg=1.033045 -> Vg=1.0
% INFO    : Gen at bus 976	: Pg=21.3, Qg=-5.46 -> Pg=53.915, Qg=0.335
% INFO    : Gen at bus 976	: Vg=1.024328 -> Vg=1.0
% INFO    : Gen at bus 978	: Pg=14.9, Qg=0.14 -> Pg=7.575, Qg=1.72
% INFO    : Gen at bus 978	: Vg=1.017319 -> Vg=1.0
% INFO    : Gen at bus 983	: Pg=1034.8, Qg=-256.65 -> Pg=1333.335, Qg=335.545
% INFO    : Gen at bus 983	: Vg=1.078039 -> Vg=1.0
% INFO    : Gen at bus 984	: Pg=1029.2, Qg=8.1 -> Pg=1066.665, Qg=249.045
% INFO    : Gen at bus 984	: Vg=1.031963 -> Vg=1.0
% INFO    : Gen at bus 991	: Pg=21.68, Qg=2.06 -> Pg=20.0, Qg=4.39
% INFO    : Gen at bus 991	: Vg=1.001634 -> Vg=1.0
% INFO    : Gen at bus 992	: Pg=14.96, Qg=6.97 -> Pg=30.0, Qg=7.55
% INFO    : Gen at bus 992	: Vg=1.030255 -> Vg=1.0
% INFO    : Gen at bus 993	: Pg=-136.9, Qg=5.75 -> Pg=-41.265, Qg=5.39
% INFO    : Gen at bus 993	: Vg=1.037248 -> Vg=1.0
% INFO    : Gen at bus 1001	: Pg=92.1, Qg=23.68 -> Pg=60.0, Qg=17.605
% INFO    : Gen at bus 1001	: Vg=1.069874 -> Vg=1.0
% INFO    : Gen at bus 1002	: Pg=171.0, Qg=10.18 -> Pg=100.0, Qg=27.2
% INFO    : Gen at bus 1002	: Vg=1.03837 -> Vg=1.0
% INFO    : Gen at bus 1004	: Pg=86.4, Qg=35.09 -> Pg=50.0, Qg=13.295
% INFO    : Gen at bus 1004	: Vg=0.99944 -> Vg=1.0
% INFO    : Gen at bus 1021	: Pg=-179.3, Qg=8.75 -> Pg=-69.535, Qg=21.055
% INFO    : Gen at bus 1021	: Vg=1.012345 -> Vg=1.0
% INFO    : Gen at bus 1029	: Pg=138.6, Qg=5.85 -> Pg=100.0, Qg=29.455
% INFO    : Gen at bus 1029	: Vg=1.037886 -> Vg=1.0
% INFO    : Gen at bus 1030	: Pg=164.94, Qg=9.31 -> Pg=250.0, Qg=21.885
% INFO    : Gen at bus 1030	: Vg=1.007808 -> Vg=1.0
% INFO    : Gen at bus 1036	: Pg=202.5, Qg=0.73 -> Pg=200.0, Qg=45.47
% INFO    : Gen at bus 1036	: Vg=1.037074 -> Vg=1.0
% INFO    : Gen at bus 1043	: Pg=829.5, Qg=49.52 -> Pg=600.0, Qg=112.24
% INFO    : Gen at bus 1043	: Vg=1.027465 -> Vg=1.0
% INFO    : Gen at bus 1050	: Pg=337.91, Qg=1.63 -> Pg=385.385, Qg=50.855
% INFO    : Gen at bus 1050	: Vg=1.055375 -> Vg=1.0
% INFO    : Gen at bus 1082	: Pg=364.4, Qg=56.84 -> Pg=266.665, Qg=49.06
% INFO    : Gen at bus 1082	: Vg=1.027941 -> Vg=1.0
% INFO    : Gen at bus 1083	: Pg=91.8, Qg=8.04 -> Pg=60.0, Qg=17.515
% INFO    : Gen at bus 1083	: Vg=1.050507 -> Vg=1.0
% INFO    : Gen at bus 1088	: Pg=4.6, Qg=1.01 -> Pg=22.995, Qg=2.2
% INFO    : Gen at bus 1088	: Vg=1.025882 -> Vg=1.0
% INFO    : Gen at bus 1093	: Pg=837.0, Qg=97.07 -> Pg=800.0, Qg=182.77
% INFO    : Gen at bus 1093	: Vg=1.024587 -> Vg=1.0
% INFO    : Gen at bus 1097	: Pg=17.5, Qg=-0.91 -> Pg=9.19, Qg=-0.235
% INFO    : Gen at bus 1097	: Vg=1.013606 -> Vg=1.0
% INFO    : Gen at bus 1098	: Pg=93.35, Qg=-19.73 -> Pg=133.335, Qg=30.09
% INFO    : Gen at bus 1098	: Vg=1.104358 -> Vg=1.0
% INFO    : Gen at bus 1100	: Pg=58.2, Qg=6.13 -> Pg=40.0, Qg=11.895
% INFO    : Gen at bus 1100	: Vg=1.042301 -> Vg=1.0
% INFO    : Gen at bus 1102	: Pg=-124.15, Qg=12.14 -> Pg=-32.77, Qg=13.23
% INFO    : Gen at bus 1102	: Vg=1.048163 -> Vg=1.0
% INFO    : Gen at bus 1103	: Pg=405.69, Qg=-35.07 -> Pg=533.335, Qg=132.0
% INFO    : Gen at bus 1103	: Vg=1.043526 -> Vg=1.0
% INFO    : Gen at bus 1117	: Pg=744.1, Qg=-245.23 -> Pg=576.0, Qg=-89.82
% INFO    : Gen at bus 1117	: Vg=1.009173 -> Vg=1.0
% INFO    : Gen at bus 1119	: Pg=298.7, Qg=-10.62 -> Pg=200.0, Qg=34.58
% INFO    : Gen at bus 1119	: Vg=1.044725 -> Vg=1.0
% INFO    : Gen at bus 1121	: Pg=289.79, Qg=-11.59 -> Pg=180.0, Qg=47.695
% INFO    : Gen at bus 1121	: Vg=1.017488 -> Vg=1.0
% INFO    : Gen at bus 1122	: Pg=75.2, Qg=2.31 -> Pg=95.14, Qg=5.96
% INFO    : Gen at bus 1122	: Vg=1.043868 -> Vg=1.0
% INFO    : Gen at bus 1125	: Pg=129.6, Qg=13.26 -> Pg=120.0, Qg=39.915
% INFO    : Gen at bus 1125	: Vg=1.04319 -> Vg=1.0
% INFO    : Gen at bus 1131	: Pg=667.5, Qg=108.89 -> Pg=600.0, Qg=132.025
% INFO    : Gen at bus 1131	: Vg=1.036981 -> Vg=1.0
% INFO    : Gen at bus 1138	: Pg=930.3, Qg=93.88 -> Pg=666.665, Qg=125.87
% INFO    : Gen at bus 1138	: Vg=1.088765 -> Vg=1.0
% INFO    : Gen at bus 1139	: Pg=175.48, Qg=49.36 -> Pg=120.0, Qg=33.195
% INFO    : Gen at bus 1139	: Vg=1.054186 -> Vg=1.0
% INFO    : Gen at bus 1145	: Pg=173.47, Qg=-1.29 -> Pg=245.12, Qg=4.415
% INFO    : Gen at bus 1145	: Vg=1.040382 -> Vg=1.0
% INFO    : Gen at bus 1173	: Pg=-124.7, Qg=-0.42 -> Pg=-33.135, Qg=0.485
% INFO    : Gen at bus 1173	: Vg=1.018544 -> Vg=1.0
% INFO    : Gen at bus 1174	: Pg=26.8, Qg=5.65 -> Pg=20.0, Qg=6.165
% INFO    : Gen at bus 1174	: Vg=1.002801 -> Vg=1.0
% INFO    : Gen at bus 1175	: Pg=309.54, Qg=3.13 -> Pg=450.0, Qg=34.615
% INFO    : Gen at bus 1175	: Vg=1.038334 -> Vg=1.0
% INFO    : Gen at bus 1176	: Pg=6.7, Qg=13.93 -> Pg=52.23, Qg=33.02
% INFO    : Gen at bus 1176	: Vg=1.016193 -> Vg=1.0
% INFO    : Gen at bus 1184	: Pg=329.2, Qg=159.58 -> Pg=200.0, Qg=55.235
% INFO    : Gen at bus 1184	: Vg=1.037371 -> Vg=1.0
% INFO    : Gen at bus 1220	: Pg=107.4, Qg=57.33 -> Pg=90.0, Qg=28.795
% INFO    : Gen at bus 1220	: Vg=1.008655 -> Vg=1.0
% INFO    : Gen at bus 1225	: Pg=282.8, Qg=18.73 -> Pg=145.215, Qg=31.6
% INFO    : Gen at bus 1225	: Vg=1.051668 -> Vg=1.0
% INFO    : Gen at bus 1237	: Pg=1504.8, Qg=346.47 -> Pg=1333.335, Qg=293.585
% INFO    : Gen at bus 1237	: Vg=1.103909 -> Vg=1.0
% INFO    : Gen at bus 1241	: Pg=46.13, Qg=-7.09 -> Pg=32.815, Qg=0.655
% INFO    : Gen at bus 1241	: Vg=1.019582 -> Vg=1.0
% INFO    : Gen at bus 1243	: Pg=81.7, Qg=-2.62 -> Pg=50.0, Qg=13.64
% INFO    : Gen at bus 1243	: Vg=1.080005 -> Vg=1.0
% INFO    : Gen at bus 1244	: Pg=16.2, Qg=-0.85 -> Pg=31.895, Qg=-2.495
% INFO    : Gen at bus 1244	: Vg=1.026736 -> Vg=1.0
% INFO    : Gen at bus 1251	: Pg=837.0, Qg=90.81 -> Pg=800.0, Qg=182.77
% INFO    : Gen at bus 1251	: Vg=1.024626 -> Vg=1.0
% INFO    : Gen at bus 1258	: Pg=71.0, Qg=20.62 -> Pg=40.0, Qg=10.04
% INFO    : Gen at bus 1258	: Vg=1.032962 -> Vg=1.0
% INFO    : Gen at bus 1267	: Pg=155.3, Qg=6.62 -> Pg=266.665, Qg=69.24
% INFO    : Gen at bus 1267	: Vg=1.04637 -> Vg=1.0
% INFO    : Gen at bus 1271	: Pg=-100.5, Qg=-11.0 -> Pg=-17.0, Qg=0.215
% INFO    : Gen at bus 1271	: Vg=1.0139 -> Vg=1.0
% INFO    : Gen at bus 1295	: Pg=-124.1, Qg=7.57 -> Pg=-32.735, Qg=12.02
% INFO    : Gen at bus 1295	: Vg=1.035594 -> Vg=1.0
% INFO    : Gen at bus 1307	: Pg=-410.1, Qg=8.83 -> Pg=-223.4, Qg=10.57
% INFO    : Gen at bus 1307	: Vg=1.062062 -> Vg=1.0
% INFO    : Gen at bus 1313	: Pg=18.18, Qg=4.52 -> Pg=20.0, Qg=5.045
% INFO    : Gen at bus 1313	: Vg=1.031257 -> Vg=1.0
% INFO    : Gen at bus 1315	: Pg=-234.9, Qg=12.44 -> Pg=-106.6, Qg=13.355
% INFO    : Gen at bus 1315	: Vg=1.091975 -> Vg=1.0
% INFO    : Gen at bus 1320	: Pg=279.6, Qg=57.98 -> Pg=180.0, Qg=50.16
% INFO    : Gen at bus 1320	: Vg=1.01339 -> Vg=1.0
% INFO    : Gen at bus 1337	: Pg=184.1, Qg=2.66 -> Pg=266.665, Qg=68.235
% INFO    : Gen at bus 1337	: Vg=1.05919 -> Vg=1.0
% INFO    : Gen at bus 1341	: Pg=67.2, Qg=26.36 -> Pg=60.0, Qg=19.705
% INFO    : Gen at bus 1341	: Vg=1.035237 -> Vg=1.0
% INFO    : Gen at bus 1354	: Pg=-246.5, Qg=15.08 -> Pg=-114.335, Qg=13.175
% INFO    : Gen at bus 1354	: Vg=1.034497 -> Vg=1.0
% INFO    : Gen at bus 1361	: Pg=-83.6, Qg=-11.72 -> Pg=-5.735, Qg=30.375
% INFO    : Gen at bus 1361	: Vg=1.001499 -> Vg=1.0
% INFO    : Gen at bus 1365	: Pg=314.0, Qg=47.8 -> Pg=266.665, Qg=56.62
% INFO    : Gen at bus 1365	: Vg=1.045092 -> Vg=1.0
% INFO    : Gen at bus 1371	: Pg=87.1, Qg=-31.41 -> Pg=98.7, Qg=-20.84
% INFO    : Gen at bus 1371	: Vg=1.02639 -> Vg=1.0
% INFO    : Gen at bus 1378	: Pg=-30.21, Qg=-1.88 -> Pg=29.86, Qg=-1.255
% INFO    : Gen at bus 1378	: Vg=1.015715 -> Vg=1.0
% INFO    : Gen at bus 1387	: Pg=-198.4, Qg=-13.94 -> Pg=-82.265, Qg=51.435
% INFO    : Gen at bus 1387	: Vg=1.029614 -> Vg=1.0
% INFO    : Gen at bus 1390	: Pg=299.2, Qg=38.81 -> Pg=200.675, Qg=34.85
% INFO    : Gen at bus 1390	: Vg=1.076512 -> Vg=1.0
% INFO    : Gen at bus 1391	: Pg=26.2, Qg=2.2 -> Pg=20.0, Qg=6.285
% INFO    : Gen at bus 1391	: Vg=1.027192 -> Vg=1.0
% INFO    : Gen at bus 1399	: Pg=-174.6, Qg=-3.16 -> Pg=-66.4, Qg=0.72
% INFO    : Gen at bus 1399	: Vg=1.04788 -> Vg=1.0
% INFO    : Gen at bus 1402	: Pg=200.2, Qg=-7.59 -> Pg=200.0, Qg=44.905
% INFO    : Gen at bus 1402	: Vg=1.019959 -> Vg=1.0
% INFO    : Gen at bus 1409	: Pg=628.19, Qg=-75.91 -> Pg=533.335, Qg=93.45
% INFO    : Gen at bus 1409	: Vg=1.022303 -> Vg=1.0
% INFO    : Gen at bus 1417	: Pg=39.99, Qg=12.96 -> Pg=40.0, Qg=13.19
% INFO    : Gen at bus 1417	: Vg=1.009035 -> Vg=1.0
% INFO    : Gen at bus 1420	: Pg=399.5, Qg=101.83 -> Pg=526.665, Qg=62.155
% INFO    : Gen at bus 1420	: Vg=1.001444 -> Vg=1.0
% INFO    : Gen at bus 1422	: Pg=-101.0, Qg=4.92 -> Pg=-17.335, Qg=5.65
% INFO    : Gen at bus 1422	: Vg=1.047835 -> Vg=1.0
% INFO    : Gen at bus 1426	: Pg=416.5, Qg=190.14 -> Pg=250.0, Qg=67.05
% INFO    : Gen at bus 1426	: Vg=1.072946 -> Vg=1.0
% INFO    : Gen at bus 1433	: Pg=57.2, Qg=-11.62 -> Pg=30.03, Qg=-7.26
% INFO    : Gen at bus 1433	: Vg=1.01442 -> Vg=1.0
% INFO    : Gen at bus 1436	: Pg=49.4, Qg=5.52 -> Pg=40.0, Qg=12.815
% INFO    : Gen at bus 1436	: Vg=1.054052 -> Vg=1.0
% INFO    : Gen at bus 1440	: Pg=115.0, Qg=-7.3 -> Pg=60.375, Qg=-8.17
% INFO    : Gen at bus 1440	: Vg=1.011268 -> Vg=1.0
% INFO    : Gen at bus 1444	: Pg=130.32, Qg=-74.8 -> Pg=135.635, Qg=-65.115
% INFO    : Gen at bus 1444	: Vg=1.023146 -> Vg=1.0
% INFO    : Gen at bus 1458	: Pg=1588.0, Qg=-294.83 -> Pg=1333.335, Qg=282.225
% INFO    : Gen at bus 1458	: Vg=1.045766 -> Vg=1.0
% INFO    : Gen at bus 1474	: Pg=-27.0, Qg=0.2 -> Pg=32.0, Qg=0.43
% INFO    : Gen at bus 1474	: Vg=1.010259 -> Vg=1.0
% INFO    : Gen at bus 1475	: Pg=783.9, Qg=-95.73 -> Pg=600.0, Qg=118.725
% INFO    : Gen at bus 1475	: Vg=1.020467 -> Vg=1.0
% INFO    : Gen at bus 1478	: Pg=62.6, Qg=8.63 -> Pg=40.0, Qg=11.48
% INFO    : Gen at bus 1478	: Vg=1.048923 -> Vg=1.0
% INFO    : Gen at bus 1481	: Pg=297.8, Qg=-56.44 -> Pg=350.0, Qg=172.07
% INFO    : Gen at bus 1481	: Vg=1.040265 -> Vg=1.0
% INFO    : Gen at bus 1484	: Pg=288.3, Qg=-36.25 -> Pg=150.0, Qg=35.68
% INFO    : Gen at bus 1484	: Vg=1.027385 -> Vg=1.0
% INFO    : Gen at bus 1487	: Pg=389.03, Qg=-5.18 -> Pg=200.0, Qg=51.935
% INFO    : Gen at bus 1487	: Vg=1.055167 -> Vg=1.0
% INFO    : Gen at bus 1492	: Pg=261.6, Qg=3.44 -> Pg=350.0, Qg=131.065
% INFO    : Gen at bus 1492	: Vg=1.02928 -> Vg=1.0
% INFO    : Gen at bus 1498	: Pg=5.2, Qg=-0.57 -> Pg=2.655, Qg=0.595
% INFO    : Gen at bus 1498	: Vg=1.073955 -> Vg=1.0
% INFO    : Gen at bus 1507	: Pg=-99.2, Qg=5.83 -> Pg=-16.13, Qg=6.305
% INFO    : Gen at bus 1507	: Vg=1.057885 -> Vg=1.0
% INFO    : Gen at bus 1508	: Pg=149.2, Qg=9.16 -> Pg=100.0, Qg=28.8
% INFO    : Gen at bus 1508	: Vg=1.062401 -> Vg=1.0
% INFO    : Gen at bus 1529	: Pg=-22.7, Qg=-0.03 -> Pg=34.865, Qg=0.41
% INFO    : Gen at bus 1529	: Vg=1.01463 -> Vg=1.0
% INFO    : Gen at bus 1546	: Pg=341.2, Qg=25.97 -> Pg=266.665, Qg=52.67
% INFO    : Gen at bus 1546	: Vg=1.042059 -> Vg=1.0
% INFO    : Gen at bus 1550	: Pg=350.0, Qg=-54.69 -> Pg=266.665, Qg=51.73
% INFO    : Gen at bus 1550	: Vg=1.082656 -> Vg=1.0
% INFO    : Gen at bus 1555	: Pg=453.4, Qg=62.5 -> Pg=533.335, Qg=131.14
% INFO    : Gen at bus 1555	: Vg=1.065019 -> Vg=1.0
% INFO    : Gen at bus 1557	: Pg=993.3, Qg=344.07 -> Pg=733.335, Qg=140.805
% INFO    : Gen at bus 1557	: Vg=1.039811 -> Vg=1.0
% INFO    : Gen at bus 1558	: Pg=24.1, Qg=1.36 -> Pg=23.625, Qg=2.045
% INFO    : Gen at bus 1558	: Vg=1.01534 -> Vg=1.0
% INFO    : Gen at bus 1570	: Pg=121.4, Qg=-1.61 -> Pg=133.335, Qg=31.835
% INFO    : Gen at bus 1570	: Vg=1.076277 -> Vg=1.0
% INFO    : Gen at bus 1582	: Pg=312.0, Qg=0.62 -> Pg=200.0, Qg=55.485
% INFO    : Gen at bus 1582	: Vg=1.042602 -> Vg=1.0
% INFO    : Gen at bus 1589	: Pg=-31.54, Qg=-7.08 -> Pg=28.975, Qg=-5.725
% INFO    : Gen at bus 1589	: Vg=1.023343 -> Vg=1.0
% INFO    : Gen at bus 1604	: Pg=50.6, Qg=13.86 -> Pg=40.0, Qg=12.745
% INFO    : Gen at bus 1604	: Vg=1.037285 -> Vg=1.0
% INFO    : Gen at bus 1606	: Pg=358.2, Qg=24.61 -> Pg=266.665, Qg=51.945
% INFO    : Gen at bus 1606	: Vg=1.077423 -> Vg=1.0
% INFO    : Gen at bus 1618	: Pg=-136.6, Qg=-8.43 -> Pg=-41.065, Qg=0.6
% INFO    : Gen at bus 1618	: Vg=1.075715 -> Vg=1.0
% INFO    : Gen at bus 1626	: Pg=22.8, Qg=-0.41 -> Pg=14.175, Qg=1.28
% INFO    : Gen at bus 1626	: Vg=1.038045 -> Vg=1.0
% INFO    : Gen at bus 1642	: Pg=50.4, Qg=13.84 -> Pg=40.0, Qg=12.815
% INFO    : Gen at bus 1642	: Vg=1.025423 -> Vg=1.0
% INFO    : Gen at bus 1680	: Pg=1250.4, Qg=263.29 -> Pg=1333.335, Qg=316.395
% INFO    : Gen at bus 1680	: Vg=1.038879 -> Vg=1.0
% INFO    : Gen at bus 1684	: Pg=599.3, Qg=132.44 -> Pg=800.0, Qg=162.315
% INFO    : Gen at bus 1684	: Vg=1.033747 -> Vg=1.0
% INFO    : Gen at bus 1685	: Pg=62.7, Qg=18.2 -> Pg=60.0, Qg=20.095
% INFO    : Gen at bus 1685	: Vg=1.003785 -> Vg=1.0
% INFO    : Gen at bus 1697	: Pg=-189.0, Qg=-10.95 -> Pg=-76.0, Qg=0.35
% INFO    : Gen at bus 1697	: Vg=1.036203 -> Vg=1.0
% INFO    : Gen at bus 1708	: Pg=860.8, Qg=121.45 -> Pg=666.665, Qg=133.035
% INFO    : Gen at bus 1708	: Vg=1.034651 -> Vg=1.0
% INFO    : Gen at bus 1715	: Pg=25.35, Qg=0.82 -> Pg=40.0, Qg=10.175
% INFO    : Gen at bus 1715	: Vg=1.054322 -> Vg=1.0
% INFO    : Gen at bus 1717	: Pg=19.9, Qg=1.13 -> Pg=20.0, Qg=6.8
% INFO    : Gen at bus 1717	: Vg=1.022926 -> Vg=1.0
% INFO    : Gen at bus 1719	: Pg=269.17, Qg=92.54 -> Pg=533.335, Qg=133.425
% INFO    : Gen at bus 1719	: Vg=1.085028 -> Vg=1.0
% INFO    : Gen at bus 1720	: Pg=994.5, Qg=504.86 -> Pg=800.0, Qg=166.21
% INFO    : Gen at bus 1720	: Vg=1.072226 -> Vg=1.0
% INFO    : Gen at bus 1721	: Pg=28.1, Qg=2.89 -> Pg=20.0, Qg=6.065
% INFO    : Gen at bus 1721	: Vg=1.061454 -> Vg=1.0
% INFO    : Gen at bus 1726	: Pg=48.66, Qg=10.82 -> Pg=60.0, Qg=17.92
% INFO    : Gen at bus 1726	: Vg=1.067726 -> Vg=1.0
% INFO    : Gen at bus 1736	: Pg=200.0, Qg=28.4 -> Pg=135.055, Qg=23.305
% INFO    : Gen at bus 1736	: Vg=1.06645 -> Vg=1.0
% INFO    : Gen at bus 1738	: Pg=623.6, Qg=42.99 -> Pg=480.0, Qg=26.11
% INFO    : Gen at bus 1738	: Vg=1.015757 -> Vg=1.0
% INFO    : Gen at bus 1743	: Pg=79.6, Qg=12.98 -> Pg=62.5, Qg=18.365
% INFO    : Gen at bus 1743	: Vg=1.033701 -> Vg=1.0
% INFO    : Gen at bus 1747	: Pg=835.5, Qg=254.03 -> Pg=600.0, Qg=111.97
% INFO    : Gen at bus 1747	: Vg=1.053359 -> Vg=1.0
% INFO    : Gen at bus 1748	: Pg=326.8, Qg=60.91 -> Pg=266.665, Qg=54.12
% INFO    : Gen at bus 1748	: Vg=1.038042 -> Vg=1.0
% INFO    : Gen at bus 1754	: Pg=40.0, Qg=3.39 -> Pg=20.53, Qg=4.535
% INFO    : Gen at bus 1754	: Vg=1.037047 -> Vg=1.0
% INFO    : Gen at bus 1756	: Pg=178.8, Qg=74.32 -> Pg=133.335, Qg=26.055
% INFO    : Gen at bus 1756	: Vg=1.037533 -> Vg=1.0
% INFO    : Gen at bus 1776	: Pg=595.0, Qg=-773.19 -> Pg=312.375, Qg=0.0
% INFO    : Gen at bus 1776	: Vg=0.967759 -> Vg=1.0
% INFO    : Gen at bus 1785	: Pg=108.3, Qg=23.49 -> Pg=60.0, Qg=14.405
% INFO    : Gen at bus 1785	: Vg=0.998 -> Vg=1.0
% INFO    : Gen at bus 1786	: Pg=1124.0, Qg=-115.84 -> Pg=800.0, Qg=147.1
% INFO    : Gen at bus 1786	: Vg=1.083767 -> Vg=1.0
% INFO    : Gen at bus 1788	: Pg=430.2, Qg=245.8 -> Pg=400.0, Qg=88.665
% INFO    : Gen at bus 1788	: Vg=1.021039 -> Vg=1.0
% INFO    : Gen at bus 1793	: Pg=-90.3, Qg=1.11 -> Pg=-10.2, Qg=9.72
% INFO    : Gen at bus 1793	: Vg=1.020092 -> Vg=1.0
% INFO    : Gen at bus 1794	: Pg=1250.4, Qg=239.03 -> Pg=1333.335, Qg=314.335
% INFO    : Gen at bus 1794	: Vg=1.04708 -> Vg=1.0
% INFO    : Gen at bus 1797	: Pg=42.29, Qg=11.75 -> Pg=40.0, Qg=12.07
% INFO    : Gen at bus 1797	: Vg=1.005885 -> Vg=1.0
% INFO    : Gen at bus 1808	: Pg=-0.6, Qg=-6.0 -> Pg=49.6, Qg=36.535
% INFO    : Gen at bus 1808	: Vg=1.04521 -> Vg=1.0
% INFO    : Gen at bus 1812	: Pg=53.6, Qg=2.97 -> Pg=35.44, Qg=3.615
% INFO    : Gen at bus 1812	: Vg=1.03994 -> Vg=1.0
% INFO    : Gen at bus 1814	: Pg=311.46, Qg=58.05 -> Pg=266.665, Qg=51.655
% INFO    : Gen at bus 1814	: Vg=1.039354 -> Vg=1.0
% INFO    : Gen at bus 1819	: Pg=246.0, Qg=16.81 -> Pg=150.0, Qg=40.375
% INFO    : Gen at bus 1819	: Vg=1.039397 -> Vg=1.0
% INFO    : Gen at bus 1822	: Pg=658.2, Qg=29.36 -> Pg=533.335, Qg=110.79
% INFO    : Gen at bus 1822	: Vg=1.043084 -> Vg=1.0
% INFO    : Gen at bus 1823	: Pg=64.8, Qg=27.99 -> Pg=40.0, Qg=11.13
% INFO    : Gen at bus 1823	: Vg=1.020728 -> Vg=1.0
% INFO    : Gen at bus 1843	: Pg=29.17, Qg=-7.52 -> Pg=60.0, Qg=20.605
% INFO    : Gen at bus 1843	: Vg=1.080669 -> Vg=1.0
% INFO    : Gen at bus 1846	: Pg=117.6, Qg=-22.86 -> Pg=61.74, Qg=-10.9
% INFO    : Gen at bus 1846	: Vg=1.028122 -> Vg=1.0
% INFO    : Gen at bus 1847	: Pg=40.6, Qg=13.24 -> Pg=40.0, Qg=13.53
% INFO    : Gen at bus 1847	: Vg=1.002793 -> Vg=1.0
% INFO    : Gen at bus 1850	: Pg=2.89, Qg=-2.53 -> Pg=16.485, Qg=0.715
% INFO    : Gen at bus 1850	: Vg=1.014744 -> Vg=1.0
% INFO    : Gen at bus 1851	: Pg=15.6, Qg=0.08 -> Pg=15.96, Qg=1.435
% INFO    : Gen at bus 1851	: Vg=1.053982 -> Vg=1.0
% INFO    : Gen at bus 1852	: Pg=-241.8, Qg=16.53 -> Pg=-111.2, Qg=20.82
% INFO    : Gen at bus 1852	: Vg=1.054605 -> Vg=1.0
% INFO    : Gen at bus 1871	: Pg=-51.7, Qg=9.04 -> Pg=15.535, Qg=8.875
% INFO    : Gen at bus 1871	: Vg=1.000876 -> Vg=1.0
% INFO    : Gen at bus 1877	: Pg=99.0, Qg=-12.35 -> Pg=120.0, Qg=42.385
% INFO    : Gen at bus 1877	: Vg=1.050568 -> Vg=1.0
% INFO    : Gen at bus 1888	: Pg=573.68, Qg=36.11 -> Pg=612.78, Qg=120.095
% INFO    : Gen at bus 1888	: Vg=1.034904 -> Vg=1.0
% INFO    : Gen at bus 1890	: Pg=1526.0, Qg=133.56 -> Pg=1066.665, Qg=196.055
% INFO    : Gen at bus 1890	: Vg=1.04228 -> Vg=1.0
% INFO    : Gen at bus 1892	: Pg=-12.6, Qg=1.19 -> Pg=41.6, Qg=1.12
% INFO    : Gen at bus 1892	: Vg=1.020022 -> Vg=1.0
% INFO    : Gen at bus 1898	: Pg=246.0, Qg=-21.87 -> Pg=150.0, Qg=40.93
% INFO    : Gen at bus 1898	: Vg=1.074634 -> Vg=1.0
% INFO    : Gen at bus 1900	: Pg=478.2, Qg=-90.11 -> Pg=300.0, Qg=79.86
% INFO    : Gen at bus 1900	: Vg=1.077688 -> Vg=1.0
% INFO    : Gen at bus 1905	: Pg=313.1, Qg=108.79 -> Pg=400.0, Qg=99.485
% INFO    : Gen at bus 1905	: Vg=1.049117 -> Vg=1.0
% INFO    : Gen at bus 1907	: Pg=76.2, Qg=8.8 -> Pg=50.0, Qg=14.215
% INFO    : Gen at bus 1907	: Vg=1.038735 -> Vg=1.0
% INFO    : Gen at bus 1909	: Pg=-31.18, Qg=5.07 -> Pg=29.215, Qg=13.785
% INFO    : Gen at bus 1909	: Vg=1.019677 -> Vg=1.0
% INFO    : Gen at bus 1914	: Pg=115.5, Qg=-39.66 -> Pg=255.755, Qg=4.705
% INFO    : Gen at bus 1914	: Vg=1.038898 -> Vg=1.0
% INFO    : Gen at bus 1919	: Pg=411.8, Qg=63.9 -> Pg=400.0, Qg=90.555
% INFO    : Gen at bus 1919	: Vg=1.036866 -> Vg=1.0
% INFO    : Gen at bus 1925	: Pg=-184.0, Qg=-0.69 -> Pg=-72.665, Qg=0.215
% INFO    : Gen at bus 1925	: Vg=1.003974 -> Vg=1.0
% INFO    : Gen at bus 1927	: Pg=349.13, Qg=200.69 -> Pg=250.0, Qg=67.995
% INFO    : Gen at bus 1927	: Vg=1.0345 -> Vg=1.0
% INFO    : Gen at bus 1935	: Pg=-55.4, Qg=0.52 -> Pg=13.065, Qg=2.13
% INFO    : Gen at bus 1935	: Vg=1.014926 -> Vg=1.0
% INFO    : Gen at bus 1938	: Pg=506.1, Qg=-36.31 -> Pg=265.78, Qg=-82.74
% INFO    : Gen at bus 1938	: Vg=1.038487 -> Vg=1.0
% INFO    : Gen at bus 1947	: Pg=-17.02, Qg=-0.22 -> Pg=38.65, Qg=0.54
% INFO    : Gen at bus 1947	: Vg=1.053959 -> Vg=1.0
% INFO    : Gen at bus 1959	: Pg=31.0, Qg=3.11 -> Pg=20.0, Qg=5.695
% INFO    : Gen at bus 1959	: Vg=1.069553 -> Vg=1.0
% INFO    : Gen at bus 1970	: Pg=90.69, Qg=31.2 -> Pg=60.0, Qg=16.805
% INFO    : Gen at bus 1970	: Vg=1.026295 -> Vg=1.0
% INFO    : Gen at bus 1982	: Pg=-2.2, Qg=-5.28 -> Pg=48.535, Qg=-5.34
% INFO    : Gen at bus 1982	: Vg=1.008845 -> Vg=1.0
% INFO    : Gen at bus 1991	: Pg=44.0, Qg=7.99 -> Pg=30.0, Qg=8.765
% INFO    : Gen at bus 1991	: Vg=1.022737 -> Vg=1.0
% INFO    : Gen at bus 1999	: Pg=141.6, Qg=8.84 -> Pg=90.0, Qg=25.22
% INFO    : Gen at bus 1999	: Vg=1.076837 -> Vg=1.0
% INFO    : Gen at bus 2017	: Pg=216.0, Qg=92.42 -> Pg=333.335, Qg=86.445
% INFO    : Gen at bus 2017	: Vg=1.042851 -> Vg=1.0
% INFO    : Gen at bus 2018	: Pg=42.8, Qg=7.03 -> Pg=40.0, Qg=13.24
% INFO    : Gen at bus 2018	: Vg=1.00366 -> Vg=1.0
% INFO    : Gen at bus 2030	: Pg=576.0, Qg=148.48 -> Pg=400.0, Qg=73.075
% INFO    : Gen at bus 2030	: Vg=1.067534 -> Vg=1.0
% INFO    : Gen at bus 2035	: Pg=855.6, Qg=159.27 -> Pg=666.665, Qg=135.29
% INFO    : Gen at bus 2035	: Vg=1.028122 -> Vg=1.0
% INFO    : Gen at bus 2046	: Pg=234.0, Qg=6.2 -> Pg=150.0, Qg=41.615
% INFO    : Gen at bus 2046	: Vg=1.042366 -> Vg=1.0
% INFO    : Gen at bus 2050	: Pg=836.2, Qg=-52.53 -> Pg=1333.335, Qg=349.275
% INFO    : Gen at bus 2050	: Vg=1.004886 -> Vg=1.0
% INFO    : Gen at bus 2051	: Pg=71.0, Qg=-33.53 -> Pg=145.145, Qg=3.005
% INFO    : Gen at bus 2051	: Vg=1.047683 -> Vg=1.0
% INFO    : Gen at bus 2054	: Pg=1.8, Qg=-0.15 -> Pg=1.85, Qg=0.175
% INFO    : Gen at bus 2054	: Vg=1.055574 -> Vg=1.0
% INFO    : Gen at bus 2063	: Pg=47.6, Qg=-8.08 -> Pg=65.865, Qg=18.1
% INFO    : Gen at bus 2063	: Vg=1.027043 -> Vg=1.0
% INFO    : Gen at bus 2082	: Pg=-142.47, Qg=-2.35 -> Pg=-44.975, Qg=-1.52
% INFO    : Gen at bus 2082	: Vg=1.014544 -> Vg=1.0
% INFO    : Gen at bus 2085	: Pg=176.0, Qg=32.54 -> Pg=100.0, Qg=26.1
% INFO    : Gen at bus 2085	: Vg=1.029587 -> Vg=1.0
% INFO    : Gen at bus 2086	: Pg=64.2, Qg=14.61 -> Pg=40.0, Qg=11.4
% INFO    : Gen at bus 2086	: Vg=1.058532 -> Vg=1.0
% INFO    : Gen at bus 2091	: Pg=33.9, Qg=1.68 -> Pg=20.0, Qg=5.42
% INFO    : Gen at bus 2091	: Vg=1.02498 -> Vg=1.0
% INFO    : Gen at bus 2096	: Pg=1063.5, Qg=-188.42 -> Pg=800.0, Qg=155.185
% INFO    : Gen at bus 2096	: Vg=1.046008 -> Vg=1.0
% INFO    : Gen at bus 2098	: Pg=178.0, Qg=5.19 -> Pg=133.335, Qg=24.975
% INFO    : Gen at bus 2098	: Vg=1.064541 -> Vg=1.0
% INFO    : Gen at bus 2100	: Pg=152.1, Qg=-1.71 -> Pg=257.07, Qg=9.86
% INFO    : Gen at bus 2100	: Vg=1.022492 -> Vg=1.0
% INFO    : Gen at bus 2104	: Pg=-20.9, Qg=0.58 -> Pg=36.065, Qg=1.025
% INFO    : Gen at bus 2104	: Vg=1.005555 -> Vg=1.0
% INFO    : Gen at bus 2107	: Pg=1269.4, Qg=568.11 -> Pg=1000.0, Qg=202.14
% INFO    : Gen at bus 2107	: Vg=1.040878 -> Vg=1.0
% INFO    : Gen at bus 2113	: Pg=379.2, Qg=52.49 -> Pg=266.665, Qg=49.39
% INFO    : Gen at bus 2113	: Vg=1.151426 -> Vg=1.0
% INFO    : Gen at bus 2150	: Pg=498.4, Qg=91.07 -> Pg=400.0, Qg=82.335
% INFO    : Gen at bus 2150	: Vg=1.061614 -> Vg=1.0
% INFO    : Gen at bus 2153	: Pg=-496.6, Qg=16.51 -> Pg=-281.065, Qg=45.47
% INFO    : Gen at bus 2153	: Vg=1.065758 -> Vg=1.0
% INFO    : Gen at bus 2163	: Pg=33.09, Qg=0.38 -> Pg=20.0, Qg=4.76
% INFO    : Gen at bus 2163	: Vg=1.042967 -> Vg=1.0
% INFO    : Gen at bus 2167	: Pg=95.07, Qg=12.28 -> Pg=133.335, Qg=31.12
% INFO    : Gen at bus 2167	: Vg=1.027081 -> Vg=1.0
% INFO    : Gen at bus 2176	: Pg=1443.55, Qg=27.75 -> Pg=1900.0, Qg=13.26
% INFO    : Gen at bus 2176	: Vg=1.0196 -> Vg=1.0
% INFO    : Gen at bus 2177	: Pg=-121.3, Qg=15.15 -> Pg=-30.865, Qg=21.045
% INFO    : Gen at bus 2177	: Vg=1.068942 -> Vg=1.0
% INFO    : Gen at bus 2181	: Pg=502.2, Qg=-132.48 -> Pg=356.0, Qg=-37.925
% INFO    : Gen at bus 2181	: Vg=1.00154 -> Vg=1.0
% INFO    : Gen at bus 2185	: Pg=99.3, Qg=-5.75 -> Pg=60.0, Qg=16.555
% INFO    : Gen at bus 2185	: Vg=1.056295 -> Vg=1.0
% INFO    : Gen at bus 2187	: Pg=511.9, Qg=-56.25 -> Pg=600.0, Qg=129.965
% INFO    : Gen at bus 2187	: Vg=1.036364 -> Vg=1.0
% INFO    : Gen at bus 2193	: Pg=7.9, Qg=0.77 -> Pg=8.06, Qg=2.455
% INFO    : Gen at bus 2193	: Vg=1.009622 -> Vg=1.0
% INFO    : Gen at bus 2197	: Pg=-53.29, Qg=1.19 -> Pg=14.475, Qg=2.385
% INFO    : Gen at bus 2197	: Vg=1.031798 -> Vg=1.0
% INFO    : Gen at bus 2206	: Pg=204.3, Qg=26.26 -> Pg=200.0, Qg=45.355
% INFO    : Gen at bus 2206	: Vg=1.018916 -> Vg=1.0
% INFO    : Gen at bus 2207	: Pg=14.08, Qg=9.17 -> Pg=40.0, Qg=14.1
% INFO    : Gen at bus 2207	: Vg=1.006198 -> Vg=1.0
% INFO    : Gen at bus 2225	: Pg=-83.5, Qg=-0.44 -> Pg=-5.665, Qg=0.615
% INFO    : Gen at bus 2225	: Vg=1.025903 -> Vg=1.0
% INFO    : Gen at bus 2236	: Pg=-38.45, Qg=-0.25 -> Pg=24.37, Qg=0.58
% INFO    : Gen at bus 2236	: Vg=1.020813 -> Vg=1.0
% INFO    : Gen at bus 2237	: Pg=100.0, Qg=-9.31 -> Pg=100.0, Qg=33.54
% INFO    : Gen at bus 2237	: Vg=1.034951 -> Vg=1.0
% INFO    : Gen at bus 2241	: Pg=1170.0, Qg=-365.53 -> Pg=805.335, Qg=-175.96
% INFO    : Gen at bus 2241	: Vg=1.005014 -> Vg=1.0
% INFO    : Gen at bus 2243	: Pg=-30.6, Qg=0.11 -> Pg=29.6, Qg=1.305
% INFO    : Gen at bus 2243	: Vg=1.029391 -> Vg=1.0
% INFO    : Gen at bus 2245	: Pg=165.1, Qg=-63.63 -> Pg=104.235, Qg=-22.81
% INFO    : Gen at bus 2245	: Vg=1.010255 -> Vg=1.0
% INFO    : Gen at bus 2250	: Pg=-108.5, Qg=9.33 -> Pg=-22.335, Qg=7.625
% INFO    : Gen at bus 2250	: Vg=1.024801 -> Vg=1.0
% INFO    : Gen at bus 2253	: Pg=706.8, Qg=277.06 -> Pg=533.335, Qg=105.89
% INFO    : Gen at bus 2253	: Vg=1.147706 -> Vg=1.0
% INFO    : Gen at bus 2266	: Pg=190.0, Qg=-8.49 -> Pg=99.75, Qg=-14.155
% INFO    : Gen at bus 2266	: Vg=1.013425 -> Vg=1.0
% INFO    : Gen at bus 2267	: Pg=362.0, Qg=138.59 -> Pg=333.335, Qg=74.665
% INFO    : Gen at bus 2267	: Vg=1.003207 -> Vg=1.0
% INFO    : Gen at bus 2276	: Pg=38.9, Qg=-19.68 -> Pg=59.65, Qg=2.585
% INFO    : Gen at bus 2276	: Vg=1.062473 -> Vg=1.0
% INFO    : Gen at bus 2278	: Pg=140.0, Qg=-15.33 -> Pg=73.5, Qg=-16.65
% INFO    : Gen at bus 2278	: Vg=1.030091 -> Vg=1.0
% INFO    : Gen at bus 2284	: Pg=-59.5, Qg=6.01 -> Pg=10.335, Qg=13.565
% INFO    : Gen at bus 2284	: Vg=1.030581 -> Vg=1.0
% INFO    : Gen at bus 2287	: Pg=148.8, Qg=-3.23 -> Pg=84.0, Qg=-19.79
% INFO    : Gen at bus 2287	: Vg=1.034619 -> Vg=1.0
% INFO    : Gen at bus 2289	: Pg=36.9, Qg=-4.69 -> Pg=19.37, Qg=-2.41
% INFO    : Gen at bus 2289	: Vg=1.036649 -> Vg=1.0
% INFO    : Gen at bus 2291	: Pg=110.5, Qg=11.33 -> Pg=100.0, Qg=33.38
% INFO    : Gen at bus 2291	: Vg=1.063998 -> Vg=1.0
% INFO    : Gen at bus 2310	: Pg=164.5, Qg=2.75 -> Pg=200.0, Qg=49.51
% INFO    : Gen at bus 2310	: Vg=1.013414 -> Vg=1.0
% INFO    : Gen at bus 2320	: Pg=82.2, Qg=11.83 -> Pg=60.0, Qg=18.03
% INFO    : Gen at bus 2320	: Vg=1.025327 -> Vg=1.0
% INFO    : Gen at bus 2335	: Pg=431.2, Qg=215.21 -> Pg=400.0, Qg=89.695
% INFO    : Gen at bus 2335	: Vg=1.044074 -> Vg=1.0
% INFO    : Gen at bus 2351	: Pg=-35.89, Qg=6.16 -> Pg=26.07, Qg=16.685
% INFO    : Gen at bus 2351	: Vg=1.019563 -> Vg=1.0
% INFO    : Gen at bus 2353	: Pg=-113.5, Qg=-3.43 -> Pg=-25.665, Qg=-2.66
% INFO    : Gen at bus 2353	: Vg=1.010677 -> Vg=1.0
% INFO    : Gen at bus 2357	: Pg=-184.1, Qg=8.93 -> Pg=-72.735, Qg=13.42
% INFO    : Gen at bus 2357	: Vg=1.072612 -> Vg=1.0
% INFO    : Gen at bus 2359	: Pg=78.2, Qg=8.57 -> Pg=40.0, Qg=9.425
% INFO    : Gen at bus 2359	: Vg=1.021762 -> Vg=1.0
% INFO    : Gen at bus 2362	: Pg=662.2, Qg=-71.97 -> Pg=533.335, Qg=106.7
% INFO    : Gen at bus 2362	: Vg=1.038978 -> Vg=1.0
% INFO    : Gen at bus 2369	: Pg=129.4, Qg=-0.75 -> Pg=133.335, Qg=31.34
% INFO    : Gen at bus 2369	: Vg=1.055918 -> Vg=1.0
% INFO    : Gen at bus 2394	: Pg=200.3, Qg=150.64 -> Pg=300.0, Qg=135.115
% INFO    : Gen at bus 2394	: Vg=1.065017 -> Vg=1.0
% INFO    : Gen at bus 2398	: Pg=473.42, Qg=293.64 -> Pg=533.335, Qg=123.43
% INFO    : Gen at bus 2398	: Vg=1.147454 -> Vg=1.0
% INFO    : Gen at bus 2402	: Pg=179.5, Qg=26.25 -> Pg=100.0, Qg=26.32
% INFO    : Gen at bus 2402	: Vg=1.076661 -> Vg=1.0
% INFO    : Gen at bus 2412	: Pg=67.3, Qg=-95.99 -> Pg=204.545, Qg=-0.875
% INFO    : Gen at bus 2412	: Vg=1.013238 -> Vg=1.0
% INFO    : Gen at bus 2413	: Pg=51.3, Qg=80.69 -> Pg=100.0, Qg=29.375
% INFO    : Gen at bus 2413	: Vg=0.996424 -> Vg=1.0
% INFO    : Gen at bus 2421	: Pg=-320.4, Qg=12.79 -> Pg=-163.6, Qg=12.47
% INFO    : Gen at bus 2421	: Vg=1.043537 -> Vg=1.0
% INFO    : Gen at bus 2425	: Pg=-100.5, Qg=15.1 -> Pg=-17.0, Qg=16.905
% INFO    : Gen at bus 2425	: Vg=1.037815 -> Vg=1.0
% INFO    : Gen at bus 2426	: Pg=-43.2, Qg=-29.0 -> Pg=21.2, Qg=3.16
% INFO    : Gen at bus 2426	: Vg=1.045936 -> Vg=1.0
% INFO    : Gen at bus 2429	: Pg=370.6, Qg=193.25 -> Pg=333.335, Qg=60.725
% INFO    : Gen at bus 2429	: Vg=1.063143 -> Vg=1.0
% INFO    : Gen at bus 2446	: Pg=1367.0, Qg=257.39 -> Pg=1333.335, Qg=308.445
% INFO    : Gen at bus 2446	: Vg=1.048971 -> Vg=1.0
% INFO    : Gen at bus 2447	: Pg=-14.5, Qg=1.59 -> Pg=40.335, Qg=8.365
% INFO    : Gen at bus 2447	: Vg=1.031874 -> Vg=1.0
% INFO    : Gen at bus 2452	: Pg=103.0, Qg=-19.92 -> Pg=54.075, Qg=-7.18
% INFO    : Gen at bus 2452	: Vg=1.026174 -> Vg=1.0
% INFO    : Gen at bus 2460	: Pg=37.79, Qg=17.77 -> Pg=40.0, Qg=13.135
% INFO    : Gen at bus 2460	: Vg=0.979599 -> Vg=1.0
% INFO    : Gen at bus 2468	: Pg=46.8, Qg=5.87 -> Pg=40.0, Qg=13.105
% INFO    : Gen at bus 2468	: Vg=1.046839 -> Vg=1.0
% INFO    : Gen at bus 2481	: Pg=31.8, Qg=12.06 -> Pg=40.0, Qg=14.205
% INFO    : Gen at bus 2481	: Vg=1.045831 -> Vg=1.0
% INFO    : Gen at bus 2489	: Pg=286.5, Qg=-19.35 -> Pg=180.0, Qg=50.305
% INFO    : Gen at bus 2489	: Vg=1.046032 -> Vg=1.0
% INFO    : Gen at bus 2501	: Pg=76.8, Qg=7.72 -> Pg=40.0, Qg=9.635
% INFO    : Gen at bus 2501	: Vg=1.044679 -> Vg=1.0
% INFO    : Gen at bus 2509	: Pg=-92.5, Qg=5.49 -> Pg=-11.665, Qg=13.55
% INFO    : Gen at bus 2509	: Vg=1.025789 -> Vg=1.0
% INFO    : Gen at bus 2515	: Pg=27.7, Qg=6.44 -> Pg=20.0, Qg=5.995
% INFO    : Gen at bus 2515	: Vg=0.998497 -> Vg=1.0
% INFO    : Gen at bus 2517	: Pg=3.85, Qg=-9.83 -> Pg=117.26, Qg=0.53
% INFO    : Gen at bus 2517	: Vg=1.013559 -> Vg=1.0
% INFO    : Gen at bus 2519	: Pg=-48.0, Qg=5.16 -> Pg=18.0, Qg=8.845
% INFO    : Gen at bus 2519	: Vg=1.028396 -> Vg=1.0
% INFO    : Gen at bus 2534	: Pg=179.0, Qg=27.06 -> Pg=133.335, Qg=24.95
% INFO    : Gen at bus 2534	: Vg=1.066932 -> Vg=1.0
% INFO    : Gen at bus 2539	: Pg=-122.4, Qg=9.3 -> Pg=-31.6, Qg=7.545
% INFO    : Gen at bus 2539	: Vg=1.024702 -> Vg=1.0
% INFO    : Gen at bus 2541	: Pg=123.2, Qg=3.39 -> Pg=80.0, Qg=23.45
% INFO    : Gen at bus 2541	: Vg=1.02273 -> Vg=1.0
% INFO    : Gen at bus 2547	: Pg=-16.7, Qg=-0.07 -> Pg=38.865, Qg=0.14
% INFO    : Gen at bus 2547	: Vg=1.014326 -> Vg=1.0
% INFO    : Gen at bus 2550	: Pg=54.3, Qg=5.24 -> Pg=60.0, Qg=20.87
% INFO    : Gen at bus 2550	: Vg=1.047876 -> Vg=1.0
% INFO    : Gen at bus 2568	: Pg=80.91, Qg=61.89 -> Pg=100.0, Qg=28.865
% INFO    : Gen at bus 2568	: Vg=1.020248 -> Vg=1.0
% INFO    : Gen at bus 2569	: Pg=-17.85, Qg=3.12 -> Pg=38.1, Qg=6.415
% INFO    : Gen at bus 2569	: Vg=1.027206 -> Vg=1.0
% INFO    : Gen at bus 2572	: Pg=411.2, Qg=80.78 -> Pg=400.0, Qg=92.28
% INFO    : Gen at bus 2572	: Vg=1.044176 -> Vg=1.0
% INFO    : Gen at bus 2588	: Pg=-196.1, Qg=3.0 -> Pg=-80.735, Qg=4.61
% INFO    : Gen at bus 2588	: Vg=1.028186 -> Vg=1.0
% INFO    : Gen at bus 2589	: Pg=567.0, Qg=-54.77 -> Pg=400.0, Qg=67.235
% INFO    : Gen at bus 2589	: Vg=1.02499 -> Vg=1.0
% INFO    : Gen at bus 2594	: Pg=127.2, Qg=2.04 -> Pg=90.0, Qg=26.555
% INFO    : Gen at bus 2594	: Vg=1.058099 -> Vg=1.0
% INFO    : Gen at bus 2595	: Pg=994.2, Qg=511.43 -> Pg=800.0, Qg=165.9
% INFO    : Gen at bus 2595	: Vg=1.073729 -> Vg=1.0
% INFO    : Gen at bus 2600	: Pg=76.48, Qg=16.03 -> Pg=80.0, Qg=26.245
% INFO    : Gen at bus 2600	: Vg=1.047035 -> Vg=1.0
% INFO    : Gen at bus 2604	: Pg=-196.5, Qg=6.1 -> Pg=-81.0, Qg=4.705
% INFO    : Gen at bus 2604	: Vg=1.031949 -> Vg=1.0
% INFO    : Gen at bus 2606	: Pg=291.9, Qg=110.24 -> Pg=150.0, Qg=35.895
% INFO    : Gen at bus 2606	: Vg=1.041601 -> Vg=1.0
% INFO    : Gen at bus 2620	: Pg=201.0, Qg=38.52 -> Pg=120.0, Qg=32.85
% INFO    : Gen at bus 2620	: Vg=1.030287 -> Vg=1.0
% INFO    : Gen at bus 2624	: Pg=53.4, Qg=21.86 -> Pg=60.0, Qg=20.915
% INFO    : Gen at bus 2624	: Vg=1.037675 -> Vg=1.0
% INFO    : Gen at bus 2627	: Pg=1367.0, Qg=260.89 -> Pg=1333.335, Qg=308.365
% INFO    : Gen at bus 2627	: Vg=1.048065 -> Vg=1.0
% INFO    : Gen at bus 2642	: Pg=1897.0, Qg=-225.17 -> Pg=1333.335, Qg=235.545
% INFO    : Gen at bus 2642	: Vg=1.052836 -> Vg=1.0
% INFO    : Gen at bus 2649	: Pg=156.9, Qg=17.66 -> Pg=200.0, Qg=49.865
% INFO    : Gen at bus 2649	: Vg=1.087006 -> Vg=1.0
% INFO    : Gen at bus 2650	: Pg=116.6, Qg=5.92 -> Pg=60.0, Qg=13.97
% INFO    : Gen at bus 2650	: Vg=1.036234 -> Vg=1.0
% INFO    : Gen at bus 2653	: Pg=41.92, Qg=11.13 -> Pg=60.0, Qg=14.57
% INFO    : Gen at bus 2653	: Vg=1.032593 -> Vg=1.0
% INFO    : Gen at bus 2658	: Pg=308.31, Qg=-16.39 -> Pg=450.0, Qg=32.645
% INFO    : Gen at bus 2658	: Vg=1.020867 -> Vg=1.0
% INFO    : Gen at bus 2660	: Pg=144.9, Qg=13.53 -> Pg=90.0, Qg=24.46
% INFO    : Gen at bus 2660	: Vg=1.011944 -> Vg=1.0
% INFO    : Gen at bus 2662	: Pg=-27.87, Qg=5.55 -> Pg=31.42, Qg=9.59
% INFO    : Gen at bus 2662	: Vg=1.014043 -> Vg=1.0
% INFO    : Gen at bus 2664	: Pg=371.59, Qg=162.21 -> Pg=266.665, Qg=49.085
% INFO    : Gen at bus 2664	: Vg=1.049614 -> Vg=1.0
% INFO    : Gen at bus 2685	: Pg=157.2, Qg=48.72 -> Pg=90.0, Qg=22.855
% INFO    : Gen at bus 2685	: Vg=1.010899 -> Vg=1.0
% INFO    : Gen at bus 2686	: Pg=-72.9, Qg=-40.28 -> Pg=1.4, Qg=-0.445
% INFO    : Gen at bus 2686	: Vg=1.016926 -> Vg=1.0
% INFO    : Gen at bus 2710	: Pg=768.7, Qg=279.5 -> Pg=806.665, Qg=211.385
% INFO    : Gen at bus 2710	: Vg=1.035068 -> Vg=1.0
% INFO    : Gen at bus 2719	: Pg=77.6, Qg=-19.13 -> Pg=98.36, Qg=6.025
% INFO    : Gen at bus 2719	: Vg=1.041789 -> Vg=1.0
% INFO    : Gen at bus 2725	: Pg=105.45, Qg=-10.6 -> Pg=80.0, Qg=19.435
% INFO    : Gen at bus 2725	: Vg=1.014934 -> Vg=1.0
% INFO    : Gen at bus 2729	: Pg=38.47, Qg=14.26 -> Pg=60.0, Qg=20.045
% INFO    : Gen at bus 2729	: Vg=1.050822 -> Vg=1.0
% INFO    : Gen at bus 2736	: Pg=204.3, Qg=-30.6 -> Pg=150.0, Qg=45.135
% INFO    : Gen at bus 2736	: Vg=1.032664 -> Vg=1.0
% INFO    : Gen at bus 2743	: Pg=69.2, Qg=5.17 -> Pg=40.0, Qg=10.66
% INFO    : Gen at bus 2743	: Vg=1.039467 -> Vg=1.0
% INFO    : Gen at bus 2758	: Pg=608.9, Qg=-54.79 -> Pg=1033.335, Qg=258.475
% INFO    : Gen at bus 2758	: Vg=1.050098 -> Vg=1.0
% INFO    : Gen at bus 2764	: Pg=575.4, Qg=-114.16 -> Pg=600.0, Qg=141.1
% INFO    : Gen at bus 2764	: Vg=1.045688 -> Vg=1.0
% INFO    : Gen at bus 2775	: Pg=660.0, Qg=37.02 -> Pg=496.0, Qg=101.225
% INFO    : Gen at bus 2775	: Vg=1.024728 -> Vg=1.0
% INFO    : Gen at bus 2786	: Pg=1221.2, Qg=413.65 -> Pg=1333.335, Qg=321.67
% INFO    : Gen at bus 2786	: Vg=1.078984 -> Vg=1.0
% INFO    : Gen at bus 2791	: Pg=-4.7, Qg=-0.61 -> Pg=46.865, Qg=-0.095
% INFO    : Gen at bus 2791	: Vg=1.015494 -> Vg=1.0
% INFO    : Gen at bus 2797	: Pg=-95.1, Qg=-2.35 -> Pg=-13.4, Qg=26.0
% INFO    : Gen at bus 2797	: Vg=1.041702 -> Vg=1.0
% INFO    : Gen at bus 2799	: Pg=66.8, Qg=0.9 -> Pg=80.0, Qg=28.125
% INFO    : Gen at bus 2799	: Vg=1.059752 -> Vg=1.0
% INFO    : Gen at bus 2800	: Pg=1048.2, Qg=-86.22 -> Pg=800.0, Qg=157.75
% INFO    : Gen at bus 2800	: Vg=1.02478 -> Vg=1.0
% INFO    : Gen at bus 2810	: Pg=283.5, Qg=-18.98 -> Pg=148.84, Qg=-28.18
% INFO    : Gen at bus 2810	: Vg=1.036015 -> Vg=1.0
% INFO    : Gen at bus 2816	: Pg=1250.4, Qg=281.83 -> Pg=1333.335, Qg=314.26
% INFO    : Gen at bus 2816	: Vg=1.049577 -> Vg=1.0
% INFO    : Gen at bus 2817	: Pg=71.8, Qg=6.19 -> Pg=40.0, Qg=9.93
% INFO    : Gen at bus 2817	: Vg=0.987457 -> Vg=1.0
% INFO    : Gen at bus 2822	: Pg=86.4, Qg=8.74 -> Pg=60.0, Qg=17.755
% INFO    : Gen at bus 2822	: Vg=1.020284 -> Vg=1.0
% INFO    : Gen at bus 2826	: Pg=160.0, Qg=-24.38 -> Pg=84.0, Qg=-18.26
% INFO    : Gen at bus 2826	: Vg=1.022551 -> Vg=1.0
% INFO    : Gen at bus 2835	: Pg=756.52, Qg=-21.62 -> Pg=800.0, Qg=183.14
% INFO    : Gen at bus 2835	: Vg=1.043216 -> Vg=1.0
% INFO    : Gen at bus 2839	: Pg=29.2, Qg=4.72 -> Pg=30.0, Qg=10.0
% INFO    : Gen at bus 2839	: Vg=1.03617 -> Vg=1.0
% INFO    : Gen at bus 2841	: Pg=80.7, Qg=-0.53 -> Pg=60.0, Qg=18.61
% INFO    : Gen at bus 2841	: Vg=1.080183 -> Vg=1.0
% INFO    : Gen at bus 2842	: Pg=31.6, Qg=5.81 -> Pg=20.0, Qg=5.725
% INFO    : Gen at bus 2842	: Vg=1.037135 -> Vg=1.0
% INFO    : Gen at bus 2852	: Pg=138.4, Qg=-21.04 -> Pg=100.0, Qg=29.925
% INFO    : Gen at bus 2852	: Vg=1.063812 -> Vg=1.0
% INFO    : Gen at bus 2853	: Pg=126.0, Qg=12.34 -> Pg=80.0, Qg=22.275
% INFO    : Gen at bus 2853	: Vg=0.998154 -> Vg=1.0
% INFO    : Gen at bus 2862	: Pg=-109.6, Qg=7.54 -> Pg=-23.065, Qg=13.025
% INFO    : Gen at bus 2862	: Vg=1.027949 -> Vg=1.0
% INFO    : Gen at bus 2867	: Pg=-120.1, Qg=-19.34 -> Pg=-30.065, Qg=8.58
% INFO    : Gen at bus 2867	: Vg=1.047385 -> Vg=1.0
% INFO    : Gen at bus 2872	: Pg=4.5, Qg=-0.7 -> Pg=4.525, Qg=0.385
% INFO    : Gen at bus 2872	: Vg=1.054344 -> Vg=1.0
% INFO    : Gen at bus 2874	: Pg=-144.07, Qg=-1.31 -> Pg=-46.05, Qg=0.7
% INFO    : Gen at bus 2874	: Vg=1.006921 -> Vg=1.0
% INFO    : Gen at bus 2878	: Pg=8.95, Qg=-11.02 -> Pg=107.43, Qg=2.12
% INFO    : Gen at bus 2878	: Vg=1.047923 -> Vg=1.0
% INFO    : Gen at bus 2881	: Pg=131.9, Qg=-17.39 -> Pg=93.49, Qg=27.665
% INFO    : Gen at bus 2881	: Vg=1.024879 -> Vg=1.0
% INFO    : Gen at bus 2886	: Pg=60.9, Qg=11.04 -> Pg=60.0, Qg=20.335
% INFO    : Gen at bus 2886	: Vg=1.057004 -> Vg=1.0
% INFO    : Gen at bus 2896	: Pg=-223.4, Qg=-0.12 -> Pg=-98.935, Qg=0.395
% INFO    : Gen at bus 2896	: Vg=1.009058 -> Vg=1.0
% INFO    : Gen at bus 2897	: Pg=99.6, Qg=-13.74 -> Pg=133.335, Qg=33.405
% INFO    : Gen at bus 2897	: Vg=1.079272 -> Vg=1.0
% INFO    : Gen at bus 2902	: Pg=20.9, Qg=2.79 -> Pg=20.0, Qg=6.735
% INFO    : Gen at bus 2902	: Vg=1.069 -> Vg=1.0
% INFO    : Gen at bus 2920	: Pg=658.5, Qg=201.52 -> Pg=800.0, Qg=196.625
% INFO    : Gen at bus 2920	: Vg=1.036969 -> Vg=1.0
% INFO    : Gen at bus 2923	: Pg=962.1, Qg=207.61 -> Pg=800.0, Qg=168.98
% INFO    : Gen at bus 2923	: Vg=1.040379 -> Vg=1.0
% INFO    : Gen at bus 2930	: Pg=53.2, Qg=5.05 -> Pg=40.0, Qg=12.35
% INFO    : Gen at bus 2930	: Vg=1.054065 -> Vg=1.0
% INFO    : Gen at bus 2934	: Pg=3.4, Qg=-0.64 -> Pg=3.415, Qg=0.3
% INFO    : Gen at bus 2934	: Vg=1.049297 -> Vg=1.0
% INFO    : Gen at bus 2942	: Pg=313.1, Qg=108.89 -> Pg=400.0, Qg=99.485
% INFO    : Gen at bus 2942	: Vg=1.049098 -> Vg=1.0
% INFO    : Gen at bus 2946	: Pg=-222.1, Qg=-0.41 -> Pg=-98.065, Qg=0.48
% INFO    : Gen at bus 2946	: Vg=1.012911 -> Vg=1.0
% INFO    : Gen at bus 2956	: Pg=362.8, Qg=80.52 -> Pg=266.665, Qg=49.89
% INFO    : Gen at bus 2956	: Vg=1.032523 -> Vg=1.0
% INFO    : Gen at bus 2973	: Pg=930.1, Qg=95.59 -> Pg=666.665, Qg=125.9
% INFO    : Gen at bus 2973	: Vg=1.088757 -> Vg=1.0
% INFO    : Gen at bus 2975	: Pg=-23.66, Qg=5.96 -> Pg=34.225, Qg=5.885
% INFO    : Gen at bus 2975	: Vg=1.03823 -> Vg=1.0
% INFO    : Gen at bus 2982	: Pg=79.4, Qg=17.7 -> Pg=40.0, Qg=9.13
% INFO    : Gen at bus 2982	: Vg=1.020472 -> Vg=1.0
% INFO    : Gen at bus 2985	: Pg=46.6, Qg=-71.83 -> Pg=246.675, Qg=25.895
% INFO    : Gen at bus 2985	: Vg=1.046452 -> Vg=1.0
% INFO    : Gen at bus 2987	: Pg=296.8, Qg=0.48 -> Pg=160.0, Qg=39.945
% INFO    : Gen at bus 2987	: Vg=1.060068 -> Vg=1.0
% INFO    : Gen at bus 2989	: Pg=-542.0, Qg=13.11 -> Pg=-311.335, Qg=17.87
% INFO    : Gen at bus 2989	: Vg=1.066576 -> Vg=1.0
% INFO    : Gen at bus 2992	: Pg=200.1, Qg=33.77 -> Pg=266.665, Qg=67.125
% INFO    : Gen at bus 2992	: Vg=1.104121 -> Vg=1.0
% INFO    : Gen at bus 2997	: Pg=2334.5, Qg=109.9 -> Pg=2133.335, Qg=453.315
% INFO    : Gen at bus 2997	: Vg=1.089588 -> Vg=1.0
% INFO    : Gen at bus 3002	: Pg=-18.0, Qg=-3.78 -> Pg=38.0, Qg=-2.44
% INFO    : Gen at bus 3002	: Vg=1.015981 -> Vg=1.0
% INFO    : Gen at bus 3003	: Pg=176.9, Qg=-24.23 -> Pg=250.0, Qg=125.405
% INFO    : Gen at bus 3003	: Vg=1.048371 -> Vg=1.0
% INFO    : Gen at bus 3009	: Pg=-103.0, Qg=9.04 -> Pg=-18.665, Qg=17.11
% INFO    : Gen at bus 3009	: Vg=1.016186 -> Vg=1.0
% INFO    : Gen at bus 3018	: Pg=162.5, Qg=-6.58 -> Pg=100.0, Qg=27.395
% INFO    : Gen at bus 3018	: Vg=1.049496 -> Vg=1.0
% INFO    : Gen at bus 3028	: Pg=855.7, Qg=156.32 -> Pg=666.665, Qg=135.29
% INFO    : Gen at bus 3028	: Vg=1.02789 -> Vg=1.0
% INFO    : Gen at bus 3029	: Pg=20.87, Qg=8.87 -> Pg=40.0, Qg=12.625
% INFO    : Gen at bus 3029	: Vg=1.011669 -> Vg=1.0
% INFO    : Gen at bus 3035	: Pg=676.2, Qg=339.33 -> Pg=800.0, Qg=196.85
% INFO    : Gen at bus 3035	: Vg=1.0405 -> Vg=1.0
% INFO    : Gen at bus 3038	: Pg=292.2, Qg=105.65 -> Pg=150.0, Qg=35.785
% INFO    : Gen at bus 3038	: Vg=1.041581 -> Vg=1.0
% INFO    : Gen at bus 3039	: Pg=-59.31, Qg=2.38 -> Pg=10.46, Qg=4.97
% INFO    : Gen at bus 3039	: Vg=1.027247 -> Vg=1.0
% INFO    : Gen at bus 3045	: Pg=-58.4, Qg=-2.78 -> Pg=11.065, Qg=-1.56
% INFO    : Gen at bus 3045	: Vg=1.015762 -> Vg=1.0
% INFO    : Gen at bus 3054	: Pg=210.4, Qg=123.15 -> Pg=266.665, Qg=45.305
% INFO    : Gen at bus 3054	: Vg=0.995142 -> Vg=1.0
% INFO    : Gen at bus 3064	: Pg=224.0, Qg=-37.31 -> Pg=256.0, Qg=-0.6
% INFO    : Gen at bus 3064	: Vg=1.022454 -> Vg=1.0
% INFO    : Gen at bus 3078	: Pg=340.5, Qg=79.13 -> Pg=333.335, Qg=75.065
% INFO    : Gen at bus 3078	: Vg=1.024108 -> Vg=1.0
% INFO    : Gen at bus 3084	: Pg=-82.33, Qg=0.43 -> Pg=-4.885, Qg=66.305
% INFO    : Gen at bus 3084	: Vg=1.042602 -> Vg=1.0
% INFO    : Gen at bus 3088	: Pg=203.4, Qg=18.79 -> Pg=120.0, Qg=32.235
% INFO    : Gen at bus 3088	: Vg=1.043452 -> Vg=1.0
% INFO    : Gen at bus 3090	: Pg=47.0, Qg=27.75 -> Pg=40.0, Qg=13.13
% INFO    : Gen at bus 3090	: Vg=1.003861 -> Vg=1.0
% INFO    : Gen at bus 3091	: Pg=31.4, Qg=-5.7 -> Pg=16.515, Qg=-5.13
% INFO    : Gen at bus 3091	: Vg=1.021666 -> Vg=1.0
% INFO    : Gen at bus 3096	: Pg=-59.3, Qg=-7.67 -> Pg=10.465, Qg=-7.755
% INFO    : Gen at bus 3096	: Vg=1.008864 -> Vg=1.0
% INFO    : Gen at bus 3113	: Pg=-20.3, Qg=-8.58 -> Pg=36.465, Qg=0.7
% INFO    : Gen at bus 3113	: Vg=1.064513 -> Vg=1.0
% INFO    : Gen at bus 3114	: Pg=38.6, Qg=3.07 -> Pg=20.0, Qg=4.86
% INFO    : Gen at bus 3114	: Vg=1.063117 -> Vg=1.0
% INFO    : Gen at bus 3127	: Pg=580.7, Qg=-110.71 -> Pg=400.0, Qg=66.65
% INFO    : Gen at bus 3127	: Vg=1.097365 -> Vg=1.0
% INFO    : Gen at bus 3130	: Pg=357.4, Qg=-13.9 -> Pg=400.0, Qg=94.845
% INFO    : Gen at bus 3130	: Vg=1.038694 -> Vg=1.0
% INFO    : Gen at bus 3133	: Pg=85.54, Qg=0.61 -> Pg=120.0, Qg=39.205
% INFO    : Gen at bus 3133	: Vg=1.05743 -> Vg=1.0
% INFO    : Gen at bus 3134	: Pg=-136.3, Qg=2.44 -> Pg=-40.865, Qg=20.46
% INFO    : Gen at bus 3134	: Vg=1.034426 -> Vg=1.0
% INFO    : Gen at bus 3135	: Pg=54.6, Qg=6.61 -> Pg=99.04, Qg=29.29
% INFO    : Gen at bus 3135	: Vg=1.03216 -> Vg=1.0
% INFO    : Gen at bus 3147	: Pg=84.2, Qg=8.22 -> Pg=128.065, Qg=64.795
% INFO    : Gen at bus 3147	: Vg=1.063849 -> Vg=1.0
% INFO    : Gen at bus 3150	: Pg=-31.34, Qg=-0.52 -> Pg=29.105, Qg=0.78
% INFO    : Gen at bus 3150	: Vg=1.010317 -> Vg=1.0
% INFO    : Gen at bus 3152	: Pg=94.5, Qg=12.28 -> Pg=60.0, Qg=17.275
% INFO    : Gen at bus 3152	: Vg=1.069675 -> Vg=1.0
% INFO    : Gen at bus 3156	: Pg=-63.2, Qg=-7.96 -> Pg=7.865, Qg=-5.425
% INFO    : Gen at bus 3156	: Vg=1.024848 -> Vg=1.0
% INFO    : Gen at bus 3157	: Pg=9.0, Qg=-1.18 -> Pg=9.205, Qg=0.825
% INFO    : Gen at bus 3157	: Vg=1.021742 -> Vg=1.0
% INFO    : Gen at bus 3158	: Pg=-23.7, Qg=-25.2 -> Pg=34.2, Qg=47.155
% INFO    : Gen at bus 3158	: Vg=1.058123 -> Vg=1.0
% INFO    : Gen at bus 3163	: Pg=33.9, Qg=-26.5 -> Pg=103.43, Qg=-0.55
% INFO    : Gen at bus 3163	: Vg=1.002654 -> Vg=1.0
% INFO    : Gen at bus 3183	: Pg=98.7, Qg=-1.06 -> Pg=60.0, Qg=16.36
% INFO    : Gen at bus 3183	: Vg=1.061538 -> Vg=1.0
% INFO    : Gen at bus 3189	: Pg=77.1, Qg=-3.53 -> Pg=50.0, Qg=14.05
% INFO    : Gen at bus 3189	: Vg=1.027406 -> Vg=1.0
% INFO    : Gen at bus 3198	: Pg=144.0, Qg=59.93 -> Pg=120.0, Qg=38.845
% INFO    : Gen at bus 3198	: Vg=1.008016 -> Vg=1.0
% INFO    : Gen at bus 3205	: Pg=416.7, Qg=74.13 -> Pg=270.0, Qg=77.575
% INFO    : Gen at bus 3205	: Vg=1.043987 -> Vg=1.0
% INFO    : Gen at bus 3218	: Pg=-107.4, Qg=7.74 -> Pg=-21.6, Qg=11.895
% INFO    : Gen at bus 3218	: Vg=1.02981 -> Vg=1.0
% INFO    : Gen at bus 3219	: Pg=-36.5, Qg=-22.62 -> Pg=25.665, Qg=57.96
% INFO    : Gen at bus 3219	: Vg=1.06035 -> Vg=1.0
% INFO    : Gen at bus 3227	: Pg=360.0, Qg=3.76 -> Pg=266.665, Qg=51.2
% INFO    : Gen at bus 3227	: Vg=1.051132 -> Vg=1.0
% INFO    : Gen at bus 3229	: Pg=323.2, Qg=44.1 -> Pg=266.665, Qg=54.975
% INFO    : Gen at bus 3229	: Vg=1.034116 -> Vg=1.0
% INFO    : Gen at bus 3233	: Pg=13.0, Qg=6.69 -> Pg=210.0, Qg=49.68
% INFO    : Gen at bus 3233	: Vg=1.006814 -> Vg=1.0
% INFO    : Gen at bus 3234	: Pg=108.24, Qg=19.49 -> Pg=60.0, Qg=19.305
% INFO    : Gen at bus 3234	: Vg=1.034756 -> Vg=1.0
% INFO    : Gen at bus 3236	: Pg=359.3, Qg=64.06 -> Pg=266.665, Qg=51.27
% INFO    : Gen at bus 3236	: Vg=1.022886 -> Vg=1.0
% INFO    : Gen at bus 3240	: Pg=-42.3, Qg=-21.97 -> Pg=21.8, Qg=5.43
% INFO    : Gen at bus 3240	: Vg=1.048993 -> Vg=1.0
% INFO    : Gen at bus 3251	: Pg=285.6, Qg=104.22 -> Pg=533.335, Qg=133.365
% INFO    : Gen at bus 3251	: Vg=1.085025 -> Vg=1.0
% INFO    : Gen at bus 3253	: Pg=123.1, Qg=-16.44 -> Pg=64.625, Qg=-4.13
% INFO    : Gen at bus 3253	: Vg=1.024777 -> Vg=1.0
% INFO    : Gen at bus 3263	: Pg=30.39, Qg=2.91 -> Pg=40.0, Qg=13.725
% INFO    : Gen at bus 3263	: Vg=1.036588 -> Vg=1.0
% INFO    : Gen at bus 3264	: Pg=37.8, Qg=12.1 -> Pg=22.5, Qg=4.9
% INFO    : Gen at bus 3264	: Vg=1.039352 -> Vg=1.0
% INFO    : Gen at bus 3278	: Pg=46.73, Qg=21.66 -> Pg=60.0, Qg=14.895
% INFO    : Gen at bus 3278	: Vg=1.024557 -> Vg=1.0
% INFO    : Gen at bus 3284	: Pg=130.2, Qg=34.9 -> Pg=90.0, Qg=26.655
% INFO    : Gen at bus 3284	: Vg=1.031123 -> Vg=1.0
% INFO    : Gen at bus 3285	: Pg=654.8, Qg=92.94 -> Pg=533.335, Qg=111.175
% INFO    : Gen at bus 3285	: Vg=1.04544 -> Vg=1.0
% INFO    : Gen at bus 3290	: Pg=176.7, Qg=15.21 -> Pg=90.0, Qg=21.17
% INFO    : Gen at bus 3290	: Vg=1.076876 -> Vg=1.0
% INFO    : Gen at bus 3291	: Pg=326.4, Qg=-20.22 -> Pg=333.335, Qg=75.99
% INFO    : Gen at bus 3291	: Vg=1.020441 -> Vg=1.0
% INFO    : Gen at bus 3292	: Pg=309.0, Qg=-101.33 -> Pg=213.335, Qg=-33.72
% INFO    : Gen at bus 3292	: Vg=0.995766 -> Vg=1.0
% INFO    : Gen at bus 3298	: Pg=206.48, Qg=-21.12 -> Pg=120.0, Qg=28.845
% INFO    : Gen at bus 3298	: Vg=1.06827 -> Vg=1.0
% INFO    : Gen at bus 3304	: Pg=334.5, Qg=-47.86 -> Pg=276.0, Qg=-45.42
% INFO    : Gen at bus 3304	: Vg=1.024949 -> Vg=1.0
% INFO    : Gen at bus 3306	: Pg=861.3, Qg=141.54 -> Pg=666.665, Qg=132.885
% INFO    : Gen at bus 3306	: Vg=1.065504 -> Vg=1.0
% INFO    : Gen at bus 3310	: Pg=29.8, Qg=-1.53 -> Pg=30.53, Qg=2.82
% INFO    : Gen at bus 3310	: Vg=1.032355 -> Vg=1.0
% INFO    : Gen at bus 3322	: Pg=-25.59, Qg=9.63 -> Pg=32.94, Qg=16.3
% INFO    : Gen at bus 3322	: Vg=1.029763 -> Vg=1.0
% INFO    : Gen at bus 3323	: Pg=-12.51, Qg=-2.29 -> Pg=41.66, Qg=-1.55
% INFO    : Gen at bus 3323	: Vg=1.021399 -> Vg=1.0
% INFO    : Gen at bus 3324	: Pg=-26.48, Qg=15.21 -> Pg=32.35, Qg=13.245
% INFO    : Gen at bus 3324	: Vg=1.012342 -> Vg=1.0
% INFO    : Gen at bus 3326	: Pg=441.18, Qg=1.6 -> Pg=800.0, Qg=196.985
% INFO    : Gen at bus 3326	: Vg=1.057931 -> Vg=1.0
% INFO    : Gen at bus 3330	: Pg=44.12, Qg=6.53 -> Pg=100.0, Qg=32.125
% INFO    : Gen at bus 3330	: Vg=1.049026 -> Vg=1.0
% INFO    : Gen at bus 3334	: Pg=-45.5, Qg=2.75 -> Pg=19.665, Qg=9.535
% INFO    : Gen at bus 3334	: Vg=1.027102 -> Vg=1.0
% INFO    : Gen at bus 3335	: Pg=-600.0, Qg=1825.38 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 3335	: Vg=1.08064 -> Vg=1.0
% INFO    : Gen at bus 3336	: Pg=-42.3, Qg=-0.32 -> Pg=21.8, Qg=0.36
% INFO    : Gen at bus 3336	: Vg=1.010354 -> Vg=1.0
% INFO    : Gen at bus 3340	: Pg=-287.7, Qg=16.95 -> Pg=-141.8, Qg=17.595
% INFO    : Gen at bus 3340	: Vg=1.027329 -> Vg=1.0
% INFO    : Gen at bus 3345	: Pg=-111.9, Qg=-1.83 -> Pg=-24.6, Qg=-4.16
% INFO    : Gen at bus 3345	: Vg=0.998722 -> Vg=1.0
% INFO    : Gen at bus 3346	: Pg=56.8, Qg=11.85 -> Pg=40.0, Qg=12.17
% INFO    : Gen at bus 3346	: Vg=1.014446 -> Vg=1.0
% INFO    : Gen at bus 3349	: Pg=136.8, Qg=11.71 -> Pg=100.0, Qg=30.185
% INFO    : Gen at bus 3349	: Vg=1.047992 -> Vg=1.0
% INFO    : Gen at bus 3353	: Pg=19.07, Qg=6.86 -> Pg=40.0, Qg=13.295
% INFO    : Gen at bus 3353	: Vg=1.045086 -> Vg=1.0
% INFO    : Gen at bus 3362	: Pg=59.2, Qg=13.88 -> Pg=40.0, Qg=11.9
% INFO    : Gen at bus 3362	: Vg=1.060735 -> Vg=1.0
% INFO    : Gen at bus 3364	: Pg=44.5, Qg=-19.63 -> Pg=67.635, Qg=2.875
% INFO    : Gen at bus 3364	: Vg=1.059596 -> Vg=1.0
% INFO    : Gen at bus 3371	: Pg=61.8, Qg=8.32 -> Pg=40.0, Qg=11.42
% INFO    : Gen at bus 3371	: Vg=1.029674 -> Vg=1.0
% INFO    : Gen at bus 3375	: Pg=25.6, Qg=-9.24 -> Pg=58.535, Qg=53.045
% INFO    : Gen at bus 3375	: Vg=1.035048 -> Vg=1.0
% INFO    : Gen at bus 3389	: Pg=78.6, Qg=6.14 -> Pg=60.0, Qg=18.955
% INFO    : Gen at bus 3389	: Vg=1.037252 -> Vg=1.0
% INFO    : Gen at bus 3390	: Pg=2.4, Qg=18.47 -> Pg=60.0, Qg=17.2
% INFO    : Gen at bus 3390	: Vg=1.035344 -> Vg=1.0
% INFO    : Gen at bus 3396	: Pg=249.1, Qg=-44.22 -> Pg=150.0, Qg=39.855
% INFO    : Gen at bus 3396	: Vg=1.095689 -> Vg=1.0
% INFO    : Gen at bus 3411	: Pg=-123.7, Qg=8.93 -> Pg=-32.465, Qg=7.155
% INFO    : Gen at bus 3411	: Vg=1.024699 -> Vg=1.0
% INFO    : Gen at bus 3416	: Pg=171.3, Qg=38.36 -> Pg=90.0, Qg=21.155
% INFO    : Gen at bus 3416	: Vg=0.99364 -> Vg=1.0
% INFO    : Gen at bus 3422	: Pg=53.7, Qg=1.18 -> Pg=60.0, Qg=20.845
% INFO    : Gen at bus 3422	: Vg=1.068276 -> Vg=1.0
% INFO    : Gen at bus 3426	: Pg=70.0, Qg=-8.13 -> Pg=36.71, Qg=-6.125
% INFO    : Gen at bus 3426	: Vg=1.01782 -> Vg=1.0
% INFO    : Gen at bus 3431	: Pg=127.6, Qg=7.58 -> Pg=100.0, Qg=31.0
% INFO    : Gen at bus 3431	: Vg=1.037857 -> Vg=1.0
% INFO    : Gen at bus 3436	: Pg=521.0, Qg=242.21 -> Pg=800.0, Qg=183.04
% INFO    : Gen at bus 3436	: Vg=1.052704 -> Vg=1.0
% INFO    : Gen at bus 3438	: Pg=-87.5, Qg=7.68 -> Pg=-8.335, Qg=12.49
% INFO    : Gen at bus 3438	: Vg=1.048328 -> Vg=1.0
% INFO    : Gen at bus 3441	: Pg=159.2, Qg=-12.64 -> Pg=133.335, Qg=28.085
% INFO    : Gen at bus 3441	: Vg=1.059719 -> Vg=1.0
% INFO    : Gen at bus 3480	: Pg=239.6, Qg=-31.21 -> Pg=266.665, Qg=62.82
% INFO    : Gen at bus 3480	: Vg=1.039565 -> Vg=1.0
% INFO    : Gen at bus 3492	: Pg=-370.8, Qg=7.94 -> Pg=-197.2, Qg=16.335
% INFO    : Gen at bus 3492	: Vg=1.049517 -> Vg=1.0
% INFO    : Gen at bus 3507	: Pg=109.8, Qg=17.58 -> Pg=60.0, Qg=14.725
% INFO    : Gen at bus 3507	: Vg=1.009668 -> Vg=1.0
% INFO    : Gen at bus 3508	: Pg=96.9, Qg=3.27 -> Pg=60.0, Qg=16.725
% INFO    : Gen at bus 3508	: Vg=1.05417 -> Vg=1.0
% INFO    : Gen at bus 3511	: Pg=522.8, Qg=-5.35 -> Pg=533.335, Qg=122.145
% INFO    : Gen at bus 3511	: Vg=1.086282 -> Vg=1.0
% INFO    : Gen at bus 3513	: Pg=829.8, Qg=50.36 -> Pg=600.0, Qg=112.24
% INFO    : Gen at bus 3513	: Vg=1.027289 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=-85.4, Qg=9.97 -> Pg=-6.935, Qg=13.66
% INFO    : Gen at bus 3515	: Vg=1.053923 -> Vg=1.0
% INFO    : Gen at bus 3518	: Pg=808.66, Qg=-125.32 -> Pg=666.665, Qg=127.965
% INFO    : Gen at bus 3518	: Vg=1.006674 -> Vg=1.0
% INFO    : Gen at bus 3547	: Pg=140.0, Qg=10.96 -> Pg=133.335, Qg=29.78
% INFO    : Gen at bus 3547	: Vg=1.05946 -> Vg=1.0
% INFO    : Gen at bus 3550	: Pg=341.1, Qg=59.49 -> Pg=180.0, Qg=44.875
% INFO    : Gen at bus 3550	: Vg=1.042925 -> Vg=1.0
% INFO    : Gen at bus 3551	: Pg=-37.1, Qg=-18.62 -> Pg=25.265, Qg=52.875
% INFO    : Gen at bus 3551	: Vg=1.039557 -> Vg=1.0
% INFO    : Gen at bus 3565	: Pg=15.88, Qg=4.48 -> Pg=40.0, Qg=13.93
% INFO    : Gen at bus 3565	: Vg=1.079183 -> Vg=1.0
% INFO    : Gen at bus 3570	: Pg=298.9, Qg=81.81 -> Pg=200.0, Qg=32.47
% INFO    : Gen at bus 3570	: Vg=1.062522 -> Vg=1.0
% INFO    : Gen at bus 3571	: Pg=233.6, Qg=56.61 -> Pg=120.0, Qg=27.24
% INFO    : Gen at bus 3571	: Vg=0.997978 -> Vg=1.0
% INFO    : Gen at bus 3580	: Pg=539.0, Qg=182.86 -> Pg=300.0, Qg=77.17
% INFO    : Gen at bus 3580	: Vg=1.071709 -> Vg=1.0
% INFO    : Gen at bus 3582	: Pg=-321.8, Qg=-33.51 -> Pg=-164.535, Qg=0.395
% INFO    : Gen at bus 3582	: Vg=1.040375 -> Vg=1.0
% INFO    : Gen at bus 3583	: Pg=36.3, Qg=8.71 -> Pg=20.0, Qg=5.225
% INFO    : Gen at bus 3583	: Vg=1.041006 -> Vg=1.0
% INFO    : Gen at bus 3584	: Pg=-88.4, Qg=-1.89 -> Pg=-8.935, Qg=2.34
% INFO    : Gen at bus 3584	: Vg=1.016191 -> Vg=1.0
% INFO    : Gen at bus 3585	: Pg=50.8, Qg=17.16 -> Pg=40.0, Qg=12.555
% INFO    : Gen at bus 3585	: Vg=1.001933 -> Vg=1.0
% INFO    : Gen at bus 3590	: Pg=-31.0, Qg=0.35 -> Pg=29.335, Qg=0.705
% INFO    : Gen at bus 3590	: Vg=1.014988 -> Vg=1.0
% INFO    : Gen at bus 3599	: Pg=-85.6, Qg=7.19 -> Pg=-7.065, Qg=13.24
% INFO    : Gen at bus 3599	: Vg=1.035573 -> Vg=1.0
% INFO    : Gen at bus 3605	: Pg=158.7, Qg=-3.06 -> Pg=90.0, Qg=23.28
% INFO    : Gen at bus 3605	: Vg=1.037656 -> Vg=1.0
% INFO    : Gen at bus 3611	: Pg=-125.4, Qg=13.66 -> Pg=-33.6, Qg=17.235
% INFO    : Gen at bus 3611	: Vg=1.0427 -> Vg=1.0
% INFO    : Gen at bus 3618	: Pg=54.49, Qg=4.99 -> Pg=40.0, Qg=11.27
% INFO    : Gen at bus 3618	: Vg=1.059129 -> Vg=1.0
% INFO    : Gen at bus 3621	: Pg=202.03, Qg=-30.52 -> Pg=150.0, Qg=37.985
% INFO    : Gen at bus 3621	: Vg=1.018584 -> Vg=1.0
% INFO    : Gen at bus 3625	: Pg=150.0, Qg=-21.2 -> Pg=78.75, Qg=-8.145
% INFO    : Gen at bus 3625	: Vg=1.035196 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=490.0, Qg=81.97 -> Pg=526.665, Qg=63.89
% INFO    : Gen at bus 3628	: Vg=1.011525 -> Vg=1.0
% INFO    : Gen at bus 3629	: Pg=54.97, Qg=2.84 -> Pg=80.0, Qg=27.105
% INFO    : Gen at bus 3629	: Vg=1.019084 -> Vg=1.0
% INFO    : Gen at bus 3634	: Pg=412.0, Qg=-42.4 -> Pg=333.335, Qg=64.62
% INFO    : Gen at bus 3634	: Vg=1.058312 -> Vg=1.0
% INFO    : Gen at bus 3635	: Pg=78.2, Qg=-13.76 -> Pg=41.055, Qg=-9.44
% INFO    : Gen at bus 3635	: Vg=1.027369 -> Vg=1.0
% INFO    : Gen at bus 3638	: Pg=214.1, Qg=-16.86 -> Pg=167.79, Qg=22.35
% INFO    : Gen at bus 3638	: Vg=1.027553 -> Vg=1.0
% INFO    : Gen at bus 3644	: Pg=16.4, Qg=-5.19 -> Pg=33.045, Qg=0.565
% INFO    : Gen at bus 3644	: Vg=1.01566 -> Vg=1.0
% INFO    : Gen at bus 3656	: Pg=-26.2, Qg=18.12 -> Pg=32.535, Qg=41.375
% INFO    : Gen at bus 3656	: Vg=1.062208 -> Vg=1.0
% INFO    : Gen at bus 3659	: Pg=1097.4, Qg=790.96 -> Pg=1333.335, Qg=330.815
% INFO    : Gen at bus 3659	: Vg=1.057396 -> Vg=1.0
% INFO    : Gen at bus 3660	: Pg=-128.54, Qg=-15.82 -> Pg=-35.69, Qg=-6.485
% INFO    : Gen at bus 3660	: Vg=1.032448 -> Vg=1.0
% INFO    : Gen at bus 3661	: Pg=861.2, Qg=134.9 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 3661	: Vg=1.055245 -> Vg=1.0
% INFO    : Gen at bus 3673	: Pg=424.5, Qg=-77.32 -> Pg=400.0, Qg=73.59
% INFO    : Gen at bus 3673	: Vg=1.011536 -> Vg=1.0
% INFO    : Gen at bus 3689	: Pg=5.2, Qg=-0.19 -> Pg=3.1, Qg=0.565
% INFO    : Gen at bus 3689	: Vg=1.029361 -> Vg=1.0
% INFO    : Gen at bus 3691	: Pg=239.6, Qg=48.56 -> Pg=200.0, Qg=41.975
% INFO    : Gen at bus 3691	: Vg=1.030004 -> Vg=1.0
% INFO    : Gen at bus 3692	: Pg=164.4, Qg=-45.72 -> Pg=210.0, Qg=51.135
% INFO    : Gen at bus 3692	: Vg=1.024383 -> Vg=1.0
% INFO    : Gen at bus 3696	: Pg=662.8, Qg=86.36 -> Pg=533.335, Qg=109.44
% INFO    : Gen at bus 3696	: Vg=1.041264 -> Vg=1.0
% INFO    : Gen at bus 3698	: Pg=-12.58, Qg=7.25 -> Pg=41.61, Qg=11.435
% INFO    : Gen at bus 3698	: Vg=1.039409 -> Vg=1.0
% INFO    : Gen at bus 3711	: Pg=40.4, Qg=13.02 -> Pg=40.0, Qg=13.49
% INFO    : Gen at bus 3711	: Vg=0.999169 -> Vg=1.0
% INFO    : Gen at bus 3720	: Pg=-75.4, Qg=4.94 -> Pg=-0.265, Qg=5.955
% INFO    : Gen at bus 3720	: Vg=1.050724 -> Vg=1.0
% INFO    : Gen at bus 3723	: Pg=1146.3, Qg=50.9 -> Pg=800.0, Qg=146.21
% INFO    : Gen at bus 3723	: Vg=1.048349 -> Vg=1.0
% INFO    : Gen at bus 3724	: Pg=94.9, Qg=28.33 -> Pg=50.0, Qg=12.235
% INFO    : Gen at bus 3724	: Vg=1.020045 -> Vg=1.0
% INFO    : Gen at bus 3739	: Pg=34.1, Qg=2.85 -> Pg=40.0, Qg=14.0
% INFO    : Gen at bus 3739	: Vg=1.035011 -> Vg=1.0
% INFO    : Gen at bus 3741	: Pg=854.7, Qg=211.29 -> Pg=800.0, Qg=180.705
% INFO    : Gen at bus 3741	: Vg=1.029075 -> Vg=1.0
% INFO    : Gen at bus 3743	: Pg=-41.48, Qg=5.47 -> Pg=22.345, Qg=9.99
% INFO    : Gen at bus 3743	: Vg=1.026432 -> Vg=1.0
% INFO    : Gen at bus 3746	: Pg=10.66, Qg=4.33 -> Pg=40.0, Qg=13.17
% INFO    : Gen at bus 3746	: Vg=1.035948 -> Vg=1.0
% INFO    : Gen at bus 3750	: Pg=169.92, Qg=90.72 -> Pg=160.0, Qg=48.16
% INFO    : Gen at bus 3750	: Vg=1.066155 -> Vg=1.0
% INFO    : Gen at bus 3753	: Pg=572.4, Qg=226.8 -> Pg=400.0, Qg=71.73
% INFO    : Gen at bus 3753	: Vg=1.055722 -> Vg=1.0
% INFO    : Gen at bus 3755	: Pg=-141.7, Qg=-0.77 -> Pg=-44.465, Qg=-5.2
% INFO    : Gen at bus 3755	: Vg=0.993935 -> Vg=1.0
% INFO    : Gen at bus 3759	: Pg=147.6, Qg=-17.08 -> Pg=100.0, Qg=29.02
% INFO    : Gen at bus 3759	: Vg=1.031969 -> Vg=1.0
% INFO    : Gen at bus 3766	: Pg=16.7, Qg=-5.93 -> Pg=33.39, Qg=-2.845
% INFO    : Gen at bus 3766	: Vg=1.0335 -> Vg=1.0
% INFO    : Gen at bus 3769	: Pg=162.4, Qg=22.12 -> Pg=120.0, Qg=36.61
% INFO    : Gen at bus 3769	: Vg=1.021894 -> Vg=1.0
% INFO    : Gen at bus 3782	: Pg=-126.9, Qg=6.37 -> Pg=-34.6, Qg=5.29
% INFO    : Gen at bus 3782	: Vg=1.02915 -> Vg=1.0
% INFO    : Gen at bus 3791	: Pg=90.6, Qg=18.83 -> Pg=60.0, Qg=17.365
% INFO    : Gen at bus 3791	: Vg=0.995335 -> Vg=1.0
% INFO    : Gen at bus 3792	: Pg=85.4, Qg=-23.53 -> Pg=120.0, Qg=33.405
% INFO    : Gen at bus 3792	: Vg=1.052349 -> Vg=1.0
% INFO    : Gen at bus 3797	: Pg=-204.2, Qg=11.12 -> Pg=-86.135, Qg=10.52
% INFO    : Gen at bus 3797	: Vg=1.060935 -> Vg=1.0
% INFO    : Gen at bus 3800	: Pg=71.9, Qg=-11.13 -> Pg=38.485, Qg=-6.53
% INFO    : Gen at bus 3800	: Vg=1.036528 -> Vg=1.0
% INFO    : Gen at bus 3808	: Pg=615.0, Qg=-57.36 -> Pg=666.665, Qg=160.45
% INFO    : Gen at bus 3808	: Vg=1.073884 -> Vg=1.0
% INFO    : Gen at bus 3809	: Pg=257.0, Qg=132.48 -> Pg=466.665, Qg=98.14
% INFO    : Gen at bus 3809	: Vg=1.081564 -> Vg=1.0
% INFO    : Gen at bus 3810	: Pg=89.6, Qg=-0.62 -> Pg=133.335, Qg=33.725
% INFO    : Gen at bus 3810	: Vg=1.038535 -> Vg=1.0
% INFO    : Gen at bus 3821	: Pg=292.0, Qg=-24.15 -> Pg=266.665, Qg=43.295
% INFO    : Gen at bus 3821	: Vg=1.022257 -> Vg=1.0
% INFO    : Gen at bus 3825	: Pg=837.3, Qg=55.38 -> Pg=600.0, Qg=112.385
% INFO    : Gen at bus 3825	: Vg=1.024468 -> Vg=1.0
% INFO    : Gen at bus 3840	: Pg=-22.95, Qg=-13.55 -> Pg=34.7, Qg=0.435
% INFO    : Gen at bus 3840	: Vg=1.027073 -> Vg=1.0
% INFO    : Gen at bus 3841	: Pg=143.4, Qg=-7.13 -> Pg=90.0, Qg=24.335
% INFO    : Gen at bus 3841	: Vg=1.03976 -> Vg=1.0
% INFO    : Gen at bus 3850	: Pg=239.6, Qg=-30.79 -> Pg=266.665, Qg=62.82
% INFO    : Gen at bus 3850	: Vg=1.039563 -> Vg=1.0
% INFO    : Gen at bus 3851	: Pg=-41.48, Qg=4.66 -> Pg=22.345, Qg=9.84
% INFO    : Gen at bus 3851	: Vg=1.022667 -> Vg=1.0
% INFO    : Gen at bus 3853	: Pg=287.0, Qg=-20.4 -> Pg=266.665, Qg=60.095
% INFO    : Gen at bus 3853	: Vg=1.080197 -> Vg=1.0
% INFO    : Gen at bus 3869	: Pg=855.6, Qg=159.36 -> Pg=666.665, Qg=134.275
% INFO    : Gen at bus 3869	: Vg=1.028967 -> Vg=1.0
% INFO    : Gen at bus 3870	: Pg=134.4, Qg=-19.43 -> Pg=77.28, Qg=-24.795
% INFO    : Gen at bus 3870	: Vg=1.023622 -> Vg=1.0
% INFO    : Gen at bus 3876	: Pg=-25.1, Qg=10.33 -> Pg=33.265, Qg=9.375
% INFO    : Gen at bus 3876	: Vg=1.04066 -> Vg=1.0
% INFO    : Gen at bus 3879	: Pg=140.69, Qg=-5.19 -> Pg=80.0, Qg=21.17
% INFO    : Gen at bus 3879	: Vg=1.042235 -> Vg=1.0
% INFO    : Gen at bus 3888	: Pg=70.2, Qg=11.45 -> Pg=60.0, Qg=19.5
% INFO    : Gen at bus 3888	: Vg=1.064956 -> Vg=1.0
% INFO    : Gen at bus 3900	: Pg=99.6, Qg=21.01 -> Pg=60.0, Qg=16.77
% INFO    : Gen at bus 3900	: Vg=1.061016 -> Vg=1.0
% INFO    : Gen at bus 3907	: Pg=319.6, Qg=9.5 -> Pg=240.0, Qg=21.145
% INFO    : Gen at bus 3907	: Vg=1.025805 -> Vg=1.0
% INFO    : Gen at bus 3908	: Pg=4.69, Qg=0.16 -> Pg=5.04, Qg=1.115
% INFO    : Gen at bus 3908	: Vg=0.982046 -> Vg=1.0
% INFO    : Gen at bus 3910	: Pg=362.0, Qg=149.08 -> Pg=266.665, Qg=51.22
% INFO    : Gen at bus 3910	: Vg=1.069291 -> Vg=1.0
% INFO    : Gen at bus 3916	: Pg=-21.27, Qg=14.73 -> Pg=35.815, Qg=13.125
% INFO    : Gen at bus 3916	: Vg=1.039177 -> Vg=1.0
% INFO    : Gen at bus 3920	: Pg=349.3, Qg=-8.65 -> Pg=266.665, Qg=52.9
% INFO    : Gen at bus 3920	: Vg=1.064621 -> Vg=1.0
% INFO    : Gen at bus 3922	: Pg=571.2, Qg=227.31 -> Pg=400.0, Qg=72.025
% INFO    : Gen at bus 3922	: Vg=1.07194 -> Vg=1.0
% INFO    : Gen at bus 3938	: Pg=-43.8, Qg=4.41 -> Pg=20.8, Qg=6.97
% INFO    : Gen at bus 3938	: Vg=1.049226 -> Vg=1.0
% INFO    : Gen at bus 3940	: Pg=660.6, Qg=-113.14 -> Pg=666.665, Qg=144.52
% INFO    : Gen at bus 3940	: Vg=1.018221 -> Vg=1.0
% INFO    : Gen at bus 3948	: Pg=-23.68, Qg=0.49 -> Pg=34.21, Qg=7.895
% INFO    : Gen at bus 3948	: Vg=1.03639 -> Vg=1.0
% INFO    : Gen at bus 3949	: Pg=124.0, Qg=19.51 -> Pg=100.0, Qg=31.885
% INFO    : Gen at bus 3949	: Vg=1.052164 -> Vg=1.0
% INFO    : Gen at bus 3951	: Pg=-27.1, Qg=-70.83 -> Pg=31.935, Qg=-0.7
% INFO    : Gen at bus 3951	: Vg=1.03485 -> Vg=1.0
% INFO    : Gen at bus 3958	: Pg=79.2, Qg=14.63 -> Pg=60.0, Qg=18.45
% INFO    : Gen at bus 3958	: Vg=1.034533 -> Vg=1.0
% INFO    : Gen at bus 3959	: Pg=56.4, Qg=-6.65 -> Pg=29.625, Qg=-4.29
% INFO    : Gen at bus 3959	: Vg=1.052799 -> Vg=1.0
% INFO    : Gen at bus 3963	: Pg=207.0, Qg=51.71 -> Pg=266.665, Qg=54.34
% INFO    : Gen at bus 3963	: Vg=1.020596 -> Vg=1.0
% INFO    : Gen at bus 3971	: Pg=-134.5, Qg=15.26 -> Pg=-39.665, Qg=18.29
% INFO    : Gen at bus 3971	: Vg=1.053061 -> Vg=1.0
% INFO    : Gen at bus 3979	: Pg=304.0, Qg=-4.57 -> Pg=159.6, Qg=-43.05
% INFO    : Gen at bus 3979	: Vg=1.027309 -> Vg=1.0
% INFO    : Gen at bus 3983	: Pg=229.9, Qg=24.94 -> Pg=200.0, Qg=43.115
% INFO    : Gen at bus 3983	: Vg=1.014828 -> Vg=1.0
% INFO    : Gen at bus 3987	: Pg=44.6, Qg=8.46 -> Pg=40.0, Qg=13.165
% INFO    : Gen at bus 3987	: Vg=1.019043 -> Vg=1.0
% INFO    : Gen at bus 3991	: Pg=-210.89, Qg=11.91 -> Pg=-90.595, Qg=12.705
% INFO    : Gen at bus 3991	: Vg=1.035055 -> Vg=1.0
% INFO    : Gen at bus 3996	: Pg=-121.2, Qg=4.16 -> Pg=-30.8, Qg=6.155
% INFO    : Gen at bus 3996	: Vg=1.034652 -> Vg=1.0
% INFO    : Gen at bus 4009	: Pg=66.47, Qg=10.91 -> Pg=60.0, Qg=17.54
% INFO    : Gen at bus 4009	: Vg=1.043192 -> Vg=1.0
% INFO    : Gen at bus 4012	: Pg=46.0, Qg=9.06 -> Pg=40.0, Qg=13.0
% INFO    : Gen at bus 4012	: Vg=1.04188 -> Vg=1.0
% INFO    : Gen at bus 4016	: Pg=109.2, Qg=-2.07 -> Pg=60.0, Qg=14.905
% INFO    : Gen at bus 4016	: Vg=1.022786 -> Vg=1.0
% INFO    : Gen at bus 4024	: Pg=89.5, Qg=41.31 -> Pg=100.0, Qg=34.815
% INFO    : Gen at bus 4024	: Vg=1.029565 -> Vg=1.0
% INFO    : Gen at bus 4026	: Pg=399.3, Qg=-27.46 -> Pg=333.335, Qg=69.685
% INFO    : Gen at bus 4026	: Vg=1.05562 -> Vg=1.0
% INFO    : Gen at bus 4028	: Pg=-63.7, Qg=4.77 -> Pg=7.53, Qg=5.965
% INFO    : Gen at bus 4028	: Vg=1.022221 -> Vg=1.0
% INFO    : Gen at bus 4046	: Pg=323.1, Qg=-15.89 -> Pg=266.665, Qg=56.055
% INFO    : Gen at bus 4046	: Vg=1.071125 -> Vg=1.0
% INFO    : Gen at bus 4052	: Pg=68.2, Qg=12.09 -> Pg=40.0, Qg=10.805
% INFO    : Gen at bus 4052	: Vg=1.059535 -> Vg=1.0
% INFO    : Gen at bus 4056	: Pg=-76.9, Qg=7.64 -> Pg=-1.265, Qg=13.14
% INFO    : Gen at bus 4056	: Vg=1.038451 -> Vg=1.0
% INFO    : Gen at bus 4071	: Pg=100.0, Qg=-10.38 -> Pg=52.5, Qg=-5.875
% INFO    : Gen at bus 4071	: Vg=1.026598 -> Vg=1.0
% INFO    : Gen at bus 4075	: Pg=79.6, Qg=12.92 -> Pg=60.0, Qg=18.365
% INFO    : Gen at bus 4075	: Vg=1.033829 -> Vg=1.0
% INFO    : Gen at bus 4076	: Pg=162.8, Qg=2.33 -> Pg=133.335, Qg=27.215
% INFO    : Gen at bus 4076	: Vg=1.042958 -> Vg=1.0
% INFO    : Gen at bus 4084	: Pg=366.1, Qg=44.03 -> Pg=300.0, Qg=80.6
% INFO    : Gen at bus 4084	: Vg=1.053107 -> Vg=1.0
% INFO    : Gen at bus 4085	: Pg=188.0, Qg=67.0 -> Pg=100.0, Qg=24.455
% INFO    : Gen at bus 4085	: Vg=1.028863 -> Vg=1.0
% INFO    : Gen at bus 4090	: Pg=-107.2, Qg=-11.0 -> Pg=-21.465, Qg=-10.09
% INFO    : Gen at bus 4090	: Vg=1.010258 -> Vg=1.0
% INFO    : Gen at bus 4094	: Pg=165.2, Qg=33.4 -> Pg=250.0, Qg=70.58
% INFO    : Gen at bus 4094	: Vg=1.026088 -> Vg=1.0
% INFO    : Gen at bus 4106	: Pg=57.0, Qg=-9.11 -> Pg=32.13, Qg=-3.01
% INFO    : Gen at bus 4106	: Vg=1.022601 -> Vg=1.0
% INFO    : Gen at bus 4118	: Pg=41.0, Qg=6.87 -> Pg=40.0, Qg=13.485
% INFO    : Gen at bus 4118	: Vg=1.025736 -> Vg=1.0
% INFO    : Gen at bus 4122	: Pg=216.0, Qg=-30.79 -> Pg=150.0, Qg=42.51
% INFO    : Gen at bus 4122	: Vg=1.016568 -> Vg=1.0
% INFO    : Gen at bus 4125	: Pg=59.6, Qg=15.79 -> Pg=40.0, Qg=11.945
% INFO    : Gen at bus 4125	: Vg=1.002666 -> Vg=1.0
% INFO    : Gen at bus 4128	: Pg=67.5, Qg=21.6 -> Pg=60.0, Qg=19.7
% INFO    : Gen at bus 4128	: Vg=1.027647 -> Vg=1.0
% INFO    : Gen at bus 4131	: Pg=229.26, Qg=80.13 -> Pg=266.665, Qg=61.615
% INFO    : Gen at bus 4131	: Vg=1.034065 -> Vg=1.0
% INFO    : Gen at bus 4163	: Pg=191.97, Qg=-9.59 -> Pg=266.665, Qg=65.625
% INFO    : Gen at bus 4163	: Vg=1.047216 -> Vg=1.0
% INFO    : Gen at bus 4172	: Pg=26.2, Qg=9.34 -> Pg=20.0, Qg=6.15
% INFO    : Gen at bus 4172	: Vg=1.02637 -> Vg=1.0
% INFO    : Gen at bus 4175	: Pg=1530.2, Qg=-301.1 -> Pg=1333.335, Qg=291.53
% INFO    : Gen at bus 4175	: Vg=1.078047 -> Vg=1.0
% INFO    : Gen at bus 4178	: Pg=514.6, Qg=24.43 -> Pg=400.0, Qg=80.195
% INFO    : Gen at bus 4178	: Vg=1.031771 -> Vg=1.0
% INFO    : Gen at bus 4179	: Pg=95.1, Qg=12.7 -> Pg=60.0, Qg=17.19
% INFO    : Gen at bus 4179	: Vg=1.010218 -> Vg=1.0
% INFO    : Gen at bus 4182	: Pg=710.7, Qg=-13.98 -> Pg=533.335, Qg=99.42
% INFO    : Gen at bus 4182	: Vg=1.011247 -> Vg=1.0
% INFO    : Gen at bus 4183	: Pg=-2.55, Qg=9.11 -> Pg=48.3, Qg=13.42
% INFO    : Gen at bus 4183	: Vg=1.031152 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=767.4, Qg=288.6 -> Pg=600.0, Qg=120.695
% INFO    : Gen at bus 4192	: Vg=1.076318 -> Vg=1.0
% INFO    : Gen at bus 4195	: Pg=-488.9, Qg=177.35 -> Pg=-275.935, Qg=159.055
% INFO    : Gen at bus 4195	: Vg=1.076653 -> Vg=1.0
% INFO    : Gen at bus 4198	: Pg=87.5, Qg=7.35 -> Pg=45.915, Qg=3.97
% INFO    : Gen at bus 4198	: Vg=1.01015 -> Vg=1.0
% INFO    : Gen at bus 4200	: Pg=260.1, Qg=-13.03 -> Pg=200.0, Qg=39.4
% INFO    : Gen at bus 4200	: Vg=1.016165 -> Vg=1.0
% INFO    : Gen at bus 4204	: Pg=-48.16, Qg=-0.17 -> Pg=17.895, Qg=0.49
% INFO    : Gen at bus 4204	: Vg=1.014828 -> Vg=1.0
% INFO    : Gen at bus 4207	: Pg=423.93, Qg=23.68 -> Pg=500.0, Qg=127.4
% INFO    : Gen at bus 4207	: Vg=1.009702 -> Vg=1.0
% INFO    : Gen at bus 4210	: Pg=141.89, Qg=-13.69 -> Pg=80.0, Qg=21.685
% INFO    : Gen at bus 4210	: Vg=1.031932 -> Vg=1.0
% INFO    : Gen at bus 4211	: Pg=16.0, Qg=5.84 -> Pg=20.0, Qg=7.095
% INFO    : Gen at bus 4211	: Vg=1.042563 -> Vg=1.0
% INFO    : Gen at bus 4221	: Pg=110.4, Qg=-6.82 -> Pg=101.875, Qg=-2.19
% INFO    : Gen at bus 4221	: Vg=1.036578 -> Vg=1.0
% INFO    : Gen at bus 4228	: Pg=-73.1, Qg=1.66 -> Pg=1.265, Qg=16.995
% INFO    : Gen at bus 4228	: Vg=1.060932 -> Vg=1.0
% INFO    : Gen at bus 4231	: Pg=2641.24, Qg=604.18 -> Pg=2761.14, Qg=0.0
% INFO    : Gen at bus 4231	: Vg=1.042866 -> Vg=1.0
% INFO    : Gen at bus 4244	: Pg=354.7, Qg=-13.59 -> Pg=533.335, Qg=109.72
% INFO    : Gen at bus 4244	: Vg=1.039687 -> Vg=1.0
% INFO    : Gen at bus 4259	: Pg=28.0, Qg=6.43 -> Pg=20.0, Qg=5.98
% INFO    : Gen at bus 4259	: Vg=1.01039 -> Vg=1.0
% INFO    : Gen at bus 4278	: Pg=153.8, Qg=-16.21 -> Pg=83.68, Qg=-30.21
% INFO    : Gen at bus 4278	: Vg=1.038839 -> Vg=1.0
% INFO    : Gen at bus 4279	: Pg=515.39, Qg=-60.67 -> Pg=400.0, Qg=77.605
% INFO    : Gen at bus 4279	: Vg=1.01498 -> Vg=1.0
% INFO    : Gen at bus 4291	: Pg=251.0, Qg=-30.24 -> Pg=210.0, Qg=67.1
% INFO    : Gen at bus 4291	: Vg=1.019753 -> Vg=1.0
% INFO    : Gen at bus 4296	: Pg=33.5, Qg=6.93 -> Pg=20.0, Qg=5.545
% INFO    : Gen at bus 4296	: Vg=1.040271 -> Vg=1.0
% INFO    : Gen at bus 4322	: Pg=108.74, Qg=-12.84 -> Pg=200.0, Qg=49.89
% INFO    : Gen at bus 4322	: Vg=1.055269 -> Vg=1.0
% INFO    : Gen at bus 4323	: Pg=212.8, Qg=74.9 -> Pg=160.0, Qg=50.255
% INFO    : Gen at bus 4323	: Vg=1.038456 -> Vg=1.0
% INFO    : Gen at bus 4330	: Pg=1176.0, Qg=113.62 -> Pg=1066.665, Qg=233.235
% INFO    : Gen at bus 4330	: Vg=1.049093 -> Vg=1.0
% INFO    : Gen at bus 4331	: Pg=60.2, Qg=6.72 -> Pg=40.0, Qg=11.805
% INFO    : Gen at bus 4331	: Vg=1.029918 -> Vg=1.0
% INFO    : Gen at bus 4333	: Pg=152.4, Qg=7.48 -> Pg=90.0, Qg=23.82
% INFO    : Gen at bus 4333	: Vg=0.997274 -> Vg=1.0
% INFO    : Gen at bus 4334	: Pg=73.3, Qg=20.25 -> Pg=50.0, Qg=14.46
% INFO    : Gen at bus 4334	: Vg=1.057462 -> Vg=1.0
% INFO    : Gen at bus 4337	: Pg=490.5, Qg=542.31 -> Pg=800.0, Qg=209.295
% INFO    : Gen at bus 4337	: Vg=1.026934 -> Vg=1.0
% INFO    : Gen at bus 4338	: Pg=-52.5, Qg=2.88 -> Pg=15.0, Qg=4.48
% INFO    : Gen at bus 4338	: Vg=1.021243 -> Vg=1.0
% INFO    : Gen at bus 4350	: Pg=167.0, Qg=-16.07 -> Pg=100.0, Qg=26.155
% INFO    : Gen at bus 4350	: Vg=1.028107 -> Vg=1.0
% INFO    : Gen at bus 4375	: Pg=59.2, Qg=24.66 -> Pg=40.0, Qg=11.99
% INFO    : Gen at bus 4375	: Vg=1.045136 -> Vg=1.0
% INFO    : Gen at bus 4376	: Pg=273.6, Qg=-12.75 -> Pg=200.0, Qg=37.455
% INFO    : Gen at bus 4376	: Vg=1.018032 -> Vg=1.0
% INFO    : Gen at bus 4393	: Pg=115.36, Qg=-17.2 -> Pg=200.0, Qg=50.065
% INFO    : Gen at bus 4393	: Vg=1.061357 -> Vg=1.0
% INFO    : Gen at bus 4395	: Pg=-129.1, Qg=12.5 -> Pg=-36.065, Qg=13.575
% INFO    : Gen at bus 4395	: Vg=1.036974 -> Vg=1.0
% INFO    : Gen at bus 4396	: Pg=147.6, Qg=15.97 -> Pg=200.0, Qg=50.9
% INFO    : Gen at bus 4396	: Vg=1.08226 -> Vg=1.0
% INFO    : Gen at bus 4398	: Pg=236.0, Qg=1.19 -> Pg=150.0, Qg=42.2
% INFO    : Gen at bus 4398	: Vg=1.046214 -> Vg=1.0
% INFO    : Gen at bus 4399	: Pg=-9.15, Qg=4.89 -> Pg=43.905, Qg=5.645
% INFO    : Gen at bus 4399	: Vg=1.054017 -> Vg=1.0
% INFO    : Gen at bus 4400	: Pg=358.2, Qg=24.67 -> Pg=266.665, Qg=51.945
% INFO    : Gen at bus 4400	: Vg=1.077395 -> Vg=1.0
% INFO    : Gen at bus 4419	: Pg=861.3, Qg=136.32 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 4419	: Vg=1.055121 -> Vg=1.0
% INFO    : Gen at bus 4420	: Pg=84.0, Qg=2.27 -> Pg=44.1, Qg=-2.815
% INFO    : Gen at bus 4420	: Vg=1.009808 -> Vg=1.0
% INFO    : Gen at bus 4428	: Pg=14.7, Qg=-4.43 -> Pg=30.12, Qg=0.625
% INFO    : Gen at bus 4428	: Vg=1.016576 -> Vg=1.0
% INFO    : Gen at bus 4429	: Pg=5.0, Qg=9.69 -> Pg=23.1, Qg=9.995
% INFO    : Gen at bus 4429	: Vg=1.007433 -> Vg=1.0
% INFO    : Gen at bus 4440	: Pg=-50.6, Qg=7.72 -> Pg=16.265, Qg=33.65
% INFO    : Gen at bus 4440	: Vg=1.012622 -> Vg=1.0
% INFO    : Gen at bus 4442	: Pg=-11.23, Qg=-10.66 -> Pg=42.51, Qg=0.345
% INFO    : Gen at bus 4442	: Vg=1.031243 -> Vg=1.0
% INFO    : Gen at bus 4445	: Pg=252.6, Qg=155.85 -> Pg=429.19, Qg=17.18
% INFO    : Gen at bus 4445	: Vg=1.031204 -> Vg=1.0
% INFO    : Gen at bus 4447	: Pg=261.77, Qg=82.45 -> Pg=266.665, Qg=60.175
% INFO    : Gen at bus 4447	: Vg=1.115565 -> Vg=1.0
% INFO    : Gen at bus 4455	: Pg=742.6, Qg=68.51 -> Pg=601.335, Qg=15.245
% INFO    : Gen at bus 4455	: Vg=1.01091 -> Vg=1.0
% INFO    : Gen at bus 4464	: Pg=50.1, Qg=26.81 -> Pg=60.0, Qg=21.075
% INFO    : Gen at bus 4464	: Vg=1.054883 -> Vg=1.0
% INFO    : Gen at bus 4468	: Pg=-76.7, Qg=14.09 -> Pg=-1.135, Qg=13.09
% INFO    : Gen at bus 4468	: Vg=1.041888 -> Vg=1.0
% INFO    : Gen at bus 4478	: Pg=410.5, Qg=109.19 -> Pg=333.335, Qg=67.405
% INFO    : Gen at bus 4478	: Vg=1.062733 -> Vg=1.0
% INFO    : Gen at bus 4480	: Pg=861.3, Qg=142.46 -> Pg=666.665, Qg=132.885
% INFO    : Gen at bus 4480	: Vg=1.065482 -> Vg=1.0
% INFO    : Gen at bus 4482	: Pg=35.2, Qg=13.98 -> Pg=40.0, Qg=13.95
% INFO    : Gen at bus 4482	: Vg=1.043069 -> Vg=1.0
% INFO    : Gen at bus 4486	: Pg=38.5, Qg=1.4 -> Pg=20.0, Qg=4.46
% INFO    : Gen at bus 4486	: Vg=1.026359 -> Vg=1.0
% INFO    : Gen at bus 4498	: Pg=156.8, Qg=-17.45 -> Pg=100.0, Qg=28.235
% INFO    : Gen at bus 4498	: Vg=1.085986 -> Vg=1.0
% INFO    : Gen at bus 4502	: Pg=115.0, Qg=10.66 -> Pg=60.0, Qg=14.265
% INFO    : Gen at bus 4502	: Vg=1.022423 -> Vg=1.0
% INFO    : Gen at bus 4506	: Pg=-171.8, Qg=15.64 -> Pg=-64.535, Qg=12.955
% INFO    : Gen at bus 4506	: Vg=1.032581 -> Vg=1.0
% INFO    : Gen at bus 4516	: Pg=364.8, Qg=11.93 -> Pg=266.665, Qg=50.34
% INFO    : Gen at bus 4516	: Vg=1.018246 -> Vg=1.0
% INFO    : Gen at bus 4526	: Pg=6.45, Qg=-3.38 -> Pg=30.0, Qg=8.395
% INFO    : Gen at bus 4526	: Vg=1.059432 -> Vg=1.0
% INFO    : Gen at bus 4533	: Pg=1530.1, Qg=40.53 -> Pg=1600.0, Qg=338.34
% INFO    : Gen at bus 4533	: Vg=1.087859 -> Vg=1.0
% INFO    : Gen at bus 4552	: Pg=-117.74, Qg=-1.44 -> Pg=-28.495, Qg=-0.425
% INFO    : Gen at bus 4552	: Vg=1.021862 -> Vg=1.0
% INFO    : Gen at bus 4564	: Pg=318.0, Qg=12.17 -> Pg=162.5, Qg=30.49
% INFO    : Gen at bus 4564	: Vg=1.026639 -> Vg=1.0
% INFO    : Gen at bus 4566	: Pg=-30.39, Qg=7.17 -> Pg=29.745, Qg=13.035
% INFO    : Gen at bus 4566	: Vg=1.07048 -> Vg=1.0
% INFO    : Gen at bus 4573	: Pg=61.1, Qg=-1.78 -> Pg=46.745, Qg=2.415
% INFO    : Gen at bus 4573	: Vg=1.021097 -> Vg=1.0
% INFO    : Gen at bus 4586	: Pg=-545.7, Qg=54.63 -> Pg=-313.8, Qg=31.575
% INFO    : Gen at bus 4586	: Vg=1.037111 -> Vg=1.0
% INFO    : Gen at bus 4602	: Pg=428.86, Qg=198.47 -> Pg=533.335, Qg=130.385
% INFO    : Gen at bus 4602	: Vg=1.120537 -> Vg=1.0
% INFO    : Gen at bus 4608	: Pg=25.2, Qg=-3.94 -> Pg=13.23, Qg=0.04
% INFO    : Gen at bus 4608	: Vg=1.034566 -> Vg=1.0
% INFO    : Gen at bus 4609	: Pg=60.7, Qg=-4.43 -> Pg=36.29, Qg=3.39
% INFO    : Gen at bus 4609	: Vg=1.019251 -> Vg=1.0
% INFO    : Gen at bus 4613	: Pg=689.2, Qg=-122.64 -> Pg=514.665, Qg=-56.625
% INFO    : Gen at bus 4613	: Vg=1.021632 -> Vg=1.0
% INFO    : Gen at bus 4620	: Pg=115.2, Qg=21.17 -> Pg=100.0, Qg=32.5
% INFO    : Gen at bus 4620	: Vg=1.089892 -> Vg=1.0
% INFO    : Gen at bus 4624	: Pg=68.0, Qg=8.12 -> Pg=40.0, Qg=10.715
% INFO    : Gen at bus 4624	: Vg=1.045235 -> Vg=1.0
% INFO    : Gen at bus 4633	: Pg=-66.1, Qg=-4.03 -> Pg=5.935, Qg=-3.66
% INFO    : Gen at bus 4633	: Vg=1.009572 -> Vg=1.0
% INFO    : Gen at bus 4638	: Pg=-236.3, Qg=9.42 -> Pg=-107.535, Qg=13.355
% INFO    : Gen at bus 4638	: Vg=1.050874 -> Vg=1.0
% INFO    : Gen at bus 4647	: Pg=78.4, Qg=22.32 -> Pg=50.0, Qg=14.305
% INFO    : Gen at bus 4647	: Vg=1.050276 -> Vg=1.0
% INFO    : Gen at bus 4654	: Pg=200.0, Qg=-15.84 -> Pg=105.0, Qg=8.875
% INFO    : Gen at bus 4654	: Vg=1.017349 -> Vg=1.0
% INFO    : Gen at bus 4657	: Pg=101.62, Qg=1.21 -> Pg=150.0, Qg=48.835
% INFO    : Gen at bus 4657	: Vg=1.020179 -> Vg=1.0
% INFO    : Gen at bus 4661	: Pg=-78.9, Qg=4.32 -> Pg=-2.6, Qg=6.685
% INFO    : Gen at bus 4661	: Vg=1.056504 -> Vg=1.0
% INFO    : Gen at bus 4662	: Pg=1509.3, Qg=-223.5 -> Pg=1333.335, Qg=284.39
% INFO    : Gen at bus 4662	: Vg=1.066687 -> Vg=1.0
% INFO    : Gen at bus 4663	: Pg=-116.0, Qg=4.15 -> Pg=-27.335, Qg=17.72
% INFO    : Gen at bus 4663	: Vg=1.021171 -> Vg=1.0
% INFO    : Gen at bus 4666	: Pg=491.0, Qg=28.31 -> Pg=333.335, Qg=46.7
% INFO    : Gen at bus 4666	: Vg=1.011313 -> Vg=1.0
% INFO    : Gen at bus 4667	: Pg=-20.78, Qg=6.39 -> Pg=36.15, Qg=12.87
% INFO    : Gen at bus 4667	: Vg=1.01948 -> Vg=1.0
% INFO    : Gen at bus 4670	: Pg=450.2, Qg=-86.23 -> Pg=333.335, Qg=61.565
% INFO    : Gen at bus 4670	: Vg=1.092961 -> Vg=1.0
% INFO    : Gen at bus 4676	: Pg=763.6, Qg=-70.38 -> Pg=533.335, Qg=97.91
% INFO    : Gen at bus 4676	: Vg=1.088792 -> Vg=1.0
% INFO    : Gen at bus 4690	: Pg=541.0, Qg=10.35 -> Pg=600.0, Qg=142.755
% INFO    : Gen at bus 4690	: Vg=1.026559 -> Vg=1.0
% INFO    : Gen at bus 4695	: Pg=-85.9, Qg=9.98 -> Pg=-7.265, Qg=13.655
% INFO    : Gen at bus 4695	: Vg=1.053968 -> Vg=1.0
% INFO    : Gen at bus 4701	: Pg=93.2, Qg=-37.03 -> Pg=140.925, Qg=6.055
% INFO    : Gen at bus 4701	: Vg=1.042354 -> Vg=1.0
% INFO    : Gen at bus 4708	: Pg=79.5, Qg=27.06 -> Pg=60.0, Qg=18.675
% INFO    : Gen at bus 4708	: Vg=0.996652 -> Vg=1.0
% INFO    : Gen at bus 4739	: Pg=49.6, Qg=10.6 -> Pg=40.0, Qg=12.58
% INFO    : Gen at bus 4739	: Vg=1.021645 -> Vg=1.0
% INFO    : Gen at bus 4749	: Pg=527.3, Qg=-66.96 -> Pg=276.83, Qg=0.34
% INFO    : Gen at bus 4749	: Vg=1.030135 -> Vg=1.0
% INFO    : Gen at bus 4755	: Pg=55.2, Qg=-5.3 -> Pg=28.98, Qg=-5.52
% INFO    : Gen at bus 4755	: Vg=1.0132 -> Vg=1.0
% INFO    : Gen at bus 4758	: Pg=570.6, Qg=237.26 -> Pg=400.0, Qg=73.27
% INFO    : Gen at bus 4758	: Vg=1.064718 -> Vg=1.0
% INFO    : Gen at bus 4772	: Pg=78.0, Qg=-14.48 -> Pg=100.0, Qg=27.28
% INFO    : Gen at bus 4772	: Vg=1.023126 -> Vg=1.0
% INFO    : Gen at bus 4773	: Pg=16.0, Qg=-4.51 -> Pg=32.65, Qg=0.625
% INFO    : Gen at bus 4773	: Vg=1.017383 -> Vg=1.0
% INFO    : Gen at bus 4776	: Pg=805.5, Qg=127.43 -> Pg=600.0, Qg=114.335
% INFO    : Gen at bus 4776	: Vg=1.063105 -> Vg=1.0
% INFO    : Gen at bus 4783	: Pg=861.3, Qg=140.63 -> Pg=666.665, Qg=132.885
% INFO    : Gen at bus 4783	: Vg=1.06564 -> Vg=1.0
% INFO    : Gen at bus 4788	: Pg=387.47, Qg=62.3 -> Pg=533.335, Qg=134.22
% INFO    : Gen at bus 4788	: Vg=1.009861 -> Vg=1.0
% INFO    : Gen at bus 4805	: Pg=-183.5, Qg=32.22 -> Pg=-72.335, Qg=67.885
% INFO    : Gen at bus 4805	: Vg=1.046224 -> Vg=1.0
% INFO    : Gen at bus 4816	: Pg=-26.08, Qg=11.74 -> Pg=32.615, Qg=13.465
% INFO    : Gen at bus 4816	: Vg=1.060527 -> Vg=1.0
% INFO    : Gen at bus 4819	: Pg=855.6, Qg=159.85 -> Pg=666.665, Qg=134.275
% INFO    : Gen at bus 4819	: Vg=1.028949 -> Vg=1.0
% INFO    : Gen at bus 4823	: Pg=10.3, Qg=0.51 -> Pg=5.23, Qg=1.185
% INFO    : Gen at bus 4823	: Vg=1.055712 -> Vg=1.0
% INFO    : Gen at bus 4824	: Pg=728.4, Qg=-75.11 -> Pg=800.0, Qg=191.065
% INFO    : Gen at bus 4824	: Vg=1.089599 -> Vg=1.0
% INFO    : Gen at bus 4834	: Pg=10.5, Qg=-1.01 -> Pg=5.515, Qg=0.08
% INFO    : Gen at bus 4834	: Vg=1.038553 -> Vg=1.0
% INFO    : Gen at bus 4843	: Pg=6.8, Qg=-1.73 -> Pg=6.815, Qg=0.595
% INFO    : Gen at bus 4843	: Vg=1.048394 -> Vg=1.0
% INFO    : Gen at bus 4844	: Pg=226.6, Qg=-78.28 -> Pg=300.0, Qg=133.03
% INFO    : Gen at bus 4844	: Vg=1.00703 -> Vg=1.0
% INFO    : Gen at bus 4845	: Pg=-6.25, Qg=3.32 -> Pg=45.835, Qg=9.15
% INFO    : Gen at bus 4845	: Vg=1.024167 -> Vg=1.0
% INFO    : Gen at bus 4846	: Pg=239.6, Qg=48.55 -> Pg=200.0, Qg=41.975
% INFO    : Gen at bus 4846	: Vg=1.030121 -> Vg=1.0
% INFO    : Gen at bus 4847	: Pg=-173.7, Qg=-13.76 -> Pg=-65.8, Qg=69.475
% INFO    : Gen at bus 4847	: Vg=1.081656 -> Vg=1.0
% INFO    : Gen at bus 4848	: Pg=160.94, Qg=15.95 -> Pg=266.665, Qg=65.035
% INFO    : Gen at bus 4848	: Vg=1.070363 -> Vg=1.0
% INFO    : Gen at bus 4850	: Pg=88.8, Qg=11.12 -> Pg=80.0, Qg=26.665
% INFO    : Gen at bus 4850	: Vg=1.057137 -> Vg=1.0
% INFO    : Gen at bus 4871	: Pg=58.27, Qg=10.0 -> Pg=50.0, Qg=13.17
% INFO    : Gen at bus 4871	: Vg=1.054823 -> Vg=1.0
% INFO    : Gen at bus 4880	: Pg=-40.3, Qg=7.15 -> Pg=23.135, Qg=25.83
% INFO    : Gen at bus 4880	: Vg=1.041763 -> Vg=1.0
% INFO    : Gen at bus 4882	: Pg=13.0, Qg=-2.75 -> Pg=6.825, Qg=-1.78
% INFO    : Gen at bus 4882	: Vg=1.028068 -> Vg=1.0
% INFO    : Gen at bus 4892	: Pg=357.0, Qg=-28.65 -> Pg=200.0, Qg=51.72
% INFO    : Gen at bus 4892	: Vg=1.033418 -> Vg=1.0
% INFO    : Gen at bus 4897	: Pg=18.56, Qg=6.55 -> Pg=40.0, Qg=12.675
% INFO    : Gen at bus 4897	: Vg=1.014069 -> Vg=1.0
% INFO    : Gen at bus 4900	: Pg=23.8, Qg=-3.06 -> Pg=12.495, Qg=-2.21
% INFO    : Gen at bus 4900	: Vg=1.023832 -> Vg=1.0
% INFO    : Gen at bus 4918	: Pg=41.69, Qg=11.87 -> Pg=40.0, Qg=12.35
% INFO    : Gen at bus 4918	: Vg=1.053068 -> Vg=1.0
% INFO    : Gen at bus 4931	: Pg=20.2, Qg=-14.61 -> Pg=51.395, Qg=0.375
% INFO    : Gen at bus 4931	: Vg=1.035713 -> Vg=1.0
% INFO    : Gen at bus 4938	: Pg=1201.0, Qg=128.03 -> Pg=1333.335, Qg=321.275
% INFO    : Gen at bus 4938	: Vg=1.031692 -> Vg=1.0
% INFO    : Gen at bus 4944	: Pg=-8.84, Qg=8.01 -> Pg=44.105, Qg=6.17
% INFO    : Gen at bus 4944	: Vg=1.0154 -> Vg=1.0
% INFO    : Gen at bus 4945	: Pg=385.4, Qg=-29.74 -> Pg=333.335, Qg=71.09
% INFO    : Gen at bus 4945	: Vg=1.055797 -> Vg=1.0
% INFO    : Gen at bus 4949	: Pg=60.0, Qg=3.02 -> Pg=60.0, Qg=20.315
% INFO    : Gen at bus 4949	: Vg=1.046901 -> Vg=1.0
% INFO    : Gen at bus 4952	: Pg=-12.57, Qg=9.87 -> Pg=41.615, Qg=12.31
% INFO    : Gen at bus 4952	: Vg=1.047958 -> Vg=1.0
% INFO    : Gen at bus 4954	: Pg=40.84, Qg=3.16 -> Pg=60.0, Qg=17.1
% INFO    : Gen at bus 4954	: Vg=1.016721 -> Vg=1.0
% INFO    : Gen at bus 4955	: Pg=123.9, Qg=-20.46 -> Pg=79.7, Qg=3.89
% INFO    : Gen at bus 4955	: Vg=1.037342 -> Vg=1.0
% INFO    : Gen at bus 4957	: Pg=961.0, Qg=-175.55 -> Pg=800.0, Qg=166.135
% INFO    : Gen at bus 4957	: Vg=1.045811 -> Vg=1.0
% INFO    : Gen at bus 4959	: Pg=853.9, Qg=192.65 -> Pg=584.0, Qg=10.17
% INFO    : Gen at bus 4959	: Vg=1.051773 -> Vg=1.0
% INFO    : Gen at bus 4967	: Pg=83.2, Qg=-14.91 -> Pg=210.0, Qg=53.185
% INFO    : Gen at bus 4967	: Vg=1.020942 -> Vg=1.0
% INFO    : Gen at bus 4969	: Pg=453.4, Qg=62.07 -> Pg=533.335, Qg=130.64
% INFO    : Gen at bus 4969	: Vg=1.065019 -> Vg=1.0
% INFO    : Gen at bus 4979	: Pg=246.0, Qg=16.81 -> Pg=150.0, Qg=40.375
% INFO    : Gen at bus 4979	: Vg=1.039397 -> Vg=1.0
% INFO    : Gen at bus 4994	: Pg=360.4, Qg=135.52 -> Pg=266.665, Qg=51.02
% INFO    : Gen at bus 4994	: Vg=1.047685 -> Vg=1.0
% INFO    : Gen at bus 4996	: Pg=130.8, Qg=16.37 -> Pg=80.0, Qg=22.085
% INFO    : Gen at bus 4996	: Vg=1.040488 -> Vg=1.0
% INFO    : Gen at bus 5004	: Pg=54.3, Qg=1.52 -> Pg=110.06, Qg=2.16
% INFO    : Gen at bus 5004	: Vg=1.054301 -> Vg=1.0
% INFO    : Gen at bus 5005	: Pg=406.0, Qg=151.95 -> Pg=333.335, Qg=67.715
% INFO    : Gen at bus 5005	: Vg=1.062291 -> Vg=1.0
% INFO    : Gen at bus 5019	: Pg=49.4, Qg=5.52 -> Pg=40.0, Qg=12.815
% INFO    : Gen at bus 5019	: Vg=1.05406 -> Vg=1.0
% INFO    : Gen at bus 5020	: Pg=35.2, Qg=7.78 -> Pg=40.0, Qg=13.97
% INFO    : Gen at bus 5020	: Vg=1.067392 -> Vg=1.0
% INFO    : Gen at bus 5025	: Pg=-155.1, Qg=-0.48 -> Pg=-53.4, Qg=0.675
% INFO    : Gen at bus 5025	: Vg=1.002981 -> Vg=1.0
% INFO    : Gen at bus 5027	: Pg=-10.3, Qg=-14.47 -> Pg=43.135, Qg=32.2
% INFO    : Gen at bus 5027	: Vg=1.046647 -> Vg=1.0
% INFO    : Gen at bus 5036	: Pg=75.2, Qg=7.15 -> Pg=40.0, Qg=10.105
% INFO    : Gen at bus 5036	: Vg=1.060776 -> Vg=1.0
% INFO    : Gen at bus 5043	: Pg=179.5, Qg=27.83 -> Pg=100.0, Qg=26.275
% INFO    : Gen at bus 5043	: Vg=1.07576 -> Vg=1.0
% INFO    : Gen at bus 5051	: Pg=83.48, Qg=1.58 -> Pg=80.0, Qg=24.79
% INFO    : Gen at bus 5051	: Vg=1.042576 -> Vg=1.0
% INFO    : Gen at bus 5059	: Pg=130.2, Qg=34.96 -> Pg=90.0, Qg=26.655
% INFO    : Gen at bus 5059	: Vg=1.031064 -> Vg=1.0
% INFO    : Gen at bus 5060	: Pg=13.3, Qg=-4.32 -> Pg=20.34, Qg=0.895
% INFO    : Gen at bus 5060	: Vg=1.06427 -> Vg=1.0
% INFO    : Gen at bus 5065	: Pg=1008.3, Qg=175.33 -> Pg=800.0, Qg=164.885
% INFO    : Gen at bus 5065	: Vg=1.06654 -> Vg=1.0
% INFO    : Gen at bus 5067	: Pg=542.0, Qg=117.94 -> Pg=300.0, Qg=74.665
% INFO    : Gen at bus 5067	: Vg=1.016664 -> Vg=1.0
% INFO    : Gen at bus 5075	: Pg=-92.6, Qg=4.26 -> Pg=-11.735, Qg=7.46
% INFO    : Gen at bus 5075	: Vg=1.027964 -> Vg=1.0
% INFO    : Gen at bus 5091	: Pg=276.42, Qg=-47.94 -> Pg=180.0, Qg=41.28
% INFO    : Gen at bus 5091	: Vg=1.051243 -> Vg=1.0
% INFO    : Gen at bus 5092	: Pg=416.4, Qg=-21.8 -> Pg=333.335, Qg=68.33
% INFO    : Gen at bus 5092	: Vg=1.061075 -> Vg=1.0
% INFO    : Gen at bus 5097	: Pg=21.1, Qg=2.69 -> Pg=14.155, Qg=2.4
% INFO    : Gen at bus 5097	: Vg=1.052774 -> Vg=1.0
% INFO    : Gen at bus 5098	: Pg=517.2, Qg=-103.83 -> Pg=536.0, Qg=-141.735
% INFO    : Gen at bus 5098	: Vg=1.006462 -> Vg=1.0
% INFO    : Gen at bus 5110	: Pg=-52.51, Qg=10.15 -> Pg=14.995, Qg=13.39
% INFO    : Gen at bus 5110	: Vg=1.033935 -> Vg=1.0
% INFO    : Gen at bus 5120	: Pg=75.6, Qg=-2.03 -> Pg=60.0, Qg=18.965
% INFO    : Gen at bus 5120	: Vg=1.06465 -> Vg=1.0
% INFO    : Gen at bus 5134	: Pg=197.3, Qg=26.91 -> Pg=110.225, Qg=32.885
% INFO    : Gen at bus 5134	: Vg=1.022715 -> Vg=1.0
% INFO    : Gen at bus 5138	: Pg=308.8, Qg=33.72 -> Pg=266.665, Qg=57.15
% INFO    : Gen at bus 5138	: Vg=1.048344 -> Vg=1.0
% INFO    : Gen at bus 5144	: Pg=1713.6, Qg=141.65 -> Pg=1333.335, Qg=269.81
% INFO    : Gen at bus 5144	: Vg=1.032838 -> Vg=1.0
% INFO    : Gen at bus 5145	: Pg=422.0, Qg=219.01 -> Pg=716.955, Qg=29.645
% INFO    : Gen at bus 5145	: Vg=1.049287 -> Vg=1.0
% INFO    : Gen at bus 5152	: Pg=50.59, Qg=28.52 -> Pg=40.0, Qg=12.82
% INFO    : Gen at bus 5152	: Vg=1.033193 -> Vg=1.0
% INFO    : Gen at bus 5154	: Pg=-54.09, Qg=8.3 -> Pg=13.94, Qg=10.05
% INFO    : Gen at bus 5154	: Vg=1.021968 -> Vg=1.0
% INFO    : Gen at bus 5158	: Pg=690.05, Qg=79.89 -> Pg=533.335, Qg=100.475
% INFO    : Gen at bus 5158	: Vg=1.043194 -> Vg=1.0
% INFO    : Gen at bus 5164	: Pg=629.3, Qg=204.21 -> Pg=466.665, Qg=87.35
% INFO    : Gen at bus 5164	: Vg=1.083362 -> Vg=1.0
% INFO    : Gen at bus 5171	: Pg=-87.6, Qg=-6.41 -> Pg=-8.4, Qg=0.3
% INFO    : Gen at bus 5171	: Vg=1.011094 -> Vg=1.0
% INFO    : Gen at bus 5180	: Pg=-17.5, Qg=0.2 -> Pg=38.335, Qg=1.105
% INFO    : Gen at bus 5180	: Vg=1.010906 -> Vg=1.0
% INFO    : Gen at bus 5192	: Pg=143.4, Qg=-7.13 -> Pg=90.0, Qg=24.335
% INFO    : Gen at bus 5192	: Vg=1.039762 -> Vg=1.0
% INFO    : Gen at bus 5193	: Pg=38.49, Qg=-1.19 -> Pg=40.0, Qg=12.605
% INFO    : Gen at bus 5193	: Vg=1.022466 -> Vg=1.0
% INFO    : Gen at bus 5225	: Pg=178.82, Qg=26.14 -> Pg=160.0, Qg=45.565
% INFO    : Gen at bus 5225	: Vg=1.050345 -> Vg=1.0
% INFO    : Gen at bus 5226	: Pg=235.1, Qg=-47.98 -> Pg=160.0, Qg=45.86
% INFO    : Gen at bus 5226	: Vg=0.992484 -> Vg=1.0
% INFO    : Gen at bus 5231	: Pg=120.79, Qg=23.81 -> Pg=133.335, Qg=30.685
% INFO    : Gen at bus 5231	: Vg=1.026163 -> Vg=1.0
% INFO    : Gen at bus 5236	: Pg=403.7, Qg=14.5 -> Pg=220.0, Qg=56.365
% INFO    : Gen at bus 5236	: Vg=1.047863 -> Vg=1.0
% INFO    : Gen at bus 5237	: Pg=106.8, Qg=11.87 -> Pg=80.0, Qg=25.14
% INFO    : Gen at bus 5237	: Vg=1.0542 -> Vg=1.0
% INFO    : Gen at bus 5239	: Pg=-1344.4, Qg=-125.88 -> Pg=-846.265, Qg=0.0
% INFO    : Gen at bus 5239	: Vg=0.990479 -> Vg=1.0
% INFO    : Gen at bus 5251	: Pg=137.3, Qg=24.03 -> Pg=80.0, Qg=21.54
% INFO    : Gen at bus 5251	: Vg=1.038759 -> Vg=1.0
% INFO    : Gen at bus 5262	: Pg=418.2, Qg=-22.48 -> Pg=333.335, Qg=68.055
% INFO    : Gen at bus 5262	: Vg=1.059967 -> Vg=1.0
% INFO    : Gen at bus 5264	: Pg=120.6, Qg=-40.08 -> Pg=63.315, Qg=-17.95
% INFO    : Gen at bus 5264	: Vg=1.034663 -> Vg=1.0
% INFO    : Gen at bus 5273	: Pg=-5.35, Qg=5.9 -> Pg=46.435, Qg=17.31
% INFO    : Gen at bus 5273	: Vg=1.026805 -> Vg=1.0
% INFO    : Gen at bus 5278	: Pg=119.4, Qg=1.98 -> Pg=60.0, Qg=13.905
% INFO    : Gen at bus 5278	: Vg=1.03962 -> Vg=1.0
% INFO    : Gen at bus 5280	: Pg=-193.9, Qg=-0.28 -> Pg=-79.265, Qg=0.615
% INFO    : Gen at bus 5280	: Vg=1.018895 -> Vg=1.0
% INFO    : Gen at bus 5285	: Pg=151.0, Qg=0.45 -> Pg=100.0, Qg=29.405
% INFO    : Gen at bus 5285	: Vg=1.057359 -> Vg=1.0
% INFO    : Gen at bus 5290	: Pg=332.54, Qg=-6.89 -> Pg=180.0, Qg=49.125
% INFO    : Gen at bus 5290	: Vg=1.009333 -> Vg=1.0
% INFO    : Gen at bus 5293	: Pg=306.0, Qg=-17.74 -> Pg=229.335, Qg=26.775
% INFO    : Gen at bus 5293	: Vg=1.008689 -> Vg=1.0
% INFO    : Gen at bus 5299	: Pg=152.3, Qg=-130.43 -> Pg=870.165, Qg=-19.975
% INFO    : Gen at bus 5299	: Vg=1.045101 -> Vg=1.0
% INFO    : Gen at bus 5301	: Pg=102.6, Qg=-9.51 -> Pg=100.0, Qg=33.355
% INFO    : Gen at bus 5301	: Vg=1.034956 -> Vg=1.0
% INFO    : Gen at bus 5305	: Pg=75.8, Qg=17.27 -> Pg=125.265, Qg=63.06
% INFO    : Gen at bus 5305	: Vg=1.029341 -> Vg=1.0
% INFO    : Gen at bus 5309	: Pg=44.9, Qg=-15.99 -> Pg=204.545, Qg=-3.695
% INFO    : Gen at bus 5309	: Vg=1.042975 -> Vg=1.0
% INFO    : Gen at bus 5323	: Pg=41.0, Qg=3.48 -> Pg=40.0, Qg=13.52
% INFO    : Gen at bus 5323	: Vg=1.031211 -> Vg=1.0
% INFO    : Gen at bus 5329	: Pg=-54.78, Qg=-8.89 -> Pg=13.475, Qg=0.325
% INFO    : Gen at bus 5329	: Vg=1.015053 -> Vg=1.0
% INFO    : Gen at bus 5340	: Pg=-159.0, Qg=11.36 -> Pg=-56.0, Qg=11.47
% INFO    : Gen at bus 5340	: Vg=1.044898 -> Vg=1.0
% INFO    : Gen at bus 5348	: Pg=10.8, Qg=-1.79 -> Pg=16.37, Qg=0.64
% INFO    : Gen at bus 5348	: Vg=1.013341 -> Vg=1.0
% INFO    : Gen at bus 5352	: Pg=10.0, Qg=-1.61 -> Pg=5.25, Qg=-0.71
% INFO    : Gen at bus 5352	: Vg=1.022029 -> Vg=1.0
% INFO    : Gen at bus 5365	: Pg=19.59, Qg=3.68 -> Pg=20.0, Qg=5.695
% INFO    : Gen at bus 5365	: Vg=1.065324 -> Vg=1.0
% INFO    : Gen at bus 5368	: Pg=200.0, Qg=5.66 -> Pg=200.0, Qg=45.87
% INFO    : Gen at bus 5368	: Vg=1.058977 -> Vg=1.0
% INFO    : Gen at bus 5369	: Pg=-76.5, Qg=14.66 -> Pg=-0.995, Qg=13.445
% INFO    : Gen at bus 5369	: Vg=1.037177 -> Vg=1.0
% INFO    : Gen at bus 5379	: Pg=1250.6, Qg=364.73 -> Pg=1333.335, Qg=314.42
% INFO    : Gen at bus 5379	: Vg=1.10493 -> Vg=1.0
% INFO    : Gen at bus 5395	: Pg=-395.8, Qg=11.26 -> Pg=-213.865, Qg=20.7
% INFO    : Gen at bus 5395	: Vg=1.05041 -> Vg=1.0
% INFO    : Gen at bus 5397	: Pg=-131.0, Qg=17.95 -> Pg=-37.335, Qg=11.96
% INFO    : Gen at bus 5397	: Vg=1.016845 -> Vg=1.0
% INFO    : Gen at bus 5398	: Pg=333.2, Qg=135.77 -> Pg=266.665, Qg=54.54
% INFO    : Gen at bus 5398	: Vg=1.041434 -> Vg=1.0
% INFO    : Gen at bus 5401	: Pg=91.8, Qg=18.12 -> Pg=50.0, Qg=12.055
% INFO    : Gen at bus 5401	: Vg=1.056816 -> Vg=1.0
% INFO    : Gen at bus 5403	: Pg=439.0, Qg=208.3 -> Pg=333.335, Qg=65.915
% INFO    : Gen at bus 5403	: Vg=1.032334 -> Vg=1.0
% INFO    : Gen at bus 5409	: Pg=219.5, Qg=-18.7 -> Pg=120.0, Qg=28.955
% INFO    : Gen at bus 5409	: Vg=1.021468 -> Vg=1.0
% INFO    : Gen at bus 5412	: Pg=359.1, Qg=-8.27 -> Pg=266.665, Qg=52.07
% INFO    : Gen at bus 5412	: Vg=1.07527 -> Vg=1.0
% INFO    : Gen at bus 5425	: Pg=181.1, Qg=-8.83 -> Pg=120.0, Qg=34.535
% INFO    : Gen at bus 5425	: Vg=1.074405 -> Vg=1.0
% INFO    : Gen at bus 5429	: Pg=292.5, Qg=104.21 -> Pg=150.0, Qg=35.08
% INFO    : Gen at bus 5429	: Vg=1.043614 -> Vg=1.0
% INFO    : Gen at bus 5444	: Pg=865.8, Qg=351.49 -> Pg=550.0, Qg=106.75
% INFO    : Gen at bus 5444	: Vg=1.059208 -> Vg=1.0
% INFO    : Gen at bus 5457	: Pg=33.99, Qg=11.2 -> Pg=40.0, Qg=13.595
% INFO    : Gen at bus 5457	: Vg=1.044659 -> Vg=1.0
% INFO    : Gen at bus 5461	: Pg=43.4, Qg=11.36 -> Pg=40.0, Qg=13.355
% INFO    : Gen at bus 5461	: Vg=1.055685 -> Vg=1.0
% INFO    : Gen at bus 5465	: Pg=18.5, Qg=-6.87 -> Pg=46.735, Qg=0.165
% INFO    : Gen at bus 5465	: Vg=0.997959 -> Vg=1.0
% INFO    : Gen at bus 5471	: Pg=519.6, Qg=134.28 -> Pg=400.0, Qg=79.265
% INFO    : Gen at bus 5471	: Vg=1.026437 -> Vg=1.0
% INFO    : Gen at bus 5479	: Pg=179.07, Qg=131.32 -> Pg=266.665, Qg=66.12
% INFO    : Gen at bus 5479	: Vg=1.05048 -> Vg=1.0
% INFO    : Gen at bus 5480	: Pg=47.8, Qg=19.88 -> Pg=40.0, Qg=12.98
% INFO    : Gen at bus 5480	: Vg=1.043829 -> Vg=1.0
% INFO    : Gen at bus 5481	: Pg=1368.6, Qg=134.39 -> Pg=1333.335, Qg=307.335
% INFO    : Gen at bus 5481	: Vg=1.05825 -> Vg=1.0
% INFO    : Gen at bus 5482	: Pg=56.8, Qg=-10.13 -> Pg=124.53, Qg=26.6
% INFO    : Gen at bus 5482	: Vg=1.042942 -> Vg=1.0
% INFO    : Gen at bus 5486	: Pg=861.3, Qg=135.67 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 5486	: Vg=1.055199 -> Vg=1.0
% INFO    : Gen at bus 5487	: Pg=265.8, Qg=74.35 -> Pg=200.0, Qg=37.435
% INFO    : Gen at bus 5487	: Vg=1.050272 -> Vg=1.0
% INFO    : Gen at bus 5488	: Pg=-96.4, Qg=15.72 -> Pg=-14.265, Qg=12.58
% INFO    : Gen at bus 5488	: Vg=1.037007 -> Vg=1.0
% INFO    : Gen at bus 5490	: Pg=3424.8, Qg=281.52 -> Pg=2666.665, Qg=539.345
% INFO    : Gen at bus 5490	: Vg=1.062487 -> Vg=1.0
% INFO    : Gen at bus 5504	: Pg=29.58, Qg=10.59 -> Pg=40.0, Qg=13.06
% INFO    : Gen at bus 5504	: Vg=1.033273 -> Vg=1.0
% INFO    : Gen at bus 5512	: Pg=75.62, Qg=7.15 -> Pg=80.0, Qg=19.835
% INFO    : Gen at bus 5512	: Vg=1.017916 -> Vg=1.0
% INFO    : Gen at bus 5513	: Pg=-196.0, Qg=-2.87 -> Pg=-80.665, Qg=62.485
% INFO    : Gen at bus 5513	: Vg=1.030251 -> Vg=1.0
% INFO    : Gen at bus 5530	: Pg=-95.9, Qg=27.28 -> Pg=-13.935, Qg=12.0
% INFO    : Gen at bus 5530	: Vg=1.011393 -> Vg=1.0
% INFO    : Gen at bus 5533	: Pg=173.0, Qg=12.32 -> Pg=100.0, Qg=26.58
% INFO    : Gen at bus 5533	: Vg=1.046404 -> Vg=1.0
% INFO    : Gen at bus 5546	: Pg=21.5, Qg=3.53 -> Pg=20.0, Qg=6.705
% INFO    : Gen at bus 5546	: Vg=1.063123 -> Vg=1.0
% INFO    : Gen at bus 5556	: Pg=571.8, Qg=229.47 -> Pg=400.0, Qg=71.865
% INFO    : Gen at bus 5556	: Vg=1.067161 -> Vg=1.0
% INFO    : Gen at bus 5564	: Pg=57.6, Qg=10.39 -> Pg=40.0, Qg=11.905
% INFO    : Gen at bus 5564	: Vg=1.038385 -> Vg=1.0
% INFO    : Gen at bus 5572	: Pg=79.6, Qg=12.95 -> Pg=60.0, Qg=18.365
% INFO    : Gen at bus 5572	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 5594	: Pg=-238.2, Qg=0.6 -> Pg=-108.8, Qg=5.05
% INFO    : Gen at bus 5594	: Vg=1.048652 -> Vg=1.0
% INFO    : Gen at bus 5602	: Pg=42.0, Qg=-3.27 -> Pg=22.05, Qg=-4.16
% INFO    : Gen at bus 5602	: Vg=1.032916 -> Vg=1.0
% INFO    : Gen at bus 5603	: Pg=228.6, Qg=-8.28 -> Pg=120.015, Qg=9.07
% INFO    : Gen at bus 5603	: Vg=1.027661 -> Vg=1.0
% INFO    : Gen at bus 5611	: Pg=33.7, Qg=0.38 -> Pg=20.0, Qg=5.52
% INFO    : Gen at bus 5611	: Vg=1.079526 -> Vg=1.0
% INFO    : Gen at bus 5620	: Pg=-165.1, Qg=62.85 -> Pg=-60.065, Qg=25.495
% INFO    : Gen at bus 5620	: Vg=1.055555 -> Vg=1.0
% INFO    : Gen at bus 5645	: Pg=78.17, Qg=27.37 -> Pg=60.0, Qg=15.635
% INFO    : Gen at bus 5645	: Vg=1.000282 -> Vg=1.0
% INFO    : Gen at bus 5656	: Pg=35.69, Qg=-2.39 -> Pg=61.895, Qg=64.55
% INFO    : Gen at bus 5656	: Vg=1.039989 -> Vg=1.0
% INFO    : Gen at bus 5658	: Pg=229.8, Qg=81.02 -> Pg=120.0, Qg=28.465
% INFO    : Gen at bus 5658	: Vg=1.005722 -> Vg=1.0
% INFO    : Gen at bus 5664	: Pg=128.0, Qg=17.27 -> Pg=80.0, Qg=22.83
% INFO    : Gen at bus 5664	: Vg=1.063661 -> Vg=1.0
% INFO    : Gen at bus 5668	: Pg=152.1, Qg=50.4 -> Pg=180.0, Qg=54.375
% INFO    : Gen at bus 5668	: Vg=1.028943 -> Vg=1.0
% INFO    : Gen at bus 5669	: Pg=294.54, Qg=12.23 -> Pg=350.0, Qg=9.565
% INFO    : Gen at bus 5669	: Vg=1.000678 -> Vg=1.0
% INFO    : Gen at bus 5670	: Pg=16.6, Qg=-3.12 -> Pg=33.88, Qg=0.635
% INFO    : Gen at bus 5670	: Vg=1.013301 -> Vg=1.0
% INFO    : Gen at bus 5677	: Pg=64.35, Qg=15.03 -> Pg=60.0, Qg=15.255
% INFO    : Gen at bus 5677	: Vg=1.033561 -> Vg=1.0
% INFO    : Gen at bus 5679	: Pg=-36.09, Qg=1.41 -> Pg=25.94, Qg=8.85
% INFO    : Gen at bus 5679	: Vg=1.057325 -> Vg=1.0
% INFO    : Gen at bus 5692	: Pg=654.8, Qg=78.31 -> Pg=533.335, Qg=111.26
% INFO    : Gen at bus 5692	: Vg=1.048689 -> Vg=1.0
% INFO    : Gen at bus 5705	: Pg=33.4, Qg=0.38 -> Pg=30.0, Qg=9.76
% INFO    : Gen at bus 5705	: Vg=1.084017 -> Vg=1.0
% INFO    : Gen at bus 5709	: Pg=837.0, Qg=87.13 -> Pg=800.0, Qg=182.77
% INFO    : Gen at bus 5709	: Vg=1.024594 -> Vg=1.0
% INFO    : Gen at bus 5714	: Pg=74.8, Qg=15.83 -> Pg=60.0, Qg=18.675
% INFO    : Gen at bus 5714	: Vg=1.020678 -> Vg=1.0
% INFO    : Gen at bus 5717	: Pg=84.5, Qg=10.79 -> Pg=50.0, Qg=13.335
% INFO    : Gen at bus 5717	: Vg=1.070074 -> Vg=1.0
% INFO    : Gen at bus 5721	: Pg=114.99, Qg=6.44 -> Pg=90.0, Qg=27.355
% INFO    : Gen at bus 5721	: Vg=1.054563 -> Vg=1.0
% INFO    : Gen at bus 5722	: Pg=-42.07, Qg=-11.46 -> Pg=21.955, Qg=-15.805
% INFO    : Gen at bus 5722	: Vg=1.009245 -> Vg=1.0
% INFO    : Gen at bus 5726	: Pg=18.5, Qg=-8.95 -> Pg=47.99, Qg=0.22
% INFO    : Gen at bus 5726	: Vg=1.01699 -> Vg=1.0
% INFO    : Gen at bus 5737	: Pg=13.86, Qg=10.54 -> Pg=40.0, Qg=13.115
% INFO    : Gen at bus 5737	: Vg=1.008529 -> Vg=1.0
% INFO    : Gen at bus 5742	: Pg=84.5, Qg=14.45 -> Pg=56.76, Qg=9.63
% INFO    : Gen at bus 5742	: Vg=1.023074 -> Vg=1.0
% INFO    : Gen at bus 5750	: Pg=128.1, Qg=49.62 -> Pg=204.0, Qg=31.905
% INFO    : Gen at bus 5750	: Vg=1.026001 -> Vg=1.0
% INFO    : Gen at bus 5759	: Pg=448.4, Qg=-95.85 -> Pg=533.335, Qg=131.455
% INFO    : Gen at bus 5759	: Vg=1.075601 -> Vg=1.0
% INFO    : Gen at bus 5781	: Pg=1652.7, Qg=590.72 -> Pg=1200.0, Qg=227.25
% INFO    : Gen at bus 5781	: Vg=1.046351 -> Vg=1.0
% INFO    : Gen at bus 5786	: Pg=31.7, Qg=8.04 -> Pg=31.92, Qg=2.66
% INFO    : Gen at bus 5786	: Vg=1.006382 -> Vg=1.0
% INFO    : Gen at bus 5787	: Pg=63.55, Qg=-9.4 -> Pg=120.0, Qg=41.055
% INFO    : Gen at bus 5787	: Vg=1.028374 -> Vg=1.0
% INFO    : Gen at bus 5809	: Pg=354.4, Qg=51.07 -> Pg=266.665, Qg=47.08
% INFO    : Gen at bus 5809	: Vg=1.010105 -> Vg=1.0
% INFO    : Gen at bus 5811	: Pg=2.66, Qg=2.33 -> Pg=20.0, Qg=5.005
% INFO    : Gen at bus 5811	: Vg=1.018688 -> Vg=1.0
% INFO    : Gen at bus 5812	: Pg=292.5, Qg=110.27 -> Pg=150.0, Qg=34.95
% INFO    : Gen at bus 5812	: Vg=1.031099 -> Vg=1.0
% INFO    : Gen at bus 5814	: Pg=181.2, Qg=56.15 -> Pg=293.335, Qg=59.905
% INFO    : Gen at bus 5814	: Vg=1.040708 -> Vg=1.0
% INFO    : Gen at bus 5821	: Pg=-74.21, Qg=-17.31 -> Pg=0.53, Qg=-0.235
% INFO    : Gen at bus 5821	: Vg=1.016327 -> Vg=1.0
% INFO    : Gen at bus 5822	: Pg=111.7, Qg=16.67 -> Pg=187.235, Qg=62.665
% INFO    : Gen at bus 5822	: Vg=1.063749 -> Vg=1.0
% INFO    : Gen at bus 5823	: Pg=404.6, Qg=-40.2 -> Pg=333.335, Qg=67.605
% INFO    : Gen at bus 5823	: Vg=1.060066 -> Vg=1.0
% INFO    : Gen at bus 5824	: Pg=935.4, Qg=54.24 -> Pg=800.0, Qg=171.45
% INFO    : Gen at bus 5824	: Vg=1.050736 -> Vg=1.0
% INFO    : Gen at bus 5825	: Pg=262.6, Qg=39.74 -> Pg=350.0, Qg=21.225
% INFO    : Gen at bus 5825	: Vg=0.992342 -> Vg=1.0
% INFO    : Gen at bus 5828	: Pg=13.2, Qg=-3.42 -> Pg=19.99, Qg=0.83
% INFO    : Gen at bus 5828	: Vg=1.027766 -> Vg=1.0
% INFO    : Gen at bus 5831	: Pg=-179.4, Qg=-0.29 -> Pg=-69.6, Qg=0.42
% INFO    : Gen at bus 5831	: Vg=1.026046 -> Vg=1.0
% INFO    : Gen at bus 5838	: Pg=16.1, Qg=-2.61 -> Pg=8.455, Qg=-1.97
% INFO    : Gen at bus 5838	: Vg=1.030725 -> Vg=1.0
% INFO    : Gen at bus 5839	: Pg=101.4, Qg=13.53 -> Pg=60.0, Qg=16.125
% INFO    : Gen at bus 5839	: Vg=1.013483 -> Vg=1.0
% INFO    : Gen at bus 5844	: Pg=696.8, Qg=45.98 -> Pg=400.0, Qg=105.685
% INFO    : Gen at bus 5844	: Vg=1.050341 -> Vg=1.0
% INFO    : Gen at bus 5846	: Pg=-46.5, Qg=-7.47 -> Pg=19.0, Qg=-2.59
% INFO    : Gen at bus 5846	: Vg=1.02116 -> Vg=1.0
% INFO    : Gen at bus 5855	: Pg=453.4, Qg=62.66 -> Pg=533.335, Qg=131.165
% INFO    : Gen at bus 5855	: Vg=1.065097 -> Vg=1.0
% INFO    : Gen at bus 5856	: Pg=305.7, Qg=29.18 -> Pg=320.0, Qg=64.565
% INFO    : Gen at bus 5856	: Vg=1.036185 -> Vg=1.0
% INFO    : Gen at bus 5862	: Pg=68.2, Qg=12.09 -> Pg=40.0, Qg=10.805
% INFO    : Gen at bus 5862	: Vg=1.059582 -> Vg=1.0
% INFO    : Gen at bus 5863	: Pg=438.2, Qg=-35.2 -> Pg=533.335, Qg=113.18
% INFO    : Gen at bus 5863	: Vg=1.048267 -> Vg=1.0
% INFO    : Gen at bus 5864	: Pg=46.4, Qg=-0.25 -> Pg=24.36, Qg=0.96
% INFO    : Gen at bus 5864	: Vg=1.024889 -> Vg=1.0
% INFO    : Gen at bus 5868	: Pg=514.8, Qg=96.08 -> Pg=533.335, Qg=124.73
% INFO    : Gen at bus 5868	: Vg=1.048327 -> Vg=1.0
% INFO    : Gen at bus 5874	: Pg=16.16, Qg=3.36 -> Pg=55.385, Qg=15.97
% INFO    : Gen at bus 5874	: Vg=1.045045 -> Vg=1.0
% INFO    : Gen at bus 5881	: Pg=60.0, Qg=6.68 -> Pg=40.0, Qg=11.795
% INFO    : Gen at bus 5881	: Vg=1.056126 -> Vg=1.0
% INFO    : Gen at bus 5882	: Pg=106.8, Qg=12.2 -> Pg=60.0, Qg=15.575
% INFO    : Gen at bus 5882	: Vg=1.077465 -> Vg=1.0
% INFO    : Gen at bus 5883	: Pg=1031.4, Qg=513.54 -> Pg=800.0, Qg=158.73
% INFO    : Gen at bus 5883	: Vg=1.175144 -> Vg=1.0
% INFO    : Gen at bus 5885	: Pg=107.8, Qg=15.27 -> Pg=60.0, Qg=15.23
% INFO    : Gen at bus 5885	: Vg=1.031733 -> Vg=1.0
% INFO    : Gen at bus 5894	: Pg=182.6, Qg=67.91 -> Pg=100.0, Qg=24.955
% INFO    : Gen at bus 5894	: Vg=1.035315 -> Vg=1.0
% INFO    : Gen at bus 5896	: Pg=55.6, Qg=31.81 -> Pg=40.0, Qg=12.375
% INFO    : Gen at bus 5896	: Vg=0.986344 -> Vg=1.0
% INFO    : Gen at bus 5922	: Pg=-10.23, Qg=6.73 -> Pg=43.18, Qg=7.05
% INFO    : Gen at bus 5922	: Vg=1.030869 -> Vg=1.0
% INFO    : Gen at bus 5930	: Pg=155.19, Qg=8.0 -> Pg=82.46, Qg=18.455
% INFO    : Gen at bus 5930	: Vg=1.042525 -> Vg=1.0
% INFO    : Gen at bus 5940	: Pg=-74.9, Qg=4.4 -> Pg=0.065, Qg=4.74
% INFO    : Gen at bus 5940	: Vg=1.026879 -> Vg=1.0
% INFO    : Gen at bus 5941	: Pg=51.2, Qg=17.66 -> Pg=40.0, Qg=12.625
% INFO    : Gen at bus 5941	: Vg=1.051545 -> Vg=1.0
% INFO    : Gen at bus 5955	: Pg=-32.29, Qg=-0.25 -> Pg=28.475, Qg=12.895
% INFO    : Gen at bus 5955	: Vg=1.015926 -> Vg=1.0
% INFO    : Gen at bus 5964	: Pg=9.35, Qg=6.13 -> Pg=40.0, Qg=12.21
% INFO    : Gen at bus 5964	: Vg=1.005428 -> Vg=1.0
% INFO    : Gen at bus 5970	: Pg=127.57, Qg=-18.86 -> Pg=180.0, Qg=62.065
% INFO    : Gen at bus 5970	: Vg=1.017378 -> Vg=1.0
% INFO    : Gen at bus 5971	: Pg=1221.2, Qg=407.37 -> Pg=1333.335, Qg=321.45
% INFO    : Gen at bus 5971	: Vg=1.076888 -> Vg=1.0
% INFO    : Gen at bus 5973	: Pg=102.8, Qg=14.2 -> Pg=80.0, Qg=25.41
% INFO    : Gen at bus 5973	: Vg=1.055332 -> Vg=1.0
% INFO    : Gen at bus 5975	: Pg=60.4, Qg=13.58 -> Pg=40.0, Qg=11.09
% INFO    : Gen at bus 5975	: Vg=1.0347 -> Vg=1.0
% INFO    : Gen at bus 5977	: Pg=310.7, Qg=-35.81 -> Pg=266.665, Qg=57.32
% INFO    : Gen at bus 5977	: Vg=1.030489 -> Vg=1.0
% INFO    : Gen at bus 5980	: Pg=269.1, Qg=119.8 -> Pg=150.0, Qg=37.75
% INFO    : Gen at bus 5980	: Vg=1.05163 -> Vg=1.0
% INFO    : Gen at bus 5983	: Pg=-102.5, Qg=8.05 -> Pg=-18.335, Qg=12.34
% INFO    : Gen at bus 5983	: Vg=1.061878 -> Vg=1.0
% INFO    : Gen at bus 5985	: Pg=560.66, Qg=187.71 -> Pg=533.335, Qg=117.04
% INFO    : Gen at bus 5985	: Vg=1.120491 -> Vg=1.0
% INFO    : Gen at bus 5986	: Pg=1499.6, Qg=799.32 -> Pg=1333.335, Qg=271.38
% INFO    : Gen at bus 5986	: Vg=1.103376 -> Vg=1.0
% INFO    : Gen at bus 5988	: Pg=492.0, Qg=-44.29 -> Pg=533.335, Qg=128.26
% INFO    : Gen at bus 5988	: Vg=1.069038 -> Vg=1.0
% INFO    : Gen at bus 5991	: Pg=854.6, Qg=-175.04 -> Pg=800.0, Qg=150.15
% INFO    : Gen at bus 5991	: Vg=1.012716 -> Vg=1.0
% INFO    : Gen at bus 5994	: Pg=-87.3, Qg=-10.42 -> Pg=-8.2, Qg=-0.285
% INFO    : Gen at bus 5994	: Vg=1.036793 -> Vg=1.0
% INFO    : Gen at bus 5998	: Pg=-68.1, Qg=-3.53 -> Pg=4.6, Qg=-4.29
% INFO    : Gen at bus 5998	: Vg=1.02348 -> Vg=1.0
% INFO    : Gen at bus 6000	: Pg=617.7, Qg=335.83 -> Pg=600.0, Qg=136.225
% INFO    : Gen at bus 6000	: Vg=1.085353 -> Vg=1.0
% INFO    : Gen at bus 6001	: Pg=19.2, Qg=-1.86 -> Pg=10.05, Qg=-0.295
% INFO    : Gen at bus 6001	: Vg=1.036406 -> Vg=1.0
% INFO    : Gen at bus 6033	: Pg=49.87, Qg=10.06 -> Pg=60.0, Qg=19.465
% INFO    : Gen at bus 6033	: Vg=1.013332 -> Vg=1.0
% INFO    : Gen at bus 6036	: Pg=820.2, Qg=289.17 -> Pg=600.0, Qg=114.62
% INFO    : Gen at bus 6036	: Vg=1.036335 -> Vg=1.0
% INFO    : Gen at bus 6046	: Pg=636.63, Qg=-101.82 -> Pg=533.335, Qg=106.355
% INFO    : Gen at bus 6046	: Vg=1.094629 -> Vg=1.0
% INFO    : Gen at bus 6086	: Pg=88.2, Qg=-11.17 -> Pg=46.305, Qg=-7.99
% INFO    : Gen at bus 6086	: Vg=1.017402 -> Vg=1.0
% INFO    : Gen at bus 6088	: Pg=-278.2, Qg=6.05 -> Pg=-135.465, Qg=9.765
% INFO    : Gen at bus 6088	: Vg=1.069764 -> Vg=1.0
% INFO    : Gen at bus 6090	: Pg=60.4, Qg=6.35 -> Pg=40.0, Qg=11.675
% INFO    : Gen at bus 6090	: Vg=1.030088 -> Vg=1.0
% INFO    : Gen at bus 6092	: Pg=774.9, Qg=-107.4 -> Pg=600.0, Qg=119.855
% INFO    : Gen at bus 6092	: Vg=1.035378 -> Vg=1.0
% INFO    : Gen at bus 6100	: Pg=-139.51, Qg=5.48 -> Pg=-43.005, Qg=63.04
% INFO    : Gen at bus 6100	: Vg=1.041341 -> Vg=1.0
% INFO    : Gen at bus 6103	: Pg=164.5, Qg=2.74 -> Pg=200.0, Qg=49.51
% INFO    : Gen at bus 6103	: Vg=1.013429 -> Vg=1.0
% INFO    : Gen at bus 6105	: Pg=84.9, Qg=42.02 -> Pg=60.0, Qg=18.33
% INFO    : Gen at bus 6105	: Vg=1.010683 -> Vg=1.0
% INFO    : Gen at bus 6120	: Pg=58.6, Qg=28.58 -> Pg=40.0, Qg=11.83
% INFO    : Gen at bus 6120	: Vg=1.024222 -> Vg=1.0
% INFO    : Gen at bus 6124	: Pg=490.0, Qg=49.36 -> Pg=526.665, Qg=65.33
% INFO    : Gen at bus 6124	: Vg=1.025031 -> Vg=1.0
% INFO    : Gen at bus 6129	: Pg=356.0, Qg=89.29 -> Pg=266.665, Qg=50.845
% INFO    : Gen at bus 6129	: Vg=1.033744 -> Vg=1.0
% INFO    : Gen at bus 6130	: Pg=49.4, Qg=21.24 -> Pg=40.0, Qg=12.78
% INFO    : Gen at bus 6130	: Vg=1.026444 -> Vg=1.0
% INFO    : Gen at bus 6131	: Pg=602.4, Qg=295.03 -> Pg=600.0, Qg=139.465
% INFO    : Gen at bus 6131	: Vg=1.133869 -> Vg=1.0
% INFO    : Gen at bus 6138	: Pg=-121.9, Qg=1.77 -> Pg=-31.265, Qg=4.46
% INFO    : Gen at bus 6138	: Vg=1.010882 -> Vg=1.0
% INFO    : Gen at bus 6144	: Pg=9.9, Qg=0.42 -> Pg=5.02, Qg=1.09
% INFO    : Gen at bus 6144	: Vg=0.987224 -> Vg=1.0
% INFO    : Gen at bus 6145	: Pg=190.58, Qg=-4.95 -> Pg=120.0, Qg=31.08
% INFO    : Gen at bus 6145	: Vg=1.019556 -> Vg=1.0
% INFO    : Gen at bus 6153	: Pg=94.3, Qg=-49.05 -> Pg=401.01, Qg=-6.085
% INFO    : Gen at bus 6153	: Vg=1.019885 -> Vg=1.0
% INFO    : Gen at bus 6168	: Pg=26.3, Qg=-0.36 -> Pg=26.88, Qg=2.465
% INFO    : Gen at bus 6168	: Vg=1.047693 -> Vg=1.0
% INFO    : Gen at bus 6169	: Pg=-85.8, Qg=12.05 -> Pg=-7.2, Qg=13.605
% INFO    : Gen at bus 6169	: Vg=1.033616 -> Vg=1.0
% INFO    : Gen at bus 6175	: Pg=405.8, Qg=58.75 -> Pg=213.045, Qg=55.555
% INFO    : Gen at bus 6175	: Vg=1.023886 -> Vg=1.0
% INFO    : Gen at bus 6179	: Pg=65.9, Qg=4.7 -> Pg=40.0, Qg=10.51
% INFO    : Gen at bus 6179	: Vg=1.036613 -> Vg=1.0
% INFO    : Gen at bus 6181	: Pg=540.0, Qg=-67.57 -> Pg=384.0, Qg=30.475
% INFO    : Gen at bus 6181	: Vg=1.000322 -> Vg=1.0
% INFO    : Gen at bus 6182	: Pg=55.8, Qg=9.34 -> Pg=60.0, Qg=20.615
% INFO    : Gen at bus 6182	: Vg=1.054529 -> Vg=1.0
% INFO    : Gen at bus 6201	: Pg=310.4, Qg=21.09 -> Pg=266.665, Qg=56.36
% INFO    : Gen at bus 6201	: Vg=1.049209 -> Vg=1.0
% INFO    : Gen at bus 6204	: Pg=767.5, Qg=-119.16 -> Pg=666.665, Qg=141.285
% INFO    : Gen at bus 6204	: Vg=1.02934 -> Vg=1.0
% INFO    : Gen at bus 6207	: Pg=411.8, Qg=63.77 -> Pg=400.0, Qg=90.555
% INFO    : Gen at bus 6207	: Vg=1.03672 -> Vg=1.0
% INFO    : Gen at bus 6233	: Pg=879.6, Qg=255.34 -> Pg=800.0, Qg=177.855
% INFO    : Gen at bus 6233	: Vg=1.017658 -> Vg=1.0
% INFO    : Gen at bus 6237	: Pg=-83.33, Qg=-1.84 -> Pg=-5.555, Qg=-0.615
% INFO    : Gen at bus 6237	: Vg=1.01301 -> Vg=1.0
% INFO    : Gen at bus 6239	: Pg=5.3, Qg=-0.18 -> Pg=2.66, Qg=0.585
% INFO    : Gen at bus 6239	: Vg=1.026501 -> Vg=1.0
% INFO    : Gen at bus 6242	: Pg=81.3, Qg=8.95 -> Pg=60.0, Qg=18.22
% INFO    : Gen at bus 6242	: Vg=1.018892 -> Vg=1.0
% INFO    : Gen at bus 6249	: Pg=333.2, Qg=132.94 -> Pg=266.665, Qg=54.54
% INFO    : Gen at bus 6249	: Vg=1.040939 -> Vg=1.0
% INFO    : Gen at bus 6270	: Pg=450.4, Qg=-124.7 -> Pg=236.46, Qg=38.525
% INFO    : Gen at bus 6270	: Vg=1.02754 -> Vg=1.0
% INFO    : Gen at bus 6279	: Pg=-32.89, Qg=10.48 -> Pg=28.075, Qg=13.2
% INFO    : Gen at bus 6279	: Vg=1.008432 -> Vg=1.0
% INFO    : Gen at bus 6280	: Pg=117.9, Qg=4.51 -> Pg=60.0, Qg=13.88
% INFO    : Gen at bus 6280	: Vg=1.017343 -> Vg=1.0
% INFO    : Gen at bus 6284	: Pg=91.9, Qg=18.24 -> Pg=50.0, Qg=12.055
% INFO    : Gen at bus 6284	: Vg=1.057119 -> Vg=1.0
% INFO    : Gen at bus 6291	: Pg=55.5, Qg=30.11 -> Pg=60.0, Qg=20.76
% INFO    : Gen at bus 6291	: Vg=1.036939 -> Vg=1.0
% INFO    : Gen at bus 6329	: Pg=223.4, Qg=3.69 -> Pg=200.0, Qg=42.465
% INFO    : Gen at bus 6329	: Vg=0.991058 -> Vg=1.0
% INFO    : Gen at bus 6331	: Pg=48.8, Qg=5.91 -> Pg=40.0, Qg=12.855
% INFO    : Gen at bus 6331	: Vg=1.050971 -> Vg=1.0
% INFO    : Gen at bus 6332	: Pg=96.0, Qg=-5.55 -> Pg=100.0, Qg=34.305
% INFO    : Gen at bus 6332	: Vg=1.065904 -> Vg=1.0
% INFO    : Gen at bus 6334	: Pg=66.6, Qg=17.6 -> Pg=60.0, Qg=19.44
% INFO    : Gen at bus 6334	: Vg=1.005334 -> Vg=1.0
% INFO    : Gen at bus 6338	: Pg=29.5, Qg=0.45 -> Pg=29.99, Qg=2.53
% INFO    : Gen at bus 6338	: Vg=1.022507 -> Vg=1.0
% INFO    : Gen at bus 6351	: Pg=22.08, Qg=13.57 -> Pg=40.0, Qg=13.365
% INFO    : Gen at bus 6351	: Vg=1.0521 -> Vg=1.0
% INFO    : Gen at bus 6358	: Pg=40.79, Qg=28.9 -> Pg=40.0, Qg=12.785
% INFO    : Gen at bus 6358	: Vg=0.986287 -> Vg=1.0
% INFO    : Gen at bus 6366	: Pg=188.9, Qg=27.37 -> Pg=200.0, Qg=47.225
% INFO    : Gen at bus 6366	: Vg=1.077817 -> Vg=1.0
% INFO    : Gen at bus 6368	: Pg=-145.3, Qg=11.76 -> Pg=-46.865, Qg=13.825
% INFO    : Gen at bus 6368	: Vg=1.042432 -> Vg=1.0
% INFO    : Gen at bus 6370	: Pg=450.4, Qg=48.2 -> Pg=358.665, Qg=50.695
% INFO    : Gen at bus 6370	: Vg=1.014839 -> Vg=1.0
% INFO    : Gen at bus 6373	: Pg=-201.0, Qg=1.6 -> Pg=-84.0, Qg=22.72
% INFO    : Gen at bus 6373	: Vg=1.04869 -> Vg=1.0
% INFO    : Gen at bus 6374	: Pg=318.4, Qg=-54.24 -> Pg=200.0, Qg=54.275
% INFO    : Gen at bus 6374	: Vg=1.077431 -> Vg=1.0
% INFO    : Gen at bus 6376	: Pg=-27.8, Qg=-13.24 -> Pg=31.465, Qg=48.96
% INFO    : Gen at bus 6376	: Vg=1.044986 -> Vg=1.0
% INFO    : Gen at bus 6403	: Pg=52.8, Qg=-4.9 -> Pg=27.72, Qg=-6.87
% INFO    : Gen at bus 6403	: Vg=1.020309 -> Vg=1.0
% INFO    : Gen at bus 6410	: Pg=-57.0, Qg=-18.17 -> Pg=12.0, Qg=-3.135
% INFO    : Gen at bus 6410	: Vg=1.044406 -> Vg=1.0
% INFO    : Gen at bus 6413	: Pg=958.2, Qg=465.98 -> Pg=800.0, Qg=169.2
% INFO    : Gen at bus 6413	: Vg=1.044796 -> Vg=1.0
% INFO    : Gen at bus 6415	: Pg=310.83, Qg=46.0 -> Pg=450.0, Qg=22.4
% INFO    : Gen at bus 6415	: Vg=0.983673 -> Vg=1.0
% INFO    : Gen at bus 6419	: Pg=1156.8, Qg=483.73 -> Pg=800.0, Qg=139.69
% INFO    : Gen at bus 6419	: Vg=1.095905 -> Vg=1.0
% INFO    : Gen at bus 6429	: Pg=171.0, Qg=19.61 -> Pg=100.0, Qg=26.57
% INFO    : Gen at bus 6429	: Vg=1.035857 -> Vg=1.0
% INFO    : Gen at bus 6432	: Pg=291.2, Qg=-18.62 -> Pg=200.0, Qg=58.365
% INFO    : Gen at bus 6432	: Vg=1.049448 -> Vg=1.0
% INFO    : Gen at bus 6434	: Pg=767.52, Qg=155.73 -> Pg=800.0, Qg=183.3
% INFO    : Gen at bus 6434	: Vg=1.116905 -> Vg=1.0
% INFO    : Gen at bus 6436	: Pg=-86.5, Qg=-0.2 -> Pg=-7.67, Qg=0.61
% INFO    : Gen at bus 6436	: Vg=1.01064 -> Vg=1.0
% INFO    : Gen at bus 6448	: Pg=19.39, Qg=11.37 -> Pg=20.0, Qg=5.865
% INFO    : Gen at bus 6448	: Vg=1.004995 -> Vg=1.0
% INFO    : Gen at bus 6458	: Pg=91.2, Qg=-2.12 -> Pg=50.0, Qg=12.425
% INFO    : Gen at bus 6458	: Vg=1.078056 -> Vg=1.0
% INFO    : Gen at bus 6459	: Pg=77.4, Qg=21.19 -> Pg=90.0, Qg=30.96
% INFO    : Gen at bus 6459	: Vg=1.005175 -> Vg=1.0
% INFO    : Gen at bus 6474	: Pg=718.5, Qg=-17.68 -> Pg=666.665, Qg=132.285
% INFO    : Gen at bus 6474	: Vg=1.055298 -> Vg=1.0
% INFO    : Gen at bus 6483	: Pg=86.3, Qg=5.42 -> Pg=60.0, Qg=17.915
% INFO    : Gen at bus 6483	: Vg=1.064876 -> Vg=1.0
% INFO    : Gen at bus 6484	: Pg=1168.8, Qg=-39.57 -> Pg=800.0, Qg=140.36
% INFO    : Gen at bus 6484	: Vg=1.024853 -> Vg=1.0
% INFO    : Gen at bus 6492	: Pg=304.8, Qg=-9.69 -> Pg=266.665, Qg=57.51
% INFO    : Gen at bus 6492	: Vg=1.004319 -> Vg=1.0
% INFO    : Gen at bus 6497	: Pg=701.6, Qg=89.4 -> Pg=533.335, Qg=103.49
% INFO    : Gen at bus 6497	: Vg=1.064333 -> Vg=1.0
% INFO    : Gen at bus 6498	: Pg=187.8, Qg=-11.92 -> Pg=98.595, Qg=-19.35
% INFO    : Gen at bus 6498	: Vg=1.019 -> Vg=1.0
% INFO    : Gen at bus 6502	: Pg=44.99, Qg=12.84 -> Pg=40.0, Qg=12.685
% INFO    : Gen at bus 6502	: Vg=1.002332 -> Vg=1.0
% INFO    : Gen at bus 6516	: Pg=228.2, Qg=0.52 -> Pg=140.0, Qg=39.45
% INFO    : Gen at bus 6516	: Vg=1.050158 -> Vg=1.0
% INFO    : Gen at bus 6518	: Pg=1254.0, Qg=-198.78 -> Pg=938.665, Qg=-98.81
% INFO    : Gen at bus 6518	: Vg=0.999167 -> Vg=1.0
% INFO    : Gen at bus 6525	: Pg=16.0, Qg=-2.44 -> Pg=8.4, Qg=-1.88
% INFO    : Gen at bus 6525	: Vg=1.007591 -> Vg=1.0
% INFO    : Gen at bus 6552	: Pg=-204.2, Qg=12.17 -> Pg=-86.135, Qg=12.71
% INFO    : Gen at bus 6552	: Vg=1.045563 -> Vg=1.0
% INFO    : Gen at bus 6587	: Pg=56.1, Qg=-6.68 -> Pg=29.455, Qg=-5.535
% INFO    : Gen at bus 6587	: Vg=1.017615 -> Vg=1.0
% INFO    : Gen at bus 6591	: Pg=209.39, Qg=1.22 -> Pg=266.665, Qg=65.92
% INFO    : Gen at bus 6591	: Vg=1.040735 -> Vg=1.0
% INFO    : Gen at bus 6594	: Pg=488.87, Qg=91.52 -> Pg=600.0, Qg=138.63
% INFO    : Gen at bus 6594	: Vg=1.022988 -> Vg=1.0
% INFO    : Gen at bus 6608	: Pg=-22.07, Qg=8.66 -> Pg=35.285, Qg=17.0
% INFO    : Gen at bus 6608	: Vg=1.019233 -> Vg=1.0
% INFO    : Gen at bus 6621	: Pg=290.3, Qg=-54.73 -> Pg=150.0, Qg=33.74
% INFO    : Gen at bus 6621	: Vg=1.077535 -> Vg=1.0
% INFO    : Gen at bus 6626	: Pg=31.9, Qg=7.47 -> Pg=20.0, Qg=5.83
% INFO    : Gen at bus 6626	: Vg=1.042091 -> Vg=1.0
% INFO    : Gen at bus 6627	: Pg=99.5, Qg=5.37 -> Pg=66.665, Qg=11.455
% INFO    : Gen at bus 6627	: Vg=1.064448 -> Vg=1.0
% INFO    : Gen at bus 6632	: Pg=2013.9, Qg=-432.25 -> Pg=2000.0, Qg=459.55
% INFO    : Gen at bus 6632	: Vg=1.057948 -> Vg=1.0
% INFO    : Gen at bus 6641	: Pg=37.8, Qg=20.26 -> Pg=40.0, Qg=13.67
% INFO    : Gen at bus 6641	: Vg=1.007887 -> Vg=1.0
% INFO    : Gen at bus 6654	: Pg=742.76, Qg=-57.91 -> Pg=533.335, Qg=91.89
% INFO    : Gen at bus 6654	: Vg=1.021829 -> Vg=1.0
% INFO    : Gen at bus 6656	: Pg=249.0, Qg=-27.52 -> Pg=150.0, Qg=39.82
% INFO    : Gen at bus 6656	: Vg=1.021248 -> Vg=1.0
% INFO    : Gen at bus 6661	: Pg=79.9, Qg=35.8 -> Pg=50.0, Qg=13.835
% INFO    : Gen at bus 6661	: Vg=0.997723 -> Vg=1.0
% INFO    : Gen at bus 6680	: Pg=41.41, Qg=5.89 -> Pg=30.0, Qg=9.745
% INFO    : Gen at bus 6680	: Vg=1.025575 -> Vg=1.0
% INFO    : Gen at bus 6681	: Pg=21.3, Qg=-20.42 -> Pg=54.19, Qg=0.36
% INFO    : Gen at bus 6681	: Vg=1.067534 -> Vg=1.0
% INFO    : Gen at bus 6703	: Pg=989.7, Qg=-97.77 -> Pg=800.0, Qg=166.055
% INFO    : Gen at bus 6703	: Vg=1.089943 -> Vg=1.0
% INFO    : Gen at bus 6715	: Pg=32.8, Qg=1.23 -> Pg=20.0, Qg=5.565
% INFO    : Gen at bus 6715	: Vg=1.025113 -> Vg=1.0
% INFO    : Gen at bus 6734	: Pg=382.7, Qg=-66.68 -> Pg=360.0, Qg=89.715
% INFO    : Gen at bus 6734	: Vg=1.061659 -> Vg=1.0
% INFO    : Gen at bus 6736	: Pg=670.8, Qg=138.75 -> Pg=600.0, Qg=130.46
% INFO    : Gen at bus 6736	: Vg=1.032666 -> Vg=1.0
% INFO    : Gen at bus 6739	: Pg=59.4, Qg=-5.89 -> Pg=40.0, Qg=11.98
% INFO    : Gen at bus 6739	: Vg=1.07283 -> Vg=1.0
% INFO    : Gen at bus 6753	: Pg=68.2, Qg=20.16 -> Pg=40.0, Qg=10.925
% INFO    : Gen at bus 6753	: Vg=1.045824 -> Vg=1.0
% INFO    : Gen at bus 6756	: Pg=32.2, Qg=5.92 -> Pg=30.0, Qg=9.835
% INFO    : Gen at bus 6756	: Vg=1.025997 -> Vg=1.0
% INFO    : Gen at bus 6764	: Pg=9.9, Qg=0.34 -> Pg=4.995, Qg=1.105
% INFO    : Gen at bus 6764	: Vg=0.99015 -> Vg=1.0
% INFO    : Gen at bus 6778	: Pg=276.8, Qg=66.94 -> Pg=266.665, Qg=60.69
% INFO    : Gen at bus 6778	: Vg=1.038013 -> Vg=1.0
% INFO    : Gen at bus 6780	: Pg=14.5, Qg=-0.39 -> Pg=17.025, Qg=1.31
% INFO    : Gen at bus 6780	: Vg=1.074673 -> Vg=1.0
% INFO    : Gen at bus 6793	: Pg=32.6, Qg=-1.29 -> Pg=30.0, Qg=9.8
% INFO    : Gen at bus 6793	: Vg=1.049876 -> Vg=1.0
% INFO    : Gen at bus 6798	: Pg=949.7, Qg=178.3 -> Pg=666.665, Qg=123.065
% INFO    : Gen at bus 6798	: Vg=1.018682 -> Vg=1.0
% INFO    : Gen at bus 6807	: Pg=44.07, Qg=25.54 -> Pg=80.0, Qg=27.34
% INFO    : Gen at bus 6807	: Vg=1.025274 -> Vg=1.0
% INFO    : Gen at bus 6811	: Pg=113.9, Qg=-24.22 -> Pg=100.0, Qg=31.96
% INFO    : Gen at bus 6811	: Vg=1.093866 -> Vg=1.0
% INFO    : Gen at bus 6816	: Pg=16.53, Qg=-4.05 -> Pg=80.0, Qg=27.545
% INFO    : Gen at bus 6816	: Vg=1.062526 -> Vg=1.0
% INFO    : Gen at bus 6820	: Pg=15.9, Qg=-0.62 -> Pg=16.265, Qg=1.465
% INFO    : Gen at bus 6820	: Vg=1.047984 -> Vg=1.0
% INFO    : Gen at bus 6822	: Pg=251.0, Qg=16.22 -> Pg=150.0, Qg=39.725
% INFO    : Gen at bus 6822	: Vg=1.039383 -> Vg=1.0
% INFO    : Gen at bus 6831	: Pg=-57.5, Qg=6.93 -> Pg=11.665, Qg=10.685
% INFO    : Gen at bus 6831	: Vg=1.031732 -> Vg=1.0
% INFO    : Gen at bus 6838	: Pg=578.0, Qg=215.46 -> Pg=400.0, Qg=71.46
% INFO    : Gen at bus 6838	: Vg=1.050849 -> Vg=1.0
% INFO    : Gen at bus 6843	: Pg=60.67, Qg=34.01 -> Pg=60.0, Qg=17.36
% INFO    : Gen at bus 6843	: Vg=1.013427 -> Vg=1.0
% INFO    : Gen at bus 6845	: Pg=102.9, Qg=16.22 -> Pg=60.0, Qg=15.885
% INFO    : Gen at bus 6845	: Vg=1.045173 -> Vg=1.0
% INFO    : Gen at bus 6847	: Pg=297.7, Qg=171.1 -> Pg=200.0, Qg=58.835
% INFO    : Gen at bus 6847	: Vg=1.018848 -> Vg=1.0
% INFO    : Gen at bus 6850	: Pg=30.0, Qg=-0.94 -> Pg=15.75, Qg=-0.72
% INFO    : Gen at bus 6850	: Vg=1.010801 -> Vg=1.0
% INFO    : Gen at bus 6852	: Pg=-344.9, Qg=4.29 -> Pg=-179.935, Qg=6.11
% INFO    : Gen at bus 6852	: Vg=1.034908 -> Vg=1.0
% INFO    : Gen at bus 6857	: Pg=2463.6, Qg=394.19 -> Pg=2666.665, Qg=639.94
% INFO    : Gen at bus 6857	: Vg=1.018722 -> Vg=1.0
% INFO    : Gen at bus 6861	: Pg=-76.4, Qg=14.66 -> Pg=-0.935, Qg=13.445
% INFO    : Gen at bus 6861	: Vg=1.037118 -> Vg=1.0
% INFO    : Gen at bus 6864	: Pg=64.6, Qg=27.73 -> Pg=40.0, Qg=11.165
% INFO    : Gen at bus 6864	: Vg=1.020438 -> Vg=1.0
% INFO    : Gen at bus 6868	: Pg=48.5, Qg=-5.97 -> Pg=25.46, Qg=-6.66
% INFO    : Gen at bus 6868	: Vg=1.042934 -> Vg=1.0
% INFO    : Gen at bus 6874	: Pg=362.8, Qg=112.78 -> Pg=266.665, Qg=49.785
% INFO    : Gen at bus 6874	: Vg=1.03371 -> Vg=1.0
% INFO    : Gen at bus 6877	: Pg=19.8, Qg=-11.51 -> Pg=50.255, Qg=0.31
% INFO    : Gen at bus 6877	: Vg=1.062542 -> Vg=1.0
% INFO    : Gen at bus 6888	: Pg=133.0, Qg=2.32 -> Pg=194.335, Qg=64.72
% INFO    : Gen at bus 6888	: Vg=1.046712 -> Vg=1.0
% INFO    : Gen at bus 6893	: Pg=306.6, Qg=-51.67 -> Pg=242.665, Qg=-15.99
% INFO    : Gen at bus 6893	: Vg=1.002405 -> Vg=1.0
% INFO    : Gen at bus 6900	: Pg=420.5, Qg=-72.58 -> Pg=333.335, Qg=65.665
% INFO    : Gen at bus 6900	: Vg=1.08427 -> Vg=1.0
% INFO    : Gen at bus 6907	: Pg=520.5, Qg=21.03 -> Pg=380.0, Qg=90.29
% INFO    : Gen at bus 6907	: Vg=1.059798 -> Vg=1.0
% INFO    : Gen at bus 6910	: Pg=116.8, Qg=45.51 -> Pg=147.915, Qg=8.855
% INFO    : Gen at bus 6910	: Vg=1.028742 -> Vg=1.0
% INFO    : Gen at bus 6914	: Pg=173.4, Qg=-21.81 -> Pg=100.0, Qg=25.965
% INFO    : Gen at bus 6914	: Vg=1.083288 -> Vg=1.0
% INFO    : Gen at bus 6920	: Pg=-9.7, Qg=-5.58 -> Pg=43.535, Qg=-5.23
% INFO    : Gen at bus 6920	: Vg=1.008862 -> Vg=1.0
% INFO    : Gen at bus 6924	: Pg=131.2, Qg=16.98 -> Pg=88.56, Qg=15.31
% INFO    : Gen at bus 6924	: Vg=1.02139 -> Vg=1.0
% INFO    : Gen at bus 6930	: Pg=98.3, Qg=-1.8 -> Pg=116.22, Qg=8.935
% INFO    : Gen at bus 6930	: Vg=1.047953 -> Vg=1.0
% INFO    : Gen at bus 6934	: Pg=-42.68, Qg=2.17 -> Pg=21.545, Qg=9.715
% INFO    : Gen at bus 6934	: Vg=1.059171 -> Vg=1.0
% INFO    : Gen at bus 6936	: Pg=665.8, Qg=-96.62 -> Pg=600.0, Qg=113.03
% INFO    : Gen at bus 6936	: Vg=1.022407 -> Vg=1.0
% INFO    : Gen at bus 6937	: Pg=156.62, Qg=-9.6 -> Pg=250.0, Qg=65.595
% INFO    : Gen at bus 6937	: Vg=1.025063 -> Vg=1.0
% INFO    : Gen at bus 6947	: Pg=227.5, Qg=-8.57 -> Pg=140.0, Qg=38.9
% INFO    : Gen at bus 6947	: Vg=1.049432 -> Vg=1.0
% INFO    : Gen at bus 6948	: Pg=319.2, Qg=167.0 -> Pg=200.0, Qg=56.58
% INFO    : Gen at bus 6948	: Vg=1.010398 -> Vg=1.0
% INFO    : Gen at bus 6950	: Pg=10.6, Qg=-3.02 -> Pg=15.75, Qg=-1.15
% INFO    : Gen at bus 6950	: Vg=1.020998 -> Vg=1.0
% INFO    : Gen at bus 6967	: Pg=269.0, Qg=0.93 -> Pg=266.665, Qg=61.9
% INFO    : Gen at bus 6967	: Vg=1.065194 -> Vg=1.0
% INFO    : Gen at bus 6969	: Pg=39.8, Qg=1.1 -> Pg=40.0, Qg=13.63
% INFO    : Gen at bus 6969	: Vg=1.069563 -> Vg=1.0
% INFO    : Gen at bus 6982	: Pg=-12.6, Qg=16.76 -> Pg=41.6, Qg=18.89
% INFO    : Gen at bus 6982	: Vg=1.039641 -> Vg=1.0
% INFO    : Gen at bus 6993	: Pg=152.19, Qg=49.0 -> Pg=100.0, Qg=28.32
% INFO    : Gen at bus 6993	: Vg=1.069361 -> Vg=1.0
% INFO    : Gen at bus 6999	: Pg=1780.9, Qg=-177.13 -> Pg=1333.335, Qg=249.04
% INFO    : Gen at bus 6999	: Vg=1.083106 -> Vg=1.0
% INFO    : Gen at bus 7008	: Pg=862.0, Qg=77.66 -> Pg=480.0, Qg=107.345
% INFO    : Gen at bus 7008	: Vg=1.04776 -> Vg=1.0
% INFO    : Gen at bus 7025	: Pg=-199.6, Qg=5.74 -> Pg=-83.065, Qg=5.125
% INFO    : Gen at bus 7025	: Vg=1.027158 -> Vg=1.0
% INFO    : Gen at bus 7027	: Pg=77.3, Qg=13.79 -> Pg=200.0, Qg=50.905
% INFO    : Gen at bus 7027	: Vg=1.043049 -> Vg=1.0
% INFO    : Gen at bus 7028	: Pg=438.5, Qg=206.5 -> Pg=333.335, Qg=65.82
% INFO    : Gen at bus 7028	: Vg=1.031022 -> Vg=1.0
% INFO    : Gen at bus 7029	: Pg=1152.7, Qg=-190.53 -> Pg=800.0, Qg=140.5
% INFO    : Gen at bus 7029	: Vg=1.058412 -> Vg=1.0
% INFO    : Gen at bus 7032	: Pg=204.0, Qg=38.47 -> Pg=107.1, Qg=30.085
% INFO    : Gen at bus 7032	: Vg=1.004806 -> Vg=1.0
% INFO    : Gen at bus 7033	: Pg=182.88, Qg=30.29 -> Pg=266.665, Qg=67.795
% INFO    : Gen at bus 7033	: Vg=1.098728 -> Vg=1.0
% INFO    : Gen at bus 7036	: Pg=65.8, Qg=9.66 -> Pg=40.0, Qg=11.22
% INFO    : Gen at bus 7036	: Vg=1.038394 -> Vg=1.0
% INFO    : Gen at bus 7049	: Pg=55.5, Qg=15.24 -> Pg=60.0, Qg=20.81
% INFO    : Gen at bus 7049	: Vg=1.052472 -> Vg=1.0
% INFO    : Gen at bus 7056	: Pg=448.85, Qg=159.76 -> Pg=400.0, Qg=83.19
% INFO    : Gen at bus 7056	: Vg=1.000187 -> Vg=1.0
% INFO    : Gen at bus 7058	: Pg=50.4, Qg=8.58 -> Pg=40.0, Qg=12.695
% INFO    : Gen at bus 7058	: Vg=1.040913 -> Vg=1.0
% INFO    : Gen at bus 7063	: Pg=423.2, Qg=-30.87 -> Pg=333.335, Qg=67.385
% INFO    : Gen at bus 7063	: Vg=1.059581 -> Vg=1.0
% INFO    : Gen at bus 7065	: Pg=199.5, Qg=-7.58 -> Pg=200.0, Qg=45.095
% INFO    : Gen at bus 7065	: Vg=1.019881 -> Vg=1.0
% INFO    : Gen at bus 7075	: Pg=-49.37, Qg=-2.12 -> Pg=17.085, Qg=0.76
% INFO    : Gen at bus 7075	: Vg=1.019093 -> Vg=1.0
% INFO    : Gen at bus 7085	: Pg=292.8, Qg=106.83 -> Pg=150.0, Qg=34.905
% INFO    : Gen at bus 7085	: Vg=1.044403 -> Vg=1.0
% INFO    : Gen at bus 7089	: Pg=-178.8, Qg=9.96 -> Pg=-69.2, Qg=13.455
% INFO    : Gen at bus 7089	: Vg=1.081026 -> Vg=1.0
% INFO    : Gen at bus 7093	: Pg=119.2, Qg=80.4 -> Pg=100.0, Qg=31.86
% INFO    : Gen at bus 7093	: Vg=1.03985 -> Vg=1.0
% INFO    : Gen at bus 7104	: Pg=234.2, Qg=6.25 -> Pg=200.0, Qg=41.365
% INFO    : Gen at bus 7104	: Vg=1.002634 -> Vg=1.0
% INFO    : Gen at bus 7107	: Pg=9.5, Qg=-8.39 -> Pg=53.165, Qg=54.945
% INFO    : Gen at bus 7107	: Vg=1.040026 -> Vg=1.0
% INFO    : Gen at bus 7113	: Pg=159.8, Qg=-17.04 -> Pg=83.895, Qg=3.665
% INFO    : Gen at bus 7113	: Vg=1.033847 -> Vg=1.0
% INFO    : Gen at bus 7114	: Pg=-207.1, Qg=15.82 -> Pg=-88.065, Qg=17.015
% INFO    : Gen at bus 7114	: Vg=1.083134 -> Vg=1.0
% INFO    : Gen at bus 7115	: Pg=65.87, Qg=0.7 -> Pg=136.14, Qg=5.86
% INFO    : Gen at bus 7115	: Vg=1.026738 -> Vg=1.0
% INFO    : Gen at bus 7128	: Pg=490.0, Qg=-59.58 -> Pg=526.665, Qg=62.39
% INFO    : Gen at bus 7128	: Vg=1.007918 -> Vg=1.0
% INFO    : Gen at bus 7134	: Pg=73.3, Qg=-17.37 -> Pg=47.25, Qg=-6.58
% INFO    : Gen at bus 7134	: Vg=1.039671 -> Vg=1.0
% INFO    : Gen at bus 7137	: Pg=876.4, Qg=-76.31 -> Pg=800.0, Qg=148.43
% INFO    : Gen at bus 7137	: Vg=1.024472 -> Vg=1.0
% INFO    : Gen at bus 7153	: Pg=13.48, Qg=5.86 -> Pg=20.0, Qg=5.15
% INFO    : Gen at bus 7153	: Vg=1.034539 -> Vg=1.0
% INFO    : Gen at bus 7159	: Pg=861.3, Qg=135.91 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 7159	: Vg=1.055132 -> Vg=1.0
% INFO    : Gen at bus 7166	: Pg=54.66, Qg=32.86 -> Pg=60.0, Qg=17.73
% INFO    : Gen at bus 7166	: Vg=1.002006 -> Vg=1.0
% INFO    : Gen at bus 7169	: Pg=56.4, Qg=0.64 -> Pg=40.0, Qg=12.145
% INFO    : Gen at bus 7169	: Vg=1.087809 -> Vg=1.0
% INFO    : Gen at bus 7183	: Pg=1250.6, Qg=365.49 -> Pg=1333.335, Qg=314.42
% INFO    : Gen at bus 7183	: Vg=1.104721 -> Vg=1.0
% INFO    : Gen at bus 7200	: Pg=177.08, Qg=60.6 -> Pg=100.0, Qg=23.785
% INFO    : Gen at bus 7200	: Vg=1.022531 -> Vg=1.0
% INFO    : Gen at bus 7207	: Pg=119.2, Qg=80.35 -> Pg=100.0, Qg=31.86
% INFO    : Gen at bus 7207	: Vg=1.039936 -> Vg=1.0
% INFO    : Gen at bus 7209	: Pg=7.3, Qg=-0.12 -> Pg=3.675, Qg=0.83
% INFO    : Gen at bus 7209	: Vg=1.049275 -> Vg=1.0
% INFO    : Gen at bus 7212	: Pg=66.3, Qg=-0.62 -> Pg=101.35, Qg=4.1
% INFO    : Gen at bus 7212	: Vg=1.021331 -> Vg=1.0
% INFO    : Gen at bus 7214	: Pg=359.1, Qg=-8.29 -> Pg=266.665, Qg=52.07
% INFO    : Gen at bus 7214	: Vg=1.0752 -> Vg=1.0
% INFO    : Gen at bus 7223	: Pg=49.0, Qg=-11.8 -> Pg=25.81, Qg=-6.41
% INFO    : Gen at bus 7223	: Vg=1.018777 -> Vg=1.0
% INFO    : Gen at bus 7227	: Pg=650.0, Qg=-60.82 -> Pg=486.665, Qg=22.785
% INFO    : Gen at bus 7227	: Vg=1.008346 -> Vg=1.0
% INFO    : Gen at bus 7228	: Pg=524.9, Qg=358.08 -> Pg=533.335, Qg=125.015
% INFO    : Gen at bus 7228	: Vg=1.172784 -> Vg=1.0
% INFO    : Gen at bus 7238	: Pg=-16.8, Qg=9.36 -> Pg=38.8, Qg=5.465
% INFO    : Gen at bus 7238	: Vg=1.019781 -> Vg=1.0
% INFO    : Gen at bus 7250	: Pg=19.58, Qg=1.9 -> Pg=20.0, Qg=4.78
% INFO    : Gen at bus 7250	: Vg=1.041313 -> Vg=1.0
% INFO    : Gen at bus 7257	: Pg=21.3, Qg=-8.32 -> Pg=53.645, Qg=0.27
% INFO    : Gen at bus 7257	: Vg=1.023182 -> Vg=1.0
% INFO    : Gen at bus 7260	: Pg=32.0, Qg=5.76 -> Pg=21.8, Qg=3.725
% INFO    : Gen at bus 7260	: Vg=1.020734 -> Vg=1.0
% INFO    : Gen at bus 7267	: Pg=-39.7, Qg=40.06 -> Pg=23.535, Qg=27.5
% INFO    : Gen at bus 7267	: Vg=1.006635 -> Vg=1.0
% INFO    : Gen at bus 7270	: Pg=766.8, Qg=125.58 -> Pg=600.0, Qg=119.37
% INFO    : Gen at bus 7270	: Vg=1.063771 -> Vg=1.0
% INFO    : Gen at bus 7278	: Pg=354.7, Qg=-48.14 -> Pg=266.665, Qg=51.48
% INFO    : Gen at bus 7278	: Vg=1.063694 -> Vg=1.0
% INFO    : Gen at bus 7279	: Pg=-681.7, Qg=7.51 -> Pg=-404.465, Qg=4.07
% INFO    : Gen at bus 7279	: Vg=1.02664 -> Vg=1.0
% INFO    : Gen at bus 7281	: Pg=460.5, Qg=-70.11 -> Pg=336.86, Qg=-15.21
% INFO    : Gen at bus 7281	: Vg=1.020691 -> Vg=1.0
% INFO    : Gen at bus 7282	: Pg=2340.4, Qg=58.73 -> Pg=2666.665, Qg=637.065
% INFO    : Gen at bus 7282	: Vg=1.029197 -> Vg=1.0
% INFO    : Gen at bus 7293	: Pg=-64.7, Qg=6.49 -> Pg=6.865, Qg=12.795
% INFO    : Gen at bus 7293	: Vg=1.029739 -> Vg=1.0
% INFO    : Gen at bus 7303	: Pg=856.4, Qg=-33.97 -> Pg=600.0, Qg=108.65
% INFO    : Gen at bus 7303	: Vg=1.026431 -> Vg=1.0
% INFO    : Gen at bus 7327	: Pg=59.06, Qg=21.53 -> Pg=80.0, Qg=26.245
% INFO    : Gen at bus 7327	: Vg=1.046207 -> Vg=1.0
% INFO    : Gen at bus 7328	: Pg=53.0, Qg=24.52 -> Pg=40.0, Qg=12.53
% INFO    : Gen at bus 7328	: Vg=0.98954 -> Vg=1.0
% INFO    : Gen at bus 7329	: Pg=62.8, Qg=8.94 -> Pg=40.0, Qg=11.355
% INFO    : Gen at bus 7329	: Vg=1.037608 -> Vg=1.0
% INFO    : Gen at bus 7330	: Pg=399.0, Qg=147.35 -> Pg=267.34, Qg=44.65
% INFO    : Gen at bus 7330	: Vg=1.166291 -> Vg=1.0
% INFO    : Gen at bus 7331	: Pg=32.1, Qg=4.28 -> Pg=20.0, Qg=5.655
% INFO    : Gen at bus 7331	: Vg=1.064241 -> Vg=1.0
% INFO    : Gen at bus 7337	: Pg=30.6, Qg=8.42 -> Pg=16.065, Qg=9.065
% INFO    : Gen at bus 7337	: Vg=1.015107 -> Vg=1.0
% INFO    : Gen at bus 7350	: Pg=165.6, Qg=-8.63 -> Pg=87.02, Qg=-23.69
% INFO    : Gen at bus 7350	: Vg=1.027675 -> Vg=1.0
% INFO    : Gen at bus 7359	: Pg=116.8, Qg=5.3 -> Pg=60.0, Qg=14.105
% INFO    : Gen at bus 7359	: Vg=1.046487 -> Vg=1.0
% INFO    : Gen at bus 7363	: Pg=-134.8, Qg=-2.96 -> Pg=-39.865, Qg=-2.515
% INFO    : Gen at bus 7363	: Vg=1.005537 -> Vg=1.0
% INFO    : Gen at bus 7370	: Pg=-22.3, Qg=-0.2 -> Pg=35.135, Qg=0.615
% INFO    : Gen at bus 7370	: Vg=1.034338 -> Vg=1.0
% INFO    : Gen at bus 7376	: Pg=80.4, Qg=8.84 -> Pg=60.0, Qg=18.78
% INFO    : Gen at bus 7376	: Vg=1.041198 -> Vg=1.0
% INFO    : Gen at bus 7383	: Pg=100.6, Qg=7.5 -> Pg=67.6, Qg=11.5
% INFO    : Gen at bus 7383	: Vg=1.011076 -> Vg=1.0
% INFO    : Gen at bus 7386	: Pg=124.0, Qg=-8.83 -> Pg=65.1, Qg=-13.39
% INFO    : Gen at bus 7386	: Vg=1.023477 -> Vg=1.0
% INFO    : Gen at bus 7393	: Pg=-8.75, Qg=-10.7 -> Pg=44.17, Qg=2.105
% INFO    : Gen at bus 7393	: Vg=1.057049 -> Vg=1.0
% INFO    : Gen at bus 7401	: Pg=242.4, Qg=117.46 -> Pg=150.0, Qg=41.93
% INFO    : Gen at bus 7401	: Vg=1.018508 -> Vg=1.0
% INFO    : Gen at bus 7408	: Pg=1485.2, Qg=99.7 -> Pg=1202.665, Qg=30.49
% INFO    : Gen at bus 7408	: Vg=1.010858 -> Vg=1.0
% INFO    : Gen at bus 7427	: Pg=856.4, Qg=-30.15 -> Pg=1066.665, Qg=263.095
% INFO    : Gen at bus 7427	: Vg=1.072596 -> Vg=1.0
% INFO    : Gen at bus 7429	: Pg=159.8, Qg=-4.54 -> Pg=120.0, Qg=8.815
% INFO    : Gen at bus 7429	: Vg=1.011339 -> Vg=1.0
% INFO    : Gen at bus 7431	: Pg=735.6, Qg=-104.15 -> Pg=600.0, Qg=124.25
% INFO    : Gen at bus 7431	: Vg=1.016271 -> Vg=1.0
% INFO    : Gen at bus 7432	: Pg=49.6, Qg=3.49 -> Pg=40.0, Qg=12.755
% INFO    : Gen at bus 7432	: Vg=1.040989 -> Vg=1.0
% INFO    : Gen at bus 7446	: Pg=13.3, Qg=-1.36 -> Pg=20.48, Qg=0.865
% INFO    : Gen at bus 7446	: Vg=1.008326 -> Vg=1.0
% INFO    : Gen at bus 7465	: Pg=-7.55, Qg=6.29 -> Pg=44.965, Qg=9.29
% INFO    : Gen at bus 7465	: Vg=1.012708 -> Vg=1.0
% INFO    : Gen at bus 7466	: Pg=-202.53, Qg=35.04 -> Pg=-85.02, Qg=-0.605
% INFO    : Gen at bus 7466	: Vg=1.060565 -> Vg=1.0
% INFO    : Gen at bus 7474	: Pg=76.5, Qg=9.57 -> Pg=60.0, Qg=18.93
% INFO    : Gen at bus 7474	: Vg=1.035524 -> Vg=1.0
% INFO    : Gen at bus 7490	: Pg=-2.2, Qg=-34.65 -> Pg=48.535, Qg=21.79
% INFO    : Gen at bus 7490	: Vg=1.097048 -> Vg=1.0
% INFO    : Gen at bus 7495	: Pg=75.8, Qg=60.86 -> Pg=125.265, Qg=77.23
% INFO    : Gen at bus 7495	: Vg=1.031216 -> Vg=1.0
% INFO    : Gen at bus 7498	: Pg=-108.9, Qg=-8.62 -> Pg=-22.6, Qg=-5.205
% INFO    : Gen at bus 7498	: Vg=1.000261 -> Vg=1.0
% INFO    : Gen at bus 7499	: Pg=47.8, Qg=-14.94 -> Pg=65.935, Qg=29.01
% INFO    : Gen at bus 7499	: Vg=0.999526 -> Vg=1.0
% INFO    : Gen at bus 7504	: Pg=5.2, Qg=-0.4 -> Pg=2.65, Qg=0.595
% INFO    : Gen at bus 7504	: Vg=1.015325 -> Vg=1.0
% INFO    : Gen at bus 7508	: Pg=715.1, Qg=-115.84 -> Pg=600.0, Qg=126.49
% INFO    : Gen at bus 7508	: Vg=1.058554 -> Vg=1.0
% INFO    : Gen at bus 7520	: Pg=702.4, Qg=259.25 -> Pg=533.335, Qg=104.815
% INFO    : Gen at bus 7520	: Vg=1.027003 -> Vg=1.0
% INFO    : Gen at bus 7522	: Pg=508.0, Qg=234.68 -> Pg=533.335, Qg=125.72
% INFO    : Gen at bus 7522	: Vg=0.995659 -> Vg=1.0
% INFO    : Gen at bus 7558	: Pg=-75.5, Qg=-1.14 -> Pg=-0.335, Qg=-0.57
% INFO    : Gen at bus 7558	: Vg=1.005058 -> Vg=1.0
% INFO    : Gen at bus 7568	: Pg=100.8, Qg=11.35 -> Pg=60.0, Qg=16.07
% INFO    : Gen at bus 7568	: Vg=1.043388 -> Vg=1.0
% INFO    : Gen at bus 7607	: Pg=166.09, Qg=18.53 -> Pg=140.0, Qg=44.635
% INFO    : Gen at bus 7607	: Vg=1.054831 -> Vg=1.0
% INFO    : Gen at bus 7616	: Pg=375.8, Qg=226.75 -> Pg=400.0, Qg=93.555
% INFO    : Gen at bus 7616	: Vg=1.131608 -> Vg=1.0
% INFO    : Gen at bus 7619	: Pg=115.8, Qg=13.16 -> Pg=60.0, Qg=14.2
% INFO    : Gen at bus 7619	: Vg=1.037789 -> Vg=1.0
% INFO    : Gen at bus 7627	: Pg=261.97, Qg=91.09 -> Pg=266.665, Qg=58.275
% INFO    : Gen at bus 7627	: Vg=1.054377 -> Vg=1.0
% INFO    : Gen at bus 7628	: Pg=243.0, Qg=91.06 -> Pg=200.0, Qg=41.87
% INFO    : Gen at bus 7628	: Vg=1.064136 -> Vg=1.0
% INFO    : Gen at bus 7630	: Pg=33.09, Qg=-15.93 -> Pg=65.91, Qg=2.675
% INFO    : Gen at bus 7630	: Vg=1.017306 -> Vg=1.0
% INFO    : Gen at bus 7639	: Pg=-72.7, Qg=7.55 -> Pg=1.535, Qg=9.38
% INFO    : Gen at bus 7639	: Vg=1.016695 -> Vg=1.0
% INFO    : Gen at bus 7641	: Pg=769.2, Qg=27.55 -> Pg=540.0, Qg=107.93
% INFO    : Gen at bus 7641	: Vg=1.049265 -> Vg=1.0
% INFO    : Gen at bus 7645	: Pg=-95.8, Qg=-1.08 -> Pg=-13.865, Qg=-0.575
% INFO    : Gen at bus 7645	: Vg=1.028371 -> Vg=1.0
% INFO    : Gen at bus 7656	: Pg=101.6, Qg=-32.92 -> Pg=173.52, Qg=6.645
% INFO    : Gen at bus 7656	: Vg=1.013707 -> Vg=1.0
% INFO    : Gen at bus 7657	: Pg=378.0, Qg=165.57 -> Pg=266.665, Qg=49.71
% INFO    : Gen at bus 7657	: Vg=1.129049 -> Vg=1.0
% INFO    : Gen at bus 7659	: Pg=-39.5, Qg=-0.51 -> Pg=23.665, Qg=24.96
% INFO    : Gen at bus 7659	: Vg=1.029603 -> Vg=1.0
% INFO    : Gen at bus 7661	: Pg=168.6, Qg=8.37 -> Pg=90.0, Qg=21.48
% INFO    : Gen at bus 7661	: Vg=1.037591 -> Vg=1.0
% INFO    : Gen at bus 7670	: Pg=-30.87, Qg=10.15 -> Pg=29.42, Qg=9.69
% INFO    : Gen at bus 7670	: Vg=1.005135 -> Vg=1.0
% INFO    : Gen at bus 7671	: Pg=285.1, Qg=-20.5 -> Pg=266.665, Qg=60.31
% INFO    : Gen at bus 7671	: Vg=1.080257 -> Vg=1.0
% INFO    : Gen at bus 7676	: Pg=46.6, Qg=12.69 -> Pg=40.0, Qg=13.11
% INFO    : Gen at bus 7676	: Vg=1.074322 -> Vg=1.0
% INFO    : Gen at bus 7681	: Pg=330.06, Qg=13.88 -> Pg=200.0, Qg=51.435
% INFO    : Gen at bus 7681	: Vg=1.052405 -> Vg=1.0
% INFO    : Gen at bus 7683	: Pg=40.5, Qg=-7.8 -> Pg=21.25, Qg=-3.96
% INFO    : Gen at bus 7683	: Vg=1.038382 -> Vg=1.0
% INFO    : Gen at bus 7687	: Pg=-40.2, Qg=17.73 -> Pg=23.2, Qg=13.03
% INFO    : Gen at bus 7687	: Vg=1.043409 -> Vg=1.0
% INFO    : Gen at bus 7697	: Pg=228.2, Qg=0.49 -> Pg=140.0, Qg=39.45
% INFO    : Gen at bus 7697	: Vg=1.050111 -> Vg=1.0
% INFO    : Gen at bus 7707	: Pg=-93.9, Qg=11.6 -> Pg=-12.6, Qg=13.78
% INFO    : Gen at bus 7707	: Vg=1.042135 -> Vg=1.0
% INFO    : Gen at bus 7718	: Pg=348.0, Qg=87.15 -> Pg=266.665, Qg=51.345
% INFO    : Gen at bus 7718	: Vg=1.008757 -> Vg=1.0
% INFO    : Gen at bus 7728	: Pg=420.0, Qg=-22.62 -> Pg=314.665, Qg=19.975
% INFO    : Gen at bus 7728	: Vg=1.008042 -> Vg=1.0
% INFO    : Gen at bus 7737	: Pg=24.26, Qg=3.69 -> Pg=40.0, Qg=11.95
% INFO    : Gen at bus 7737	: Vg=1.061861 -> Vg=1.0
% INFO    : Gen at bus 7742	: Pg=-18.64, Qg=4.17 -> Pg=37.57, Qg=6.68
% INFO    : Gen at bus 7742	: Vg=1.016237 -> Vg=1.0
% INFO    : Gen at bus 7743	: Pg=229.6, Qg=20.17 -> Pg=120.0, Qg=24.14
% INFO    : Gen at bus 7743	: Vg=1.011249 -> Vg=1.0
% INFO    : Gen at bus 7755	: Pg=6.3, Qg=-0.96 -> Pg=6.45, Qg=0.605
% INFO    : Gen at bus 7755	: Vg=1.058479 -> Vg=1.0
% INFO    : Gen at bus 7758	: Pg=382.8, Qg=-18.73 -> Pg=220.0, Qg=58.235
% INFO    : Gen at bus 7758	: Vg=1.059721 -> Vg=1.0
% INFO    : Gen at bus 7759	: Pg=1425.1, Qg=688.92 -> Pg=1000.0, Qg=209.285
% INFO    : Gen at bus 7759	: Vg=1.17759 -> Vg=1.0
% INFO    : Gen at bus 7761	: Pg=106.8, Qg=15.27 -> Pg=60.0, Qg=15.39
% INFO    : Gen at bus 7761	: Vg=1.012378 -> Vg=1.0
% INFO    : Gen at bus 7776	: Pg=1221.2, Qg=403.17 -> Pg=1333.335, Qg=321.605
% INFO    : Gen at bus 7776	: Vg=1.077614 -> Vg=1.0
% INFO    : Gen at bus 7779	: Pg=345.2, Qg=157.99 -> Pg=400.0, Qg=98.05
% INFO    : Gen at bus 7779	: Vg=1.0806 -> Vg=1.0
% INFO    : Gen at bus 7785	: Pg=212.4, Qg=26.57 -> Pg=120.0, Qg=31.11
% INFO    : Gen at bus 7785	: Vg=1.048533 -> Vg=1.0
% INFO    : Gen at bus 7798	: Pg=47.6, Qg=-0.3 -> Pg=40.0, Qg=12.895
% INFO    : Gen at bus 7798	: Vg=1.015906 -> Vg=1.0
% INFO    : Gen at bus 7800	: Pg=76.49, Qg=8.33 -> Pg=60.0, Qg=17.715
% INFO    : Gen at bus 7800	: Vg=1.005948 -> Vg=1.0
% INFO    : Gen at bus 7808	: Pg=1250.4, Qg=286.78 -> Pg=1333.335, Qg=314.335
% INFO    : Gen at bus 7808	: Vg=1.050047 -> Vg=1.0
% INFO    : Gen at bus 7819	: Pg=25.6, Qg=-4.18 -> Pg=25.77, Qg=2.23
% INFO    : Gen at bus 7819	: Vg=1.018324 -> Vg=1.0
% INFO    : Gen at bus 7833	: Pg=15.5, Qg=50.12 -> Pg=120.0, Qg=31.98
% INFO    : Gen at bus 7833	: Vg=1.015416 -> Vg=1.0
% INFO    : Gen at bus 7835	: Pg=23.5, Qg=8.52 -> Pg=90.0, Qg=26.12
% INFO    : Gen at bus 7835	: Vg=1.037848 -> Vg=1.0
% INFO    : Gen at bus 7836	: Pg=14.9, Qg=0.18 -> Pg=7.61, Qg=1.66
% INFO    : Gen at bus 7836	: Vg=0.997593 -> Vg=1.0
% INFO    : Gen at bus 7842	: Pg=165.0, Qg=30.82 -> Pg=100.0, Qg=27.76
% INFO    : Gen at bus 7842	: Vg=1.014075 -> Vg=1.0
% INFO    : Gen at bus 7843	: Pg=390.4, Qg=37.76 -> Pg=200.0, Qg=47.34
% INFO    : Gen at bus 7843	: Vg=1.056109 -> Vg=1.0
% INFO    : Gen at bus 7854	: Pg=4.8, Qg=-33.27 -> Pg=51.6, Qg=53.17
% INFO    : Gen at bus 7854	: Vg=1.018633 -> Vg=1.0
% INFO    : Gen at bus 7860	: Pg=397.0, Qg=-58.45 -> Pg=533.335, Qg=135.225
% INFO    : Gen at bus 7860	: Vg=1.054905 -> Vg=1.0
% INFO    : Gen at bus 7880	: Pg=436.0, Qg=206.76 -> Pg=333.335, Qg=63.98
% INFO    : Gen at bus 7880	: Vg=1.024905 -> Vg=1.0
% INFO    : Gen at bus 7890	: Pg=-99.0, Qg=5.82 -> Pg=-16.0, Qg=6.295
% INFO    : Gen at bus 7890	: Vg=1.05789 -> Vg=1.0
% INFO    : Gen at bus 7894	: Pg=150.1, Qg=-24.46 -> Pg=83.895, Qg=7.805
% INFO    : Gen at bus 7894	: Vg=1.044899 -> Vg=1.0
% INFO    : Gen at bus 7896	: Pg=216.8, Qg=9.94 -> Pg=160.0, Qg=49.605
% INFO    : Gen at bus 7896	: Vg=1.054626 -> Vg=1.0
% INFO    : Gen at bus 7913	: Pg=1368.6, Qg=134.37 -> Pg=1333.335, Qg=307.415
% INFO    : Gen at bus 7913	: Vg=1.0583 -> Vg=1.0
% INFO    : Gen at bus 7926	: Pg=-157.2, Qg=-16.55 -> Pg=-54.8, Qg=-6.265
% INFO    : Gen at bus 7926	: Vg=1.033819 -> Vg=1.0
% INFO    : Gen at bus 7929	: Pg=1101.5, Qg=-34.68 -> Pg=1066.665, Qg=207.95
% INFO    : Gen at bus 7929	: Vg=1.044801 -> Vg=1.0
% INFO    : Gen at bus 7934	: Pg=207.9, Qg=-41.49 -> Pg=150.0, Qg=44.24
% INFO    : Gen at bus 7934	: Vg=1.090866 -> Vg=1.0
% INFO    : Gen at bus 7940	: Pg=411.8, Qg=64.52 -> Pg=400.0, Qg=90.555
% INFO    : Gen at bus 7940	: Vg=1.036846 -> Vg=1.0
% INFO    : Gen at bus 7949	: Pg=75.6, Qg=-20.49 -> Pg=39.69, Qg=-5.81
% INFO    : Gen at bus 7949	: Vg=1.033042 -> Vg=1.0
% INFO    : Gen at bus 7953	: Pg=-175.7, Qg=51.03 -> Pg=-67.135, Qg=99.305
% INFO    : Gen at bus 7953	: Vg=1.067896 -> Vg=1.0
% INFO    : Gen at bus 7960	: Pg=419.0, Qg=107.78 -> Pg=400.0, Qg=90.49
% INFO    : Gen at bus 7960	: Vg=1.017582 -> Vg=1.0
% INFO    : Gen at bus 7964	: Pg=144.4, Qg=11.79 -> Pg=75.8, Qg=10.535
% INFO    : Gen at bus 7964	: Vg=1.005985 -> Vg=1.0
% INFO    : Gen at bus 7979	: Pg=1637.1, Qg=-390.58 -> Pg=2133.335, Qg=508.205
% INFO    : Gen at bus 7979	: Vg=1.064388 -> Vg=1.0
% INFO    : Gen at bus 7983	: Pg=189.3, Qg=-45.62 -> Pg=162.435, Qg=-6.7
% INFO    : Gen at bus 7983	: Vg=1.014534 -> Vg=1.0
% INFO    : Gen at bus 7995	: Pg=60.0, Qg=-10.75 -> Pg=31.5, Qg=-6.995
% INFO    : Gen at bus 7995	: Vg=1.024627 -> Vg=1.0
% INFO    : Gen at bus 7998	: Pg=811.8, Qg=72.83 -> Pg=600.0, Qg=115.31
% INFO    : Gen at bus 7998	: Vg=1.046131 -> Vg=1.0
% INFO    : Gen at bus 8036	: Pg=-4.64, Qg=3.9 -> Pg=46.905, Qg=9.785
% INFO    : Gen at bus 8036	: Vg=1.029729 -> Vg=1.0
% INFO    : Gen at bus 8043	: Pg=-27.0, Qg=9.24 -> Pg=32.0, Qg=25.855
% INFO    : Gen at bus 8043	: Vg=1.058234 -> Vg=1.0
% INFO    : Gen at bus 8044	: Pg=337.6, Qg=73.11 -> Pg=400.0, Qg=97.96
% INFO    : Gen at bus 8044	: Vg=1.041629 -> Vg=1.0
% INFO    : Gen at bus 8045	: Pg=7.4, Qg=2.88 -> Pg=5.49, Qg=1.225
% INFO    : Gen at bus 8045	: Vg=1.023558 -> Vg=1.0
% INFO    : Gen at bus 8065	: Pg=399.4, Qg=-33.09 -> Pg=400.0, Qg=93.095
% INFO    : Gen at bus 8065	: Vg=1.059118 -> Vg=1.0
% INFO    : Gen at bus 8066	: Pg=-188.9, Qg=-1.29 -> Pg=-75.935, Qg=0.6
% INFO    : Gen at bus 8066	: Vg=1.011708 -> Vg=1.0
% INFO    : Gen at bus 8085	: Pg=94.6, Qg=-14.36 -> Pg=49.61, Qg=-9.76
% INFO    : Gen at bus 8085	: Vg=1.020835 -> Vg=1.0
% INFO    : Gen at bus 8087	: Pg=322.12, Qg=-42.11 -> Pg=210.0, Qg=48.475
% INFO    : Gen at bus 8087	: Vg=1.027752 -> Vg=1.0
% INFO    : Gen at bus 8096	: Pg=46.9, Qg=2.83 -> Pg=40.0, Qg=12.76
% INFO    : Gen at bus 8096	: Vg=1.065973 -> Vg=1.0
% INFO    : Gen at bus 8101	: Pg=76.3, Qg=40.77 -> Pg=230.655, Qg=-1.11
% INFO    : Gen at bus 8101	: Vg=1.059601 -> Vg=1.0
% INFO    : Gen at bus 8105	: Pg=22.5, Qg=0.03 -> Pg=11.81, Qg=1.165
% INFO    : Gen at bus 8105	: Vg=1.013571 -> Vg=1.0
% INFO    : Gen at bus 8109	: Pg=992.0, Qg=834.95 -> Pg=520.8, Qg=0.0
% INFO    : Gen at bus 8109	: Vg=1.059636 -> Vg=1.0
% INFO    : Gen at bus 8116	: Pg=110.5, Qg=-22.04 -> Pg=163.325, Qg=0.155
% INFO    : Gen at bus 8116	: Vg=1.035167 -> Vg=1.0
% INFO    : Gen at bus 8117	: Pg=962.42, Qg=143.88 -> Pg=800.0, Qg=157.36
% INFO    : Gen at bus 8117	: Vg=1.032328 -> Vg=1.0
% INFO    : Gen at bus 8119	: Pg=75.8, Qg=12.03 -> Pg=40.0, Qg=9.625
% INFO    : Gen at bus 8119	: Vg=1.073486 -> Vg=1.0
% INFO    : Gen at bus 8123	: Pg=57.4, Qg=29.59 -> Pg=40.0, Qg=11.935
% INFO    : Gen at bus 8123	: Vg=1.009241 -> Vg=1.0
% INFO    : Gen at bus 8134	: Pg=56.8, Qg=29.63 -> Pg=40.0, Qg=11.98
% INFO    : Gen at bus 8134	: Vg=1.008958 -> Vg=1.0
% INFO    : Gen at bus 8136	: Pg=-60.6, Qg=-0.67 -> Pg=9.6, Qg=-0.14
% INFO    : Gen at bus 8136	: Vg=1.028389 -> Vg=1.0
% INFO    : Gen at bus 8156	: Pg=178.0, Qg=7.63 -> Pg=133.335, Qg=26.02
% INFO    : Gen at bus 8156	: Vg=1.075225 -> Vg=1.0
% INFO    : Gen at bus 8157	: Pg=314.0, Qg=47.92 -> Pg=266.665, Qg=56.62
% INFO    : Gen at bus 8157	: Vg=1.045038 -> Vg=1.0
% INFO    : Gen at bus 8158	: Pg=153.0, Qg=-3.21 -> Pg=100.0, Qg=29.33
% INFO    : Gen at bus 8158	: Vg=1.051259 -> Vg=1.0
% INFO    : Gen at bus 8159	: Pg=698.6, Qg=-93.08 -> Pg=473.245, Qg=77.15
% INFO    : Gen at bus 8159	: Vg=1.060727 -> Vg=1.0
% INFO    : Gen at bus 8185	: Pg=116.8, Qg=45.07 -> Pg=147.175, Qg=8.725
% INFO    : Gen at bus 8185	: Vg=1.028753 -> Vg=1.0
% INFO    : Gen at bus 8187	: Pg=386.04, Qg=207.25 -> Pg=333.335, Qg=65.595
% INFO    : Gen at bus 8187	: Vg=1.0215 -> Vg=1.0
% INFO    : Gen at bus 8203	: Pg=-83.2, Qg=0.09 -> Pg=-5.465, Qg=4.475
% INFO    : Gen at bus 8203	: Vg=1.008878 -> Vg=1.0
% INFO    : Gen at bus 8207	: Pg=1.75, Qg=-40.48 -> Pg=103.635, Qg=1.86
% INFO    : Gen at bus 8207	: Vg=1.029137 -> Vg=1.0
% INFO    : Gen at bus 8210	: Pg=1321.7, Qg=-224.83 -> Pg=1066.665, Qg=219.065
% INFO    : Gen at bus 8210	: Vg=1.044939 -> Vg=1.0
% INFO    : Gen at bus 8212	: Pg=49.8, Qg=19.31 -> Pg=40.0, Qg=12.61
% INFO    : Gen at bus 8212	: Vg=1.009223 -> Vg=1.0
% INFO    : Gen at bus 8215	: Pg=103.8, Qg=7.37 -> Pg=60.0, Qg=15.38
% INFO    : Gen at bus 8215	: Vg=1.031215 -> Vg=1.0
% INFO    : Gen at bus 8218	: Pg=82.0, Qg=-0.38 -> Pg=43.05, Qg=1.18
% INFO    : Gen at bus 8218	: Vg=1.013588 -> Vg=1.0
% INFO    : Gen at bus 8222	: Pg=66.8, Qg=15.48 -> Pg=40.0, Qg=10.855
% INFO    : Gen at bus 8222	: Vg=1.013304 -> Vg=1.0
% INFO    : Gen at bus 8223	: Pg=401.0, Qg=137.22 -> Pg=400.0, Qg=92.965
% INFO    : Gen at bus 8223	: Vg=1.056121 -> Vg=1.0
% INFO    : Gen at bus 8225	: Pg=17.0, Qg=5.38 -> Pg=20.0, Qg=7.035
% INFO    : Gen at bus 8225	: Vg=1.062685 -> Vg=1.0
% INFO    : Gen at bus 8227	: Pg=483.0, Qg=-58.9 -> Pg=372.0, Qg=-56.55
% INFO    : Gen at bus 8227	: Vg=1.022197 -> Vg=1.0
% INFO    : Gen at bus 8240	: Pg=-15.64, Qg=-15.94 -> Pg=39.575, Qg=0.375
% INFO    : Gen at bus 8240	: Vg=1.056841 -> Vg=1.0
% INFO    : Gen at bus 8242	: Pg=358.36, Qg=-20.32 -> Pg=210.0, Qg=48.94
% INFO    : Gen at bus 8242	: Vg=1.010793 -> Vg=1.0
% INFO    : Gen at bus 8247	: Pg=253.4, Qg=-36.5 -> Pg=180.0, Qg=53.725
% INFO    : Gen at bus 8247	: Vg=1.055867 -> Vg=1.0
% INFO    : Gen at bus 8252	: Pg=320.6, Qg=50.95 -> Pg=266.665, Qg=55.385
% INFO    : Gen at bus 8252	: Vg=1.02226 -> Vg=1.0
% INFO    : Gen at bus 8267	: Pg=203.4, Qg=1.68 -> Pg=120.0, Qg=32.14
% INFO    : Gen at bus 8267	: Vg=1.042576 -> Vg=1.0
% INFO    : Gen at bus 8269	: Pg=12.89, Qg=2.61 -> Pg=20.0, Qg=6.47
% INFO    : Gen at bus 8269	: Vg=1.039628 -> Vg=1.0
% INFO    : Gen at bus 8278	: Pg=97.2, Qg=11.03 -> Pg=60.0, Qg=16.54
% INFO    : Gen at bus 8278	: Vg=1.005256 -> Vg=1.0
% INFO    : Gen at bus 8297	: Pg=87.2, Qg=-8.2 -> Pg=45.78, Qg=-10.1
% INFO    : Gen at bus 8297	: Vg=1.024007 -> Vg=1.0
% INFO    : Gen at bus 8304	: Pg=411.8, Qg=64.09 -> Pg=400.0, Qg=90.555
% INFO    : Gen at bus 8304	: Vg=1.036714 -> Vg=1.0
% INFO    : Gen at bus 8311	: Pg=-8.75, Qg=3.46 -> Pg=44.17, Qg=5.335
% INFO    : Gen at bus 8311	: Vg=1.041866 -> Vg=1.0
% INFO    : Gen at bus 8312	: Pg=1702.2, Qg=438.81 -> Pg=1600.0, Qg=360.845
% INFO    : Gen at bus 8312	: Vg=1.075986 -> Vg=1.0
% INFO    : Gen at bus 8317	: Pg=1485.2, Qg=-75.45 -> Pg=1202.665, Qg=25.08
% INFO    : Gen at bus 8317	: Vg=1.000913 -> Vg=1.0
% INFO    : Gen at bus 8340	: Pg=95.05, Qg=-20.86 -> Pg=80.0, Qg=22.68
% INFO    : Gen at bus 8340	: Vg=1.020459 -> Vg=1.0
% INFO    : Gen at bus 8362	: Pg=407.0, Qg=44.27 -> Pg=220.0, Qg=55.555
% INFO    : Gen at bus 8362	: Vg=1.047632 -> Vg=1.0
% INFO    : Gen at bus 8371	: Pg=242.0, Qg=-6.52 -> Pg=266.665, Qg=63.29
% INFO    : Gen at bus 8371	: Vg=1.107597 -> Vg=1.0
% INFO    : Gen at bus 8375	: Pg=459.2, Qg=95.88 -> Pg=240.0, Qg=55.85
% INFO    : Gen at bus 8375	: Vg=1.024751 -> Vg=1.0
% INFO    : Gen at bus 8377	: Pg=163.23, Qg=37.86 -> Pg=200.0, Qg=43.97
% INFO    : Gen at bus 8377	: Vg=1.011199 -> Vg=1.0
% INFO    : Gen at bus 8378	: Pg=33.8, Qg=1.38 -> Pg=20.0, Qg=5.335
% INFO    : Gen at bus 8378	: Vg=1.020496 -> Vg=1.0
% INFO    : Gen at bus 8383	: Pg=331.0, Qg=79.17 -> Pg=333.335, Qg=72.935
% INFO    : Gen at bus 8383	: Vg=1.008495 -> Vg=1.0
% INFO    : Gen at bus 8384	: Pg=-35.8, Qg=6.59 -> Pg=26.135, Qg=10.015
% INFO    : Gen at bus 8384	: Vg=1.051363 -> Vg=1.0
% INFO    : Gen at bus 8398	: Pg=61.78, Qg=11.94 -> Pg=41.16, Qg=9.225
% INFO    : Gen at bus 8398	: Vg=1.034241 -> Vg=1.0
% INFO    : Gen at bus 8401	: Pg=414.97, Qg=61.1 -> Pg=533.335, Qg=132.32
% INFO    : Gen at bus 8401	: Vg=1.074893 -> Vg=1.0
% INFO    : Gen at bus 8413	: Pg=379.2, Qg=20.12 -> Pg=266.665, Qg=48.29
% INFO    : Gen at bus 8413	: Vg=1.031312 -> Vg=1.0
% INFO    : Gen at bus 8415	: Pg=425.0, Qg=-73.81 -> Pg=333.335, Qg=64.945
% INFO    : Gen at bus 8415	: Vg=1.082292 -> Vg=1.0
% INFO    : Gen at bus 8427	: Pg=50.0, Qg=27.87 -> Pg=40.0, Qg=12.71
% INFO    : Gen at bus 8427	: Vg=1.012295 -> Vg=1.0
% INFO    : Gen at bus 8433	: Pg=1.2, Qg=-51.84 -> Pg=50.4, Qg=135.75
% INFO    : Gen at bus 8433	: Vg=1.055181 -> Vg=1.0
% INFO    : Gen at bus 8451	: Pg=57.2, Qg=30.71 -> Pg=40.0, Qg=12.21
% INFO    : Gen at bus 8451	: Vg=0.998015 -> Vg=1.0
% INFO    : Gen at bus 8458	: Pg=517.1, Qg=-66.57 -> Pg=666.665, Qg=167.965
% INFO    : Gen at bus 8458	: Vg=1.042019 -> Vg=1.0
% INFO    : Gen at bus 8464	: Pg=194.6, Qg=52.62 -> Pg=133.335, Qg=23.265
% INFO    : Gen at bus 8464	: Vg=1.080213 -> Vg=1.0
% INFO    : Gen at bus 8473	: Pg=-135.0, Qg=4.31 -> Pg=-40.0, Qg=27.88
% INFO    : Gen at bus 8473	: Vg=1.038343 -> Vg=1.0
% INFO    : Gen at bus 8474	: Pg=592.44, Qg=150.22 -> Pg=533.335, Qg=111.47
% INFO    : Gen at bus 8474	: Vg=1.093709 -> Vg=1.0
% INFO    : Gen at bus 8481	: Pg=61.48, Qg=20.86 -> Pg=60.0, Qg=18.355
% INFO    : Gen at bus 8481	: Vg=1.035652 -> Vg=1.0
% INFO    : Gen at bus 8486	: Pg=78.8, Qg=8.89 -> Pg=40.0, Qg=9.245
% INFO    : Gen at bus 8486	: Vg=1.043845 -> Vg=1.0
% INFO    : Gen at bus 8515	: Pg=32.3, Qg=-7.39 -> Pg=100.0, Qg=30.8
% INFO    : Gen at bus 8515	: Vg=1.059651 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=44.8, Qg=-9.87 -> Pg=23.52, Qg=-4.41
% INFO    : Gen at bus 8518	: Vg=1.031547 -> Vg=1.0
% INFO    : Gen at bus 8522	: Pg=-75.69, Qg=0.41 -> Pg=-0.46, Qg=0.96
% INFO    : Gen at bus 8522	: Vg=1.027564 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=194.8, Qg=-6.11 -> Pg=133.335, Qg=22.135
% INFO    : Gen at bus 8531	: Vg=1.019991 -> Vg=1.0
% INFO    : Gen at bus 8532	: Pg=-697.25, Qg=-741.74 -> Pg=-414.835, Qg=0.0
% INFO    : Gen at bus 8532	: Vg=1.032486 -> Vg=1.0
% INFO    : Gen at bus 8553	: Pg=2486.5, Qg=568.35 -> Pg=2633.335, Qg=627.205
% INFO    : Gen at bus 8553	: Vg=1.077556 -> Vg=1.0
% INFO    : Gen at bus 8564	: Pg=-65.0, Qg=19.6 -> Pg=6.665, Qg=14.525
% INFO    : Gen at bus 8564	: Vg=1.01667 -> Vg=1.0
% INFO    : Gen at bus 8569	: Pg=296.8, Qg=65.13 -> Pg=266.665, Qg=58.525
% INFO    : Gen at bus 8569	: Vg=1.038006 -> Vg=1.0
% INFO    : Gen at bus 8576	: Pg=-1.0, Qg=2.92 -> Pg=49.335, Qg=3.39
% INFO    : Gen at bus 8576	: Vg=1.017525 -> Vg=1.0
% INFO    : Gen at bus 8586	: Pg=34.78, Qg=5.45 -> Pg=40.0, Qg=12.855
% INFO    : Gen at bus 8586	: Vg=1.002287 -> Vg=1.0
% INFO    : Gen at bus 8591	: Pg=342.49, Qg=-75.59 -> Pg=400.0, Qg=95.435
% INFO    : Gen at bus 8591	: Vg=1.06486 -> Vg=1.0
% INFO    : Gen at bus 8603	: Pg=205.2, Qg=-7.69 -> Pg=120.0, Qg=32.125
% INFO    : Gen at bus 8603	: Vg=1.022771 -> Vg=1.0
% INFO    : Gen at bus 8605	: Pg=427.0, Qg=174.48 -> Pg=400.0, Qg=90.145
% INFO    : Gen at bus 8605	: Vg=1.005953 -> Vg=1.0
% INFO    : Gen at bus 8608	: Pg=285.0, Qg=78.06 -> Pg=333.335, Qg=80.53
% INFO    : Gen at bus 8608	: Vg=1.033413 -> Vg=1.0
% INFO    : Gen at bus 8610	: Pg=-182.09, Qg=-0.22 -> Pg=-71.39, Qg=77.195
% INFO    : Gen at bus 8610	: Vg=1.056933 -> Vg=1.0
% INFO    : Gen at bus 8611	: Pg=-22.19, Qg=5.31 -> Pg=35.21, Qg=16.215
% INFO    : Gen at bus 8611	: Vg=1.024775 -> Vg=1.0
% INFO    : Gen at bus 8622	: Pg=109.2, Qg=32.5 -> Pg=60.0, Qg=15.425
% INFO    : Gen at bus 8622	: Vg=1.028478 -> Vg=1.0
% INFO    : Gen at bus 8623	: Pg=183.23, Qg=24.91 -> Pg=120.0, Qg=36.77
% INFO    : Gen at bus 8623	: Vg=1.034977 -> Vg=1.0
% INFO    : Gen at bus 8625	: Pg=20.3, Qg=-3.77 -> Pg=51.515, Qg=0.38
% INFO    : Gen at bus 8625	: Vg=1.051079 -> Vg=1.0
% INFO    : Gen at bus 8630	: Pg=298.2, Qg=-23.82 -> Pg=200.0, Qg=32.685
% INFO    : Gen at bus 8630	: Vg=1.059594 -> Vg=1.0
% INFO    : Gen at bus 8640	: Pg=264.3, Qg=117.08 -> Pg=150.0, Qg=39.245
% INFO    : Gen at bus 8640	: Vg=1.174902 -> Vg=1.0
% INFO    : Gen at bus 8663	: Pg=461.0, Qg=-38.92 -> Pg=333.335, Qg=55.4
% INFO    : Gen at bus 8663	: Vg=1.025281 -> Vg=1.0
% INFO    : Gen at bus 8670	: Pg=-138.3, Qg=13.27 -> Pg=-42.2, Qg=12.47
% INFO    : Gen at bus 8670	: Vg=1.042199 -> Vg=1.0
% INFO    : Gen at bus 8675	: Pg=47.0, Qg=12.59 -> Pg=40.0, Qg=13.095
% INFO    : Gen at bus 8675	: Vg=1.037158 -> Vg=1.0
% INFO    : Gen at bus 8676	: Pg=-259.1, Qg=16.18 -> Pg=-122.735, Qg=9.98
% INFO    : Gen at bus 8676	: Vg=1.019558 -> Vg=1.0
% INFO    : Gen at bus 8683	: Pg=-37.28, Qg=5.99 -> Pg=25.15, Qg=16.965
% INFO    : Gen at bus 8683	: Vg=1.039554 -> Vg=1.0
% INFO    : Gen at bus 8693	: Pg=62.2, Qg=10.25 -> Pg=40.0, Qg=11.475
% INFO    : Gen at bus 8693	: Vg=1.073334 -> Vg=1.0
% INFO    : Gen at bus 8702	: Pg=130.69, Qg=-8.78 -> Pg=180.0, Qg=62.765
% INFO    : Gen at bus 8702	: Vg=1.026759 -> Vg=1.0
% INFO    : Gen at bus 8714	: Pg=609.8, Qg=65.01 -> Pg=536.0, Qg=73.985
% INFO    : Gen at bus 8714	: Vg=1.015463 -> Vg=1.0
% INFO    : Gen at bus 8721	: Pg=1232.6, Qg=206.3 -> Pg=1333.335, Qg=319.77
% INFO    : Gen at bus 8721	: Vg=1.055054 -> Vg=1.0
% INFO    : Gen at bus 8729	: Pg=20.89, Qg=-6.14 -> Pg=50.18, Qg=2.075
% INFO    : Gen at bus 8729	: Vg=1.008386 -> Vg=1.0
% INFO    : Gen at bus 8737	: Pg=355.83, Qg=378.51 -> Pg=533.335, Qg=134.335
% INFO    : Gen at bus 8737	: Vg=1.058573 -> Vg=1.0
% INFO    : Gen at bus 8758	: Pg=675.23, Qg=59.97 -> Pg=533.335, Qg=101.17
% INFO    : Gen at bus 8758	: Vg=1.047294 -> Vg=1.0
% INFO    : Gen at bus 8762	: Pg=327.23, Qg=140.11 -> Pg=266.665, Qg=46.31
% INFO    : Gen at bus 8762	: Vg=1.046022 -> Vg=1.0
% INFO    : Gen at bus 8764	: Pg=128.6, Qg=13.58 -> Pg=192.87, Qg=55.395
% INFO    : Gen at bus 8764	: Vg=1.048209 -> Vg=1.0
% INFO    : Gen at bus 8770	: Pg=-40.4, Qg=4.29 -> Pg=23.065, Qg=6.785
% INFO    : Gen at bus 8770	: Vg=1.012975 -> Vg=1.0
% INFO    : Gen at bus 8771	: Pg=21.7, Qg=5.79 -> Pg=20.0, Qg=6.635
% INFO    : Gen at bus 8771	: Vg=1.006983 -> Vg=1.0
% INFO    : Gen at bus 8795	: Pg=166.2, Qg=-7.21 -> Pg=120.0, Qg=36.925
% INFO    : Gen at bus 8795	: Vg=1.052731 -> Vg=1.0
% INFO    : Gen at bus 8797	: Pg=29.7, Qg=-9.16 -> Pg=30.215, Qg=2.79
% INFO    : Gen at bus 8797	: Vg=1.072681 -> Vg=1.0
% INFO    : Gen at bus 8807	: Pg=-304.0, Qg=6.99 -> Pg=-152.665, Qg=10.885
% INFO    : Gen at bus 8807	: Vg=1.049311 -> Vg=1.0
% INFO    : Gen at bus 8818	: Pg=44.66, Qg=-0.48 -> Pg=80.0, Qg=27.06
% INFO    : Gen at bus 8818	: Vg=1.049908 -> Vg=1.0
% INFO    : Gen at bus 8820	: Pg=118.8, Qg=-7.91 -> Pg=133.335, Qg=31.72
% INFO    : Gen at bus 8820	: Vg=1.063983 -> Vg=1.0
% INFO    : Gen at bus 8822	: Pg=-59.72, Qg=46.21 -> Pg=10.185, Qg=70.11
% INFO    : Gen at bus 8822	: Vg=1.064182 -> Vg=1.0
% INFO    : Gen at bus 8851	: Pg=76.9, Qg=10.72 -> Pg=50.0, Qg=14.23
% INFO    : Gen at bus 8851	: Vg=1.063062 -> Vg=1.0
% INFO    : Gen at bus 8858	: Pg=42.8, Qg=-30.35 -> Pg=180.0, Qg=53.465
% INFO    : Gen at bus 8858	: Vg=1.023098 -> Vg=1.0
% INFO    : Gen at bus 8869	: Pg=334.4, Qg=42.17 -> Pg=533.335, Qg=139.235
% INFO    : Gen at bus 8869	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 8871	: Pg=-233.8, Qg=-23.38 -> Pg=-105.865, Qg=32.935
% INFO    : Gen at bus 8871	: Vg=1.032491 -> Vg=1.0
% INFO    : Gen at bus 8872	: Pg=1232.6, Qg=176.03 -> Pg=1333.335, Qg=319.77
% INFO    : Gen at bus 8872	: Vg=1.054777 -> Vg=1.0
% INFO    : Gen at bus 8875	: Pg=443.8, Qg=90.2 -> Pg=400.0, Qg=88.875
% INFO    : Gen at bus 8875	: Vg=1.045119 -> Vg=1.0
% INFO    : Gen at bus 8894	: Pg=299.8, Qg=22.2 -> Pg=266.665, Qg=57.345
% INFO    : Gen at bus 8894	: Vg=1.093076 -> Vg=1.0
% INFO    : Gen at bus 8896	: Pg=40.0, Qg=-3.41 -> Pg=21.0, Qg=-1.965
% INFO    : Gen at bus 8896	: Vg=1.032282 -> Vg=1.0
% INFO    : Gen at bus 8897	: Pg=26.05, Qg=3.47 -> Pg=60.0, Qg=19.145
% INFO    : Gen at bus 8897	: Vg=1.053267 -> Vg=1.0
% INFO    : Gen at bus 8903	: Pg=17.0, Qg=0.9 -> Pg=43.365, Qg=0.29
% INFO    : Gen at bus 8903	: Vg=1.023893 -> Vg=1.0
% INFO    : Gen at bus 8914	: Pg=50.4, Qg=14.68 -> Pg=40.0, Qg=12.365
% INFO    : Gen at bus 8914	: Vg=1.034467 -> Vg=1.0
% INFO    : Gen at bus 8920	: Pg=38.8, Qg=6.33 -> Pg=20.0, Qg=4.8
% INFO    : Gen at bus 8920	: Vg=1.01084 -> Vg=1.0
% INFO    : Gen at bus 8927	: Pg=37.2, Qg=14.46 -> Pg=40.0, Qg=13.76
% INFO    : Gen at bus 8927	: Vg=1.012236 -> Vg=1.0
% INFO    : Gen at bus 8944	: Pg=88.4, Qg=-9.35 -> Pg=50.0, Qg=12.305
% INFO    : Gen at bus 8944	: Vg=1.06934 -> Vg=1.0
% INFO    : Gen at bus 8946	: Pg=756.8, Qg=-111.17 -> Pg=533.335, Qg=93.92
% INFO    : Gen at bus 8946	: Vg=1.036925 -> Vg=1.0
% INFO    : Gen at bus 8950	: Pg=-255.7, Qg=11.51 -> Pg=-120.47, Qg=13.31
% INFO    : Gen at bus 8950	: Vg=1.050158 -> Vg=1.0
% INFO    : Gen at bus 8956	: Pg=498.4, Qg=92.59 -> Pg=400.0, Qg=82.335
% INFO    : Gen at bus 8956	: Vg=1.061596 -> Vg=1.0
% INFO    : Gen at bus 8961	: Pg=-61.8, Qg=-9.66 -> Pg=8.8, Qg=1.57
% INFO    : Gen at bus 8961	: Vg=1.043576 -> Vg=1.0
% INFO    : Gen at bus 8966	: Pg=203.1, Qg=-28.42 -> Pg=150.0, Qg=45.105
% INFO    : Gen at bus 8966	: Vg=1.087897 -> Vg=1.0
% INFO    : Gen at bus 8971	: Pg=-95.4, Qg=-5.46 -> Pg=-13.6, Qg=66.79
% INFO    : Gen at bus 8971	: Vg=1.043573 -> Vg=1.0
% INFO    : Gen at bus 8972	: Pg=25.3, Qg=7.2 -> Pg=20.0, Qg=6.265
% INFO    : Gen at bus 8972	: Vg=1.038393 -> Vg=1.0
% INFO    : Gen at bus 8973	: Pg=1624.7, Qg=-336.51 -> Pg=1333.335, Qg=245.94
% INFO    : Gen at bus 8973	: Vg=1.048016 -> Vg=1.0
% INFO    : Gen at bus 8976	: Pg=110.0, Qg=17.41 -> Pg=100.0, Qg=33.35
% INFO    : Gen at bus 8976	: Vg=1.04878 -> Vg=1.0
% INFO    : Gen at bus 8978	: Pg=567.23, Qg=27.21 -> Pg=533.335, Qg=114.65
% INFO    : Gen at bus 8978	: Vg=1.038763 -> Vg=1.0
% INFO    : Gen at bus 8981	: Pg=19.3, Qg=-11.77 -> Pg=48.99, Qg=0.24
% INFO    : Gen at bus 8981	: Vg=1.023844 -> Vg=1.0
% INFO    : Gen at bus 8987	: Pg=-21.95, Qg=-11.67 -> Pg=35.365, Qg=0.88
% INFO    : Gen at bus 8987	: Vg=1.045054 -> Vg=1.0
% INFO    : Gen at bus 8988	: Pg=70.0, Qg=-6.34 -> Pg=36.75, Qg=-5.2
% INFO    : Gen at bus 8988	: Vg=1.016047 -> Vg=1.0
% INFO    : Gen at bus 8993	: Pg=-46.19, Qg=4.21 -> Pg=19.21, Qg=14.08
% INFO    : Gen at bus 8993	: Vg=1.020391 -> Vg=1.0
% INFO    : Gen at bus 8997	: Pg=78.2, Qg=6.36 -> Pg=158.545, Qg=3.055
% INFO    : Gen at bus 8997	: Vg=1.01701 -> Vg=1.0
% INFO    : Gen at bus 9000	: Pg=341.2, Qg=25.87 -> Pg=266.665, Qg=52.67
% INFO    : Gen at bus 9000	: Vg=1.042081 -> Vg=1.0
% INFO    : Gen at bus 9001	: Pg=338.71, Qg=-10.47 -> Pg=333.335, Qg=67.175
% INFO    : Gen at bus 9001	: Vg=1.023475 -> Vg=1.0
% INFO    : Gen at bus 9013	: Pg=31.2, Qg=6.42 -> Pg=30.0, Qg=9.945
% INFO    : Gen at bus 9013	: Vg=1.023407 -> Vg=1.0
% INFO    : Gen at bus 9027	: Pg=458.0, Qg=43.78 -> Pg=533.335, Qg=130.97
% INFO    : Gen at bus 9027	: Vg=1.070556 -> Vg=1.0
% INFO    : Gen at bus 9034	: Pg=-138.3, Qg=-8.08 -> Pg=-42.2, Qg=-7.755
% INFO    : Gen at bus 9034	: Vg=1.005697 -> Vg=1.0
% INFO    : Gen at bus 9035	: Pg=25.86, Qg=13.24 -> Pg=40.0, Qg=11.495
% INFO    : Gen at bus 9035	: Vg=1.009337 -> Vg=1.0
% INFO    : Gen at bus 9039	: Pg=-39.85, Qg=-0.41 -> Pg=23.435, Qg=0.58
% INFO    : Gen at bus 9039	: Vg=1.017349 -> Vg=1.0
% INFO    : Gen at bus 9043	: Pg=-10.55, Qg=0.92 -> Pg=42.965, Qg=5.365
% INFO    : Gen at bus 9043	: Vg=1.018389 -> Vg=1.0
% INFO    : Gen at bus 9046	: Pg=340.4, Qg=-38.99 -> Pg=200.0, Qg=53.42
% INFO    : Gen at bus 9046	: Vg=1.070778 -> Vg=1.0
% INFO    : Gen at bus 9047	: Pg=238.0, Qg=-20.85 -> Pg=266.665, Qg=64.41
% INFO    : Gen at bus 9047	: Vg=1.03154 -> Vg=1.0
% INFO    : Gen at bus 9048	: Pg=144.0, Qg=16.2 -> Pg=100.0, Qg=30.145
% INFO    : Gen at bus 9048	: Vg=1.050428 -> Vg=1.0
% INFO    : Gen at bus 9054	: Pg=306.37, Qg=73.2 -> Pg=266.665, Qg=55.18
% INFO    : Gen at bus 9054	: Vg=1.116695 -> Vg=1.0
% INFO    : Gen at bus 9055	: Pg=-90.0, Qg=0.38 -> Pg=-10.0, Qg=0.685
% INFO    : Gen at bus 9055	: Vg=0.97622 -> Vg=1.0
% INFO    : Gen at bus 9058	: Pg=4.25, Qg=10.64 -> Pg=51.42, Qg=16.78
% INFO    : Gen at bus 9058	: Vg=1.013989 -> Vg=1.0
% INFO    : Gen at bus 9060	: Pg=-418.8, Qg=5.84 -> Pg=-229.2, Qg=9.89
% INFO    : Gen at bus 9060	: Vg=1.066622 -> Vg=1.0
% INFO    : Gen at bus 9067	: Pg=369.6, Qg=64.56 -> Pg=293.335, Qg=60.865
% INFO    : Gen at bus 9067	: Vg=1.03898 -> Vg=1.0
% INFO    : Gen at bus 9097	: Pg=40.1, Qg=0.82 -> Pg=20.58, Qg=4.565
% INFO    : Gen at bus 9097	: Vg=1.016295 -> Vg=1.0
% INFO    : Gen at bus 9099	: Pg=-89.8, Qg=8.34 -> Pg=-9.865, Qg=-2.63
% INFO    : Gen at bus 9099	: Vg=1.028779 -> Vg=1.0
% INFO    : Gen at bus 9100	: Pg=84.5, Qg=10.89 -> Pg=50.0, Qg=13.335
% INFO    : Gen at bus 9100	: Vg=1.07025 -> Vg=1.0
% INFO    : Gen at bus 9101	: Pg=698.8, Qg=5.65 -> Pg=666.665, Qg=136.535
% INFO    : Gen at bus 9101	: Vg=1.026276 -> Vg=1.0
% INFO    : Gen at bus 9103	: Pg=-58.6, Qg=-3.89 -> Pg=10.935, Qg=-4.055
% INFO    : Gen at bus 9103	: Vg=1.027331 -> Vg=1.0
% INFO    : Gen at bus 9105	: Pg=99.4, Qg=-13.56 -> Pg=66.665, Qg=10.05
% INFO    : Gen at bus 9105	: Vg=1.088711 -> Vg=1.0
% INFO    : Gen at bus 9108	: Pg=-34.07, Qg=1.26 -> Pg=27.29, Qg=2.245
% INFO    : Gen at bus 9108	: Vg=1.046328 -> Vg=1.0
% INFO    : Gen at bus 9110	: Pg=438.2, Qg=126.21 -> Pg=550.0, Qg=49.84
% INFO    : Gen at bus 9110	: Vg=1.126918 -> Vg=1.0
% INFO    : Gen at bus 9113	: Pg=123.4, Qg=13.71 -> Pg=62.89, Qg=12.79
% INFO    : Gen at bus 9113	: Vg=1.014547 -> Vg=1.0
% INFO    : Gen at bus 9125	: Pg=39.7, Qg=1.38 -> Pg=20.0, Qg=4.795
% INFO    : Gen at bus 9125	: Vg=1.042649 -> Vg=1.0
% INFO    : Gen at bus 9132	: Pg=663.0, Qg=67.31 -> Pg=533.335, Qg=109.925
% INFO    : Gen at bus 9132	: Vg=1.04609 -> Vg=1.0
% INFO    : Gen at bus 9137	: Pg=42.7, Qg=31.91 -> Pg=64.235, Qg=121.365
% INFO    : Gen at bus 9137	: Vg=1.048884 -> Vg=1.0
% INFO    : Gen at bus 9140	: Pg=-37.2, Qg=33.7 -> Pg=25.2, Qg=23.355
% INFO    : Gen at bus 9140	: Vg=1.042971 -> Vg=1.0
% INFO    : Gen at bus 9150	: Pg=860.8, Qg=118.28 -> Pg=666.665, Qg=133.05
% INFO    : Gen at bus 9150	: Vg=1.034687 -> Vg=1.0
% INFO    : Gen at bus 9161	: Pg=366.4, Qg=77.61 -> Pg=200.0, Qg=51.225
% INFO    : Gen at bus 9161	: Vg=1.033176 -> Vg=1.0
% INFO    : Gen at bus 9167	: Pg=119.1, Qg=9.75 -> Pg=90.0, Qg=27.505
% INFO    : Gen at bus 9167	: Vg=1.046867 -> Vg=1.0
% INFO    : Gen at bus 9168	: Pg=299.2, Qg=39.33 -> Pg=200.675, Qg=34.85
% INFO    : Gen at bus 9168	: Vg=1.076561 -> Vg=1.0
% INFO    : Gen at bus 9174	: Pg=-331.4, Qg=152.65 -> Pg=-170.935, Qg=62.92
% INFO    : Gen at bus 9174	: Vg=1.015292 -> Vg=1.0
% INFO    : Gen at bus 9180	: Pg=72.0, Qg=7.21 -> Pg=80.0, Qg=27.86
% INFO    : Gen at bus 9180	: Vg=1.053552 -> Vg=1.0
% INFO    : Gen at bus 9187	: Pg=47.1, Qg=6.95 -> Pg=30.0, Qg=8.42
% INFO    : Gen at bus 9187	: Vg=1.017206 -> Vg=1.0
% INFO    : Gen at bus 9195	: Pg=30.16, Qg=17.78 -> Pg=40.0, Qg=11.21
% INFO    : Gen at bus 9195	: Vg=1.025329 -> Vg=1.0
% INFO    : Gen at bus 9197	: Pg=46.4, Qg=-0.98 -> Pg=47.51, Qg=4.115
% INFO    : Gen at bus 9197	: Vg=1.017237 -> Vg=1.0
% INFO    : Gen at bus 9200	: Pg=292.5, Qg=104.97 -> Pg=150.0, Qg=34.88
% INFO    : Gen at bus 9200	: Vg=1.040977 -> Vg=1.0
% INFO    : Gen at bus 9215	: Pg=4.77, Qg=3.71 -> Pg=20.0, Qg=5.79
% INFO    : Gen at bus 9215	: Vg=1.008696 -> Vg=1.0
% INFO    : Gen at bus 9230	: Pg=-126.7, Qg=47.4 -> Pg=-34.465, Qg=36.04
% INFO    : Gen at bus 9230	: Vg=1.027519 -> Vg=1.0
% INFO    : Gen at bus 9235	: Pg=353.39, Qg=124.55 -> Pg=200.0, Qg=51.69
% INFO    : Gen at bus 9235	: Vg=1.04114 -> Vg=1.0
% INFO    : Gen at bus 9238	: Pg=829.8, Qg=16.82 -> Pg=800.0, Qg=184.045
% INFO    : Gen at bus 9238	: Vg=1.097633 -> Vg=1.0
% INFO    : Gen at bus 9239	: Pg=419.0, Qg=107.54 -> Pg=400.0, Qg=90.49
% INFO    : Gen at bus 9239	: Vg=1.017601 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
